# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-05-16 20:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_geo_db', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='is_private',
            field=models.BooleanField(default=False, help_text='Is this a location that should not be available to be seen publically?'),
        ),
    ]
