PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE "django_geo_db_state" ("state_id" integer NOT NULL PRIMARY KEY AUTOINCREMENT, "name" varchar(50) NOT NULL UNIQUE, "abbreviation" varchar(2) NOT NULL UNIQUE, "generated_name" varchar(50) NULL, "country_id" integer NOT NULL REFERENCES "django_geo_db_country" ("country_id"), "geocoordinate_id" integer NOT NULL REFERENCES "django_geo_db_geocoordinate" ("geocoordinate_id"), UNIQUE ("country_id", "name"));
INSERT INTO "django_geo_db_state" VALUES(1,'Alabama','AL','Alabama, US',222,235);
INSERT INTO "django_geo_db_state" VALUES(2,'Alaska','AK','Alaska, US',222,236);
INSERT INTO "django_geo_db_state" VALUES(3,'Arizona','AZ','Arizona, US',222,237);
INSERT INTO "django_geo_db_state" VALUES(4,'Arkansas','AR','Arkansas, US',222,238);
INSERT INTO "django_geo_db_state" VALUES(5,'American Samoa','AS','American Samoa, US',222,239);
INSERT INTO "django_geo_db_state" VALUES(6,'California','CA','California, US',222,240);
INSERT INTO "django_geo_db_state" VALUES(7,'Colorado','CO','Colorado, US',222,241);
INSERT INTO "django_geo_db_state" VALUES(8,'Connecticut','CT','Connecticut, US',222,242);
INSERT INTO "django_geo_db_state" VALUES(9,'Delaware','DE','Delaware, US',222,243);
INSERT INTO "django_geo_db_state" VALUES(10,'District of Columbia','DC','District of Columbia, US',222,244);
INSERT INTO "django_geo_db_state" VALUES(11,'Florida','FL','Florida, US',222,245);
INSERT INTO "django_geo_db_state" VALUES(12,'Federated States Of Micronesia','FM','Federated States Of Micronesia, US',222,246);
INSERT INTO "django_geo_db_state" VALUES(13,'Georgia','GA','Georgia, US',222,247);
INSERT INTO "django_geo_db_state" VALUES(14,'Guam','GU','Guam, US',222,248);
INSERT INTO "django_geo_db_state" VALUES(15,'Hawaii','HI','Hawaii, US',222,249);
INSERT INTO "django_geo_db_state" VALUES(16,'Idaho','ID','Idaho, US',222,250);
INSERT INTO "django_geo_db_state" VALUES(17,'Illinois','IL','Illinois, US',222,251);
INSERT INTO "django_geo_db_state" VALUES(18,'Indiana','IN','Indiana, US',222,252);
INSERT INTO "django_geo_db_state" VALUES(19,'Iowa','IA','Iowa, US',222,253);
INSERT INTO "django_geo_db_state" VALUES(20,'Kansas','KS','Kansas, US',222,254);
INSERT INTO "django_geo_db_state" VALUES(21,'Kentucky','KY','Kentucky, US',222,255);
INSERT INTO "django_geo_db_state" VALUES(22,'Louisiana','LA','Louisiana, US',222,256);
INSERT INTO "django_geo_db_state" VALUES(23,'Maine','ME','Maine, US',222,257);
INSERT INTO "django_geo_db_state" VALUES(24,'Marshall Islands','MH','Marshall Islands, US',222,258);
INSERT INTO "django_geo_db_state" VALUES(25,'Northern Mariana Islands','MP','Northern Mariana Islands, US',222,259);
INSERT INTO "django_geo_db_state" VALUES(26,'Montana','MT','Montana, US',222,260);
INSERT INTO "django_geo_db_state" VALUES(27,'Nebraska','NE','Nebraska, US',222,261);
INSERT INTO "django_geo_db_state" VALUES(28,'Nevada','NV','Nevada, US',222,262);
INSERT INTO "django_geo_db_state" VALUES(29,'New Hampshire','NH','New Hampshire, US',222,263);
INSERT INTO "django_geo_db_state" VALUES(30,'New Jersey','NJ','New Jersey, US',222,264);
INSERT INTO "django_geo_db_state" VALUES(31,'New Mexico','NM','New Mexico, US',222,265);
INSERT INTO "django_geo_db_state" VALUES(32,'New York','NY','New York, US',222,266);
INSERT INTO "django_geo_db_state" VALUES(33,'North Carolina','NC','North Carolina, US',222,267);
INSERT INTO "django_geo_db_state" VALUES(34,'North Dakota','ND','North Dakota, US',222,268);
INSERT INTO "django_geo_db_state" VALUES(35,'Ohio','OH','Ohio, US',222,269);
INSERT INTO "django_geo_db_state" VALUES(36,'Oklahoma','OK','Oklahoma, US',222,270);
INSERT INTO "django_geo_db_state" VALUES(37,'Oregon','OR','Oregon, US',222,271);
INSERT INTO "django_geo_db_state" VALUES(38,'Maryland','MD','Maryland, US',222,272);
INSERT INTO "django_geo_db_state" VALUES(39,'Massachusetts','MA','Massachusetts, US',222,273);
INSERT INTO "django_geo_db_state" VALUES(40,'Michigan','MI','Michigan, US',222,274);
INSERT INTO "django_geo_db_state" VALUES(41,'Minnesota','MN','Minnesota, US',222,275);
INSERT INTO "django_geo_db_state" VALUES(42,'Mississippi','MS','Mississippi, US',222,276);
INSERT INTO "django_geo_db_state" VALUES(43,'Missouri','MO','Missouri, US',222,277);
INSERT INTO "django_geo_db_state" VALUES(44,'Pennsylvania','PA','Pennsylvania, US',222,278);
INSERT INTO "django_geo_db_state" VALUES(45,'Palau','PW','Palau, US',222,279);
INSERT INTO "django_geo_db_state" VALUES(46,'Rhode Island','RI','Rhode Island, US',222,280);
INSERT INTO "django_geo_db_state" VALUES(47,'Puero Rico','PR','Puero Rico, US',222,281);
INSERT INTO "django_geo_db_state" VALUES(48,'South Carolina','SC','South Carolina, US',222,282);
INSERT INTO "django_geo_db_state" VALUES(49,'South Dakota','SD','South Dakota, US',222,283);
INSERT INTO "django_geo_db_state" VALUES(50,'Tennessee','TN','Tennessee, US',222,284);
INSERT INTO "django_geo_db_state" VALUES(51,'Texas','TX','Texas, US',222,285);
INSERT INTO "django_geo_db_state" VALUES(52,'Utah','UT','Utah, US',222,286);
INSERT INTO "django_geo_db_state" VALUES(53,'Vermont','VT','Vermont, US',222,287);
INSERT INTO "django_geo_db_state" VALUES(54,'Virginia','VA','Virginia, US',222,288);
INSERT INTO "django_geo_db_state" VALUES(55,'Saint Thomas','VI','Saint Thomas, US',222,289);
INSERT INTO "django_geo_db_state" VALUES(56,'Washington','WA','Washington, US',222,290);
INSERT INTO "django_geo_db_state" VALUES(57,'West Virginia','WV','West Virginia, US',222,291);
INSERT INTO "django_geo_db_state" VALUES(58,'Wisconsin','WI','Wisconsin, US',222,292);
INSERT INTO "django_geo_db_state" VALUES(59,'Wyoming','WY','Wyoming, US',222,293);
CREATE INDEX "django_geo_db_state_93bfec8a" ON "django_geo_db_state" ("country_id");
CREATE INDEX "django_geo_db_state_c2ff64a1" ON "django_geo_db_state" ("geocoordinate_id");
COMMIT;
