# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-05-18 17:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_geo_db', '0003_userlocation_user_created'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='usergeographysettings',
            name='location',
        ),
        migrations.RemoveField(
            model_name='usergeographysettings',
            name='user',
        ),
        migrations.DeleteModel(
            name='UserGeographySettings',
        ),
    ]
