PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE "django_geo_db_zipcode" ("zipcode_id" integer NOT NULL PRIMARY KEY AUTOINCREMENT, "zipcode" integer NOT NULL UNIQUE, "timezone" integer NOT NULL, "generated_name" varchar(50) NULL, "city_id" integer NOT NULL REFERENCES "django_geo_db_city" ("city_id"), "geocoordinate_id" integer NOT NULL REFERENCES "django_geo_db_geocoordinate" ("geocoordinate_id"), UNIQUE ("zipcode", "geocoordinate_id"));
INSERT INTO "django_geo_db_zipcode" VALUES(1,210,-5,'Portsmouth, New Hampshire 210',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(2,211,-5,'Portsmouth, New Hampshire 211',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(3,212,-5,'Portsmouth, New Hampshire 212',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(4,213,-5,'Portsmouth, New Hampshire 213',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(5,214,-5,'Portsmouth, New Hampshire 214',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(6,215,-5,'Portsmouth, New Hampshire 215',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(7,501,-5,'Holtsville, New York 501',2,295);
INSERT INTO "django_geo_db_zipcode" VALUES(8,544,-5,'Holtsville, New York 544',2,295);
INSERT INTO "django_geo_db_zipcode" VALUES(9,601,-4,'Adjuntas, Puero Rico 601',3,296);
INSERT INTO "django_geo_db_zipcode" VALUES(10,602,-4,'Aguada, Puero Rico 602',4,297);
INSERT INTO "django_geo_db_zipcode" VALUES(11,603,-4,'Aguadilla, Puero Rico 603',5,298);
INSERT INTO "django_geo_db_zipcode" VALUES(12,604,-4,'Aguadilla, Puero Rico 604',5,299);
INSERT INTO "django_geo_db_zipcode" VALUES(13,605,-4,'Aguadilla, Puero Rico 605',5,300);
INSERT INTO "django_geo_db_zipcode" VALUES(14,606,-4,'Maricao, Puero Rico 606',6,301);
INSERT INTO "django_geo_db_zipcode" VALUES(15,607,-4,'Aguas Buenas, Puero Rico 607',7,302);
INSERT INTO "django_geo_db_zipcode" VALUES(16,609,-4,'Aibonito, Puero Rico 609',8,303);
INSERT INTO "django_geo_db_zipcode" VALUES(17,610,-4,'Anasco, Puero Rico 610',9,304);
INSERT INTO "django_geo_db_zipcode" VALUES(18,611,-4,'Angeles, Puero Rico 611',10,305);
INSERT INTO "django_geo_db_zipcode" VALUES(19,612,-4,'Arecibo, Puero Rico 612',11,306);
INSERT INTO "django_geo_db_zipcode" VALUES(20,613,-4,'Arecibo, Puero Rico 613',11,307);
INSERT INTO "django_geo_db_zipcode" VALUES(21,614,-4,'Arecibo, Puero Rico 614',11,308);
INSERT INTO "django_geo_db_zipcode" VALUES(22,615,-4,'Arroyo, Puero Rico 615',12,309);
INSERT INTO "django_geo_db_zipcode" VALUES(23,616,-4,'Bajadero, Puero Rico 616',13,310);
INSERT INTO "django_geo_db_zipcode" VALUES(24,617,-4,'Barceloneta, Puero Rico 617',14,311);
INSERT INTO "django_geo_db_zipcode" VALUES(25,618,-4,'Barranquitas, Puero Rico 618',15,312);
INSERT INTO "django_geo_db_zipcode" VALUES(26,622,-4,'Boqueron, Puero Rico 622',16,313);
INSERT INTO "django_geo_db_zipcode" VALUES(27,623,-4,'Cabo Rojo, Puero Rico 623',17,314);
INSERT INTO "django_geo_db_zipcode" VALUES(28,624,-4,'Penuelas, Puero Rico 624',18,315);
INSERT INTO "django_geo_db_zipcode" VALUES(29,625,-4,'Caguas, Puero Rico 625',19,316);
INSERT INTO "django_geo_db_zipcode" VALUES(30,626,-4,'Caguas, Puero Rico 626',19,317);
INSERT INTO "django_geo_db_zipcode" VALUES(31,627,-4,'Camuy, Puero Rico 627',20,318);
INSERT INTO "django_geo_db_zipcode" VALUES(32,631,-4,'Castaner, Puero Rico 631',21,319);
INSERT INTO "django_geo_db_zipcode" VALUES(33,633,-4,'Cayey, Puero Rico 633',22,320);
INSERT INTO "django_geo_db_zipcode" VALUES(34,634,-4,'Cayey, Puero Rico 634',22,321);
INSERT INTO "django_geo_db_zipcode" VALUES(35,635,-4,'Ceiba, Puero Rico 635',23,322);
INSERT INTO "django_geo_db_zipcode" VALUES(36,636,-4,'Rosario, Puero Rico 636',24,323);
INSERT INTO "django_geo_db_zipcode" VALUES(37,637,-4,'Sabana Grande, Puero Rico 637',25,324);
INSERT INTO "django_geo_db_zipcode" VALUES(38,638,-4,'Ciales, Puero Rico 638',26,325);
INSERT INTO "django_geo_db_zipcode" VALUES(39,639,-4,'Cidra, Puero Rico 639',27,326);
INSERT INTO "django_geo_db_zipcode" VALUES(40,640,-4,'Coamo, Puero Rico 640',28,327);
INSERT INTO "django_geo_db_zipcode" VALUES(41,641,-4,'Utuado, Puero Rico 641',29,328);
INSERT INTO "django_geo_db_zipcode" VALUES(42,643,-4,'Corozal, Puero Rico 643',30,329);
INSERT INTO "django_geo_db_zipcode" VALUES(43,644,-4,'Coto Laurel, Puero Rico 644',31,330);
INSERT INTO "django_geo_db_zipcode" VALUES(44,645,-4,'Culebra, Puero Rico 645',32,331);
INSERT INTO "django_geo_db_zipcode" VALUES(45,646,-4,'Dorado, Puero Rico 646',33,332);
INSERT INTO "django_geo_db_zipcode" VALUES(46,647,-4,'Ensenada, Puero Rico 647',34,333);
INSERT INTO "django_geo_db_zipcode" VALUES(47,648,-4,'Fajardo, Puero Rico 648',35,334);
INSERT INTO "django_geo_db_zipcode" VALUES(48,650,-4,'Florida, Puero Rico 650',36,335);
INSERT INTO "django_geo_db_zipcode" VALUES(49,652,-4,'Garrochales, Puero Rico 652',37,336);
INSERT INTO "django_geo_db_zipcode" VALUES(50,653,-4,'Guanica, Puero Rico 653',38,337);
INSERT INTO "django_geo_db_zipcode" VALUES(51,654,-4,'Jobos, Puero Rico 654',39,338);
INSERT INTO "django_geo_db_zipcode" VALUES(52,655,-4,'Olimpo, Puero Rico 655',40,339);
INSERT INTO "django_geo_db_zipcode" VALUES(53,656,-4,'Guayanilla, Puero Rico 656',41,340);
INSERT INTO "django_geo_db_zipcode" VALUES(54,658,-4,'Gurabo, Puero Rico 658',42,341);
INSERT INTO "django_geo_db_zipcode" VALUES(55,659,-4,'Hatillo, Puero Rico 659',43,342);
INSERT INTO "django_geo_db_zipcode" VALUES(56,660,-4,'Hormigueros, Puero Rico 660',44,343);
INSERT INTO "django_geo_db_zipcode" VALUES(57,661,-4,'Humacao, Puero Rico 661',45,344);
INSERT INTO "django_geo_db_zipcode" VALUES(58,662,-4,'Isabela, Puero Rico 662',46,345);
INSERT INTO "django_geo_db_zipcode" VALUES(59,664,-4,'Jayuya, Puero Rico 664',47,346);
INSERT INTO "django_geo_db_zipcode" VALUES(60,665,-4,'Ponce, Puero Rico 665',48,347);
INSERT INTO "django_geo_db_zipcode" VALUES(61,666,-4,'Juncos, Puero Rico 666',49,348);
INSERT INTO "django_geo_db_zipcode" VALUES(62,667,-4,'Lajas, Puero Rico 667',50,349);
INSERT INTO "django_geo_db_zipcode" VALUES(63,669,-4,'Lares, Puero Rico 669',51,350);
INSERT INTO "django_geo_db_zipcode" VALUES(64,670,-4,'Las Marias, Puero Rico 670',52,351);
INSERT INTO "django_geo_db_zipcode" VALUES(65,671,-4,'Las Piedras, Puero Rico 671',53,352);
INSERT INTO "django_geo_db_zipcode" VALUES(66,674,-4,'Manati, Puero Rico 674',54,353);
INSERT INTO "django_geo_db_zipcode" VALUES(67,676,-4,'Moca, Puero Rico 676',55,354);
INSERT INTO "django_geo_db_zipcode" VALUES(68,677,-4,'Rincon, Puero Rico 677',56,355);
INSERT INTO "django_geo_db_zipcode" VALUES(69,678,-4,'Quebradillas, Puero Rico 678',57,356);
INSERT INTO "django_geo_db_zipcode" VALUES(70,680,-4,'Mayaguez, Puero Rico 680',58,357);
INSERT INTO "django_geo_db_zipcode" VALUES(71,681,-4,'Mayaguez, Puero Rico 681',58,358);
INSERT INTO "django_geo_db_zipcode" VALUES(72,682,-4,'Mayaguez, Puero Rico 682',58,359);
INSERT INTO "django_geo_db_zipcode" VALUES(73,683,-4,'San German, Puero Rico 683',59,360);
INSERT INTO "django_geo_db_zipcode" VALUES(74,685,-4,'San Sebastian, Puero Rico 685',60,361);
INSERT INTO "django_geo_db_zipcode" VALUES(75,687,-4,'Morovis, Puero Rico 687',61,362);
INSERT INTO "django_geo_db_zipcode" VALUES(76,688,-4,'Sabana Hoyos, Puero Rico 688',62,363);
INSERT INTO "django_geo_db_zipcode" VALUES(77,690,-4,'San Antonio, Puero Rico 690',63,364);
INSERT INTO "django_geo_db_zipcode" VALUES(78,692,-4,'Vega Alta, Puero Rico 692',64,365);
INSERT INTO "django_geo_db_zipcode" VALUES(79,693,-4,'Vega Baja, Puero Rico 693',65,366);
INSERT INTO "django_geo_db_zipcode" VALUES(80,694,-4,'Vega Baja, Puero Rico 694',65,367);
INSERT INTO "django_geo_db_zipcode" VALUES(81,698,-4,'Yauco, Puero Rico 698',66,368);
INSERT INTO "django_geo_db_zipcode" VALUES(82,703,-4,'Aguas Buenas, Puero Rico 703',7,369);
INSERT INTO "django_geo_db_zipcode" VALUES(83,704,-4,'Aguirre, Puero Rico 704',67,370);
INSERT INTO "django_geo_db_zipcode" VALUES(84,705,-4,'Aibonito, Puero Rico 705',8,371);
INSERT INTO "django_geo_db_zipcode" VALUES(85,707,-4,'Maunabo, Puero Rico 707',68,372);
INSERT INTO "django_geo_db_zipcode" VALUES(86,714,-4,'Arroyo, Puero Rico 714',12,373);
INSERT INTO "django_geo_db_zipcode" VALUES(87,715,-4,'Mercedita, Puero Rico 715',69,374);
INSERT INTO "django_geo_db_zipcode" VALUES(88,716,-4,'Ponce, Puero Rico 716',48,375);
INSERT INTO "django_geo_db_zipcode" VALUES(89,717,-4,'Ponce, Puero Rico 717',48,376);
INSERT INTO "django_geo_db_zipcode" VALUES(90,718,-4,'Naguabo, Puero Rico 718',70,377);
INSERT INTO "django_geo_db_zipcode" VALUES(91,719,-4,'Naranjito, Puero Rico 719',71,378);
INSERT INTO "django_geo_db_zipcode" VALUES(92,720,-4,'Orocovis, Puero Rico 720',72,379);
INSERT INTO "django_geo_db_zipcode" VALUES(93,721,-4,'Palmer, Puero Rico 721',73,380);
INSERT INTO "django_geo_db_zipcode" VALUES(94,723,-4,'Patillas, Puero Rico 723',74,381);
INSERT INTO "django_geo_db_zipcode" VALUES(95,725,-4,'Caguas, Puero Rico 725',19,382);
INSERT INTO "django_geo_db_zipcode" VALUES(96,726,-4,'Caguas, Puero Rico 726',19,383);
INSERT INTO "django_geo_db_zipcode" VALUES(97,728,-4,'Ponce, Puero Rico 728',48,384);
INSERT INTO "django_geo_db_zipcode" VALUES(98,729,-4,'Canovanas, Puero Rico 729',75,385);
INSERT INTO "django_geo_db_zipcode" VALUES(99,730,-4,'Ponce, Puero Rico 730',48,386);
INSERT INTO "django_geo_db_zipcode" VALUES(100,731,-4,'Ponce, Puero Rico 731',48,387);
INSERT INTO "django_geo_db_zipcode" VALUES(101,732,-4,'Ponce, Puero Rico 732',48,388);
INSERT INTO "django_geo_db_zipcode" VALUES(102,733,-4,'Ponce, Puero Rico 733',48,389);
INSERT INTO "django_geo_db_zipcode" VALUES(103,734,-4,'Ponce, Puero Rico 734',48,390);
INSERT INTO "django_geo_db_zipcode" VALUES(104,735,-4,'Ceiba, Puero Rico 735',23,391);
INSERT INTO "django_geo_db_zipcode" VALUES(105,736,-4,'Cayey, Puero Rico 736',22,392);
INSERT INTO "django_geo_db_zipcode" VALUES(106,737,-4,'Cayey, Puero Rico 737',22,393);
INSERT INTO "django_geo_db_zipcode" VALUES(107,738,-4,'Fajardo, Puero Rico 738',35,394);
INSERT INTO "django_geo_db_zipcode" VALUES(108,739,-4,'Cidra, Puero Rico 739',27,395);
INSERT INTO "django_geo_db_zipcode" VALUES(109,740,-4,'Puerto Real, Puero Rico 740',76,396);
INSERT INTO "django_geo_db_zipcode" VALUES(110,741,-4,'Punta Santiago, Puero Rico 741',77,397);
INSERT INTO "django_geo_db_zipcode" VALUES(111,742,-4,'Roosevelt Roads, Puero Rico 742',78,398);
INSERT INTO "django_geo_db_zipcode" VALUES(112,744,-4,'Rio Blanco, Puero Rico 744',79,399);
INSERT INTO "django_geo_db_zipcode" VALUES(113,745,-4,'Rio Grande, Puero Rico 745',80,400);
INSERT INTO "django_geo_db_zipcode" VALUES(114,747,-4,'Lluveras, Puero Rico 747',81,401);
INSERT INTO "django_geo_db_zipcode" VALUES(115,748,-4,'Fajardo, Puero Rico 748',35,402);
INSERT INTO "django_geo_db_zipcode" VALUES(116,751,-4,'Salinas, Puero Rico 751',82,403);
INSERT INTO "django_geo_db_zipcode" VALUES(117,752,-4,'San Antonio, Puero Rico 752',63,404);
INSERT INTO "django_geo_db_zipcode" VALUES(118,754,-4,'San Lorenzo, Puero Rico 754',83,405);
INSERT INTO "django_geo_db_zipcode" VALUES(119,757,-4,'Santa Isabel, Puero Rico 757',84,406);
INSERT INTO "django_geo_db_zipcode" VALUES(120,761,-4,'Utuado, Puero Rico 761',29,407);
INSERT INTO "django_geo_db_zipcode" VALUES(121,762,-4,'Vega Alta, Puero Rico 762',64,408);
INSERT INTO "django_geo_db_zipcode" VALUES(122,763,-4,'Monserrate, Puero Rico 763',85,409);
INSERT INTO "django_geo_db_zipcode" VALUES(123,764,-4,'Vega Baja, Puero Rico 764',65,410);
INSERT INTO "django_geo_db_zipcode" VALUES(124,765,-4,'Vieques, Puero Rico 765',86,411);
INSERT INTO "django_geo_db_zipcode" VALUES(125,766,-4,'Villalba, Puero Rico 766',87,412);
INSERT INTO "django_geo_db_zipcode" VALUES(126,767,-4,'Yabucoa, Puero Rico 767',88,413);
INSERT INTO "django_geo_db_zipcode" VALUES(127,768,-4,'Yauco, Puero Rico 768',66,414);
INSERT INTO "django_geo_db_zipcode" VALUES(128,769,-4,'Coamo, Puero Rico 769',28,415);
INSERT INTO "django_geo_db_zipcode" VALUES(129,771,-4,'Las Piedras, Puero Rico 771',53,416);
INSERT INTO "django_geo_db_zipcode" VALUES(130,772,-4,'Loiza, Puero Rico 772',89,417);
INSERT INTO "django_geo_db_zipcode" VALUES(131,773,-4,'Luquillo, Puero Rico 773',90,418);
INSERT INTO "django_geo_db_zipcode" VALUES(132,775,-4,'Culebra, Puero Rico 775',32,419);
INSERT INTO "django_geo_db_zipcode" VALUES(133,777,-4,'Juncos, Puero Rico 777',49,420);
INSERT INTO "django_geo_db_zipcode" VALUES(134,778,-4,'Gurabo, Puero Rico 778',42,421);
INSERT INTO "django_geo_db_zipcode" VALUES(135,780,-4,'Coto Laurel, Puero Rico 780',31,422);
INSERT INTO "django_geo_db_zipcode" VALUES(136,782,-4,'Comerio, Puero Rico 782',91,423);
INSERT INTO "django_geo_db_zipcode" VALUES(137,783,-4,'Corozal, Puero Rico 783',30,424);
INSERT INTO "django_geo_db_zipcode" VALUES(138,784,-4,'Guayama, Puero Rico 784',92,425);
INSERT INTO "django_geo_db_zipcode" VALUES(139,785,-4,'Guayama, Puero Rico 785',92,426);
INSERT INTO "django_geo_db_zipcode" VALUES(140,786,-4,'La Plata, Puero Rico 786',93,427);
INSERT INTO "django_geo_db_zipcode" VALUES(141,791,-4,'Humacao, Puero Rico 791',45,428);
INSERT INTO "django_geo_db_zipcode" VALUES(142,792,-4,'Humacao, Puero Rico 792',45,429);
INSERT INTO "django_geo_db_zipcode" VALUES(143,794,-4,'Barranquitas, Puero Rico 794',15,430);
INSERT INTO "django_geo_db_zipcode" VALUES(144,795,-4,'Juana Diaz, Puero Rico 795',94,431);
INSERT INTO "django_geo_db_zipcode" VALUES(145,801,-4,'St Thomas, Saint Thomas 801',95,432);
INSERT INTO "django_geo_db_zipcode" VALUES(146,802,-4,'St Thomas, Saint Thomas 802',95,432);
INSERT INTO "django_geo_db_zipcode" VALUES(147,803,-4,'St Thomas, Saint Thomas 803',95,432);
INSERT INTO "django_geo_db_zipcode" VALUES(148,804,-4,'St Thomas, Saint Thomas 804',95,432);
INSERT INTO "django_geo_db_zipcode" VALUES(149,805,-4,'St Thomas, Saint Thomas 805',95,432);
INSERT INTO "django_geo_db_zipcode" VALUES(150,820,-4,'Christiansted, Saint Thomas 820',96,433);
INSERT INTO "django_geo_db_zipcode" VALUES(151,821,-4,'Christiansted, Saint Thomas 821',96,433);
INSERT INTO "django_geo_db_zipcode" VALUES(152,822,-4,'Christiansted, Saint Thomas 822',96,433);
INSERT INTO "django_geo_db_zipcode" VALUES(153,823,-4,'Christiansted, Saint Thomas 823',96,433);
INSERT INTO "django_geo_db_zipcode" VALUES(154,824,-4,'Christiansted, Saint Thomas 824',96,433);
INSERT INTO "django_geo_db_zipcode" VALUES(155,830,-4,'St John, Saint Thomas 830',97,434);
INSERT INTO "django_geo_db_zipcode" VALUES(156,831,-4,'St John, Saint Thomas 831',97,434);
INSERT INTO "django_geo_db_zipcode" VALUES(157,840,-4,'Frederiksted, Saint Thomas 840',98,433);
INSERT INTO "django_geo_db_zipcode" VALUES(158,841,-4,'Frederiksted, Saint Thomas 841',98,433);
INSERT INTO "django_geo_db_zipcode" VALUES(159,850,-4,'Kingshill, Saint Thomas 850',99,433);
INSERT INTO "django_geo_db_zipcode" VALUES(160,851,-4,'Kingshill, Saint Thomas 851',99,433);
INSERT INTO "django_geo_db_zipcode" VALUES(161,901,-4,'San Juan, Puero Rico 901',100,435);
INSERT INTO "django_geo_db_zipcode" VALUES(162,902,-4,'San Juan, Puero Rico 902',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(163,906,-4,'San Juan, Puero Rico 906',100,437);
INSERT INTO "django_geo_db_zipcode" VALUES(164,907,-4,'San Juan, Puero Rico 907',100,438);
INSERT INTO "django_geo_db_zipcode" VALUES(165,908,-4,'San Juan, Puero Rico 908',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(166,909,-4,'San Juan, Puero Rico 909',100,439);
INSERT INTO "django_geo_db_zipcode" VALUES(167,910,-4,'San Juan, Puero Rico 910',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(168,911,-4,'San Juan, Puero Rico 911',100,440);
INSERT INTO "django_geo_db_zipcode" VALUES(169,912,-4,'San Juan, Puero Rico 912',100,441);
INSERT INTO "django_geo_db_zipcode" VALUES(170,913,-4,'San Juan, Puero Rico 913',100,442);
INSERT INTO "django_geo_db_zipcode" VALUES(171,914,-4,'San Juan, Puero Rico 914',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(172,915,-4,'San Juan, Puero Rico 915',100,443);
INSERT INTO "django_geo_db_zipcode" VALUES(173,916,-4,'San Juan, Puero Rico 916',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(174,917,-4,'San Juan, Puero Rico 917',100,444);
INSERT INTO "django_geo_db_zipcode" VALUES(175,918,-4,'San Juan, Puero Rico 918',100,445);
INSERT INTO "django_geo_db_zipcode" VALUES(176,919,-4,'San Juan, Puero Rico 919',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(177,920,-4,'San Juan, Puero Rico 920',100,446);
INSERT INTO "django_geo_db_zipcode" VALUES(178,921,-4,'San Juan, Puero Rico 921',100,447);
INSERT INTO "django_geo_db_zipcode" VALUES(179,922,-4,'San Juan, Puero Rico 922',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(180,923,-4,'San Juan, Puero Rico 923',100,448);
INSERT INTO "django_geo_db_zipcode" VALUES(181,924,-4,'San Juan, Puero Rico 924',100,449);
INSERT INTO "django_geo_db_zipcode" VALUES(182,925,-4,'San Juan, Puero Rico 925',100,450);
INSERT INTO "django_geo_db_zipcode" VALUES(183,926,-4,'San Juan, Puero Rico 926',100,451);
INSERT INTO "django_geo_db_zipcode" VALUES(184,927,-4,'San Juan, Puero Rico 927',100,452);
INSERT INTO "django_geo_db_zipcode" VALUES(185,928,-4,'San Juan, Puero Rico 928',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(186,929,-4,'San Juan, Puero Rico 929',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(187,930,-4,'San Juan, Puero Rico 930',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(188,931,-4,'San Juan, Puero Rico 931',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(189,933,-4,'San Juan, Puero Rico 933',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(190,934,-4,'Fort Buchanan, Puero Rico 934',101,453);
INSERT INTO "django_geo_db_zipcode" VALUES(191,935,-4,'San Juan, Puero Rico 935',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(192,936,-4,'San Juan, Puero Rico 936',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(193,937,-4,'San Juan, Puero Rico 937',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(194,938,-4,'San Juan, Puero Rico 938',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(195,939,-4,'San Juan, Puero Rico 939',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(196,940,-4,'San Juan, Puero Rico 940',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(197,949,-4,'Toa Baja, Puero Rico 949',102,454);
INSERT INTO "django_geo_db_zipcode" VALUES(198,950,-4,'Toa Baja, Puero Rico 950',102,455);
INSERT INTO "django_geo_db_zipcode" VALUES(199,951,-4,'Toa Baja, Puero Rico 951',102,455);
INSERT INTO "django_geo_db_zipcode" VALUES(200,952,-4,'Sabana Seca, Puero Rico 952',103,456);
INSERT INTO "django_geo_db_zipcode" VALUES(201,953,-4,'Toa Alta, Puero Rico 953',104,457);
INSERT INTO "django_geo_db_zipcode" VALUES(202,954,-4,'Toa Alta, Puero Rico 954',104,458);
INSERT INTO "django_geo_db_zipcode" VALUES(203,955,-4,'San Juan, Puero Rico 955',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(204,956,-4,'Bayamon, Puero Rico 956',105,459);
INSERT INTO "django_geo_db_zipcode" VALUES(205,957,-4,'Bayamon, Puero Rico 957',105,460);
INSERT INTO "django_geo_db_zipcode" VALUES(206,958,-4,'Bayamon, Puero Rico 958',105,461);
INSERT INTO "django_geo_db_zipcode" VALUES(207,959,-4,'Bayamon, Puero Rico 959',105,462);
INSERT INTO "django_geo_db_zipcode" VALUES(208,960,-4,'Bayamon, Puero Rico 960',105,461);
INSERT INTO "django_geo_db_zipcode" VALUES(209,961,-4,'Bayamon, Puero Rico 961',105,463);
INSERT INTO "django_geo_db_zipcode" VALUES(210,962,-4,'Catano, Puero Rico 962',106,464);
INSERT INTO "django_geo_db_zipcode" VALUES(211,963,-4,'Catano, Puero Rico 963',106,465);
INSERT INTO "django_geo_db_zipcode" VALUES(212,965,-4,'Guaynabo, Puero Rico 965',107,466);
INSERT INTO "django_geo_db_zipcode" VALUES(213,966,-4,'Guaynabo, Puero Rico 966',107,467);
INSERT INTO "django_geo_db_zipcode" VALUES(214,968,-4,'Guaynabo, Puero Rico 968',107,468);
INSERT INTO "django_geo_db_zipcode" VALUES(215,969,-4,'Guaynabo, Puero Rico 969',107,469);
INSERT INTO "django_geo_db_zipcode" VALUES(216,970,-4,'Guaynabo, Puero Rico 970',107,470);
INSERT INTO "django_geo_db_zipcode" VALUES(217,971,-4,'Guaynabo, Puero Rico 971',107,471);
INSERT INTO "django_geo_db_zipcode" VALUES(218,975,-4,'San Juan, Puero Rico 975',100,436);
INSERT INTO "django_geo_db_zipcode" VALUES(219,976,-4,'Trujillo Alto, Puero Rico 976',108,472);
INSERT INTO "django_geo_db_zipcode" VALUES(220,977,-4,'Trujillo Alto, Puero Rico 977',108,473);
INSERT INTO "django_geo_db_zipcode" VALUES(221,978,-4,'St Just, Puero Rico 978',109,473);
INSERT INTO "django_geo_db_zipcode" VALUES(222,979,-4,'Carolina, Puero Rico 979',110,474);
INSERT INTO "django_geo_db_zipcode" VALUES(223,981,-4,'Carolina, Puero Rico 981',110,436);
INSERT INTO "django_geo_db_zipcode" VALUES(224,982,-4,'Carolina, Puero Rico 982',110,475);
INSERT INTO "django_geo_db_zipcode" VALUES(225,983,-4,'Carolina, Puero Rico 983',110,476);
INSERT INTO "django_geo_db_zipcode" VALUES(226,984,-4,'Carolina, Puero Rico 984',110,477);
INSERT INTO "django_geo_db_zipcode" VALUES(227,985,-4,'Carolina, Puero Rico 985',110,478);
INSERT INTO "django_geo_db_zipcode" VALUES(228,986,-4,'Carolina, Puero Rico 986',110,477);
INSERT INTO "django_geo_db_zipcode" VALUES(229,987,-4,'Carolina, Puero Rico 987',110,479);
INSERT INTO "django_geo_db_zipcode" VALUES(230,988,-4,'Carolina, Puero Rico 988',110,477);
INSERT INTO "django_geo_db_zipcode" VALUES(231,1001,-5,'Agawam, Massachusetts 1001',111,480);
INSERT INTO "django_geo_db_zipcode" VALUES(232,1002,-5,'Amherst, Massachusetts 1002',112,481);
INSERT INTO "django_geo_db_zipcode" VALUES(233,1003,-5,'Amherst, Massachusetts 1003',112,482);
INSERT INTO "django_geo_db_zipcode" VALUES(234,1004,-5,'Amherst, Massachusetts 1004',112,483);
INSERT INTO "django_geo_db_zipcode" VALUES(235,1005,-5,'Barre, Massachusetts 1005',113,484);
INSERT INTO "django_geo_db_zipcode" VALUES(236,1007,-5,'Belchertown, Massachusetts 1007',114,485);
INSERT INTO "django_geo_db_zipcode" VALUES(237,1008,-5,'Blandford, Massachusetts 1008',115,486);
INSERT INTO "django_geo_db_zipcode" VALUES(238,1009,-5,'Bondsville, Massachusetts 1009',116,487);
INSERT INTO "django_geo_db_zipcode" VALUES(239,1010,-5,'Brimfield, Massachusetts 1010',117,488);
INSERT INTO "django_geo_db_zipcode" VALUES(240,1011,-5,'Chester, Massachusetts 1011',118,489);
INSERT INTO "django_geo_db_zipcode" VALUES(241,1012,-5,'Chesterfield, Massachusetts 1012',119,490);
INSERT INTO "django_geo_db_zipcode" VALUES(242,1013,-5,'Chicopee, Massachusetts 1013',120,491);
INSERT INTO "django_geo_db_zipcode" VALUES(243,1014,-5,'Chicopee, Massachusetts 1014',120,492);
INSERT INTO "django_geo_db_zipcode" VALUES(244,1020,-5,'Chicopee, Massachusetts 1020',120,493);
INSERT INTO "django_geo_db_zipcode" VALUES(245,1021,-5,'Chicopee, Massachusetts 1021',120,492);
INSERT INTO "django_geo_db_zipcode" VALUES(246,1022,-5,'Chicopee, Massachusetts 1022',120,494);
INSERT INTO "django_geo_db_zipcode" VALUES(247,1026,-5,'Cummington, Massachusetts 1026',121,495);
INSERT INTO "django_geo_db_zipcode" VALUES(248,1027,-5,'Easthampton, Massachusetts 1027',122,496);
INSERT INTO "django_geo_db_zipcode" VALUES(249,1028,-5,'East Longmeadow, Massachusetts 1028',123,497);
INSERT INTO "django_geo_db_zipcode" VALUES(250,1029,-5,'East Otis, Massachusetts 1029',124,498);
INSERT INTO "django_geo_db_zipcode" VALUES(251,1030,-5,'Feeding Hills, Massachusetts 1030',125,499);
INSERT INTO "django_geo_db_zipcode" VALUES(252,1031,-5,'Gilbertville, Massachusetts 1031',126,500);
INSERT INTO "django_geo_db_zipcode" VALUES(253,1032,-5,'Goshen, Massachusetts 1032',127,501);
INSERT INTO "django_geo_db_zipcode" VALUES(254,1033,-5,'Granby, Massachusetts 1033',128,502);
INSERT INTO "django_geo_db_zipcode" VALUES(255,1034,-5,'Granville, Massachusetts 1034',129,503);
INSERT INTO "django_geo_db_zipcode" VALUES(256,1035,-5,'Hadley, Massachusetts 1035',130,504);
INSERT INTO "django_geo_db_zipcode" VALUES(257,1036,-5,'Hampden, Massachusetts 1036',131,505);
INSERT INTO "django_geo_db_zipcode" VALUES(258,1037,-5,'Hardwick, Massachusetts 1037',132,506);
INSERT INTO "django_geo_db_zipcode" VALUES(259,1038,-5,'Hatfield, Massachusetts 1038',133,507);
INSERT INTO "django_geo_db_zipcode" VALUES(260,1039,-5,'Haydenville, Massachusetts 1039',134,508);
INSERT INTO "django_geo_db_zipcode" VALUES(261,1040,-5,'Holyoke, Massachusetts 1040',135,509);
INSERT INTO "django_geo_db_zipcode" VALUES(262,1041,-5,'Holyoke, Massachusetts 1041',135,492);
INSERT INTO "django_geo_db_zipcode" VALUES(263,1050,-5,'Huntington, Massachusetts 1050',136,510);
INSERT INTO "django_geo_db_zipcode" VALUES(264,1053,-5,'Leeds, Massachusetts 1053',137,511);
INSERT INTO "django_geo_db_zipcode" VALUES(265,1054,-5,'Leverett, Massachusetts 1054',138,512);
INSERT INTO "django_geo_db_zipcode" VALUES(266,1056,-5,'Ludlow, Massachusetts 1056',139,513);
INSERT INTO "django_geo_db_zipcode" VALUES(267,1057,-5,'Monson, Massachusetts 1057',140,514);
INSERT INTO "django_geo_db_zipcode" VALUES(268,1059,-5,'North Amherst, Massachusetts 1059',141,482);
INSERT INTO "django_geo_db_zipcode" VALUES(269,1060,-5,'Northampton, Massachusetts 1060',142,515);
INSERT INTO "django_geo_db_zipcode" VALUES(270,1061,-5,'Northampton, Massachusetts 1061',142,482);
INSERT INTO "django_geo_db_zipcode" VALUES(271,1062,-5,'Florence, Massachusetts 1062',143,516);
INSERT INTO "django_geo_db_zipcode" VALUES(272,1063,-5,'Northampton, Massachusetts 1063',142,517);
INSERT INTO "django_geo_db_zipcode" VALUES(273,1066,-5,'North Hatfield, Massachusetts 1066',144,518);
INSERT INTO "django_geo_db_zipcode" VALUES(274,1068,-5,'Oakham, Massachusetts 1068',145,519);
INSERT INTO "django_geo_db_zipcode" VALUES(275,1069,-5,'Palmer, Massachusetts 1069',146,520);
INSERT INTO "django_geo_db_zipcode" VALUES(276,1070,-5,'Plainfield, Massachusetts 1070',147,521);
INSERT INTO "django_geo_db_zipcode" VALUES(277,1071,-5,'Russell, Massachusetts 1071',148,522);
INSERT INTO "django_geo_db_zipcode" VALUES(278,1072,-5,'Shutesbury, Massachusetts 1072',149,523);
INSERT INTO "django_geo_db_zipcode" VALUES(279,1073,-5,'Southampton, Massachusetts 1073',150,524);
INSERT INTO "django_geo_db_zipcode" VALUES(280,1074,-5,'South Barre, Massachusetts 1074',151,525);
INSERT INTO "django_geo_db_zipcode" VALUES(281,1075,-5,'South Hadley, Massachusetts 1075',152,526);
INSERT INTO "django_geo_db_zipcode" VALUES(282,1077,-5,'Southwick, Massachusetts 1077',153,527);
INSERT INTO "django_geo_db_zipcode" VALUES(283,1079,-5,'Thorndike, Massachusetts 1079',154,528);
INSERT INTO "django_geo_db_zipcode" VALUES(284,1080,-5,'Three Rivers, Massachusetts 1080',155,529);
INSERT INTO "django_geo_db_zipcode" VALUES(285,1081,-5,'Wales, Massachusetts 1081',156,530);
INSERT INTO "django_geo_db_zipcode" VALUES(286,1082,-5,'Ware, Massachusetts 1082',157,531);
INSERT INTO "django_geo_db_zipcode" VALUES(287,1083,-5,'Warren, Massachusetts 1083',158,532);
INSERT INTO "django_geo_db_zipcode" VALUES(288,1084,-5,'West Chesterfield, Massachusetts 1084',159,533);
INSERT INTO "django_geo_db_zipcode" VALUES(289,1085,-5,'Westfield, Massachusetts 1085',160,534);
INSERT INTO "django_geo_db_zipcode" VALUES(290,1086,-5,'Westfield, Massachusetts 1086',160,535);
INSERT INTO "django_geo_db_zipcode" VALUES(291,1088,-5,'West Hatfield, Massachusetts 1088',161,536);
INSERT INTO "django_geo_db_zipcode" VALUES(292,1089,-5,'West Springfield, Massachusetts 1089',162,537);
INSERT INTO "django_geo_db_zipcode" VALUES(293,1090,-5,'West Springfield, Massachusetts 1090',162,492);
INSERT INTO "django_geo_db_zipcode" VALUES(294,1092,-5,'West Warren, Massachusetts 1092',163,538);
INSERT INTO "django_geo_db_zipcode" VALUES(295,1093,-5,'Whately, Massachusetts 1093',164,539);
INSERT INTO "django_geo_db_zipcode" VALUES(296,1094,-5,'Wheelwright, Massachusetts 1094',165,540);
INSERT INTO "django_geo_db_zipcode" VALUES(297,1095,-5,'Wilbraham, Massachusetts 1095',166,541);
INSERT INTO "django_geo_db_zipcode" VALUES(298,1096,-5,'Williamsburg, Massachusetts 1096',167,542);
INSERT INTO "django_geo_db_zipcode" VALUES(299,1097,-5,'Woronoco, Massachusetts 1097',168,543);
INSERT INTO "django_geo_db_zipcode" VALUES(300,1098,-5,'Worthington, Massachusetts 1098',169,544);
INSERT INTO "django_geo_db_zipcode" VALUES(301,1101,-5,'Springfield, Massachusetts 1101',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(302,1102,-5,'Springfield, Massachusetts 1102',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(303,1103,-5,'Springfield, Massachusetts 1103',170,545);
INSERT INTO "django_geo_db_zipcode" VALUES(304,1104,-5,'Springfield, Massachusetts 1104',170,546);
INSERT INTO "django_geo_db_zipcode" VALUES(305,1105,-5,'Springfield, Massachusetts 1105',170,547);
INSERT INTO "django_geo_db_zipcode" VALUES(306,1106,-5,'Longmeadow, Massachusetts 1106',171,548);
INSERT INTO "django_geo_db_zipcode" VALUES(307,1107,-5,'Springfield, Massachusetts 1107',170,549);
INSERT INTO "django_geo_db_zipcode" VALUES(308,1108,-5,'Springfield, Massachusetts 1108',170,550);
INSERT INTO "django_geo_db_zipcode" VALUES(309,1109,-5,'Springfield, Massachusetts 1109',170,551);
INSERT INTO "django_geo_db_zipcode" VALUES(310,1111,-5,'Springfield, Massachusetts 1111',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(311,1114,-5,'Springfield, Massachusetts 1114',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(312,1115,-5,'Springfield, Massachusetts 1115',170,552);
INSERT INTO "django_geo_db_zipcode" VALUES(313,1116,-5,'Longmeadow, Massachusetts 1116',171,492);
INSERT INTO "django_geo_db_zipcode" VALUES(314,1118,-5,'Springfield, Massachusetts 1118',170,553);
INSERT INTO "django_geo_db_zipcode" VALUES(315,1119,-5,'Springfield, Massachusetts 1119',170,554);
INSERT INTO "django_geo_db_zipcode" VALUES(316,1128,-5,'Springfield, Massachusetts 1128',170,555);
INSERT INTO "django_geo_db_zipcode" VALUES(317,1129,-5,'Springfield, Massachusetts 1129',170,556);
INSERT INTO "django_geo_db_zipcode" VALUES(318,1133,-5,'Springfield, Massachusetts 1133',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(319,1138,-5,'Springfield, Massachusetts 1138',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(320,1139,-5,'Springfield, Massachusetts 1139',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(321,1144,-5,'Springfield, Massachusetts 1144',170,557);
INSERT INTO "django_geo_db_zipcode" VALUES(322,1151,-5,'Indian Orchard, Massachusetts 1151',172,558);
INSERT INTO "django_geo_db_zipcode" VALUES(323,1152,-5,'Springfield, Massachusetts 1152',170,492);
INSERT INTO "django_geo_db_zipcode" VALUES(324,1199,-5,'Springfield, Massachusetts 1199',170,559);
INSERT INTO "django_geo_db_zipcode" VALUES(325,1201,-5,'Pittsfield, Massachusetts 1201',173,560);
INSERT INTO "django_geo_db_zipcode" VALUES(326,1202,-5,'Pittsfield, Massachusetts 1202',173,561);
INSERT INTO "django_geo_db_zipcode" VALUES(327,1203,-5,'Pittsfield, Massachusetts 1203',173,561);
INSERT INTO "django_geo_db_zipcode" VALUES(328,1220,-5,'Adams, Massachusetts 1220',174,562);
INSERT INTO "django_geo_db_zipcode" VALUES(329,1222,-5,'Ashley Falls, Massachusetts 1222',175,563);
INSERT INTO "django_geo_db_zipcode" VALUES(330,1223,-5,'Becket, Massachusetts 1223',176,564);
INSERT INTO "django_geo_db_zipcode" VALUES(331,1224,-5,'Berkshire, Massachusetts 1224',177,561);
INSERT INTO "django_geo_db_zipcode" VALUES(332,1225,-5,'Cheshire, Massachusetts 1225',178,565);
INSERT INTO "django_geo_db_zipcode" VALUES(333,1226,-5,'Dalton, Massachusetts 1226',179,566);
INSERT INTO "django_geo_db_zipcode" VALUES(334,1227,-5,'Dalton, Massachusetts 1227',179,567);
INSERT INTO "django_geo_db_zipcode" VALUES(335,1229,-5,'Glendale, Massachusetts 1229',180,568);
INSERT INTO "django_geo_db_zipcode" VALUES(336,1230,-5,'Great Barrington, Massachusetts 1230',181,569);
INSERT INTO "django_geo_db_zipcode" VALUES(337,1231,-5,'Sheffield, Massachusetts 1231',182,570);
INSERT INTO "django_geo_db_zipcode" VALUES(338,1235,-5,'Hinsdale, Massachusetts 1235',183,571);
INSERT INTO "django_geo_db_zipcode" VALUES(339,1236,-5,'Housatonic, Massachusetts 1236',184,572);
INSERT INTO "django_geo_db_zipcode" VALUES(340,1237,-5,'Lanesboro, Massachusetts 1237',185,573);
INSERT INTO "django_geo_db_zipcode" VALUES(341,1238,-5,'Lee, Massachusetts 1238',186,574);
INSERT INTO "django_geo_db_zipcode" VALUES(342,1240,-5,'Lenox, Massachusetts 1240',187,575);
INSERT INTO "django_geo_db_zipcode" VALUES(343,1242,-5,'Lenox Dale, Massachusetts 1242',188,576);
INSERT INTO "django_geo_db_zipcode" VALUES(344,1243,-5,'Middlefield, Massachusetts 1243',189,577);
INSERT INTO "django_geo_db_zipcode" VALUES(345,1244,-5,'Mill River, Massachusetts 1244',190,578);
INSERT INTO "django_geo_db_zipcode" VALUES(346,1245,-5,'Monterey, Massachusetts 1245',191,579);
INSERT INTO "django_geo_db_zipcode" VALUES(347,1247,-5,'North Adams, Massachusetts 1247',192,580);
INSERT INTO "django_geo_db_zipcode" VALUES(348,1252,-5,'North Egremont, Massachusetts 1252',193,581);
INSERT INTO "django_geo_db_zipcode" VALUES(349,1253,-5,'Otis, Massachusetts 1253',194,582);
INSERT INTO "django_geo_db_zipcode" VALUES(350,1254,-5,'Richmond, Massachusetts 1254',195,583);
INSERT INTO "django_geo_db_zipcode" VALUES(351,1255,-5,'Sandisfield, Massachusetts 1255',196,584);
INSERT INTO "django_geo_db_zipcode" VALUES(352,1256,-5,'Savoy, Massachusetts 1256',197,585);
INSERT INTO "django_geo_db_zipcode" VALUES(353,1257,-5,'Sheffield, Massachusetts 1257',182,586);
INSERT INTO "django_geo_db_zipcode" VALUES(354,1258,-5,'South Egremont, Massachusetts 1258',198,587);
INSERT INTO "django_geo_db_zipcode" VALUES(355,1259,-5,'Southfield, Massachusetts 1259',199,588);
INSERT INTO "django_geo_db_zipcode" VALUES(356,1260,-5,'South Lee, Massachusetts 1260',200,589);
INSERT INTO "django_geo_db_zipcode" VALUES(357,1262,-5,'Stockbridge, Massachusetts 1262',201,590);
INSERT INTO "django_geo_db_zipcode" VALUES(358,1263,-5,'Stockbridge, Massachusetts 1263',201,561);
INSERT INTO "django_geo_db_zipcode" VALUES(359,1264,-5,'Tyringham, Massachusetts 1264',202,591);
INSERT INTO "django_geo_db_zipcode" VALUES(360,1266,-5,'West Stockbridge, Massachusetts 1266',203,592);
INSERT INTO "django_geo_db_zipcode" VALUES(361,1267,-5,'Williamstown, Massachusetts 1267',204,593);
INSERT INTO "django_geo_db_zipcode" VALUES(362,1270,-5,'Windsor, Massachusetts 1270',205,594);
INSERT INTO "django_geo_db_zipcode" VALUES(363,1301,-5,'Greenfield, Massachusetts 1301',206,595);
INSERT INTO "django_geo_db_zipcode" VALUES(364,1302,-5,'Greenfield, Massachusetts 1302',206,596);
INSERT INTO "django_geo_db_zipcode" VALUES(365,1330,-5,'Ashfield, Massachusetts 1330',207,597);
INSERT INTO "django_geo_db_zipcode" VALUES(366,1331,-5,'Athol, Massachusetts 1331',208,598);
INSERT INTO "django_geo_db_zipcode" VALUES(367,1337,-5,'Bernardston, Massachusetts 1337',209,599);
INSERT INTO "django_geo_db_zipcode" VALUES(368,1338,-5,'Buckland, Massachusetts 1338',210,600);
INSERT INTO "django_geo_db_zipcode" VALUES(369,1339,-5,'Charlemont, Massachusetts 1339',211,601);
INSERT INTO "django_geo_db_zipcode" VALUES(370,1340,-5,'Colrain, Massachusetts 1340',212,602);
INSERT INTO "django_geo_db_zipcode" VALUES(371,1341,-5,'Conway, Massachusetts 1341',213,603);
INSERT INTO "django_geo_db_zipcode" VALUES(372,1342,-5,'Deerfield, Massachusetts 1342',214,604);
INSERT INTO "django_geo_db_zipcode" VALUES(373,1343,-5,'Drury, Massachusetts 1343',215,605);
INSERT INTO "django_geo_db_zipcode" VALUES(374,1344,-5,'Erving, Massachusetts 1344',216,606);
INSERT INTO "django_geo_db_zipcode" VALUES(375,1346,-5,'Heath, Massachusetts 1346',217,607);
INSERT INTO "django_geo_db_zipcode" VALUES(376,1347,-5,'Lake Pleasant, Massachusetts 1347',218,608);
INSERT INTO "django_geo_db_zipcode" VALUES(377,1349,-5,'Turners Falls, Massachusetts 1349',219,609);
INSERT INTO "django_geo_db_zipcode" VALUES(378,1350,-5,'Monroe Bridge, Massachusetts 1350',220,610);
INSERT INTO "django_geo_db_zipcode" VALUES(379,1351,-5,'Montague, Massachusetts 1351',221,611);
INSERT INTO "django_geo_db_zipcode" VALUES(380,1354,-5,'Northfield, Massachusetts 1354',222,596);
INSERT INTO "django_geo_db_zipcode" VALUES(381,1355,-5,'New Salem, Massachusetts 1355',223,612);
INSERT INTO "django_geo_db_zipcode" VALUES(382,1360,-5,'Northfield, Massachusetts 1360',222,613);
INSERT INTO "django_geo_db_zipcode" VALUES(383,1364,-5,'Orange, Massachusetts 1364',224,614);
INSERT INTO "django_geo_db_zipcode" VALUES(384,1366,-5,'Petersham, Massachusetts 1366',225,615);
INSERT INTO "django_geo_db_zipcode" VALUES(385,1367,-5,'Rowe, Massachusetts 1367',226,616);
INSERT INTO "django_geo_db_zipcode" VALUES(386,1368,-5,'Royalston, Massachusetts 1368',227,617);
INSERT INTO "django_geo_db_zipcode" VALUES(387,1369,-5,'Shattuckville, Massachusetts 1369',228,596);
INSERT INTO "django_geo_db_zipcode" VALUES(388,1370,-5,'Shelburne Falls, Massachusetts 1370',229,618);
INSERT INTO "django_geo_db_zipcode" VALUES(389,1373,-5,'South Deerfield, Massachusetts 1373',230,619);
INSERT INTO "django_geo_db_zipcode" VALUES(390,1374,-5,'Charlemont, Massachusetts 1374',211,620);
INSERT INTO "django_geo_db_zipcode" VALUES(391,1375,-5,'Sunderland, Massachusetts 1375',231,621);
INSERT INTO "django_geo_db_zipcode" VALUES(392,1376,-5,'Turners Falls, Massachusetts 1376',219,622);
INSERT INTO "django_geo_db_zipcode" VALUES(393,1378,-5,'Warwick, Massachusetts 1378',232,623);
INSERT INTO "django_geo_db_zipcode" VALUES(394,1379,-5,'Wendell, Massachusetts 1379',233,624);
INSERT INTO "django_geo_db_zipcode" VALUES(395,1380,-5,'Wendell Depot, Massachusetts 1380',234,625);
INSERT INTO "django_geo_db_zipcode" VALUES(396,1393,-5,'Whately, Massachusetts 1393',164,626);
INSERT INTO "django_geo_db_zipcode" VALUES(397,1420,-5,'Fitchburg, Massachusetts 1420',235,627);
INSERT INTO "django_geo_db_zipcode" VALUES(398,1427,-5,'Westborough, Massachusetts 1427',236,628);
INSERT INTO "django_geo_db_zipcode" VALUES(399,1430,-5,'Ashburnham, Massachusetts 1430',237,629);
INSERT INTO "django_geo_db_zipcode" VALUES(400,1431,-5,'Ashby, Massachusetts 1431',238,630);
INSERT INTO "django_geo_db_zipcode" VALUES(401,1432,-5,'Ayer, Massachusetts 1432',239,631);
INSERT INTO "django_geo_db_zipcode" VALUES(402,1436,-5,'Baldwinville, Massachusetts 1436',240,632);
INSERT INTO "django_geo_db_zipcode" VALUES(403,1438,-5,'East Templeton, Massachusetts 1438',241,633);
INSERT INTO "django_geo_db_zipcode" VALUES(404,1440,-5,'Gardner, Massachusetts 1440',242,634);
INSERT INTO "django_geo_db_zipcode" VALUES(405,1441,-5,'Gardner, Massachusetts 1441',242,635);
INSERT INTO "django_geo_db_zipcode" VALUES(406,1450,-5,'Groton, Massachusetts 1450',243,636);
INSERT INTO "django_geo_db_zipcode" VALUES(407,1451,-5,'Harvard, Massachusetts 1451',244,637);
INSERT INTO "django_geo_db_zipcode" VALUES(408,1452,-5,'Hubbardston, Massachusetts 1452',245,638);
INSERT INTO "django_geo_db_zipcode" VALUES(409,1453,-5,'Leominster, Massachusetts 1453',246,639);
INSERT INTO "django_geo_db_zipcode" VALUES(410,1460,-5,'Littleton, Massachusetts 1460',247,640);
INSERT INTO "django_geo_db_zipcode" VALUES(411,1462,-5,'Lunenburg, Massachusetts 1462',248,641);
INSERT INTO "django_geo_db_zipcode" VALUES(412,1463,-5,'Pepperell, Massachusetts 1463',249,642);
INSERT INTO "django_geo_db_zipcode" VALUES(413,1464,-5,'Shirley, Massachusetts 1464',250,643);
INSERT INTO "django_geo_db_zipcode" VALUES(414,1467,-5,'Still River, Massachusetts 1467',251,644);
INSERT INTO "django_geo_db_zipcode" VALUES(415,1468,-5,'Templeton, Massachusetts 1468',252,645);
INSERT INTO "django_geo_db_zipcode" VALUES(416,1469,-5,'Townsend, Massachusetts 1469',253,646);
INSERT INTO "django_geo_db_zipcode" VALUES(417,1470,-5,'Groton, Massachusetts 1470',243,647);
INSERT INTO "django_geo_db_zipcode" VALUES(418,1471,-5,'Groton, Massachusetts 1471',243,647);
INSERT INTO "django_geo_db_zipcode" VALUES(419,1472,-5,'West Groton, Massachusetts 1472',254,647);
INSERT INTO "django_geo_db_zipcode" VALUES(420,1473,-5,'Westminster, Massachusetts 1473',255,648);
INSERT INTO "django_geo_db_zipcode" VALUES(421,1474,-5,'West Townsend, Massachusetts 1474',256,649);
INSERT INTO "django_geo_db_zipcode" VALUES(422,1475,-5,'Winchendon, Massachusetts 1475',257,650);
INSERT INTO "django_geo_db_zipcode" VALUES(423,1477,-5,'Winchendon Springs, Massachusetts 1477',258,635);
INSERT INTO "django_geo_db_zipcode" VALUES(424,1501,-5,'Auburn, Massachusetts 1501',259,651);
INSERT INTO "django_geo_db_zipcode" VALUES(425,1503,-5,'Berlin, Massachusetts 1503',260,652);
INSERT INTO "django_geo_db_zipcode" VALUES(426,1504,-5,'Blackstone, Massachusetts 1504',261,653);
INSERT INTO "django_geo_db_zipcode" VALUES(427,1505,-5,'Boylston, Massachusetts 1505',262,654);
INSERT INTO "django_geo_db_zipcode" VALUES(428,1506,-5,'Brookfield, Massachusetts 1506',263,655);
INSERT INTO "django_geo_db_zipcode" VALUES(429,1507,-5,'Charlton, Massachusetts 1507',264,656);
INSERT INTO "django_geo_db_zipcode" VALUES(430,1508,-5,'Charlton City, Massachusetts 1508',265,657);
INSERT INTO "django_geo_db_zipcode" VALUES(431,1509,-5,'Charlton Depot, Massachusetts 1509',266,635);
INSERT INTO "django_geo_db_zipcode" VALUES(432,1510,-5,'Clinton, Massachusetts 1510',267,658);
INSERT INTO "django_geo_db_zipcode" VALUES(433,1515,-5,'East Brookfield, Massachusetts 1515',268,659);
INSERT INTO "django_geo_db_zipcode" VALUES(434,1516,-5,'Douglas, Massachusetts 1516',269,660);
INSERT INTO "django_geo_db_zipcode" VALUES(435,1517,-5,'East Princeton, Massachusetts 1517',270,635);
INSERT INTO "django_geo_db_zipcode" VALUES(436,1518,-5,'Fiskdale, Massachusetts 1518',271,661);
INSERT INTO "django_geo_db_zipcode" VALUES(437,1519,-5,'Grafton, Massachusetts 1519',272,662);
INSERT INTO "django_geo_db_zipcode" VALUES(438,1520,-5,'Holden, Massachusetts 1520',273,663);
INSERT INTO "django_geo_db_zipcode" VALUES(439,1521,-5,'Holland, Massachusetts 1521',274,664);
INSERT INTO "django_geo_db_zipcode" VALUES(440,1522,-5,'Jefferson, Massachusetts 1522',275,665);
INSERT INTO "django_geo_db_zipcode" VALUES(441,1523,-5,'Lancaster, Massachusetts 1523',276,666);
INSERT INTO "django_geo_db_zipcode" VALUES(442,1524,-5,'Leicester, Massachusetts 1524',277,667);
INSERT INTO "django_geo_db_zipcode" VALUES(443,1525,-5,'Linwood, Massachusetts 1525',278,635);
INSERT INTO "django_geo_db_zipcode" VALUES(444,1526,-5,'Manchaug, Massachusetts 1526',279,635);
INSERT INTO "django_geo_db_zipcode" VALUES(445,1527,-5,'Millbury, Massachusetts 1527',280,668);
INSERT INTO "django_geo_db_zipcode" VALUES(446,1529,-5,'Millville, Massachusetts 1529',281,669);
INSERT INTO "django_geo_db_zipcode" VALUES(447,1531,-5,'New Braintree, Massachusetts 1531',282,670);
INSERT INTO "django_geo_db_zipcode" VALUES(448,1532,-5,'Northborough, Massachusetts 1532',283,671);
INSERT INTO "django_geo_db_zipcode" VALUES(449,1534,-5,'Northbridge, Massachusetts 1534',284,672);
INSERT INTO "django_geo_db_zipcode" VALUES(450,1535,-5,'North Brookfield, Massachusetts 1535',285,673);
INSERT INTO "django_geo_db_zipcode" VALUES(451,1536,-5,'North Grafton, Massachusetts 1536',286,674);
INSERT INTO "django_geo_db_zipcode" VALUES(452,1537,-5,'North Oxford, Massachusetts 1537',287,675);
INSERT INTO "django_geo_db_zipcode" VALUES(453,1538,-5,'North Uxbridge, Massachusetts 1538',288,635);
INSERT INTO "django_geo_db_zipcode" VALUES(454,1540,-5,'Oxford, Massachusetts 1540',289,676);
INSERT INTO "django_geo_db_zipcode" VALUES(455,1541,-5,'Princeton, Massachusetts 1541',290,677);
INSERT INTO "django_geo_db_zipcode" VALUES(456,1542,-5,'Rochdale, Massachusetts 1542',291,678);
INSERT INTO "django_geo_db_zipcode" VALUES(457,1543,-5,'Rutland, Massachusetts 1543',292,679);
INSERT INTO "django_geo_db_zipcode" VALUES(458,1545,-5,'Shrewsbury, Massachusetts 1545',293,680);
INSERT INTO "django_geo_db_zipcode" VALUES(459,1546,-5,'Shrewsbury, Massachusetts 1546',293,635);
INSERT INTO "django_geo_db_zipcode" VALUES(460,1550,-5,'Southbridge, Massachusetts 1550',294,681);
INSERT INTO "django_geo_db_zipcode" VALUES(461,1560,-5,'South Grafton, Massachusetts 1560',295,682);
INSERT INTO "django_geo_db_zipcode" VALUES(462,1561,-5,'South Lancaster, Massachusetts 1561',296,683);
INSERT INTO "django_geo_db_zipcode" VALUES(463,1562,-5,'Spencer, Massachusetts 1562',297,684);
INSERT INTO "django_geo_db_zipcode" VALUES(464,1564,-5,'Sterling, Massachusetts 1564',298,685);
INSERT INTO "django_geo_db_zipcode" VALUES(465,1566,-5,'Sturbridge, Massachusetts 1566',299,686);
INSERT INTO "django_geo_db_zipcode" VALUES(466,1568,-5,'Upton, Massachusetts 1568',300,687);
INSERT INTO "django_geo_db_zipcode" VALUES(467,1569,-5,'Uxbridge, Massachusetts 1569',301,688);
INSERT INTO "django_geo_db_zipcode" VALUES(468,1570,-5,'Webster, Massachusetts 1570',302,689);
INSERT INTO "django_geo_db_zipcode" VALUES(469,1571,-5,'Dudley, Massachusetts 1571',303,690);
INSERT INTO "django_geo_db_zipcode" VALUES(470,1580,-5,'Westborough, Massachusetts 1580',236,635);
INSERT INTO "django_geo_db_zipcode" VALUES(471,1581,-5,'Westborough, Massachusetts 1581',236,691);
INSERT INTO "django_geo_db_zipcode" VALUES(472,1582,-5,'Westborough, Massachusetts 1582',236,635);
INSERT INTO "django_geo_db_zipcode" VALUES(473,1583,-5,'West Boylston, Massachusetts 1583',304,692);
INSERT INTO "django_geo_db_zipcode" VALUES(474,1585,-5,'West Brookfield, Massachusetts 1585',305,693);
INSERT INTO "django_geo_db_zipcode" VALUES(475,1586,-5,'West Millbury, Massachusetts 1586',306,635);
INSERT INTO "django_geo_db_zipcode" VALUES(476,1588,-5,'Whitinsville, Massachusetts 1588',307,694);
INSERT INTO "django_geo_db_zipcode" VALUES(477,1590,-5,'Sutton, Massachusetts 1590',308,695);
INSERT INTO "django_geo_db_zipcode" VALUES(478,1601,-5,'Worcester, Massachusetts 1601',309,696);
INSERT INTO "django_geo_db_zipcode" VALUES(479,1602,-5,'Worcester, Massachusetts 1602',309,697);
INSERT INTO "django_geo_db_zipcode" VALUES(480,1603,-5,'Worcester, Massachusetts 1603',309,698);
INSERT INTO "django_geo_db_zipcode" VALUES(481,1604,-5,'Worcester, Massachusetts 1604',309,699);
INSERT INTO "django_geo_db_zipcode" VALUES(482,1605,-5,'Worcester, Massachusetts 1605',309,700);
INSERT INTO "django_geo_db_zipcode" VALUES(483,1606,-5,'Worcester, Massachusetts 1606',309,701);
INSERT INTO "django_geo_db_zipcode" VALUES(484,1607,-5,'Worcester, Massachusetts 1607',309,702);
INSERT INTO "django_geo_db_zipcode" VALUES(485,1608,-5,'Worcester, Massachusetts 1608',309,703);
INSERT INTO "django_geo_db_zipcode" VALUES(486,1609,-5,'Worcester, Massachusetts 1609',309,704);
INSERT INTO "django_geo_db_zipcode" VALUES(487,1610,-5,'Worcester, Massachusetts 1610',309,705);
INSERT INTO "django_geo_db_zipcode" VALUES(488,1611,-5,'Cherry Valley, Massachusetts 1611',310,706);
INSERT INTO "django_geo_db_zipcode" VALUES(489,1612,-5,'Paxton, Massachusetts 1612',311,707);
INSERT INTO "django_geo_db_zipcode" VALUES(490,1613,-5,'Worcester, Massachusetts 1613',309,708);
INSERT INTO "django_geo_db_zipcode" VALUES(491,1614,-5,'Worcester, Massachusetts 1614',309,635);
INSERT INTO "django_geo_db_zipcode" VALUES(492,1615,-5,'Worcester, Massachusetts 1615',309,635);
INSERT INTO "django_geo_db_zipcode" VALUES(493,1634,-5,'Tolland, Massachusetts 1634',312,709);
INSERT INTO "django_geo_db_zipcode" VALUES(494,1653,-5,'Worcester, Massachusetts 1653',309,635);
INSERT INTO "django_geo_db_zipcode" VALUES(495,1654,-5,'Worcester, Massachusetts 1654',309,635);
INSERT INTO "django_geo_db_zipcode" VALUES(496,1655,-5,'Worcester, Massachusetts 1655',309,635);
INSERT INTO "django_geo_db_zipcode" VALUES(497,1701,-5,'Framingham, Massachusetts 1701',313,710);
INSERT INTO "django_geo_db_zipcode" VALUES(498,1702,-5,'Framingham, Massachusetts 1702',313,711);
INSERT INTO "django_geo_db_zipcode" VALUES(499,1703,-5,'Framingham, Massachusetts 1703',313,647);
INSERT INTO "django_geo_db_zipcode" VALUES(500,1704,-5,'Framingham, Massachusetts 1704',313,647);
INSERT INTO "django_geo_db_zipcode" VALUES(501,1705,-5,'Framingham, Massachusetts 1705',313,647);
INSERT INTO "django_geo_db_zipcode" VALUES(502,1718,-5,'Village Of Nagog Woods, Massachusetts 1718',314,712);
INSERT INTO "django_geo_db_zipcode" VALUES(503,1719,-5,'Boxborough, Massachusetts 1719',315,713);
INSERT INTO "django_geo_db_zipcode" VALUES(504,1720,-5,'Acton, Massachusetts 1720',316,714);
INSERT INTO "django_geo_db_zipcode" VALUES(505,1721,-5,'Ashland, Massachusetts 1721',317,715);
INSERT INTO "django_geo_db_zipcode" VALUES(506,1730,-5,'Bedford, Massachusetts 1730',318,716);
INSERT INTO "django_geo_db_zipcode" VALUES(507,1731,-5,'Hanscom AFB, Massachusetts 1731',319,717);
INSERT INTO "django_geo_db_zipcode" VALUES(508,1740,-5,'Bolton, Massachusetts 1740',320,718);
INSERT INTO "django_geo_db_zipcode" VALUES(509,1741,-5,'Carlisle, Massachusetts 1741',321,719);
INSERT INTO "django_geo_db_zipcode" VALUES(510,1742,-5,'Concord, Massachusetts 1742',322,720);
INSERT INTO "django_geo_db_zipcode" VALUES(511,1745,-5,'Fayville, Massachusetts 1745',323,721);
INSERT INTO "django_geo_db_zipcode" VALUES(512,1746,-5,'Holliston, Massachusetts 1746',324,722);
INSERT INTO "django_geo_db_zipcode" VALUES(513,1747,-5,'Hopedale, Massachusetts 1747',325,723);
INSERT INTO "django_geo_db_zipcode" VALUES(514,1748,-5,'Hopkinton, Massachusetts 1748',326,724);
INSERT INTO "django_geo_db_zipcode" VALUES(515,1749,-5,'Hudson, Massachusetts 1749',327,725);
INSERT INTO "django_geo_db_zipcode" VALUES(516,1750,-5,'Natick, Massachusetts 1750',328,726);
INSERT INTO "django_geo_db_zipcode" VALUES(517,1752,-5,'Marlborough, Massachusetts 1752',329,727);
INSERT INTO "django_geo_db_zipcode" VALUES(518,1754,-5,'Maynard, Massachusetts 1754',330,728);
INSERT INTO "django_geo_db_zipcode" VALUES(519,1756,-5,'Mendon, Massachusetts 1756',331,729);
INSERT INTO "django_geo_db_zipcode" VALUES(520,1757,-5,'Milford, Massachusetts 1757',332,730);
INSERT INTO "django_geo_db_zipcode" VALUES(521,1760,-5,'Natick, Massachusetts 1760',328,731);
INSERT INTO "django_geo_db_zipcode" VALUES(522,1770,-5,'Sherborn, Massachusetts 1770',333,732);
INSERT INTO "django_geo_db_zipcode" VALUES(523,1772,-5,'Southborough, Massachusetts 1772',334,733);
INSERT INTO "django_geo_db_zipcode" VALUES(524,1773,-5,'Lincoln, Massachusetts 1773',335,734);
INSERT INTO "django_geo_db_zipcode" VALUES(525,1775,-5,'Stow, Massachusetts 1775',336,735);
INSERT INTO "django_geo_db_zipcode" VALUES(526,1776,-5,'Sudbury, Massachusetts 1776',337,736);
INSERT INTO "django_geo_db_zipcode" VALUES(527,1778,-5,'Wayland, Massachusetts 1778',338,737);
INSERT INTO "django_geo_db_zipcode" VALUES(528,1784,-5,'Woodville, Massachusetts 1784',339,647);
INSERT INTO "django_geo_db_zipcode" VALUES(529,1801,-5,'Woburn, Massachusetts 1801',340,738);
INSERT INTO "django_geo_db_zipcode" VALUES(530,1803,-5,'Burlington, Massachusetts 1803',341,739);
INSERT INTO "django_geo_db_zipcode" VALUES(531,1805,-5,'Burlington, Massachusetts 1805',341,647);
INSERT INTO "django_geo_db_zipcode" VALUES(532,1806,-5,'Woburn, Massachusetts 1806',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(533,1807,-5,'Woburn, Massachusetts 1807',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(534,1808,-5,'Woburn, Massachusetts 1808',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(535,1810,-5,'Andover, Massachusetts 1810',342,740);
INSERT INTO "django_geo_db_zipcode" VALUES(536,1812,-5,'Andover, Massachusetts 1812',342,741);
INSERT INTO "django_geo_db_zipcode" VALUES(537,1813,-5,'Woburn, Massachusetts 1813',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(538,1815,-5,'Woburn, Massachusetts 1815',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(539,1820,-5,'Pinehurst, Massachusetts 1820',343,742);
INSERT INTO "django_geo_db_zipcode" VALUES(540,1821,-5,'Billerica, Massachusetts 1821',344,743);
INSERT INTO "django_geo_db_zipcode" VALUES(541,1822,-5,'Billerica, Massachusetts 1822',344,647);
INSERT INTO "django_geo_db_zipcode" VALUES(542,1823,-5,'Haverhill, Massachusetts 1823',345,744);
INSERT INTO "django_geo_db_zipcode" VALUES(543,1824,-5,'Chelmsford, Massachusetts 1824',346,745);
INSERT INTO "django_geo_db_zipcode" VALUES(544,1826,-5,'Dracut, Massachusetts 1826',347,746);
INSERT INTO "django_geo_db_zipcode" VALUES(545,1827,-5,'Dunstable, Massachusetts 1827',348,747);
INSERT INTO "django_geo_db_zipcode" VALUES(546,1830,-5,'Haverhill, Massachusetts 1830',345,748);
INSERT INTO "django_geo_db_zipcode" VALUES(547,1831,-5,'Haverhill, Massachusetts 1831',345,749);
INSERT INTO "django_geo_db_zipcode" VALUES(548,1832,-5,'Haverhill, Massachusetts 1832',345,750);
INSERT INTO "django_geo_db_zipcode" VALUES(549,1833,-5,'Georgetown, Massachusetts 1833',349,751);
INSERT INTO "django_geo_db_zipcode" VALUES(550,1834,-5,'Groveland, Massachusetts 1834',350,752);
INSERT INTO "django_geo_db_zipcode" VALUES(551,1835,-5,'Haverhill, Massachusetts 1835',345,753);
INSERT INTO "django_geo_db_zipcode" VALUES(552,1840,-5,'Lawrence, Massachusetts 1840',351,754);
INSERT INTO "django_geo_db_zipcode" VALUES(553,1841,-5,'Lawrence, Massachusetts 1841',351,755);
INSERT INTO "django_geo_db_zipcode" VALUES(554,1842,-5,'Lawrence, Massachusetts 1842',351,756);
INSERT INTO "django_geo_db_zipcode" VALUES(555,1843,-5,'Lawrence, Massachusetts 1843',351,757);
INSERT INTO "django_geo_db_zipcode" VALUES(556,1844,-5,'Methuen, Massachusetts 1844',352,758);
INSERT INTO "django_geo_db_zipcode" VALUES(557,1845,-5,'North Andover, Massachusetts 1845',353,759);
INSERT INTO "django_geo_db_zipcode" VALUES(558,1850,-5,'Lowell, Massachusetts 1850',354,760);
INSERT INTO "django_geo_db_zipcode" VALUES(559,1851,-5,'Lowell, Massachusetts 1851',354,761);
INSERT INTO "django_geo_db_zipcode" VALUES(560,1852,-5,'Lowell, Massachusetts 1852',354,762);
INSERT INTO "django_geo_db_zipcode" VALUES(561,1853,-5,'Lowell, Massachusetts 1853',354,647);
INSERT INTO "django_geo_db_zipcode" VALUES(562,1854,-5,'Lowell, Massachusetts 1854',354,763);
INSERT INTO "django_geo_db_zipcode" VALUES(563,1856,-5,'Lowell, Massachusetts 1856',354,764);
INSERT INTO "django_geo_db_zipcode" VALUES(564,1860,-5,'Merrimac, Massachusetts 1860',355,765);
INSERT INTO "django_geo_db_zipcode" VALUES(565,1862,-5,'North Billerica, Massachusetts 1862',356,766);
INSERT INTO "django_geo_db_zipcode" VALUES(566,1863,-5,'North Chelmsford, Massachusetts 1863',357,767);
INSERT INTO "django_geo_db_zipcode" VALUES(567,1864,-5,'North Reading, Massachusetts 1864',358,768);
INSERT INTO "django_geo_db_zipcode" VALUES(568,1865,-5,'Nutting Lake, Massachusetts 1865',359,647);
INSERT INTO "django_geo_db_zipcode" VALUES(569,1866,-5,'Pinehurst, Massachusetts 1866',343,647);
INSERT INTO "django_geo_db_zipcode" VALUES(570,1867,-5,'Reading, Massachusetts 1867',360,769);
INSERT INTO "django_geo_db_zipcode" VALUES(571,1876,-5,'Tewksbury, Massachusetts 1876',361,770);
INSERT INTO "django_geo_db_zipcode" VALUES(572,1879,-5,'Tyngsboro, Massachusetts 1879',362,771);
INSERT INTO "django_geo_db_zipcode" VALUES(573,1880,-5,'Wakefield, Massachusetts 1880',363,772);
INSERT INTO "django_geo_db_zipcode" VALUES(574,1885,-5,'West Boxford, Massachusetts 1885',364,756);
INSERT INTO "django_geo_db_zipcode" VALUES(575,1886,-5,'Westford, Massachusetts 1886',365,773);
INSERT INTO "django_geo_db_zipcode" VALUES(576,1887,-5,'Wilmington, Massachusetts 1887',366,774);
INSERT INTO "django_geo_db_zipcode" VALUES(577,1888,-5,'Woburn, Massachusetts 1888',340,647);
INSERT INTO "django_geo_db_zipcode" VALUES(578,1889,-5,'North Reading, Massachusetts 1889',358,775);
INSERT INTO "django_geo_db_zipcode" VALUES(579,1890,-5,'Winchester, Massachusetts 1890',367,776);
INSERT INTO "django_geo_db_zipcode" VALUES(580,1899,-5,'Andover, Massachusetts 1899',342,756);
INSERT INTO "django_geo_db_zipcode" VALUES(581,1901,-5,'Lynn, Massachusetts 1901',368,777);
INSERT INTO "django_geo_db_zipcode" VALUES(582,1902,-5,'Lynn, Massachusetts 1902',368,778);
INSERT INTO "django_geo_db_zipcode" VALUES(583,1903,-5,'Lynn, Massachusetts 1903',368,756);
INSERT INTO "django_geo_db_zipcode" VALUES(584,1904,-5,'Lynn, Massachusetts 1904',368,779);
INSERT INTO "django_geo_db_zipcode" VALUES(585,1905,-5,'Lynn, Massachusetts 1905',368,780);
INSERT INTO "django_geo_db_zipcode" VALUES(586,1906,-5,'Saugus, Massachusetts 1906',369,781);
INSERT INTO "django_geo_db_zipcode" VALUES(587,1907,-5,'Swampscott, Massachusetts 1907',370,782);
INSERT INTO "django_geo_db_zipcode" VALUES(588,1908,-5,'Nahant, Massachusetts 1908',371,783);
INSERT INTO "django_geo_db_zipcode" VALUES(589,1910,-5,'Lynn, Massachusetts 1910',368,784);
INSERT INTO "django_geo_db_zipcode" VALUES(590,1913,-5,'Amesbury, Massachusetts 1913',372,785);
INSERT INTO "django_geo_db_zipcode" VALUES(591,1915,-5,'Beverly, Massachusetts 1915',373,786);
INSERT INTO "django_geo_db_zipcode" VALUES(592,1921,-5,'Boxford, Massachusetts 1921',374,787);
INSERT INTO "django_geo_db_zipcode" VALUES(593,1922,-5,'Byfield, Massachusetts 1922',375,788);
INSERT INTO "django_geo_db_zipcode" VALUES(594,1923,-5,'Danvers, Massachusetts 1923',376,789);
INSERT INTO "django_geo_db_zipcode" VALUES(595,1929,-5,'Essex, Massachusetts 1929',377,790);
INSERT INTO "django_geo_db_zipcode" VALUES(596,1930,-5,'Gloucester, Massachusetts 1930',378,791);
INSERT INTO "django_geo_db_zipcode" VALUES(597,1931,-5,'Gloucester, Massachusetts 1931',378,756);
INSERT INTO "django_geo_db_zipcode" VALUES(598,1936,-5,'Hamilton, Massachusetts 1936',379,756);
INSERT INTO "django_geo_db_zipcode" VALUES(599,1937,-5,'Hathorne, Massachusetts 1937',380,756);
INSERT INTO "django_geo_db_zipcode" VALUES(600,1938,-5,'Ipswich, Massachusetts 1938',381,792);
INSERT INTO "django_geo_db_zipcode" VALUES(601,1940,-5,'Lynnfield, Massachusetts 1940',382,793);
INSERT INTO "django_geo_db_zipcode" VALUES(602,1944,-5,'Manchester, Massachusetts 1944',383,794);
INSERT INTO "django_geo_db_zipcode" VALUES(603,1945,-5,'Marblehead, Massachusetts 1945',384,795);
INSERT INTO "django_geo_db_zipcode" VALUES(604,1947,-5,'Salem, Massachusetts 1947',385,796);
INSERT INTO "django_geo_db_zipcode" VALUES(605,1949,-5,'Middleton, Massachusetts 1949',386,797);
INSERT INTO "django_geo_db_zipcode" VALUES(606,1950,-5,'Newburyport, Massachusetts 1950',387,798);
INSERT INTO "django_geo_db_zipcode" VALUES(607,1951,-5,'Newbury, Massachusetts 1951',388,799);
INSERT INTO "django_geo_db_zipcode" VALUES(608,1952,-5,'Salisbury, Massachusetts 1952',389,800);
INSERT INTO "django_geo_db_zipcode" VALUES(609,1960,-5,'Peabody, Massachusetts 1960',390,801);
INSERT INTO "django_geo_db_zipcode" VALUES(610,1961,-5,'Peabody, Massachusetts 1961',390,756);
INSERT INTO "django_geo_db_zipcode" VALUES(611,1965,-5,'Prides Crossing, Massachusetts 1965',391,802);
INSERT INTO "django_geo_db_zipcode" VALUES(612,1966,-5,'Rockport, Massachusetts 1966',392,803);
INSERT INTO "django_geo_db_zipcode" VALUES(613,1969,-5,'Rowley, Massachusetts 1969',393,804);
INSERT INTO "django_geo_db_zipcode" VALUES(614,1970,-5,'Salem, Massachusetts 1970',385,805);
INSERT INTO "django_geo_db_zipcode" VALUES(615,1971,-5,'Salem, Massachusetts 1971',385,756);
INSERT INTO "django_geo_db_zipcode" VALUES(616,1982,-5,'South Hamilton, Massachusetts 1982',394,806);
INSERT INTO "django_geo_db_zipcode" VALUES(617,1983,-5,'Topsfield, Massachusetts 1983',395,807);
INSERT INTO "django_geo_db_zipcode" VALUES(618,1984,-5,'Wenham, Massachusetts 1984',396,808);
INSERT INTO "django_geo_db_zipcode" VALUES(619,1985,-5,'West Newbury, Massachusetts 1985',397,809);
INSERT INTO "django_geo_db_zipcode" VALUES(620,2018,-5,'Accord, Massachusetts 2018',398,810);
INSERT INTO "django_geo_db_zipcode" VALUES(621,2019,-5,'Bellingham, Massachusetts 2019',399,811);
INSERT INTO "django_geo_db_zipcode" VALUES(622,2020,-5,'Brant Rock, Massachusetts 2020',400,812);
INSERT INTO "django_geo_db_zipcode" VALUES(623,2021,-5,'Canton, Massachusetts 2021',401,813);
INSERT INTO "django_geo_db_zipcode" VALUES(624,2025,-5,'Cohasset, Massachusetts 2025',402,814);
INSERT INTO "django_geo_db_zipcode" VALUES(625,2026,-5,'Dedham, Massachusetts 2026',403,815);
INSERT INTO "django_geo_db_zipcode" VALUES(626,2027,-5,'Dedham, Massachusetts 2027',403,816);
INSERT INTO "django_geo_db_zipcode" VALUES(627,2029,-5,'Providence, Rhode Island 2029',404,817);
INSERT INTO "django_geo_db_zipcode" VALUES(628,2030,-5,'Dover, Massachusetts 2030',405,818);
INSERT INTO "django_geo_db_zipcode" VALUES(629,2031,-5,'East Mansfield, Massachusetts 2031',406,819);
INSERT INTO "django_geo_db_zipcode" VALUES(630,2032,-5,'East Walpole, Massachusetts 2032',407,820);
INSERT INTO "django_geo_db_zipcode" VALUES(631,2035,-5,'Foxboro, Massachusetts 2035',408,821);
INSERT INTO "django_geo_db_zipcode" VALUES(632,2038,-5,'Franklin, Massachusetts 2038',409,822);
INSERT INTO "django_geo_db_zipcode" VALUES(633,2040,-5,'Greenbush, Massachusetts 2040',410,810);
INSERT INTO "django_geo_db_zipcode" VALUES(634,2041,-5,'Green Harbor, Massachusetts 2041',411,823);
INSERT INTO "django_geo_db_zipcode" VALUES(635,2043,-5,'Hingham, Massachusetts 2043',412,824);
INSERT INTO "django_geo_db_zipcode" VALUES(636,2044,-5,'Hingham, Massachusetts 2044',412,810);
INSERT INTO "django_geo_db_zipcode" VALUES(637,2045,-5,'Hull, Massachusetts 2045',413,825);
INSERT INTO "django_geo_db_zipcode" VALUES(638,2047,-5,'Humarock, Massachusetts 2047',414,826);
INSERT INTO "django_geo_db_zipcode" VALUES(639,2048,-5,'Mansfield, Massachusetts 2048',415,827);
INSERT INTO "django_geo_db_zipcode" VALUES(640,2050,-5,'Marshfield, Massachusetts 2050',416,828);
INSERT INTO "django_geo_db_zipcode" VALUES(641,2051,-5,'Marshfield Hills, Massachusetts 2051',417,829);
INSERT INTO "django_geo_db_zipcode" VALUES(642,2052,-5,'Medfield, Massachusetts 2052',418,830);
INSERT INTO "django_geo_db_zipcode" VALUES(643,2053,-5,'Medway, Massachusetts 2053',419,831);
INSERT INTO "django_geo_db_zipcode" VALUES(644,2054,-5,'Millis, Massachusetts 2054',420,832);
INSERT INTO "django_geo_db_zipcode" VALUES(645,2055,-5,'Minot, Massachusetts 2055',421,810);
INSERT INTO "django_geo_db_zipcode" VALUES(646,2056,-5,'Norfolk, Massachusetts 2056',422,833);
INSERT INTO "django_geo_db_zipcode" VALUES(647,2059,-5,'North Marshfield, Massachusetts 2059',423,810);
INSERT INTO "django_geo_db_zipcode" VALUES(648,2060,-5,'North Scituate, Massachusetts 2060',424,810);
INSERT INTO "django_geo_db_zipcode" VALUES(649,2061,-5,'Norwell, Massachusetts 2061',425,834);
INSERT INTO "django_geo_db_zipcode" VALUES(650,2062,-5,'Norwood, Massachusetts 2062',426,835);
INSERT INTO "django_geo_db_zipcode" VALUES(651,2065,-5,'Ocean Bluff, Massachusetts 2065',427,836);
INSERT INTO "django_geo_db_zipcode" VALUES(652,2066,-5,'Scituate, Massachusetts 2066',428,837);
INSERT INTO "django_geo_db_zipcode" VALUES(653,2067,-5,'Sharon, Massachusetts 2067',429,838);
INSERT INTO "django_geo_db_zipcode" VALUES(654,2070,-5,'Sheldonville, Massachusetts 2070',430,816);
INSERT INTO "django_geo_db_zipcode" VALUES(655,2071,-5,'South Walpole, Massachusetts 2071',431,839);
INSERT INTO "django_geo_db_zipcode" VALUES(656,2072,-5,'Stoughton, Massachusetts 2072',432,840);
INSERT INTO "django_geo_db_zipcode" VALUES(657,2081,-5,'Walpole, Massachusetts 2081',433,841);
INSERT INTO "django_geo_db_zipcode" VALUES(658,2085,-5,'Foxborough, Massachusetts 2085',434,842);
INSERT INTO "django_geo_db_zipcode" VALUES(659,2090,-5,'Westwood, Massachusetts 2090',435,843);
INSERT INTO "django_geo_db_zipcode" VALUES(660,2093,-5,'Wrentham, Massachusetts 2093',436,844);
INSERT INTO "django_geo_db_zipcode" VALUES(661,2101,-5,'Boston, Massachusetts 2101',437,845);
INSERT INTO "django_geo_db_zipcode" VALUES(662,2102,-5,'Boston, Massachusetts 2102',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(663,2103,-5,'Boston, Massachusetts 2103',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(664,2104,-5,'Boston, Massachusetts 2104',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(665,2105,-5,'Boston, Massachusetts 2105',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(666,2106,-5,'Boston, Massachusetts 2106',437,847);
INSERT INTO "django_geo_db_zipcode" VALUES(667,2107,-5,'Boston, Massachusetts 2107',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(668,2108,-5,'Boston, Massachusetts 2108',437,848);
INSERT INTO "django_geo_db_zipcode" VALUES(669,2109,-5,'Boston, Massachusetts 2109',437,849);
INSERT INTO "django_geo_db_zipcode" VALUES(670,2110,-5,'Boston, Massachusetts 2110',437,850);
INSERT INTO "django_geo_db_zipcode" VALUES(671,2111,-5,'Boston, Massachusetts 2111',437,851);
INSERT INTO "django_geo_db_zipcode" VALUES(672,2112,-5,'Boston, Massachusetts 2112',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(673,2113,-5,'Boston, Massachusetts 2113',437,852);
INSERT INTO "django_geo_db_zipcode" VALUES(674,2114,-5,'Boston, Massachusetts 2114',437,853);
INSERT INTO "django_geo_db_zipcode" VALUES(675,2115,-5,'Boston, Massachusetts 2115',437,854);
INSERT INTO "django_geo_db_zipcode" VALUES(676,2116,-5,'Boston, Massachusetts 2116',437,855);
INSERT INTO "django_geo_db_zipcode" VALUES(677,2117,-5,'Boston, Massachusetts 2117',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(678,2118,-5,'Boston, Massachusetts 2118',437,856);
INSERT INTO "django_geo_db_zipcode" VALUES(679,2119,-5,'Boston, Massachusetts 2119',437,857);
INSERT INTO "django_geo_db_zipcode" VALUES(680,2120,-5,'Boston, Massachusetts 2120',437,858);
INSERT INTO "django_geo_db_zipcode" VALUES(681,2121,-5,'Boston, Massachusetts 2121',437,859);
INSERT INTO "django_geo_db_zipcode" VALUES(682,2122,-5,'Boston, Massachusetts 2122',437,860);
INSERT INTO "django_geo_db_zipcode" VALUES(683,2123,-5,'Boston, Massachusetts 2123',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(684,2124,-5,'Boston, Massachusetts 2124',437,861);
INSERT INTO "django_geo_db_zipcode" VALUES(685,2125,-5,'Boston, Massachusetts 2125',437,862);
INSERT INTO "django_geo_db_zipcode" VALUES(686,2126,-5,'Mattapan, Massachusetts 2126',438,863);
INSERT INTO "django_geo_db_zipcode" VALUES(687,2127,-5,'Boston, Massachusetts 2127',437,864);
INSERT INTO "django_geo_db_zipcode" VALUES(688,2128,-5,'Boston, Massachusetts 2128',437,865);
INSERT INTO "django_geo_db_zipcode" VALUES(689,2129,-5,'Charlestown, Massachusetts 2129',439,866);
INSERT INTO "django_geo_db_zipcode" VALUES(690,2130,-5,'Jamaica Plain, Massachusetts 2130',440,867);
INSERT INTO "django_geo_db_zipcode" VALUES(691,2131,-5,'Roslindale, Massachusetts 2131',441,868);
INSERT INTO "django_geo_db_zipcode" VALUES(692,2132,-5,'West Roxbury, Massachusetts 2132',442,869);
INSERT INTO "django_geo_db_zipcode" VALUES(693,2133,-5,'Boston, Massachusetts 2133',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(694,2134,-5,'Allston, Massachusetts 2134',443,870);
INSERT INTO "django_geo_db_zipcode" VALUES(695,2135,-5,'Brighton, Massachusetts 2135',444,871);
INSERT INTO "django_geo_db_zipcode" VALUES(696,2136,-5,'Hyde Park, Massachusetts 2136',445,872);
INSERT INTO "django_geo_db_zipcode" VALUES(697,2137,-5,'Readville, Massachusetts 2137',446,846);
INSERT INTO "django_geo_db_zipcode" VALUES(698,2138,-5,'Cambridge, Massachusetts 2138',447,873);
INSERT INTO "django_geo_db_zipcode" VALUES(699,2139,-5,'Cambridge, Massachusetts 2139',447,874);
INSERT INTO "django_geo_db_zipcode" VALUES(700,2140,-5,'Cambridge, Massachusetts 2140',447,875);
INSERT INTO "django_geo_db_zipcode" VALUES(701,2141,-5,'Cambridge, Massachusetts 2141',447,876);
INSERT INTO "django_geo_db_zipcode" VALUES(702,2142,-5,'Cambridge, Massachusetts 2142',447,877);
INSERT INTO "django_geo_db_zipcode" VALUES(703,2143,-5,'Somerville, Massachusetts 2143',448,878);
INSERT INTO "django_geo_db_zipcode" VALUES(704,2144,-5,'Somerville, Massachusetts 2144',448,879);
INSERT INTO "django_geo_db_zipcode" VALUES(705,2145,-5,'Somerville, Massachusetts 2145',448,880);
INSERT INTO "django_geo_db_zipcode" VALUES(706,2146,-5,'Brookline, Massachusetts 2146',449,881);
INSERT INTO "django_geo_db_zipcode" VALUES(707,2147,-5,'Brookline Village, Massachusetts 2147',450,816);
INSERT INTO "django_geo_db_zipcode" VALUES(708,2148,-5,'Malden, Massachusetts 2148',451,882);
INSERT INTO "django_geo_db_zipcode" VALUES(709,2149,-5,'Everett, Massachusetts 2149',452,883);
INSERT INTO "django_geo_db_zipcode" VALUES(710,2150,-5,'Chelsea, Massachusetts 2150',453,884);
INSERT INTO "django_geo_db_zipcode" VALUES(711,2151,-5,'Revere, Massachusetts 2151',454,885);
INSERT INTO "django_geo_db_zipcode" VALUES(712,2152,-5,'Winthrop, Massachusetts 2152',455,886);
INSERT INTO "django_geo_db_zipcode" VALUES(713,2153,-5,'Medford, Massachusetts 2153',456,647);
INSERT INTO "django_geo_db_zipcode" VALUES(714,2154,-5,'Waltham, Massachusetts 2154',457,887);
INSERT INTO "django_geo_db_zipcode" VALUES(715,2155,-5,'Medford, Massachusetts 2155',456,888);
INSERT INTO "django_geo_db_zipcode" VALUES(716,2156,-5,'West Medford, Massachusetts 2156',458,647);
INSERT INTO "django_geo_db_zipcode" VALUES(717,2157,-5,'Babson Park, Massachusetts 2157',459,889);
INSERT INTO "django_geo_db_zipcode" VALUES(718,2158,-5,'Newton, Massachusetts 2158',460,890);
INSERT INTO "django_geo_db_zipcode" VALUES(719,2159,-5,'Newton, Massachusetts 2159',460,891);
INSERT INTO "django_geo_db_zipcode" VALUES(720,2160,-5,'Newton, Massachusetts 2160',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(721,2161,-5,'Newton, Massachusetts 2161',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(722,2162,-5,'Newton, Massachusetts 2162',460,892);
INSERT INTO "django_geo_db_zipcode" VALUES(723,2163,-5,'Boston, Massachusetts 2163',437,893);
INSERT INTO "django_geo_db_zipcode" VALUES(724,2164,-5,'Newton, Massachusetts 2164',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(725,2165,-5,'Newton, Massachusetts 2165',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(726,2166,-5,'Auburndale, Massachusetts 2166',461,894);
INSERT INTO "django_geo_db_zipcode" VALUES(727,2167,-5,'Chestnut Hill, Massachusetts 2167',462,895);
INSERT INTO "django_geo_db_zipcode" VALUES(728,2168,-5,'Waban, Massachusetts 2168',463,647);
INSERT INTO "django_geo_db_zipcode" VALUES(729,2169,-5,'Quincy, Massachusetts 2169',464,896);
INSERT INTO "django_geo_db_zipcode" VALUES(730,2170,-5,'Quincy, Massachusetts 2170',464,897);
INSERT INTO "django_geo_db_zipcode" VALUES(731,2171,-5,'Quincy, Massachusetts 2171',464,898);
INSERT INTO "django_geo_db_zipcode" VALUES(732,2172,-5,'Watertown, Massachusetts 2172',465,899);
INSERT INTO "django_geo_db_zipcode" VALUES(733,2173,-5,'Lexington, Massachusetts 2173',466,647);
INSERT INTO "django_geo_db_zipcode" VALUES(734,2174,-5,'Arlington, Massachusetts 2174',467,900);
INSERT INTO "django_geo_db_zipcode" VALUES(735,2175,-5,'Arlington Heights, Massachusetts 2175',468,647);
INSERT INTO "django_geo_db_zipcode" VALUES(736,2176,-5,'Melrose, Massachusetts 2176',469,901);
INSERT INTO "django_geo_db_zipcode" VALUES(737,2177,-5,'Melrose, Massachusetts 2177',469,647);
INSERT INTO "django_geo_db_zipcode" VALUES(738,2178,-5,'Belmont, Massachusetts 2178',470,647);
INSERT INTO "django_geo_db_zipcode" VALUES(739,2179,-5,'Waverley, Massachusetts 2179',471,647);
INSERT INTO "django_geo_db_zipcode" VALUES(740,2180,-5,'Stoneham, Massachusetts 2180',472,902);
INSERT INTO "django_geo_db_zipcode" VALUES(741,2181,-5,'Wellesley, Massachusetts 2181',473,903);
INSERT INTO "django_geo_db_zipcode" VALUES(742,2184,-5,'Braintree, Massachusetts 2184',474,904);
INSERT INTO "django_geo_db_zipcode" VALUES(743,2185,-5,'Braintree, Massachusetts 2185',474,816);
INSERT INTO "django_geo_db_zipcode" VALUES(744,2186,-5,'Milton, Massachusetts 2186',475,905);
INSERT INTO "django_geo_db_zipcode" VALUES(745,2187,-5,'Milton Village, Massachusetts 2187',476,816);
INSERT INTO "django_geo_db_zipcode" VALUES(746,2188,-5,'Weymouth, Massachusetts 2188',477,906);
INSERT INTO "django_geo_db_zipcode" VALUES(747,2189,-5,'Weymouth, Massachusetts 2189',477,907);
INSERT INTO "django_geo_db_zipcode" VALUES(748,2190,-5,'Weymouth, Massachusetts 2190',477,908);
INSERT INTO "django_geo_db_zipcode" VALUES(749,2191,-5,'Weymouth, Massachusetts 2191',477,909);
INSERT INTO "django_geo_db_zipcode" VALUES(750,2192,-5,'Needham, Massachusetts 2192',478,816);
INSERT INTO "django_geo_db_zipcode" VALUES(751,2193,-5,'Weston, Massachusetts 2193',479,647);
INSERT INTO "django_geo_db_zipcode" VALUES(752,2194,-5,'Needham, Massachusetts 2194',478,910);
INSERT INTO "django_geo_db_zipcode" VALUES(753,2195,-5,'Newton, Massachusetts 2195',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(754,2196,-5,'Boston, Massachusetts 2196',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(755,2199,-5,'Boston, Massachusetts 2199',437,911);
INSERT INTO "django_geo_db_zipcode" VALUES(756,2201,-5,'Boston, Massachusetts 2201',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(757,2202,-5,'Boston, Massachusetts 2202',437,912);
INSERT INTO "django_geo_db_zipcode" VALUES(758,2203,-5,'Boston, Massachusetts 2203',437,913);
INSERT INTO "django_geo_db_zipcode" VALUES(759,2204,-5,'Boston, Massachusetts 2204',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(760,2205,-5,'Boston, Massachusetts 2205',437,914);
INSERT INTO "django_geo_db_zipcode" VALUES(761,2206,-5,'Boston, Massachusetts 2206',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(762,2207,-5,'Boston, Massachusetts 2207',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(763,2208,-5,'Boston, Massachusetts 2208',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(764,2209,-5,'Boston, Massachusetts 2209',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(765,2210,-5,'Boston, Massachusetts 2210',437,915);
INSERT INTO "django_geo_db_zipcode" VALUES(766,2211,-5,'Boston, Massachusetts 2211',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(767,2212,-5,'Boston, Massachusetts 2212',437,647);
INSERT INTO "django_geo_db_zipcode" VALUES(768,2215,-5,'Boston, Massachusetts 2215',437,916);
INSERT INTO "django_geo_db_zipcode" VALUES(769,2216,-5,'Boston, Massachusetts 2216',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(770,2217,-5,'Boston, Massachusetts 2217',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(771,2222,-5,'Boston, Massachusetts 2222',437,917);
INSERT INTO "django_geo_db_zipcode" VALUES(772,2238,-5,'Cambridge, Massachusetts 2238',447,647);
INSERT INTO "django_geo_db_zipcode" VALUES(773,2239,-5,'Cambridge, Massachusetts 2239',447,647);
INSERT INTO "django_geo_db_zipcode" VALUES(774,2241,-5,'Boston, Massachusetts 2241',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(775,2254,-5,'Waltham, Massachusetts 2254',457,647);
INSERT INTO "django_geo_db_zipcode" VALUES(776,2258,-5,'Newton, Massachusetts 2258',460,647);
INSERT INTO "django_geo_db_zipcode" VALUES(777,2266,-5,'Boston, Massachusetts 2266',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(778,2269,-5,'Quincy, Massachusetts 2269',464,816);
INSERT INTO "django_geo_db_zipcode" VALUES(779,2272,-5,'Watertown, Massachusetts 2272',465,647);
INSERT INTO "django_geo_db_zipcode" VALUES(780,2277,-5,'Watertown, Massachusetts 2277',465,647);
INSERT INTO "django_geo_db_zipcode" VALUES(781,2283,-5,'Boston, Massachusetts 2283',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(782,2284,-5,'Boston, Massachusetts 2284',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(783,2293,-5,'Boston, Massachusetts 2293',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(784,2295,-5,'Boston, Massachusetts 2295',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(785,2297,-5,'Boston, Massachusetts 2297',437,846);
INSERT INTO "django_geo_db_zipcode" VALUES(786,2301,-5,'Brockton, Massachusetts 2301',480,918);
INSERT INTO "django_geo_db_zipcode" VALUES(787,2302,-5,'Brockton, Massachusetts 2302',480,919);
INSERT INTO "django_geo_db_zipcode" VALUES(788,2303,-5,'Brockton, Massachusetts 2303',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(789,2304,-5,'Brockton, Massachusetts 2304',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(790,2305,-5,'Brockton, Massachusetts 2305',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(791,2322,-5,'Avon, Massachusetts 2322',481,920);
INSERT INTO "django_geo_db_zipcode" VALUES(792,2324,-5,'Bridgewater, Massachusetts 2324',482,921);
INSERT INTO "django_geo_db_zipcode" VALUES(793,2325,-5,'Bridgewater, Massachusetts 2325',482,922);
INSERT INTO "django_geo_db_zipcode" VALUES(794,2327,-5,'Bryantville, Massachusetts 2327',483,923);
INSERT INTO "django_geo_db_zipcode" VALUES(795,2330,-5,'Carver, Massachusetts 2330',484,924);
INSERT INTO "django_geo_db_zipcode" VALUES(796,2331,-5,'Duxbury, Massachusetts 2331',485,810);
INSERT INTO "django_geo_db_zipcode" VALUES(797,2332,-5,'Duxbury, Massachusetts 2332',485,925);
INSERT INTO "django_geo_db_zipcode" VALUES(798,2333,-5,'East Bridgewater, Massachusetts 2333',486,926);
INSERT INTO "django_geo_db_zipcode" VALUES(799,2334,-5,'Easton, Massachusetts 2334',487,927);
INSERT INTO "django_geo_db_zipcode" VALUES(800,2337,-5,'Elmwood, Massachusetts 2337',488,928);
INSERT INTO "django_geo_db_zipcode" VALUES(801,2338,-5,'Halifax, Massachusetts 2338',489,929);
INSERT INTO "django_geo_db_zipcode" VALUES(802,2339,-5,'Hanover, Massachusetts 2339',490,930);
INSERT INTO "django_geo_db_zipcode" VALUES(803,2341,-5,'Hanson, Massachusetts 2341',491,931);
INSERT INTO "django_geo_db_zipcode" VALUES(804,2343,-5,'Holbrook, Massachusetts 2343',492,932);
INSERT INTO "django_geo_db_zipcode" VALUES(805,2344,-5,'Middleboro, Massachusetts 2344',493,810);
INSERT INTO "django_geo_db_zipcode" VALUES(806,2345,-5,'Manomet, Massachusetts 2345',494,933);
INSERT INTO "django_geo_db_zipcode" VALUES(807,2346,-5,'Middleboro, Massachusetts 2346',493,934);
INSERT INTO "django_geo_db_zipcode" VALUES(808,2347,-5,'Lakeville, Massachusetts 2347',495,935);
INSERT INTO "django_geo_db_zipcode" VALUES(809,2348,-5,'Middleboro, Massachusetts 2348',493,810);
INSERT INTO "django_geo_db_zipcode" VALUES(810,2349,-5,'Middleboro, Massachusetts 2349',493,810);
INSERT INTO "django_geo_db_zipcode" VALUES(811,2350,-5,'Monponsett, Massachusetts 2350',496,936);
INSERT INTO "django_geo_db_zipcode" VALUES(812,2351,-5,'Abington, Massachusetts 2351',497,937);
INSERT INTO "django_geo_db_zipcode" VALUES(813,2355,-5,'North Carver, Massachusetts 2355',498,938);
INSERT INTO "django_geo_db_zipcode" VALUES(814,2356,-5,'North Easton, Massachusetts 2356',499,939);
INSERT INTO "django_geo_db_zipcode" VALUES(815,2357,-5,'North Easton, Massachusetts 2357',499,940);
INSERT INTO "django_geo_db_zipcode" VALUES(816,2358,-5,'North Pembroke, Massachusetts 2358',500,941);
INSERT INTO "django_geo_db_zipcode" VALUES(817,2359,-5,'Pembroke, Massachusetts 2359',501,942);
INSERT INTO "django_geo_db_zipcode" VALUES(818,2360,-5,'Plymouth, Massachusetts 2360',502,943);
INSERT INTO "django_geo_db_zipcode" VALUES(819,2361,-5,'Plymouth, Massachusetts 2361',502,810);
INSERT INTO "django_geo_db_zipcode" VALUES(820,2362,-5,'Plymouth, Massachusetts 2362',502,810);
INSERT INTO "django_geo_db_zipcode" VALUES(821,2363,-5,'Plymouth, Massachusetts 2363',502,944);
INSERT INTO "django_geo_db_zipcode" VALUES(822,2364,-5,'Kingston, Massachusetts 2364',503,945);
INSERT INTO "django_geo_db_zipcode" VALUES(823,2366,-5,'South Carver, Massachusetts 2366',504,946);
INSERT INTO "django_geo_db_zipcode" VALUES(824,2367,-5,'Plympton, Massachusetts 2367',505,947);
INSERT INTO "django_geo_db_zipcode" VALUES(825,2368,-5,'Randolph, Massachusetts 2368',506,948);
INSERT INTO "django_geo_db_zipcode" VALUES(826,2369,-5,'Dennis Port, Massachusetts 2369',507,949);
INSERT INTO "django_geo_db_zipcode" VALUES(827,2370,-5,'Rockland, Massachusetts 2370',508,950);
INSERT INTO "django_geo_db_zipcode" VALUES(828,2375,-5,'South Easton, Massachusetts 2375',509,951);
INSERT INTO "django_geo_db_zipcode" VALUES(829,2379,-5,'West Bridgewater, Massachusetts 2379',510,952);
INSERT INTO "django_geo_db_zipcode" VALUES(830,2381,-5,'White Horse Beach, Massachusetts 2381',511,953);
INSERT INTO "django_geo_db_zipcode" VALUES(831,2382,-5,'Whitman, Massachusetts 2382',512,954);
INSERT INTO "django_geo_db_zipcode" VALUES(832,2401,-5,'Brockton, Massachusetts 2401',480,955);
INSERT INTO "django_geo_db_zipcode" VALUES(833,2402,-5,'Brockton, Massachusetts 2402',480,956);
INSERT INTO "django_geo_db_zipcode" VALUES(834,2403,-5,'Brockton, Massachusetts 2403',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(835,2404,-5,'Brockton, Massachusetts 2404',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(836,2405,-5,'Brockton, Massachusetts 2405',480,810);
INSERT INTO "django_geo_db_zipcode" VALUES(837,2407,-5,'Scituate, Massachusetts 2407',428,957);
INSERT INTO "django_geo_db_zipcode" VALUES(838,2420,-5,'Lexington, Massachusetts 2420',466,958);
INSERT INTO "django_geo_db_zipcode" VALUES(839,2421,-5,'Lexington, Massachusetts 2421',466,959);
INSERT INTO "django_geo_db_zipcode" VALUES(840,2445,-5,'Brookline, Massachusetts 2445',449,960);
INSERT INTO "django_geo_db_zipcode" VALUES(841,2446,-5,'Brookline, Massachusetts 2446',449,961);
INSERT INTO "django_geo_db_zipcode" VALUES(842,2447,-5,'Brookline Village, Massachusetts 2447',450,816);
INSERT INTO "django_geo_db_zipcode" VALUES(843,2451,-5,'Waltham, Massachusetts 2451',457,962);
INSERT INTO "django_geo_db_zipcode" VALUES(844,2452,-5,'Waltham, Massachusetts 2452',457,963);
INSERT INTO "django_geo_db_zipcode" VALUES(845,2453,-5,'Waltham, Massachusetts 2453',457,964);
INSERT INTO "django_geo_db_zipcode" VALUES(846,2454,-5,'Waltham, Massachusetts 2454',457,965);
INSERT INTO "django_geo_db_zipcode" VALUES(847,2456,-5,'New Town, Massachusetts 2456',513,647);
INSERT INTO "django_geo_db_zipcode" VALUES(848,2457,-5,'Babson Park, Massachusetts 2457',459,816);
INSERT INTO "django_geo_db_zipcode" VALUES(849,2458,-5,'Newton, Massachusetts 2458',460,966);
INSERT INTO "django_geo_db_zipcode" VALUES(850,2459,-5,'Newton Center, Massachusetts 2459',514,967);
INSERT INTO "django_geo_db_zipcode" VALUES(851,2460,-5,'Newtonville, Massachusetts 2460',515,968);
INSERT INTO "django_geo_db_zipcode" VALUES(852,2461,-5,'Newton Highlands, Massachusetts 2461',516,969);
INSERT INTO "django_geo_db_zipcode" VALUES(853,2462,-5,'Newton Lower Falls, Massachusetts 2462',517,970);
INSERT INTO "django_geo_db_zipcode" VALUES(854,2464,-5,'Newton Upper Falls, Massachusetts 2464',518,971);
INSERT INTO "django_geo_db_zipcode" VALUES(855,2465,-5,'West Newton, Massachusetts 2465',519,972);
INSERT INTO "django_geo_db_zipcode" VALUES(856,2466,-5,'Auburndale, Massachusetts 2466',461,973);
INSERT INTO "django_geo_db_zipcode" VALUES(857,2467,-5,'Chestnut Hill, Massachusetts 2467',462,974);
INSERT INTO "django_geo_db_zipcode" VALUES(858,2468,-5,'Waban, Massachusetts 2468',463,975);
INSERT INTO "django_geo_db_zipcode" VALUES(859,2471,-5,'Watertown, Massachusetts 2471',465,647);
INSERT INTO "django_geo_db_zipcode" VALUES(860,2472,-5,'Watertown, Massachusetts 2472',465,976);
INSERT INTO "django_geo_db_zipcode" VALUES(861,2474,-5,'Arlington, Massachusetts 2474',467,977);
INSERT INTO "django_geo_db_zipcode" VALUES(862,2475,-5,'Arlington Heights, Massachusetts 2475',468,647);
INSERT INTO "django_geo_db_zipcode" VALUES(863,2476,-5,'Arlington, Massachusetts 2476',467,978);
INSERT INTO "django_geo_db_zipcode" VALUES(864,2477,-5,'Watertown, Massachusetts 2477',465,647);
INSERT INTO "django_geo_db_zipcode" VALUES(865,2478,-5,'Belmont, Massachusetts 2478',470,979);
INSERT INTO "django_geo_db_zipcode" VALUES(866,2479,-5,'Waverley, Massachusetts 2479',471,647);
INSERT INTO "django_geo_db_zipcode" VALUES(867,2481,-5,'Wellesley Hills, Massachusetts 2481',520,980);
INSERT INTO "django_geo_db_zipcode" VALUES(868,2482,-5,'Wellesley, Massachusetts 2482',473,981);
INSERT INTO "django_geo_db_zipcode" VALUES(869,2492,-5,'Needham, Massachusetts 2492',478,982);
INSERT INTO "django_geo_db_zipcode" VALUES(870,2493,-5,'Weston, Massachusetts 2493',479,983);
INSERT INTO "django_geo_db_zipcode" VALUES(871,2494,-5,'Needham, Massachusetts 2494',478,984);
INSERT INTO "django_geo_db_zipcode" VALUES(872,2495,-5,'Nonantum, Massachusetts 2495',521,647);
INSERT INTO "django_geo_db_zipcode" VALUES(873,2532,-5,'Buzzards Bay, Massachusetts 2532',522,985);
INSERT INTO "django_geo_db_zipcode" VALUES(874,2534,-5,'Cataumet, Massachusetts 2534',523,986);
INSERT INTO "django_geo_db_zipcode" VALUES(875,2535,-5,'Chilmark, Massachusetts 2535',524,987);
INSERT INTO "django_geo_db_zipcode" VALUES(876,2536,-5,'East Falmouth, Massachusetts 2536',525,988);
INSERT INTO "django_geo_db_zipcode" VALUES(877,2537,-5,'East Sandwich, Massachusetts 2537',526,989);
INSERT INTO "django_geo_db_zipcode" VALUES(878,2538,-5,'East Wareham, Massachusetts 2538',527,990);
INSERT INTO "django_geo_db_zipcode" VALUES(879,2539,-5,'Edgartown, Massachusetts 2539',528,991);
INSERT INTO "django_geo_db_zipcode" VALUES(880,2540,-5,'Falmouth, Massachusetts 2540',529,992);
INSERT INTO "django_geo_db_zipcode" VALUES(881,2541,-5,'Falmouth, Massachusetts 2541',529,993);
INSERT INTO "django_geo_db_zipcode" VALUES(882,2542,-5,'Buzzards Bay, Massachusetts 2542',522,994);
INSERT INTO "django_geo_db_zipcode" VALUES(883,2543,-5,'Woods Hole, Massachusetts 2543',530,995);
INSERT INTO "django_geo_db_zipcode" VALUES(884,2549,-5,'Mashpee, Massachusetts 2549',531,996);
INSERT INTO "django_geo_db_zipcode" VALUES(885,2551,-5,'Oak Bluffs, Massachusetts 2551',532,997);
INSERT INTO "django_geo_db_zipcode" VALUES(886,2552,-5,'Menemsha, Massachusetts 2552',533,998);
INSERT INTO "django_geo_db_zipcode" VALUES(887,2553,-5,'Monument Beach, Massachusetts 2553',534,999);
INSERT INTO "django_geo_db_zipcode" VALUES(888,2554,-5,'Nantucket, Massachusetts 2554',535,1000);
INSERT INTO "django_geo_db_zipcode" VALUES(889,2556,-5,'North Falmouth, Massachusetts 2556',536,1001);
INSERT INTO "django_geo_db_zipcode" VALUES(890,2557,-5,'Oak Bluffs, Massachusetts 2557',532,1002);
INSERT INTO "django_geo_db_zipcode" VALUES(891,2558,-5,'Onset, Massachusetts 2558',537,1003);
INSERT INTO "django_geo_db_zipcode" VALUES(892,2559,-5,'Pocasset, Massachusetts 2559',538,1004);
INSERT INTO "django_geo_db_zipcode" VALUES(893,2561,-5,'Sagamore, Massachusetts 2561',539,1005);
INSERT INTO "django_geo_db_zipcode" VALUES(894,2562,-5,'Sagamore Beach, Massachusetts 2562',540,1006);
INSERT INTO "django_geo_db_zipcode" VALUES(895,2563,-5,'Sandwich, Massachusetts 2563',541,1007);
INSERT INTO "django_geo_db_zipcode" VALUES(896,2564,-5,'Siasconset, Massachusetts 2564',542,1008);
INSERT INTO "django_geo_db_zipcode" VALUES(897,2565,-5,'Silver Beach, Massachusetts 2565',543,993);
INSERT INTO "django_geo_db_zipcode" VALUES(898,2567,-5,'Sagamore, Massachusetts 2567',539,1009);
INSERT INTO "django_geo_db_zipcode" VALUES(899,2568,-5,'Vineyard Haven, Massachusetts 2568',544,1010);
INSERT INTO "django_geo_db_zipcode" VALUES(900,2571,-5,'Wareham, Massachusetts 2571',545,1011);
INSERT INTO "django_geo_db_zipcode" VALUES(901,2573,-5,'Vineyard Haven, Massachusetts 2573',544,998);
INSERT INTO "django_geo_db_zipcode" VALUES(902,2574,-5,'West Falmouth, Massachusetts 2574',546,1012);
INSERT INTO "django_geo_db_zipcode" VALUES(903,2575,-5,'West Tisbury, Massachusetts 2575',547,1013);
INSERT INTO "django_geo_db_zipcode" VALUES(904,2576,-5,'West Wareham, Massachusetts 2576',548,1014);
INSERT INTO "django_geo_db_zipcode" VALUES(905,2584,-5,'Nantucket, Massachusetts 2584',535,1015);
INSERT INTO "django_geo_db_zipcode" VALUES(906,2595,-5,'West Tisbury, Massachusetts 2595',547,1016);
INSERT INTO "django_geo_db_zipcode" VALUES(907,2601,-5,'Hyannis, Massachusetts 2601',549,1017);
INSERT INTO "django_geo_db_zipcode" VALUES(908,2625,-5,'Barnstable Town, Massachusetts 2625',550,1018);
INSERT INTO "django_geo_db_zipcode" VALUES(909,2630,-5,'Barnstable, Massachusetts 2630',551,1019);
INSERT INTO "django_geo_db_zipcode" VALUES(910,2631,-5,'Brewster, Massachusetts 2631',552,1020);
INSERT INTO "django_geo_db_zipcode" VALUES(911,2632,-5,'Centerville, Massachusetts 2632',553,1021);
INSERT INTO "django_geo_db_zipcode" VALUES(912,2633,-5,'Chatham, Massachusetts 2633',554,1022);
INSERT INTO "django_geo_db_zipcode" VALUES(913,2634,-5,'Centerville, Massachusetts 2634',553,993);
INSERT INTO "django_geo_db_zipcode" VALUES(914,2635,-5,'Cotuit, Massachusetts 2635',555,1023);
INSERT INTO "django_geo_db_zipcode" VALUES(915,2636,-5,'Centerville, Massachusetts 2636',553,993);
INSERT INTO "django_geo_db_zipcode" VALUES(916,2637,-5,'Cummaquid, Massachusetts 2637',556,1024);
INSERT INTO "django_geo_db_zipcode" VALUES(917,2638,-5,'Dennis, Massachusetts 2638',557,1025);
INSERT INTO "django_geo_db_zipcode" VALUES(918,2639,-5,'Dennis Port, Massachusetts 2639',507,1026);
INSERT INTO "django_geo_db_zipcode" VALUES(919,2641,-5,'East Dennis, Massachusetts 2641',558,1027);
INSERT INTO "django_geo_db_zipcode" VALUES(920,2642,-5,'Eastham, Massachusetts 2642',559,1028);
INSERT INTO "django_geo_db_zipcode" VALUES(921,2643,-5,'East Orleans, Massachusetts 2643',560,1029);
INSERT INTO "django_geo_db_zipcode" VALUES(922,2644,-5,'Forestdale, Massachusetts 2644',561,1030);
INSERT INTO "django_geo_db_zipcode" VALUES(923,2645,-5,'Harwich, Massachusetts 2645',562,1031);
INSERT INTO "django_geo_db_zipcode" VALUES(924,2646,-5,'Harwich Port, Massachusetts 2646',563,1032);
INSERT INTO "django_geo_db_zipcode" VALUES(925,2647,-5,'Hyannis Port, Massachusetts 2647',564,1033);
INSERT INTO "django_geo_db_zipcode" VALUES(926,2648,-5,'Marstons Mills, Massachusetts 2648',565,1034);
INSERT INTO "django_geo_db_zipcode" VALUES(927,2649,-5,'Mashpee, Massachusetts 2649',531,1035);
INSERT INTO "django_geo_db_zipcode" VALUES(928,2650,-5,'North Chatham, Massachusetts 2650',566,1036);
INSERT INTO "django_geo_db_zipcode" VALUES(929,2651,-5,'North Eastham, Massachusetts 2651',567,1037);
INSERT INTO "django_geo_db_zipcode" VALUES(930,2652,-5,'North Truro, Massachusetts 2652',568,1038);
INSERT INTO "django_geo_db_zipcode" VALUES(931,2653,-5,'Orleans, Massachusetts 2653',569,1039);
INSERT INTO "django_geo_db_zipcode" VALUES(932,2654,-5,'Nantucket, Massachusetts 2654',535,1040);
INSERT INTO "django_geo_db_zipcode" VALUES(933,2655,-5,'Osterville, Massachusetts 2655',570,1041);
INSERT INTO "django_geo_db_zipcode" VALUES(934,2657,-5,'Provincetown, Massachusetts 2657',571,1042);
INSERT INTO "django_geo_db_zipcode" VALUES(935,2659,-5,'South Chatham, Massachusetts 2659',572,1043);
INSERT INTO "django_geo_db_zipcode" VALUES(936,2660,-5,'South Dennis, Massachusetts 2660',573,1044);
INSERT INTO "django_geo_db_zipcode" VALUES(937,2661,-5,'South Harwich, Massachusetts 2661',574,1045);
INSERT INTO "django_geo_db_zipcode" VALUES(938,2662,-5,'South Orleans, Massachusetts 2662',575,1046);
INSERT INTO "django_geo_db_zipcode" VALUES(939,2663,-5,'South Wellfleet, Massachusetts 2663',576,1047);
INSERT INTO "django_geo_db_zipcode" VALUES(940,2664,-5,'South Yarmouth, Massachusetts 2664',577,1048);
INSERT INTO "django_geo_db_zipcode" VALUES(941,2666,-5,'Truro, Massachusetts 2666',578,1049);
INSERT INTO "django_geo_db_zipcode" VALUES(942,2667,-5,'Wellfleet, Massachusetts 2667',579,1050);
INSERT INTO "django_geo_db_zipcode" VALUES(943,2668,-5,'West Barnstable, Massachusetts 2668',580,1051);
INSERT INTO "django_geo_db_zipcode" VALUES(944,2669,-5,'West Chatham, Massachusetts 2669',581,1052);
INSERT INTO "django_geo_db_zipcode" VALUES(945,2670,-5,'West Dennis, Massachusetts 2670',582,1053);
INSERT INTO "django_geo_db_zipcode" VALUES(946,2671,-5,'West Harwich, Massachusetts 2671',583,1054);
INSERT INTO "django_geo_db_zipcode" VALUES(947,2672,-5,'West Hyannisport, Massachusetts 2672',584,1055);
INSERT INTO "django_geo_db_zipcode" VALUES(948,2673,-5,'West Yarmouth, Massachusetts 2673',585,1056);
INSERT INTO "django_geo_db_zipcode" VALUES(949,2675,-5,'Yarmouth Port, Massachusetts 2675',586,1057);
INSERT INTO "django_geo_db_zipcode" VALUES(950,2702,-5,'Assonet, Massachusetts 2702',587,1058);
INSERT INTO "django_geo_db_zipcode" VALUES(951,2703,-5,'Attleboro, Massachusetts 2703',588,1059);
INSERT INTO "django_geo_db_zipcode" VALUES(952,2712,-5,'Chartley, Massachusetts 2712',589,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(953,2713,-5,'Cuttyhunk, Massachusetts 2713',590,1061);
INSERT INTO "django_geo_db_zipcode" VALUES(954,2714,-5,'Dartmouth, Massachusetts 2714',591,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(955,2715,-5,'Dighton, Massachusetts 2715',592,1062);
INSERT INTO "django_geo_db_zipcode" VALUES(956,2717,-5,'East Freetown, Massachusetts 2717',593,1063);
INSERT INTO "django_geo_db_zipcode" VALUES(957,2718,-5,'East Taunton, Massachusetts 2718',594,1064);
INSERT INTO "django_geo_db_zipcode" VALUES(958,2719,-5,'Fairhaven, Massachusetts 2719',595,1065);
INSERT INTO "django_geo_db_zipcode" VALUES(959,2720,-5,'Fall River, Massachusetts 2720',596,1066);
INSERT INTO "django_geo_db_zipcode" VALUES(960,2721,-5,'Fall River, Massachusetts 2721',596,1067);
INSERT INTO "django_geo_db_zipcode" VALUES(961,2722,-5,'Fall River, Massachusetts 2722',596,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(962,2723,-5,'Fall River, Massachusetts 2723',596,1068);
INSERT INTO "django_geo_db_zipcode" VALUES(963,2724,-5,'Fall River, Massachusetts 2724',596,1069);
INSERT INTO "django_geo_db_zipcode" VALUES(964,2725,-5,'Somerset, Massachusetts 2725',597,1070);
INSERT INTO "django_geo_db_zipcode" VALUES(965,2726,-5,'Somerset, Massachusetts 2726',597,1071);
INSERT INTO "django_geo_db_zipcode" VALUES(966,2735,-5,'Easton, Massachusetts 2735',487,1072);
INSERT INTO "django_geo_db_zipcode" VALUES(967,2738,-5,'Marion, Massachusetts 2738',598,1073);
INSERT INTO "django_geo_db_zipcode" VALUES(968,2739,-5,'Mattapoisett, Massachusetts 2739',599,1074);
INSERT INTO "django_geo_db_zipcode" VALUES(969,2740,-5,'New Bedford, Massachusetts 2740',600,1075);
INSERT INTO "django_geo_db_zipcode" VALUES(970,2741,-5,'New Bedford, Massachusetts 2741',600,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(971,2742,-5,'New Bedford, Massachusetts 2742',600,1076);
INSERT INTO "django_geo_db_zipcode" VALUES(972,2743,-5,'Acushnet, Massachusetts 2743',601,1077);
INSERT INTO "django_geo_db_zipcode" VALUES(973,2744,-5,'New Bedford, Massachusetts 2744',600,1078);
INSERT INTO "django_geo_db_zipcode" VALUES(974,2745,-5,'New Bedford, Massachusetts 2745',600,1079);
INSERT INTO "django_geo_db_zipcode" VALUES(975,2746,-5,'New Bedford, Massachusetts 2746',600,1080);
INSERT INTO "django_geo_db_zipcode" VALUES(976,2747,-5,'North Dartmouth, Massachusetts 2747',602,1081);
INSERT INTO "django_geo_db_zipcode" VALUES(977,2748,-5,'South Dartmouth, Massachusetts 2748',603,1082);
INSERT INTO "django_geo_db_zipcode" VALUES(978,2760,-5,'North Attleboro, Massachusetts 2760',604,1083);
INSERT INTO "django_geo_db_zipcode" VALUES(979,2761,-5,'North Attleboro, Massachusetts 2761',604,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(980,2762,-5,'Plainville, Massachusetts 2762',605,1084);
INSERT INTO "django_geo_db_zipcode" VALUES(981,2763,-5,'Attleboro Falls, Massachusetts 2763',606,1085);
INSERT INTO "django_geo_db_zipcode" VALUES(982,2764,-5,'North Dighton, Massachusetts 2764',607,1086);
INSERT INTO "django_geo_db_zipcode" VALUES(983,2766,-5,'Norton, Massachusetts 2766',608,1087);
INSERT INTO "django_geo_db_zipcode" VALUES(984,2767,-5,'Raynham, Massachusetts 2767',609,1088);
INSERT INTO "django_geo_db_zipcode" VALUES(985,2768,-5,'Raynham Center, Massachusetts 2768',610,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(986,2769,-5,'Rehoboth, Massachusetts 2769',611,1089);
INSERT INTO "django_geo_db_zipcode" VALUES(987,2770,-5,'Rochester, Massachusetts 2770',612,1090);
INSERT INTO "django_geo_db_zipcode" VALUES(988,2771,-5,'Seekonk, Massachusetts 2771',613,1091);
INSERT INTO "django_geo_db_zipcode" VALUES(989,2777,-5,'Swansea, Massachusetts 2777',614,1092);
INSERT INTO "django_geo_db_zipcode" VALUES(990,2779,-5,'Berkley, Massachusetts 2779',615,1093);
INSERT INTO "django_geo_db_zipcode" VALUES(991,2780,-5,'Taunton, Massachusetts 2780',616,1094);
INSERT INTO "django_geo_db_zipcode" VALUES(992,2781,-5,'Westport, Massachusetts 2781',617,1095);
INSERT INTO "django_geo_db_zipcode" VALUES(993,2783,-5,'Taunton, Massachusetts 2783',616,1060);
INSERT INTO "django_geo_db_zipcode" VALUES(994,2789,-5,'South Kingstown, Rhode Island 2789',618,1096);
INSERT INTO "django_geo_db_zipcode" VALUES(995,2790,-5,'Westport, Massachusetts 2790',617,1097);
INSERT INTO "django_geo_db_zipcode" VALUES(996,2791,-5,'Westport Point, Massachusetts 2791',619,1098);
INSERT INTO "django_geo_db_zipcode" VALUES(997,2801,-5,'Adamsville, Rhode Island 2801',620,1099);
INSERT INTO "django_geo_db_zipcode" VALUES(998,2802,-5,'Albion, Rhode Island 2802',621,1100);
INSERT INTO "django_geo_db_zipcode" VALUES(999,2804,-5,'Ashaway, Rhode Island 2804',622,1101);
INSERT INTO "django_geo_db_zipcode" VALUES(1000,2805,-5,'Foster, Rhode Island 2805',623,1102);
INSERT INTO "django_geo_db_zipcode" VALUES(1001,2806,-5,'Barrington, Rhode Island 2806',624,1103);
INSERT INTO "django_geo_db_zipcode" VALUES(1002,2807,-5,'Block Island, Rhode Island 2807',625,1104);
INSERT INTO "django_geo_db_zipcode" VALUES(1003,2808,-5,'Bradford, Rhode Island 2808',626,1105);
INSERT INTO "django_geo_db_zipcode" VALUES(1004,2809,-5,'Bristol, Rhode Island 2809',627,1106);
INSERT INTO "django_geo_db_zipcode" VALUES(1005,2812,-5,'Carolina, Rhode Island 2812',628,1107);
INSERT INTO "django_geo_db_zipcode" VALUES(1006,2813,-5,'Charlestown, Rhode Island 2813',629,1108);
INSERT INTO "django_geo_db_zipcode" VALUES(1007,2814,-5,'Chepachet, Rhode Island 2814',630,1109);
INSERT INTO "django_geo_db_zipcode" VALUES(1008,2815,-5,'Clayville, Rhode Island 2815',631,1110);
INSERT INTO "django_geo_db_zipcode" VALUES(1009,2816,-5,'Coventry, Rhode Island 2816',632,1111);
INSERT INTO "django_geo_db_zipcode" VALUES(1010,2817,-5,'West Greenwich, Rhode Island 2817',633,1112);
INSERT INTO "django_geo_db_zipcode" VALUES(1011,2818,-5,'East Greenwich, Rhode Island 2818',634,1113);
INSERT INTO "django_geo_db_zipcode" VALUES(1012,2822,-5,'Exeter, Rhode Island 2822',635,1114);
INSERT INTO "django_geo_db_zipcode" VALUES(1013,2823,-5,'Fiskeville, Rhode Island 2823',636,1115);
INSERT INTO "django_geo_db_zipcode" VALUES(1014,2824,-5,'Forestdale, Rhode Island 2824',637,1116);
INSERT INTO "django_geo_db_zipcode" VALUES(1015,2825,-5,'Foster, Rhode Island 2825',623,1117);
INSERT INTO "django_geo_db_zipcode" VALUES(1016,2826,-5,'Glendale, Rhode Island 2826',638,1118);
INSERT INTO "django_geo_db_zipcode" VALUES(1017,2827,-5,'Greene, Rhode Island 2827',639,1119);
INSERT INTO "django_geo_db_zipcode" VALUES(1018,2828,-5,'Greenville, Rhode Island 2828',640,1120);
INSERT INTO "django_geo_db_zipcode" VALUES(1019,2829,-5,'Harmony, Rhode Island 2829',641,1121);
INSERT INTO "django_geo_db_zipcode" VALUES(1020,2830,-5,'Harrisville, Rhode Island 2830',642,1122);
INSERT INTO "django_geo_db_zipcode" VALUES(1021,2831,-5,'Hope, Rhode Island 2831',643,1123);
INSERT INTO "django_geo_db_zipcode" VALUES(1022,2832,-5,'Hope Valley, Rhode Island 2832',644,1124);
INSERT INTO "django_geo_db_zipcode" VALUES(1023,2833,-5,'Hopkinton, Rhode Island 2833',645,1125);
INSERT INTO "django_geo_db_zipcode" VALUES(1024,2835,-5,'Jamestown, Rhode Island 2835',646,1126);
INSERT INTO "django_geo_db_zipcode" VALUES(1025,2836,-5,'Kenyon, Rhode Island 2836',647,1127);
INSERT INTO "django_geo_db_zipcode" VALUES(1026,2837,-5,'Little Compton, Rhode Island 2837',648,1128);
INSERT INTO "django_geo_db_zipcode" VALUES(1027,2838,-5,'Manville, Rhode Island 2838',649,1129);
INSERT INTO "django_geo_db_zipcode" VALUES(1028,2839,-5,'Mapleville, Rhode Island 2839',650,1130);
INSERT INTO "django_geo_db_zipcode" VALUES(1029,2840,-5,'Newport, Rhode Island 2840',651,1131);
INSERT INTO "django_geo_db_zipcode" VALUES(1030,2841,-5,'Newport, Rhode Island 2841',651,1132);
INSERT INTO "django_geo_db_zipcode" VALUES(1031,2842,-5,'Middletown, Rhode Island 2842',652,1133);
INSERT INTO "django_geo_db_zipcode" VALUES(1032,2852,-5,'North Kingstown, Rhode Island 2852',653,1134);
INSERT INTO "django_geo_db_zipcode" VALUES(1033,2854,-5,'North Kingstown, Rhode Island 2854',653,1135);
INSERT INTO "django_geo_db_zipcode" VALUES(1034,2857,-5,'North Scituate, Rhode Island 2857',654,1136);
INSERT INTO "django_geo_db_zipcode" VALUES(1035,2858,-5,'Oakland, Rhode Island 2858',655,1137);
INSERT INTO "django_geo_db_zipcode" VALUES(1036,2859,-5,'Pascoag, Rhode Island 2859',656,1138);
INSERT INTO "django_geo_db_zipcode" VALUES(1037,2860,-5,'Pawtucket, Rhode Island 2860',657,1139);
INSERT INTO "django_geo_db_zipcode" VALUES(1038,2861,-5,'Pawtucket, Rhode Island 2861',657,1140);
INSERT INTO "django_geo_db_zipcode" VALUES(1039,2862,-5,'Pawtucket, Rhode Island 2862',657,1141);
INSERT INTO "django_geo_db_zipcode" VALUES(1040,2863,-5,'Central Falls, Rhode Island 2863',658,1142);
INSERT INTO "django_geo_db_zipcode" VALUES(1041,2864,-5,'Cumberland, Rhode Island 2864',659,1143);
INSERT INTO "django_geo_db_zipcode" VALUES(1042,2865,-5,'Lincoln, Rhode Island 2865',660,1144);
INSERT INTO "django_geo_db_zipcode" VALUES(1043,2871,-5,'Portsmouth, Rhode Island 2871',661,1145);
INSERT INTO "django_geo_db_zipcode" VALUES(1044,2872,-5,'Prudence Island, Rhode Island 2872',662,1146);
INSERT INTO "django_geo_db_zipcode" VALUES(1045,2873,-5,'Rockville, Rhode Island 2873',663,1147);
INSERT INTO "django_geo_db_zipcode" VALUES(1046,2874,-5,'Saunderstown, Rhode Island 2874',664,1148);
INSERT INTO "django_geo_db_zipcode" VALUES(1047,2875,-5,'Shannock, Rhode Island 2875',665,1149);
INSERT INTO "django_geo_db_zipcode" VALUES(1048,2876,-5,'Slatersville, Rhode Island 2876',666,1150);
INSERT INTO "django_geo_db_zipcode" VALUES(1049,2877,-5,'Slocum, Rhode Island 2877',667,1151);
INSERT INTO "django_geo_db_zipcode" VALUES(1050,2878,-5,'Tiverton, Rhode Island 2878',668,1152);
INSERT INTO "django_geo_db_zipcode" VALUES(1051,2879,-5,'Wakefield, Rhode Island 2879',669,1153);
INSERT INTO "django_geo_db_zipcode" VALUES(1052,2880,-5,'Wakefield, Rhode Island 2880',669,1135);
INSERT INTO "django_geo_db_zipcode" VALUES(1053,2881,-5,'Kingston, Rhode Island 2881',670,1154);
INSERT INTO "django_geo_db_zipcode" VALUES(1054,2882,-5,'Narragansett, Rhode Island 2882',671,1155);
INSERT INTO "django_geo_db_zipcode" VALUES(1055,2883,-5,'Peace Dale, Rhode Island 2883',672,1135);
INSERT INTO "django_geo_db_zipcode" VALUES(1056,2885,-5,'Warren, Rhode Island 2885',673,1156);
INSERT INTO "django_geo_db_zipcode" VALUES(1057,2886,-5,'Warwick, Rhode Island 2886',674,1157);
INSERT INTO "django_geo_db_zipcode" VALUES(1058,2887,-5,'Warwick, Rhode Island 2887',674,1158);
INSERT INTO "django_geo_db_zipcode" VALUES(1059,2888,-5,'Warwick, Rhode Island 2888',674,1159);
INSERT INTO "django_geo_db_zipcode" VALUES(1060,2889,-5,'Warwick, Rhode Island 2889',674,1160);
INSERT INTO "django_geo_db_zipcode" VALUES(1061,2891,-5,'Westerly, Rhode Island 2891',675,1161);
INSERT INTO "django_geo_db_zipcode" VALUES(1062,2892,-5,'West Kingston, Rhode Island 2892',676,1162);
INSERT INTO "django_geo_db_zipcode" VALUES(1063,2893,-5,'West Warwick, Rhode Island 2893',677,1163);
INSERT INTO "django_geo_db_zipcode" VALUES(1064,2894,-5,'Wood River Junction, Rhode Island 2894',678,1164);
INSERT INTO "django_geo_db_zipcode" VALUES(1065,2895,-5,'Woonsocket, Rhode Island 2895',679,1165);
INSERT INTO "django_geo_db_zipcode" VALUES(1066,2896,-5,'North Smithfield, Rhode Island 2896',680,1166);
INSERT INTO "django_geo_db_zipcode" VALUES(1067,2898,-5,'Wyoming, Rhode Island 2898',681,1167);
INSERT INTO "django_geo_db_zipcode" VALUES(1068,2901,-5,'Providence, Rhode Island 2901',404,1168);
INSERT INTO "django_geo_db_zipcode" VALUES(1069,2902,-5,'Providence, Rhode Island 2902',404,1169);
INSERT INTO "django_geo_db_zipcode" VALUES(1070,2903,-5,'Providence, Rhode Island 2903',404,1170);
INSERT INTO "django_geo_db_zipcode" VALUES(1071,2904,-5,'Providence, Rhode Island 2904',404,1171);
INSERT INTO "django_geo_db_zipcode" VALUES(1072,2905,-5,'Providence, Rhode Island 2905',404,1172);
INSERT INTO "django_geo_db_zipcode" VALUES(1073,2906,-5,'Providence, Rhode Island 2906',404,1173);
INSERT INTO "django_geo_db_zipcode" VALUES(1074,2907,-5,'Providence, Rhode Island 2907',404,1174);
INSERT INTO "django_geo_db_zipcode" VALUES(1075,2908,-5,'Providence, Rhode Island 2908',404,1175);
INSERT INTO "django_geo_db_zipcode" VALUES(1076,2909,-5,'Providence, Rhode Island 2909',404,1176);
INSERT INTO "django_geo_db_zipcode" VALUES(1077,2910,-5,'Cranston, Rhode Island 2910',682,1177);
INSERT INTO "django_geo_db_zipcode" VALUES(1078,2911,-5,'North Providence, Rhode Island 2911',683,1178);
INSERT INTO "django_geo_db_zipcode" VALUES(1079,2912,-5,'Providence, Rhode Island 2912',404,1179);
INSERT INTO "django_geo_db_zipcode" VALUES(1080,2914,-5,'East Providence, Rhode Island 2914',684,1180);
INSERT INTO "django_geo_db_zipcode" VALUES(1081,2915,-5,'Riverside, Rhode Island 2915',685,1181);
INSERT INTO "django_geo_db_zipcode" VALUES(1082,2916,-5,'Rumford, Rhode Island 2916',686,1182);
INSERT INTO "django_geo_db_zipcode" VALUES(1083,2917,-5,'Smithfield, Rhode Island 2917',687,1183);
INSERT INTO "django_geo_db_zipcode" VALUES(1084,2918,-5,'Providence, Rhode Island 2918',404,1184);
INSERT INTO "django_geo_db_zipcode" VALUES(1085,2919,-5,'Johnston, Rhode Island 2919',688,1185);
INSERT INTO "django_geo_db_zipcode" VALUES(1086,2920,-5,'Cranston, Rhode Island 2920',682,1186);
INSERT INTO "django_geo_db_zipcode" VALUES(1087,2921,-5,'Cranston, Rhode Island 2921',682,1187);
INSERT INTO "django_geo_db_zipcode" VALUES(1088,2940,-5,'Providence, Rhode Island 2940',404,1188);
INSERT INTO "django_geo_db_zipcode" VALUES(1089,3004,-5,'Fremont, New Hampshire 3004',689,1189);
INSERT INTO "django_geo_db_zipcode" VALUES(1090,3030,-5,'Nashua, New Hampshire 3030',690,1190);
INSERT INTO "django_geo_db_zipcode" VALUES(1091,3031,-5,'Amherst, New Hampshire 3031',691,1191);
INSERT INTO "django_geo_db_zipcode" VALUES(1092,3032,-5,'Auburn, New Hampshire 3032',692,1192);
INSERT INTO "django_geo_db_zipcode" VALUES(1093,3033,-5,'Brookline, New Hampshire 3033',693,1193);
INSERT INTO "django_geo_db_zipcode" VALUES(1094,3034,-5,'Candia, New Hampshire 3034',694,1194);
INSERT INTO "django_geo_db_zipcode" VALUES(1095,3036,-5,'Chester, New Hampshire 3036',695,1195);
INSERT INTO "django_geo_db_zipcode" VALUES(1096,3037,-5,'Deerfield, New Hampshire 3037',696,1196);
INSERT INTO "django_geo_db_zipcode" VALUES(1097,3038,-5,'Derry, New Hampshire 3038',697,1197);
INSERT INTO "django_geo_db_zipcode" VALUES(1098,3040,-5,'East Candia, New Hampshire 3040',698,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1099,3041,-5,'East Derry, New Hampshire 3041',699,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1100,3042,-5,'Epping, New Hampshire 3042',700,1198);
INSERT INTO "django_geo_db_zipcode" VALUES(1101,3043,-5,'Francestown, New Hampshire 3043',701,1199);
INSERT INTO "django_geo_db_zipcode" VALUES(1102,3044,-5,'Fremont, New Hampshire 3044',689,1200);
INSERT INTO "django_geo_db_zipcode" VALUES(1103,3045,-5,'Goffstown, New Hampshire 3045',702,1201);
INSERT INTO "django_geo_db_zipcode" VALUES(1104,3046,-5,'Dunbarton, New Hampshire 3046',703,1202);
INSERT INTO "django_geo_db_zipcode" VALUES(1105,3047,-5,'Greenfield, New Hampshire 3047',704,1203);
INSERT INTO "django_geo_db_zipcode" VALUES(1106,3048,-5,'Greenville, New Hampshire 3048',705,1204);
INSERT INTO "django_geo_db_zipcode" VALUES(1107,3049,-5,'Hollis, New Hampshire 3049',706,1205);
INSERT INTO "django_geo_db_zipcode" VALUES(1108,3051,-5,'Hudson, New Hampshire 3051',707,1206);
INSERT INTO "django_geo_db_zipcode" VALUES(1109,3052,-5,'Litchfield, New Hampshire 3052',708,1207);
INSERT INTO "django_geo_db_zipcode" VALUES(1110,3053,-5,'Londonderry, New Hampshire 3053',709,1208);
INSERT INTO "django_geo_db_zipcode" VALUES(1111,3054,-5,'Merrimack, New Hampshire 3054',710,1209);
INSERT INTO "django_geo_db_zipcode" VALUES(1112,3055,-5,'Milford, New Hampshire 3055',711,1210);
INSERT INTO "django_geo_db_zipcode" VALUES(1113,3057,-5,'Mont Vernon, New Hampshire 3057',712,1211);
INSERT INTO "django_geo_db_zipcode" VALUES(1114,3058,-5,'Sharon, New Hampshire 3058',713,1212);
INSERT INTO "django_geo_db_zipcode" VALUES(1115,3060,-5,'Nashua, New Hampshire 3060',690,1213);
INSERT INTO "django_geo_db_zipcode" VALUES(1116,3061,-5,'Nashua, New Hampshire 3061',690,1214);
INSERT INTO "django_geo_db_zipcode" VALUES(1117,3062,-5,'Nashua, New Hampshire 3062',690,1215);
INSERT INTO "django_geo_db_zipcode" VALUES(1118,3063,-5,'Nashua, New Hampshire 3063',690,1216);
INSERT INTO "django_geo_db_zipcode" VALUES(1119,3064,-5,'Nashua, New Hampshire 3064',690,1217);
INSERT INTO "django_geo_db_zipcode" VALUES(1120,3070,-5,'New Boston, New Hampshire 3070',714,1218);
INSERT INTO "django_geo_db_zipcode" VALUES(1121,3071,-5,'New Ipswich, New Hampshire 3071',715,1219);
INSERT INTO "django_geo_db_zipcode" VALUES(1122,3073,-5,'North Salem, New Hampshire 3073',716,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1123,3076,-5,'Pelham, New Hampshire 3076',717,1220);
INSERT INTO "django_geo_db_zipcode" VALUES(1124,3077,-5,'Raymond, New Hampshire 3077',718,1221);
INSERT INTO "django_geo_db_zipcode" VALUES(1125,3079,-5,'Salem, New Hampshire 3079',719,1222);
INSERT INTO "django_geo_db_zipcode" VALUES(1126,3082,-5,'Lyndeborough, New Hampshire 3082',720,1223);
INSERT INTO "django_geo_db_zipcode" VALUES(1127,3084,-5,'Temple, New Hampshire 3084',721,1224);
INSERT INTO "django_geo_db_zipcode" VALUES(1128,3086,-5,'Wilton, New Hampshire 3086',722,1225);
INSERT INTO "django_geo_db_zipcode" VALUES(1129,3087,-5,'Windham, New Hampshire 3087',723,1226);
INSERT INTO "django_geo_db_zipcode" VALUES(1130,3091,-5,'Berwick, Maine 3091',724,1227);
INSERT INTO "django_geo_db_zipcode" VALUES(1131,3097,-5,'Ogunquit, Maine 3097',725,1228);
INSERT INTO "django_geo_db_zipcode" VALUES(1132,3101,-5,'Manchester, New Hampshire 3101',726,1229);
INSERT INTO "django_geo_db_zipcode" VALUES(1133,3102,-5,'Manchester, New Hampshire 3102',726,1230);
INSERT INTO "django_geo_db_zipcode" VALUES(1134,3103,-5,'Manchester, New Hampshire 3103',726,1231);
INSERT INTO "django_geo_db_zipcode" VALUES(1135,3104,-5,'Manchester, New Hampshire 3104',726,1232);
INSERT INTO "django_geo_db_zipcode" VALUES(1136,3105,-5,'Manchester, New Hampshire 3105',726,1214);
INSERT INTO "django_geo_db_zipcode" VALUES(1137,3106,-5,'Hooksett, New Hampshire 3106',727,1233);
INSERT INTO "django_geo_db_zipcode" VALUES(1138,3107,-5,'Manchester, New Hampshire 3107',726,1214);
INSERT INTO "django_geo_db_zipcode" VALUES(1139,3108,-5,'Manchester, New Hampshire 3108',726,1214);
INSERT INTO "django_geo_db_zipcode" VALUES(1140,3109,-5,'Manchester, New Hampshire 3109',726,1234);
INSERT INTO "django_geo_db_zipcode" VALUES(1141,3110,-5,'Bedford, New Hampshire 3110',728,1235);
INSERT INTO "django_geo_db_zipcode" VALUES(1142,3111,-5,'Manchester, New Hampshire 3111',726,1214);
INSERT INTO "django_geo_db_zipcode" VALUES(1143,3215,-5,'Waterville Valley, New Hampshire 3215',729,1236);
INSERT INTO "django_geo_db_zipcode" VALUES(1144,3216,-5,'Andover, New Hampshire 3216',730,1237);
INSERT INTO "django_geo_db_zipcode" VALUES(1145,3217,-5,'Ashland, New Hampshire 3217',731,1238);
INSERT INTO "django_geo_db_zipcode" VALUES(1146,3218,-5,'Barnstead, New Hampshire 3218',732,1239);
INSERT INTO "django_geo_db_zipcode" VALUES(1147,3220,-5,'Belmont, New Hampshire 3220',733,1240);
INSERT INTO "django_geo_db_zipcode" VALUES(1148,3221,-5,'Bradford, New Hampshire 3221',734,1241);
INSERT INTO "django_geo_db_zipcode" VALUES(1149,3222,-5,'Bristol, New Hampshire 3222',735,1242);
INSERT INTO "django_geo_db_zipcode" VALUES(1150,3223,-5,'Campton, New Hampshire 3223',736,1243);
INSERT INTO "django_geo_db_zipcode" VALUES(1151,3224,-5,'Canterbury, New Hampshire 3224',737,1244);
INSERT INTO "django_geo_db_zipcode" VALUES(1152,3225,-5,'Center Barnstead, New Hampshire 3225',738,1245);
INSERT INTO "django_geo_db_zipcode" VALUES(1153,3226,-5,'Center Harbor, New Hampshire 3226',739,1246);
INSERT INTO "django_geo_db_zipcode" VALUES(1154,3227,-5,'Center Sandwich, New Hampshire 3227',740,1247);
INSERT INTO "django_geo_db_zipcode" VALUES(1155,3229,-5,'Contoocook, New Hampshire 3229',741,1248);
INSERT INTO "django_geo_db_zipcode" VALUES(1156,3230,-5,'Danbury, New Hampshire 3230',742,1249);
INSERT INTO "django_geo_db_zipcode" VALUES(1157,3231,-5,'East Andover, New Hampshire 3231',743,1250);
INSERT INTO "django_geo_db_zipcode" VALUES(1158,3232,-5,'East Hebron, New Hampshire 3232',744,1251);
INSERT INTO "django_geo_db_zipcode" VALUES(1159,3233,-5,'Elkins, New Hampshire 3233',745,1252);
INSERT INTO "django_geo_db_zipcode" VALUES(1160,3234,-5,'Epsom, New Hampshire 3234',746,1253);
INSERT INTO "django_geo_db_zipcode" VALUES(1161,3235,-5,'Franklin, New Hampshire 3235',747,1254);
INSERT INTO "django_geo_db_zipcode" VALUES(1162,3237,-5,'Gilmanton, New Hampshire 3237',748,1255);
INSERT INTO "django_geo_db_zipcode" VALUES(1163,3238,-5,'Glencliff, New Hampshire 3238',749,1251);
INSERT INTO "django_geo_db_zipcode" VALUES(1164,3240,-5,'Grafton, New Hampshire 3240',750,1256);
INSERT INTO "django_geo_db_zipcode" VALUES(1165,3241,-5,'Hebron, New Hampshire 3241',751,1257);
INSERT INTO "django_geo_db_zipcode" VALUES(1166,3242,-5,'Henniker, New Hampshire 3242',752,1258);
INSERT INTO "django_geo_db_zipcode" VALUES(1167,3243,-5,'Hill, New Hampshire 3243',753,1259);
INSERT INTO "django_geo_db_zipcode" VALUES(1168,3244,-5,'Hillsboro, New Hampshire 3244',754,1260);
INSERT INTO "django_geo_db_zipcode" VALUES(1169,3245,-5,'Holderness, New Hampshire 3245',755,1261);
INSERT INTO "django_geo_db_zipcode" VALUES(1170,3246,-5,'Laconia, New Hampshire 3246',756,1262);
INSERT INTO "django_geo_db_zipcode" VALUES(1171,3247,-5,'Laconia, New Hampshire 3247',756,1263);
INSERT INTO "django_geo_db_zipcode" VALUES(1172,3249,-5,'Laconia, New Hampshire 3249',756,1264);
INSERT INTO "django_geo_db_zipcode" VALUES(1173,3251,-5,'Lincoln, New Hampshire 3251',757,1265);
INSERT INTO "django_geo_db_zipcode" VALUES(1174,3252,-5,'Lochmere, New Hampshire 3252',758,1266);
INSERT INTO "django_geo_db_zipcode" VALUES(1175,3253,-5,'Meredith, New Hampshire 3253',759,1267);
INSERT INTO "django_geo_db_zipcode" VALUES(1176,3254,-5,'Moultonborough, New Hampshire 3254',760,1268);
INSERT INTO "django_geo_db_zipcode" VALUES(1177,3255,-5,'Newbury, New Hampshire 3255',761,1269);
INSERT INTO "django_geo_db_zipcode" VALUES(1178,3256,-5,'New Hampton, New Hampshire 3256',762,1270);
INSERT INTO "django_geo_db_zipcode" VALUES(1179,3257,-5,'New London, New Hampshire 3257',763,1271);
INSERT INTO "django_geo_db_zipcode" VALUES(1180,3258,-5,'Chichester, New Hampshire 3258',764,1272);
INSERT INTO "django_geo_db_zipcode" VALUES(1181,3259,-5,'North Sandwich, New Hampshire 3259',765,1273);
INSERT INTO "django_geo_db_zipcode" VALUES(1182,3260,-5,'North Sutton, New Hampshire 3260',766,1274);
INSERT INTO "django_geo_db_zipcode" VALUES(1183,3261,-5,'Northwood, New Hampshire 3261',767,1275);
INSERT INTO "django_geo_db_zipcode" VALUES(1184,3262,-5,'North Woodstock, New Hampshire 3262',768,1276);
INSERT INTO "django_geo_db_zipcode" VALUES(1185,3263,-5,'Pittsfield, New Hampshire 3263',769,1277);
INSERT INTO "django_geo_db_zipcode" VALUES(1186,3264,-5,'Plymouth, New Hampshire 3264',770,1278);
INSERT INTO "django_geo_db_zipcode" VALUES(1187,3266,-5,'Rumney, New Hampshire 3266',771,1279);
INSERT INTO "django_geo_db_zipcode" VALUES(1188,3268,-5,'Salisbury, New Hampshire 3268',772,1280);
INSERT INTO "django_geo_db_zipcode" VALUES(1189,3269,-5,'Sanbornton, New Hampshire 3269',773,1281);
INSERT INTO "django_geo_db_zipcode" VALUES(1190,3270,-5,'New Boston, New Hampshire 3270',714,1282);
INSERT INTO "django_geo_db_zipcode" VALUES(1191,3272,-5,'South Newbury, New Hampshire 3272',774,1283);
INSERT INTO "django_geo_db_zipcode" VALUES(1192,3273,-5,'South Sutton, New Hampshire 3273',775,1284);
INSERT INTO "django_geo_db_zipcode" VALUES(1193,3274,-5,'Stinson Lake, New Hampshire 3274',776,1251);
INSERT INTO "django_geo_db_zipcode" VALUES(1194,3275,-5,'Suncook, New Hampshire 3275',777,1285);
INSERT INTO "django_geo_db_zipcode" VALUES(1195,3276,-5,'Tilton, New Hampshire 3276',778,1286);
INSERT INTO "django_geo_db_zipcode" VALUES(1196,3278,-5,'Warner, New Hampshire 3278',779,1287);
INSERT INTO "django_geo_db_zipcode" VALUES(1197,3279,-5,'Warren, New Hampshire 3279',780,1288);
INSERT INTO "django_geo_db_zipcode" VALUES(1198,3280,-5,'Washington, New Hampshire 3280',781,1289);
INSERT INTO "django_geo_db_zipcode" VALUES(1199,3281,-5,'Weare, New Hampshire 3281',782,1290);
INSERT INTO "django_geo_db_zipcode" VALUES(1200,3282,-5,'Wentworth, New Hampshire 3282',783,1291);
INSERT INTO "django_geo_db_zipcode" VALUES(1201,3284,-5,'Springfield, New Hampshire 3284',784,1292);
INSERT INTO "django_geo_db_zipcode" VALUES(1202,3287,-5,'Wilmot, New Hampshire 3287',785,1293);
INSERT INTO "django_geo_db_zipcode" VALUES(1203,3289,-5,'Winnisquam, New Hampshire 3289',786,1294);
INSERT INTO "django_geo_db_zipcode" VALUES(1204,3290,-5,'Nottingham, New Hampshire 3290',787,1295);
INSERT INTO "django_geo_db_zipcode" VALUES(1205,3291,-5,'West Nottingham, New Hampshire 3291',788,1296);
INSERT INTO "django_geo_db_zipcode" VALUES(1206,3293,-5,'Woodstock, New Hampshire 3293',789,1251);
INSERT INTO "django_geo_db_zipcode" VALUES(1207,3298,-5,'Tilton, New Hampshire 3298',778,1297);
INSERT INTO "django_geo_db_zipcode" VALUES(1208,3299,-5,'Tilton, New Hampshire 3299',778,1297);
INSERT INTO "django_geo_db_zipcode" VALUES(1209,3301,-5,'Concord, New Hampshire 3301',790,1298);
INSERT INTO "django_geo_db_zipcode" VALUES(1210,3302,-5,'Concord, New Hampshire 3302',790,1283);
INSERT INTO "django_geo_db_zipcode" VALUES(1211,3303,-5,'Concord, New Hampshire 3303',790,1299);
INSERT INTO "django_geo_db_zipcode" VALUES(1212,3304,-5,'Bow, New Hampshire 3304',791,1300);
INSERT INTO "django_geo_db_zipcode" VALUES(1213,3305,-5,'Concord, New Hampshire 3305',790,1301);
INSERT INTO "django_geo_db_zipcode" VALUES(1214,3307,-5,'Loudon, New Hampshire 3307',792,1302);
INSERT INTO "django_geo_db_zipcode" VALUES(1215,3342,-5,'Bennington, New Hampshire 3342',793,1303);
INSERT INTO "django_geo_db_zipcode" VALUES(1216,3386,-5,'Tamworth, New Hampshire 3386',794,1304);
INSERT INTO "django_geo_db_zipcode" VALUES(1217,3431,-5,'Keene, New Hampshire 3431',795,1305);
INSERT INTO "django_geo_db_zipcode" VALUES(1218,3435,-5,'Keene, New Hampshire 3435',795,1306);
INSERT INTO "django_geo_db_zipcode" VALUES(1219,3438,-5,'Harrisville, New Hampshire 3438',796,1307);
INSERT INTO "django_geo_db_zipcode" VALUES(1220,3440,-5,'Antrim, New Hampshire 3440',797,1308);
INSERT INTO "django_geo_db_zipcode" VALUES(1221,3441,-5,'Ashuelot, New Hampshire 3441',798,1309);
INSERT INTO "django_geo_db_zipcode" VALUES(1222,3442,-5,'Bennington, New Hampshire 3442',793,1310);
INSERT INTO "django_geo_db_zipcode" VALUES(1223,3443,-5,'Chesterfield, New Hampshire 3443',799,1311);
INSERT INTO "django_geo_db_zipcode" VALUES(1224,3444,-5,'Dublin, New Hampshire 3444',800,1312);
INSERT INTO "django_geo_db_zipcode" VALUES(1225,3445,-5,'Sullivan, New Hampshire 3445',801,1313);
INSERT INTO "django_geo_db_zipcode" VALUES(1226,3446,-5,'Swanzey, New Hampshire 3446',802,1314);
INSERT INTO "django_geo_db_zipcode" VALUES(1227,3447,-5,'Fitzwilliam, New Hampshire 3447',803,1315);
INSERT INTO "django_geo_db_zipcode" VALUES(1228,3448,-5,'Gilsum, New Hampshire 3448',804,1316);
INSERT INTO "django_geo_db_zipcode" VALUES(1229,3449,-5,'Hancock, New Hampshire 3449',805,1317);
INSERT INTO "django_geo_db_zipcode" VALUES(1230,3450,-5,'Harrisville, New Hampshire 3450',796,1318);
INSERT INTO "django_geo_db_zipcode" VALUES(1231,3451,-5,'Hinsdale, New Hampshire 3451',806,1319);
INSERT INTO "django_geo_db_zipcode" VALUES(1232,3452,-5,'Jaffrey, New Hampshire 3452',807,1320);
INSERT INTO "django_geo_db_zipcode" VALUES(1233,3455,-5,'Marlborough, New Hampshire 3455',808,1321);
INSERT INTO "django_geo_db_zipcode" VALUES(1234,3456,-5,'Marlow, New Hampshire 3456',809,1322);
INSERT INTO "django_geo_db_zipcode" VALUES(1235,3457,-5,'Munsonville, New Hampshire 3457',810,1323);
INSERT INTO "django_geo_db_zipcode" VALUES(1236,3458,-5,'Peterborough, New Hampshire 3458',811,1324);
INSERT INTO "django_geo_db_zipcode" VALUES(1237,3461,-5,'Rindge, New Hampshire 3461',812,1325);
INSERT INTO "django_geo_db_zipcode" VALUES(1238,3462,-5,'Spofford, New Hampshire 3462',813,1326);
INSERT INTO "django_geo_db_zipcode" VALUES(1239,3464,-5,'Stoddard, New Hampshire 3464',814,1327);
INSERT INTO "django_geo_db_zipcode" VALUES(1240,3465,-5,'Troy, New Hampshire 3465',815,1328);
INSERT INTO "django_geo_db_zipcode" VALUES(1241,3466,-5,'West Chesterfield, New Hampshire 3466',816,1329);
INSERT INTO "django_geo_db_zipcode" VALUES(1242,3467,-5,'Westmoreland, New Hampshire 3467',817,1330);
INSERT INTO "django_geo_db_zipcode" VALUES(1243,3468,-5,'West Peterborough, New Hampshire 3468',818,1331);
INSERT INTO "django_geo_db_zipcode" VALUES(1244,3469,-5,'West Swanzey, New Hampshire 3469',819,1332);
INSERT INTO "django_geo_db_zipcode" VALUES(1245,3470,-5,'Winchester, New Hampshire 3470',820,1333);
INSERT INTO "django_geo_db_zipcode" VALUES(1246,3477,-5,'Fitzwilliam, New Hampshire 3477',803,1334);
INSERT INTO "django_geo_db_zipcode" VALUES(1247,3552,-5,'Pittsburg, New Hampshire 3552',821,1335);
INSERT INTO "django_geo_db_zipcode" VALUES(1248,3561,-5,'Littleton, New Hampshire 3561',822,1336);
INSERT INTO "django_geo_db_zipcode" VALUES(1249,3570,-5,'Berlin, New Hampshire 3570',823,1337);
INSERT INTO "django_geo_db_zipcode" VALUES(1250,3572,-5,'Goshen, New Hampshire 3572',824,1338);
INSERT INTO "django_geo_db_zipcode" VALUES(1251,3574,-5,'Bethlehem, New Hampshire 3574',825,1339);
INSERT INTO "django_geo_db_zipcode" VALUES(1252,3575,-5,'Bretton Woods, New Hampshire 3575',826,1340);
INSERT INTO "django_geo_db_zipcode" VALUES(1253,3576,-5,'Colebrook, New Hampshire 3576',827,1341);
INSERT INTO "django_geo_db_zipcode" VALUES(1254,3578,-5,'Landaff, New Hampshire 3578',828,1342);
INSERT INTO "django_geo_db_zipcode" VALUES(1255,3579,-5,'Errol, New Hampshire 3579',829,1343);
INSERT INTO "django_geo_db_zipcode" VALUES(1256,3580,-5,'Franconia, New Hampshire 3580',830,1344);
INSERT INTO "django_geo_db_zipcode" VALUES(1257,3581,-5,'Gorham, New Hampshire 3581',831,1345);
INSERT INTO "django_geo_db_zipcode" VALUES(1258,3582,-5,'Groveton, New Hampshire 3582',832,1346);
INSERT INTO "django_geo_db_zipcode" VALUES(1259,3583,-5,'Jefferson, New Hampshire 3583',833,1347);
INSERT INTO "django_geo_db_zipcode" VALUES(1260,3584,-5,'Lancaster, New Hampshire 3584',834,1348);
INSERT INTO "django_geo_db_zipcode" VALUES(1261,3585,-5,'Lisbon, New Hampshire 3585',835,1349);
INSERT INTO "django_geo_db_zipcode" VALUES(1262,3587,-5,'Meadows, New Hampshire 3587',836,1340);
INSERT INTO "django_geo_db_zipcode" VALUES(1263,3588,-5,'Milan, New Hampshire 3588',837,1350);
INSERT INTO "django_geo_db_zipcode" VALUES(1264,3589,-5,'Mount Washington, New Hampshire 3589',838,1340);
INSERT INTO "django_geo_db_zipcode" VALUES(1265,3590,-5,'North Stratford, New Hampshire 3590',839,1351);
INSERT INTO "django_geo_db_zipcode" VALUES(1266,3592,-5,'Pittsburg, New Hampshire 3592',821,1352);
INSERT INTO "django_geo_db_zipcode" VALUES(1267,3595,-5,'Twin Mountain, New Hampshire 3595',840,1353);
INSERT INTO "django_geo_db_zipcode" VALUES(1268,3597,-5,'West Stewartstown, New Hampshire 3597',841,1340);
INSERT INTO "django_geo_db_zipcode" VALUES(1269,3598,-5,'Whitefield, New Hampshire 3598',842,1354);
INSERT INTO "django_geo_db_zipcode" VALUES(1270,3601,-5,'Acworth, New Hampshire 3601',843,1355);
INSERT INTO "django_geo_db_zipcode" VALUES(1271,3602,-5,'Alstead, New Hampshire 3602',844,1356);
INSERT INTO "django_geo_db_zipcode" VALUES(1272,3603,-5,'Charlestown, New Hampshire 3603',845,1357);
INSERT INTO "django_geo_db_zipcode" VALUES(1273,3604,-5,'Drewsville, New Hampshire 3604',846,1306);
INSERT INTO "django_geo_db_zipcode" VALUES(1274,3605,-5,'Lempster, New Hampshire 3605',847,1358);
INSERT INTO "django_geo_db_zipcode" VALUES(1275,3607,-5,'South Acworth, New Hampshire 3607',848,1359);
INSERT INTO "django_geo_db_zipcode" VALUES(1276,3608,-5,'Walpole, New Hampshire 3608',849,1360);
INSERT INTO "django_geo_db_zipcode" VALUES(1277,3609,-5,'North Walpole, New Hampshire 3609',850,1361);
INSERT INTO "django_geo_db_zipcode" VALUES(1278,3638,-5,'Freedom, New Hampshire 3638',851,1362);
INSERT INTO "django_geo_db_zipcode" VALUES(1279,3648,-5,'Enfield, New Hampshire 3648',852,1363);
INSERT INTO "django_geo_db_zipcode" VALUES(1280,3678,-5,'Lyme, New Hampshire 3678',853,1364);
INSERT INTO "django_geo_db_zipcode" VALUES(1281,3688,-5,'Lebanon, Maine 3688',854,1365);
INSERT INTO "django_geo_db_zipcode" VALUES(1282,3733,-5,'Newport, New Hampshire 3733',855,1366);
INSERT INTO "django_geo_db_zipcode" VALUES(1283,3740,-5,'Bath, New Hampshire 3740',856,1367);
INSERT INTO "django_geo_db_zipcode" VALUES(1284,3741,-5,'Canaan, New Hampshire 3741',857,1368);
INSERT INTO "django_geo_db_zipcode" VALUES(1285,3743,-5,'Claremont, New Hampshire 3743',858,1369);
INSERT INTO "django_geo_db_zipcode" VALUES(1286,3745,-5,'Cornish, New Hampshire 3745',859,1370);
INSERT INTO "django_geo_db_zipcode" VALUES(1287,3746,-5,'Cornish Flat, New Hampshire 3746',860,1371);
INSERT INTO "django_geo_db_zipcode" VALUES(1288,3747,-5,'Enfield, New Hampshire 3747',852,1372);
INSERT INTO "django_geo_db_zipcode" VALUES(1289,3748,-5,'Enfield, New Hampshire 3748',852,1373);
INSERT INTO "django_geo_db_zipcode" VALUES(1290,3749,-5,'Enfield Center, New Hampshire 3749',861,1374);
INSERT INTO "django_geo_db_zipcode" VALUES(1291,3750,-5,'Etna, New Hampshire 3750',862,1375);
INSERT INTO "django_geo_db_zipcode" VALUES(1292,3751,-5,'Georges Mills, New Hampshire 3751',863,1376);
INSERT INTO "django_geo_db_zipcode" VALUES(1293,3752,-5,'Goshen, New Hampshire 3752',824,1377);
INSERT INTO "django_geo_db_zipcode" VALUES(1294,3753,-5,'Grantham, New Hampshire 3753',864,1378);
INSERT INTO "django_geo_db_zipcode" VALUES(1295,3754,-5,'Guild, New Hampshire 3754',865,1379);
INSERT INTO "django_geo_db_zipcode" VALUES(1296,3755,-5,'Hanover, New Hampshire 3755',866,1380);
INSERT INTO "django_geo_db_zipcode" VALUES(1297,3756,-5,'Lebanon, New Hampshire 3756',867,1251);
INSERT INTO "django_geo_db_zipcode" VALUES(1298,3757,-5,'Sunapee, New Hampshire 3757',868,1381);
INSERT INTO "django_geo_db_zipcode" VALUES(1299,3765,-5,'Haverhill, New Hampshire 3765',869,1382);
INSERT INTO "django_geo_db_zipcode" VALUES(1300,3766,-5,'Lebanon, New Hampshire 3766',867,1383);
INSERT INTO "django_geo_db_zipcode" VALUES(1301,3768,-5,'Lyme, New Hampshire 3768',853,1384);
INSERT INTO "django_geo_db_zipcode" VALUES(1302,3769,-5,'Lyme Center, New Hampshire 3769',870,1385);
INSERT INTO "django_geo_db_zipcode" VALUES(1303,3770,-5,'Meriden, New Hampshire 3770',871,1386);
INSERT INTO "django_geo_db_zipcode" VALUES(1304,3771,-5,'Monroe, New Hampshire 3771',872,1387);
INSERT INTO "django_geo_db_zipcode" VALUES(1305,3773,-5,'Newport, New Hampshire 3773',855,1388);
INSERT INTO "django_geo_db_zipcode" VALUES(1306,3774,-5,'North Haverhill, New Hampshire 3774',873,1389);
INSERT INTO "django_geo_db_zipcode" VALUES(1307,3777,-5,'Orford, New Hampshire 3777',874,1390);
INSERT INTO "django_geo_db_zipcode" VALUES(1308,3779,-5,'Piermont, New Hampshire 3779',875,1391);
INSERT INTO "django_geo_db_zipcode" VALUES(1309,3780,-5,'Pike, New Hampshire 3780',876,1392);
INSERT INTO "django_geo_db_zipcode" VALUES(1310,3781,-5,'Plainfield, New Hampshire 3781',877,1393);
INSERT INTO "django_geo_db_zipcode" VALUES(1311,3782,-5,'Sunapee, New Hampshire 3782',868,1394);
INSERT INTO "django_geo_db_zipcode" VALUES(1312,3784,-5,'West Lebanon, New Hampshire 3784',878,1395);
INSERT INTO "django_geo_db_zipcode" VALUES(1313,3785,-5,'Woodsville, New Hampshire 3785',879,1396);
INSERT INTO "django_geo_db_zipcode" VALUES(1314,3801,-5,'Portsmouth, New Hampshire 3801',1,1397);
INSERT INTO "django_geo_db_zipcode" VALUES(1315,3802,-5,'Portsmouth, New Hampshire 3802',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1316,3803,-5,'Portsmouth, New Hampshire 3803',1,1398);
INSERT INTO "django_geo_db_zipcode" VALUES(1317,3804,-5,'Portsmouth, New Hampshire 3804',1,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1318,3805,-5,'Rollinsford, New Hampshire 3805',880,1399);
INSERT INTO "django_geo_db_zipcode" VALUES(1319,3809,-5,'Alton, New Hampshire 3809',881,1400);
INSERT INTO "django_geo_db_zipcode" VALUES(1320,3810,-5,'Alton Bay, New Hampshire 3810',882,1401);
INSERT INTO "django_geo_db_zipcode" VALUES(1321,3811,-5,'Atkinson, New Hampshire 3811',883,1402);
INSERT INTO "django_geo_db_zipcode" VALUES(1322,3812,-5,'Bartlett, New Hampshire 3812',884,1403);
INSERT INTO "django_geo_db_zipcode" VALUES(1323,3813,-5,'Center Conway, New Hampshire 3813',885,1404);
INSERT INTO "django_geo_db_zipcode" VALUES(1324,3814,-5,'Center Ossipee, New Hampshire 3814',886,1405);
INSERT INTO "django_geo_db_zipcode" VALUES(1325,3815,-5,'Center Strafford, New Hampshire 3815',887,1406);
INSERT INTO "django_geo_db_zipcode" VALUES(1326,3816,-5,'Center Tuftonboro, New Hampshire 3816',888,1407);
INSERT INTO "django_geo_db_zipcode" VALUES(1327,3817,-5,'Chocorua, New Hampshire 3817',889,1408);
INSERT INTO "django_geo_db_zipcode" VALUES(1328,3818,-5,'Conway, New Hampshire 3818',890,1409);
INSERT INTO "django_geo_db_zipcode" VALUES(1329,3819,-5,'Danville, New Hampshire 3819',891,1410);
INSERT INTO "django_geo_db_zipcode" VALUES(1330,3820,-5,'Dover, New Hampshire 3820',892,1411);
INSERT INTO "django_geo_db_zipcode" VALUES(1331,3821,-5,'Dover, New Hampshire 3821',892,1412);
INSERT INTO "django_geo_db_zipcode" VALUES(1332,3822,-5,'Dover, New Hampshire 3822',892,1412);
INSERT INTO "django_geo_db_zipcode" VALUES(1333,3824,-5,'Durham, New Hampshire 3824',893,1413);
INSERT INTO "django_geo_db_zipcode" VALUES(1334,3825,-5,'Barrington, New Hampshire 3825',894,1414);
INSERT INTO "django_geo_db_zipcode" VALUES(1335,3826,-5,'East Hampstead, New Hampshire 3826',895,1415);
INSERT INTO "django_geo_db_zipcode" VALUES(1336,3827,-5,'East Kingston, New Hampshire 3827',896,1416);
INSERT INTO "django_geo_db_zipcode" VALUES(1337,3830,-5,'East Wakefield, New Hampshire 3830',897,1417);
INSERT INTO "django_geo_db_zipcode" VALUES(1338,3832,-5,'Eaton Center, New Hampshire 3832',898,1418);
INSERT INTO "django_geo_db_zipcode" VALUES(1339,3833,-5,'Exeter, New Hampshire 3833',899,1419);
INSERT INTO "django_geo_db_zipcode" VALUES(1340,3835,-5,'Farmington, New Hampshire 3835',900,1420);
INSERT INTO "django_geo_db_zipcode" VALUES(1341,3836,-5,'Freedom, New Hampshire 3836',851,1421);
INSERT INTO "django_geo_db_zipcode" VALUES(1342,3837,-5,'Gilmanton Iron Works, New Hampshire 3837',901,1422);
INSERT INTO "django_geo_db_zipcode" VALUES(1343,3838,-5,'Glen, New Hampshire 3838',902,1423);
INSERT INTO "django_geo_db_zipcode" VALUES(1344,3839,-5,'Rochester, New Hampshire 3839',903,1424);
INSERT INTO "django_geo_db_zipcode" VALUES(1345,3840,-5,'Greenland, New Hampshire 3840',904,1425);
INSERT INTO "django_geo_db_zipcode" VALUES(1346,3841,-5,'Hampstead, New Hampshire 3841',905,1426);
INSERT INTO "django_geo_db_zipcode" VALUES(1347,3842,-5,'Hampton, New Hampshire 3842',906,1427);
INSERT INTO "django_geo_db_zipcode" VALUES(1348,3843,-5,'Hampton, New Hampshire 3843',906,294);
INSERT INTO "django_geo_db_zipcode" VALUES(1349,3844,-5,'Hampton Falls, New Hampshire 3844',907,1428);
INSERT INTO "django_geo_db_zipcode" VALUES(1350,3845,-5,'Intervale, New Hampshire 3845',908,1429);
INSERT INTO "django_geo_db_zipcode" VALUES(1351,3846,-5,'Jackson, New Hampshire 3846',909,1430);
INSERT INTO "django_geo_db_zipcode" VALUES(1352,3847,-5,'Kearsarge, New Hampshire 3847',910,1431);
INSERT INTO "django_geo_db_zipcode" VALUES(1353,3848,-5,'Kingston, New Hampshire 3848',911,1432);
INSERT INTO "django_geo_db_zipcode" VALUES(1354,3849,-5,'Madison, New Hampshire 3849',912,1433);
INSERT INTO "django_geo_db_zipcode" VALUES(1355,3850,-5,'Melvin Village, New Hampshire 3850',913,1434);
INSERT INTO "django_geo_db_zipcode" VALUES(1356,3851,-5,'Milton, New Hampshire 3851',914,1435);
INSERT INTO "django_geo_db_zipcode" VALUES(1357,3852,-5,'Milton Mills, New Hampshire 3852',915,1436);
INSERT INTO "django_geo_db_zipcode" VALUES(1358,3853,-5,'Mirror Lake, New Hampshire 3853',916,1437);
INSERT INTO "django_geo_db_zipcode" VALUES(1359,3854,-5,'New Castle, New Hampshire 3854',917,1438);
INSERT INTO "django_geo_db_zipcode" VALUES(1360,3855,-5,'New Durham, New Hampshire 3855',918,1439);
INSERT INTO "django_geo_db_zipcode" VALUES(1361,3856,-5,'Newfields, New Hampshire 3856',919,1440);
INSERT INTO "django_geo_db_zipcode" VALUES(1362,3857,-5,'Newmarket, New Hampshire 3857',920,1441);
INSERT INTO "django_geo_db_zipcode" VALUES(1363,3858,-5,'Newton, New Hampshire 3858',921,1442);
INSERT INTO "django_geo_db_zipcode" VALUES(1364,3859,-5,'Newton Junction, New Hampshire 3859',922,1443);
INSERT INTO "django_geo_db_zipcode" VALUES(1365,3860,-5,'North Conway, New Hampshire 3860',923,1444);
INSERT INTO "django_geo_db_zipcode" VALUES(1366,3862,-5,'North Hampton, New Hampshire 3862',924,1445);
INSERT INTO "django_geo_db_zipcode" VALUES(1367,3864,-5,'Ossipee, New Hampshire 3864',925,1446);
INSERT INTO "django_geo_db_zipcode" VALUES(1368,3865,-5,'Plaistow, New Hampshire 3865',926,1447);
INSERT INTO "django_geo_db_zipcode" VALUES(1369,3866,-5,'Rochester, New Hampshire 3866',903,1448);
INSERT INTO "django_geo_db_zipcode" VALUES(1370,3867,-5,'Rochester, New Hampshire 3867',903,1449);
INSERT INTO "django_geo_db_zipcode" VALUES(1371,3868,-5,'Rochester, New Hampshire 3868',903,1450);
INSERT INTO "django_geo_db_zipcode" VALUES(1372,3869,-5,'Rollinsford, New Hampshire 3869',880,1451);
INSERT INTO "django_geo_db_zipcode" VALUES(1373,3870,-5,'Rye, New Hampshire 3870',927,1452);
INSERT INTO "django_geo_db_zipcode" VALUES(1374,3871,-5,'Rye Beach, New Hampshire 3871',928,1453);
INSERT INTO "django_geo_db_zipcode" VALUES(1375,3872,-5,'Sanbornville, New Hampshire 3872',929,1454);
INSERT INTO "django_geo_db_zipcode" VALUES(1376,3873,-5,'Sandown, New Hampshire 3873',930,1455);
INSERT INTO "django_geo_db_zipcode" VALUES(1377,3874,-5,'Seabrook, New Hampshire 3874',931,1456);
INSERT INTO "django_geo_db_zipcode" VALUES(1378,3875,-5,'Silver Lake, New Hampshire 3875',932,1457);
INSERT INTO "django_geo_db_zipcode" VALUES(1379,3878,-5,'Somersworth, New Hampshire 3878',933,1458);
INSERT INTO "django_geo_db_zipcode" VALUES(1380,3882,-5,'South Effingham, New Hampshire 3882',934,1459);
INSERT INTO "django_geo_db_zipcode" VALUES(1381,3883,-5,'South Tamworth, New Hampshire 3883',935,1460);
INSERT INTO "django_geo_db_zipcode" VALUES(1382,3884,-5,'Strafford, New Hampshire 3884',936,1461);
INSERT INTO "django_geo_db_zipcode" VALUES(1383,3885,-5,'Stratham, New Hampshire 3885',937,1462);
INSERT INTO "django_geo_db_zipcode" VALUES(1384,3886,-5,'Tamworth, New Hampshire 3886',794,1463);
INSERT INTO "django_geo_db_zipcode" VALUES(1385,3887,-5,'Union, New Hampshire 3887',938,1464);
INSERT INTO "django_geo_db_zipcode" VALUES(1386,3890,-5,'West Ossipee, New Hampshire 3890',939,1465);
INSERT INTO "django_geo_db_zipcode" VALUES(1387,3891,-5,'Danville, New Hampshire 3891',891,1466);
INSERT INTO "django_geo_db_zipcode" VALUES(1388,3894,-5,'Wolfeboro, New Hampshire 3894',940,1467);
INSERT INTO "django_geo_db_zipcode" VALUES(1389,3896,-5,'Wolfeboro Falls, New Hampshire 3896',941,1468);
INSERT INTO "django_geo_db_zipcode" VALUES(1390,3897,-5,'Wonalancet, New Hampshire 3897',942,1469);
INSERT INTO "django_geo_db_zipcode" VALUES(1391,3901,-5,'Berwick, Maine 3901',724,1470);
INSERT INTO "django_geo_db_zipcode" VALUES(1392,3902,-5,'Cape Neddick, Maine 3902',943,1471);
INSERT INTO "django_geo_db_zipcode" VALUES(1393,3903,-5,'Eliot, Maine 3903',944,1472);
INSERT INTO "django_geo_db_zipcode" VALUES(1394,3904,-5,'Kittery, Maine 3904',945,1473);
INSERT INTO "django_geo_db_zipcode" VALUES(1395,3905,-5,'Kittery Point, Maine 3905',946,1474);
INSERT INTO "django_geo_db_zipcode" VALUES(1396,3906,-5,'North Berwick, Maine 3906',947,1475);
INSERT INTO "django_geo_db_zipcode" VALUES(1397,3907,-5,'Ogunquit, Maine 3907',725,1476);
INSERT INTO "django_geo_db_zipcode" VALUES(1398,3908,-5,'South Berwick, Maine 3908',948,1477);
INSERT INTO "django_geo_db_zipcode" VALUES(1399,3909,-5,'York, Maine 3909',949,1478);
INSERT INTO "django_geo_db_zipcode" VALUES(1400,3910,-5,'York Beach, Maine 3910',950,1479);
INSERT INTO "django_geo_db_zipcode" VALUES(1401,3911,-5,'York Harbor, Maine 3911',951,1480);
INSERT INTO "django_geo_db_zipcode" VALUES(1402,4001,-5,'Acton, Maine 4001',952,1481);
INSERT INTO "django_geo_db_zipcode" VALUES(1403,4002,-5,'Alfred, Maine 4002',953,1482);
INSERT INTO "django_geo_db_zipcode" VALUES(1404,4003,-5,'Bailey Island, Maine 4003',954,1483);
INSERT INTO "django_geo_db_zipcode" VALUES(1405,4004,-5,'Bar Mills, Maine 4004',955,1484);
INSERT INTO "django_geo_db_zipcode" VALUES(1406,4005,-5,'Biddeford, Maine 4005',956,1485);
INSERT INTO "django_geo_db_zipcode" VALUES(1407,4006,-5,'Biddeford Pool, Maine 4006',957,1486);
INSERT INTO "django_geo_db_zipcode" VALUES(1408,4007,-5,'Biddeford, Maine 4007',956,1487);
INSERT INTO "django_geo_db_zipcode" VALUES(1409,4008,-5,'Bowdoinham, Maine 4008',958,1488);
INSERT INTO "django_geo_db_zipcode" VALUES(1410,4009,-5,'Bridgton, Maine 4009',959,1489);
INSERT INTO "django_geo_db_zipcode" VALUES(1411,4010,-5,'Brownfield, Maine 4010',960,1490);
INSERT INTO "django_geo_db_zipcode" VALUES(1412,4011,-5,'Brunswick, Maine 4011',961,1491);
INSERT INTO "django_geo_db_zipcode" VALUES(1413,4013,-5,'Bustins Island, Maine 4013',962,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1414,4014,-5,'Cape Porpoise, Maine 4014',963,1484);
INSERT INTO "django_geo_db_zipcode" VALUES(1415,4015,-5,'Casco, Maine 4015',964,1493);
INSERT INTO "django_geo_db_zipcode" VALUES(1416,4016,-5,'Center Lovell, Maine 4016',965,1494);
INSERT INTO "django_geo_db_zipcode" VALUES(1417,4017,-5,'Chebeague Island, Maine 4017',966,1495);
INSERT INTO "django_geo_db_zipcode" VALUES(1418,4019,-5,'Cliff Island, Maine 4019',967,1496);
INSERT INTO "django_geo_db_zipcode" VALUES(1419,4020,-5,'Cornish, Maine 4020',968,1497);
INSERT INTO "django_geo_db_zipcode" VALUES(1420,4021,-5,'Cumberland Center, Maine 4021',969,1498);
INSERT INTO "django_geo_db_zipcode" VALUES(1421,4022,-5,'Denmark, Maine 4022',970,1499);
INSERT INTO "django_geo_db_zipcode" VALUES(1422,4024,-5,'East Baldwin, Maine 4024',971,1500);
INSERT INTO "django_geo_db_zipcode" VALUES(1423,4027,-5,'Lebanon, Maine 4027',854,1501);
INSERT INTO "django_geo_db_zipcode" VALUES(1424,4028,-5,'East Parsonfield, Maine 4028',972,1502);
INSERT INTO "django_geo_db_zipcode" VALUES(1425,4029,-5,'Sebago, Maine 4029',973,1503);
INSERT INTO "django_geo_db_zipcode" VALUES(1426,4030,-5,'East Waterboro, Maine 4030',974,1504);
INSERT INTO "django_geo_db_zipcode" VALUES(1427,4031,-5,'Raymond, Maine 4031',975,1505);
INSERT INTO "django_geo_db_zipcode" VALUES(1428,4032,-5,'Freeport, Maine 4032',976,1506);
INSERT INTO "django_geo_db_zipcode" VALUES(1429,4033,-5,'Freeport, Maine 4033',976,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1430,4034,-5,'Freeport, Maine 4034',976,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1431,4037,-5,'Fryeburg, Maine 4037',977,1507);
INSERT INTO "django_geo_db_zipcode" VALUES(1432,4038,-5,'Gorham, Maine 4038',978,1508);
INSERT INTO "django_geo_db_zipcode" VALUES(1433,4039,-5,'Gray, Maine 4039',979,1509);
INSERT INTO "django_geo_db_zipcode" VALUES(1434,4040,-5,'Harrison, Maine 4040',980,1510);
INSERT INTO "django_geo_db_zipcode" VALUES(1435,4041,-5,'Hiram, Maine 4041',981,1511);
INSERT INTO "django_geo_db_zipcode" VALUES(1436,4042,-5,'Hollis Center, Maine 4042',982,1512);
INSERT INTO "django_geo_db_zipcode" VALUES(1437,4043,-5,'Kennebunk, Maine 4043',983,1513);
INSERT INTO "django_geo_db_zipcode" VALUES(1438,4046,-5,'Kennebunkport, Maine 4046',984,1514);
INSERT INTO "django_geo_db_zipcode" VALUES(1439,4047,-5,'Parsonsfield, Maine 4047',985,1515);
INSERT INTO "django_geo_db_zipcode" VALUES(1440,4048,-5,'Limerick, Maine 4048',986,1516);
INSERT INTO "django_geo_db_zipcode" VALUES(1441,4049,-5,'Limington, Maine 4049',987,1517);
INSERT INTO "django_geo_db_zipcode" VALUES(1442,4050,-5,'Long Island, Maine 4050',988,1518);
INSERT INTO "django_geo_db_zipcode" VALUES(1443,4051,-5,'Lovell, Maine 4051',989,1519);
INSERT INTO "django_geo_db_zipcode" VALUES(1444,4053,-5,'Merepoint, Maine 4053',990,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1445,4054,-5,'Moody, Maine 4054',991,1520);
INSERT INTO "django_geo_db_zipcode" VALUES(1446,4055,-5,'Naples, Maine 4055',992,1521);
INSERT INTO "django_geo_db_zipcode" VALUES(1447,4056,-5,'Newfield, Maine 4056',993,1522);
INSERT INTO "django_geo_db_zipcode" VALUES(1448,4057,-5,'North Bridgton, Maine 4057',994,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1449,4061,-5,'North Waterboro, Maine 4061',995,1523);
INSERT INTO "django_geo_db_zipcode" VALUES(1450,4062,-5,'Windham, Maine 4062',996,1524);
INSERT INTO "django_geo_db_zipcode" VALUES(1451,4063,-5,'Ocean Park, Maine 4063',997,1525);
INSERT INTO "django_geo_db_zipcode" VALUES(1452,4064,-5,'Old Orchard Beach, Maine 4064',998,1526);
INSERT INTO "django_geo_db_zipcode" VALUES(1453,4065,-5,'Ellsworth, Maine 4065',999,1527);
INSERT INTO "django_geo_db_zipcode" VALUES(1454,4066,-5,'Orrs Island, Maine 4066',1000,1528);
INSERT INTO "django_geo_db_zipcode" VALUES(1455,4068,-5,'Porter, Maine 4068',1001,1529);
INSERT INTO "django_geo_db_zipcode" VALUES(1456,4069,-5,'Pownal, Maine 4069',1002,1530);
INSERT INTO "django_geo_db_zipcode" VALUES(1457,4070,-5,'Scarborough, Maine 4070',1003,1531);
INSERT INTO "django_geo_db_zipcode" VALUES(1458,4071,-5,'Raymond, Maine 4071',975,1532);
INSERT INTO "django_geo_db_zipcode" VALUES(1459,4072,-5,'Saco, Maine 4072',1004,1533);
INSERT INTO "django_geo_db_zipcode" VALUES(1460,4073,-5,'Sanford, Maine 4073',1005,1534);
INSERT INTO "django_geo_db_zipcode" VALUES(1461,4074,-5,'Scarborough, Maine 4074',1003,1535);
INSERT INTO "django_geo_db_zipcode" VALUES(1462,4075,-5,'Sebago Lake, Maine 4075',1006,1536);
INSERT INTO "django_geo_db_zipcode" VALUES(1463,4076,-5,'Shapleigh, Maine 4076',1007,1537);
INSERT INTO "django_geo_db_zipcode" VALUES(1464,4077,-5,'South Casco, Maine 4077',1008,1538);
INSERT INTO "django_geo_db_zipcode" VALUES(1465,4078,-5,'South Freeport, Maine 4078',1009,1539);
INSERT INTO "django_geo_db_zipcode" VALUES(1466,4079,-5,'Harpswell, Maine 4079',1010,1540);
INSERT INTO "django_geo_db_zipcode" VALUES(1467,4081,-5,'South Waterford, Maine 4081',1011,1541);
INSERT INTO "django_geo_db_zipcode" VALUES(1468,4082,-5,'South Windham, Maine 4082',1012,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1469,4083,-5,'Springvale, Maine 4083',1013,1542);
INSERT INTO "django_geo_db_zipcode" VALUES(1470,4084,-5,'Standish, Maine 4084',1014,1543);
INSERT INTO "django_geo_db_zipcode" VALUES(1471,4085,-5,'Steep Falls, Maine 4085',1015,1544);
INSERT INTO "django_geo_db_zipcode" VALUES(1472,4086,-5,'Topsham, Maine 4086',1016,1545);
INSERT INTO "django_geo_db_zipcode" VALUES(1473,4087,-5,'Waterboro, Maine 4087',1017,1546);
INSERT INTO "django_geo_db_zipcode" VALUES(1474,4088,-5,'Waterford, Maine 4088',1018,1547);
INSERT INTO "django_geo_db_zipcode" VALUES(1475,4090,-5,'Wells, Maine 4090',1019,1548);
INSERT INTO "django_geo_db_zipcode" VALUES(1476,4091,-5,'West Baldwin, Maine 4091',1020,1549);
INSERT INTO "django_geo_db_zipcode" VALUES(1477,4092,-5,'Westbrook, Maine 4092',1021,1550);
INSERT INTO "django_geo_db_zipcode" VALUES(1478,4093,-5,'West Buxton, Maine 4093',1022,1551);
INSERT INTO "django_geo_db_zipcode" VALUES(1479,4094,-5,'West Kennebunk, Maine 4094',1023,1552);
INSERT INTO "django_geo_db_zipcode" VALUES(1480,4095,-5,'West Newfield, Maine 4095',1024,1553);
INSERT INTO "django_geo_db_zipcode" VALUES(1481,4096,-5,'Yarmouth, Maine 4096',1025,1554);
INSERT INTO "django_geo_db_zipcode" VALUES(1482,4097,-5,'North Yarmouth, Maine 4097',1026,1555);
INSERT INTO "django_geo_db_zipcode" VALUES(1483,4098,-5,'Westbrook, Maine 4098',1021,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1484,4101,-5,'Portland, Maine 4101',1027,1556);
INSERT INTO "django_geo_db_zipcode" VALUES(1485,4102,-5,'Portland, Maine 4102',1027,1557);
INSERT INTO "django_geo_db_zipcode" VALUES(1486,4103,-5,'Portland, Maine 4103',1027,1558);
INSERT INTO "django_geo_db_zipcode" VALUES(1487,4104,-5,'Portland, Maine 4104',1027,1559);
INSERT INTO "django_geo_db_zipcode" VALUES(1488,4105,-5,'Falmouth, Maine 4105',1028,1560);
INSERT INTO "django_geo_db_zipcode" VALUES(1489,4106,-5,'South Portland, Maine 4106',1029,1561);
INSERT INTO "django_geo_db_zipcode" VALUES(1490,4107,-5,'Cape Elizabeth, Maine 4107',1030,1562);
INSERT INTO "django_geo_db_zipcode" VALUES(1491,4108,-5,'Peaks Island, Maine 4108',1031,1563);
INSERT INTO "django_geo_db_zipcode" VALUES(1492,4109,-5,'Portland, Maine 4109',1027,1564);
INSERT INTO "django_geo_db_zipcode" VALUES(1493,4110,-5,'Cumberland Foreside, Maine 4110',1032,1565);
INSERT INTO "django_geo_db_zipcode" VALUES(1494,4112,-5,'Portland, Maine 4112',1027,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1495,4116,-5,'South Portland, Maine 4116',1029,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1496,4122,-5,'Portland, Maine 4122',1027,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1497,4123,-5,'Portland, Maine 4123',1027,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1498,4124,-5,'Portland, Maine 4124',1027,1492);
INSERT INTO "django_geo_db_zipcode" VALUES(1499,4210,-5,'Auburn, Maine 4210',1033,1566);
INSERT INTO "django_geo_db_zipcode" VALUES(1500,4211,-5,'Auburn, Maine 4211',1033,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1501,4212,-5,'Auburn, Maine 4212',1033,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1502,4216,-5,'Andover, Maine 4216',1034,1568);
INSERT INTO "django_geo_db_zipcode" VALUES(1503,4217,-5,'Bethel, Maine 4217',1035,1569);
INSERT INTO "django_geo_db_zipcode" VALUES(1504,4219,-5,'Bryant Pond, Maine 4219',1036,1570);
INSERT INTO "django_geo_db_zipcode" VALUES(1505,4220,-5,'Buckfield, Maine 4220',1037,1571);
INSERT INTO "django_geo_db_zipcode" VALUES(1506,4221,-5,'Canton, Maine 4221',1038,1572);
INSERT INTO "django_geo_db_zipcode" VALUES(1507,4222,-5,'Durham, Maine 4222',1039,1573);
INSERT INTO "django_geo_db_zipcode" VALUES(1508,4223,-5,'Danville, Maine 4223',1040,1574);
INSERT INTO "django_geo_db_zipcode" VALUES(1509,4224,-5,'Dixfield, Maine 4224',1041,1575);
INSERT INTO "django_geo_db_zipcode" VALUES(1510,4225,-5,'Dryden, Maine 4225',1042,1576);
INSERT INTO "django_geo_db_zipcode" VALUES(1511,4226,-5,'East Andover, Maine 4226',1043,1577);
INSERT INTO "django_geo_db_zipcode" VALUES(1512,4227,-5,'East Dixfield, Maine 4227',1044,1578);
INSERT INTO "django_geo_db_zipcode" VALUES(1513,4228,-5,'East Livermore, Maine 4228',1045,1579);
INSERT INTO "django_geo_db_zipcode" VALUES(1514,4230,-5,'East Poland, Maine 4230',1046,1580);
INSERT INTO "django_geo_db_zipcode" VALUES(1515,4231,-5,'Stoneham, Maine 4231',1047,1581);
INSERT INTO "django_geo_db_zipcode" VALUES(1516,4234,-5,'East Wilton, Maine 4234',1048,1582);
INSERT INTO "django_geo_db_zipcode" VALUES(1517,4236,-5,'Greene, Maine 4236',1049,1583);
INSERT INTO "django_geo_db_zipcode" VALUES(1518,4237,-5,'Hanover, Maine 4237',1050,1584);
INSERT INTO "django_geo_db_zipcode" VALUES(1519,4238,-5,'Hebron, Maine 4238',1051,1585);
INSERT INTO "django_geo_db_zipcode" VALUES(1520,4239,-5,'Jay, Maine 4239',1052,1586);
INSERT INTO "django_geo_db_zipcode" VALUES(1521,4240,-5,'Lewiston, Maine 4240',1053,1587);
INSERT INTO "django_geo_db_zipcode" VALUES(1522,4241,-5,'Lewiston, Maine 4241',1053,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1523,4243,-5,'Lewiston, Maine 4243',1053,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1524,4250,-5,'Lisbon, Maine 4250',1054,1588);
INSERT INTO "django_geo_db_zipcode" VALUES(1525,4252,-5,'Lisbon Falls, Maine 4252',1055,1589);
INSERT INTO "django_geo_db_zipcode" VALUES(1526,4253,-5,'Livermore, Maine 4253',1056,1590);
INSERT INTO "django_geo_db_zipcode" VALUES(1527,4254,-5,'Livermore Falls, Maine 4254',1057,1591);
INSERT INTO "django_geo_db_zipcode" VALUES(1528,4255,-5,'Locke Mills, Maine 4255',1058,1592);
INSERT INTO "django_geo_db_zipcode" VALUES(1529,4256,-5,'Mechanic Falls, Maine 4256',1059,1593);
INSERT INTO "django_geo_db_zipcode" VALUES(1530,4257,-5,'Mexico, Maine 4257',1060,1594);
INSERT INTO "django_geo_db_zipcode" VALUES(1531,4258,-5,'Minot, Maine 4258',1061,1595);
INSERT INTO "django_geo_db_zipcode" VALUES(1532,4259,-5,'Monmouth, Maine 4259',1062,1596);
INSERT INTO "django_geo_db_zipcode" VALUES(1533,4260,-5,'New Gloucester, Maine 4260',1063,1597);
INSERT INTO "django_geo_db_zipcode" VALUES(1534,4261,-5,'Newry, Maine 4261',1064,1598);
INSERT INTO "django_geo_db_zipcode" VALUES(1535,4262,-5,'North Jay, Maine 4262',1065,1599);
INSERT INTO "django_geo_db_zipcode" VALUES(1536,4263,-5,'Leeds, Maine 4263',1066,1600);
INSERT INTO "django_geo_db_zipcode" VALUES(1537,4265,-5,'North Monmouth, Maine 4265',1067,1601);
INSERT INTO "django_geo_db_zipcode" VALUES(1538,4266,-5,'North Turner, Maine 4266',1068,1602);
INSERT INTO "django_geo_db_zipcode" VALUES(1539,4267,-5,'North Waterford, Maine 4267',1069,1541);
INSERT INTO "django_geo_db_zipcode" VALUES(1540,4268,-5,'Norway, Maine 4268',1070,1603);
INSERT INTO "django_geo_db_zipcode" VALUES(1541,4270,-5,'Oxford, Maine 4270',1071,1604);
INSERT INTO "django_geo_db_zipcode" VALUES(1542,4271,-5,'Paris, Maine 4271',1072,1605);
INSERT INTO "django_geo_db_zipcode" VALUES(1543,4273,-5,'Hanover, Maine 4273',1050,1606);
INSERT INTO "django_geo_db_zipcode" VALUES(1544,4274,-5,'Poland, Maine 4274',1073,1607);
INSERT INTO "django_geo_db_zipcode" VALUES(1545,4275,-5,'Roxbury, Maine 4275',1074,1608);
INSERT INTO "django_geo_db_zipcode" VALUES(1546,4276,-5,'Rumford, Maine 4276',1075,1609);
INSERT INTO "django_geo_db_zipcode" VALUES(1547,4278,-5,'Rumford Center, Maine 4278',1076,1610);
INSERT INTO "django_geo_db_zipcode" VALUES(1548,4279,-5,'Rumford, Maine 4279',1075,1611);
INSERT INTO "django_geo_db_zipcode" VALUES(1549,4280,-5,'Sabattus, Maine 4280',1077,1612);
INSERT INTO "django_geo_db_zipcode" VALUES(1550,4281,-5,'South Paris, Maine 4281',1078,1613);
INSERT INTO "django_geo_db_zipcode" VALUES(1551,4282,-5,'Turner, Maine 4282',1079,1614);
INSERT INTO "django_geo_db_zipcode" VALUES(1552,4283,-5,'Turner Center, Maine 4283',1080,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1553,4284,-5,'Wayne, Maine 4284',1081,1615);
INSERT INTO "django_geo_db_zipcode" VALUES(1554,4285,-5,'Weld, Maine 4285',1082,1616);
INSERT INTO "django_geo_db_zipcode" VALUES(1555,4286,-5,'West Bethel, Maine 4286',1083,1617);
INSERT INTO "django_geo_db_zipcode" VALUES(1556,4287,-5,'Bowdoin, Maine 4287',1084,1618);
INSERT INTO "django_geo_db_zipcode" VALUES(1557,4288,-5,'West Minot, Maine 4288',1085,1567);
INSERT INTO "django_geo_db_zipcode" VALUES(1558,4289,-5,'West Paris, Maine 4289',1086,1619);
INSERT INTO "django_geo_db_zipcode" VALUES(1559,4290,-5,'Peru, Maine 4290',1087,1620);
INSERT INTO "django_geo_db_zipcode" VALUES(1560,4291,-5,'West Poland, Maine 4291',1088,1621);
INSERT INTO "django_geo_db_zipcode" VALUES(1561,4292,-5,'Sumner, Maine 4292',1089,1622);
INSERT INTO "django_geo_db_zipcode" VALUES(1562,4294,-5,'Wilton, Maine 4294',1090,1623);
INSERT INTO "django_geo_db_zipcode" VALUES(1563,4321,-5,'Stoneham, Maine 4321',1047,1624);
INSERT INTO "django_geo_db_zipcode" VALUES(1564,4327,-5,'Richmond, Maine 4327',1091,1625);
INSERT INTO "django_geo_db_zipcode" VALUES(1565,4330,-5,'Augusta, Maine 4330',1092,1626);
INSERT INTO "django_geo_db_zipcode" VALUES(1566,4332,-5,'Augusta, Maine 4332',1092,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1567,4333,-5,'Augusta, Maine 4333',1092,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1568,4336,-5,'Augusta, Maine 4336',1092,1628);
INSERT INTO "django_geo_db_zipcode" VALUES(1569,4338,-5,'Augusta, Maine 4338',1092,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1570,4341,-5,'Coopers Mills, Maine 4341',1093,1629);
INSERT INTO "django_geo_db_zipcode" VALUES(1571,4342,-5,'Dresden, Maine 4342',1094,1630);
INSERT INTO "django_geo_db_zipcode" VALUES(1572,4343,-5,'East Winthrop, Maine 4343',1095,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1573,4344,-5,'Farmingdale, Maine 4344',1096,1631);
INSERT INTO "django_geo_db_zipcode" VALUES(1574,4345,-5,'Gardiner, Maine 4345',1097,1632);
INSERT INTO "django_geo_db_zipcode" VALUES(1575,4346,-5,'Randolph, Maine 4346',1098,1633);
INSERT INTO "django_geo_db_zipcode" VALUES(1576,4347,-5,'Hallowell, Maine 4347',1099,1634);
INSERT INTO "django_geo_db_zipcode" VALUES(1577,4348,-5,'Jefferson, Maine 4348',1100,1635);
INSERT INTO "django_geo_db_zipcode" VALUES(1578,4349,-5,'Kents Hill, Maine 4349',1101,1636);
INSERT INTO "django_geo_db_zipcode" VALUES(1579,4350,-5,'Litchfield, Maine 4350',1102,1637);
INSERT INTO "django_geo_db_zipcode" VALUES(1580,4351,-5,'Manchester, Maine 4351',1103,1638);
INSERT INTO "django_geo_db_zipcode" VALUES(1581,4352,-5,'Mount Vernon, Maine 4352',1104,1639);
INSERT INTO "django_geo_db_zipcode" VALUES(1582,4353,-5,'Whitefield, Maine 4353',1105,1640);
INSERT INTO "django_geo_db_zipcode" VALUES(1583,4354,-5,'Palermo, Maine 4354',1106,1641);
INSERT INTO "django_geo_db_zipcode" VALUES(1584,4355,-5,'Readfield, Maine 4355',1107,1642);
INSERT INTO "django_geo_db_zipcode" VALUES(1585,4357,-5,'Richmond, Maine 4357',1091,1643);
INSERT INTO "django_geo_db_zipcode" VALUES(1586,4358,-5,'South China, Maine 4358',1108,1644);
INSERT INTO "django_geo_db_zipcode" VALUES(1587,4359,-5,'South Gardiner, Maine 4359',1109,1645);
INSERT INTO "django_geo_db_zipcode" VALUES(1588,4360,-5,'Vienna, Maine 4360',1110,1646);
INSERT INTO "django_geo_db_zipcode" VALUES(1589,4363,-5,'Windsor, Maine 4363',1111,1647);
INSERT INTO "django_geo_db_zipcode" VALUES(1590,4364,-5,'Winthrop, Maine 4364',1112,1648);
INSERT INTO "django_geo_db_zipcode" VALUES(1591,4401,-5,'Bangor, Maine 4401',1113,1649);
INSERT INTO "django_geo_db_zipcode" VALUES(1592,4402,-5,'Bangor, Maine 4402',1113,1650);
INSERT INTO "django_geo_db_zipcode" VALUES(1593,4406,-5,'Abbot, Maine 4406',1114,1651);
INSERT INTO "django_geo_db_zipcode" VALUES(1594,4408,-5,'Aurora, Maine 4408',1115,1652);
INSERT INTO "django_geo_db_zipcode" VALUES(1595,4410,-5,'Bradford, Maine 4410',1116,1653);
INSERT INTO "django_geo_db_zipcode" VALUES(1596,4411,-5,'Bradley, Maine 4411',1117,1654);
INSERT INTO "django_geo_db_zipcode" VALUES(1597,4412,-5,'Brewer, Maine 4412',1118,1655);
INSERT INTO "django_geo_db_zipcode" VALUES(1598,4413,-5,'Brookton, Maine 4413',1119,1656);
INSERT INTO "django_geo_db_zipcode" VALUES(1599,4414,-5,'Brownville, Maine 4414',1120,1657);
INSERT INTO "django_geo_db_zipcode" VALUES(1600,4415,-5,'Brownville Junction, Maine 4415',1121,1658);
INSERT INTO "django_geo_db_zipcode" VALUES(1601,4416,-5,'Bucksport, Maine 4416',1122,1659);
INSERT INTO "django_geo_db_zipcode" VALUES(1602,4417,-5,'Burlington, Maine 4417',1123,1660);
INSERT INTO "django_geo_db_zipcode" VALUES(1603,4418,-5,'Cardville, Maine 4418',1124,1661);
INSERT INTO "django_geo_db_zipcode" VALUES(1604,4419,-5,'Carmel, Maine 4419',1125,1662);
INSERT INTO "django_geo_db_zipcode" VALUES(1605,4420,-5,'Castine, Maine 4420',1126,1663);
INSERT INTO "django_geo_db_zipcode" VALUES(1606,4421,-5,'Castine, Maine 4421',1126,1664);
INSERT INTO "django_geo_db_zipcode" VALUES(1607,4422,-5,'Charleston, Maine 4422',1127,1665);
INSERT INTO "django_geo_db_zipcode" VALUES(1608,4423,-5,'Costigan, Maine 4423',1128,1666);
INSERT INTO "django_geo_db_zipcode" VALUES(1609,4424,-5,'Danforth, Maine 4424',1129,1667);
INSERT INTO "django_geo_db_zipcode" VALUES(1610,4426,-5,'Dover Foxcroft, Maine 4426',1130,1668);
INSERT INTO "django_geo_db_zipcode" VALUES(1611,4427,-5,'Corinth, Maine 4427',1131,1669);
INSERT INTO "django_geo_db_zipcode" VALUES(1612,4428,-5,'Eddington, Maine 4428',1132,1670);
INSERT INTO "django_geo_db_zipcode" VALUES(1613,4429,-5,'Holden, Maine 4429',1133,1671);
INSERT INTO "django_geo_db_zipcode" VALUES(1614,4430,-5,'East Millinocket, Maine 4430',1134,1672);
INSERT INTO "django_geo_db_zipcode" VALUES(1615,4431,-5,'East Orland, Maine 4431',1135,1673);
INSERT INTO "django_geo_db_zipcode" VALUES(1616,4434,-5,'Etna, Maine 4434',1136,1674);
INSERT INTO "django_geo_db_zipcode" VALUES(1617,4435,-5,'Exeter, Maine 4435',1137,1675);
INSERT INTO "django_geo_db_zipcode" VALUES(1618,4438,-5,'Frankfort, Maine 4438',1138,1676);
INSERT INTO "django_geo_db_zipcode" VALUES(1619,4441,-5,'Greenville, Maine 4441',1139,1677);
INSERT INTO "django_geo_db_zipcode" VALUES(1620,4442,-5,'Greenville Junction, Maine 4442',1140,1678);
INSERT INTO "django_geo_db_zipcode" VALUES(1621,4443,-5,'Guilford, Maine 4443',1141,1679);
INSERT INTO "django_geo_db_zipcode" VALUES(1622,4444,-5,'Hampden, Maine 4444',1142,1680);
INSERT INTO "django_geo_db_zipcode" VALUES(1623,4448,-5,'Howland, Maine 4448',1143,1681);
INSERT INTO "django_geo_db_zipcode" VALUES(1624,4449,-5,'Hudson, Maine 4449',1144,1682);
INSERT INTO "django_geo_db_zipcode" VALUES(1625,4450,-5,'Kenduskeag, Maine 4450',1145,1683);
INSERT INTO "django_geo_db_zipcode" VALUES(1626,4451,-5,'Kingman, Maine 4451',1146,1684);
INSERT INTO "django_geo_db_zipcode" VALUES(1627,4453,-5,'Lagrange, Maine 4453',1147,1685);
INSERT INTO "django_geo_db_zipcode" VALUES(1628,4454,-5,'Lambert Lake, Maine 4454',1148,1686);
INSERT INTO "django_geo_db_zipcode" VALUES(1629,4455,-5,'Lee, Maine 4455',1149,1687);
INSERT INTO "django_geo_db_zipcode" VALUES(1630,4456,-5,'Levant, Maine 4456',1150,1688);
INSERT INTO "django_geo_db_zipcode" VALUES(1631,4457,-5,'Lincoln, Maine 4457',1151,1689);
INSERT INTO "django_geo_db_zipcode" VALUES(1632,4459,-5,'Mattawamkeag, Maine 4459',1152,1690);
INSERT INTO "django_geo_db_zipcode" VALUES(1633,4460,-5,'Medway, Maine 4460',1153,1691);
INSERT INTO "django_geo_db_zipcode" VALUES(1634,4461,-5,'Milford, Maine 4461',1154,1692);
INSERT INTO "django_geo_db_zipcode" VALUES(1635,4462,-5,'Millinocket, Maine 4462',1155,1693);
INSERT INTO "django_geo_db_zipcode" VALUES(1636,4463,-5,'Milo, Maine 4463',1156,1694);
INSERT INTO "django_geo_db_zipcode" VALUES(1637,4464,-5,'Monson, Maine 4464',1157,1695);
INSERT INTO "django_geo_db_zipcode" VALUES(1638,4465,-5,'Cary, Maine 4465',1158,1696);
INSERT INTO "django_geo_db_zipcode" VALUES(1639,4467,-5,'Olamon, Maine 4467',1159,1650);
INSERT INTO "django_geo_db_zipcode" VALUES(1640,4468,-5,'Old Town, Maine 4468',1160,1697);
INSERT INTO "django_geo_db_zipcode" VALUES(1641,4469,-5,'Orono, Maine 4469',1161,1698);
INSERT INTO "django_geo_db_zipcode" VALUES(1642,4471,-5,'Orient, Maine 4471',1162,1699);
INSERT INTO "django_geo_db_zipcode" VALUES(1643,4472,-5,'Orland, Maine 4472',1163,1700);
INSERT INTO "django_geo_db_zipcode" VALUES(1644,4473,-5,'Orono, Maine 4473',1161,1701);
INSERT INTO "django_geo_db_zipcode" VALUES(1645,4474,-5,'Orrington, Maine 4474',1164,1702);
INSERT INTO "django_geo_db_zipcode" VALUES(1646,4475,-5,'Passadumkeag, Maine 4475',1165,1703);
INSERT INTO "django_geo_db_zipcode" VALUES(1647,4476,-5,'Penobscot, Maine 4476',1166,1704);
INSERT INTO "django_geo_db_zipcode" VALUES(1648,4478,-5,'Rockwood, Maine 4478',1167,1705);
INSERT INTO "django_geo_db_zipcode" VALUES(1649,4479,-5,'Sangerville, Maine 4479',1168,1706);
INSERT INTO "django_geo_db_zipcode" VALUES(1650,4481,-5,'Sebec, Maine 4481',1169,1707);
INSERT INTO "django_geo_db_zipcode" VALUES(1651,4485,-5,'Shirley Mills, Maine 4485',1170,1707);
INSERT INTO "django_geo_db_zipcode" VALUES(1652,4487,-5,'Springfield, Maine 4487',1171,1708);
INSERT INTO "django_geo_db_zipcode" VALUES(1653,4488,-5,'Stetson, Maine 4488',1172,1709);
INSERT INTO "django_geo_db_zipcode" VALUES(1654,4489,-5,'Stillwater, Maine 4489',1173,1710);
INSERT INTO "django_geo_db_zipcode" VALUES(1655,4490,-5,'Topsfield, Maine 4490',1174,1711);
INSERT INTO "django_geo_db_zipcode" VALUES(1656,4491,-5,'Vanceboro, Maine 4491',1175,1686);
INSERT INTO "django_geo_db_zipcode" VALUES(1657,4492,-5,'Waite, Maine 4492',1176,1686);
INSERT INTO "django_geo_db_zipcode" VALUES(1658,4493,-5,'West Enfield, Maine 4493',1177,1712);
INSERT INTO "django_geo_db_zipcode" VALUES(1659,4495,-5,'Winn, Maine 4495',1178,1713);
INSERT INTO "django_geo_db_zipcode" VALUES(1660,4496,-5,'Winterport, Maine 4496',1179,1714);
INSERT INTO "django_geo_db_zipcode" VALUES(1661,4497,-5,'Wytopitlock, Maine 4497',1180,1715);
INSERT INTO "django_geo_db_zipcode" VALUES(1662,4530,-5,'Bath, Maine 4530',1181,1716);
INSERT INTO "django_geo_db_zipcode" VALUES(1663,4535,-5,'Alna, Maine 4535',1182,1717);
INSERT INTO "django_geo_db_zipcode" VALUES(1664,4536,-5,'Bayville, Maine 4536',1183,1718);
INSERT INTO "django_geo_db_zipcode" VALUES(1665,4537,-5,'Boothbay, Maine 4537',1184,1719);
INSERT INTO "django_geo_db_zipcode" VALUES(1666,4538,-5,'Boothbay Harbor, Maine 4538',1185,1720);
INSERT INTO "django_geo_db_zipcode" VALUES(1667,4539,-5,'Bristol, Maine 4539',1186,1721);
INSERT INTO "django_geo_db_zipcode" VALUES(1668,4541,-5,'Chamberlain, Maine 4541',1187,1722);
INSERT INTO "django_geo_db_zipcode" VALUES(1669,4543,-5,'Damariscotta, Maine 4543',1188,1723);
INSERT INTO "django_geo_db_zipcode" VALUES(1670,4544,-5,'East Boothbay, Maine 4544',1189,1724);
INSERT INTO "django_geo_db_zipcode" VALUES(1671,4546,-5,'Georgetown, Maine 4546',1190,1725);
INSERT INTO "django_geo_db_zipcode" VALUES(1672,4547,-5,'Friendship, Maine 4547',1191,1726);
INSERT INTO "django_geo_db_zipcode" VALUES(1673,4548,-5,'Georgetown, Maine 4548',1190,1727);
INSERT INTO "django_geo_db_zipcode" VALUES(1674,4549,-5,'Isle Of Springs, Maine 4549',1192,1718);
INSERT INTO "django_geo_db_zipcode" VALUES(1675,4551,-5,'Bremen, Maine 4551',1193,1728);
INSERT INTO "django_geo_db_zipcode" VALUES(1676,4552,-5,'Newagen, Maine 4552',1194,1718);
INSERT INTO "django_geo_db_zipcode" VALUES(1677,4553,-5,'Newcastle, Maine 4553',1195,1729);
INSERT INTO "django_geo_db_zipcode" VALUES(1678,4554,-5,'New Harbor, Maine 4554',1196,1730);
INSERT INTO "django_geo_db_zipcode" VALUES(1679,4555,-5,'Nobleboro, Maine 4555',1197,1731);
INSERT INTO "django_geo_db_zipcode" VALUES(1680,4556,-5,'Edgecomb, Maine 4556',1198,1732);
INSERT INTO "django_geo_db_zipcode" VALUES(1681,4557,-5,'Richmond, Maine 4557',1091,1733);
INSERT INTO "django_geo_db_zipcode" VALUES(1682,4558,-5,'Pemaquid, Maine 4558',1199,1734);
INSERT INTO "django_geo_db_zipcode" VALUES(1683,4562,-5,'Phippsburg, Maine 4562',1200,1735);
INSERT INTO "django_geo_db_zipcode" VALUES(1684,4563,-5,'Cushing, Maine 4563',1201,1736);
INSERT INTO "django_geo_db_zipcode" VALUES(1685,4564,-5,'Round Pond, Maine 4564',1202,1737);
INSERT INTO "django_geo_db_zipcode" VALUES(1686,4565,-5,'Sebasco Estates, Maine 4565',1203,1738);
INSERT INTO "django_geo_db_zipcode" VALUES(1687,4567,-5,'Small Point, Maine 4567',1204,1739);
INSERT INTO "django_geo_db_zipcode" VALUES(1688,4568,-5,'South Bristol, Maine 4568',1205,1740);
INSERT INTO "django_geo_db_zipcode" VALUES(1689,4570,-5,'Squirrel Island, Maine 4570',1206,1718);
INSERT INTO "django_geo_db_zipcode" VALUES(1690,4571,-5,'Trevett, Maine 4571',1207,1741);
INSERT INTO "django_geo_db_zipcode" VALUES(1691,4572,-5,'Waldoboro, Maine 4572',1208,1742);
INSERT INTO "django_geo_db_zipcode" VALUES(1692,4573,-5,'Walpole, Maine 4573',1209,1743);
INSERT INTO "django_geo_db_zipcode" VALUES(1693,4574,-5,'Washington, Maine 4574',1210,1744);
INSERT INTO "django_geo_db_zipcode" VALUES(1694,4575,-5,'West Boothbay Harbor, Maine 4575',1211,1745);
INSERT INTO "django_geo_db_zipcode" VALUES(1695,4576,-5,'Southport, Maine 4576',1212,1746);
INSERT INTO "django_geo_db_zipcode" VALUES(1696,4578,-5,'Wiscasset, Maine 4578',1213,1747);
INSERT INTO "django_geo_db_zipcode" VALUES(1697,4579,-5,'Woolwich, Maine 4579',1214,1748);
INSERT INTO "django_geo_db_zipcode" VALUES(1698,4600,-5,'Winter Harbor, Maine 4600',1215,1749);
INSERT INTO "django_geo_db_zipcode" VALUES(1699,4605,-5,'Ellsworth, Maine 4605',999,1750);
INSERT INTO "django_geo_db_zipcode" VALUES(1700,4606,-5,'Addison, Maine 4606',1216,1751);
INSERT INTO "django_geo_db_zipcode" VALUES(1701,4607,-5,'Gouldsboro, Maine 4607',1217,1752);
INSERT INTO "django_geo_db_zipcode" VALUES(1702,4609,-5,'Bar Harbor, Maine 4609',1218,1753);
INSERT INTO "django_geo_db_zipcode" VALUES(1703,4611,-5,'Beals, Maine 4611',1219,1754);
INSERT INTO "django_geo_db_zipcode" VALUES(1704,4612,-5,'Bernard, Maine 4612',1220,1755);
INSERT INTO "django_geo_db_zipcode" VALUES(1705,4613,-5,'Birch Harbor, Maine 4613',1221,1756);
INSERT INTO "django_geo_db_zipcode" VALUES(1706,4614,-5,'Blue Hill, Maine 4614',1222,1757);
INSERT INTO "django_geo_db_zipcode" VALUES(1707,4615,-5,'Blue Hill Falls, Maine 4615',1223,1758);
INSERT INTO "django_geo_db_zipcode" VALUES(1708,4616,-5,'Brooklin, Maine 4616',1224,1759);
INSERT INTO "django_geo_db_zipcode" VALUES(1709,4617,-5,'Brooksville, Maine 4617',1225,1760);
INSERT INTO "django_geo_db_zipcode" VALUES(1710,4619,-5,'Calais, Maine 4619',1226,1761);
INSERT INTO "django_geo_db_zipcode" VALUES(1711,4621,-5,'Eastport, Maine 4621',1227,1762);
INSERT INTO "django_geo_db_zipcode" VALUES(1712,4622,-5,'Cherryfield, Maine 4622',1228,1763);
INSERT INTO "django_geo_db_zipcode" VALUES(1713,4623,-5,'Columbia Falls, Maine 4623',1229,1764);
INSERT INTO "django_geo_db_zipcode" VALUES(1714,4624,-5,'Corea, Maine 4624',1230,1765);
INSERT INTO "django_geo_db_zipcode" VALUES(1715,4625,-5,'Cranberry Isles, Maine 4625',1231,1766);
INSERT INTO "django_geo_db_zipcode" VALUES(1716,4626,-5,'Cutler, Maine 4626',1232,1767);
INSERT INTO "django_geo_db_zipcode" VALUES(1717,4627,-5,'Deer Isle, Maine 4627',1233,1768);
INSERT INTO "django_geo_db_zipcode" VALUES(1718,4628,-5,'Dennysville, Maine 4628',1234,1769);
INSERT INTO "django_geo_db_zipcode" VALUES(1719,4629,-5,'East Blue Hill, Maine 4629',1235,1770);
INSERT INTO "django_geo_db_zipcode" VALUES(1720,4630,-5,'East Machias, Maine 4630',1236,1771);
INSERT INTO "django_geo_db_zipcode" VALUES(1721,4631,-5,'Eastport, Maine 4631',1227,1772);
INSERT INTO "django_geo_db_zipcode" VALUES(1722,4634,-5,'Franklin, Maine 4634',1237,1773);
INSERT INTO "django_geo_db_zipcode" VALUES(1723,4635,-5,'Frenchboro, Maine 4635',1238,1774);
INSERT INTO "django_geo_db_zipcode" VALUES(1724,4637,-5,'Grand Lake Stream, Maine 4637',1239,1775);
INSERT INTO "django_geo_db_zipcode" VALUES(1725,4640,-5,'Hancock, Maine 4640',1240,1776);
INSERT INTO "django_geo_db_zipcode" VALUES(1726,4642,-5,'Harborside, Maine 4642',1241,1777);
INSERT INTO "django_geo_db_zipcode" VALUES(1727,4643,-5,'Harrington, Maine 4643',1242,1778);
INSERT INTO "django_geo_db_zipcode" VALUES(1728,4644,-5,'Hulls Cove, Maine 4644',1243,1779);
INSERT INTO "django_geo_db_zipcode" VALUES(1729,4645,-5,'Isle Au Haut, Maine 4645',1244,1780);
INSERT INTO "django_geo_db_zipcode" VALUES(1730,4646,-5,'Islesford, Maine 4646',1245,1781);
INSERT INTO "django_geo_db_zipcode" VALUES(1731,4648,-5,'Jonesboro, Maine 4648',1246,1782);
INSERT INTO "django_geo_db_zipcode" VALUES(1732,4649,-5,'Jonesport, Maine 4649',1247,1783);
INSERT INTO "django_geo_db_zipcode" VALUES(1733,4650,-5,'Little Deer Isle, Maine 4650',1248,1784);
INSERT INTO "django_geo_db_zipcode" VALUES(1734,4652,-5,'Lubec, Maine 4652',1249,1785);
INSERT INTO "django_geo_db_zipcode" VALUES(1735,4653,-5,'Bass Harbor, Maine 4653',1250,1786);
INSERT INTO "django_geo_db_zipcode" VALUES(1736,4654,-5,'Machias, Maine 4654',1251,1787);
INSERT INTO "django_geo_db_zipcode" VALUES(1737,4655,-5,'Machiasport, Maine 4655',1252,1788);
INSERT INTO "django_geo_db_zipcode" VALUES(1738,4656,-5,'Manset, Maine 4656',1253,1779);
INSERT INTO "django_geo_db_zipcode" VALUES(1739,4657,-5,'Meddybemps, Maine 4657',1254,1789);
INSERT INTO "django_geo_db_zipcode" VALUES(1740,4658,-5,'Milbridge, Maine 4658',1255,1790);
INSERT INTO "django_geo_db_zipcode" VALUES(1741,4660,-5,'Mount Desert, Maine 4660',1256,1791);
INSERT INTO "django_geo_db_zipcode" VALUES(1742,4662,-5,'Northeast Harbor, Maine 4662',1257,1792);
INSERT INTO "django_geo_db_zipcode" VALUES(1743,4664,-5,'Sullivan, Maine 4664',1258,1793);
INSERT INTO "django_geo_db_zipcode" VALUES(1744,4665,-5,'Otter Creek, Maine 4665',1259,1779);
INSERT INTO "django_geo_db_zipcode" VALUES(1745,4666,-5,'Pembroke, Maine 4666',1260,1794);
INSERT INTO "django_geo_db_zipcode" VALUES(1746,4667,-5,'Perry, Maine 4667',1261,1795);
INSERT INTO "django_geo_db_zipcode" VALUES(1747,4668,-5,'Princeton, Maine 4668',1262,1796);
INSERT INTO "django_geo_db_zipcode" VALUES(1748,4669,-5,'Prospect Harbor, Maine 4669',1263,1797);
INSERT INTO "django_geo_db_zipcode" VALUES(1749,4671,-5,'Robbinston, Maine 4671',1264,1798);
INSERT INTO "django_geo_db_zipcode" VALUES(1750,4672,-5,'Salsbury Cove, Maine 4672',1265,1799);
INSERT INTO "django_geo_db_zipcode" VALUES(1751,4673,-5,'Sargentville, Maine 4673',1266,1800);
INSERT INTO "django_geo_db_zipcode" VALUES(1752,4674,-5,'Seal Cove, Maine 4674',1267,1801);
INSERT INTO "django_geo_db_zipcode" VALUES(1753,4675,-5,'Seal Harbor, Maine 4675',1268,1802);
INSERT INTO "django_geo_db_zipcode" VALUES(1754,4676,-5,'Sedgwick, Maine 4676',1269,1803);
INSERT INTO "django_geo_db_zipcode" VALUES(1755,4677,-5,'Sorrento, Maine 4677',1270,1804);
INSERT INTO "django_geo_db_zipcode" VALUES(1756,4679,-5,'Southwest Harbor, Maine 4679',1271,1805);
INSERT INTO "django_geo_db_zipcode" VALUES(1757,4680,-5,'Steuben, Maine 4680',1272,1806);
INSERT INTO "django_geo_db_zipcode" VALUES(1758,4681,-5,'Stonington, Maine 4681',1273,1807);
INSERT INTO "django_geo_db_zipcode" VALUES(1759,4683,-5,'Sunset, Maine 4683',1274,1808);
INSERT INTO "django_geo_db_zipcode" VALUES(1760,4684,-5,'Surry, Maine 4684',1275,1809);
INSERT INTO "django_geo_db_zipcode" VALUES(1761,4685,-5,'Swans Island, Maine 4685',1276,1810);
INSERT INTO "django_geo_db_zipcode" VALUES(1762,4686,-5,'Wesley, Maine 4686',1277,1686);
INSERT INTO "django_geo_db_zipcode" VALUES(1763,4690,-5,'West Tremont, Maine 4690',1278,1779);
INSERT INTO "django_geo_db_zipcode" VALUES(1764,4691,-5,'Whiting, Maine 4691',1279,1811);
INSERT INTO "django_geo_db_zipcode" VALUES(1765,4693,-5,'Winter Harbor, Maine 4693',1215,1812);
INSERT INTO "django_geo_db_zipcode" VALUES(1766,4694,-5,'Baileyville, Maine 4694',1280,1813);
INSERT INTO "django_geo_db_zipcode" VALUES(1767,4724,-5,'Poland, Maine 4724',1073,1814);
INSERT INTO "django_geo_db_zipcode" VALUES(1768,4730,-5,'Houlton, Maine 4730',1281,1815);
INSERT INTO "django_geo_db_zipcode" VALUES(1769,4732,-5,'Ashland, Maine 4732',1282,1816);
INSERT INTO "django_geo_db_zipcode" VALUES(1770,4733,-5,'Benedicta, Maine 4733',1283,1817);
INSERT INTO "django_geo_db_zipcode" VALUES(1771,4734,-5,'Blaine, Maine 4734',1284,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1772,4735,-5,'Bridgewater, Maine 4735',1285,1819);
INSERT INTO "django_geo_db_zipcode" VALUES(1773,4736,-5,'Caribou, Maine 4736',1286,1820);
INSERT INTO "django_geo_db_zipcode" VALUES(1774,4737,-5,'Clayton Lake, Maine 4737',1287,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1775,4738,-5,'Crouseville, Maine 4738',1288,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1776,4739,-5,'Eagle Lake, Maine 4739',1289,1821);
INSERT INTO "django_geo_db_zipcode" VALUES(1777,4740,-5,'Easton, Maine 4740',1290,1822);
INSERT INTO "django_geo_db_zipcode" VALUES(1778,4741,-5,'Estcourt Station, Maine 4741',1291,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1779,4742,-5,'Fort Fairfield, Maine 4742',1292,1823);
INSERT INTO "django_geo_db_zipcode" VALUES(1780,4743,-5,'Fort Kent, Maine 4743',1293,1824);
INSERT INTO "django_geo_db_zipcode" VALUES(1781,4744,-5,'Fort Kent Mills, Maine 4744',1294,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1782,4745,-5,'Frenchville, Maine 4745',1295,1825);
INSERT INTO "django_geo_db_zipcode" VALUES(1783,4746,-5,'Grand Isle, Maine 4746',1296,1826);
INSERT INTO "django_geo_db_zipcode" VALUES(1784,4747,-5,'Island Falls, Maine 4747',1297,1827);
INSERT INTO "django_geo_db_zipcode" VALUES(1785,4750,-5,'Limestone, Maine 4750',1298,1828);
INSERT INTO "django_geo_db_zipcode" VALUES(1786,4751,-5,'Limestone, Maine 4751',1298,1829);
INSERT INTO "django_geo_db_zipcode" VALUES(1787,4752,-5,'Ashland, Maine 4752',1282,1830);
INSERT INTO "django_geo_db_zipcode" VALUES(1788,4756,-5,'Madawaska, Maine 4756',1299,1831);
INSERT INTO "django_geo_db_zipcode" VALUES(1789,4757,-5,'Mapleton, Maine 4757',1300,1832);
INSERT INTO "django_geo_db_zipcode" VALUES(1790,4758,-5,'Mars Hill, Maine 4758',1301,1833);
INSERT INTO "django_geo_db_zipcode" VALUES(1791,4759,-5,'Masardis, Maine 4759',1302,1834);
INSERT INTO "django_geo_db_zipcode" VALUES(1792,4760,-5,'Monticello, Maine 4760',1303,1835);
INSERT INTO "django_geo_db_zipcode" VALUES(1793,4761,-5,'New Limerick, Maine 4761',1304,1836);
INSERT INTO "django_geo_db_zipcode" VALUES(1794,4762,-5,'New Sweden, Maine 4762',1305,1837);
INSERT INTO "django_geo_db_zipcode" VALUES(1795,4763,-5,'Oakfield, Maine 4763',1306,1838);
INSERT INTO "django_geo_db_zipcode" VALUES(1796,4764,-5,'Oxbow, Maine 4764',1307,1839);
INSERT INTO "django_geo_db_zipcode" VALUES(1797,4765,-5,'Patten, Maine 4765',1308,1840);
INSERT INTO "django_geo_db_zipcode" VALUES(1798,4766,-5,'Perham, Maine 4766',1309,1841);
INSERT INTO "django_geo_db_zipcode" VALUES(1799,4768,-5,'Portage, Maine 4768',1310,1842);
INSERT INTO "django_geo_db_zipcode" VALUES(1800,4769,-5,'Presque Isle, Maine 4769',1311,1843);
INSERT INTO "django_geo_db_zipcode" VALUES(1801,4770,-5,'Quimby, Maine 4770',1312,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1802,4772,-5,'Saint Agatha, Maine 4772',1313,1844);
INSERT INTO "django_geo_db_zipcode" VALUES(1803,4773,-5,'Saint David, Maine 4773',1314,1845);
INSERT INTO "django_geo_db_zipcode" VALUES(1804,4774,-5,'Saint Francis, Maine 4774',1315,1846);
INSERT INTO "django_geo_db_zipcode" VALUES(1805,4775,-5,'Sheridan, Maine 4775',1316,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1806,4776,-5,'Sherman Mills, Maine 4776',1317,1847);
INSERT INTO "django_geo_db_zipcode" VALUES(1807,4777,-5,'Sherman Station, Maine 4777',1318,1848);
INSERT INTO "django_geo_db_zipcode" VALUES(1808,4779,-5,'Sinclair, Maine 4779',1319,1849);
INSERT INTO "django_geo_db_zipcode" VALUES(1809,4780,-5,'Smyrna Mills, Maine 4780',1320,1850);
INSERT INTO "django_geo_db_zipcode" VALUES(1810,4781,-5,'Soldier Pond, Maine 4781',1321,1851);
INSERT INTO "django_geo_db_zipcode" VALUES(1811,4782,-5,'Stacyville, Maine 4782',1322,1650);
INSERT INTO "django_geo_db_zipcode" VALUES(1812,4783,-5,'Stockholm, Maine 4783',1323,1852);
INSERT INTO "django_geo_db_zipcode" VALUES(1813,4785,-5,'Van Buren, Maine 4785',1324,1853);
INSERT INTO "django_geo_db_zipcode" VALUES(1814,4786,-5,'Washburn, Maine 4786',1325,1854);
INSERT INTO "django_geo_db_zipcode" VALUES(1815,4787,-5,'Westfield, Maine 4787',1326,1855);
INSERT INTO "django_geo_db_zipcode" VALUES(1816,4788,-5,'Winterville, Maine 4788',1327,1818);
INSERT INTO "django_geo_db_zipcode" VALUES(1817,4840,-5,'Camden, Maine 4840',1328,1856);
INSERT INTO "django_geo_db_zipcode" VALUES(1818,4841,-5,'Rockland, Maine 4841',1329,1857);
INSERT INTO "django_geo_db_zipcode" VALUES(1819,4842,-5,'Owls Head, Maine 4842',1330,1858);
INSERT INTO "django_geo_db_zipcode" VALUES(1820,4843,-5,'Camden, Maine 4843',1328,1859);
INSERT INTO "django_geo_db_zipcode" VALUES(1821,4846,-5,'Glen Cove, Maine 4846',1331,1860);
INSERT INTO "django_geo_db_zipcode" VALUES(1822,4847,-5,'Hope, Maine 4847',1332,1861);
INSERT INTO "django_geo_db_zipcode" VALUES(1823,4848,-5,'Islesboro, Maine 4848',1333,1862);
INSERT INTO "django_geo_db_zipcode" VALUES(1824,4849,-5,'Lincolnville, Maine 4849',1334,1863);
INSERT INTO "django_geo_db_zipcode" VALUES(1825,4850,-5,'Lincolnville Center, Maine 4850',1335,1864);
INSERT INTO "django_geo_db_zipcode" VALUES(1826,4851,-5,'Matinicus, Maine 4851',1336,1865);
INSERT INTO "django_geo_db_zipcode" VALUES(1827,4852,-5,'Monhegan, Maine 4852',1337,1866);
INSERT INTO "django_geo_db_zipcode" VALUES(1828,4853,-5,'North Haven, Maine 4853',1338,1867);
INSERT INTO "django_geo_db_zipcode" VALUES(1829,4854,-5,'Owls Head, Maine 4854',1330,1868);
INSERT INTO "django_geo_db_zipcode" VALUES(1830,4855,-5,'Port Clyde, Maine 4855',1339,1869);
INSERT INTO "django_geo_db_zipcode" VALUES(1831,4856,-5,'Rockport, Maine 4856',1340,1870);
INSERT INTO "django_geo_db_zipcode" VALUES(1832,4857,-5,'Saint George, Maine 4857',1341,1871);
INSERT INTO "django_geo_db_zipcode" VALUES(1833,4858,-5,'South Thomaston, Maine 4858',1342,1872);
INSERT INTO "django_geo_db_zipcode" VALUES(1834,4859,-5,'Spruce Head, Maine 4859',1343,1873);
INSERT INTO "django_geo_db_zipcode" VALUES(1835,4860,-5,'Tenants Harbor, Maine 4860',1344,1874);
INSERT INTO "django_geo_db_zipcode" VALUES(1836,4861,-5,'Thomaston, Maine 4861',1345,1875);
INSERT INTO "django_geo_db_zipcode" VALUES(1837,4862,-5,'Union, Maine 4862',1346,1876);
INSERT INTO "django_geo_db_zipcode" VALUES(1838,4863,-5,'Vinalhaven, Maine 4863',1347,1877);
INSERT INTO "django_geo_db_zipcode" VALUES(1839,4864,-5,'Warren, Maine 4864',1348,1878);
INSERT INTO "django_geo_db_zipcode" VALUES(1840,4865,-5,'West Rockport, Maine 4865',1349,1879);
INSERT INTO "django_geo_db_zipcode" VALUES(1841,4901,-5,'Waterville, Maine 4901',1350,1880);
INSERT INTO "django_geo_db_zipcode" VALUES(1842,4903,-5,'Waterville, Maine 4903',1350,1881);
INSERT INTO "django_geo_db_zipcode" VALUES(1843,4910,-5,'Albion, Maine 4910',1351,1882);
INSERT INTO "django_geo_db_zipcode" VALUES(1844,4911,-5,'Anson, Maine 4911',1352,1883);
INSERT INTO "django_geo_db_zipcode" VALUES(1845,4912,-5,'Athens, Maine 4912',1353,1884);
INSERT INTO "django_geo_db_zipcode" VALUES(1846,4915,-5,'Belfast, Maine 4915',1354,1885);
INSERT INTO "django_geo_db_zipcode" VALUES(1847,4917,-5,'Belgrade, Maine 4917',1355,1886);
INSERT INTO "django_geo_db_zipcode" VALUES(1848,4918,-5,'Belgrade Lakes, Maine 4918',1356,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1849,4920,-5,'Bingham, Maine 4920',1357,1887);
INSERT INTO "django_geo_db_zipcode" VALUES(1850,4921,-5,'Brooks, Maine 4921',1358,1888);
INSERT INTO "django_geo_db_zipcode" VALUES(1851,4922,-5,'Burnham, Maine 4922',1359,1889);
INSERT INTO "django_geo_db_zipcode" VALUES(1852,4923,-5,'Cambridge, Maine 4923',1360,1890);
INSERT INTO "django_geo_db_zipcode" VALUES(1853,4924,-5,'Canaan, Maine 4924',1361,1891);
INSERT INTO "django_geo_db_zipcode" VALUES(1854,4925,-5,'Caratunk, Maine 4925',1362,1892);
INSERT INTO "django_geo_db_zipcode" VALUES(1855,4926,-5,'China, Maine 4926',1363,1893);
INSERT INTO "django_geo_db_zipcode" VALUES(1856,4927,-5,'Clinton, Maine 4927',1364,1894);
INSERT INTO "django_geo_db_zipcode" VALUES(1857,4928,-5,'Corinna, Maine 4928',1365,1895);
INSERT INTO "django_geo_db_zipcode" VALUES(1858,4929,-5,'Detroit, Maine 4929',1366,1896);
INSERT INTO "django_geo_db_zipcode" VALUES(1859,4930,-5,'Dexter, Maine 4930',1367,1897);
INSERT INTO "django_geo_db_zipcode" VALUES(1860,4932,-5,'Dixmont, Maine 4932',1368,1898);
INSERT INTO "django_geo_db_zipcode" VALUES(1861,4933,-5,'East Newport, Maine 4933',1369,1650);
INSERT INTO "django_geo_db_zipcode" VALUES(1862,4935,-5,'East Vassalboro, Maine 4935',1370,1627);
INSERT INTO "django_geo_db_zipcode" VALUES(1863,4936,-5,'Eustis, Maine 4936',1371,1899);
INSERT INTO "django_geo_db_zipcode" VALUES(1864,4937,-5,'Fairfield, Maine 4937',1372,1900);
INSERT INTO "django_geo_db_zipcode" VALUES(1865,4938,-5,'Farmington, Maine 4938',1373,1901);
INSERT INTO "django_geo_db_zipcode" VALUES(1866,4939,-5,'Garland, Maine 4939',1374,1902);
INSERT INTO "django_geo_db_zipcode" VALUES(1867,4940,-5,'Farmington Falls, Maine 4940',1375,1903);
INSERT INTO "django_geo_db_zipcode" VALUES(1868,4941,-5,'Freedom, Maine 4941',1376,1904);
INSERT INTO "django_geo_db_zipcode" VALUES(1869,4942,-5,'Harmony, Maine 4942',1377,1905);
INSERT INTO "django_geo_db_zipcode" VALUES(1870,4943,-5,'Hartland, Maine 4943',1378,1906);
INSERT INTO "django_geo_db_zipcode" VALUES(1871,4944,-5,'Hinckley, Maine 4944',1379,1907);
INSERT INTO "django_geo_db_zipcode" VALUES(1872,4945,-5,'Jackman, Maine 4945',1380,1908);
INSERT INTO "django_geo_db_zipcode" VALUES(1873,4947,-5,'Kingfield, Maine 4947',1381,1909);
INSERT INTO "django_geo_db_zipcode" VALUES(1874,4949,-5,'Liberty, Maine 4949',1382,1910);
INSERT INTO "django_geo_db_zipcode" VALUES(1875,4950,-5,'Madison, Maine 4950',1383,1911);
INSERT INTO "django_geo_db_zipcode" VALUES(1876,4951,-5,'Monroe, Maine 4951',1384,1912);
INSERT INTO "django_geo_db_zipcode" VALUES(1877,4952,-5,'Morrill, Maine 4952',1385,1913);
INSERT INTO "django_geo_db_zipcode" VALUES(1878,4953,-5,'Newport, Maine 4953',1386,1914);
INSERT INTO "django_geo_db_zipcode" VALUES(1879,4954,-5,'New Portland, Maine 4954',1387,1915);
INSERT INTO "django_geo_db_zipcode" VALUES(1880,4955,-5,'New Sharon, Maine 4955',1388,1916);
INSERT INTO "django_geo_db_zipcode" VALUES(1881,4956,-5,'New Vineyard, Maine 4956',1389,1917);
INSERT INTO "django_geo_db_zipcode" VALUES(1882,4957,-5,'Norridgewock, Maine 4957',1390,1918);
INSERT INTO "django_geo_db_zipcode" VALUES(1883,4958,-5,'North Anson, Maine 4958',1391,1919);
INSERT INTO "django_geo_db_zipcode" VALUES(1884,4961,-5,'North New Portland, Maine 4961',1392,1920);
INSERT INTO "django_geo_db_zipcode" VALUES(1885,4962,-5,'North Vassalboro, Maine 4962',1393,1921);
INSERT INTO "django_geo_db_zipcode" VALUES(1886,4963,-5,'Oakland, Maine 4963',1394,1922);
INSERT INTO "django_geo_db_zipcode" VALUES(1887,4964,-5,'Oquossoc, Maine 4964',1395,1923);
INSERT INTO "django_geo_db_zipcode" VALUES(1888,4965,-5,'Palmyra, Maine 4965',1396,1924);
INSERT INTO "django_geo_db_zipcode" VALUES(1889,4966,-5,'Phillips, Maine 4966',1397,1925);
INSERT INTO "django_geo_db_zipcode" VALUES(1890,4967,-5,'Pittsfield, Maine 4967',1398,1926);
INSERT INTO "django_geo_db_zipcode" VALUES(1891,4969,-5,'Plymouth, Maine 4969',1399,1927);
INSERT INTO "django_geo_db_zipcode" VALUES(1892,4970,-5,'Rangeley, Maine 4970',1400,1928);
INSERT INTO "django_geo_db_zipcode" VALUES(1893,4971,-5,'Saint Albans, Maine 4971',1401,1929);
INSERT INTO "django_geo_db_zipcode" VALUES(1894,4972,-5,'Sandy Point, Maine 4972',1402,1864);
INSERT INTO "django_geo_db_zipcode" VALUES(1895,4973,-5,'Searsmont, Maine 4973',1403,1930);
INSERT INTO "django_geo_db_zipcode" VALUES(1896,4974,-5,'Searsport, Maine 4974',1404,1931);
INSERT INTO "django_geo_db_zipcode" VALUES(1897,4975,-5,'Shawmut, Maine 4975',1405,1932);
INSERT INTO "django_geo_db_zipcode" VALUES(1898,4976,-5,'Skowhegan, Maine 4976',1406,1933);
INSERT INTO "django_geo_db_zipcode" VALUES(1899,4978,-5,'Smithfield, Maine 4978',1407,1934);
INSERT INTO "django_geo_db_zipcode" VALUES(1900,4979,-5,'Solon, Maine 4979',1408,1935);
INSERT INTO "django_geo_db_zipcode" VALUES(1901,4981,-5,'Stockton Springs, Maine 4981',1409,1936);
INSERT INTO "django_geo_db_zipcode" VALUES(1902,4982,-5,'Stratton, Maine 4982',1410,1937);
INSERT INTO "django_geo_db_zipcode" VALUES(1903,4983,-5,'Strong, Maine 4983',1411,1938);
INSERT INTO "django_geo_db_zipcode" VALUES(1904,4984,-5,'Temple, Maine 4984',1412,1939);
INSERT INTO "django_geo_db_zipcode" VALUES(1905,4985,-5,'West Forks, Maine 4985',1413,1940);
INSERT INTO "django_geo_db_zipcode" VALUES(1906,4986,-5,'Thorndike, Maine 4986',1414,1941);
INSERT INTO "django_geo_db_zipcode" VALUES(1907,4987,-5,'Troy, Maine 4987',1415,1942);
INSERT INTO "django_geo_db_zipcode" VALUES(1908,4988,-5,'Unity, Maine 4988',1416,1943);
INSERT INTO "django_geo_db_zipcode" VALUES(1909,4989,-5,'Vassalboro, Maine 4989',1417,1944);
INSERT INTO "django_geo_db_zipcode" VALUES(1910,4992,-5,'West Farmington, Maine 4992',1418,1945);
INSERT INTO "django_geo_db_zipcode" VALUES(1911,5001,-5,'White River Junction, Vermont 5001',1419,1946);
INSERT INTO "django_geo_db_zipcode" VALUES(1912,5009,-5,'White River Junction, Vermont 5009',1419,1947);
INSERT INTO "django_geo_db_zipcode" VALUES(1913,5030,-5,'Ascutney, Vermont 5030',1420,1948);
INSERT INTO "django_geo_db_zipcode" VALUES(1914,5031,-5,'Barnard, Vermont 5031',1421,1949);
INSERT INTO "django_geo_db_zipcode" VALUES(1915,5032,-5,'Bethel, Vermont 5032',1422,1950);
INSERT INTO "django_geo_db_zipcode" VALUES(1916,5033,-5,'Bradford, Vermont 5033',1423,1951);
INSERT INTO "django_geo_db_zipcode" VALUES(1917,5034,-5,'Bridgewater, Vermont 5034',1424,1952);
INSERT INTO "django_geo_db_zipcode" VALUES(1918,5035,-5,'Bridgewater Corners, Vermont 5035',1425,1953);
INSERT INTO "django_geo_db_zipcode" VALUES(1919,5036,-5,'Brookfield, Vermont 5036',1426,1954);
INSERT INTO "django_geo_db_zipcode" VALUES(1920,5037,-5,'Brownsville, Vermont 5037',1427,1955);
INSERT INTO "django_geo_db_zipcode" VALUES(1921,5038,-5,'Chelsea, Vermont 5038',1428,1956);
INSERT INTO "django_geo_db_zipcode" VALUES(1922,5039,-5,'Corinth, Vermont 5039',1429,1957);
INSERT INTO "django_geo_db_zipcode" VALUES(1923,5040,-5,'East Corinth, Vermont 5040',1430,1958);
INSERT INTO "django_geo_db_zipcode" VALUES(1924,5041,-5,'East Randolph, Vermont 5041',1431,1959);
INSERT INTO "django_geo_db_zipcode" VALUES(1925,5042,-5,'East Ryegate, Vermont 5042',1432,1960);
INSERT INTO "django_geo_db_zipcode" VALUES(1926,5043,-5,'East Thetford, Vermont 5043',1433,1961);
INSERT INTO "django_geo_db_zipcode" VALUES(1927,5045,-5,'Fairlee, Vermont 5045',1434,1962);
INSERT INTO "django_geo_db_zipcode" VALUES(1928,5046,-5,'Groton, Vermont 5046',1435,1963);
INSERT INTO "django_geo_db_zipcode" VALUES(1929,5047,-5,'Hartford, Vermont 5047',1436,1964);
INSERT INTO "django_geo_db_zipcode" VALUES(1930,5048,-5,'Hartland, Vermont 5048',1437,1965);
INSERT INTO "django_geo_db_zipcode" VALUES(1931,5049,-5,'Hartland Four Corners, Vermont 5049',1438,1947);
INSERT INTO "django_geo_db_zipcode" VALUES(1932,5050,-5,'McIndoe Falls, Vermont 5050',1439,1966);
INSERT INTO "django_geo_db_zipcode" VALUES(1933,5051,-5,'Newbury, Vermont 5051',1440,1967);
INSERT INTO "django_geo_db_zipcode" VALUES(1934,5052,-5,'North Hartland, Vermont 5052',1441,1968);
INSERT INTO "django_geo_db_zipcode" VALUES(1935,5053,-5,'North Pomfret, Vermont 5053',1442,1969);
INSERT INTO "django_geo_db_zipcode" VALUES(1936,5054,-5,'North Thetford, Vermont 5054',1443,1970);
INSERT INTO "django_geo_db_zipcode" VALUES(1937,5055,-5,'Norwich, Vermont 5055',1444,1971);
INSERT INTO "django_geo_db_zipcode" VALUES(1938,5056,-5,'Plymouth, Vermont 5056',1445,1972);
INSERT INTO "django_geo_db_zipcode" VALUES(1939,5058,-5,'Post Mills, Vermont 5058',1446,1973);
INSERT INTO "django_geo_db_zipcode" VALUES(1940,5059,-5,'Quechee, Vermont 5059',1447,1974);
INSERT INTO "django_geo_db_zipcode" VALUES(1941,5060,-5,'Randolph, Vermont 5060',1448,1975);
INSERT INTO "django_geo_db_zipcode" VALUES(1942,5061,-5,'Randolph Center, Vermont 5061',1449,1976);
INSERT INTO "django_geo_db_zipcode" VALUES(1943,5062,-5,'Reading, Vermont 5062',1450,1977);
INSERT INTO "django_geo_db_zipcode" VALUES(1944,5065,-5,'Sharon, Vermont 5065',1451,1978);
INSERT INTO "django_geo_db_zipcode" VALUES(1945,5067,-5,'South Pomfret, Vermont 5067',1452,1979);
INSERT INTO "django_geo_db_zipcode" VALUES(1946,5068,-5,'South Royalton, Vermont 5068',1453,1980);
INSERT INTO "django_geo_db_zipcode" VALUES(1947,5069,-5,'South Ryegate, Vermont 5069',1454,1981);
INSERT INTO "django_geo_db_zipcode" VALUES(1948,5070,-5,'South Strafford, Vermont 5070',1455,1982);
INSERT INTO "django_geo_db_zipcode" VALUES(1949,5071,-5,'South Woodstock, Vermont 5071',1456,1983);
INSERT INTO "django_geo_db_zipcode" VALUES(1950,5072,-5,'Strafford, Vermont 5072',1457,1984);
INSERT INTO "django_geo_db_zipcode" VALUES(1951,5073,-5,'Taftsville, Vermont 5073',1458,1985);
INSERT INTO "django_geo_db_zipcode" VALUES(1952,5074,-5,'Thetford, Vermont 5074',1459,1986);
INSERT INTO "django_geo_db_zipcode" VALUES(1953,5075,-5,'Thetford Center, Vermont 5075',1460,1987);
INSERT INTO "django_geo_db_zipcode" VALUES(1954,5076,-5,'East Corinth, Vermont 5076',1430,1988);
INSERT INTO "django_geo_db_zipcode" VALUES(1955,5077,-5,'Tunbridge, Vermont 5077',1461,1989);
INSERT INTO "django_geo_db_zipcode" VALUES(1956,5079,-5,'Vershire, Vermont 5079',1462,1990);
INSERT INTO "django_geo_db_zipcode" VALUES(1957,5080,-5,'Hartford, Vermont 5080',1436,1991);
INSERT INTO "django_geo_db_zipcode" VALUES(1958,5081,-5,'Wells River, Vermont 5081',1463,1992);
INSERT INTO "django_geo_db_zipcode" VALUES(1959,5083,-5,'West Fairlee, Vermont 5083',1464,1993);
INSERT INTO "django_geo_db_zipcode" VALUES(1960,5084,-5,'West Hartford, Vermont 5084',1465,1994);
INSERT INTO "django_geo_db_zipcode" VALUES(1961,5085,-5,'West Newbury, Vermont 5085',1466,1995);
INSERT INTO "django_geo_db_zipcode" VALUES(1962,5086,-5,'West Topsham, Vermont 5086',1467,1996);
INSERT INTO "django_geo_db_zipcode" VALUES(1963,5088,-5,'Wilder, Vermont 5088',1468,1997);
INSERT INTO "django_geo_db_zipcode" VALUES(1964,5089,-5,'Windsor, Vermont 5089',1469,1998);
INSERT INTO "django_geo_db_zipcode" VALUES(1965,5091,-5,'Woodstock, Vermont 5091',1470,1999);
INSERT INTO "django_geo_db_zipcode" VALUES(1966,5101,-5,'Bellows Falls, Vermont 5101',1471,2000);
INSERT INTO "django_geo_db_zipcode" VALUES(1967,5124,-5,'Cavendish, Vermont 5124',1472,2001);
INSERT INTO "django_geo_db_zipcode" VALUES(1968,5141,-5,'Cambridgeport, Vermont 5141',1473,2002);
INSERT INTO "django_geo_db_zipcode" VALUES(1969,5142,-5,'Cavendish, Vermont 5142',1472,2003);
INSERT INTO "django_geo_db_zipcode" VALUES(1970,5143,-5,'Chester, Vermont 5143',1474,2004);
INSERT INTO "django_geo_db_zipcode" VALUES(1971,5144,-5,'Chester Depot, Vermont 5144',1475,1947);
INSERT INTO "django_geo_db_zipcode" VALUES(1972,5146,-5,'Grafton, Vermont 5146',1476,2005);
INSERT INTO "django_geo_db_zipcode" VALUES(1973,5148,-5,'Londonderry, Vermont 5148',1477,2006);
INSERT INTO "django_geo_db_zipcode" VALUES(1974,5149,-5,'Ludlow, Vermont 5149',1478,2007);
INSERT INTO "django_geo_db_zipcode" VALUES(1975,5150,-5,'North Springfield, Vermont 5150',1479,2008);
INSERT INTO "django_geo_db_zipcode" VALUES(1976,5151,-5,'Perkinsville, Vermont 5151',1480,2009);
INSERT INTO "django_geo_db_zipcode" VALUES(1977,5152,-5,'Peru, Vermont 5152',1481,2010);
INSERT INTO "django_geo_db_zipcode" VALUES(1978,5153,-5,'Proctorsville, Vermont 5153',1482,2011);
INSERT INTO "django_geo_db_zipcode" VALUES(1979,5154,-5,'Saxtons River, Vermont 5154',1483,2012);
INSERT INTO "django_geo_db_zipcode" VALUES(1980,5155,-5,'South Londonderry, Vermont 5155',1484,2013);
INSERT INTO "django_geo_db_zipcode" VALUES(1981,5156,-5,'Springfield, Vermont 5156',1485,2014);
INSERT INTO "django_geo_db_zipcode" VALUES(1982,5158,-5,'Westminster, Vermont 5158',1486,2015);
INSERT INTO "django_geo_db_zipcode" VALUES(1983,5159,-5,'Westminster Station, Vermont 5159',1487,2016);
INSERT INTO "django_geo_db_zipcode" VALUES(1984,5161,-5,'Weston, Vermont 5161',1488,2017);
INSERT INTO "django_geo_db_zipcode" VALUES(1985,5201,-5,'Bennington, Vermont 5201',1489,2018);
INSERT INTO "django_geo_db_zipcode" VALUES(1986,5210,-5,'Woodford, Vermont 5210',1490,2019);
INSERT INTO "django_geo_db_zipcode" VALUES(1987,5219,-5,'Barnet, Vermont 5219',1491,2020);
INSERT INTO "django_geo_db_zipcode" VALUES(1988,5233,-5,'Sudbury, Vermont 5233',1492,2021);
INSERT INTO "django_geo_db_zipcode" VALUES(1989,5250,-5,'Arlington, Vermont 5250',1493,2022);
INSERT INTO "django_geo_db_zipcode" VALUES(1990,5251,-5,'Dorset, Vermont 5251',1494,2023);
INSERT INTO "django_geo_db_zipcode" VALUES(1991,5252,-5,'East Arlington, Vermont 5252',1495,2024);
INSERT INTO "django_geo_db_zipcode" VALUES(1992,5253,-5,'East Dorset, Vermont 5253',1496,2025);
INSERT INTO "django_geo_db_zipcode" VALUES(1993,5254,-5,'Manchester, Vermont 5254',1497,2026);
INSERT INTO "django_geo_db_zipcode" VALUES(1994,5255,-5,'Manchester Center, Vermont 5255',1498,2027);
INSERT INTO "django_geo_db_zipcode" VALUES(1995,5257,-5,'North Bennington, Vermont 5257',1499,2028);
INSERT INTO "django_geo_db_zipcode" VALUES(1996,5260,-5,'North Pownal, Vermont 5260',1500,2029);
INSERT INTO "django_geo_db_zipcode" VALUES(1997,5261,-5,'Pownal, Vermont 5261',1501,2030);
INSERT INTO "django_geo_db_zipcode" VALUES(1998,5262,-5,'Shaftsbury, Vermont 5262',1502,2031);
INSERT INTO "django_geo_db_zipcode" VALUES(1999,5267,-5,'Sutton, Vermont 5267',1503,2032);
INSERT INTO "django_geo_db_zipcode" VALUES(2000,5286,-5,'Craftsbury, Vermont 5286',1504,2033);
INSERT INTO "django_geo_db_zipcode" VALUES(2001,5301,-5,'Brattleboro, Vermont 5301',1505,2034);
INSERT INTO "django_geo_db_zipcode" VALUES(2002,5302,-5,'Brattleboro, Vermont 5302',1505,2002);
INSERT INTO "django_geo_db_zipcode" VALUES(2003,5303,-5,'Brattleboro, Vermont 5303',1505,2002);
INSERT INTO "django_geo_db_zipcode" VALUES(2004,5304,-5,'Brattleboro, Vermont 5304',1505,2002);
INSERT INTO "django_geo_db_zipcode" VALUES(2005,5340,-5,'Bondville, Vermont 5340',1506,2035);
INSERT INTO "django_geo_db_zipcode" VALUES(2006,5341,-5,'East Dover, Vermont 5341',1507,2036);
INSERT INTO "django_geo_db_zipcode" VALUES(2007,5342,-5,'Jacksonville, Vermont 5342',1508,2037);
INSERT INTO "django_geo_db_zipcode" VALUES(2008,5343,-5,'Jamaica, Vermont 5343',1509,2038);
INSERT INTO "django_geo_db_zipcode" VALUES(2009,5344,-5,'Marlboro, Vermont 5344',1510,2039);
INSERT INTO "django_geo_db_zipcode" VALUES(2010,5345,-5,'Newfane, Vermont 5345',1511,2040);
INSERT INTO "django_geo_db_zipcode" VALUES(2011,5346,-5,'Putney, Vermont 5346',1512,2041);
INSERT INTO "django_geo_db_zipcode" VALUES(2012,5350,-5,'Readsboro, Vermont 5350',1513,2042);
INSERT INTO "django_geo_db_zipcode" VALUES(2013,5351,-5,'South Newfane, Vermont 5351',1514,2043);
INSERT INTO "django_geo_db_zipcode" VALUES(2014,5352,-5,'Readsboro, Vermont 5352',1513,2044);
INSERT INTO "django_geo_db_zipcode" VALUES(2015,5353,-5,'Townshend, Vermont 5353',1515,2045);
INSERT INTO "django_geo_db_zipcode" VALUES(2016,5354,-5,'Vernon, Vermont 5354',1516,2046);
INSERT INTO "django_geo_db_zipcode" VALUES(2017,5355,-5,'Wardsboro, Vermont 5355',1517,2047);
INSERT INTO "django_geo_db_zipcode" VALUES(2018,5356,-5,'West Dover, Vermont 5356',1518,2048);
INSERT INTO "django_geo_db_zipcode" VALUES(2019,5357,-5,'West Dummerston, Vermont 5357',1519,2049);
INSERT INTO "django_geo_db_zipcode" VALUES(2020,5358,-5,'West Halifax, Vermont 5358',1520,2050);
INSERT INTO "django_geo_db_zipcode" VALUES(2021,5359,-5,'West Townshend, Vermont 5359',1521,2051);
INSERT INTO "django_geo_db_zipcode" VALUES(2022,5360,-5,'West Wardsboro, Vermont 5360',1522,2052);
INSERT INTO "django_geo_db_zipcode" VALUES(2023,5361,-5,'Whitingham, Vermont 5361',1523,2053);
INSERT INTO "django_geo_db_zipcode" VALUES(2024,5362,-5,'Williamsville, Vermont 5362',1524,2054);
INSERT INTO "django_geo_db_zipcode" VALUES(2025,5363,-5,'Wilmington, Vermont 5363',1525,2055);
INSERT INTO "django_geo_db_zipcode" VALUES(2026,5364,-5,'Westminster, Vermont 5364',1486,2056);
INSERT INTO "django_geo_db_zipcode" VALUES(2027,5401,-5,'Burlington, Vermont 5401',1526,2057);
INSERT INTO "django_geo_db_zipcode" VALUES(2028,5402,-5,'Burlington, Vermont 5402',1526,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2029,5403,-5,'South Burlington, Vermont 5403',1527,2059);
INSERT INTO "django_geo_db_zipcode" VALUES(2030,5404,-5,'Winooski, Vermont 5404',1528,2060);
INSERT INTO "django_geo_db_zipcode" VALUES(2031,5405,-5,'Burlington, Vermont 5405',1526,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2032,5406,-5,'Burlington, Vermont 5406',1526,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2033,5407,-5,'South Burlington, Vermont 5407',1527,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2034,5418,-5,'Fletcher, Vermont 5418',1529,2061);
INSERT INTO "django_geo_db_zipcode" VALUES(2035,5433,-5,'Lincoln, Vermont 5433',1530,2062);
INSERT INTO "django_geo_db_zipcode" VALUES(2036,5439,-5,'Colchester, Vermont 5439',1531,2063);
INSERT INTO "django_geo_db_zipcode" VALUES(2037,5440,-5,'Alburg, Vermont 5440',1532,2064);
INSERT INTO "django_geo_db_zipcode" VALUES(2038,5441,-5,'Bakersfield, Vermont 5441',1533,2065);
INSERT INTO "django_geo_db_zipcode" VALUES(2039,5442,-5,'Belvidere Center, Vermont 5442',1534,2066);
INSERT INTO "django_geo_db_zipcode" VALUES(2040,5443,-5,'Bristol, Vermont 5443',1535,2067);
INSERT INTO "django_geo_db_zipcode" VALUES(2041,5444,-5,'Cambridge, Vermont 5444',1536,2068);
INSERT INTO "django_geo_db_zipcode" VALUES(2042,5445,-5,'Charlotte, Vermont 5445',1537,2069);
INSERT INTO "django_geo_db_zipcode" VALUES(2043,5446,-5,'Colchester, Vermont 5446',1531,2070);
INSERT INTO "django_geo_db_zipcode" VALUES(2044,5447,-5,'East Berkshire, Vermont 5447',1538,2071);
INSERT INTO "django_geo_db_zipcode" VALUES(2045,5448,-5,'East Fairfield, Vermont 5448',1539,2072);
INSERT INTO "django_geo_db_zipcode" VALUES(2046,5449,-5,'Colchester, Vermont 5449',1531,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2047,5450,-5,'Enosburg Falls, Vermont 5450',1540,2073);
INSERT INTO "django_geo_db_zipcode" VALUES(2048,5451,-5,'Essex, Vermont 5451',1541,2074);
INSERT INTO "django_geo_db_zipcode" VALUES(2049,5452,-5,'Essex Junction, Vermont 5452',1542,2075);
INSERT INTO "django_geo_db_zipcode" VALUES(2050,5453,-5,'Essex Junction, Vermont 5453',1542,2058);
INSERT INTO "django_geo_db_zipcode" VALUES(2051,5454,-5,'Fairfax, Vermont 5454',1543,2076);
INSERT INTO "django_geo_db_zipcode" VALUES(2052,5455,-5,'Fairfield, Vermont 5455',1544,2077);
INSERT INTO "django_geo_db_zipcode" VALUES(2053,5456,-5,'Ferrisburg, Vermont 5456',1545,2078);
INSERT INTO "django_geo_db_zipcode" VALUES(2054,5457,-5,'Franklin, Vermont 5457',1546,2079);
INSERT INTO "django_geo_db_zipcode" VALUES(2055,5458,-5,'Grand Isle, Vermont 5458',1547,2080);
INSERT INTO "django_geo_db_zipcode" VALUES(2056,5459,-5,'Highgate Center, Vermont 5459',1548,2081);
INSERT INTO "django_geo_db_zipcode" VALUES(2057,5460,-5,'Highgate Springs, Vermont 5460',1549,2082);
INSERT INTO "django_geo_db_zipcode" VALUES(2058,5461,-5,'Hinesburg, Vermont 5461',1550,2083);
INSERT INTO "django_geo_db_zipcode" VALUES(2059,5462,-5,'Huntington, Vermont 5462',1551,2084);
INSERT INTO "django_geo_db_zipcode" VALUES(2060,5463,-5,'Isle La Motte, Vermont 5463',1552,2085);
INSERT INTO "django_geo_db_zipcode" VALUES(2061,5464,-5,'Jeffersonville, Vermont 5464',1553,2086);
INSERT INTO "django_geo_db_zipcode" VALUES(2062,5465,-5,'Jericho, Vermont 5465',1554,2087);
INSERT INTO "django_geo_db_zipcode" VALUES(2063,5466,-5,'Jonesville, Vermont 5466',1555,2088);
INSERT INTO "django_geo_db_zipcode" VALUES(2064,5468,-5,'Milton, Vermont 5468',1556,2089);
INSERT INTO "django_geo_db_zipcode" VALUES(2065,5469,-5,'Monkton, Vermont 5469',1557,2090);
INSERT INTO "django_geo_db_zipcode" VALUES(2066,5470,-5,'Montgomery, Vermont 5470',1558,2071);
INSERT INTO "django_geo_db_zipcode" VALUES(2067,5471,-5,'Montgomery Center, Vermont 5471',1559,2091);
INSERT INTO "django_geo_db_zipcode" VALUES(2068,5472,-5,'New Haven, Vermont 5472',1560,2092);
INSERT INTO "django_geo_db_zipcode" VALUES(2069,5473,-5,'North Ferrisburg, Vermont 5473',1561,2093);
INSERT INTO "django_geo_db_zipcode" VALUES(2070,5474,-5,'North Hero, Vermont 5474',1562,2094);
INSERT INTO "django_geo_db_zipcode" VALUES(2071,5476,-5,'Richford, Vermont 5476',1563,2095);
INSERT INTO "django_geo_db_zipcode" VALUES(2072,5477,-5,'Richmond, Vermont 5477',1564,2096);
INSERT INTO "django_geo_db_zipcode" VALUES(2073,5478,-5,'Saint Albans, Vermont 5478',1565,2097);
INSERT INTO "django_geo_db_zipcode" VALUES(2074,5479,-5,'Saint Albans, Vermont 5479',1565,2071);
INSERT INTO "django_geo_db_zipcode" VALUES(2075,5481,-5,'Saint Albans Bay, Vermont 5481',1566,2071);
INSERT INTO "django_geo_db_zipcode" VALUES(2076,5482,-5,'Shelburne, Vermont 5482',1567,2098);
INSERT INTO "django_geo_db_zipcode" VALUES(2077,5483,-5,'Sheldon, Vermont 5483',1568,2099);
INSERT INTO "django_geo_db_zipcode" VALUES(2078,5485,-5,'Sheldon Springs, Vermont 5485',1569,2100);
INSERT INTO "django_geo_db_zipcode" VALUES(2079,5486,-5,'South Hero, Vermont 5486',1570,2101);
INSERT INTO "django_geo_db_zipcode" VALUES(2080,5487,-5,'Starksboro, Vermont 5487',1571,2102);
INSERT INTO "django_geo_db_zipcode" VALUES(2081,5488,-5,'Swanton, Vermont 5488',1572,2103);
INSERT INTO "django_geo_db_zipcode" VALUES(2082,5489,-5,'Underhill, Vermont 5489',1573,2104);
INSERT INTO "django_geo_db_zipcode" VALUES(2083,5490,-5,'Underhill Center, Vermont 5490',1574,2105);
INSERT INTO "django_geo_db_zipcode" VALUES(2084,5491,-5,'Vergennes, Vermont 5491',1575,2106);
INSERT INTO "django_geo_db_zipcode" VALUES(2085,5492,-5,'Waterville, Vermont 5492',1576,2107);
INSERT INTO "django_geo_db_zipcode" VALUES(2086,5494,-5,'Westford, Vermont 5494',1577,2108);
INSERT INTO "django_geo_db_zipcode" VALUES(2087,5495,-5,'Williston, Vermont 5495',1578,2109);
INSERT INTO "django_geo_db_zipcode" VALUES(2088,5501,-5,'Andover, Massachusetts 5501',342,741);
INSERT INTO "django_geo_db_zipcode" VALUES(2089,5544,-5,'Andover, Massachusetts 5544',342,741);
INSERT INTO "django_geo_db_zipcode" VALUES(2090,5601,-5,'Montpelier, Vermont 5601',1579,2110);
INSERT INTO "django_geo_db_zipcode" VALUES(2091,5602,-5,'Montpelier, Vermont 5602',1579,2111);
INSERT INTO "django_geo_db_zipcode" VALUES(2092,5603,-5,'Montpelier, Vermont 5603',1579,2112);
INSERT INTO "django_geo_db_zipcode" VALUES(2093,5604,-5,'Montpelier, Vermont 5604',1579,2113);
INSERT INTO "django_geo_db_zipcode" VALUES(2094,5609,-5,'Montpelier, Vermont 5609',1579,2113);
INSERT INTO "django_geo_db_zipcode" VALUES(2095,5620,-5,'Montpelier, Vermont 5620',1579,2113);
INSERT INTO "django_geo_db_zipcode" VALUES(2096,5626,-5,'Waterbury, Vermont 5626',1580,2114);
INSERT INTO "django_geo_db_zipcode" VALUES(2097,5633,-5,'Montpelier, Vermont 5633',1579,2113);
INSERT INTO "django_geo_db_zipcode" VALUES(2098,5640,-5,'Adamant, Vermont 5640',1581,2115);
INSERT INTO "django_geo_db_zipcode" VALUES(2099,5641,-5,'Barre, Vermont 5641',1582,2116);
INSERT INTO "django_geo_db_zipcode" VALUES(2100,5647,-5,'Cabot, Vermont 5647',1583,2117);
INSERT INTO "django_geo_db_zipcode" VALUES(2101,5648,-5,'Calais, Vermont 5648',1584,2118);
INSERT INTO "django_geo_db_zipcode" VALUES(2102,5649,-5,'East Barre, Vermont 5649',1585,2119);
INSERT INTO "django_geo_db_zipcode" VALUES(2103,5650,-5,'East Calais, Vermont 5650',1586,2120);
INSERT INTO "django_geo_db_zipcode" VALUES(2104,5651,-5,'East Montpelier, Vermont 5651',1587,2121);
INSERT INTO "django_geo_db_zipcode" VALUES(2105,5652,-5,'Eden, Vermont 5652',1588,2122);
INSERT INTO "django_geo_db_zipcode" VALUES(2106,5653,-5,'Eden Mills, Vermont 5653',1589,2123);
INSERT INTO "django_geo_db_zipcode" VALUES(2107,5654,-5,'Graniteville, Vermont 5654',1590,2124);
INSERT INTO "django_geo_db_zipcode" VALUES(2108,5655,-5,'Hyde Park, Vermont 5655',1591,2125);
INSERT INTO "django_geo_db_zipcode" VALUES(2109,5656,-5,'Johnson, Vermont 5656',1592,2126);
INSERT INTO "django_geo_db_zipcode" VALUES(2110,5657,-5,'Lake Elmore, Vermont 5657',1593,2127);
INSERT INTO "django_geo_db_zipcode" VALUES(2111,5658,-5,'Marshfield, Vermont 5658',1594,2128);
INSERT INTO "django_geo_db_zipcode" VALUES(2112,5660,-5,'Moretown, Vermont 5660',1595,2129);
INSERT INTO "django_geo_db_zipcode" VALUES(2113,5661,-5,'Morrisville, Vermont 5661',1596,2130);
INSERT INTO "django_geo_db_zipcode" VALUES(2114,5662,-5,'Moscow, Vermont 5662',1597,2131);
INSERT INTO "django_geo_db_zipcode" VALUES(2115,5663,-5,'Northfield, Vermont 5663',1598,2132);
INSERT INTO "django_geo_db_zipcode" VALUES(2116,5664,-5,'Northfield Falls, Vermont 5664',1599,2133);
INSERT INTO "django_geo_db_zipcode" VALUES(2117,5665,-5,'North Hyde Park, Vermont 5665',1600,2134);
INSERT INTO "django_geo_db_zipcode" VALUES(2118,5666,-5,'North Montpelier, Vermont 5666',1601,2135);
INSERT INTO "django_geo_db_zipcode" VALUES(2119,5667,-5,'Plainfield, Vermont 5667',1602,2136);
INSERT INTO "django_geo_db_zipcode" VALUES(2120,5669,-5,'Roxbury, Vermont 5669',1603,2137);
INSERT INTO "django_geo_db_zipcode" VALUES(2121,5670,-5,'South Barre, Vermont 5670',1604,2138);
INSERT INTO "django_geo_db_zipcode" VALUES(2122,5671,-5,'Waterbury, Vermont 5671',1580,2113);
INSERT INTO "django_geo_db_zipcode" VALUES(2123,5672,-5,'Stowe, Vermont 5672',1605,2139);
INSERT INTO "django_geo_db_zipcode" VALUES(2124,5673,-5,'Waitsfield, Vermont 5673',1606,2140);
INSERT INTO "django_geo_db_zipcode" VALUES(2125,5674,-5,'Warren, Vermont 5674',1607,2141);
INSERT INTO "django_geo_db_zipcode" VALUES(2126,5675,-5,'Washington, Vermont 5675',1608,2142);
INSERT INTO "django_geo_db_zipcode" VALUES(2127,5676,-5,'Waterbury, Vermont 5676',1580,2143);
INSERT INTO "django_geo_db_zipcode" VALUES(2128,5677,-5,'Waterbury Center, Vermont 5677',1609,2144);
INSERT INTO "django_geo_db_zipcode" VALUES(2129,5678,-5,'Websterville, Vermont 5678',1610,2145);
INSERT INTO "django_geo_db_zipcode" VALUES(2130,5679,-5,'Williamstown, Vermont 5679',1611,2146);
INSERT INTO "django_geo_db_zipcode" VALUES(2131,5680,-5,'Wolcott, Vermont 5680',1612,2147);
INSERT INTO "django_geo_db_zipcode" VALUES(2132,5681,-5,'Woodbury, Vermont 5681',1613,2148);
INSERT INTO "django_geo_db_zipcode" VALUES(2133,5682,-5,'Worcester, Vermont 5682',1614,2149);
INSERT INTO "django_geo_db_zipcode" VALUES(2134,5701,-5,'Rutland, Vermont 5701',1615,2150);
INSERT INTO "django_geo_db_zipcode" VALUES(2135,5702,-5,'Rutland, Vermont 5702',1615,2151);
INSERT INTO "django_geo_db_zipcode" VALUES(2136,5730,-5,'Belmont, Vermont 5730',1616,2152);
INSERT INTO "django_geo_db_zipcode" VALUES(2137,5731,-5,'Benson, Vermont 5731',1617,2153);
INSERT INTO "django_geo_db_zipcode" VALUES(2138,5732,-5,'Bomoseen, Vermont 5732',1618,2154);
INSERT INTO "django_geo_db_zipcode" VALUES(2139,5733,-5,'Brandon, Vermont 5733',1619,2155);
INSERT INTO "django_geo_db_zipcode" VALUES(2140,5734,-5,'Bridport, Vermont 5734',1620,2156);
INSERT INTO "django_geo_db_zipcode" VALUES(2141,5735,-5,'Castleton, Vermont 5735',1621,2157);
INSERT INTO "django_geo_db_zipcode" VALUES(2142,5736,-5,'Center Rutland, Vermont 5736',1622,2158);
INSERT INTO "django_geo_db_zipcode" VALUES(2143,5737,-5,'Chittenden, Vermont 5737',1623,2159);
INSERT INTO "django_geo_db_zipcode" VALUES(2144,5738,-5,'Cuttingsville, Vermont 5738',1624,2160);
INSERT INTO "django_geo_db_zipcode" VALUES(2145,5739,-5,'Danby, Vermont 5739',1625,2161);
INSERT INTO "django_geo_db_zipcode" VALUES(2146,5740,-5,'East Middlebury, Vermont 5740',1626,2162);
INSERT INTO "django_geo_db_zipcode" VALUES(2147,5741,-5,'East Poultney, Vermont 5741',1627,2163);
INSERT INTO "django_geo_db_zipcode" VALUES(2148,5742,-5,'East Wallingford, Vermont 5742',1628,2164);
INSERT INTO "django_geo_db_zipcode" VALUES(2149,5743,-5,'Fair Haven, Vermont 5743',1629,2165);
INSERT INTO "django_geo_db_zipcode" VALUES(2150,5744,-5,'Florence, Vermont 5744',1630,2166);
INSERT INTO "django_geo_db_zipcode" VALUES(2151,5745,-5,'Forest Dale, Vermont 5745',1631,2163);
INSERT INTO "django_geo_db_zipcode" VALUES(2152,5746,-5,'Gaysville, Vermont 5746',1632,2167);
INSERT INTO "django_geo_db_zipcode" VALUES(2153,5747,-5,'Granville, Vermont 5747',1633,2168);
INSERT INTO "django_geo_db_zipcode" VALUES(2154,5748,-5,'Hancock, Vermont 5748',1634,2169);
INSERT INTO "django_geo_db_zipcode" VALUES(2155,5750,-5,'Hydeville, Vermont 5750',1635,2170);
INSERT INTO "django_geo_db_zipcode" VALUES(2156,5751,-5,'Killington, Vermont 5751',1636,2171);
INSERT INTO "django_geo_db_zipcode" VALUES(2157,5752,-5,'Poultney, Vermont 5752',1637,2172);
INSERT INTO "django_geo_db_zipcode" VALUES(2158,5753,-5,'Middlebury, Vermont 5753',1638,2173);
INSERT INTO "django_geo_db_zipcode" VALUES(2159,5757,-5,'Middletown Springs, Vermont 5757',1639,2174);
INSERT INTO "django_geo_db_zipcode" VALUES(2160,5758,-5,'Mount Holly, Vermont 5758',1640,2175);
INSERT INTO "django_geo_db_zipcode" VALUES(2161,5759,-5,'North Clarendon, Vermont 5759',1641,2176);
INSERT INTO "django_geo_db_zipcode" VALUES(2162,5760,-5,'Orwell, Vermont 5760',1642,2177);
INSERT INTO "django_geo_db_zipcode" VALUES(2163,5761,-5,'Pawlet, Vermont 5761',1643,2178);
INSERT INTO "django_geo_db_zipcode" VALUES(2164,5762,-5,'Pittsfield, Vermont 5762',1644,2179);
INSERT INTO "django_geo_db_zipcode" VALUES(2165,5763,-5,'Pittsford, Vermont 5763',1645,2180);
INSERT INTO "django_geo_db_zipcode" VALUES(2166,5764,-5,'Poultney, Vermont 5764',1637,2181);
INSERT INTO "django_geo_db_zipcode" VALUES(2167,5765,-5,'Proctor, Vermont 5765',1646,2182);
INSERT INTO "django_geo_db_zipcode" VALUES(2168,5766,-5,'Ripton, Vermont 5766',1647,2183);
INSERT INTO "django_geo_db_zipcode" VALUES(2169,5767,-5,'Rochester, Vermont 5767',1648,2184);
INSERT INTO "django_geo_db_zipcode" VALUES(2170,5768,-5,'Rupert, Vermont 5768',1649,2185);
INSERT INTO "django_geo_db_zipcode" VALUES(2171,5769,-5,'Salisbury, Vermont 5769',1650,2186);
INSERT INTO "django_geo_db_zipcode" VALUES(2172,5770,-5,'Shoreham, Vermont 5770',1651,2187);
INSERT INTO "django_geo_db_zipcode" VALUES(2173,5772,-5,'Stockbridge, Vermont 5772',1652,2188);
INSERT INTO "django_geo_db_zipcode" VALUES(2174,5773,-5,'Wallingford, Vermont 5773',1653,2189);
INSERT INTO "django_geo_db_zipcode" VALUES(2175,5774,-5,'Wells, Vermont 5774',1654,2190);
INSERT INTO "django_geo_db_zipcode" VALUES(2176,5775,-5,'West Pawlet, Vermont 5775',1655,2191);
INSERT INTO "django_geo_db_zipcode" VALUES(2177,5776,-5,'West Rupert, Vermont 5776',1656,2192);
INSERT INTO "django_geo_db_zipcode" VALUES(2178,5777,-5,'West Rutland, Vermont 5777',1657,2193);
INSERT INTO "django_geo_db_zipcode" VALUES(2179,5778,-5,'Whiting, Vermont 5778',1658,2194);
INSERT INTO "django_geo_db_zipcode" VALUES(2180,5801,-5,'White River Junction, Vermont 5801',1419,2195);
INSERT INTO "django_geo_db_zipcode" VALUES(2181,5819,-5,'Saint Johnsbury, Vermont 5819',1659,2196);
INSERT INTO "django_geo_db_zipcode" VALUES(2182,5820,-5,'Albany, Vermont 5820',1660,2197);
INSERT INTO "django_geo_db_zipcode" VALUES(2183,5821,-5,'Barnet, Vermont 5821',1491,2198);
INSERT INTO "django_geo_db_zipcode" VALUES(2184,5822,-5,'Barton, Vermont 5822',1661,2199);
INSERT INTO "django_geo_db_zipcode" VALUES(2185,5823,-5,'Beebe Plain, Vermont 5823',1662,2200);
INSERT INTO "django_geo_db_zipcode" VALUES(2186,5824,-5,'Concord, Vermont 5824',1663,2201);
INSERT INTO "django_geo_db_zipcode" VALUES(2187,5825,-5,'Coventry, Vermont 5825',1664,2202);
INSERT INTO "django_geo_db_zipcode" VALUES(2188,5826,-5,'Craftsbury, Vermont 5826',1504,2203);
INSERT INTO "django_geo_db_zipcode" VALUES(2189,5827,-5,'Craftsbury Common, Vermont 5827',1665,2204);
INSERT INTO "django_geo_db_zipcode" VALUES(2190,5828,-5,'Danville, Vermont 5828',1666,2205);
INSERT INTO "django_geo_db_zipcode" VALUES(2191,5829,-5,'Derby, Vermont 5829',1667,2206);
INSERT INTO "django_geo_db_zipcode" VALUES(2192,5830,-5,'Derby Line, Vermont 5830',1668,2207);
INSERT INTO "django_geo_db_zipcode" VALUES(2193,5832,-5,'East Burke, Vermont 5832',1669,2208);
INSERT INTO "django_geo_db_zipcode" VALUES(2194,5833,-5,'East Charleston, Vermont 5833',1670,2209);
INSERT INTO "django_geo_db_zipcode" VALUES(2195,5836,-5,'East Hardwick, Vermont 5836',1671,2210);
INSERT INTO "django_geo_db_zipcode" VALUES(2196,5837,-5,'East Haven, Vermont 5837',1672,2211);
INSERT INTO "django_geo_db_zipcode" VALUES(2197,5838,-5,'East Saint Johnsbury, Vermont 5838',1673,2212);
INSERT INTO "django_geo_db_zipcode" VALUES(2198,5839,-5,'Glover, Vermont 5839',1674,2213);
INSERT INTO "django_geo_db_zipcode" VALUES(2199,5840,-5,'Granby, Vermont 5840',1675,2214);
INSERT INTO "django_geo_db_zipcode" VALUES(2200,5841,-5,'Greensboro, Vermont 5841',1676,2215);
INSERT INTO "django_geo_db_zipcode" VALUES(2201,5842,-5,'Greensboro Bend, Vermont 5842',1677,2216);
INSERT INTO "django_geo_db_zipcode" VALUES(2202,5843,-5,'Hardwick, Vermont 5843',1678,2217);
INSERT INTO "django_geo_db_zipcode" VALUES(2203,5845,-5,'Irasburg, Vermont 5845',1679,2218);
INSERT INTO "django_geo_db_zipcode" VALUES(2204,5846,-5,'Island Pond, Vermont 5846',1680,2219);
INSERT INTO "django_geo_db_zipcode" VALUES(2205,5847,-5,'Lowell, Vermont 5847',1681,2220);
INSERT INTO "django_geo_db_zipcode" VALUES(2206,5848,-5,'Lower Waterford, Vermont 5848',1682,2221);
INSERT INTO "django_geo_db_zipcode" VALUES(2207,5849,-5,'Lyndon, Vermont 5849',1683,2222);
INSERT INTO "django_geo_db_zipcode" VALUES(2208,5850,-5,'Lyndon Center, Vermont 5850',1684,2223);
INSERT INTO "django_geo_db_zipcode" VALUES(2209,5851,-5,'Lyndonville, Vermont 5851',1685,2224);
INSERT INTO "django_geo_db_zipcode" VALUES(2210,5852,-5,'Newport, Vermont 5852',1686,2225);
INSERT INTO "django_geo_db_zipcode" VALUES(2211,5853,-5,'Morgan, Vermont 5853',1687,2226);
INSERT INTO "django_geo_db_zipcode" VALUES(2212,5855,-5,'Newport, Vermont 5855',1686,2227);
INSERT INTO "django_geo_db_zipcode" VALUES(2213,5857,-5,'Newport Center, Vermont 5857',1688,2228);
INSERT INTO "django_geo_db_zipcode" VALUES(2214,5858,-5,'North Concord, Vermont 5858',1689,2229);
INSERT INTO "django_geo_db_zipcode" VALUES(2215,5859,-5,'North Troy, Vermont 5859',1690,2230);
INSERT INTO "django_geo_db_zipcode" VALUES(2216,5860,-5,'Orleans, Vermont 5860',1691,2231);
INSERT INTO "django_geo_db_zipcode" VALUES(2217,5861,-5,'Passumpsic, Vermont 5861',1692,1966);
INSERT INTO "django_geo_db_zipcode" VALUES(2218,5862,-5,'Peacham, Vermont 5862',1693,1966);
INSERT INTO "django_geo_db_zipcode" VALUES(2219,5863,-5,'Saint Johnsbury Center, Vermont 5863',1694,2232);
INSERT INTO "django_geo_db_zipcode" VALUES(2220,5864,-5,'Stannard, Vermont 5864',1695,2233);
INSERT INTO "django_geo_db_zipcode" VALUES(2221,5866,-5,'Sheffield, Vermont 5866',1696,2234);
INSERT INTO "django_geo_db_zipcode" VALUES(2222,5867,-5,'Sutton, Vermont 5867',1503,2235);
INSERT INTO "django_geo_db_zipcode" VALUES(2223,5868,-5,'Troy, Vermont 5868',1697,2236);
INSERT INTO "django_geo_db_zipcode" VALUES(2224,5871,-5,'West Burke, Vermont 5871',1698,2237);
INSERT INTO "django_geo_db_zipcode" VALUES(2225,5872,-5,'West Charleston, Vermont 5872',1699,2238);
INSERT INTO "django_geo_db_zipcode" VALUES(2226,5873,-5,'West Danville, Vermont 5873',1700,2239);
INSERT INTO "django_geo_db_zipcode" VALUES(2227,5874,-5,'Westfield, Vermont 5874',1701,2240);
INSERT INTO "django_geo_db_zipcode" VALUES(2228,5875,-5,'West Glover, Vermont 5875',1702,2241);
INSERT INTO "django_geo_db_zipcode" VALUES(2229,5892,-5,'Derby, Vermont 5892',1667,2242);
INSERT INTO "django_geo_db_zipcode" VALUES(2230,5901,-5,'Averill, Vermont 5901',1703,2243);
INSERT INTO "django_geo_db_zipcode" VALUES(2231,5902,-5,'Beecher Falls, Vermont 5902',1704,2244);
INSERT INTO "django_geo_db_zipcode" VALUES(2232,5903,-5,'Canaan, Vermont 5903',1705,2245);
INSERT INTO "django_geo_db_zipcode" VALUES(2233,5904,-5,'Gilman, Vermont 5904',1706,2246);
INSERT INTO "django_geo_db_zipcode" VALUES(2234,5905,-5,'Guildhall, Vermont 5905',1707,2247);
INSERT INTO "django_geo_db_zipcode" VALUES(2235,5906,-5,'Lunenburg, Vermont 5906',1708,2248);
INSERT INTO "django_geo_db_zipcode" VALUES(2236,5907,-5,'Norton, Vermont 5907',1709,2249);
INSERT INTO "django_geo_db_zipcode" VALUES(2237,5928,-5,'Derby Center, Vermont 5928',1710,2250);
INSERT INTO "django_geo_db_zipcode" VALUES(2238,5958,-5,'Mount Holly, Vermont 5958',1640,2251);
INSERT INTO "django_geo_db_zipcode" VALUES(2239,6001,-5,'Avon, Connecticut 6001',1711,2252);
INSERT INTO "django_geo_db_zipcode" VALUES(2240,6002,-5,'Bloomfield, Connecticut 6002',1712,2253);
INSERT INTO "django_geo_db_zipcode" VALUES(2241,6006,-5,'Windsor, Connecticut 6006',1713,2254);
INSERT INTO "django_geo_db_zipcode" VALUES(2242,6010,-5,'Bristol, Connecticut 6010',1714,2255);
INSERT INTO "django_geo_db_zipcode" VALUES(2243,6011,-5,'Bristol, Connecticut 6011',1714,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2244,6013,-5,'Burlington, Connecticut 6013',1715,2257);
INSERT INTO "django_geo_db_zipcode" VALUES(2245,6016,-5,'Broad Brook, Connecticut 6016',1716,2258);
INSERT INTO "django_geo_db_zipcode" VALUES(2246,6018,-5,'Canaan, Connecticut 6018',1717,2259);
INSERT INTO "django_geo_db_zipcode" VALUES(2247,6019,-5,'Canton, Connecticut 6019',1718,2260);
INSERT INTO "django_geo_db_zipcode" VALUES(2248,6020,-5,'Canton Center, Connecticut 6020',1719,2261);
INSERT INTO "django_geo_db_zipcode" VALUES(2249,6021,-5,'Colebrook, Connecticut 6021',1720,2262);
INSERT INTO "django_geo_db_zipcode" VALUES(2250,6022,-5,'Collinsville, Connecticut 6022',1721,2263);
INSERT INTO "django_geo_db_zipcode" VALUES(2251,6023,-5,'East Berlin, Connecticut 6023',1722,2264);
INSERT INTO "django_geo_db_zipcode" VALUES(2252,6024,-5,'East Canaan, Connecticut 6024',1723,2265);
INSERT INTO "django_geo_db_zipcode" VALUES(2253,6025,-5,'East Glastonbury, Connecticut 6025',1724,2266);
INSERT INTO "django_geo_db_zipcode" VALUES(2254,6026,-5,'East Granby, Connecticut 6026',1725,2267);
INSERT INTO "django_geo_db_zipcode" VALUES(2255,6027,-5,'East Hartland, Connecticut 6027',1726,2268);
INSERT INTO "django_geo_db_zipcode" VALUES(2256,6028,-5,'East Windsor Hill, Connecticut 6028',1727,2269);
INSERT INTO "django_geo_db_zipcode" VALUES(2257,6029,-5,'Ellington, Connecticut 6029',1728,2270);
INSERT INTO "django_geo_db_zipcode" VALUES(2258,6030,-5,'Farmington, Connecticut 6030',1729,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2259,6031,-5,'Falls Village, Connecticut 6031',1730,2271);
INSERT INTO "django_geo_db_zipcode" VALUES(2260,6032,-5,'Farmington, Connecticut 6032',1729,2272);
INSERT INTO "django_geo_db_zipcode" VALUES(2261,6033,-5,'Glastonbury, Connecticut 6033',1731,2273);
INSERT INTO "django_geo_db_zipcode" VALUES(2262,6034,-5,'Farmington, Connecticut 6034',1729,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2263,6035,-5,'Granby, Connecticut 6035',1732,2274);
INSERT INTO "django_geo_db_zipcode" VALUES(2264,6037,-5,'Kensington, Connecticut 6037',1733,2275);
INSERT INTO "django_geo_db_zipcode" VALUES(2265,6039,-5,'Lakeville, Connecticut 6039',1734,2276);
INSERT INTO "django_geo_db_zipcode" VALUES(2266,6040,-5,'Manchester, Connecticut 6040',1735,2277);
INSERT INTO "django_geo_db_zipcode" VALUES(2267,6041,-5,'Manchester, Connecticut 6041',1735,2278);
INSERT INTO "django_geo_db_zipcode" VALUES(2268,6043,-5,'Bolton, Connecticut 6043',1736,2279);
INSERT INTO "django_geo_db_zipcode" VALUES(2269,6045,-5,'Manchester, Connecticut 6045',1735,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2270,6049,-5,'Melrose, Connecticut 6049',1737,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2271,6050,-5,'New Britain, Connecticut 6050',1738,2280);
INSERT INTO "django_geo_db_zipcode" VALUES(2272,6051,-5,'New Britain, Connecticut 6051',1738,2281);
INSERT INTO "django_geo_db_zipcode" VALUES(2273,6052,-5,'New Britain, Connecticut 6052',1738,2282);
INSERT INTO "django_geo_db_zipcode" VALUES(2274,6053,-5,'New Britain, Connecticut 6053',1738,2283);
INSERT INTO "django_geo_db_zipcode" VALUES(2275,6057,-5,'New Hartford, Connecticut 6057',1739,2284);
INSERT INTO "django_geo_db_zipcode" VALUES(2276,6058,-5,'Norfolk, Connecticut 6058',1740,2285);
INSERT INTO "django_geo_db_zipcode" VALUES(2277,6059,-5,'North Canton, Connecticut 6059',1741,2286);
INSERT INTO "django_geo_db_zipcode" VALUES(2278,6060,-5,'North Granby, Connecticut 6060',1742,2287);
INSERT INTO "django_geo_db_zipcode" VALUES(2279,6061,-5,'Pine Meadow, Connecticut 6061',1743,2288);
INSERT INTO "django_geo_db_zipcode" VALUES(2280,6062,-5,'Plainville, Connecticut 6062',1744,2289);
INSERT INTO "django_geo_db_zipcode" VALUES(2281,6063,-5,'Pleasant Valley, Connecticut 6063',1745,2290);
INSERT INTO "django_geo_db_zipcode" VALUES(2282,6064,-5,'Poquonock, Connecticut 6064',1746,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2283,6065,-5,'Riverton, Connecticut 6065',1747,2291);
INSERT INTO "django_geo_db_zipcode" VALUES(2284,6066,-5,'Vernon Rockville, Connecticut 6066',1748,2292);
INSERT INTO "django_geo_db_zipcode" VALUES(2285,6067,-5,'Rocky Hill, Connecticut 6067',1749,2293);
INSERT INTO "django_geo_db_zipcode" VALUES(2286,6068,-5,'Salisbury, Connecticut 6068',1750,2294);
INSERT INTO "django_geo_db_zipcode" VALUES(2287,6069,-5,'Sharon, Connecticut 6069',1751,2295);
INSERT INTO "django_geo_db_zipcode" VALUES(2288,6070,-5,'Simsbury, Connecticut 6070',1752,2296);
INSERT INTO "django_geo_db_zipcode" VALUES(2289,6071,-5,'Somers, Connecticut 6071',1753,2297);
INSERT INTO "django_geo_db_zipcode" VALUES(2290,6072,-5,'Somersville, Connecticut 6072',1754,2298);
INSERT INTO "django_geo_db_zipcode" VALUES(2291,6073,-5,'South Glastonbury, Connecticut 6073',1755,2299);
INSERT INTO "django_geo_db_zipcode" VALUES(2292,6074,-5,'South Windsor, Connecticut 6074',1756,2300);
INSERT INTO "django_geo_db_zipcode" VALUES(2293,6075,-5,'Stafford, Connecticut 6075',1757,2301);
INSERT INTO "django_geo_db_zipcode" VALUES(2294,6076,-5,'Stafford Springs, Connecticut 6076',1758,2302);
INSERT INTO "django_geo_db_zipcode" VALUES(2295,6077,-5,'Staffordville, Connecticut 6077',1759,2303);
INSERT INTO "django_geo_db_zipcode" VALUES(2296,6078,-5,'Suffield, Connecticut 6078',1760,2304);
INSERT INTO "django_geo_db_zipcode" VALUES(2297,6079,-5,'Taconic, Connecticut 6079',1761,2305);
INSERT INTO "django_geo_db_zipcode" VALUES(2298,6080,-5,'Suffield, Connecticut 6080',1760,2306);
INSERT INTO "django_geo_db_zipcode" VALUES(2299,6081,-5,'Tariffville, Connecticut 6081',1762,2307);
INSERT INTO "django_geo_db_zipcode" VALUES(2300,6082,-5,'Enfield, Connecticut 6082',1763,2308);
INSERT INTO "django_geo_db_zipcode" VALUES(2301,6083,-5,'Enfield, Connecticut 6083',1763,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2302,6084,-5,'Tolland, Connecticut 6084',1764,2309);
INSERT INTO "django_geo_db_zipcode" VALUES(2303,6085,-5,'Unionville, Connecticut 6085',1765,2310);
INSERT INTO "django_geo_db_zipcode" VALUES(2304,6087,-5,'Unionville, Connecticut 6087',1765,2311);
INSERT INTO "django_geo_db_zipcode" VALUES(2305,6088,-5,'East Windsor, Connecticut 6088',1766,2312);
INSERT INTO "django_geo_db_zipcode" VALUES(2306,6089,-5,'Weatogue, Connecticut 6089',1767,2313);
INSERT INTO "django_geo_db_zipcode" VALUES(2307,6090,-5,'West Granby, Connecticut 6090',1768,2314);
INSERT INTO "django_geo_db_zipcode" VALUES(2308,6091,-5,'West Hartland, Connecticut 6091',1769,2315);
INSERT INTO "django_geo_db_zipcode" VALUES(2309,6092,-5,'West Simsbury, Connecticut 6092',1770,2316);
INSERT INTO "django_geo_db_zipcode" VALUES(2310,6093,-5,'West Suffield, Connecticut 6093',1771,2317);
INSERT INTO "django_geo_db_zipcode" VALUES(2311,6094,-5,'Winchester Center, Connecticut 6094',1772,2318);
INSERT INTO "django_geo_db_zipcode" VALUES(2312,6095,-5,'Windsor, Connecticut 6095',1713,2319);
INSERT INTO "django_geo_db_zipcode" VALUES(2313,6096,-5,'Windsor Locks, Connecticut 6096',1773,2320);
INSERT INTO "django_geo_db_zipcode" VALUES(2314,6098,-5,'Winsted, Connecticut 6098',1774,2321);
INSERT INTO "django_geo_db_zipcode" VALUES(2315,6101,-5,'Hartford, Connecticut 6101',1775,2322);
INSERT INTO "django_geo_db_zipcode" VALUES(2316,6102,-5,'Hartford, Connecticut 6102',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2317,6103,-5,'Hartford, Connecticut 6103',1775,2323);
INSERT INTO "django_geo_db_zipcode" VALUES(2318,6104,-5,'Hartford, Connecticut 6104',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2319,6105,-5,'Hartford, Connecticut 6105',1775,2324);
INSERT INTO "django_geo_db_zipcode" VALUES(2320,6106,-5,'Hartford, Connecticut 6106',1775,2325);
INSERT INTO "django_geo_db_zipcode" VALUES(2321,6107,-5,'W Hartford, Connecticut 6107',1776,2326);
INSERT INTO "django_geo_db_zipcode" VALUES(2322,6108,-5,'East Hartford, Connecticut 6108',1777,2327);
INSERT INTO "django_geo_db_zipcode" VALUES(2323,6109,-5,'Wethersfield, Connecticut 6109',1778,2328);
INSERT INTO "django_geo_db_zipcode" VALUES(2324,6110,-5,'W Hartford, Connecticut 6110',1776,2329);
INSERT INTO "django_geo_db_zipcode" VALUES(2325,6111,-5,'Newington, Connecticut 6111',1779,2330);
INSERT INTO "django_geo_db_zipcode" VALUES(2326,6112,-5,'Hartford, Connecticut 6112',1775,2331);
INSERT INTO "django_geo_db_zipcode" VALUES(2327,6114,-5,'Hartford, Connecticut 6114',1775,2332);
INSERT INTO "django_geo_db_zipcode" VALUES(2328,6115,-5,'Hartford, Connecticut 6115',1775,2333);
INSERT INTO "django_geo_db_zipcode" VALUES(2329,6117,-5,'W Hartford, Connecticut 6117',1776,2334);
INSERT INTO "django_geo_db_zipcode" VALUES(2330,6118,-5,'East Hartford, Connecticut 6118',1777,2335);
INSERT INTO "django_geo_db_zipcode" VALUES(2331,6119,-5,'W Hartford, Connecticut 6119',1776,2336);
INSERT INTO "django_geo_db_zipcode" VALUES(2332,6120,-5,'Hartford, Connecticut 6120',1775,2337);
INSERT INTO "django_geo_db_zipcode" VALUES(2333,6123,-5,'Hartford, Connecticut 6123',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2334,6126,-5,'Hartford, Connecticut 6126',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2335,6127,-5,'W Hartford, Connecticut 6127',1776,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2336,6128,-5,'East Hartford, Connecticut 6128',1777,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2337,6129,-5,'Wethersfield, Connecticut 6129',1778,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2338,6131,-5,'Newington, Connecticut 6131',1779,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2339,6132,-5,'Hartford, Connecticut 6132',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2340,6133,-5,'W Hartford, Connecticut 6133',1776,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2341,6134,-5,'Hartford, Connecticut 6134',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2342,6137,-5,'W Hartford, Connecticut 6137',1776,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2343,6138,-5,'East Hartford, Connecticut 6138',1777,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2344,6140,-5,'Hartford, Connecticut 6140',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2345,6141,-5,'Hartford, Connecticut 6141',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2346,6142,-5,'Hartford, Connecticut 6142',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2347,6143,-5,'Hartford, Connecticut 6143',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2348,6144,-5,'Hartford, Connecticut 6144',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2349,6145,-5,'Hartford, Connecticut 6145',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2350,6146,-5,'Hartford, Connecticut 6146',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2351,6147,-5,'Hartford, Connecticut 6147',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2352,6150,-5,'Hartford, Connecticut 6150',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2353,6151,-5,'Hartford, Connecticut 6151',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2354,6152,-5,'Hartford, Connecticut 6152',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2355,6153,-5,'Hartford, Connecticut 6153',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2356,6154,-5,'Hartford, Connecticut 6154',1775,2338);
INSERT INTO "django_geo_db_zipcode" VALUES(2357,6155,-5,'Hartford, Connecticut 6155',1775,2339);
INSERT INTO "django_geo_db_zipcode" VALUES(2358,6156,-5,'Hartford, Connecticut 6156',1775,2340);
INSERT INTO "django_geo_db_zipcode" VALUES(2359,6160,-5,'Hartford, Connecticut 6160',1775,2341);
INSERT INTO "django_geo_db_zipcode" VALUES(2360,6161,-5,'Hartford, Connecticut 6161',1775,2342);
INSERT INTO "django_geo_db_zipcode" VALUES(2361,6167,-5,'Hartford, Connecticut 6167',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2362,6176,-5,'Hartford, Connecticut 6176',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2363,6180,-5,'Hartford, Connecticut 6180',1775,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2364,6183,-5,'Hartford, Connecticut 6183',1775,2343);
INSERT INTO "django_geo_db_zipcode" VALUES(2365,6199,-5,'Hartford, Connecticut 6199',1775,2344);
INSERT INTO "django_geo_db_zipcode" VALUES(2366,6226,-5,'Willimantic, Connecticut 6226',1780,2345);
INSERT INTO "django_geo_db_zipcode" VALUES(2367,6230,-5,'Abington, Connecticut 6230',1781,2346);
INSERT INTO "django_geo_db_zipcode" VALUES(2368,6231,-5,'Amston, Connecticut 6231',1782,2347);
INSERT INTO "django_geo_db_zipcode" VALUES(2369,6232,-5,'Andover, Connecticut 6232',1783,2348);
INSERT INTO "django_geo_db_zipcode" VALUES(2370,6233,-5,'Ballouville, Connecticut 6233',1784,2349);
INSERT INTO "django_geo_db_zipcode" VALUES(2371,6234,-5,'Brooklyn, Connecticut 6234',1785,2350);
INSERT INTO "django_geo_db_zipcode" VALUES(2372,6235,-5,'Chaplin, Connecticut 6235',1786,2351);
INSERT INTO "django_geo_db_zipcode" VALUES(2373,6237,-5,'Columbia, Connecticut 6237',1787,2352);
INSERT INTO "django_geo_db_zipcode" VALUES(2374,6238,-5,'Coventry, Connecticut 6238',1788,2353);
INSERT INTO "django_geo_db_zipcode" VALUES(2375,6239,-5,'Danielson, Connecticut 6239',1789,2354);
INSERT INTO "django_geo_db_zipcode" VALUES(2376,6241,-5,'Dayville, Connecticut 6241',1790,2355);
INSERT INTO "django_geo_db_zipcode" VALUES(2377,6242,-5,'Eastford, Connecticut 6242',1791,2356);
INSERT INTO "django_geo_db_zipcode" VALUES(2378,6243,-5,'East Killingly, Connecticut 6243',1792,2357);
INSERT INTO "django_geo_db_zipcode" VALUES(2379,6244,-5,'East Woodstock, Connecticut 6244',1793,2358);
INSERT INTO "django_geo_db_zipcode" VALUES(2380,6245,-5,'Fabyan, Connecticut 6245',1794,2359);
INSERT INTO "django_geo_db_zipcode" VALUES(2381,6246,-5,'Grosvenor Dale, Connecticut 6246',1795,2360);
INSERT INTO "django_geo_db_zipcode" VALUES(2382,6247,-5,'Hampton, Connecticut 6247',1796,2361);
INSERT INTO "django_geo_db_zipcode" VALUES(2383,6248,-5,'Hebron, Connecticut 6248',1797,2362);
INSERT INTO "django_geo_db_zipcode" VALUES(2384,6249,-5,'Lebanon, Connecticut 6249',1798,2363);
INSERT INTO "django_geo_db_zipcode" VALUES(2385,6250,-5,'Mansfield Center, Connecticut 6250',1799,2364);
INSERT INTO "django_geo_db_zipcode" VALUES(2386,6251,-5,'Mansfield Depot, Connecticut 6251',1800,2365);
INSERT INTO "django_geo_db_zipcode" VALUES(2387,6254,-5,'North Franklin, Connecticut 6254',1801,2366);
INSERT INTO "django_geo_db_zipcode" VALUES(2388,6255,-5,'North Grosvenordale, Connecticut 6255',1802,2367);
INSERT INTO "django_geo_db_zipcode" VALUES(2389,6256,-5,'North Windham, Connecticut 6256',1803,2368);
INSERT INTO "django_geo_db_zipcode" VALUES(2390,6258,-5,'Pomfret, Connecticut 6258',1804,2369);
INSERT INTO "django_geo_db_zipcode" VALUES(2391,6259,-5,'Pomfret Center, Connecticut 6259',1805,2370);
INSERT INTO "django_geo_db_zipcode" VALUES(2392,6260,-5,'Putnam, Connecticut 6260',1806,2371);
INSERT INTO "django_geo_db_zipcode" VALUES(2393,6262,-5,'Quinebaug, Connecticut 6262',1807,2372);
INSERT INTO "django_geo_db_zipcode" VALUES(2394,6263,-5,'Rogers, Connecticut 6263',1808,2373);
INSERT INTO "django_geo_db_zipcode" VALUES(2395,6264,-5,'Scotland, Connecticut 6264',1809,2374);
INSERT INTO "django_geo_db_zipcode" VALUES(2396,6265,-5,'South Willington, Connecticut 6265',1810,2301);
INSERT INTO "django_geo_db_zipcode" VALUES(2397,6266,-5,'South Windham, Connecticut 6266',1811,2375);
INSERT INTO "django_geo_db_zipcode" VALUES(2398,6267,-5,'South Woodstock, Connecticut 6267',1812,2376);
INSERT INTO "django_geo_db_zipcode" VALUES(2399,6268,-5,'Storrs Mansfield, Connecticut 6268',1813,2377);
INSERT INTO "django_geo_db_zipcode" VALUES(2400,6269,-5,'Storrs Mansfield, Connecticut 6269',1813,2378);
INSERT INTO "django_geo_db_zipcode" VALUES(2401,6277,-5,'Thompson, Connecticut 6277',1814,2379);
INSERT INTO "django_geo_db_zipcode" VALUES(2402,6278,-5,'Ashford, Connecticut 6278',1815,2380);
INSERT INTO "django_geo_db_zipcode" VALUES(2403,6279,-5,'Willington, Connecticut 6279',1816,2381);
INSERT INTO "django_geo_db_zipcode" VALUES(2404,6280,-5,'Windham, Connecticut 6280',1817,2382);
INSERT INTO "django_geo_db_zipcode" VALUES(2405,6281,-5,'Woodstock, Connecticut 6281',1818,2383);
INSERT INTO "django_geo_db_zipcode" VALUES(2406,6282,-5,'Woodstock Valley, Connecticut 6282',1819,2384);
INSERT INTO "django_geo_db_zipcode" VALUES(2407,6320,-5,'New London, Connecticut 6320',1820,2385);
INSERT INTO "django_geo_db_zipcode" VALUES(2408,6330,-5,'Baltic, Connecticut 6330',1821,2386);
INSERT INTO "django_geo_db_zipcode" VALUES(2409,6331,-5,'Canterbury, Connecticut 6331',1822,2387);
INSERT INTO "django_geo_db_zipcode" VALUES(2410,6332,-5,'Central Village, Connecticut 6332',1823,2388);
INSERT INTO "django_geo_db_zipcode" VALUES(2411,6333,-5,'East Lyme, Connecticut 6333',1824,2389);
INSERT INTO "django_geo_db_zipcode" VALUES(2412,6334,-5,'Bozrah, Connecticut 6334',1825,2390);
INSERT INTO "django_geo_db_zipcode" VALUES(2413,6335,-5,'Gales Ferry, Connecticut 6335',1826,2391);
INSERT INTO "django_geo_db_zipcode" VALUES(2414,6336,-5,'Gilman, Connecticut 6336',1827,2392);
INSERT INTO "django_geo_db_zipcode" VALUES(2415,6337,-5,'Glasgo, Connecticut 6337',1828,2393);
INSERT INTO "django_geo_db_zipcode" VALUES(2416,6339,-5,'Ledyard, Connecticut 6339',1829,2394);
INSERT INTO "django_geo_db_zipcode" VALUES(2417,6340,-5,'Groton, Connecticut 6340',1830,2395);
INSERT INTO "django_geo_db_zipcode" VALUES(2418,6349,-5,'Groton, Connecticut 6349',1830,2396);
INSERT INTO "django_geo_db_zipcode" VALUES(2419,6350,-5,'Hanover, Connecticut 6350',1831,2397);
INSERT INTO "django_geo_db_zipcode" VALUES(2420,6351,-5,'Jewett City, Connecticut 6351',1832,2398);
INSERT INTO "django_geo_db_zipcode" VALUES(2421,6353,-5,'Montville, Connecticut 6353',1833,2399);
INSERT INTO "django_geo_db_zipcode" VALUES(2422,6354,-5,'Moosup, Connecticut 6354',1834,2400);
INSERT INTO "django_geo_db_zipcode" VALUES(2423,6355,-5,'Mystic, Connecticut 6355',1835,2401);
INSERT INTO "django_geo_db_zipcode" VALUES(2424,6357,-5,'Niantic, Connecticut 6357',1836,2402);
INSERT INTO "django_geo_db_zipcode" VALUES(2425,6359,-5,'North Stonington, Connecticut 6359',1837,2403);
INSERT INTO "django_geo_db_zipcode" VALUES(2426,6360,-5,'Norwich, Connecticut 6360',1838,2404);
INSERT INTO "django_geo_db_zipcode" VALUES(2427,6365,-5,'Preston, Connecticut 6365',1839,2405);
INSERT INTO "django_geo_db_zipcode" VALUES(2428,6370,-5,'Oakdale, Connecticut 6370',1840,2406);
INSERT INTO "django_geo_db_zipcode" VALUES(2429,6371,-5,'Old Lyme, Connecticut 6371',1841,2407);
INSERT INTO "django_geo_db_zipcode" VALUES(2430,6372,-5,'Old Mystic, Connecticut 6372',1842,2408);
INSERT INTO "django_geo_db_zipcode" VALUES(2431,6373,-5,'Oneco, Connecticut 6373',1843,2409);
INSERT INTO "django_geo_db_zipcode" VALUES(2432,6374,-5,'Plainfield, Connecticut 6374',1844,2410);
INSERT INTO "django_geo_db_zipcode" VALUES(2433,6375,-5,'Quaker Hill, Connecticut 6375',1845,2411);
INSERT INTO "django_geo_db_zipcode" VALUES(2434,6376,-5,'South Lyme, Connecticut 6376',1846,2412);
INSERT INTO "django_geo_db_zipcode" VALUES(2435,6377,-5,'Sterling, Connecticut 6377',1847,2413);
INSERT INTO "django_geo_db_zipcode" VALUES(2436,6378,-5,'Stonington, Connecticut 6378',1848,2414);
INSERT INTO "django_geo_db_zipcode" VALUES(2437,6379,-5,'Pawcatuck, Connecticut 6379',1849,2415);
INSERT INTO "django_geo_db_zipcode" VALUES(2438,6380,-5,'Taftville, Connecticut 6380',1850,2416);
INSERT INTO "django_geo_db_zipcode" VALUES(2439,6382,-5,'Uncasville, Connecticut 6382',1851,2417);
INSERT INTO "django_geo_db_zipcode" VALUES(2440,6383,-5,'Versailles, Connecticut 6383',1852,2418);
INSERT INTO "django_geo_db_zipcode" VALUES(2441,6384,-5,'Voluntown, Connecticut 6384',1853,2419);
INSERT INTO "django_geo_db_zipcode" VALUES(2442,6385,-5,'Waterford, Connecticut 6385',1854,2420);
INSERT INTO "django_geo_db_zipcode" VALUES(2443,6386,-5,'Waterford, Connecticut 6386',1854,2421);
INSERT INTO "django_geo_db_zipcode" VALUES(2444,6387,-5,'Wauregan, Connecticut 6387',1855,2422);
INSERT INTO "django_geo_db_zipcode" VALUES(2445,6388,-5,'West Mystic, Connecticut 6388',1856,2423);
INSERT INTO "django_geo_db_zipcode" VALUES(2446,6389,-5,'Yantic, Connecticut 6389',1857,2424);
INSERT INTO "django_geo_db_zipcode" VALUES(2447,6390,-5,'Fishers Island, New York 6390',1858,2425);
INSERT INTO "django_geo_db_zipcode" VALUES(2448,6401,-5,'Ansonia, Connecticut 6401',1859,2426);
INSERT INTO "django_geo_db_zipcode" VALUES(2449,6403,-5,'Beacon Falls, Connecticut 6403',1860,2427);
INSERT INTO "django_geo_db_zipcode" VALUES(2450,6404,-5,'Botsford, Connecticut 6404',1861,2428);
INSERT INTO "django_geo_db_zipcode" VALUES(2451,6405,-5,'Branford, Connecticut 6405',1862,2429);
INSERT INTO "django_geo_db_zipcode" VALUES(2452,6408,-5,'Cheshire, Connecticut 6408',1863,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2453,6409,-5,'Centerbrook, Connecticut 6409',1864,2431);
INSERT INTO "django_geo_db_zipcode" VALUES(2454,6410,-5,'Cheshire, Connecticut 6410',1863,2432);
INSERT INTO "django_geo_db_zipcode" VALUES(2455,6411,-5,'Cheshire, Connecticut 6411',1863,2433);
INSERT INTO "django_geo_db_zipcode" VALUES(2456,6412,-5,'Chester, Connecticut 6412',1865,2434);
INSERT INTO "django_geo_db_zipcode" VALUES(2457,6413,-5,'Clinton, Connecticut 6413',1866,2435);
INSERT INTO "django_geo_db_zipcode" VALUES(2458,6414,-5,'Cobalt, Connecticut 6414',1867,2436);
INSERT INTO "django_geo_db_zipcode" VALUES(2459,6415,-5,'Colchester, Connecticut 6415',1868,2437);
INSERT INTO "django_geo_db_zipcode" VALUES(2460,6416,-5,'Cromwell, Connecticut 6416',1869,2438);
INSERT INTO "django_geo_db_zipcode" VALUES(2461,6417,-5,'Deep River, Connecticut 6417',1870,2439);
INSERT INTO "django_geo_db_zipcode" VALUES(2462,6418,-5,'Derby, Connecticut 6418',1871,2440);
INSERT INTO "django_geo_db_zipcode" VALUES(2463,6419,-5,'Killingworth, Connecticut 6419',1872,2441);
INSERT INTO "django_geo_db_zipcode" VALUES(2464,6420,-5,'Salem, Connecticut 6420',1873,2442);
INSERT INTO "django_geo_db_zipcode" VALUES(2465,6422,-5,'Durham, Connecticut 6422',1874,2443);
INSERT INTO "django_geo_db_zipcode" VALUES(2466,6423,-5,'East Haddam, Connecticut 6423',1875,2444);
INSERT INTO "django_geo_db_zipcode" VALUES(2467,6424,-5,'East Hampton, Connecticut 6424',1876,2445);
INSERT INTO "django_geo_db_zipcode" VALUES(2468,6426,-5,'Essex, Connecticut 6426',1877,2446);
INSERT INTO "django_geo_db_zipcode" VALUES(2469,6430,-5,'Fairfield, Connecticut 6430',1878,2447);
INSERT INTO "django_geo_db_zipcode" VALUES(2470,6431,-5,'Fairfield, Connecticut 6431',1878,2448);
INSERT INTO "django_geo_db_zipcode" VALUES(2471,6432,-5,'Fairfield, Connecticut 6432',1878,2449);
INSERT INTO "django_geo_db_zipcode" VALUES(2472,6436,-5,'Greens Farms, Connecticut 6436',1879,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2473,6437,-5,'Guilford, Connecticut 6437',1880,2451);
INSERT INTO "django_geo_db_zipcode" VALUES(2474,6438,-5,'Haddam, Connecticut 6438',1881,2452);
INSERT INTO "django_geo_db_zipcode" VALUES(2475,6439,-5,'Hadlyme, Connecticut 6439',1882,2453);
INSERT INTO "django_geo_db_zipcode" VALUES(2476,6440,-5,'Hawleyville, Connecticut 6440',1883,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2477,6441,-5,'Higganum, Connecticut 6441',1884,2454);
INSERT INTO "django_geo_db_zipcode" VALUES(2478,6442,-5,'Ivoryton, Connecticut 6442',1885,2455);
INSERT INTO "django_geo_db_zipcode" VALUES(2479,6443,-5,'Madison, Connecticut 6443',1886,2456);
INSERT INTO "django_geo_db_zipcode" VALUES(2480,6444,-5,'Marion, Connecticut 6444',1887,2256);
INSERT INTO "django_geo_db_zipcode" VALUES(2481,6447,-5,'Marlborough, Connecticut 6447',1888,2457);
INSERT INTO "django_geo_db_zipcode" VALUES(2482,6450,-5,'Meriden, Connecticut 6450',1889,2458);
INSERT INTO "django_geo_db_zipcode" VALUES(2483,6451,-5,'Meriden, Connecticut 6451',1889,2459);
INSERT INTO "django_geo_db_zipcode" VALUES(2484,6454,-5,'Meriden, Connecticut 6454',1889,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2485,6455,-5,'Middlefield, Connecticut 6455',1890,2460);
INSERT INTO "django_geo_db_zipcode" VALUES(2486,6456,-5,'Middle Haddam, Connecticut 6456',1891,2461);
INSERT INTO "django_geo_db_zipcode" VALUES(2487,6457,-5,'Middletown, Connecticut 6457',1892,2462);
INSERT INTO "django_geo_db_zipcode" VALUES(2488,6459,-5,'Middletown, Connecticut 6459',1892,2463);
INSERT INTO "django_geo_db_zipcode" VALUES(2489,6460,-5,'Milford, Connecticut 6460',1893,2464);
INSERT INTO "django_geo_db_zipcode" VALUES(2490,6467,-5,'Milldale, Connecticut 6467',1894,2465);
INSERT INTO "django_geo_db_zipcode" VALUES(2491,6468,-5,'Monroe, Connecticut 6468',1895,2466);
INSERT INTO "django_geo_db_zipcode" VALUES(2492,6469,-5,'Moodus, Connecticut 6469',1896,2467);
INSERT INTO "django_geo_db_zipcode" VALUES(2493,6470,-5,'Newtown, Connecticut 6470',1897,2468);
INSERT INTO "django_geo_db_zipcode" VALUES(2494,6471,-5,'North Branford, Connecticut 6471',1898,2469);
INSERT INTO "django_geo_db_zipcode" VALUES(2495,6472,-5,'Northford, Connecticut 6472',1899,2470);
INSERT INTO "django_geo_db_zipcode" VALUES(2496,6473,-5,'North Haven, Connecticut 6473',1900,2471);
INSERT INTO "django_geo_db_zipcode" VALUES(2497,6474,-5,'North Westchester, Connecticut 6474',1901,2421);
INSERT INTO "django_geo_db_zipcode" VALUES(2498,6475,-5,'Old Saybrook, Connecticut 6475',1902,2472);
INSERT INTO "django_geo_db_zipcode" VALUES(2499,6477,-5,'Orange, Connecticut 6477',1903,2473);
INSERT INTO "django_geo_db_zipcode" VALUES(2500,6478,-5,'Oxford, Connecticut 6478',1904,2474);
INSERT INTO "django_geo_db_zipcode" VALUES(2501,6479,-5,'Plantsville, Connecticut 6479',1905,2475);
INSERT INTO "django_geo_db_zipcode" VALUES(2502,6480,-5,'Portland, Connecticut 6480',1906,2476);
INSERT INTO "django_geo_db_zipcode" VALUES(2503,6481,-5,'Rockfall, Connecticut 6481',1907,2477);
INSERT INTO "django_geo_db_zipcode" VALUES(2504,6482,-5,'Sandy Hook, Connecticut 6482',1908,2478);
INSERT INTO "django_geo_db_zipcode" VALUES(2505,6483,-5,'Seymour, Connecticut 6483',1909,2479);
INSERT INTO "django_geo_db_zipcode" VALUES(2506,6484,-5,'Shelton, Connecticut 6484',1910,2480);
INSERT INTO "django_geo_db_zipcode" VALUES(2507,6487,-5,'South Britain, Connecticut 6487',1911,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2508,6488,-5,'Southbury, Connecticut 6488',1912,2481);
INSERT INTO "django_geo_db_zipcode" VALUES(2509,6489,-5,'Southington, Connecticut 6489',1913,2482);
INSERT INTO "django_geo_db_zipcode" VALUES(2510,6490,-5,'Southport, Connecticut 6490',1914,2483);
INSERT INTO "django_geo_db_zipcode" VALUES(2511,6491,-5,'Stevenson, Connecticut 6491',1915,2484);
INSERT INTO "django_geo_db_zipcode" VALUES(2512,6492,-5,'Wallingford, Connecticut 6492',1916,2485);
INSERT INTO "django_geo_db_zipcode" VALUES(2513,6493,-5,'Wallingford, Connecticut 6493',1916,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2514,6494,-5,'Wallingford, Connecticut 6494',1916,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2515,6497,-5,'Stratford, Connecticut 6497',1917,2486);
INSERT INTO "django_geo_db_zipcode" VALUES(2516,6498,-5,'Westbrook, Connecticut 6498',1918,2487);
INSERT INTO "django_geo_db_zipcode" VALUES(2517,6501,-5,'New Haven, Connecticut 6501',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2518,6502,-5,'New Haven, Connecticut 6502',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2519,6503,-5,'New Haven, Connecticut 6503',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2520,6504,-5,'New Haven, Connecticut 6504',1919,2488);
INSERT INTO "django_geo_db_zipcode" VALUES(2521,6505,-5,'New Haven, Connecticut 6505',1919,2489);
INSERT INTO "django_geo_db_zipcode" VALUES(2522,6506,-5,'New Haven, Connecticut 6506',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2523,6507,-5,'New Haven, Connecticut 6507',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2524,6508,-5,'New Haven, Connecticut 6508',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2525,6509,-5,'New Haven, Connecticut 6509',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2526,6510,-5,'New Haven, Connecticut 6510',1919,2490);
INSERT INTO "django_geo_db_zipcode" VALUES(2527,6511,-5,'New Haven, Connecticut 6511',1919,2491);
INSERT INTO "django_geo_db_zipcode" VALUES(2528,6512,-5,'East Haven, Connecticut 6512',1920,2492);
INSERT INTO "django_geo_db_zipcode" VALUES(2529,6513,-5,'New Haven, Connecticut 6513',1919,2493);
INSERT INTO "django_geo_db_zipcode" VALUES(2530,6514,-5,'Hamden, Connecticut 6514',1921,2494);
INSERT INTO "django_geo_db_zipcode" VALUES(2531,6515,-5,'New Haven, Connecticut 6515',1919,2495);
INSERT INTO "django_geo_db_zipcode" VALUES(2532,6516,-5,'West Haven, Connecticut 6516',1922,2496);
INSERT INTO "django_geo_db_zipcode" VALUES(2533,6517,-5,'Hamden, Connecticut 6517',1921,2497);
INSERT INTO "django_geo_db_zipcode" VALUES(2534,6518,-5,'Hamden, Connecticut 6518',1921,2498);
INSERT INTO "django_geo_db_zipcode" VALUES(2535,6519,-5,'New Haven, Connecticut 6519',1919,2499);
INSERT INTO "django_geo_db_zipcode" VALUES(2536,6520,-5,'New Haven, Connecticut 6520',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2537,6521,-5,'New Haven, Connecticut 6521',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2538,6524,-5,'Bethany, Connecticut 6524',1923,2500);
INSERT INTO "django_geo_db_zipcode" VALUES(2539,6525,-5,'Woodbridge, Connecticut 6525',1924,2501);
INSERT INTO "django_geo_db_zipcode" VALUES(2540,6530,-5,'New Haven, Connecticut 6530',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2541,6531,-5,'New Haven, Connecticut 6531',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2542,6532,-5,'New Haven, Connecticut 6532',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2543,6533,-5,'New Haven, Connecticut 6533',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2544,6534,-5,'New Haven, Connecticut 6534',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2545,6535,-5,'New Haven, Connecticut 6535',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2546,6536,-5,'New Haven, Connecticut 6536',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2547,6537,-5,'New Haven, Connecticut 6537',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2548,6538,-5,'New Haven, Connecticut 6538',1919,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2549,6540,-5,'New Haven, Connecticut 6540',1919,2502);
INSERT INTO "django_geo_db_zipcode" VALUES(2550,6601,-5,'Bridgeport, Connecticut 6601',1925,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2551,6602,-5,'Bridgeport, Connecticut 6602',1925,2503);
INSERT INTO "django_geo_db_zipcode" VALUES(2552,6604,-5,'Bridgeport, Connecticut 6604',1925,2504);
INSERT INTO "django_geo_db_zipcode" VALUES(2553,6605,-5,'Bridgeport, Connecticut 6605',1925,2505);
INSERT INTO "django_geo_db_zipcode" VALUES(2554,6606,-5,'Bridgeport, Connecticut 6606',1925,2506);
INSERT INTO "django_geo_db_zipcode" VALUES(2555,6607,-5,'Bridgeport, Connecticut 6607',1925,2507);
INSERT INTO "django_geo_db_zipcode" VALUES(2556,6608,-5,'Bridgeport, Connecticut 6608',1925,2508);
INSERT INTO "django_geo_db_zipcode" VALUES(2557,6610,-5,'Bridgeport, Connecticut 6610',1925,2509);
INSERT INTO "django_geo_db_zipcode" VALUES(2558,6611,-5,'Trumbull, Connecticut 6611',1926,2510);
INSERT INTO "django_geo_db_zipcode" VALUES(2559,6612,-5,'Easton, Connecticut 6612',1927,2511);
INSERT INTO "django_geo_db_zipcode" VALUES(2560,6614,-5,'Stratford, Connecticut 6614',1917,2512);
INSERT INTO "django_geo_db_zipcode" VALUES(2561,6615,-5,'Stratford, Connecticut 6615',1917,2513);
INSERT INTO "django_geo_db_zipcode" VALUES(2562,6650,-5,'Bridgeport, Connecticut 6650',1925,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2563,6673,-5,'Bridgeport, Connecticut 6673',1925,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2564,6699,-5,'Bridgeport, Connecticut 6699',1925,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2565,6701,-5,'Waterbury, Connecticut 6701',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2566,6702,-5,'Waterbury, Connecticut 6702',1928,2514);
INSERT INTO "django_geo_db_zipcode" VALUES(2567,6703,-5,'Waterbury, Connecticut 6703',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2568,6704,-5,'Waterbury, Connecticut 6704',1928,2515);
INSERT INTO "django_geo_db_zipcode" VALUES(2569,6705,-5,'Waterbury, Connecticut 6705',1928,2516);
INSERT INTO "django_geo_db_zipcode" VALUES(2570,6706,-5,'Waterbury, Connecticut 6706',1928,2517);
INSERT INTO "django_geo_db_zipcode" VALUES(2571,6708,-5,'Waterbury, Connecticut 6708',1928,2518);
INSERT INTO "django_geo_db_zipcode" VALUES(2572,6710,-5,'Waterbury, Connecticut 6710',1928,2519);
INSERT INTO "django_geo_db_zipcode" VALUES(2573,6712,-5,'Prospect, Connecticut 6712',1929,2520);
INSERT INTO "django_geo_db_zipcode" VALUES(2574,6716,-5,'Wolcott, Connecticut 6716',1930,2521);
INSERT INTO "django_geo_db_zipcode" VALUES(2575,6720,-5,'Waterbury, Connecticut 6720',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2576,6721,-5,'Waterbury, Connecticut 6721',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2577,6722,-5,'Waterbury, Connecticut 6722',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2578,6723,-5,'Waterbury, Connecticut 6723',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2579,6724,-5,'Waterbury, Connecticut 6724',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2580,6725,-5,'Waterbury, Connecticut 6725',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2581,6726,-5,'Waterbury, Connecticut 6726',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2582,6731,-5,'Salisbury, Connecticut 6731',1750,2522);
INSERT INTO "django_geo_db_zipcode" VALUES(2583,6748,-5,'Oxford, Connecticut 6748',1904,2523);
INSERT INTO "django_geo_db_zipcode" VALUES(2584,6749,-5,'Waterbury, Connecticut 6749',1928,2430);
INSERT INTO "django_geo_db_zipcode" VALUES(2585,6750,-5,'Bantam, Connecticut 6750',1931,2524);
INSERT INTO "django_geo_db_zipcode" VALUES(2586,6751,-5,'Bethlehem, Connecticut 6751',1932,2525);
INSERT INTO "django_geo_db_zipcode" VALUES(2587,6752,-5,'Bridgewater, Connecticut 6752',1933,2526);
INSERT INTO "django_geo_db_zipcode" VALUES(2588,6753,-5,'Cornwall, Connecticut 6753',1934,2527);
INSERT INTO "django_geo_db_zipcode" VALUES(2589,6754,-5,'Cornwall Bridge, Connecticut 6754',1935,2528);
INSERT INTO "django_geo_db_zipcode" VALUES(2590,6755,-5,'Gaylordsville, Connecticut 6755',1936,2529);
INSERT INTO "django_geo_db_zipcode" VALUES(2591,6756,-5,'Goshen, Connecticut 6756',1937,2530);
INSERT INTO "django_geo_db_zipcode" VALUES(2592,6757,-5,'Kent, Connecticut 6757',1938,2531);
INSERT INTO "django_geo_db_zipcode" VALUES(2593,6758,-5,'Lakeside, Connecticut 6758',1939,2532);
INSERT INTO "django_geo_db_zipcode" VALUES(2594,6759,-5,'Litchfield, Connecticut 6759',1940,2533);
INSERT INTO "django_geo_db_zipcode" VALUES(2595,6762,-5,'Middlebury, Connecticut 6762',1941,2534);
INSERT INTO "django_geo_db_zipcode" VALUES(2596,6763,-5,'Morris, Connecticut 6763',1942,2535);
INSERT INTO "django_geo_db_zipcode" VALUES(2597,6770,-5,'Naugatuck, Connecticut 6770',1943,2536);
INSERT INTO "django_geo_db_zipcode" VALUES(2598,6776,-5,'New Milford, Connecticut 6776',1944,2537);
INSERT INTO "django_geo_db_zipcode" VALUES(2599,6777,-5,'New Preston Marble Dale, Connecticut 6777',1945,2538);
INSERT INTO "django_geo_db_zipcode" VALUES(2600,6778,-5,'Northfield, Connecticut 6778',1946,2539);
INSERT INTO "django_geo_db_zipcode" VALUES(2601,6779,-5,'Oakville, Connecticut 6779',1947,2540);
INSERT INTO "django_geo_db_zipcode" VALUES(2602,6781,-5,'Pequabuck, Connecticut 6781',1948,2541);
INSERT INTO "django_geo_db_zipcode" VALUES(2603,6782,-5,'Plymouth, Connecticut 6782',1949,2542);
INSERT INTO "django_geo_db_zipcode" VALUES(2604,6783,-5,'Roxbury, Connecticut 6783',1950,2543);
INSERT INTO "django_geo_db_zipcode" VALUES(2605,6784,-5,'Sherman, Connecticut 6784',1951,2544);
INSERT INTO "django_geo_db_zipcode" VALUES(2606,6785,-5,'South Kent, Connecticut 6785',1952,2545);
INSERT INTO "django_geo_db_zipcode" VALUES(2607,6786,-5,'Terryville, Connecticut 6786',1953,2546);
INSERT INTO "django_geo_db_zipcode" VALUES(2608,6787,-5,'Thomaston, Connecticut 6787',1954,2547);
INSERT INTO "django_geo_db_zipcode" VALUES(2609,6790,-5,'Torrington, Connecticut 6790',1955,2548);
INSERT INTO "django_geo_db_zipcode" VALUES(2610,6791,-5,'Harwinton, Connecticut 6791',1956,2549);
INSERT INTO "django_geo_db_zipcode" VALUES(2611,6793,-5,'Washington, Connecticut 6793',1957,2550);
INSERT INTO "django_geo_db_zipcode" VALUES(2612,6794,-5,'Washington Depot, Connecticut 6794',1958,2551);
INSERT INTO "django_geo_db_zipcode" VALUES(2613,6795,-5,'Watertown, Connecticut 6795',1959,2552);
INSERT INTO "django_geo_db_zipcode" VALUES(2614,6796,-5,'West Cornwall, Connecticut 6796',1960,2553);
INSERT INTO "django_geo_db_zipcode" VALUES(2615,6798,-5,'Woodbury, Connecticut 6798',1961,2554);
INSERT INTO "django_geo_db_zipcode" VALUES(2616,6801,-5,'Bethel, Connecticut 6801',1962,2555);
INSERT INTO "django_geo_db_zipcode" VALUES(2617,6804,-5,'Brookfield, Connecticut 6804',1963,2556);
INSERT INTO "django_geo_db_zipcode" VALUES(2618,6807,-5,'Cos Cob, Connecticut 6807',1964,2557);
INSERT INTO "django_geo_db_zipcode" VALUES(2619,6810,-5,'Danbury, Connecticut 6810',1965,2558);
INSERT INTO "django_geo_db_zipcode" VALUES(2620,6811,-5,'Danbury, Connecticut 6811',1965,2559);
INSERT INTO "django_geo_db_zipcode" VALUES(2621,6812,-5,'New Fairfield, Connecticut 6812',1966,2560);
INSERT INTO "django_geo_db_zipcode" VALUES(2622,6813,-5,'Danbury, Connecticut 6813',1965,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2623,6814,-5,'Danbury, Connecticut 6814',1965,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2624,6815,-5,'Hamden, Connecticut 6815',1921,2561);
INSERT INTO "django_geo_db_zipcode" VALUES(2625,6816,-5,'Danbury, Connecticut 6816',1965,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2626,6817,-5,'Danbury, Connecticut 6817',1965,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2627,6819,-5,'Danbury, Connecticut 6819',1965,2562);
INSERT INTO "django_geo_db_zipcode" VALUES(2628,6820,-5,'Darien, Connecticut 6820',1967,2563);
INSERT INTO "django_geo_db_zipcode" VALUES(2629,6824,-5,'Fairfield, Connecticut 6824',1878,2564);
INSERT INTO "django_geo_db_zipcode" VALUES(2630,6825,-5,'Bridgeport, Connecticut 6825',1925,2565);
INSERT INTO "django_geo_db_zipcode" VALUES(2631,6829,-5,'Georgetown, Connecticut 6829',1968,2566);
INSERT INTO "django_geo_db_zipcode" VALUES(2632,6830,-5,'Greenwich, Connecticut 6830',1969,2567);
INSERT INTO "django_geo_db_zipcode" VALUES(2633,6831,-5,'Greenwich, Connecticut 6831',1969,2568);
INSERT INTO "django_geo_db_zipcode" VALUES(2634,6832,-5,'Greenwich, Connecticut 6832',1969,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2635,6836,-5,'Greenwich, Connecticut 6836',1969,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2636,6840,-5,'New Canaan, Connecticut 6840',1970,2569);
INSERT INTO "django_geo_db_zipcode" VALUES(2637,6842,-5,'New Canaan, Connecticut 6842',1970,2570);
INSERT INTO "django_geo_db_zipcode" VALUES(2638,6850,-5,'Norwalk, Connecticut 6850',1971,2571);
INSERT INTO "django_geo_db_zipcode" VALUES(2639,6851,-5,'Norwalk, Connecticut 6851',1971,2572);
INSERT INTO "django_geo_db_zipcode" VALUES(2640,6852,-5,'Norwalk, Connecticut 6852',1971,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2641,6853,-5,'Norwalk, Connecticut 6853',1971,2573);
INSERT INTO "django_geo_db_zipcode" VALUES(2642,6854,-5,'Norwalk, Connecticut 6854',1971,2574);
INSERT INTO "django_geo_db_zipcode" VALUES(2643,6855,-5,'Norwalk, Connecticut 6855',1971,2575);
INSERT INTO "django_geo_db_zipcode" VALUES(2644,6856,-5,'Norwalk, Connecticut 6856',1971,2576);
INSERT INTO "django_geo_db_zipcode" VALUES(2645,6857,-5,'Norwalk, Connecticut 6857',1971,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2646,6858,-5,'Norwalk, Connecticut 6858',1971,2577);
INSERT INTO "django_geo_db_zipcode" VALUES(2647,6859,-5,'Norwalk, Connecticut 6859',1971,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2648,6860,-5,'Norwalk, Connecticut 6860',1971,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2649,6870,-5,'Old Greenwich, Connecticut 6870',1972,2578);
INSERT INTO "django_geo_db_zipcode" VALUES(2650,6875,-5,'Redding Center, Connecticut 6875',1973,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2651,6876,-5,'Redding Ridge, Connecticut 6876',1974,2579);
INSERT INTO "django_geo_db_zipcode" VALUES(2652,6877,-5,'Ridgefield, Connecticut 6877',1975,2580);
INSERT INTO "django_geo_db_zipcode" VALUES(2653,6878,-5,'Riverside, Connecticut 6878',1976,2581);
INSERT INTO "django_geo_db_zipcode" VALUES(2654,6879,-5,'Ridgefield, Connecticut 6879',1975,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2655,6880,-5,'Westport, Connecticut 6880',1977,2582);
INSERT INTO "django_geo_db_zipcode" VALUES(2656,6881,-5,'Westport, Connecticut 6881',1977,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2657,6883,-5,'Weston, Connecticut 6883',1978,2583);
INSERT INTO "django_geo_db_zipcode" VALUES(2658,6888,-5,'Westport, Connecticut 6888',1977,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2659,6889,-5,'Westport, Connecticut 6889',1977,2584);
INSERT INTO "django_geo_db_zipcode" VALUES(2660,6890,-5,'Fairfield, Connecticut 6890',1878,2585);
INSERT INTO "django_geo_db_zipcode" VALUES(2661,6896,-5,'Redding, Connecticut 6896',1979,2586);
INSERT INTO "django_geo_db_zipcode" VALUES(2662,6897,-5,'Wilton, Connecticut 6897',1980,2587);
INSERT INTO "django_geo_db_zipcode" VALUES(2663,6901,-5,'Stamford, Connecticut 6901',1981,2588);
INSERT INTO "django_geo_db_zipcode" VALUES(2664,6902,-5,'Stamford, Connecticut 6902',1981,2589);
INSERT INTO "django_geo_db_zipcode" VALUES(2665,6903,-5,'Stamford, Connecticut 6903',1981,2590);
INSERT INTO "django_geo_db_zipcode" VALUES(2666,6904,-5,'Stamford, Connecticut 6904',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2667,6905,-5,'Stamford, Connecticut 6905',1981,2591);
INSERT INTO "django_geo_db_zipcode" VALUES(2668,6906,-5,'Stamford, Connecticut 6906',1981,2592);
INSERT INTO "django_geo_db_zipcode" VALUES(2669,6907,-5,'Stamford, Connecticut 6907',1981,2593);
INSERT INTO "django_geo_db_zipcode" VALUES(2670,6910,-5,'Stamford, Connecticut 6910',1981,2594);
INSERT INTO "django_geo_db_zipcode" VALUES(2671,6911,-5,'Stamford, Connecticut 6911',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2672,6912,-5,'Stamford, Connecticut 6912',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2673,6913,-5,'Stamford, Connecticut 6913',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2674,6914,-5,'Stamford, Connecticut 6914',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2675,6920,-5,'Stamford, Connecticut 6920',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2676,6921,-5,'Stamford, Connecticut 6921',1981,2595);
INSERT INTO "django_geo_db_zipcode" VALUES(2677,6922,-5,'Stamford, Connecticut 6922',1981,2596);
INSERT INTO "django_geo_db_zipcode" VALUES(2678,6925,-5,'Stamford, Connecticut 6925',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2679,6926,-5,'Stamford, Connecticut 6926',1981,2597);
INSERT INTO "django_geo_db_zipcode" VALUES(2680,6927,-5,'Stamford, Connecticut 6927',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2681,6928,-5,'Stamford, Connecticut 6928',1981,2450);
INSERT INTO "django_geo_db_zipcode" VALUES(2682,6993,-5,'Weston, Connecticut 6993',1978,2598);
INSERT INTO "django_geo_db_zipcode" VALUES(2683,7001,-5,'Avenel, New Jersey 7001',1982,2599);
INSERT INTO "django_geo_db_zipcode" VALUES(2684,7002,-5,'Bayonne, New Jersey 7002',1983,2600);
INSERT INTO "django_geo_db_zipcode" VALUES(2685,7003,-5,'Bloomfield, New Jersey 7003',1984,2601);
INSERT INTO "django_geo_db_zipcode" VALUES(2686,7004,-5,'Fairfield, New Jersey 7004',1985,2602);
INSERT INTO "django_geo_db_zipcode" VALUES(2687,7005,-5,'Boonton, New Jersey 7005',1986,2603);
INSERT INTO "django_geo_db_zipcode" VALUES(2688,7006,-5,'Caldwell, New Jersey 7006',1987,2604);
INSERT INTO "django_geo_db_zipcode" VALUES(2689,7007,-5,'Caldwell, New Jersey 7007',1987,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2690,7008,-5,'Carteret, New Jersey 7008',1988,2606);
INSERT INTO "django_geo_db_zipcode" VALUES(2691,7009,-5,'Cedar Grove, New Jersey 7009',1989,2607);
INSERT INTO "django_geo_db_zipcode" VALUES(2692,7010,-5,'Cliffside Park, New Jersey 7010',1990,2608);
INSERT INTO "django_geo_db_zipcode" VALUES(2693,7011,-5,'Clifton, New Jersey 7011',1991,2609);
INSERT INTO "django_geo_db_zipcode" VALUES(2694,7012,-5,'Clifton, New Jersey 7012',1991,2610);
INSERT INTO "django_geo_db_zipcode" VALUES(2695,7013,-5,'Clifton, New Jersey 7013',1991,2611);
INSERT INTO "django_geo_db_zipcode" VALUES(2696,7014,-5,'Clifton, New Jersey 7014',1991,2612);
INSERT INTO "django_geo_db_zipcode" VALUES(2697,7015,-5,'Clifton, New Jersey 7015',1991,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2698,7016,-5,'Cranford, New Jersey 7016',1992,2614);
INSERT INTO "django_geo_db_zipcode" VALUES(2699,7017,-5,'East Orange, New Jersey 7017',1993,2615);
INSERT INTO "django_geo_db_zipcode" VALUES(2700,7018,-5,'East Orange, New Jersey 7018',1993,2616);
INSERT INTO "django_geo_db_zipcode" VALUES(2701,7019,-5,'East Orange, New Jersey 7019',1993,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2702,7020,-5,'Edgewater, New Jersey 7020',1994,2617);
INSERT INTO "django_geo_db_zipcode" VALUES(2703,7021,-5,'Essex Fells, New Jersey 7021',1995,2618);
INSERT INTO "django_geo_db_zipcode" VALUES(2704,7022,-5,'Fairview, New Jersey 7022',1996,2619);
INSERT INTO "django_geo_db_zipcode" VALUES(2705,7023,-5,'Fanwood, New Jersey 7023',1997,2620);
INSERT INTO "django_geo_db_zipcode" VALUES(2706,7024,-5,'Fort Lee, New Jersey 7024',1998,2621);
INSERT INTO "django_geo_db_zipcode" VALUES(2707,7026,-5,'Garfield, New Jersey 7026',1999,2622);
INSERT INTO "django_geo_db_zipcode" VALUES(2708,7027,-5,'Garwood, New Jersey 7027',2000,2623);
INSERT INTO "django_geo_db_zipcode" VALUES(2709,7028,-5,'Glen Ridge, New Jersey 7028',2001,2624);
INSERT INTO "django_geo_db_zipcode" VALUES(2710,7029,-5,'Harrison, New Jersey 7029',2002,2625);
INSERT INTO "django_geo_db_zipcode" VALUES(2711,7030,-5,'Hoboken, New Jersey 7030',2003,2626);
INSERT INTO "django_geo_db_zipcode" VALUES(2712,7031,-5,'North Arlington, New Jersey 7031',2004,2627);
INSERT INTO "django_geo_db_zipcode" VALUES(2713,7032,-5,'Kearny, New Jersey 7032',2005,2628);
INSERT INTO "django_geo_db_zipcode" VALUES(2714,7033,-5,'Kenilworth, New Jersey 7033',2006,2629);
INSERT INTO "django_geo_db_zipcode" VALUES(2715,7034,-5,'Lake Hiawatha, New Jersey 7034',2007,2630);
INSERT INTO "django_geo_db_zipcode" VALUES(2716,7035,-5,'Lincoln Park, New Jersey 7035',2008,2631);
INSERT INTO "django_geo_db_zipcode" VALUES(2717,7036,-5,'Linden, New Jersey 7036',2009,2632);
INSERT INTO "django_geo_db_zipcode" VALUES(2718,7039,-5,'Livingston, New Jersey 7039',2010,2633);
INSERT INTO "django_geo_db_zipcode" VALUES(2719,7040,-5,'Maplewood, New Jersey 7040',2011,2634);
INSERT INTO "django_geo_db_zipcode" VALUES(2720,7041,-5,'Millburn, New Jersey 7041',2012,2635);
INSERT INTO "django_geo_db_zipcode" VALUES(2721,7042,-5,'Montclair, New Jersey 7042',2013,2636);
INSERT INTO "django_geo_db_zipcode" VALUES(2722,7043,-5,'Montclair, New Jersey 7043',2013,2637);
INSERT INTO "django_geo_db_zipcode" VALUES(2723,7044,-5,'Verona, New Jersey 7044',2014,2638);
INSERT INTO "django_geo_db_zipcode" VALUES(2724,7045,-5,'Montville, New Jersey 7045',2015,2639);
INSERT INTO "django_geo_db_zipcode" VALUES(2725,7046,-5,'Mountain Lakes, New Jersey 7046',2016,2640);
INSERT INTO "django_geo_db_zipcode" VALUES(2726,7047,-5,'North Bergen, New Jersey 7047',2017,2641);
INSERT INTO "django_geo_db_zipcode" VALUES(2727,7050,-5,'Orange, New Jersey 7050',2018,2642);
INSERT INTO "django_geo_db_zipcode" VALUES(2728,7051,-5,'Orange, New Jersey 7051',2018,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2729,7052,-5,'West Orange, New Jersey 7052',2019,2643);
INSERT INTO "django_geo_db_zipcode" VALUES(2730,7054,-5,'Parsippany, New Jersey 7054',2020,2644);
INSERT INTO "django_geo_db_zipcode" VALUES(2731,7055,-5,'Passaic, New Jersey 7055',2021,2645);
INSERT INTO "django_geo_db_zipcode" VALUES(2732,7057,-5,'Wallington, New Jersey 7057',2022,2646);
INSERT INTO "django_geo_db_zipcode" VALUES(2733,7058,-5,'Pine Brook, New Jersey 7058',2023,2647);
INSERT INTO "django_geo_db_zipcode" VALUES(2734,7059,-5,'Warren, New Jersey 7059',2024,2648);
INSERT INTO "django_geo_db_zipcode" VALUES(2735,7060,-5,'Plainfield, New Jersey 7060',2025,2649);
INSERT INTO "django_geo_db_zipcode" VALUES(2736,7061,-5,'Plainfield, New Jersey 7061',2025,2650);
INSERT INTO "django_geo_db_zipcode" VALUES(2737,7062,-5,'Plainfield, New Jersey 7062',2025,2651);
INSERT INTO "django_geo_db_zipcode" VALUES(2738,7063,-5,'Plainfield, New Jersey 7063',2025,2652);
INSERT INTO "django_geo_db_zipcode" VALUES(2739,7064,-5,'Port Reading, New Jersey 7064',2026,2653);
INSERT INTO "django_geo_db_zipcode" VALUES(2740,7065,-5,'Rahway, New Jersey 7065',2027,2654);
INSERT INTO "django_geo_db_zipcode" VALUES(2741,7066,-5,'Clark, New Jersey 7066',2028,2655);
INSERT INTO "django_geo_db_zipcode" VALUES(2742,7067,-5,'Colonia, New Jersey 7067',2029,2656);
INSERT INTO "django_geo_db_zipcode" VALUES(2743,7068,-5,'Roseland, New Jersey 7068',2030,2657);
INSERT INTO "django_geo_db_zipcode" VALUES(2744,7069,-5,'Watchung, New Jersey 7069',2031,2658);
INSERT INTO "django_geo_db_zipcode" VALUES(2745,7070,-5,'Rutherford, New Jersey 7070',2032,2659);
INSERT INTO "django_geo_db_zipcode" VALUES(2746,7071,-5,'Lyndhurst, New Jersey 7071',2033,2660);
INSERT INTO "django_geo_db_zipcode" VALUES(2747,7072,-5,'Carlstadt, New Jersey 7072',2034,2661);
INSERT INTO "django_geo_db_zipcode" VALUES(2748,7073,-5,'East Rutherford, New Jersey 7073',2035,2662);
INSERT INTO "django_geo_db_zipcode" VALUES(2749,7074,-5,'Moonachie, New Jersey 7074',2036,2663);
INSERT INTO "django_geo_db_zipcode" VALUES(2750,7075,-5,'Wood Ridge, New Jersey 7075',2037,2664);
INSERT INTO "django_geo_db_zipcode" VALUES(2751,7076,-5,'Scotch Plains, New Jersey 7076',2038,2665);
INSERT INTO "django_geo_db_zipcode" VALUES(2752,7077,-5,'Sewaren, New Jersey 7077',2039,2666);
INSERT INTO "django_geo_db_zipcode" VALUES(2753,7078,-5,'Short Hills, New Jersey 7078',2040,2667);
INSERT INTO "django_geo_db_zipcode" VALUES(2754,7079,-5,'South Orange, New Jersey 7079',2041,2668);
INSERT INTO "django_geo_db_zipcode" VALUES(2755,7080,-5,'South Plainfield, New Jersey 7080',2042,2669);
INSERT INTO "django_geo_db_zipcode" VALUES(2756,7081,-5,'Springfield, New Jersey 7081',2043,2670);
INSERT INTO "django_geo_db_zipcode" VALUES(2757,7082,-5,'Towaco, New Jersey 7082',2044,2671);
INSERT INTO "django_geo_db_zipcode" VALUES(2758,7083,-5,'Union, New Jersey 7083',2045,2672);
INSERT INTO "django_geo_db_zipcode" VALUES(2759,7086,-5,'Union City, New Jersey 7086',2046,2673);
INSERT INTO "django_geo_db_zipcode" VALUES(2760,7087,-5,'Union City, New Jersey 7087',2046,2674);
INSERT INTO "django_geo_db_zipcode" VALUES(2761,7088,-5,'Vauxhall, New Jersey 7088',2047,2675);
INSERT INTO "django_geo_db_zipcode" VALUES(2762,7090,-5,'Westfield, New Jersey 7090',2048,2676);
INSERT INTO "django_geo_db_zipcode" VALUES(2763,7091,-5,'Westfield, New Jersey 7091',2048,2650);
INSERT INTO "django_geo_db_zipcode" VALUES(2764,7092,-5,'Mountainside, New Jersey 7092',2049,2677);
INSERT INTO "django_geo_db_zipcode" VALUES(2765,7093,-5,'West New York, New Jersey 7093',2050,2678);
INSERT INTO "django_geo_db_zipcode" VALUES(2766,7094,-5,'Secaucus, New Jersey 7094',2051,2679);
INSERT INTO "django_geo_db_zipcode" VALUES(2767,7095,-5,'Woodbridge, New Jersey 7095',2052,2680);
INSERT INTO "django_geo_db_zipcode" VALUES(2768,7096,-5,'Secaucus, New Jersey 7096',2051,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2769,7097,-5,'Jersey City, New Jersey 7097',2053,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2770,7099,-5,'Kearny, New Jersey 7099',2005,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2771,7101,-5,'Newark, New Jersey 7101',2054,2682);
INSERT INTO "django_geo_db_zipcode" VALUES(2772,7102,-5,'Newark, New Jersey 7102',2054,2683);
INSERT INTO "django_geo_db_zipcode" VALUES(2773,7103,-5,'Newark, New Jersey 7103',2054,2684);
INSERT INTO "django_geo_db_zipcode" VALUES(2774,7104,-5,'Newark, New Jersey 7104',2054,2685);
INSERT INTO "django_geo_db_zipcode" VALUES(2775,7105,-5,'Newark, New Jersey 7105',2054,2686);
INSERT INTO "django_geo_db_zipcode" VALUES(2776,7106,-5,'Newark, New Jersey 7106',2054,2687);
INSERT INTO "django_geo_db_zipcode" VALUES(2777,7107,-5,'Newark, New Jersey 7107',2054,2688);
INSERT INTO "django_geo_db_zipcode" VALUES(2778,7108,-5,'Newark, New Jersey 7108',2054,2689);
INSERT INTO "django_geo_db_zipcode" VALUES(2779,7109,-5,'Belleville, New Jersey 7109',2055,2690);
INSERT INTO "django_geo_db_zipcode" VALUES(2780,7110,-5,'Nutley, New Jersey 7110',2056,2691);
INSERT INTO "django_geo_db_zipcode" VALUES(2781,7111,-5,'Irvington, New Jersey 7111',2057,2692);
INSERT INTO "django_geo_db_zipcode" VALUES(2782,7112,-5,'Newark, New Jersey 7112',2054,2693);
INSERT INTO "django_geo_db_zipcode" VALUES(2783,7114,-5,'Newark, New Jersey 7114',2054,2694);
INSERT INTO "django_geo_db_zipcode" VALUES(2784,7115,-5,'Newark, New Jersey 7115',2054,2695);
INSERT INTO "django_geo_db_zipcode" VALUES(2785,7175,-5,'Newark, New Jersey 7175',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2786,7182,-5,'Newark, New Jersey 7182',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2787,7184,-5,'Newark, New Jersey 7184',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2788,7188,-5,'Newark, New Jersey 7188',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2789,7189,-5,'Newark, New Jersey 7189',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2790,7191,-5,'Newark, New Jersey 7191',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2791,7192,-5,'Newark, New Jersey 7192',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2792,7193,-5,'Newark, New Jersey 7193',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2793,7194,-5,'Newark, New Jersey 7194',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2794,7195,-5,'Newark, New Jersey 7195',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2795,7197,-5,'Newark, New Jersey 7197',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2796,7198,-5,'Newark, New Jersey 7198',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2797,7199,-5,'Newark, New Jersey 7199',2054,2605);
INSERT INTO "django_geo_db_zipcode" VALUES(2798,7201,-5,'Elizabeth, New Jersey 7201',2058,2696);
INSERT INTO "django_geo_db_zipcode" VALUES(2799,7202,-5,'Elizabeth, New Jersey 7202',2058,2697);
INSERT INTO "django_geo_db_zipcode" VALUES(2800,7203,-5,'Roselle, New Jersey 7203',2059,2698);
INSERT INTO "django_geo_db_zipcode" VALUES(2801,7204,-5,'Roselle Park, New Jersey 7204',2060,2699);
INSERT INTO "django_geo_db_zipcode" VALUES(2802,7205,-5,'Hillside, New Jersey 7205',2061,2700);
INSERT INTO "django_geo_db_zipcode" VALUES(2803,7206,-5,'Elizabeth, New Jersey 7206',2058,2701);
INSERT INTO "django_geo_db_zipcode" VALUES(2804,7207,-5,'Elizabeth, New Jersey 7207',2058,2650);
INSERT INTO "django_geo_db_zipcode" VALUES(2805,7208,-5,'Elizabeth, New Jersey 7208',2058,2702);
INSERT INTO "django_geo_db_zipcode" VALUES(2806,7290,-5,'Bernards, New Jersey 7290',2062,2703);
INSERT INTO "django_geo_db_zipcode" VALUES(2807,7301,-5,'Jersey City, New Jersey 7301',2053,2704);
INSERT INTO "django_geo_db_zipcode" VALUES(2808,7302,-5,'Jersey City, New Jersey 7302',2053,2705);
INSERT INTO "django_geo_db_zipcode" VALUES(2809,7303,-5,'Jersey City, New Jersey 7303',2053,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2810,7304,-5,'Jersey City, New Jersey 7304',2053,2706);
INSERT INTO "django_geo_db_zipcode" VALUES(2811,7305,-5,'Jersey City, New Jersey 7305',2053,2707);
INSERT INTO "django_geo_db_zipcode" VALUES(2812,7306,-5,'Jersey City, New Jersey 7306',2053,2708);
INSERT INTO "django_geo_db_zipcode" VALUES(2813,7307,-5,'Jersey City, New Jersey 7307',2053,2709);
INSERT INTO "django_geo_db_zipcode" VALUES(2814,7308,-5,'Jersey City, New Jersey 7308',2053,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2815,7309,-5,'Jersey City, New Jersey 7309',2053,2681);
INSERT INTO "django_geo_db_zipcode" VALUES(2816,7310,-5,'Jersey City, New Jersey 7310',2053,2710);
INSERT INTO "django_geo_db_zipcode" VALUES(2817,7311,-5,'Jersey City, New Jersey 7311',2053,2711);
INSERT INTO "django_geo_db_zipcode" VALUES(2818,7399,-5,'Jersey City, New Jersey 7399',2053,2711);
INSERT INTO "django_geo_db_zipcode" VALUES(2819,7401,-5,'Allendale, New Jersey 7401',2063,2712);
INSERT INTO "django_geo_db_zipcode" VALUES(2820,7403,-5,'Bloomingdale, New Jersey 7403',2064,2713);
INSERT INTO "django_geo_db_zipcode" VALUES(2821,7405,-5,'Butler, New Jersey 7405',2065,2714);
INSERT INTO "django_geo_db_zipcode" VALUES(2822,7407,-5,'Elmwood Park, New Jersey 7407',2066,2715);
INSERT INTO "django_geo_db_zipcode" VALUES(2823,7410,-5,'Fair Lawn, New Jersey 7410',2067,2716);
INSERT INTO "django_geo_db_zipcode" VALUES(2824,7416,-5,'Franklin, New Jersey 7416',2068,2717);
INSERT INTO "django_geo_db_zipcode" VALUES(2825,7417,-5,'Franklin Lakes, New Jersey 7417',2069,2718);
INSERT INTO "django_geo_db_zipcode" VALUES(2826,7418,-5,'Glenwood, New Jersey 7418',2070,2719);
INSERT INTO "django_geo_db_zipcode" VALUES(2827,7419,-5,'Hamburg, New Jersey 7419',2071,2720);
INSERT INTO "django_geo_db_zipcode" VALUES(2828,7420,-5,'Haskell, New Jersey 7420',2072,2721);
INSERT INTO "django_geo_db_zipcode" VALUES(2829,7421,-5,'Hewitt, New Jersey 7421',2073,2722);
INSERT INTO "django_geo_db_zipcode" VALUES(2830,7422,-5,'Highland Lakes, New Jersey 7422',2074,2723);
INSERT INTO "django_geo_db_zipcode" VALUES(2831,7423,-5,'Ho Ho Kus, New Jersey 7423',2075,2724);
INSERT INTO "django_geo_db_zipcode" VALUES(2832,7424,-5,'Little Falls, New Jersey 7424',2076,2725);
INSERT INTO "django_geo_db_zipcode" VALUES(2833,7427,-5,'West Paterson, New Jersey 7427',2077,2726);
INSERT INTO "django_geo_db_zipcode" VALUES(2834,7428,-5,'McAfee, New Jersey 7428',2078,2727);
INSERT INTO "django_geo_db_zipcode" VALUES(2835,7430,-5,'Mahwah, New Jersey 7430',2079,2728);
INSERT INTO "django_geo_db_zipcode" VALUES(2836,7432,-5,'Midland Park, New Jersey 7432',2080,2729);
INSERT INTO "django_geo_db_zipcode" VALUES(2837,7435,-5,'Newfoundland, New Jersey 7435',2081,2730);
INSERT INTO "django_geo_db_zipcode" VALUES(2838,7436,-5,'Oakland, New Jersey 7436',2082,2731);
INSERT INTO "django_geo_db_zipcode" VALUES(2839,7438,-5,'Oak Ridge, New Jersey 7438',2083,2732);
INSERT INTO "django_geo_db_zipcode" VALUES(2840,7439,-5,'Ogdensburg, New Jersey 7439',2084,2733);
INSERT INTO "django_geo_db_zipcode" VALUES(2841,7440,-5,'Pequannock, New Jersey 7440',2085,2734);
INSERT INTO "django_geo_db_zipcode" VALUES(2842,7442,-5,'Pompton Lakes, New Jersey 7442',2086,2735);
INSERT INTO "django_geo_db_zipcode" VALUES(2843,7444,-5,'Pompton Plains, New Jersey 7444',2087,2736);
INSERT INTO "django_geo_db_zipcode" VALUES(2844,7446,-5,'Ramsey, New Jersey 7446',2088,2737);
INSERT INTO "django_geo_db_zipcode" VALUES(2845,7450,-5,'Ridgewood, New Jersey 7450',2089,2738);
INSERT INTO "django_geo_db_zipcode" VALUES(2846,7451,-5,'Ridgewood, New Jersey 7451',2089,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2847,7452,-5,'Glen Rock, New Jersey 7452',2090,2740);
INSERT INTO "django_geo_db_zipcode" VALUES(2848,7456,-5,'Ringwood, New Jersey 7456',2091,2741);
INSERT INTO "django_geo_db_zipcode" VALUES(2849,7457,-5,'Riverdale, New Jersey 7457',2092,2742);
INSERT INTO "django_geo_db_zipcode" VALUES(2850,7458,-5,'Saddle River, New Jersey 7458',2093,2743);
INSERT INTO "django_geo_db_zipcode" VALUES(2851,7460,-5,'Stockholm, New Jersey 7460',2094,2744);
INSERT INTO "django_geo_db_zipcode" VALUES(2852,7461,-5,'Sussex, New Jersey 7461',2095,2745);
INSERT INTO "django_geo_db_zipcode" VALUES(2853,7462,-5,'Vernon, New Jersey 7462',2096,2746);
INSERT INTO "django_geo_db_zipcode" VALUES(2854,7463,-5,'Waldwick, New Jersey 7463',2097,2747);
INSERT INTO "django_geo_db_zipcode" VALUES(2855,7465,-5,'Wanaque, New Jersey 7465',2098,2748);
INSERT INTO "django_geo_db_zipcode" VALUES(2856,7470,-5,'Wayne, New Jersey 7470',2099,2749);
INSERT INTO "django_geo_db_zipcode" VALUES(2857,7474,-5,'Wayne, New Jersey 7474',2099,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2858,7477,-5,'Wayne, New Jersey 7477',2099,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2859,7480,-5,'West Milford, New Jersey 7480',2100,2750);
INSERT INTO "django_geo_db_zipcode" VALUES(2860,7481,-5,'Wyckoff, New Jersey 7481',2101,2751);
INSERT INTO "django_geo_db_zipcode" VALUES(2861,7495,-5,'Mahwah, New Jersey 7495',2079,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2862,7498,-5,'Mahwah, New Jersey 7498',2079,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2863,7501,-5,'Paterson, New Jersey 7501',2102,2752);
INSERT INTO "django_geo_db_zipcode" VALUES(2864,7502,-5,'Paterson, New Jersey 7502',2102,2753);
INSERT INTO "django_geo_db_zipcode" VALUES(2865,7503,-5,'Paterson, New Jersey 7503',2102,2754);
INSERT INTO "django_geo_db_zipcode" VALUES(2866,7504,-5,'Paterson, New Jersey 7504',2102,2755);
INSERT INTO "django_geo_db_zipcode" VALUES(2867,7505,-5,'Paterson, New Jersey 7505',2102,2756);
INSERT INTO "django_geo_db_zipcode" VALUES(2868,7506,-5,'Hawthorne, New Jersey 7506',2103,2757);
INSERT INTO "django_geo_db_zipcode" VALUES(2869,7507,-5,'Hawthorne, New Jersey 7507',2103,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2870,7508,-5,'Haledon, New Jersey 7508',2104,2758);
INSERT INTO "django_geo_db_zipcode" VALUES(2871,7509,-5,'Paterson, New Jersey 7509',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2872,7510,-5,'Paterson, New Jersey 7510',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2873,7511,-5,'Totowa, New Jersey 7511',2105,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2874,7512,-5,'Totowa, New Jersey 7512',2105,2759);
INSERT INTO "django_geo_db_zipcode" VALUES(2875,7513,-5,'Paterson, New Jersey 7513',2102,2760);
INSERT INTO "django_geo_db_zipcode" VALUES(2876,7514,-5,'Paterson, New Jersey 7514',2102,2761);
INSERT INTO "django_geo_db_zipcode" VALUES(2877,7522,-5,'Paterson, New Jersey 7522',2102,2762);
INSERT INTO "django_geo_db_zipcode" VALUES(2878,7524,-5,'Paterson, New Jersey 7524',2102,2763);
INSERT INTO "django_geo_db_zipcode" VALUES(2879,7530,-5,'Paterson, New Jersey 7530',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2880,7533,-5,'Paterson, New Jersey 7533',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2881,7538,-5,'Haledon, New Jersey 7538',2104,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2882,7543,-5,'Paterson, New Jersey 7543',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2883,7544,-5,'Paterson, New Jersey 7544',2102,2613);
INSERT INTO "django_geo_db_zipcode" VALUES(2884,7571,-5,'Totowa, New Jersey 7571',2105,2764);
INSERT INTO "django_geo_db_zipcode" VALUES(2885,7601,-5,'Hackensack, New Jersey 7601',2106,2765);
INSERT INTO "django_geo_db_zipcode" VALUES(2886,7602,-5,'Hackensack, New Jersey 7602',2106,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2887,7603,-5,'Bogota, New Jersey 7603',2107,2766);
INSERT INTO "django_geo_db_zipcode" VALUES(2888,7604,-5,'Hasbrouck Heights, New Jersey 7604',2108,2767);
INSERT INTO "django_geo_db_zipcode" VALUES(2889,7605,-5,'Leonia, New Jersey 7605',2109,2768);
INSERT INTO "django_geo_db_zipcode" VALUES(2890,7606,-5,'South Hackensack, New Jersey 7606',2110,2769);
INSERT INTO "django_geo_db_zipcode" VALUES(2891,7607,-5,'Maywood, New Jersey 7607',2111,2770);
INSERT INTO "django_geo_db_zipcode" VALUES(2892,7608,-5,'Teterboro, New Jersey 7608',2112,2771);
INSERT INTO "django_geo_db_zipcode" VALUES(2893,7610,-5,'Oradell, New Jersey 7610',2113,2772);
INSERT INTO "django_geo_db_zipcode" VALUES(2894,7620,-5,'Alpine, New Jersey 7620',2114,2773);
INSERT INTO "django_geo_db_zipcode" VALUES(2895,7621,-5,'Bergenfield, New Jersey 7621',2115,2774);
INSERT INTO "django_geo_db_zipcode" VALUES(2896,7624,-5,'Closter, New Jersey 7624',2116,2775);
INSERT INTO "django_geo_db_zipcode" VALUES(2897,7626,-5,'Cresskill, New Jersey 7626',2117,2776);
INSERT INTO "django_geo_db_zipcode" VALUES(2898,7627,-5,'Demarest, New Jersey 7627',2118,2777);
INSERT INTO "django_geo_db_zipcode" VALUES(2899,7628,-5,'Dumont, New Jersey 7628',2119,2778);
INSERT INTO "django_geo_db_zipcode" VALUES(2900,7630,-5,'Emerson, New Jersey 7630',2120,2779);
INSERT INTO "django_geo_db_zipcode" VALUES(2901,7631,-5,'Englewood, New Jersey 7631',2121,2780);
INSERT INTO "django_geo_db_zipcode" VALUES(2902,7632,-5,'Englewood Cliffs, New Jersey 7632',2122,2781);
INSERT INTO "django_geo_db_zipcode" VALUES(2903,7640,-5,'Harrington Park, New Jersey 7640',2123,2782);
INSERT INTO "django_geo_db_zipcode" VALUES(2904,7641,-5,'Haworth, New Jersey 7641',2124,2783);
INSERT INTO "django_geo_db_zipcode" VALUES(2905,7642,-5,'Hillsdale, New Jersey 7642',2125,2784);
INSERT INTO "django_geo_db_zipcode" VALUES(2906,7643,-5,'Little Ferry, New Jersey 7643',2126,2785);
INSERT INTO "django_geo_db_zipcode" VALUES(2907,7644,-5,'Lodi, New Jersey 7644',2127,2786);
INSERT INTO "django_geo_db_zipcode" VALUES(2908,7645,-5,'Montvale, New Jersey 7645',2128,2787);
INSERT INTO "django_geo_db_zipcode" VALUES(2909,7646,-5,'New Milford, New Jersey 7646',2129,2788);
INSERT INTO "django_geo_db_zipcode" VALUES(2910,7647,-5,'Northvale, New Jersey 7647',2130,2789);
INSERT INTO "django_geo_db_zipcode" VALUES(2911,7648,-5,'Norwood, New Jersey 7648',2131,2790);
INSERT INTO "django_geo_db_zipcode" VALUES(2912,7649,-5,'Oradell, New Jersey 7649',2113,2791);
INSERT INTO "django_geo_db_zipcode" VALUES(2913,7650,-5,'Palisades Park, New Jersey 7650',2132,2792);
INSERT INTO "django_geo_db_zipcode" VALUES(2914,7652,-5,'Paramus, New Jersey 7652',2133,2793);
INSERT INTO "django_geo_db_zipcode" VALUES(2915,7653,-5,'Paramus, New Jersey 7653',2133,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2916,7656,-5,'Park Ridge, New Jersey 7656',2134,2794);
INSERT INTO "django_geo_db_zipcode" VALUES(2917,7657,-5,'Ridgefield, New Jersey 7657',2135,2795);
INSERT INTO "django_geo_db_zipcode" VALUES(2918,7660,-5,'Ridgefield Park, New Jersey 7660',2136,2796);
INSERT INTO "django_geo_db_zipcode" VALUES(2919,7661,-5,'River Edge, New Jersey 7661',2137,2797);
INSERT INTO "django_geo_db_zipcode" VALUES(2920,7662,-5,'Rochelle Park, New Jersey 7662',2138,2798);
INSERT INTO "django_geo_db_zipcode" VALUES(2921,7663,-5,'Saddle Brook, New Jersey 7663',2139,2799);
INSERT INTO "django_geo_db_zipcode" VALUES(2922,7666,-5,'Teaneck, New Jersey 7666',2140,2800);
INSERT INTO "django_geo_db_zipcode" VALUES(2923,7670,-5,'Tenafly, New Jersey 7670',2141,2801);
INSERT INTO "django_geo_db_zipcode" VALUES(2924,7675,-5,'Westwood, New Jersey 7675',2142,2802);
INSERT INTO "django_geo_db_zipcode" VALUES(2925,7676,-5,'Ho-Ho-Kus, New Jersey 7676',2143,2803);
INSERT INTO "django_geo_db_zipcode" VALUES(2926,7677,-5,'Woodcliff Lake, New Jersey 7677',2144,2804);
INSERT INTO "django_geo_db_zipcode" VALUES(2927,7688,-5,'Teaneck, New Jersey 7688',2140,2739);
INSERT INTO "django_geo_db_zipcode" VALUES(2928,7701,-5,'Red Bank, New Jersey 7701',2145,2805);
INSERT INTO "django_geo_db_zipcode" VALUES(2929,7702,-5,'Shrewsbury, New Jersey 7702',2146,2806);
INSERT INTO "django_geo_db_zipcode" VALUES(2930,7703,-5,'Fort Monmouth, New Jersey 7703',2147,2807);
INSERT INTO "django_geo_db_zipcode" VALUES(2931,7704,-5,'Fair Haven, New Jersey 7704',2148,2808);
INSERT INTO "django_geo_db_zipcode" VALUES(2932,7709,-5,'Allenhurst, New Jersey 7709',2149,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2933,7710,-5,'Adelphia, New Jersey 7710',2150,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2934,7711,-5,'Allenhurst, New Jersey 7711',2149,2810);
INSERT INTO "django_geo_db_zipcode" VALUES(2935,7712,-5,'Asbury Park, New Jersey 7712',2151,2811);
INSERT INTO "django_geo_db_zipcode" VALUES(2936,7715,-5,'Belmar, New Jersey 7715',2152,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2937,7716,-5,'Atlantic Highlands, New Jersey 7716',2153,2812);
INSERT INTO "django_geo_db_zipcode" VALUES(2938,7717,-5,'Avon By The Sea, New Jersey 7717',2154,2813);
INSERT INTO "django_geo_db_zipcode" VALUES(2939,7718,-5,'Belford, New Jersey 7718',2155,2814);
INSERT INTO "django_geo_db_zipcode" VALUES(2940,7719,-5,'Belmar, New Jersey 7719',2152,2815);
INSERT INTO "django_geo_db_zipcode" VALUES(2941,7720,-5,'Bradley Beach, New Jersey 7720',2156,2816);
INSERT INTO "django_geo_db_zipcode" VALUES(2942,7721,-5,'Cliffwood, New Jersey 7721',2157,2817);
INSERT INTO "django_geo_db_zipcode" VALUES(2943,7722,-5,'Colts Neck, New Jersey 7722',2158,2818);
INSERT INTO "django_geo_db_zipcode" VALUES(2944,7723,-5,'Deal, New Jersey 7723',2159,2819);
INSERT INTO "django_geo_db_zipcode" VALUES(2945,7724,-5,'Eatontown, New Jersey 7724',2160,2820);
INSERT INTO "django_geo_db_zipcode" VALUES(2946,7726,-5,'Englishtown, New Jersey 7726',2161,2821);
INSERT INTO "django_geo_db_zipcode" VALUES(2947,7727,-5,'Farmingdale, New Jersey 7727',2162,2822);
INSERT INTO "django_geo_db_zipcode" VALUES(2948,7728,-5,'Freehold, New Jersey 7728',2163,2823);
INSERT INTO "django_geo_db_zipcode" VALUES(2949,7730,-5,'Hazlet, New Jersey 7730',2164,2824);
INSERT INTO "django_geo_db_zipcode" VALUES(2950,7731,-5,'Howell, New Jersey 7731',2165,2825);
INSERT INTO "django_geo_db_zipcode" VALUES(2951,7732,-5,'Highlands, New Jersey 7732',2166,2826);
INSERT INTO "django_geo_db_zipcode" VALUES(2952,7733,-5,'Holmdel, New Jersey 7733',2167,2827);
INSERT INTO "django_geo_db_zipcode" VALUES(2953,7734,-5,'Keansburg, New Jersey 7734',2168,2828);
INSERT INTO "django_geo_db_zipcode" VALUES(2954,7735,-5,'Keyport, New Jersey 7735',2169,2829);
INSERT INTO "django_geo_db_zipcode" VALUES(2955,7737,-5,'Leonardo, New Jersey 7737',2170,2830);
INSERT INTO "django_geo_db_zipcode" VALUES(2956,7738,-5,'Lincroft, New Jersey 7738',2171,2831);
INSERT INTO "django_geo_db_zipcode" VALUES(2957,7739,-5,'Little Silver, New Jersey 7739',2172,2832);
INSERT INTO "django_geo_db_zipcode" VALUES(2958,7740,-5,'Long Branch, New Jersey 7740',2173,2833);
INSERT INTO "django_geo_db_zipcode" VALUES(2959,7746,-5,'Marlboro, New Jersey 7746',2174,2834);
INSERT INTO "django_geo_db_zipcode" VALUES(2960,7747,-5,'Matawan, New Jersey 7747',2175,2835);
INSERT INTO "django_geo_db_zipcode" VALUES(2961,7748,-5,'Middletown, New Jersey 7748',2176,2836);
INSERT INTO "django_geo_db_zipcode" VALUES(2962,7750,-5,'Monmouth Beach, New Jersey 7750',2177,2837);
INSERT INTO "django_geo_db_zipcode" VALUES(2963,7751,-5,'Morganville, New Jersey 7751',2178,2838);
INSERT INTO "django_geo_db_zipcode" VALUES(2964,7752,-5,'Navesink, New Jersey 7752',2179,2839);
INSERT INTO "django_geo_db_zipcode" VALUES(2965,7753,-5,'Neptune, New Jersey 7753',2180,2840);
INSERT INTO "django_geo_db_zipcode" VALUES(2966,7754,-5,'Neptune, New Jersey 7754',2180,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2967,7755,-5,'Oakhurst, New Jersey 7755',2181,2841);
INSERT INTO "django_geo_db_zipcode" VALUES(2968,7756,-5,'Ocean Grove, New Jersey 7756',2182,2842);
INSERT INTO "django_geo_db_zipcode" VALUES(2969,7757,-5,'Oceanport, New Jersey 7757',2183,2843);
INSERT INTO "django_geo_db_zipcode" VALUES(2970,7758,-5,'Port Monmouth, New Jersey 7758',2184,2844);
INSERT INTO "django_geo_db_zipcode" VALUES(2971,7760,-5,'Rumson, New Jersey 7760',2185,2845);
INSERT INTO "django_geo_db_zipcode" VALUES(2972,7762,-5,'Spring Lake, New Jersey 7762',2186,2846);
INSERT INTO "django_geo_db_zipcode" VALUES(2973,7763,-5,'Tennent, New Jersey 7763',2187,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2974,7764,-5,'West Long Branch, New Jersey 7764',2188,2847);
INSERT INTO "django_geo_db_zipcode" VALUES(2975,7765,-5,'Wickatunk, New Jersey 7765',2189,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2976,7777,-5,'Holmdel, New Jersey 7777',2167,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2977,7799,-5,'Eatontown, New Jersey 7799',2160,2809);
INSERT INTO "django_geo_db_zipcode" VALUES(2978,7801,-5,'Dover, New Jersey 7801',2190,2848);
INSERT INTO "django_geo_db_zipcode" VALUES(2979,7802,-5,'Dover, New Jersey 7802',2190,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(2980,7803,-5,'Mine Hill, New Jersey 7803',2191,2850);
INSERT INTO "django_geo_db_zipcode" VALUES(2981,7806,-5,'Picatinny Arsenal, New Jersey 7806',2192,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(2982,7819,-5,'Hardyston, New Jersey 7819',2193,2851);
INSERT INTO "django_geo_db_zipcode" VALUES(2983,7820,-5,'Allamuchy, New Jersey 7820',2194,2852);
INSERT INTO "django_geo_db_zipcode" VALUES(2984,7821,-5,'Andover, New Jersey 7821',2195,2853);
INSERT INTO "django_geo_db_zipcode" VALUES(2985,7822,-5,'Augusta, New Jersey 7822',2196,2854);
INSERT INTO "django_geo_db_zipcode" VALUES(2986,7823,-5,'Belvidere, New Jersey 7823',2197,2855);
INSERT INTO "django_geo_db_zipcode" VALUES(2987,7825,-5,'Blairstown, New Jersey 7825',2198,2856);
INSERT INTO "django_geo_db_zipcode" VALUES(2988,7826,-5,'Branchville, New Jersey 7826',2199,2857);
INSERT INTO "django_geo_db_zipcode" VALUES(2989,7827,-5,'Montague, New Jersey 7827',2200,2858);
INSERT INTO "django_geo_db_zipcode" VALUES(2990,7828,-5,'Budd Lake, New Jersey 7828',2201,2859);
INSERT INTO "django_geo_db_zipcode" VALUES(2991,7829,-5,'Buttzville, New Jersey 7829',2202,2860);
INSERT INTO "django_geo_db_zipcode" VALUES(2992,7830,-5,'Califon, New Jersey 7830',2203,2861);
INSERT INTO "django_geo_db_zipcode" VALUES(2993,7831,-5,'Changewater, New Jersey 7831',2204,2862);
INSERT INTO "django_geo_db_zipcode" VALUES(2994,7832,-5,'Columbia, New Jersey 7832',2205,2863);
INSERT INTO "django_geo_db_zipcode" VALUES(2995,7833,-5,'Delaware, New Jersey 7833',2206,2864);
INSERT INTO "django_geo_db_zipcode" VALUES(2996,7834,-5,'Denville, New Jersey 7834',2207,2865);
INSERT INTO "django_geo_db_zipcode" VALUES(2997,7836,-5,'Flanders, New Jersey 7836',2208,2866);
INSERT INTO "django_geo_db_zipcode" VALUES(2998,7837,-5,'Glasser, New Jersey 7837',2209,2867);
INSERT INTO "django_geo_db_zipcode" VALUES(2999,7838,-5,'Great Meadows, New Jersey 7838',2210,2868);
INSERT INTO "django_geo_db_zipcode" VALUES(3000,7839,-5,'Greendell, New Jersey 7839',2211,2867);
INSERT INTO "django_geo_db_zipcode" VALUES(3001,7840,-5,'Hackettstown, New Jersey 7840',2212,2869);
INSERT INTO "django_geo_db_zipcode" VALUES(3002,7841,-5,'Great Meadows-Vienna, New Jersey 7841',2213,2870);
INSERT INTO "django_geo_db_zipcode" VALUES(3003,7842,-5,'Hibernia, New Jersey 7842',2214,2871);
INSERT INTO "django_geo_db_zipcode" VALUES(3004,7843,-5,'Hopatcong, New Jersey 7843',2215,2872);
INSERT INTO "django_geo_db_zipcode" VALUES(3005,7844,-5,'Hope, New Jersey 7844',2216,2873);
INSERT INTO "django_geo_db_zipcode" VALUES(3006,7845,-5,'Ironia, New Jersey 7845',2217,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(3007,7846,-5,'Johnsonburg, New Jersey 7846',2218,2874);
INSERT INTO "django_geo_db_zipcode" VALUES(3008,7847,-5,'Kenvil, New Jersey 7847',2219,2875);
INSERT INTO "django_geo_db_zipcode" VALUES(3009,7848,-5,'Lafayette, New Jersey 7848',2220,2876);
INSERT INTO "django_geo_db_zipcode" VALUES(3010,7849,-5,'Lake Hopatcong, New Jersey 7849',2221,2877);
INSERT INTO "django_geo_db_zipcode" VALUES(3011,7850,-5,'Landing, New Jersey 7850',2222,2878);
INSERT INTO "django_geo_db_zipcode" VALUES(3012,7851,-5,'Layton, New Jersey 7851',2223,2879);
INSERT INTO "django_geo_db_zipcode" VALUES(3013,7852,-5,'Ledgewood, New Jersey 7852',2224,2880);
INSERT INTO "django_geo_db_zipcode" VALUES(3014,7853,-5,'Long Valley, New Jersey 7853',2225,2881);
INSERT INTO "django_geo_db_zipcode" VALUES(3015,7855,-5,'Middleville, New Jersey 7855',2226,2867);
INSERT INTO "django_geo_db_zipcode" VALUES(3016,7856,-5,'Mount Arlington, New Jersey 7856',2227,2882);
INSERT INTO "django_geo_db_zipcode" VALUES(3017,7857,-5,'Netcong, New Jersey 7857',2228,2883);
INSERT INTO "django_geo_db_zipcode" VALUES(3018,7860,-5,'Newton, New Jersey 7860',2229,2884);
INSERT INTO "django_geo_db_zipcode" VALUES(3019,7863,-5,'Oxford, New Jersey 7863',2230,2885);
INSERT INTO "django_geo_db_zipcode" VALUES(3020,7865,-5,'Port Murray, New Jersey 7865',2231,2886);
INSERT INTO "django_geo_db_zipcode" VALUES(3021,7866,-5,'Rockaway, New Jersey 7866',2232,2887);
INSERT INTO "django_geo_db_zipcode" VALUES(3022,7869,-5,'Randolph, New Jersey 7869',2233,2888);
INSERT INTO "django_geo_db_zipcode" VALUES(3023,7870,-5,'Schooleys Mountain, New Jersey 7870',2234,2889);
INSERT INTO "django_geo_db_zipcode" VALUES(3024,7871,-5,'Sparta, New Jersey 7871',2235,2890);
INSERT INTO "django_geo_db_zipcode" VALUES(3025,7874,-5,'Stanhope, New Jersey 7874',2236,2891);
INSERT INTO "django_geo_db_zipcode" VALUES(3026,7875,-5,'Stillwater, New Jersey 7875',2237,2892);
INSERT INTO "django_geo_db_zipcode" VALUES(3027,7876,-5,'Succasunna, New Jersey 7876',2238,2893);
INSERT INTO "django_geo_db_zipcode" VALUES(3028,7877,-5,'Swartswood, New Jersey 7877',2239,2894);
INSERT INTO "django_geo_db_zipcode" VALUES(3029,7878,-5,'Mount Tabor, New Jersey 7878',2240,2895);
INSERT INTO "django_geo_db_zipcode" VALUES(3030,7879,-5,'Tranquility, New Jersey 7879',2241,2896);
INSERT INTO "django_geo_db_zipcode" VALUES(3031,7880,-5,'Vienna, New Jersey 7880',2242,2897);
INSERT INTO "django_geo_db_zipcode" VALUES(3032,7881,-5,'Wallpack Center, New Jersey 7881',2243,2898);
INSERT INTO "django_geo_db_zipcode" VALUES(3033,7882,-5,'Washington, New Jersey 7882',2244,2899);
INSERT INTO "django_geo_db_zipcode" VALUES(3034,7885,-5,'Wharton, New Jersey 7885',2245,2900);
INSERT INTO "django_geo_db_zipcode" VALUES(3035,7890,-5,'Branchville, New Jersey 7890',2199,2867);
INSERT INTO "django_geo_db_zipcode" VALUES(3036,7901,-5,'Summit, New Jersey 7901',2246,2901);
INSERT INTO "django_geo_db_zipcode" VALUES(3037,7902,-5,'Summit, New Jersey 7902',2246,2650);
INSERT INTO "django_geo_db_zipcode" VALUES(3038,7919,-5,'Hardyston, New Jersey 7919',2193,2902);
INSERT INTO "django_geo_db_zipcode" VALUES(3039,7920,-5,'Basking Ridge, New Jersey 7920',2247,2903);
INSERT INTO "django_geo_db_zipcode" VALUES(3040,7921,-5,'Bedminster, New Jersey 7921',2248,2904);
INSERT INTO "django_geo_db_zipcode" VALUES(3041,7922,-5,'Berkeley Heights, New Jersey 7922',2249,2905);
INSERT INTO "django_geo_db_zipcode" VALUES(3042,7924,-5,'Bernardsville, New Jersey 7924',2250,2906);
INSERT INTO "django_geo_db_zipcode" VALUES(3043,7926,-5,'Brookside, New Jersey 7926',2251,2907);
INSERT INTO "django_geo_db_zipcode" VALUES(3044,7927,-5,'Cedar Knolls, New Jersey 7927',2252,2908);
INSERT INTO "django_geo_db_zipcode" VALUES(3045,7928,-5,'Chatham, New Jersey 7928',2253,2909);
INSERT INTO "django_geo_db_zipcode" VALUES(3046,7930,-5,'Chester, New Jersey 7930',2254,2910);
INSERT INTO "django_geo_db_zipcode" VALUES(3047,7931,-5,'Far Hills, New Jersey 7931',2255,2911);
INSERT INTO "django_geo_db_zipcode" VALUES(3048,7932,-5,'Florham Park, New Jersey 7932',2256,2912);
INSERT INTO "django_geo_db_zipcode" VALUES(3049,7933,-5,'Gillette, New Jersey 7933',2257,2913);
INSERT INTO "django_geo_db_zipcode" VALUES(3050,7934,-5,'Gladstone, New Jersey 7934',2258,2914);
INSERT INTO "django_geo_db_zipcode" VALUES(3051,7935,-5,'Green Village, New Jersey 7935',2259,2915);
INSERT INTO "django_geo_db_zipcode" VALUES(3052,7936,-5,'East Hanover, New Jersey 7936',2260,2916);
INSERT INTO "django_geo_db_zipcode" VALUES(3053,7938,-5,'Liberty Corner, New Jersey 7938',2261,2917);
INSERT INTO "django_geo_db_zipcode" VALUES(3054,7939,-5,'Lyons, New Jersey 7939',2262,2918);
INSERT INTO "django_geo_db_zipcode" VALUES(3055,7940,-5,'Madison, New Jersey 7940',2263,2919);
INSERT INTO "django_geo_db_zipcode" VALUES(3056,7945,-5,'Mendham, New Jersey 7945',2264,2920);
INSERT INTO "django_geo_db_zipcode" VALUES(3057,7946,-5,'Millington, New Jersey 7946',2265,2921);
INSERT INTO "django_geo_db_zipcode" VALUES(3058,7950,-5,'Morris Plains, New Jersey 7950',2266,2922);
INSERT INTO "django_geo_db_zipcode" VALUES(3059,7952,-5,'Bernardsville, New Jersey 7952',2250,2923);
INSERT INTO "django_geo_db_zipcode" VALUES(3060,7960,-5,'Morristown, New Jersey 7960',2267,2924);
INSERT INTO "django_geo_db_zipcode" VALUES(3061,7961,-5,'Morristown, New Jersey 7961',2267,2925);
INSERT INTO "django_geo_db_zipcode" VALUES(3062,7962,-5,'Morristown, New Jersey 7962',2267,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(3063,7963,-5,'Morristown, New Jersey 7963',2267,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(3064,7969,-5,'Watchung, New Jersey 7969',2031,2926);
INSERT INTO "django_geo_db_zipcode" VALUES(3065,7970,-5,'Mount Freedom, New Jersey 7970',2268,2927);
INSERT INTO "django_geo_db_zipcode" VALUES(3066,7974,-5,'New Providence, New Jersey 7974',2269,2928);
INSERT INTO "django_geo_db_zipcode" VALUES(3067,7976,-5,'New Vernon, New Jersey 7976',2270,2929);
INSERT INTO "django_geo_db_zipcode" VALUES(3068,7977,-5,'Peapack, New Jersey 7977',2271,2930);
INSERT INTO "django_geo_db_zipcode" VALUES(3069,7978,-5,'Pluckemin, New Jersey 7978',2272,2931);
INSERT INTO "django_geo_db_zipcode" VALUES(3070,7979,-5,'Pottersville, New Jersey 7979',2273,2932);
INSERT INTO "django_geo_db_zipcode" VALUES(3071,7980,-5,'Stirling, New Jersey 7980',2274,2933);
INSERT INTO "django_geo_db_zipcode" VALUES(3072,7981,-5,'Whippany, New Jersey 7981',2275,2934);
INSERT INTO "django_geo_db_zipcode" VALUES(3073,7983,-5,'Whippany, New Jersey 7983',2275,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(3074,7997,-5,'Peapack and Gladstone, New Jersey 7997',2276,2935);
INSERT INTO "django_geo_db_zipcode" VALUES(3075,7999,-5,'Whippany, New Jersey 7999',2275,2849);
INSERT INTO "django_geo_db_zipcode" VALUES(3076,8001,-5,'Alloway, New Jersey 8001',2277,2936);
INSERT INTO "django_geo_db_zipcode" VALUES(3077,8002,-5,'Cherry Hill, New Jersey 8002',2278,2937);
INSERT INTO "django_geo_db_zipcode" VALUES(3078,8003,-5,'Cherry Hill, New Jersey 8003',2278,2938);
INSERT INTO "django_geo_db_zipcode" VALUES(3079,8004,-5,'Atco, New Jersey 8004',2279,2939);
INSERT INTO "django_geo_db_zipcode" VALUES(3080,8005,-5,'Barnegat, New Jersey 8005',2280,2940);
INSERT INTO "django_geo_db_zipcode" VALUES(3081,8006,-5,'Barnegat Light, New Jersey 8006',2281,2941);
INSERT INTO "django_geo_db_zipcode" VALUES(3082,8007,-5,'Barrington, New Jersey 8007',2282,2942);
INSERT INTO "django_geo_db_zipcode" VALUES(3083,8008,-5,'Beach Haven, New Jersey 8008',2283,2943);
INSERT INTO "django_geo_db_zipcode" VALUES(3084,8009,-5,'Berlin, New Jersey 8009',2284,2944);
INSERT INTO "django_geo_db_zipcode" VALUES(3085,8010,-5,'Beverly, New Jersey 8010',2285,2945);
INSERT INTO "django_geo_db_zipcode" VALUES(3086,8011,-5,'Birmingham, New Jersey 8011',2286,2946);
INSERT INTO "django_geo_db_zipcode" VALUES(3087,8012,-5,'Blackwood, New Jersey 8012',2287,2947);
INSERT INTO "django_geo_db_zipcode" VALUES(3088,8014,-5,'Bridgeport, New Jersey 8014',2288,2948);
INSERT INTO "django_geo_db_zipcode" VALUES(3089,8015,-5,'Browns Mills, New Jersey 8015',2289,2949);
INSERT INTO "django_geo_db_zipcode" VALUES(3090,8016,-5,'Burlington, New Jersey 8016',2290,2950);
INSERT INTO "django_geo_db_zipcode" VALUES(3091,8017,-5,'Elwood-Magnolia, New Jersey 8017',2291,2951);
INSERT INTO "django_geo_db_zipcode" VALUES(3092,8018,-5,'Cedar Brook, New Jersey 8018',2292,2952);
INSERT INTO "django_geo_db_zipcode" VALUES(3093,8019,-5,'Chatsworth, New Jersey 8019',2293,2953);
INSERT INTO "django_geo_db_zipcode" VALUES(3094,8020,-5,'Clarksboro, New Jersey 8020',2294,2954);
INSERT INTO "django_geo_db_zipcode" VALUES(3095,8021,-5,'Clementon, New Jersey 8021',2295,2955);
INSERT INTO "django_geo_db_zipcode" VALUES(3096,8022,-5,'Columbus, New Jersey 8022',2296,2956);
INSERT INTO "django_geo_db_zipcode" VALUES(3097,8023,-5,'Deepwater, New Jersey 8023',2297,2957);
INSERT INTO "django_geo_db_zipcode" VALUES(3098,8025,-5,'Ewan, New Jersey 8025',2298,2958);
INSERT INTO "django_geo_db_zipcode" VALUES(3099,8026,-5,'Gibbsboro, New Jersey 8026',2299,2959);
INSERT INTO "django_geo_db_zipcode" VALUES(3100,8027,-5,'Gibbstown, New Jersey 8027',2300,2960);
INSERT INTO "django_geo_db_zipcode" VALUES(3101,8028,-5,'Glassboro, New Jersey 8028',2301,2961);
INSERT INTO "django_geo_db_zipcode" VALUES(3102,8029,-5,'Glendora, New Jersey 8029',2302,2962);
INSERT INTO "django_geo_db_zipcode" VALUES(3103,8030,-5,'Gloucester City, New Jersey 8030',2303,2963);
INSERT INTO "django_geo_db_zipcode" VALUES(3104,8031,-5,'Bellmawr, New Jersey 8031',2304,2964);
INSERT INTO "django_geo_db_zipcode" VALUES(3105,8032,-5,'Grenloch, New Jersey 8032',2305,2965);
INSERT INTO "django_geo_db_zipcode" VALUES(3106,8033,-5,'Haddonfield, New Jersey 8033',2306,2966);
INSERT INTO "django_geo_db_zipcode" VALUES(3107,8034,-5,'Cherry Hill, New Jersey 8034',2278,2967);
INSERT INTO "django_geo_db_zipcode" VALUES(3108,8035,-5,'Haddon Heights, New Jersey 8035',2307,2968);
INSERT INTO "django_geo_db_zipcode" VALUES(3109,8036,-5,'Hainesport, New Jersey 8036',2308,2969);
INSERT INTO "django_geo_db_zipcode" VALUES(3110,8037,-5,'Hammonton, New Jersey 8037',2309,2970);
INSERT INTO "django_geo_db_zipcode" VALUES(3111,8038,-5,'Hancocks Bridge, New Jersey 8038',2310,2971);
INSERT INTO "django_geo_db_zipcode" VALUES(3112,8039,-5,'Harrisonville, New Jersey 8039',2311,2972);
INSERT INTO "django_geo_db_zipcode" VALUES(3113,8041,-5,'Jobstown, New Jersey 8041',2312,2973);
INSERT INTO "django_geo_db_zipcode" VALUES(3114,8042,-5,'Juliustown, New Jersey 8042',2313,2974);
INSERT INTO "django_geo_db_zipcode" VALUES(3115,8043,-5,'Voorhees, New Jersey 8043',2314,2975);
INSERT INTO "django_geo_db_zipcode" VALUES(3116,8045,-5,'Lawnside, New Jersey 8045',2315,2976);
INSERT INTO "django_geo_db_zipcode" VALUES(3117,8046,-5,'Willingboro, New Jersey 8046',2316,2977);
INSERT INTO "django_geo_db_zipcode" VALUES(3118,8048,-5,'Lumberton, New Jersey 8048',2317,2978);
INSERT INTO "django_geo_db_zipcode" VALUES(3119,8049,-5,'Magnolia, New Jersey 8049',2318,2979);
INSERT INTO "django_geo_db_zipcode" VALUES(3120,8050,-5,'Manahawkin, New Jersey 8050',2319,2980);
INSERT INTO "django_geo_db_zipcode" VALUES(3121,8051,-5,'Mantua, New Jersey 8051',2320,2981);
INSERT INTO "django_geo_db_zipcode" VALUES(3122,8052,-5,'Maple Shade, New Jersey 8052',2321,2982);
INSERT INTO "django_geo_db_zipcode" VALUES(3123,8053,-5,'Marlton, New Jersey 8053',2322,2983);
INSERT INTO "django_geo_db_zipcode" VALUES(3124,8054,-5,'Mount Laurel, New Jersey 8054',2323,2984);
INSERT INTO "django_geo_db_zipcode" VALUES(3125,8055,-5,'Medford, New Jersey 8055',2324,2985);
INSERT INTO "django_geo_db_zipcode" VALUES(3126,8056,-5,'Mickleton, New Jersey 8056',2325,2986);
INSERT INTO "django_geo_db_zipcode" VALUES(3127,8057,-5,'Moorestown, New Jersey 8057',2326,2987);
INSERT INTO "django_geo_db_zipcode" VALUES(3128,8059,-5,'Mount Ephraim, New Jersey 8059',2327,2988);
INSERT INTO "django_geo_db_zipcode" VALUES(3129,8060,-5,'Mount Holly, New Jersey 8060',2328,2989);
INSERT INTO "django_geo_db_zipcode" VALUES(3130,8061,-5,'Mount Royal, New Jersey 8061',2329,2990);
INSERT INTO "django_geo_db_zipcode" VALUES(3131,8062,-5,'Mullica Hill, New Jersey 8062',2330,2991);
INSERT INTO "django_geo_db_zipcode" VALUES(3132,8063,-5,'National Park, New Jersey 8063',2331,2992);
INSERT INTO "django_geo_db_zipcode" VALUES(3133,8064,-5,'New Lisbon, New Jersey 8064',2332,2993);
INSERT INTO "django_geo_db_zipcode" VALUES(3134,8065,-5,'Palmyra, New Jersey 8065',2333,2994);
INSERT INTO "django_geo_db_zipcode" VALUES(3135,8066,-5,'Paulsboro, New Jersey 8066',2334,2995);
INSERT INTO "django_geo_db_zipcode" VALUES(3136,8067,-5,'Pedricktown, New Jersey 8067',2335,2996);
INSERT INTO "django_geo_db_zipcode" VALUES(3137,8068,-5,'Pemberton, New Jersey 8068',2336,2997);
INSERT INTO "django_geo_db_zipcode" VALUES(3138,8069,-5,'Penns Grove, New Jersey 8069',2337,2998);
INSERT INTO "django_geo_db_zipcode" VALUES(3139,8070,-5,'Pennsville, New Jersey 8070',2338,2999);
INSERT INTO "django_geo_db_zipcode" VALUES(3140,8071,-5,'Pitman, New Jersey 8071',2339,3000);
INSERT INTO "django_geo_db_zipcode" VALUES(3141,8072,-5,'Quinton, New Jersey 8072',2340,3001);
INSERT INTO "django_geo_db_zipcode" VALUES(3142,8073,-5,'Rancocas, New Jersey 8073',2341,3002);
INSERT INTO "django_geo_db_zipcode" VALUES(3143,8074,-5,'Richwood, New Jersey 8074',2342,3003);
INSERT INTO "django_geo_db_zipcode" VALUES(3144,8075,-5,'Riverside, New Jersey 8075',2343,3004);
INSERT INTO "django_geo_db_zipcode" VALUES(3145,8076,-5,'Riverton, New Jersey 8076',2344,3005);
INSERT INTO "django_geo_db_zipcode" VALUES(3146,8077,-5,'Riverton, New Jersey 8077',2344,3006);
INSERT INTO "django_geo_db_zipcode" VALUES(3147,8078,-5,'Runnemede, New Jersey 8078',2345,3007);
INSERT INTO "django_geo_db_zipcode" VALUES(3148,8079,-5,'Salem, New Jersey 8079',2346,3008);
INSERT INTO "django_geo_db_zipcode" VALUES(3149,8080,-5,'Sewell, New Jersey 8080',2347,3009);
INSERT INTO "django_geo_db_zipcode" VALUES(3150,8081,-5,'Sicklerville, New Jersey 8081',2348,3010);
INSERT INTO "django_geo_db_zipcode" VALUES(3151,8083,-5,'Somerdale, New Jersey 8083',2349,3011);
INSERT INTO "django_geo_db_zipcode" VALUES(3152,8084,-5,'Stratford, New Jersey 8084',2350,3012);
INSERT INTO "django_geo_db_zipcode" VALUES(3153,8085,-5,'Swedesboro, New Jersey 8085',2351,3013);
INSERT INTO "django_geo_db_zipcode" VALUES(3154,8086,-5,'Thorofare, New Jersey 8086',2352,3014);
INSERT INTO "django_geo_db_zipcode" VALUES(3155,8087,-5,'Tuckerton, New Jersey 8087',2353,3015);
INSERT INTO "django_geo_db_zipcode" VALUES(3156,8088,-5,'Vincentown, New Jersey 8088',2354,3016);
INSERT INTO "django_geo_db_zipcode" VALUES(3157,8089,-5,'Waterford Works, New Jersey 8089',2355,3017);
INSERT INTO "django_geo_db_zipcode" VALUES(3158,8090,-5,'Wenonah, New Jersey 8090',2356,3018);
INSERT INTO "django_geo_db_zipcode" VALUES(3159,8091,-5,'West Berlin, New Jersey 8091',2357,3019);
INSERT INTO "django_geo_db_zipcode" VALUES(3160,8092,-5,'West Creek, New Jersey 8092',2358,3020);
INSERT INTO "django_geo_db_zipcode" VALUES(3161,8093,-5,'Westville, New Jersey 8093',2359,3021);
INSERT INTO "django_geo_db_zipcode" VALUES(3162,8094,-5,'Williamstown, New Jersey 8094',2360,3022);
INSERT INTO "django_geo_db_zipcode" VALUES(3163,8095,-5,'Winslow, New Jersey 8095',2361,3023);
INSERT INTO "django_geo_db_zipcode" VALUES(3164,8096,-5,'Woodbury, New Jersey 8096',2362,3024);
INSERT INTO "django_geo_db_zipcode" VALUES(3165,8097,-5,'Woodbury Heights, New Jersey 8097',2363,3025);
INSERT INTO "django_geo_db_zipcode" VALUES(3166,8098,-5,'Woodstown, New Jersey 8098',2364,3026);
INSERT INTO "django_geo_db_zipcode" VALUES(3167,8099,-5,'Bellmawr, New Jersey 8099',2304,3027);
INSERT INTO "django_geo_db_zipcode" VALUES(3168,8101,-5,'Camden, New Jersey 8101',2365,2952);
INSERT INTO "django_geo_db_zipcode" VALUES(3169,8102,-5,'Camden, New Jersey 8102',2365,3028);
INSERT INTO "django_geo_db_zipcode" VALUES(3170,8103,-5,'Camden, New Jersey 8103',2365,3029);
INSERT INTO "django_geo_db_zipcode" VALUES(3171,8104,-5,'Camden, New Jersey 8104',2365,3030);
INSERT INTO "django_geo_db_zipcode" VALUES(3172,8105,-5,'Camden, New Jersey 8105',2365,3031);
INSERT INTO "django_geo_db_zipcode" VALUES(3173,8106,-5,'Audubon, New Jersey 8106',2366,3032);
INSERT INTO "django_geo_db_zipcode" VALUES(3174,8107,-5,'Oaklyn, New Jersey 8107',2367,3033);
INSERT INTO "django_geo_db_zipcode" VALUES(3175,8108,-5,'Collingswood, New Jersey 8108',2368,3034);
INSERT INTO "django_geo_db_zipcode" VALUES(3176,8109,-5,'Merchantville, New Jersey 8109',2369,3035);
INSERT INTO "django_geo_db_zipcode" VALUES(3177,8110,-5,'Pennsauken, New Jersey 8110',2370,3036);
INSERT INTO "django_geo_db_zipcode" VALUES(3178,8201,-5,'Absecon, New Jersey 8201',2371,3037);
INSERT INTO "django_geo_db_zipcode" VALUES(3179,8202,-5,'Avalon, New Jersey 8202',2372,3038);
INSERT INTO "django_geo_db_zipcode" VALUES(3180,8203,-5,'Brigantine, New Jersey 8203',2373,3039);
INSERT INTO "django_geo_db_zipcode" VALUES(3181,8204,-5,'Cape May, New Jersey 8204',2374,3040);
INSERT INTO "django_geo_db_zipcode" VALUES(3182,8205,-5,'Absecon, New Jersey 8205',2371,3041);
INSERT INTO "django_geo_db_zipcode" VALUES(3183,8210,-5,'Cape May Court House, New Jersey 8210',2375,3042);
INSERT INTO "django_geo_db_zipcode" VALUES(3184,8212,-5,'Cape May Point, New Jersey 8212',2376,3043);
INSERT INTO "django_geo_db_zipcode" VALUES(3185,8213,-5,'Cologne, New Jersey 8213',2377,3044);
INSERT INTO "django_geo_db_zipcode" VALUES(3186,8214,-5,'Dennisville, New Jersey 8214',2378,3045);
INSERT INTO "django_geo_db_zipcode" VALUES(3187,8215,-5,'Egg Harbor City, New Jersey 8215',2379,3046);
INSERT INTO "django_geo_db_zipcode" VALUES(3188,8217,-5,'Elwood, New Jersey 8217',2380,3047);
INSERT INTO "django_geo_db_zipcode" VALUES(3189,8218,-5,'Goshen, New Jersey 8218',2381,3045);
INSERT INTO "django_geo_db_zipcode" VALUES(3190,8219,-5,'Green Creek, New Jersey 8219',2382,3045);
INSERT INTO "django_geo_db_zipcode" VALUES(3191,8220,-5,'Leeds Point, New Jersey 8220',2383,3044);
INSERT INTO "django_geo_db_zipcode" VALUES(3192,8221,-5,'Linwood, New Jersey 8221',2384,3048);
INSERT INTO "django_geo_db_zipcode" VALUES(3193,8223,-5,'Marmora, New Jersey 8223',2385,3049);
INSERT INTO "django_geo_db_zipcode" VALUES(3194,8224,-5,'New Gretna, New Jersey 8224',2386,3050);
INSERT INTO "django_geo_db_zipcode" VALUES(3195,8225,-5,'Northfield, New Jersey 8225',2387,3051);
INSERT INTO "django_geo_db_zipcode" VALUES(3196,8226,-5,'Ocean City, New Jersey 8226',2388,3052);
INSERT INTO "django_geo_db_zipcode" VALUES(3197,8227,-5,'Bass River, New Jersey 8227',2389,3053);
INSERT INTO "django_geo_db_zipcode" VALUES(3198,8230,-5,'Ocean View, New Jersey 8230',2390,3054);
INSERT INTO "django_geo_db_zipcode" VALUES(3199,8231,-5,'Oceanville, New Jersey 8231',2391,3044);
INSERT INTO "django_geo_db_zipcode" VALUES(3200,8232,-5,'Pleasantville, New Jersey 8232',2392,3055);
INSERT INTO "django_geo_db_zipcode" VALUES(3201,8234,-5,'Egg Harbor Township, New Jersey 8234',2393,3056);
INSERT INTO "django_geo_db_zipcode" VALUES(3202,8237,-5,'Maurice River, New Jersey 8237',2394,3057);
INSERT INTO "django_geo_db_zipcode" VALUES(3203,8240,-5,'Pomona, New Jersey 8240',2395,3058);
INSERT INTO "django_geo_db_zipcode" VALUES(3204,8241,-5,'Port Republic, New Jersey 8241',2396,3059);
INSERT INTO "django_geo_db_zipcode" VALUES(3205,8242,-5,'Rio Grande, New Jersey 8242',2397,3060);
INSERT INTO "django_geo_db_zipcode" VALUES(3206,8243,-5,'Sea Isle City, New Jersey 8243',2398,3061);
INSERT INTO "django_geo_db_zipcode" VALUES(3207,8244,-5,'Somers Point, New Jersey 8244',2399,3062);
INSERT INTO "django_geo_db_zipcode" VALUES(3208,8245,-5,'South Dennis, New Jersey 8245',2400,3063);
INSERT INTO "django_geo_db_zipcode" VALUES(3209,8246,-5,'South Seaville, New Jersey 8246',2401,3045);
INSERT INTO "django_geo_db_zipcode" VALUES(3210,8247,-5,'Stone Harbor, New Jersey 8247',2402,3064);
INSERT INTO "django_geo_db_zipcode" VALUES(3211,8248,-5,'Strathmere, New Jersey 8248',2403,3065);
INSERT INTO "django_geo_db_zipcode" VALUES(3212,8250,-5,'Tuckahoe, New Jersey 8250',2404,3045);
INSERT INTO "django_geo_db_zipcode" VALUES(3213,8251,-5,'Villas, New Jersey 8251',2405,3066);
INSERT INTO "django_geo_db_zipcode" VALUES(3214,8252,-5,'Whitesboro, New Jersey 8252',2406,3067);
INSERT INTO "django_geo_db_zipcode" VALUES(3215,8253,-5,'Shiloh, New Jersey 8253',2407,3068);
INSERT INTO "django_geo_db_zipcode" VALUES(3216,8260,-5,'Wildwood, New Jersey 8260',2408,3069);
INSERT INTO "django_geo_db_zipcode" VALUES(3217,8270,-5,'Woodbine, New Jersey 8270',2409,3070);
INSERT INTO "django_geo_db_zipcode" VALUES(3218,8283,-5,'Sea Isle City, New Jersey 8283',2398,3071);
INSERT INTO "django_geo_db_zipcode" VALUES(3219,8302,-5,'Bridgeton, New Jersey 8302',2410,3072);
INSERT INTO "django_geo_db_zipcode" VALUES(3220,8310,-5,'Buena, New Jersey 8310',2411,3073);
INSERT INTO "django_geo_db_zipcode" VALUES(3221,8311,-5,'Cedarville, New Jersey 8311',2412,3074);
INSERT INTO "django_geo_db_zipcode" VALUES(3222,8312,-5,'Clayton, New Jersey 8312',2413,3075);
INSERT INTO "django_geo_db_zipcode" VALUES(3223,8313,-5,'Deerfield Street, New Jersey 8313',2414,3076);
INSERT INTO "django_geo_db_zipcode" VALUES(3224,8314,-5,'Delmont, New Jersey 8314',2415,3077);
INSERT INTO "django_geo_db_zipcode" VALUES(3225,8315,-5,'Dividing Creek, New Jersey 8315',2416,3078);
INSERT INTO "django_geo_db_zipcode" VALUES(3226,8316,-5,'Dorchester, New Jersey 8316',2417,3079);
INSERT INTO "django_geo_db_zipcode" VALUES(3227,8317,-5,'Dorothy, New Jersey 8317',2418,3080);
INSERT INTO "django_geo_db_zipcode" VALUES(3228,8318,-5,'Elmer, New Jersey 8318',2419,3081);
INSERT INTO "django_geo_db_zipcode" VALUES(3229,8319,-5,'Estell Manor, New Jersey 8319',2420,3082);
INSERT INTO "django_geo_db_zipcode" VALUES(3230,8320,-5,'Fairton, New Jersey 8320',2421,3083);
INSERT INTO "django_geo_db_zipcode" VALUES(3231,8321,-5,'Fortescue, New Jersey 8321',2422,3084);
INSERT INTO "django_geo_db_zipcode" VALUES(3232,8322,-5,'Franklinville, New Jersey 8322',2423,3085);
INSERT INTO "django_geo_db_zipcode" VALUES(3233,8323,-5,'Greenwich, New Jersey 8323',2424,3086);
INSERT INTO "django_geo_db_zipcode" VALUES(3234,8324,-5,'Heislerville, New Jersey 8324',2425,3087);
INSERT INTO "django_geo_db_zipcode" VALUES(3235,8326,-5,'Landisville, New Jersey 8326',2426,3088);
INSERT INTO "django_geo_db_zipcode" VALUES(3236,8327,-5,'Leesburg, New Jersey 8327',2427,3089);
INSERT INTO "django_geo_db_zipcode" VALUES(3237,8328,-5,'Malaga, New Jersey 8328',2428,3090);
INSERT INTO "django_geo_db_zipcode" VALUES(3238,8329,-5,'Mauricetown, New Jersey 8329',2429,3091);
INSERT INTO "django_geo_db_zipcode" VALUES(3239,8330,-5,'Mays Landing, New Jersey 8330',2430,3092);
INSERT INTO "django_geo_db_zipcode" VALUES(3240,8332,-5,'Millville, New Jersey 8332',2431,3093);
INSERT INTO "django_geo_db_zipcode" VALUES(3241,8334,-5,'Downe, New Jersey 8334',2432,3094);
INSERT INTO "django_geo_db_zipcode" VALUES(3242,8340,-5,'Milmay, New Jersey 8340',2433,3095);
INSERT INTO "django_geo_db_zipcode" VALUES(3243,8341,-5,'Minotola, New Jersey 8341',2434,3096);
INSERT INTO "django_geo_db_zipcode" VALUES(3244,8342,-5,'Mizpah, New Jersey 8342',2435,3097);
INSERT INTO "django_geo_db_zipcode" VALUES(3245,8343,-5,'Monroeville, New Jersey 8343',2436,3098);
INSERT INTO "django_geo_db_zipcode" VALUES(3246,8344,-5,'Newfield, New Jersey 8344',2437,3099);
INSERT INTO "django_geo_db_zipcode" VALUES(3247,8345,-5,'Newport, New Jersey 8345',2438,3100);
INSERT INTO "django_geo_db_zipcode" VALUES(3248,8346,-5,'Newtonville, New Jersey 8346',2439,3101);
INSERT INTO "django_geo_db_zipcode" VALUES(3249,8347,-5,'Norma, New Jersey 8347',2440,3102);
INSERT INTO "django_geo_db_zipcode" VALUES(3250,8348,-5,'Port Elizabeth, New Jersey 8348',2441,3103);
INSERT INTO "django_geo_db_zipcode" VALUES(3251,8349,-5,'Port Norris, New Jersey 8349',2442,3104);
INSERT INTO "django_geo_db_zipcode" VALUES(3252,8350,-5,'Richland, New Jersey 8350',2443,3105);
INSERT INTO "django_geo_db_zipcode" VALUES(3253,8352,-5,'Rosenhayn, New Jersey 8352',2444,3106);
INSERT INTO "django_geo_db_zipcode" VALUES(3254,8353,-5,'Shiloh, New Jersey 8353',2407,3107);
INSERT INTO "django_geo_db_zipcode" VALUES(3255,8360,-5,'Vineland, New Jersey 8360',2445,3108);
INSERT INTO "django_geo_db_zipcode" VALUES(3256,8361,-5,'Vineland, New Jersey 8361',2445,3109);
INSERT INTO "django_geo_db_zipcode" VALUES(3257,8362,-5,'Vineland, New Jersey 8362',2445,3110);
INSERT INTO "django_geo_db_zipcode" VALUES(3258,8370,-5,'Riverside, New Jersey 8370',2343,3005);
INSERT INTO "django_geo_db_zipcode" VALUES(3259,8401,-5,'Atlantic City, New Jersey 8401',2446,3111);
INSERT INTO "django_geo_db_zipcode" VALUES(3260,8402,-5,'Margate City, New Jersey 8402',2447,3112);
INSERT INTO "django_geo_db_zipcode" VALUES(3261,8403,-5,'Longport, New Jersey 8403',2448,3113);
INSERT INTO "django_geo_db_zipcode" VALUES(3262,8404,-5,'Atlantic City, New Jersey 8404',2446,3044);
INSERT INTO "django_geo_db_zipcode" VALUES(3263,8405,-5,'Atlantic City, New Jersey 8405',2446,3044);
INSERT INTO "django_geo_db_zipcode" VALUES(3264,8406,-5,'Ventnor City, New Jersey 8406',2449,3114);
INSERT INTO "django_geo_db_zipcode" VALUES(3265,8501,-5,'Allentown, New Jersey 8501',2450,3115);
INSERT INTO "django_geo_db_zipcode" VALUES(3266,8502,-5,'Belle Mead, New Jersey 8502',2451,3116);
INSERT INTO "django_geo_db_zipcode" VALUES(3267,8504,-5,'Blawenburg, New Jersey 8504',2452,3117);
INSERT INTO "django_geo_db_zipcode" VALUES(3268,8505,-5,'Bordentown, New Jersey 8505',2453,3118);
INSERT INTO "django_geo_db_zipcode" VALUES(3269,8510,-5,'Clarksburg, New Jersey 8510',2454,3119);
INSERT INTO "django_geo_db_zipcode" VALUES(3270,8511,-5,'Cookstown, New Jersey 8511',2455,3120);
INSERT INTO "django_geo_db_zipcode" VALUES(3271,8512,-5,'Cranbury, New Jersey 8512',2456,3121);
INSERT INTO "django_geo_db_zipcode" VALUES(3272,8514,-5,'Cream Ridge, New Jersey 8514',2457,3122);
INSERT INTO "django_geo_db_zipcode" VALUES(3273,8515,-5,'Crosswicks, New Jersey 8515',2458,3123);
INSERT INTO "django_geo_db_zipcode" VALUES(3274,8518,-5,'Florence, New Jersey 8518',2459,3124);
INSERT INTO "django_geo_db_zipcode" VALUES(3275,8520,-5,'Hightstown, New Jersey 8520',2460,3125);
INSERT INTO "django_geo_db_zipcode" VALUES(3276,8525,-5,'Hopewell, New Jersey 8525',2461,3126);
INSERT INTO "django_geo_db_zipcode" VALUES(3277,8526,-5,'Imlaystown, New Jersey 8526',2462,3127);
INSERT INTO "django_geo_db_zipcode" VALUES(3278,8527,-5,'Jackson, New Jersey 8527',2463,3128);
INSERT INTO "django_geo_db_zipcode" VALUES(3279,8528,-5,'Kingston, New Jersey 8528',2464,3129);
INSERT INTO "django_geo_db_zipcode" VALUES(3280,8530,-5,'Lambertville, New Jersey 8530',2465,3130);
INSERT INTO "django_geo_db_zipcode" VALUES(3281,8533,-5,'New Egypt, New Jersey 8533',2466,3131);
INSERT INTO "django_geo_db_zipcode" VALUES(3282,8534,-5,'Pennington, New Jersey 8534',2467,3132);
INSERT INTO "django_geo_db_zipcode" VALUES(3283,8535,-5,'Perrineville, New Jersey 8535',2468,3133);
INSERT INTO "django_geo_db_zipcode" VALUES(3284,8536,-5,'Plainsboro, New Jersey 8536',2469,3134);
INSERT INTO "django_geo_db_zipcode" VALUES(3285,8540,-5,'Princeton, New Jersey 8540',2470,3135);
INSERT INTO "django_geo_db_zipcode" VALUES(3286,8541,-5,'Princeton, New Jersey 8541',2470,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3287,8542,-5,'Princeton, New Jersey 8542',2470,3137);
INSERT INTO "django_geo_db_zipcode" VALUES(3288,8543,-5,'Princeton, New Jersey 8543',2470,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3289,8544,-5,'Princeton, New Jersey 8544',2470,3138);
INSERT INTO "django_geo_db_zipcode" VALUES(3290,8550,-5,'Princeton Junction, New Jersey 8550',2471,3139);
INSERT INTO "django_geo_db_zipcode" VALUES(3291,8551,-5,'Ringoes, New Jersey 8551',2472,3140);
INSERT INTO "django_geo_db_zipcode" VALUES(3292,8553,-5,'Rocky Hill, New Jersey 8553',2473,3141);
INSERT INTO "django_geo_db_zipcode" VALUES(3293,8554,-5,'Roebling, New Jersey 8554',2474,3142);
INSERT INTO "django_geo_db_zipcode" VALUES(3294,8555,-5,'Roosevelt, New Jersey 8555',2475,3143);
INSERT INTO "django_geo_db_zipcode" VALUES(3295,8556,-5,'Rosemont, New Jersey 8556',2476,3144);
INSERT INTO "django_geo_db_zipcode" VALUES(3296,8557,-5,'Sergeantsville, New Jersey 8557',2477,3145);
INSERT INTO "django_geo_db_zipcode" VALUES(3297,8558,-5,'Skillman, New Jersey 8558',2478,3146);
INSERT INTO "django_geo_db_zipcode" VALUES(3298,8559,-5,'Stockton, New Jersey 8559',2479,3147);
INSERT INTO "django_geo_db_zipcode" VALUES(3299,8560,-5,'Titusville, New Jersey 8560',2480,3148);
INSERT INTO "django_geo_db_zipcode" VALUES(3300,8561,-5,'Windsor, New Jersey 8561',2481,3149);
INSERT INTO "django_geo_db_zipcode" VALUES(3301,8562,-5,'Wrightstown, New Jersey 8562',2482,3150);
INSERT INTO "django_geo_db_zipcode" VALUES(3302,8570,-5,'Cranbury, New Jersey 8570',2456,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3303,8601,-5,'Trenton, New Jersey 8601',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3304,8602,-5,'Trenton, New Jersey 8602',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3305,8603,-5,'Trenton, New Jersey 8603',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3306,8604,-5,'Trenton, New Jersey 8604',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3307,8605,-5,'Trenton, New Jersey 8605',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3308,8606,-5,'Trenton, New Jersey 8606',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3309,8607,-5,'Trenton, New Jersey 8607',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3310,8608,-5,'Trenton, New Jersey 8608',2483,3152);
INSERT INTO "django_geo_db_zipcode" VALUES(3311,8609,-5,'Trenton, New Jersey 8609',2483,3153);
INSERT INTO "django_geo_db_zipcode" VALUES(3312,8610,-5,'Trenton, New Jersey 8610',2483,3154);
INSERT INTO "django_geo_db_zipcode" VALUES(3313,8611,-5,'Trenton, New Jersey 8611',2483,3155);
INSERT INTO "django_geo_db_zipcode" VALUES(3314,8618,-5,'Trenton, New Jersey 8618',2483,3156);
INSERT INTO "django_geo_db_zipcode" VALUES(3315,8619,-5,'Trenton, New Jersey 8619',2483,3157);
INSERT INTO "django_geo_db_zipcode" VALUES(3316,8620,-5,'Trenton, New Jersey 8620',2483,3158);
INSERT INTO "django_geo_db_zipcode" VALUES(3317,8625,-5,'Trenton, New Jersey 8625',2483,3159);
INSERT INTO "django_geo_db_zipcode" VALUES(3318,8628,-5,'Trenton, New Jersey 8628',2483,3160);
INSERT INTO "django_geo_db_zipcode" VALUES(3319,8629,-5,'Trenton, New Jersey 8629',2483,3161);
INSERT INTO "django_geo_db_zipcode" VALUES(3320,8638,-5,'Trenton, New Jersey 8638',2483,3162);
INSERT INTO "django_geo_db_zipcode" VALUES(3321,8640,-5,'Trenton, New Jersey 8640',2483,3163);
INSERT INTO "django_geo_db_zipcode" VALUES(3322,8641,-5,'Trenton, New Jersey 8641',2483,3164);
INSERT INTO "django_geo_db_zipcode" VALUES(3323,8645,-5,'Trenton, New Jersey 8645',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3324,8646,-5,'Trenton, New Jersey 8646',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3325,8647,-5,'Trenton, New Jersey 8647',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3326,8648,-5,'Trenton, New Jersey 8648',2483,3165);
INSERT INTO "django_geo_db_zipcode" VALUES(3327,8650,-5,'Trenton, New Jersey 8650',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3328,8666,-5,'Trenton, New Jersey 8666',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3329,8677,-5,'Trenton, New Jersey 8677',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3330,8690,-5,'Trenton, New Jersey 8690',2483,3166);
INSERT INTO "django_geo_db_zipcode" VALUES(3331,8691,-5,'Trenton, New Jersey 8691',2483,3167);
INSERT INTO "django_geo_db_zipcode" VALUES(3332,8695,-5,'Trenton, New Jersey 8695',2483,3136);
INSERT INTO "django_geo_db_zipcode" VALUES(3333,8701,-5,'Lakewood, New Jersey 8701',2484,3168);
INSERT INTO "django_geo_db_zipcode" VALUES(3334,8720,-5,'Allenwood, New Jersey 8720',2485,3169);
INSERT INTO "django_geo_db_zipcode" VALUES(3335,8721,-5,'Bayville, New Jersey 8721',2486,3170);
INSERT INTO "django_geo_db_zipcode" VALUES(3336,8722,-5,'Beachwood, New Jersey 8722',2487,3171);
INSERT INTO "django_geo_db_zipcode" VALUES(3337,8723,-5,'Brick, New Jersey 8723',2488,3172);
INSERT INTO "django_geo_db_zipcode" VALUES(3338,8724,-5,'Brick, New Jersey 8724',2488,3173);
INSERT INTO "django_geo_db_zipcode" VALUES(3339,8730,-5,'Brielle, New Jersey 8730',2489,3174);
INSERT INTO "django_geo_db_zipcode" VALUES(3340,8731,-5,'Forked River, New Jersey 8731',2490,3175);
INSERT INTO "django_geo_db_zipcode" VALUES(3341,8732,-5,'Island Heights, New Jersey 8732',2491,3176);
INSERT INTO "django_geo_db_zipcode" VALUES(3342,8733,-5,'Lakehurst, New Jersey 8733',2492,3177);
INSERT INTO "django_geo_db_zipcode" VALUES(3343,8734,-5,'Lanoka Harbor, New Jersey 8734',2493,3178);
INSERT INTO "django_geo_db_zipcode" VALUES(3344,8735,-5,'Lavallette, New Jersey 8735',2494,3179);
INSERT INTO "django_geo_db_zipcode" VALUES(3345,8736,-5,'Manasquan, New Jersey 8736',2495,3180);
INSERT INTO "django_geo_db_zipcode" VALUES(3346,8738,-5,'Mantoloking, New Jersey 8738',2496,3181);
INSERT INTO "django_geo_db_zipcode" VALUES(3347,8739,-5,'Normandy Beach, New Jersey 8739',2497,3182);
INSERT INTO "django_geo_db_zipcode" VALUES(3348,8740,-5,'Ocean Gate, New Jersey 8740',2498,3183);
INSERT INTO "django_geo_db_zipcode" VALUES(3349,8741,-5,'Pine Beach, New Jersey 8741',2499,3184);
INSERT INTO "django_geo_db_zipcode" VALUES(3350,8742,-5,'Point Pleasant Beach, New Jersey 8742',2500,3185);
INSERT INTO "django_geo_db_zipcode" VALUES(3351,8750,-5,'Sea Girt, New Jersey 8750',2501,3186);
INSERT INTO "django_geo_db_zipcode" VALUES(3352,8751,-5,'Seaside Heights, New Jersey 8751',2502,3187);
INSERT INTO "django_geo_db_zipcode" VALUES(3353,8752,-5,'Seaside Park, New Jersey 8752',2503,3188);
INSERT INTO "django_geo_db_zipcode" VALUES(3354,8753,-5,'Toms River, New Jersey 8753',2504,3189);
INSERT INTO "django_geo_db_zipcode" VALUES(3355,8754,-5,'Toms River, New Jersey 8754',2504,3182);
INSERT INTO "django_geo_db_zipcode" VALUES(3356,8755,-5,'Toms River, New Jersey 8755',2504,3190);
INSERT INTO "django_geo_db_zipcode" VALUES(3357,8756,-5,'Toms River, New Jersey 8756',2504,3191);
INSERT INTO "django_geo_db_zipcode" VALUES(3358,8757,-5,'Toms River, New Jersey 8757',2504,3192);
INSERT INTO "django_geo_db_zipcode" VALUES(3359,8758,-5,'Waretown, New Jersey 8758',2505,3193);
INSERT INTO "django_geo_db_zipcode" VALUES(3360,8759,-5,'Whiting, New Jersey 8759',2506,3194);
INSERT INTO "django_geo_db_zipcode" VALUES(3361,8792,-5,'Berkeley, New Jersey 8792',2507,3195);
INSERT INTO "django_geo_db_zipcode" VALUES(3362,8801,-5,'Annandale, New Jersey 8801',2508,3196);
INSERT INTO "django_geo_db_zipcode" VALUES(3363,8802,-5,'Asbury, New Jersey 8802',2509,3197);
INSERT INTO "django_geo_db_zipcode" VALUES(3364,8803,-5,'Baptistown, New Jersey 8803',2510,3145);
INSERT INTO "django_geo_db_zipcode" VALUES(3365,8804,-5,'Bloomsbury, New Jersey 8804',2511,3198);
INSERT INTO "django_geo_db_zipcode" VALUES(3366,8805,-5,'Bound Brook, New Jersey 8805',2512,3199);
INSERT INTO "django_geo_db_zipcode" VALUES(3367,8807,-5,'Bridgewater, New Jersey 8807',2513,3200);
INSERT INTO "django_geo_db_zipcode" VALUES(3368,8808,-5,'Broadway, New Jersey 8808',2514,3201);
INSERT INTO "django_geo_db_zipcode" VALUES(3369,8809,-5,'Clinton, New Jersey 8809',2515,3202);
INSERT INTO "django_geo_db_zipcode" VALUES(3370,8810,-5,'Dayton, New Jersey 8810',2516,3203);
INSERT INTO "django_geo_db_zipcode" VALUES(3371,8812,-5,'Dunellen, New Jersey 8812',2517,3204);
INSERT INTO "django_geo_db_zipcode" VALUES(3372,8816,-5,'East Brunswick, New Jersey 8816',2518,3205);
INSERT INTO "django_geo_db_zipcode" VALUES(3373,8817,-5,'Edison, New Jersey 8817',2519,3206);
INSERT INTO "django_geo_db_zipcode" VALUES(3374,8818,-5,'Edison, New Jersey 8818',2519,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3375,8820,-5,'Edison, New Jersey 8820',2519,3207);
INSERT INTO "django_geo_db_zipcode" VALUES(3376,8821,-5,'Flagtown, New Jersey 8821',2520,3208);
INSERT INTO "django_geo_db_zipcode" VALUES(3377,8822,-5,'Flemington, New Jersey 8822',2521,3209);
INSERT INTO "django_geo_db_zipcode" VALUES(3378,8823,-5,'Franklin Park, New Jersey 8823',2522,3210);
INSERT INTO "django_geo_db_zipcode" VALUES(3379,8824,-5,'Kendall Park, New Jersey 8824',2523,3211);
INSERT INTO "django_geo_db_zipcode" VALUES(3380,8825,-5,'Frenchtown, New Jersey 8825',2524,3212);
INSERT INTO "django_geo_db_zipcode" VALUES(3381,8826,-5,'Glen Gardner, New Jersey 8826',2525,3213);
INSERT INTO "django_geo_db_zipcode" VALUES(3382,8827,-5,'Hampton, New Jersey 8827',2526,3214);
INSERT INTO "django_geo_db_zipcode" VALUES(3383,8828,-5,'Helmetta, New Jersey 8828',2527,3215);
INSERT INTO "django_geo_db_zipcode" VALUES(3384,8829,-5,'High Bridge, New Jersey 8829',2528,3216);
INSERT INTO "django_geo_db_zipcode" VALUES(3385,8830,-5,'Iselin, New Jersey 8830',2529,3217);
INSERT INTO "django_geo_db_zipcode" VALUES(3386,8831,-5,'Jamesburg, New Jersey 8831',2530,3218);
INSERT INTO "django_geo_db_zipcode" VALUES(3387,8832,-5,'Keasbey, New Jersey 8832',2531,3219);
INSERT INTO "django_geo_db_zipcode" VALUES(3388,8833,-5,'Lebanon, New Jersey 8833',2532,3220);
INSERT INTO "django_geo_db_zipcode" VALUES(3389,8834,-5,'Little York, New Jersey 8834',2533,3145);
INSERT INTO "django_geo_db_zipcode" VALUES(3390,8835,-5,'Manville, New Jersey 8835',2534,3221);
INSERT INTO "django_geo_db_zipcode" VALUES(3391,8836,-5,'Martinsville, New Jersey 8836',2535,3222);
INSERT INTO "django_geo_db_zipcode" VALUES(3392,8837,-5,'Edison, New Jersey 8837',2519,3223);
INSERT INTO "django_geo_db_zipcode" VALUES(3393,8840,-5,'Metuchen, New Jersey 8840',2536,3224);
INSERT INTO "django_geo_db_zipcode" VALUES(3394,8844,-5,'Millstone, New Jersey 8844',2537,3225);
INSERT INTO "django_geo_db_zipcode" VALUES(3395,8846,-5,'Middlesex, New Jersey 8846',2538,3226);
INSERT INTO "django_geo_db_zipcode" VALUES(3396,8848,-5,'Milford, New Jersey 8848',2539,3227);
INSERT INTO "django_geo_db_zipcode" VALUES(3397,8850,-5,'Milltown, New Jersey 8850',2540,3228);
INSERT INTO "django_geo_db_zipcode" VALUES(3398,8851,-5,'East Amwell, New Jersey 8851',2541,3229);
INSERT INTO "django_geo_db_zipcode" VALUES(3399,8852,-5,'Monmouth Junction, New Jersey 8852',2542,3230);
INSERT INTO "django_geo_db_zipcode" VALUES(3400,8853,-5,'Neshanic Station, New Jersey 8853',2543,3231);
INSERT INTO "django_geo_db_zipcode" VALUES(3401,8854,-5,'Piscataway, New Jersey 8854',2544,3232);
INSERT INTO "django_geo_db_zipcode" VALUES(3402,8855,-5,'Piscataway, New Jersey 8855',2544,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3403,8857,-5,'Old Bridge, New Jersey 8857',2545,3233);
INSERT INTO "django_geo_db_zipcode" VALUES(3404,8858,-5,'Oldwick, New Jersey 8858',2546,3234);
INSERT INTO "django_geo_db_zipcode" VALUES(3405,8859,-5,'Parlin, New Jersey 8859',2547,3235);
INSERT INTO "django_geo_db_zipcode" VALUES(3406,8861,-5,'Perth Amboy, New Jersey 8861',2548,3236);
INSERT INTO "django_geo_db_zipcode" VALUES(3407,8862,-5,'Perth Amboy, New Jersey 8862',2548,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3408,8863,-5,'Fords, New Jersey 8863',2549,3237);
INSERT INTO "django_geo_db_zipcode" VALUES(3409,8865,-5,'Phillipsburg, New Jersey 8865',2550,3238);
INSERT INTO "django_geo_db_zipcode" VALUES(3410,8867,-5,'Pittstown, New Jersey 8867',2551,3239);
INSERT INTO "django_geo_db_zipcode" VALUES(3411,8868,-5,'Quakertown, New Jersey 8868',2552,3240);
INSERT INTO "django_geo_db_zipcode" VALUES(3412,8869,-5,'Raritan, New Jersey 8869',2553,3241);
INSERT INTO "django_geo_db_zipcode" VALUES(3413,8870,-5,'Readington, New Jersey 8870',2554,3145);
INSERT INTO "django_geo_db_zipcode" VALUES(3414,8871,-5,'Sayreville, New Jersey 8871',2555,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3415,8872,-5,'Sayreville, New Jersey 8872',2555,3242);
INSERT INTO "django_geo_db_zipcode" VALUES(3416,8873,-5,'Somerset, New Jersey 8873',2556,3243);
INSERT INTO "django_geo_db_zipcode" VALUES(3417,8875,-5,'Somerset, New Jersey 8875',2556,3244);
INSERT INTO "django_geo_db_zipcode" VALUES(3418,8876,-5,'Somerville, New Jersey 8876',2557,3245);
INSERT INTO "django_geo_db_zipcode" VALUES(3419,8877,-5,'South River, New Jersey 8877',2558,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3420,8878,-5,'South Amboy, New Jersey 8878',2559,3246);
INSERT INTO "django_geo_db_zipcode" VALUES(3421,8879,-5,'South Amboy, New Jersey 8879',2559,3247);
INSERT INTO "django_geo_db_zipcode" VALUES(3422,8880,-5,'South Bound Brook, New Jersey 8880',2560,3248);
INSERT INTO "django_geo_db_zipcode" VALUES(3423,8882,-5,'South River, New Jersey 8882',2558,3249);
INSERT INTO "django_geo_db_zipcode" VALUES(3424,8884,-5,'Spotswood, New Jersey 8884',2561,3250);
INSERT INTO "django_geo_db_zipcode" VALUES(3425,8885,-5,'Stanton, New Jersey 8885',2562,3251);
INSERT INTO "django_geo_db_zipcode" VALUES(3426,8886,-5,'Stewartsville, New Jersey 8886',2563,3252);
INSERT INTO "django_geo_db_zipcode" VALUES(3427,8887,-5,'Three Bridges, New Jersey 8887',2564,3253);
INSERT INTO "django_geo_db_zipcode" VALUES(3428,8888,-5,'Whitehouse, New Jersey 8888',2565,3254);
INSERT INTO "django_geo_db_zipcode" VALUES(3429,8889,-5,'Whitehouse Station, New Jersey 8889',2566,3255);
INSERT INTO "django_geo_db_zipcode" VALUES(3430,8890,-5,'Zarephath, New Jersey 8890',2567,3256);
INSERT INTO "django_geo_db_zipcode" VALUES(3431,8896,-5,'Raritan, New Jersey 8896',2553,2918);
INSERT INTO "django_geo_db_zipcode" VALUES(3432,8899,-5,'Edison, New Jersey 8899',2519,3257);
INSERT INTO "django_geo_db_zipcode" VALUES(3433,8901,-5,'New Brunswick, New Jersey 8901',2568,3258);
INSERT INTO "django_geo_db_zipcode" VALUES(3434,8902,-5,'North Brunswick, New Jersey 8902',2569,3259);
INSERT INTO "django_geo_db_zipcode" VALUES(3435,8903,-5,'New Brunswick, New Jersey 8903',2568,3260);
INSERT INTO "django_geo_db_zipcode" VALUES(3436,8904,-5,'Highland Park, New Jersey 8904',2570,3261);
INSERT INTO "django_geo_db_zipcode" VALUES(3437,8905,-5,'New Brunswick, New Jersey 8905',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3438,8906,-5,'New Brunswick, New Jersey 8906',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3439,8907,-5,'New Brunswick, New Jersey 8907',2568,3262);
INSERT INTO "django_geo_db_zipcode" VALUES(3440,8922,-5,'New Brunswick, New Jersey 8922',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3441,8933,-5,'New Brunswick, New Jersey 8933',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3442,8988,-5,'New Brunswick, New Jersey 8988',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3443,8989,-5,'New Brunswick, New Jersey 8989',2568,3151);
INSERT INTO "django_geo_db_zipcode" VALUES(3444,10001,-5,'New York, New York 10001',2571,3263);
INSERT INTO "django_geo_db_zipcode" VALUES(3445,10002,-5,'New York, New York 10002',2571,3264);
INSERT INTO "django_geo_db_zipcode" VALUES(3446,10003,-5,'New York, New York 10003',2571,3265);
INSERT INTO "django_geo_db_zipcode" VALUES(3447,10004,-5,'New York, New Jersey 10004',2572,3266);
INSERT INTO "django_geo_db_zipcode" VALUES(3448,10005,-5,'New York, New York 10005',2571,3267);
INSERT INTO "django_geo_db_zipcode" VALUES(3449,10006,-5,'New York, New York 10006',2571,3268);
INSERT INTO "django_geo_db_zipcode" VALUES(3450,10007,-5,'New York, New York 10007',2571,3269);
INSERT INTO "django_geo_db_zipcode" VALUES(3451,10008,-5,'New York, New York 10008',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3452,10009,-5,'New York, New York 10009',2571,3271);
INSERT INTO "django_geo_db_zipcode" VALUES(3453,10010,-5,'New York, New York 10010',2571,3272);
INSERT INTO "django_geo_db_zipcode" VALUES(3454,10011,-5,'New York, New York 10011',2571,3273);
INSERT INTO "django_geo_db_zipcode" VALUES(3455,10012,-5,'New York, New York 10012',2571,3274);
INSERT INTO "django_geo_db_zipcode" VALUES(3456,10013,-5,'New York, New York 10013',2571,3275);
INSERT INTO "django_geo_db_zipcode" VALUES(3457,10014,-5,'New York, New York 10014',2571,3276);
INSERT INTO "django_geo_db_zipcode" VALUES(3458,10015,-5,'New York, New York 10015',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3459,10016,-5,'New York, New York 10016',2571,3277);
INSERT INTO "django_geo_db_zipcode" VALUES(3460,10017,-5,'New York, New York 10017',2571,3278);
INSERT INTO "django_geo_db_zipcode" VALUES(3461,10018,-5,'New York, New York 10018',2571,3279);
INSERT INTO "django_geo_db_zipcode" VALUES(3462,10019,-5,'New York, New York 10019',2571,3280);
INSERT INTO "django_geo_db_zipcode" VALUES(3463,10020,-5,'New York, New York 10020',2571,3281);
INSERT INTO "django_geo_db_zipcode" VALUES(3464,10021,-5,'New York, New York 10021',2571,3282);
INSERT INTO "django_geo_db_zipcode" VALUES(3465,10022,-5,'New York, New York 10022',2571,3283);
INSERT INTO "django_geo_db_zipcode" VALUES(3466,10023,-5,'New York, New York 10023',2571,3284);
INSERT INTO "django_geo_db_zipcode" VALUES(3467,10024,-5,'New York, New York 10024',2571,3285);
INSERT INTO "django_geo_db_zipcode" VALUES(3468,10025,-5,'New York, New York 10025',2571,3286);
INSERT INTO "django_geo_db_zipcode" VALUES(3469,10026,-5,'New York, New York 10026',2571,3287);
INSERT INTO "django_geo_db_zipcode" VALUES(3470,10027,-5,'New York, New York 10027',2571,3288);
INSERT INTO "django_geo_db_zipcode" VALUES(3471,10028,-5,'New York, New York 10028',2571,3289);
INSERT INTO "django_geo_db_zipcode" VALUES(3472,10029,-5,'New York, New York 10029',2571,3290);
INSERT INTO "django_geo_db_zipcode" VALUES(3473,10030,-5,'New York, New York 10030',2571,3291);
INSERT INTO "django_geo_db_zipcode" VALUES(3474,10031,-5,'New York, New York 10031',2571,3292);
INSERT INTO "django_geo_db_zipcode" VALUES(3475,10032,-5,'New York, New York 10032',2571,3293);
INSERT INTO "django_geo_db_zipcode" VALUES(3476,10033,-5,'New York, New York 10033',2571,3294);
INSERT INTO "django_geo_db_zipcode" VALUES(3477,10034,-5,'New York, New York 10034',2571,3295);
INSERT INTO "django_geo_db_zipcode" VALUES(3478,10035,-5,'New York, New York 10035',2571,3296);
INSERT INTO "django_geo_db_zipcode" VALUES(3479,10036,-5,'New York, New York 10036',2571,3297);
INSERT INTO "django_geo_db_zipcode" VALUES(3480,10037,-5,'New York, New York 10037',2571,3298);
INSERT INTO "django_geo_db_zipcode" VALUES(3481,10038,-5,'New York, New York 10038',2571,3299);
INSERT INTO "django_geo_db_zipcode" VALUES(3482,10039,-5,'New York, New York 10039',2571,3300);
INSERT INTO "django_geo_db_zipcode" VALUES(3483,10040,-5,'New York, New York 10040',2571,3301);
INSERT INTO "django_geo_db_zipcode" VALUES(3484,10041,-5,'New York, New York 10041',2571,3302);
INSERT INTO "django_geo_db_zipcode" VALUES(3485,10043,-5,'New York, New York 10043',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3486,10044,-5,'New York, New York 10044',2571,3303);
INSERT INTO "django_geo_db_zipcode" VALUES(3487,10045,-5,'New York, New York 10045',2571,3304);
INSERT INTO "django_geo_db_zipcode" VALUES(3488,10046,-5,'New York, New York 10046',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3489,10047,-5,'New York, New York 10047',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3490,10048,-5,'New York, New York 10048',2571,3305);
INSERT INTO "django_geo_db_zipcode" VALUES(3491,10055,-5,'New York, New York 10055',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3492,10060,-5,'New York, New York 10060',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3493,10069,-5,'New York, New York 10069',2571,3306);
INSERT INTO "django_geo_db_zipcode" VALUES(3494,10072,-5,'New York, New York 10072',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3495,10079,-5,'New York, New York 10079',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3496,10080,-5,'New York, New York 10080',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3497,10081,-5,'New York, New York 10081',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3498,10082,-5,'New York, New York 10082',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3499,10087,-5,'New York, New York 10087',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3500,10090,-5,'New York, New York 10090',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3501,10094,-5,'New York, New York 10094',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3502,10095,-5,'New York, New York 10095',2571,3307);
INSERT INTO "django_geo_db_zipcode" VALUES(3503,10096,-5,'New York, New York 10096',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3504,10098,-5,'New York, New York 10098',2571,3307);
INSERT INTO "django_geo_db_zipcode" VALUES(3505,10099,-5,'New York, New York 10099',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3506,10101,-5,'New York, New York 10101',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3507,10102,-5,'New York, New York 10102',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3508,10103,-5,'New York, New York 10103',2571,3308);
INSERT INTO "django_geo_db_zipcode" VALUES(3509,10104,-5,'New York, New York 10104',2571,3309);
INSERT INTO "django_geo_db_zipcode" VALUES(3510,10105,-5,'New York, New York 10105',2571,3310);
INSERT INTO "django_geo_db_zipcode" VALUES(3511,10106,-5,'New York, New York 10106',2571,3311);
INSERT INTO "django_geo_db_zipcode" VALUES(3512,10107,-5,'New York, New York 10107',2571,3312);
INSERT INTO "django_geo_db_zipcode" VALUES(3513,10108,-5,'New York, New York 10108',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3514,10109,-5,'New York, New York 10109',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3515,10110,-5,'New York, New York 10110',2571,3313);
INSERT INTO "django_geo_db_zipcode" VALUES(3516,10111,-5,'New York, New York 10111',2571,3314);
INSERT INTO "django_geo_db_zipcode" VALUES(3517,10112,-5,'New York, New York 10112',2571,3315);
INSERT INTO "django_geo_db_zipcode" VALUES(3518,10113,-5,'New York, New York 10113',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3519,10114,-5,'New York, New York 10114',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3520,10115,-5,'New York, New York 10115',2571,3316);
INSERT INTO "django_geo_db_zipcode" VALUES(3521,10116,-5,'New York, New York 10116',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3522,10117,-5,'New York, New York 10117',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3523,10118,-5,'New York, New York 10118',2571,3317);
INSERT INTO "django_geo_db_zipcode" VALUES(3524,10119,-5,'New York, New York 10119',2571,3318);
INSERT INTO "django_geo_db_zipcode" VALUES(3525,10120,-5,'New York, New York 10120',2571,3319);
INSERT INTO "django_geo_db_zipcode" VALUES(3526,10121,-5,'New York, New York 10121',2571,3320);
INSERT INTO "django_geo_db_zipcode" VALUES(3527,10122,-5,'New York, New York 10122',2571,3321);
INSERT INTO "django_geo_db_zipcode" VALUES(3528,10123,-5,'New York, New York 10123',2571,3322);
INSERT INTO "django_geo_db_zipcode" VALUES(3529,10124,-5,'New York, New York 10124',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3530,10125,-5,'New York, New York 10125',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3531,10126,-5,'New York, New York 10126',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3532,10128,-5,'New York, New York 10128',2571,3323);
INSERT INTO "django_geo_db_zipcode" VALUES(3533,10129,-5,'New York, New York 10129',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3534,10130,-5,'New York, New York 10130',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3535,10131,-5,'New York, New York 10131',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3536,10132,-5,'New York, New York 10132',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3537,10133,-5,'New York, New York 10133',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3538,10138,-5,'New York, New York 10138',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3539,10149,-5,'New York, New York 10149',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3540,10150,-5,'New York, New York 10150',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3541,10151,-5,'New York, New York 10151',2571,3324);
INSERT INTO "django_geo_db_zipcode" VALUES(3542,10152,-5,'New York, New York 10152',2571,3325);
INSERT INTO "django_geo_db_zipcode" VALUES(3543,10153,-5,'New York, New York 10153',2571,3326);
INSERT INTO "django_geo_db_zipcode" VALUES(3544,10154,-5,'New York, New York 10154',2571,3327);
INSERT INTO "django_geo_db_zipcode" VALUES(3545,10155,-5,'New York, New York 10155',2571,3328);
INSERT INTO "django_geo_db_zipcode" VALUES(3546,10156,-5,'New York, New York 10156',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3547,10157,-5,'New York, New York 10157',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3548,10158,-5,'New York, New York 10158',2571,3329);
INSERT INTO "django_geo_db_zipcode" VALUES(3549,10159,-5,'New York, New York 10159',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3550,10160,-5,'New York, New York 10160',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3551,10161,-5,'New York, New York 10161',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3552,10162,-5,'New York, New York 10162',2571,3330);
INSERT INTO "django_geo_db_zipcode" VALUES(3553,10163,-5,'New York, New York 10163',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3554,10164,-5,'New York, New York 10164',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3555,10165,-5,'New York, New York 10165',2571,3331);
INSERT INTO "django_geo_db_zipcode" VALUES(3556,10166,-5,'New York, New York 10166',2571,3332);
INSERT INTO "django_geo_db_zipcode" VALUES(3557,10167,-5,'New York, New York 10167',2571,3333);
INSERT INTO "django_geo_db_zipcode" VALUES(3558,10168,-5,'New York, New York 10168',2571,3334);
INSERT INTO "django_geo_db_zipcode" VALUES(3559,10169,-5,'New York, New York 10169',2571,3335);
INSERT INTO "django_geo_db_zipcode" VALUES(3560,10170,-5,'New York, New York 10170',2571,3336);
INSERT INTO "django_geo_db_zipcode" VALUES(3561,10171,-5,'New York, New York 10171',2571,3337);
INSERT INTO "django_geo_db_zipcode" VALUES(3562,10172,-5,'New York, New York 10172',2571,3338);
INSERT INTO "django_geo_db_zipcode" VALUES(3563,10173,-5,'New York, New York 10173',2571,3339);
INSERT INTO "django_geo_db_zipcode" VALUES(3564,10174,-5,'New York, New York 10174',2571,3340);
INSERT INTO "django_geo_db_zipcode" VALUES(3565,10175,-5,'New York, New York 10175',2571,3341);
INSERT INTO "django_geo_db_zipcode" VALUES(3566,10176,-5,'New York, New York 10176',2571,3342);
INSERT INTO "django_geo_db_zipcode" VALUES(3567,10177,-5,'New York, New York 10177',2571,3343);
INSERT INTO "django_geo_db_zipcode" VALUES(3568,10178,-5,'New York, New York 10178',2571,3344);
INSERT INTO "django_geo_db_zipcode" VALUES(3569,10179,-5,'New York, New York 10179',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3570,10184,-5,'New York, New York 10184',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3571,10185,-5,'New York, New York 10185',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3572,10196,-5,'New York, New York 10196',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3573,10197,-5,'New York, New York 10197',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3574,10199,-5,'New York, New York 10199',2571,3345);
INSERT INTO "django_geo_db_zipcode" VALUES(3575,10203,-5,'New York, New York 10203',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3576,10211,-5,'New York, New York 10211',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3577,10212,-5,'New York, New York 10212',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3578,10213,-5,'New York, New York 10213',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3579,10242,-5,'New York, New York 10242',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3580,10249,-5,'New York, New York 10249',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3581,10250,-5,'New York, New York 10250',2571,3346);
INSERT INTO "django_geo_db_zipcode" VALUES(3582,10256,-5,'New York, New York 10256',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3583,10257,-5,'New York, New York 10257',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3584,10258,-5,'New York, New York 10258',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3585,10259,-5,'New York, New York 10259',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3586,10260,-5,'New York, New York 10260',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3587,10261,-5,'New York, New York 10261',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3588,10265,-5,'New York, New York 10265',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3589,10268,-5,'New York, New York 10268',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3590,10269,-5,'New York, New York 10269',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3591,10270,-5,'New York, New York 10270',2571,3347);
INSERT INTO "django_geo_db_zipcode" VALUES(3592,10271,-5,'New York, New York 10271',2571,3348);
INSERT INTO "django_geo_db_zipcode" VALUES(3593,10272,-5,'New York, New York 10272',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3594,10273,-5,'New York, New York 10273',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3595,10274,-5,'New York, New York 10274',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3596,10275,-5,'New York, New York 10275',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3597,10276,-5,'New York, New York 10276',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3598,10277,-5,'New York, New York 10277',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3599,10278,-5,'New York, New York 10278',2571,3349);
INSERT INTO "django_geo_db_zipcode" VALUES(3600,10279,-5,'New York, New York 10279',2571,3350);
INSERT INTO "django_geo_db_zipcode" VALUES(3601,10280,-5,'New York, New York 10280',2571,3351);
INSERT INTO "django_geo_db_zipcode" VALUES(3602,10281,-5,'New York, New York 10281',2571,3352);
INSERT INTO "django_geo_db_zipcode" VALUES(3603,10282,-5,'New York, New York 10282',2571,3353);
INSERT INTO "django_geo_db_zipcode" VALUES(3604,10285,-5,'New York, New York 10285',2571,3354);
INSERT INTO "django_geo_db_zipcode" VALUES(3605,10286,-5,'New York, New York 10286',2571,3355);
INSERT INTO "django_geo_db_zipcode" VALUES(3606,10292,-5,'New York, New York 10292',2571,3270);
INSERT INTO "django_geo_db_zipcode" VALUES(3607,10301,-5,'Staten Island, New York 10301',2573,3356);
INSERT INTO "django_geo_db_zipcode" VALUES(3608,10302,-5,'Staten Island, New York 10302',2573,3357);
INSERT INTO "django_geo_db_zipcode" VALUES(3609,10303,-5,'Staten Island, New York 10303',2573,3358);
INSERT INTO "django_geo_db_zipcode" VALUES(3610,10304,-5,'Staten Island, New York 10304',2573,3359);
INSERT INTO "django_geo_db_zipcode" VALUES(3611,10305,-5,'Staten Island, New York 10305',2573,3360);
INSERT INTO "django_geo_db_zipcode" VALUES(3612,10306,-5,'Staten Island, New York 10306',2573,3361);
INSERT INTO "django_geo_db_zipcode" VALUES(3613,10307,-5,'Staten Island, New York 10307',2573,3362);
INSERT INTO "django_geo_db_zipcode" VALUES(3614,10308,-5,'Staten Island, New York 10308',2573,3363);
INSERT INTO "django_geo_db_zipcode" VALUES(3615,10309,-5,'Staten Island, New York 10309',2573,3364);
INSERT INTO "django_geo_db_zipcode" VALUES(3616,10310,-5,'Staten Island, New York 10310',2573,3365);
INSERT INTO "django_geo_db_zipcode" VALUES(3617,10311,-5,'Staten Island, New York 10311',2573,3366);
INSERT INTO "django_geo_db_zipcode" VALUES(3618,10312,-5,'Staten Island, New York 10312',2573,3367);
INSERT INTO "django_geo_db_zipcode" VALUES(3619,10313,-5,'Staten Island, New York 10313',2573,3368);
INSERT INTO "django_geo_db_zipcode" VALUES(3620,10314,-5,'Staten Island, New York 10314',2573,3369);
INSERT INTO "django_geo_db_zipcode" VALUES(3621,10422,-5,'New York, New York 10422',2571,3370);
INSERT INTO "django_geo_db_zipcode" VALUES(3622,10451,-5,'Bronx, New York 10451',2574,3371);
INSERT INTO "django_geo_db_zipcode" VALUES(3623,10452,-5,'Bronx, New York 10452',2574,3372);
INSERT INTO "django_geo_db_zipcode" VALUES(3624,10453,-5,'Bronx, New York 10453',2574,3373);
INSERT INTO "django_geo_db_zipcode" VALUES(3625,10454,-5,'Bronx, New York 10454',2574,3374);
INSERT INTO "django_geo_db_zipcode" VALUES(3626,10455,-5,'Bronx, New York 10455',2574,3375);
INSERT INTO "django_geo_db_zipcode" VALUES(3627,10456,-5,'Bronx, New York 10456',2574,3376);
INSERT INTO "django_geo_db_zipcode" VALUES(3628,10457,-5,'Bronx, New York 10457',2574,3377);
INSERT INTO "django_geo_db_zipcode" VALUES(3629,10458,-5,'Bronx, New York 10458',2574,3378);
INSERT INTO "django_geo_db_zipcode" VALUES(3630,10459,-5,'Bronx, New York 10459',2574,3379);
INSERT INTO "django_geo_db_zipcode" VALUES(3631,10460,-5,'Bronx, New York 10460',2574,3380);
INSERT INTO "django_geo_db_zipcode" VALUES(3632,10461,-5,'Bronx, New York 10461',2574,3381);
INSERT INTO "django_geo_db_zipcode" VALUES(3633,10462,-5,'Bronx, New York 10462',2574,3382);
INSERT INTO "django_geo_db_zipcode" VALUES(3634,10463,-5,'Bronx, New York 10463',2574,3383);
INSERT INTO "django_geo_db_zipcode" VALUES(3635,10464,-5,'Bronx, New York 10464',2574,3384);
INSERT INTO "django_geo_db_zipcode" VALUES(3636,10465,-5,'Bronx, New York 10465',2574,3385);
INSERT INTO "django_geo_db_zipcode" VALUES(3637,10466,-5,'Bronx, New York 10466',2574,3386);
INSERT INTO "django_geo_db_zipcode" VALUES(3638,10467,-5,'Bronx, New York 10467',2574,3387);
INSERT INTO "django_geo_db_zipcode" VALUES(3639,10468,-5,'Bronx, New York 10468',2574,3388);
INSERT INTO "django_geo_db_zipcode" VALUES(3640,10469,-5,'Bronx, New York 10469',2574,3389);
INSERT INTO "django_geo_db_zipcode" VALUES(3641,10470,-5,'Bronx, New York 10470',2574,3390);
INSERT INTO "django_geo_db_zipcode" VALUES(3642,10471,-5,'Bronx, New York 10471',2574,3391);
INSERT INTO "django_geo_db_zipcode" VALUES(3643,10472,-5,'Bronx, New York 10472',2574,3392);
INSERT INTO "django_geo_db_zipcode" VALUES(3644,10473,-5,'Bronx, New York 10473',2574,3393);
INSERT INTO "django_geo_db_zipcode" VALUES(3645,10474,-5,'Bronx, New York 10474',2574,3394);
INSERT INTO "django_geo_db_zipcode" VALUES(3646,10475,-5,'Bronx, New York 10475',2574,3395);
INSERT INTO "django_geo_db_zipcode" VALUES(3647,10499,-5,'Bronx, New York 10499',2574,3396);
INSERT INTO "django_geo_db_zipcode" VALUES(3648,10501,-5,'Amawalk, New York 10501',2575,3397);
INSERT INTO "django_geo_db_zipcode" VALUES(3649,10502,-5,'Ardsley, New York 10502',2576,3398);
INSERT INTO "django_geo_db_zipcode" VALUES(3650,10503,-5,'Ardsley On Hudson, New York 10503',2577,3399);
INSERT INTO "django_geo_db_zipcode" VALUES(3651,10504,-5,'Armonk, New York 10504',2578,3400);
INSERT INTO "django_geo_db_zipcode" VALUES(3652,10505,-5,'Baldwin Place, New York 10505',2579,3401);
INSERT INTO "django_geo_db_zipcode" VALUES(3653,10506,-5,'Bedford, New York 10506',2580,3402);
INSERT INTO "django_geo_db_zipcode" VALUES(3654,10507,-5,'Bedford Hills, New York 10507',2581,3403);
INSERT INTO "django_geo_db_zipcode" VALUES(3655,10509,-5,'Brewster, New York 10509',2582,3404);
INSERT INTO "django_geo_db_zipcode" VALUES(3656,10510,-5,'Briarcliff Manor, New York 10510',2583,3405);
INSERT INTO "django_geo_db_zipcode" VALUES(3657,10511,-5,'Buchanan, New York 10511',2584,3406);
INSERT INTO "django_geo_db_zipcode" VALUES(3658,10512,-5,'Carmel, New York 10512',2585,3407);
INSERT INTO "django_geo_db_zipcode" VALUES(3659,10514,-5,'Chappaqua, New York 10514',2586,3408);
INSERT INTO "django_geo_db_zipcode" VALUES(3660,10516,-5,'Cold Spring, New York 10516',2587,3409);
INSERT INTO "django_geo_db_zipcode" VALUES(3661,10517,-5,'Crompond, New York 10517',2588,3410);
INSERT INTO "django_geo_db_zipcode" VALUES(3662,10518,-5,'Cross River, New York 10518',2589,3411);
INSERT INTO "django_geo_db_zipcode" VALUES(3663,10519,-5,'Croton Falls, New York 10519',2590,3412);
INSERT INTO "django_geo_db_zipcode" VALUES(3664,10520,-5,'Croton On Hudson, New York 10520',2591,3413);
INSERT INTO "django_geo_db_zipcode" VALUES(3665,10521,-5,'Croton On Hudson, New York 10521',2591,3414);
INSERT INTO "django_geo_db_zipcode" VALUES(3666,10522,-5,'Dobbs Ferry, New York 10522',2592,3415);
INSERT INTO "django_geo_db_zipcode" VALUES(3667,10523,-5,'Elmsford, New York 10523',2593,3416);
INSERT INTO "django_geo_db_zipcode" VALUES(3668,10524,-5,'Garrison, New York 10524',2594,3417);
INSERT INTO "django_geo_db_zipcode" VALUES(3669,10526,-5,'Goldens Bridge, New York 10526',2595,3418);
INSERT INTO "django_geo_db_zipcode" VALUES(3670,10527,-5,'Granite Springs, New York 10527',2596,3419);
INSERT INTO "django_geo_db_zipcode" VALUES(3671,10528,-5,'Harrison, New York 10528',2597,3420);
INSERT INTO "django_geo_db_zipcode" VALUES(3672,10530,-5,'Hartsdale, New York 10530',2598,3421);
INSERT INTO "django_geo_db_zipcode" VALUES(3673,10532,-5,'Hawthorne, New York 10532',2599,3422);
INSERT INTO "django_geo_db_zipcode" VALUES(3674,10533,-5,'Irvington, New York 10533',2600,3423);
INSERT INTO "django_geo_db_zipcode" VALUES(3675,10535,-5,'Jefferson Valley, New York 10535',2601,3424);
INSERT INTO "django_geo_db_zipcode" VALUES(3676,10536,-5,'Katonah, New York 10536',2602,3425);
INSERT INTO "django_geo_db_zipcode" VALUES(3677,10537,-5,'Lake Peekskill, New York 10537',2603,3426);
INSERT INTO "django_geo_db_zipcode" VALUES(3678,10538,-5,'Larchmont, New York 10538',2604,3427);
INSERT INTO "django_geo_db_zipcode" VALUES(3679,10540,-5,'Lincolndale, New York 10540',2605,3428);
INSERT INTO "django_geo_db_zipcode" VALUES(3680,10541,-5,'Mahopac, New York 10541',2606,3429);
INSERT INTO "django_geo_db_zipcode" VALUES(3681,10542,-5,'Mahopac Falls, New York 10542',2607,3430);
INSERT INTO "django_geo_db_zipcode" VALUES(3682,10543,-5,'Mamaroneck, New York 10543',2608,3431);
INSERT INTO "django_geo_db_zipcode" VALUES(3683,10545,-5,'Maryknoll, New York 10545',2609,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3684,10546,-5,'Millwood, New York 10546',2610,3433);
INSERT INTO "django_geo_db_zipcode" VALUES(3685,10547,-5,'Mohegan Lake, New York 10547',2611,3434);
INSERT INTO "django_geo_db_zipcode" VALUES(3686,10548,-5,'Montrose, New York 10548',2612,3435);
INSERT INTO "django_geo_db_zipcode" VALUES(3687,10549,-5,'Mount Kisco, New York 10549',2613,3436);
INSERT INTO "django_geo_db_zipcode" VALUES(3688,10550,-5,'Mount Vernon, New York 10550',2614,3437);
INSERT INTO "django_geo_db_zipcode" VALUES(3689,10551,-5,'Mount Vernon, New York 10551',2614,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3690,10552,-5,'Mount Vernon, New York 10552',2614,3438);
INSERT INTO "django_geo_db_zipcode" VALUES(3691,10553,-5,'Mount Vernon, New York 10553',2614,3439);
INSERT INTO "django_geo_db_zipcode" VALUES(3692,10557,-5,'Mount Vernon, New York 10557',2614,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3693,10558,-5,'Mount Vernon, New York 10558',2614,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3694,10559,-5,'Mount Vernon, New York 10559',2614,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3695,10560,-5,'North Salem, New York 10560',2615,3440);
INSERT INTO "django_geo_db_zipcode" VALUES(3696,10562,-5,'Ossining, New York 10562',2616,3441);
INSERT INTO "django_geo_db_zipcode" VALUES(3697,10566,-5,'Peekskill, New York 10566',2617,3442);
INSERT INTO "django_geo_db_zipcode" VALUES(3698,10567,-5,'Cortlandt Manor, New York 10567',2618,3443);
INSERT INTO "django_geo_db_zipcode" VALUES(3699,10570,-5,'Pleasantville, New York 10570',2619,3444);
INSERT INTO "django_geo_db_zipcode" VALUES(3700,10571,-5,'Pleasantville, New York 10571',2619,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3701,10572,-5,'Pleasantville, New York 10572',2619,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3702,10573,-5,'Port Chester, New York 10573',2620,3445);
INSERT INTO "django_geo_db_zipcode" VALUES(3703,10576,-5,'Pound Ridge, New York 10576',2621,3446);
INSERT INTO "django_geo_db_zipcode" VALUES(3704,10577,-5,'Purchase, New York 10577',2622,3447);
INSERT INTO "django_geo_db_zipcode" VALUES(3705,10578,-5,'Purdys, New York 10578',2623,3448);
INSERT INTO "django_geo_db_zipcode" VALUES(3706,10579,-5,'Putnam Valley, New York 10579',2624,3449);
INSERT INTO "django_geo_db_zipcode" VALUES(3707,10580,-5,'Rye, New York 10580',2625,3450);
INSERT INTO "django_geo_db_zipcode" VALUES(3708,10581,-5,'Rye, New York 10581',2625,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3709,10583,-5,'Scarsdale, New York 10583',2626,3451);
INSERT INTO "django_geo_db_zipcode" VALUES(3710,10586,-5,'Greenville, New York 10586',2627,3452);
INSERT INTO "django_geo_db_zipcode" VALUES(3711,10587,-5,'Shenorock, New York 10587',2628,3453);
INSERT INTO "django_geo_db_zipcode" VALUES(3712,10588,-5,'Shrub Oak, New York 10588',2629,3454);
INSERT INTO "django_geo_db_zipcode" VALUES(3713,10589,-5,'Somers, New York 10589',2630,3455);
INSERT INTO "django_geo_db_zipcode" VALUES(3714,10590,-5,'South Salem, New York 10590',2631,3456);
INSERT INTO "django_geo_db_zipcode" VALUES(3715,10591,-5,'Tarrytown, New York 10591',2632,3457);
INSERT INTO "django_geo_db_zipcode" VALUES(3716,10592,-5,'Tarrytown, New York 10592',2632,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3717,10594,-5,'Thornwood, New York 10594',2633,3458);
INSERT INTO "django_geo_db_zipcode" VALUES(3718,10595,-5,'Valhalla, New York 10595',2634,3459);
INSERT INTO "django_geo_db_zipcode" VALUES(3719,10596,-5,'Verplanck, New York 10596',2635,3460);
INSERT INTO "django_geo_db_zipcode" VALUES(3720,10597,-5,'Waccabuc, New York 10597',2636,3461);
INSERT INTO "django_geo_db_zipcode" VALUES(3721,10598,-5,'Yorktown Heights, New York 10598',2637,3462);
INSERT INTO "django_geo_db_zipcode" VALUES(3722,10601,-5,'White Plains, New York 10601',2638,3463);
INSERT INTO "django_geo_db_zipcode" VALUES(3723,10602,-5,'White Plains, New York 10602',2638,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3724,10603,-5,'White Plains, New York 10603',2638,3464);
INSERT INTO "django_geo_db_zipcode" VALUES(3725,10604,-5,'West Harrison, New York 10604',2639,3465);
INSERT INTO "django_geo_db_zipcode" VALUES(3726,10605,-5,'White Plains, New York 10605',2638,3466);
INSERT INTO "django_geo_db_zipcode" VALUES(3727,10606,-5,'White Plains, New York 10606',2638,3467);
INSERT INTO "django_geo_db_zipcode" VALUES(3728,10607,-5,'White Plains, New York 10607',2638,3468);
INSERT INTO "django_geo_db_zipcode" VALUES(3729,10610,-5,'White Plains, New York 10610',2638,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3730,10625,-5,'White Plains, New York 10625',2638,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3731,10629,-5,'White Plains, New York 10629',2638,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3732,10633,-5,'White Plains, New York 10633',2638,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3733,10650,-5,'White Plains, New York 10650',2638,3469);
INSERT INTO "django_geo_db_zipcode" VALUES(3734,10701,-5,'Yonkers, New York 10701',2640,3470);
INSERT INTO "django_geo_db_zipcode" VALUES(3735,10702,-5,'Yonkers, New York 10702',2640,3432);
INSERT INTO "django_geo_db_zipcode" VALUES(3736,10703,-5,'Yonkers, New York 10703',2640,3471);
INSERT INTO "django_geo_db_zipcode" VALUES(3737,10704,-5,'Yonkers, New York 10704',2640,3472);
INSERT INTO "django_geo_db_zipcode" VALUES(3738,10705,-5,'Yonkers, New York 10705',2640,3473);
INSERT INTO "django_geo_db_zipcode" VALUES(3739,10706,-5,'Hastings On Hudson, New York 10706',2641,3474);
INSERT INTO "django_geo_db_zipcode" VALUES(3740,10707,-5,'Tuckahoe, New York 10707',2642,3475);
INSERT INTO "django_geo_db_zipcode" VALUES(3741,10708,-5,'Bronxville, New York 10708',2643,3476);
INSERT INTO "django_geo_db_zipcode" VALUES(3742,10709,-5,'Eastchester, New York 10709',2644,3477);
INSERT INTO "django_geo_db_zipcode" VALUES(3743,10710,-5,'Yonkers, New York 10710',2640,3478);
INSERT INTO "django_geo_db_zipcode" VALUES(3744,10730,-5,'Woodbury, New York 10730',2645,3479);
INSERT INTO "django_geo_db_zipcode" VALUES(3745,10801,-5,'New Rochelle, New York 10801',2646,3480);
INSERT INTO "django_geo_db_zipcode" VALUES(3746,10802,-5,'New Rochelle, New York 10802',2646,3481);
INSERT INTO "django_geo_db_zipcode" VALUES(3747,10803,-5,'Pelham, New York 10803',2647,3482);
INSERT INTO "django_geo_db_zipcode" VALUES(3748,10804,-5,'Wykagyl, New York 10804',2648,3483);
INSERT INTO "django_geo_db_zipcode" VALUES(3749,10805,-5,'New Rochelle, New York 10805',2646,3484);
INSERT INTO "django_geo_db_zipcode" VALUES(3750,10901,-5,'Suffern, New York 10901',2649,3485);
INSERT INTO "django_geo_db_zipcode" VALUES(3751,10910,-5,'Arden, New York 10910',2650,3486);
INSERT INTO "django_geo_db_zipcode" VALUES(3752,10911,-5,'Bear Mountain, New York 10911',2651,3487);
INSERT INTO "django_geo_db_zipcode" VALUES(3753,10912,-5,'Bellvale, New York 10912',2652,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(3754,10913,-5,'Blauvelt, New York 10913',2653,3489);
INSERT INTO "django_geo_db_zipcode" VALUES(3755,10914,-5,'Blooming Grove, New York 10914',2654,3490);
INSERT INTO "django_geo_db_zipcode" VALUES(3756,10915,-5,'Bullville, New York 10915',2655,3491);
INSERT INTO "django_geo_db_zipcode" VALUES(3757,10916,-5,'Campbell Hall, New York 10916',2656,3492);
INSERT INTO "django_geo_db_zipcode" VALUES(3758,10917,-5,'Central Valley, New York 10917',2657,3493);
INSERT INTO "django_geo_db_zipcode" VALUES(3759,10918,-5,'Chester, New York 10918',2658,3494);
INSERT INTO "django_geo_db_zipcode" VALUES(3760,10919,-5,'Circleville, New York 10919',2659,3495);
INSERT INTO "django_geo_db_zipcode" VALUES(3761,10920,-5,'Congers, New York 10920',2660,3496);
INSERT INTO "django_geo_db_zipcode" VALUES(3762,10921,-5,'Florida, New York 10921',2661,3497);
INSERT INTO "django_geo_db_zipcode" VALUES(3763,10922,-5,'Fort Montgomery, New York 10922',2662,3498);
INSERT INTO "django_geo_db_zipcode" VALUES(3764,10923,-5,'Garnerville, New York 10923',2663,3499);
INSERT INTO "django_geo_db_zipcode" VALUES(3765,10924,-5,'Goshen, New York 10924',2664,3500);
INSERT INTO "django_geo_db_zipcode" VALUES(3766,10925,-5,'Greenwood Lake, New York 10925',2665,3501);
INSERT INTO "django_geo_db_zipcode" VALUES(3767,10926,-5,'Harriman, New York 10926',2666,3502);
INSERT INTO "django_geo_db_zipcode" VALUES(3768,10927,-5,'Haverstraw, New York 10927',2667,3503);
INSERT INTO "django_geo_db_zipcode" VALUES(3769,10928,-5,'Highland Falls, New York 10928',2668,3504);
INSERT INTO "django_geo_db_zipcode" VALUES(3770,10930,-5,'Highland Mills, New York 10930',2669,3505);
INSERT INTO "django_geo_db_zipcode" VALUES(3771,10931,-5,'Hillburn, New York 10931',2670,3506);
INSERT INTO "django_geo_db_zipcode" VALUES(3772,10932,-5,'Howells, New York 10932',2671,3507);
INSERT INTO "django_geo_db_zipcode" VALUES(3773,10933,-5,'Johnson, New York 10933',2672,3508);
INSERT INTO "django_geo_db_zipcode" VALUES(3774,10940,-5,'Middletown, New York 10940',2673,3509);
INSERT INTO "django_geo_db_zipcode" VALUES(3775,10941,-5,'Middletown, New York 10941',2673,3510);
INSERT INTO "django_geo_db_zipcode" VALUES(3776,10943,-5,'Middletown, New York 10943',2673,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(3777,10946,-5,'Wallkill, New York 10946',2674,3511);
INSERT INTO "django_geo_db_zipcode" VALUES(3778,10950,-5,'Monroe, New York 10950',2675,3512);
INSERT INTO "django_geo_db_zipcode" VALUES(3779,10952,-5,'Monsey, New York 10952',2676,3513);
INSERT INTO "django_geo_db_zipcode" VALUES(3780,10953,-5,'Mountainville, New York 10953',2677,3514);
INSERT INTO "django_geo_db_zipcode" VALUES(3781,10954,-5,'Nanuet, New York 10954',2678,3515);
INSERT INTO "django_geo_db_zipcode" VALUES(3782,10956,-5,'New City, New York 10956',2679,3516);
INSERT INTO "django_geo_db_zipcode" VALUES(3783,10957,-5,'Lewisboro, New York 10957',2680,3517);
INSERT INTO "django_geo_db_zipcode" VALUES(3784,10958,-5,'New Hampton, New York 10958',2681,3518);
INSERT INTO "django_geo_db_zipcode" VALUES(3785,10959,-5,'New Milford, New York 10959',2682,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(3786,10960,-5,'Nyack, New York 10960',2683,3519);
INSERT INTO "django_geo_db_zipcode" VALUES(3787,10962,-5,'Orangeburg, New York 10962',2684,3520);
INSERT INTO "django_geo_db_zipcode" VALUES(3788,10963,-5,'Otisville, New York 10963',2685,3521);
INSERT INTO "django_geo_db_zipcode" VALUES(3789,10964,-5,'Palisades, New York 10964',2686,3522);
INSERT INTO "django_geo_db_zipcode" VALUES(3790,10965,-5,'Pearl River, New York 10965',2687,3523);
INSERT INTO "django_geo_db_zipcode" VALUES(3791,10968,-5,'Piermont, New York 10968',2688,3524);
INSERT INTO "django_geo_db_zipcode" VALUES(3792,10969,-5,'Pine Island, New York 10969',2689,3525);
INSERT INTO "django_geo_db_zipcode" VALUES(3793,10970,-5,'Pomona, New York 10970',2690,3526);
INSERT INTO "django_geo_db_zipcode" VALUES(3794,10973,-5,'Slate Hill, New York 10973',2691,3527);
INSERT INTO "django_geo_db_zipcode" VALUES(3795,10974,-5,'Sloatsburg, New York 10974',2692,3528);
INSERT INTO "django_geo_db_zipcode" VALUES(3796,10975,-5,'Southfields, New York 10975',2693,3529);
INSERT INTO "django_geo_db_zipcode" VALUES(3797,10976,-5,'Sparkill, New York 10976',2694,3530);
INSERT INTO "django_geo_db_zipcode" VALUES(3798,10977,-5,'Spring Valley, New York 10977',2695,3531);
INSERT INTO "django_geo_db_zipcode" VALUES(3799,10979,-5,'Sterling Forest, New York 10979',2696,3532);
INSERT INTO "django_geo_db_zipcode" VALUES(3800,10980,-5,'Stony Point, New York 10980',2697,3533);
INSERT INTO "django_geo_db_zipcode" VALUES(3801,10981,-5,'Sugar Loaf, New York 10981',2698,3534);
INSERT INTO "django_geo_db_zipcode" VALUES(3802,10982,-5,'Tallman, New York 10982',2699,3487);
INSERT INTO "django_geo_db_zipcode" VALUES(3803,10983,-5,'Tappan, New York 10983',2700,3535);
INSERT INTO "django_geo_db_zipcode" VALUES(3804,10984,-5,'Thiells, New York 10984',2701,3536);
INSERT INTO "django_geo_db_zipcode" VALUES(3805,10985,-5,'Thompson Ridge, New York 10985',2702,3537);
INSERT INTO "django_geo_db_zipcode" VALUES(3806,10986,-5,'Tomkins Cove, New York 10986',2703,3538);
INSERT INTO "django_geo_db_zipcode" VALUES(3807,10987,-5,'Tuxedo Park, New York 10987',2704,3539);
INSERT INTO "django_geo_db_zipcode" VALUES(3808,10988,-5,'Unionville, New York 10988',2705,3540);
INSERT INTO "django_geo_db_zipcode" VALUES(3809,10989,-5,'Valley Cottage, New York 10989',2706,3541);
INSERT INTO "django_geo_db_zipcode" VALUES(3810,10990,-5,'Warwick, New York 10990',2707,3542);
INSERT INTO "django_geo_db_zipcode" VALUES(3811,10992,-5,'Washingtonville, New York 10992',2708,3543);
INSERT INTO "django_geo_db_zipcode" VALUES(3812,10993,-5,'West Haverstraw, New York 10993',2709,3544);
INSERT INTO "django_geo_db_zipcode" VALUES(3813,10994,-5,'West Nyack, New York 10994',2710,3545);
INSERT INTO "django_geo_db_zipcode" VALUES(3814,10995,-5,'West Nyack, New York 10995',2710,3487);
INSERT INTO "django_geo_db_zipcode" VALUES(3815,10996,-5,'West Point, New York 10996',2711,3546);
INSERT INTO "django_geo_db_zipcode" VALUES(3816,10997,-5,'West Point, New York 10997',2711,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(3817,10998,-5,'Westtown, New York 10998',2712,3547);
INSERT INTO "django_geo_db_zipcode" VALUES(3818,11001,-5,'Floral Park, New York 11001',2713,3548);
INSERT INTO "django_geo_db_zipcode" VALUES(3819,11002,-5,'Floral Park, New York 11002',2713,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3820,11003,-5,'Elmont, New York 11003',2714,3550);
INSERT INTO "django_geo_db_zipcode" VALUES(3821,11004,-5,'Glen Oaks, New York 11004',2715,3551);
INSERT INTO "django_geo_db_zipcode" VALUES(3822,11005,-5,'Floral Park, New York 11005',2713,3552);
INSERT INTO "django_geo_db_zipcode" VALUES(3823,11010,-5,'Franklin Square, New York 11010',2716,3553);
INSERT INTO "django_geo_db_zipcode" VALUES(3824,11020,-5,'Great Neck, New York 11020',2717,3554);
INSERT INTO "django_geo_db_zipcode" VALUES(3825,11021,-5,'Great Neck, New York 11021',2717,3555);
INSERT INTO "django_geo_db_zipcode" VALUES(3826,11022,-5,'Great Neck, New York 11022',2717,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3827,11023,-5,'Great Neck, New York 11023',2717,3556);
INSERT INTO "django_geo_db_zipcode" VALUES(3828,11024,-5,'Great Neck, New York 11024',2717,3557);
INSERT INTO "django_geo_db_zipcode" VALUES(3829,11025,-5,'Great Neck, New York 11025',2717,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3830,11026,-5,'Great Neck, New York 11026',2717,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3831,11027,-5,'Great Neck, New York 11027',2717,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3832,11030,-5,'Manhasset, New York 11030',2718,3558);
INSERT INTO "django_geo_db_zipcode" VALUES(3833,11040,-5,'New Hyde Park, New York 11040',2719,3559);
INSERT INTO "django_geo_db_zipcode" VALUES(3834,11041,-5,'New Hyde Park, New York 11041',2719,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3835,11042,-5,'New Hyde Park, New York 11042',2719,3560);
INSERT INTO "django_geo_db_zipcode" VALUES(3836,11043,-5,'New Hyde Park, New York 11043',2719,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3837,11044,-5,'New Hyde Park, New York 11044',2719,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3838,11050,-5,'Port Washington, New York 11050',2720,3561);
INSERT INTO "django_geo_db_zipcode" VALUES(3839,11051,-5,'Port Washington, New York 11051',2720,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3840,11052,-5,'Port Washington, New York 11052',2720,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3841,11053,-5,'Port Washington, New York 11053',2720,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3842,11054,-5,'Port Washington, New York 11054',2720,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3843,11055,-5,'Port Washington, New York 11055',2720,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3844,11096,-5,'Inwood, New York 11096',2721,3562);
INSERT INTO "django_geo_db_zipcode" VALUES(3845,11099,-5,'New Hyde Park, New York 11099',2719,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3846,11101,-5,'Long Island City, New York 11101',2722,3563);
INSERT INTO "django_geo_db_zipcode" VALUES(3847,11102,-5,'Astoria, New York 11102',2723,3564);
INSERT INTO "django_geo_db_zipcode" VALUES(3848,11103,-5,'Astoria, New York 11103',2723,3565);
INSERT INTO "django_geo_db_zipcode" VALUES(3849,11104,-5,'Sunnyside, New York 11104',2724,3566);
INSERT INTO "django_geo_db_zipcode" VALUES(3850,11105,-5,'Astoria, New York 11105',2723,3567);
INSERT INTO "django_geo_db_zipcode" VALUES(3851,11106,-5,'Astoria, New York 11106',2723,3568);
INSERT INTO "django_geo_db_zipcode" VALUES(3852,11109,-5,'Long Island City, New York 11109',2722,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3853,11120,-5,'Long Island City, New York 11120',2722,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3854,11201,-5,'Brooklyn, New York 11201',2725,3570);
INSERT INTO "django_geo_db_zipcode" VALUES(3855,11202,-5,'Brooklyn, New York 11202',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3856,11203,-5,'Brooklyn, New York 11203',2725,3572);
INSERT INTO "django_geo_db_zipcode" VALUES(3857,11204,-5,'Brooklyn, New York 11204',2725,3573);
INSERT INTO "django_geo_db_zipcode" VALUES(3858,11205,-5,'Brooklyn, New York 11205',2725,3574);
INSERT INTO "django_geo_db_zipcode" VALUES(3859,11206,-5,'Brooklyn, New York 11206',2725,3575);
INSERT INTO "django_geo_db_zipcode" VALUES(3860,11207,-5,'Brooklyn, New York 11207',2725,3576);
INSERT INTO "django_geo_db_zipcode" VALUES(3861,11208,-5,'Brooklyn, New York 11208',2725,3577);
INSERT INTO "django_geo_db_zipcode" VALUES(3862,11209,-5,'Brooklyn, New York 11209',2725,3578);
INSERT INTO "django_geo_db_zipcode" VALUES(3863,11210,-5,'Brooklyn, New York 11210',2725,3579);
INSERT INTO "django_geo_db_zipcode" VALUES(3864,11211,-5,'Brooklyn, New York 11211',2725,3580);
INSERT INTO "django_geo_db_zipcode" VALUES(3865,11212,-5,'Brooklyn, New York 11212',2725,3581);
INSERT INTO "django_geo_db_zipcode" VALUES(3866,11213,-5,'Brooklyn, New York 11213',2725,3582);
INSERT INTO "django_geo_db_zipcode" VALUES(3867,11214,-5,'Brooklyn, New York 11214',2725,3583);
INSERT INTO "django_geo_db_zipcode" VALUES(3868,11215,-5,'Brooklyn, New York 11215',2725,3584);
INSERT INTO "django_geo_db_zipcode" VALUES(3869,11216,-5,'Brooklyn, New York 11216',2725,3585);
INSERT INTO "django_geo_db_zipcode" VALUES(3870,11217,-5,'Brooklyn, New York 11217',2725,3586);
INSERT INTO "django_geo_db_zipcode" VALUES(3871,11218,-5,'Brooklyn, New York 11218',2725,3587);
INSERT INTO "django_geo_db_zipcode" VALUES(3872,11219,-5,'Brooklyn, New York 11219',2725,3588);
INSERT INTO "django_geo_db_zipcode" VALUES(3873,11220,-5,'Brooklyn, New York 11220',2725,3589);
INSERT INTO "django_geo_db_zipcode" VALUES(3874,11221,-5,'Brooklyn, New York 11221',2725,3590);
INSERT INTO "django_geo_db_zipcode" VALUES(3875,11222,-5,'Brooklyn, New York 11222',2725,3591);
INSERT INTO "django_geo_db_zipcode" VALUES(3876,11223,-5,'Brooklyn, New York 11223',2725,3592);
INSERT INTO "django_geo_db_zipcode" VALUES(3877,11224,-5,'Brooklyn, New York 11224',2725,3593);
INSERT INTO "django_geo_db_zipcode" VALUES(3878,11225,-5,'Brooklyn, New York 11225',2725,3594);
INSERT INTO "django_geo_db_zipcode" VALUES(3879,11226,-5,'Brooklyn, New York 11226',2725,3595);
INSERT INTO "django_geo_db_zipcode" VALUES(3880,11228,-5,'Brooklyn, New York 11228',2725,3596);
INSERT INTO "django_geo_db_zipcode" VALUES(3881,11229,-5,'Brooklyn, New York 11229',2725,3597);
INSERT INTO "django_geo_db_zipcode" VALUES(3882,11230,-5,'Brooklyn, New York 11230',2725,3598);
INSERT INTO "django_geo_db_zipcode" VALUES(3883,11231,-5,'Brooklyn, New York 11231',2725,3599);
INSERT INTO "django_geo_db_zipcode" VALUES(3884,11232,-5,'Brooklyn, New York 11232',2725,3600);
INSERT INTO "django_geo_db_zipcode" VALUES(3885,11233,-5,'Brooklyn, New York 11233',2725,3601);
INSERT INTO "django_geo_db_zipcode" VALUES(3886,11234,-5,'Brooklyn, New York 11234',2725,3602);
INSERT INTO "django_geo_db_zipcode" VALUES(3887,11235,-5,'Brooklyn, New York 11235',2725,3603);
INSERT INTO "django_geo_db_zipcode" VALUES(3888,11236,-5,'Brooklyn, New York 11236',2725,3604);
INSERT INTO "django_geo_db_zipcode" VALUES(3889,11237,-5,'Brooklyn, New York 11237',2725,3605);
INSERT INTO "django_geo_db_zipcode" VALUES(3890,11238,-5,'Brooklyn, New York 11238',2725,3606);
INSERT INTO "django_geo_db_zipcode" VALUES(3891,11239,-5,'Brooklyn, New York 11239',2725,3607);
INSERT INTO "django_geo_db_zipcode" VALUES(3892,11240,-5,'Brooklyn, New York 11240',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3893,11241,-5,'Brooklyn, New York 11241',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3894,11242,-5,'Brooklyn, New York 11242',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3895,11243,-5,'Brooklyn, New York 11243',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3896,11244,-5,'Brooklyn, New York 11244',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3897,11245,-5,'Brooklyn, New York 11245',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3898,11247,-5,'Brooklyn, New York 11247',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3899,11248,-5,'Brooklyn, New York 11248',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3900,11249,-5,'Brooklyn, New York 11249',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3901,11251,-5,'Brooklyn, New York 11251',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3902,11252,-5,'Brooklyn, New York 11252',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3903,11254,-5,'Brooklyn, New York 11254',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3904,11255,-5,'Brooklyn, New York 11255',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3905,11256,-5,'Brooklyn, New York 11256',2725,3571);
INSERT INTO "django_geo_db_zipcode" VALUES(3906,11286,-5,'New York, New York 11286',2571,3608);
INSERT INTO "django_geo_db_zipcode" VALUES(3907,11302,-5,'New York, New York 11302',2571,3609);
INSERT INTO "django_geo_db_zipcode" VALUES(3908,11351,-5,'Flushing, New York 11351',2726,3610);
INSERT INTO "django_geo_db_zipcode" VALUES(3909,11352,-5,'Flushing, New York 11352',2726,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3910,11353,-5,'Flushing, New York 11353',2726,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3911,11354,-5,'Flushing, New York 11354',2726,3611);
INSERT INTO "django_geo_db_zipcode" VALUES(3912,11355,-5,'Flushing, New York 11355',2726,3612);
INSERT INTO "django_geo_db_zipcode" VALUES(3913,11356,-5,'College Point, New York 11356',2727,3613);
INSERT INTO "django_geo_db_zipcode" VALUES(3914,11357,-5,'Whitestone, New York 11357',2728,3614);
INSERT INTO "django_geo_db_zipcode" VALUES(3915,11358,-5,'Flushing, New York 11358',2726,3615);
INSERT INTO "django_geo_db_zipcode" VALUES(3916,11359,-5,'Bayside, New York 11359',2729,3616);
INSERT INTO "django_geo_db_zipcode" VALUES(3917,11360,-5,'Bayside, New York 11360',2729,3617);
INSERT INTO "django_geo_db_zipcode" VALUES(3918,11361,-5,'Bayside, New York 11361',2729,3618);
INSERT INTO "django_geo_db_zipcode" VALUES(3919,11362,-5,'Little Neck, New York 11362',2730,3619);
INSERT INTO "django_geo_db_zipcode" VALUES(3920,11363,-5,'Little Neck, New York 11363',2730,3620);
INSERT INTO "django_geo_db_zipcode" VALUES(3921,11364,-5,'Oakland Gardens, New York 11364',2731,3621);
INSERT INTO "django_geo_db_zipcode" VALUES(3922,11365,-5,'Fresh Meadows, New York 11365',2732,3622);
INSERT INTO "django_geo_db_zipcode" VALUES(3923,11366,-5,'Fresh Meadows, New York 11366',2732,3623);
INSERT INTO "django_geo_db_zipcode" VALUES(3924,11367,-5,'Flushing, New York 11367',2726,3624);
INSERT INTO "django_geo_db_zipcode" VALUES(3925,11368,-5,'Corona, New York 11368',2733,3625);
INSERT INTO "django_geo_db_zipcode" VALUES(3926,11369,-5,'East Elmhurst, New York 11369',2734,3626);
INSERT INTO "django_geo_db_zipcode" VALUES(3927,11370,-5,'East Elmhurst, New York 11370',2734,3627);
INSERT INTO "django_geo_db_zipcode" VALUES(3928,11371,-5,'Flushing, New York 11371',2726,3628);
INSERT INTO "django_geo_db_zipcode" VALUES(3929,11372,-5,'Jackson Heights, New York 11372',2735,3629);
INSERT INTO "django_geo_db_zipcode" VALUES(3930,11373,-5,'Elmhurst, New York 11373',2736,3630);
INSERT INTO "django_geo_db_zipcode" VALUES(3931,11374,-5,'Rego Park, New York 11374',2737,3631);
INSERT INTO "django_geo_db_zipcode" VALUES(3932,11375,-5,'Forest Hills, New York 11375',2738,3632);
INSERT INTO "django_geo_db_zipcode" VALUES(3933,11377,-5,'Woodside, New York 11377',2739,3633);
INSERT INTO "django_geo_db_zipcode" VALUES(3934,11378,-5,'Maspeth, New York 11378',2740,3634);
INSERT INTO "django_geo_db_zipcode" VALUES(3935,11379,-5,'Middle Village, New York 11379',2741,3635);
INSERT INTO "django_geo_db_zipcode" VALUES(3936,11380,-5,'Elmhurst, New York 11380',2736,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3937,11381,-5,'Flushing, New York 11381',2726,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3938,11385,-5,'Ridgewood, New York 11385',2742,3636);
INSERT INTO "django_geo_db_zipcode" VALUES(3939,11386,-5,'Ridgewood, New York 11386',2742,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3940,11388,-5,'Flushing, New York 11388',2726,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3941,11390,-5,'Flushing, New York 11390',2726,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3942,11405,-5,'Jamaica, New York 11405',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3943,11411,-5,'Cambria Heights, New York 11411',2744,3637);
INSERT INTO "django_geo_db_zipcode" VALUES(3944,11412,-5,'Saint Albans, New York 11412',2745,3638);
INSERT INTO "django_geo_db_zipcode" VALUES(3945,11413,-5,'Springfield Gardens, New York 11413',2746,3639);
INSERT INTO "django_geo_db_zipcode" VALUES(3946,11414,-5,'Howard Beach, New York 11414',2747,3640);
INSERT INTO "django_geo_db_zipcode" VALUES(3947,11415,-5,'Kew Gardens, New York 11415',2748,3641);
INSERT INTO "django_geo_db_zipcode" VALUES(3948,11416,-5,'Ozone Park, New York 11416',2749,3642);
INSERT INTO "django_geo_db_zipcode" VALUES(3949,11417,-5,'Ozone Park, New York 11417',2749,3643);
INSERT INTO "django_geo_db_zipcode" VALUES(3950,11418,-5,'Richmond Hill, New York 11418',2750,3644);
INSERT INTO "django_geo_db_zipcode" VALUES(3951,11419,-5,'South Richmond Hill, New York 11419',2751,3645);
INSERT INTO "django_geo_db_zipcode" VALUES(3952,11420,-5,'South Ozone Park, New York 11420',2752,3646);
INSERT INTO "django_geo_db_zipcode" VALUES(3953,11421,-5,'Woodhaven, New York 11421',2753,3647);
INSERT INTO "django_geo_db_zipcode" VALUES(3954,11422,-5,'Rosedale, New York 11422',2754,3648);
INSERT INTO "django_geo_db_zipcode" VALUES(3955,11423,-5,'Hollis, New York 11423',2755,3649);
INSERT INTO "django_geo_db_zipcode" VALUES(3956,11424,-5,'Jamaica, New York 11424',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3957,11425,-5,'Jamaica, New York 11425',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3958,11426,-5,'Bellerose, New York 11426',2756,3650);
INSERT INTO "django_geo_db_zipcode" VALUES(3959,11427,-5,'Queens Village, New York 11427',2757,3651);
INSERT INTO "django_geo_db_zipcode" VALUES(3960,11428,-5,'Queens Village, New York 11428',2757,3652);
INSERT INTO "django_geo_db_zipcode" VALUES(3961,11429,-5,'Queens Village, New York 11429',2757,3653);
INSERT INTO "django_geo_db_zipcode" VALUES(3962,11430,-5,'Jamaica, New York 11430',2743,3654);
INSERT INTO "django_geo_db_zipcode" VALUES(3963,11431,-5,'Jamaica, New York 11431',2743,3655);
INSERT INTO "django_geo_db_zipcode" VALUES(3964,11432,-5,'Jamaica, New York 11432',2743,3656);
INSERT INTO "django_geo_db_zipcode" VALUES(3965,11433,-5,'Jamaica, New York 11433',2743,3657);
INSERT INTO "django_geo_db_zipcode" VALUES(3966,11434,-5,'Jamaica, New York 11434',2743,3658);
INSERT INTO "django_geo_db_zipcode" VALUES(3967,11435,-5,'Jamaica, New York 11435',2743,3659);
INSERT INTO "django_geo_db_zipcode" VALUES(3968,11436,-5,'Jamaica, New York 11436',2743,3660);
INSERT INTO "django_geo_db_zipcode" VALUES(3969,11439,-5,'Jamaica, New York 11439',2743,3661);
INSERT INTO "django_geo_db_zipcode" VALUES(3970,11451,-5,'Jamaica, New York 11451',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3971,11484,-5,'Jamaica, New York 11484',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3972,11499,-5,'Jamaica, New York 11499',2743,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(3973,11501,-5,'Mineola, New York 11501',2758,3662);
INSERT INTO "django_geo_db_zipcode" VALUES(3974,11507,-5,'Albertson, New York 11507',2759,3663);
INSERT INTO "django_geo_db_zipcode" VALUES(3975,11509,-5,'Atlantic Beach, New York 11509',2760,3664);
INSERT INTO "django_geo_db_zipcode" VALUES(3976,11510,-5,'Baldwin, New York 11510',2761,3665);
INSERT INTO "django_geo_db_zipcode" VALUES(3977,11514,-5,'Carle Place, New York 11514',2762,3666);
INSERT INTO "django_geo_db_zipcode" VALUES(3978,11516,-5,'Cedarhurst, New York 11516',2763,3667);
INSERT INTO "django_geo_db_zipcode" VALUES(3979,11517,-5,'New York, New York 11517',2571,3668);
INSERT INTO "django_geo_db_zipcode" VALUES(3980,11518,-5,'East Rockaway, New York 11518',2764,3669);
INSERT INTO "django_geo_db_zipcode" VALUES(3981,11520,-5,'Freeport, New York 11520',2765,3670);
INSERT INTO "django_geo_db_zipcode" VALUES(3982,11530,-5,'Garden City, New York 11530',2766,3671);
INSERT INTO "django_geo_db_zipcode" VALUES(3983,11531,-5,'Garden City, New York 11531',2766,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3984,11535,-5,'Garden City, New York 11535',2766,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3985,11536,-5,'Garden City, New York 11536',2766,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3986,11542,-5,'Glen Cove, New York 11542',2767,3672);
INSERT INTO "django_geo_db_zipcode" VALUES(3987,11545,-5,'Glen Head, New York 11545',2768,3673);
INSERT INTO "django_geo_db_zipcode" VALUES(3988,11547,-5,'Glenwood Landing, New York 11547',2769,3674);
INSERT INTO "django_geo_db_zipcode" VALUES(3989,11548,-5,'Greenvale, New York 11548',2770,3675);
INSERT INTO "django_geo_db_zipcode" VALUES(3990,11549,-5,'Hempstead, New York 11549',2771,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3991,11550,-5,'Hempstead, New York 11550',2771,3676);
INSERT INTO "django_geo_db_zipcode" VALUES(3992,11551,-5,'Hempstead, New York 11551',2771,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3993,11552,-5,'West Hempstead, New York 11552',2772,3677);
INSERT INTO "django_geo_db_zipcode" VALUES(3994,11553,-5,'Uniondale, New York 11553',2773,3678);
INSERT INTO "django_geo_db_zipcode" VALUES(3995,11554,-5,'East Meadow, New York 11554',2774,3679);
INSERT INTO "django_geo_db_zipcode" VALUES(3996,11555,-5,'Uniondale, New York 11555',2773,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3997,11556,-5,'Uniondale, New York 11556',2773,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(3998,11557,-5,'Hewlett, New York 11557',2775,3680);
INSERT INTO "django_geo_db_zipcode" VALUES(3999,11558,-5,'Island Park, New York 11558',2776,3681);
INSERT INTO "django_geo_db_zipcode" VALUES(4000,11559,-5,'Lawrence, New York 11559',2777,3682);
INSERT INTO "django_geo_db_zipcode" VALUES(4001,11560,-5,'Locust Valley, New York 11560',2778,3683);
INSERT INTO "django_geo_db_zipcode" VALUES(4002,11561,-5,'Long Beach, New York 11561',2779,3684);
INSERT INTO "django_geo_db_zipcode" VALUES(4003,11562,-5,'Lynbrook, New York 11562',2780,3685);
INSERT INTO "django_geo_db_zipcode" VALUES(4004,11563,-5,'Lynbrook, New York 11563',2780,3686);
INSERT INTO "django_geo_db_zipcode" VALUES(4005,11564,-5,'Lynbrook, New York 11564',2780,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4006,11565,-5,'Malverne, New York 11565',2781,3687);
INSERT INTO "django_geo_db_zipcode" VALUES(4007,11566,-5,'Merrick, New York 11566',2782,3688);
INSERT INTO "django_geo_db_zipcode" VALUES(4008,11568,-5,'Old Westbury, New York 11568',2783,3689);
INSERT INTO "django_geo_db_zipcode" VALUES(4009,11569,-5,'Point Lookout, New York 11569',2784,3690);
INSERT INTO "django_geo_db_zipcode" VALUES(4010,11570,-5,'Rockville Centre, New York 11570',2785,3691);
INSERT INTO "django_geo_db_zipcode" VALUES(4011,11571,-5,'Rockville Centre, New York 11571',2785,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4012,11572,-5,'Oceanside, New York 11572',2786,3692);
INSERT INTO "django_geo_db_zipcode" VALUES(4013,11575,-5,'Roosevelt, New York 11575',2787,3693);
INSERT INTO "django_geo_db_zipcode" VALUES(4014,11576,-5,'Roslyn, New York 11576',2788,3694);
INSERT INTO "django_geo_db_zipcode" VALUES(4015,11577,-5,'Roslyn Heights, New York 11577',2789,3695);
INSERT INTO "django_geo_db_zipcode" VALUES(4016,11579,-5,'Sea Cliff, New York 11579',2790,3696);
INSERT INTO "django_geo_db_zipcode" VALUES(4017,11580,-5,'Valley Stream, New York 11580',2791,3697);
INSERT INTO "django_geo_db_zipcode" VALUES(4018,11581,-5,'Valley Stream, New York 11581',2791,3698);
INSERT INTO "django_geo_db_zipcode" VALUES(4019,11582,-5,'Valley Stream, New York 11582',2791,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4020,11583,-5,'Valley Stream, New York 11583',2791,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4021,11588,-5,'Uniondale, New York 11588',2773,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4022,11590,-5,'Westbury, New York 11590',2792,3699);
INSERT INTO "django_geo_db_zipcode" VALUES(4023,11592,-5,'Rockville Centre, New York 11592',2785,3700);
INSERT INTO "django_geo_db_zipcode" VALUES(4024,11593,-5,'Westbury, New York 11593',2792,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4025,11594,-5,'Westbury, New York 11594',2792,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4026,11595,-5,'Westbury, New York 11595',2792,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4027,11596,-5,'Williston Park, New York 11596',2793,3701);
INSERT INTO "django_geo_db_zipcode" VALUES(4028,11597,-5,'Westbury, New York 11597',2792,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4029,11598,-5,'Woodmere, New York 11598',2794,3702);
INSERT INTO "django_geo_db_zipcode" VALUES(4030,11599,-5,'Garden City, New York 11599',2766,3703);
INSERT INTO "django_geo_db_zipcode" VALUES(4031,11690,-5,'Far Rockaway, New York 11690',2795,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(4032,11691,-5,'Far Rockaway, New York 11691',2795,3704);
INSERT INTO "django_geo_db_zipcode" VALUES(4033,11692,-5,'Arverne, New York 11692',2796,3705);
INSERT INTO "django_geo_db_zipcode" VALUES(4034,11693,-5,'Far Rockaway, New York 11693',2795,3706);
INSERT INTO "django_geo_db_zipcode" VALUES(4035,11694,-5,'Rockaway Park, New York 11694',2797,3707);
INSERT INTO "django_geo_db_zipcode" VALUES(4036,11695,-5,'Far Rockaway, New York 11695',2795,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(4037,11696,-5,'Inwood, New York 11696',2721,3569);
INSERT INTO "django_geo_db_zipcode" VALUES(4038,11697,-5,'Breezy Point, New York 11697',2798,3708);
INSERT INTO "django_geo_db_zipcode" VALUES(4039,11701,-5,'Amityville, New York 11701',2799,3709);
INSERT INTO "django_geo_db_zipcode" VALUES(4040,11702,-5,'Babylon, New York 11702',2800,3710);
INSERT INTO "django_geo_db_zipcode" VALUES(4041,11703,-5,'North Babylon, New York 11703',2801,3711);
INSERT INTO "django_geo_db_zipcode" VALUES(4042,11704,-5,'West Babylon, New York 11704',2802,3712);
INSERT INTO "django_geo_db_zipcode" VALUES(4043,11705,-5,'Bayport, New York 11705',2803,3713);
INSERT INTO "django_geo_db_zipcode" VALUES(4044,11706,-5,'Bay Shore, New York 11706',2804,3714);
INSERT INTO "django_geo_db_zipcode" VALUES(4045,11707,-5,'West Babylon, New York 11707',2802,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4046,11708,-5,'Amityville, New York 11708',2799,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4047,11709,-5,'Bayville, New York 11709',2805,3715);
INSERT INTO "django_geo_db_zipcode" VALUES(4048,11710,-5,'Bellmore, New York 11710',2806,3716);
INSERT INTO "django_geo_db_zipcode" VALUES(4049,11713,-5,'Bellport, New York 11713',2807,3717);
INSERT INTO "django_geo_db_zipcode" VALUES(4050,11714,-5,'Bethpage, New York 11714',2808,3718);
INSERT INTO "django_geo_db_zipcode" VALUES(4051,11715,-5,'Blue Point, New York 11715',2809,3719);
INSERT INTO "django_geo_db_zipcode" VALUES(4052,11716,-5,'Bohemia, New York 11716',2810,3720);
INSERT INTO "django_geo_db_zipcode" VALUES(4053,11717,-5,'Brentwood, New York 11717',2811,3721);
INSERT INTO "django_geo_db_zipcode" VALUES(4054,11718,-5,'Brightwaters, New York 11718',2812,3722);
INSERT INTO "django_geo_db_zipcode" VALUES(4055,11719,-5,'Brookhaven, New York 11719',2813,3723);
INSERT INTO "django_geo_db_zipcode" VALUES(4056,11720,-5,'Centereach, New York 11720',2814,3724);
INSERT INTO "django_geo_db_zipcode" VALUES(4057,11721,-5,'Centerport, New York 11721',2815,3725);
INSERT INTO "django_geo_db_zipcode" VALUES(4058,11722,-5,'Central Islip, New York 11722',2816,3726);
INSERT INTO "django_geo_db_zipcode" VALUES(4059,11724,-5,'Cold Spring Harbor, New York 11724',2817,3727);
INSERT INTO "django_geo_db_zipcode" VALUES(4060,11725,-5,'Commack, New York 11725',2818,3728);
INSERT INTO "django_geo_db_zipcode" VALUES(4061,11726,-5,'Copiague, New York 11726',2819,3729);
INSERT INTO "django_geo_db_zipcode" VALUES(4062,11727,-5,'Coram, New York 11727',2820,3730);
INSERT INTO "django_geo_db_zipcode" VALUES(4063,11729,-5,'Deer Park, New York 11729',2821,3731);
INSERT INTO "django_geo_db_zipcode" VALUES(4064,11730,-5,'East Islip, New York 11730',2822,3732);
INSERT INTO "django_geo_db_zipcode" VALUES(4065,11731,-5,'East Northport, New York 11731',2823,3733);
INSERT INTO "django_geo_db_zipcode" VALUES(4066,11732,-5,'East Norwich, New York 11732',2824,3734);
INSERT INTO "django_geo_db_zipcode" VALUES(4067,11733,-5,'East Setauket, New York 11733',2825,3735);
INSERT INTO "django_geo_db_zipcode" VALUES(4068,11735,-5,'Farmingdale, New York 11735',2826,3736);
INSERT INTO "django_geo_db_zipcode" VALUES(4069,11736,-5,'Farmingdale, New York 11736',2826,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4070,11737,-5,'Farmingdale, New York 11737',2826,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4071,11738,-5,'Farmingville, New York 11738',2827,3737);
INSERT INTO "django_geo_db_zipcode" VALUES(4072,11739,-5,'Great River, New York 11739',2828,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4073,11740,-5,'Greenlawn, New York 11740',2829,3738);
INSERT INTO "django_geo_db_zipcode" VALUES(4074,11741,-5,'Holbrook, New York 11741',2830,3739);
INSERT INTO "django_geo_db_zipcode" VALUES(4075,11742,-5,'Holtsville, New York 11742',2,3740);
INSERT INTO "django_geo_db_zipcode" VALUES(4076,11743,-5,'Huntington, New York 11743',2831,3741);
INSERT INTO "django_geo_db_zipcode" VALUES(4077,11745,-5,'Smithtown, New York 11745',2832,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4078,11746,-5,'Huntington Station, New York 11746',2833,3742);
INSERT INTO "django_geo_db_zipcode" VALUES(4079,11747,-5,'Melville, New York 11747',2834,3743);
INSERT INTO "django_geo_db_zipcode" VALUES(4080,11749,-5,'Islandia, New York 11749',2835,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4081,11750,-5,'Huntington Station, New York 11750',2833,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4082,11751,-5,'Islip, New York 11751',2836,3744);
INSERT INTO "django_geo_db_zipcode" VALUES(4083,11752,-5,'Islip Terrace, New York 11752',2837,3745);
INSERT INTO "django_geo_db_zipcode" VALUES(4084,11753,-5,'Jericho, New York 11753',2838,3746);
INSERT INTO "django_geo_db_zipcode" VALUES(4085,11754,-5,'Kings Park, New York 11754',2839,3747);
INSERT INTO "django_geo_db_zipcode" VALUES(4086,11755,-5,'Lake Grove, New York 11755',2840,3748);
INSERT INTO "django_geo_db_zipcode" VALUES(4087,11756,-5,'Levittown, New York 11756',2841,3749);
INSERT INTO "django_geo_db_zipcode" VALUES(4088,11757,-5,'Lindenhurst, New York 11757',2842,3750);
INSERT INTO "django_geo_db_zipcode" VALUES(4089,11758,-5,'Massapequa, New York 11758',2843,3751);
INSERT INTO "django_geo_db_zipcode" VALUES(4090,11760,-5,'Hauppauge, New York 11760',2844,3752);
INSERT INTO "django_geo_db_zipcode" VALUES(4091,11762,-5,'Massapequa Park, New York 11762',2845,3753);
INSERT INTO "django_geo_db_zipcode" VALUES(4092,11763,-5,'Medford, New York 11763',2846,3754);
INSERT INTO "django_geo_db_zipcode" VALUES(4093,11764,-5,'Miller Place, New York 11764',2847,3755);
INSERT INTO "django_geo_db_zipcode" VALUES(4094,11765,-5,'Mill Neck, New York 11765',2848,3756);
INSERT INTO "django_geo_db_zipcode" VALUES(4095,11766,-5,'Mount Sinai, New York 11766',2849,3757);
INSERT INTO "django_geo_db_zipcode" VALUES(4096,11767,-5,'Nesconset, New York 11767',2850,3758);
INSERT INTO "django_geo_db_zipcode" VALUES(4097,11768,-5,'Northport, New York 11768',2851,3759);
INSERT INTO "django_geo_db_zipcode" VALUES(4098,11769,-5,'Oakdale, New York 11769',2852,3760);
INSERT INTO "django_geo_db_zipcode" VALUES(4099,11770,-5,'Ocean Beach, New York 11770',2853,3761);
INSERT INTO "django_geo_db_zipcode" VALUES(4100,11771,-5,'Oyster Bay, New York 11771',2854,3762);
INSERT INTO "django_geo_db_zipcode" VALUES(4101,11772,-5,'Patchogue, New York 11772',2855,3763);
INSERT INTO "django_geo_db_zipcode" VALUES(4102,11773,-5,'Syosset, New York 11773',2856,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4103,11774,-5,'Farmingdale, New York 11774',2826,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4104,11775,-5,'Melville, New York 11775',2834,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4105,11776,-5,'Port Jefferson Station, New York 11776',2857,3764);
INSERT INTO "django_geo_db_zipcode" VALUES(4106,11777,-5,'Port Jefferson, New York 11777',2858,3765);
INSERT INTO "django_geo_db_zipcode" VALUES(4107,11778,-5,'Rocky Point, New York 11778',2859,3766);
INSERT INTO "django_geo_db_zipcode" VALUES(4108,11779,-5,'Ronkonkoma, New York 11779',2860,3767);
INSERT INTO "django_geo_db_zipcode" VALUES(4109,11780,-5,'Saint James, New York 11780',2861,3768);
INSERT INTO "django_geo_db_zipcode" VALUES(4110,11782,-5,'Sayville, New York 11782',2862,3769);
INSERT INTO "django_geo_db_zipcode" VALUES(4111,11783,-5,'Seaford, New York 11783',2863,3770);
INSERT INTO "django_geo_db_zipcode" VALUES(4112,11784,-5,'Selden, New York 11784',2864,3771);
INSERT INTO "django_geo_db_zipcode" VALUES(4113,11786,-5,'Shoreham, New York 11786',2865,3772);
INSERT INTO "django_geo_db_zipcode" VALUES(4114,11787,-5,'Smithtown, New York 11787',2832,3773);
INSERT INTO "django_geo_db_zipcode" VALUES(4115,11788,-5,'Hauppauge, New York 11788',2844,3774);
INSERT INTO "django_geo_db_zipcode" VALUES(4116,11789,-5,'Sound Beach, New York 11789',2866,3775);
INSERT INTO "django_geo_db_zipcode" VALUES(4117,11790,-5,'Stony Brook, New York 11790',2867,3776);
INSERT INTO "django_geo_db_zipcode" VALUES(4118,11791,-5,'Syosset, New York 11791',2856,3777);
INSERT INTO "django_geo_db_zipcode" VALUES(4119,11792,-5,'Wading River, New York 11792',2868,3778);
INSERT INTO "django_geo_db_zipcode" VALUES(4120,11793,-5,'Wantagh, New York 11793',2869,3779);
INSERT INTO "django_geo_db_zipcode" VALUES(4121,11794,-5,'Stony Brook, New York 11794',2867,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4122,11795,-5,'West Islip, New York 11795',2870,3780);
INSERT INTO "django_geo_db_zipcode" VALUES(4123,11796,-5,'West Sayville, New York 11796',2871,3781);
INSERT INTO "django_geo_db_zipcode" VALUES(4124,11797,-5,'Woodbury, New York 11797',2645,3782);
INSERT INTO "django_geo_db_zipcode" VALUES(4125,11798,-5,'Wyandanch, New York 11798',2872,3783);
INSERT INTO "django_geo_db_zipcode" VALUES(4126,11801,-5,'Hicksville, New York 11801',2873,3784);
INSERT INTO "django_geo_db_zipcode" VALUES(4127,11802,-5,'Hicksville, New York 11802',2873,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4128,11803,-5,'Plainview, New York 11803',2874,3785);
INSERT INTO "django_geo_db_zipcode" VALUES(4129,11804,-5,'Old Bethpage, New York 11804',2875,3786);
INSERT INTO "django_geo_db_zipcode" VALUES(4130,11805,-5,'Mid Island, New York 11805',2876,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4131,11815,-5,'Hicksville, New York 11815',2873,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4132,11819,-5,'Hicksville, New York 11819',2873,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4133,11853,-5,'Jericho, New York 11853',2838,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4134,11854,-5,'Hicksville, New York 11854',2873,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4135,11855,-5,'Hicksville, New York 11855',2873,3549);
INSERT INTO "django_geo_db_zipcode" VALUES(4136,11901,-5,'Riverhead, New York 11901',2877,3787);
INSERT INTO "django_geo_db_zipcode" VALUES(4137,11930,-5,'Amagansett, New York 11930',2878,3788);
INSERT INTO "django_geo_db_zipcode" VALUES(4138,11931,-5,'Aquebogue, New York 11931',2879,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4139,11932,-5,'Bridgehampton, New York 11932',2880,3789);
INSERT INTO "django_geo_db_zipcode" VALUES(4140,11933,-5,'Calverton, New York 11933',2881,3790);
INSERT INTO "django_geo_db_zipcode" VALUES(4141,11934,-5,'Center Moriches, New York 11934',2882,3791);
INSERT INTO "django_geo_db_zipcode" VALUES(4142,11935,-5,'Cutchogue, New York 11935',2883,3792);
INSERT INTO "django_geo_db_zipcode" VALUES(4143,11937,-5,'East Hampton, New York 11937',2884,3793);
INSERT INTO "django_geo_db_zipcode" VALUES(4144,11939,-5,'East Marion, New York 11939',2885,3794);
INSERT INTO "django_geo_db_zipcode" VALUES(4145,11940,-5,'East Moriches, New York 11940',2886,3795);
INSERT INTO "django_geo_db_zipcode" VALUES(4146,11941,-5,'Eastport, New York 11941',2887,3796);
INSERT INTO "django_geo_db_zipcode" VALUES(4147,11942,-5,'East Quogue, New York 11942',2888,3797);
INSERT INTO "django_geo_db_zipcode" VALUES(4148,11944,-5,'Greenport, New York 11944',2889,3798);
INSERT INTO "django_geo_db_zipcode" VALUES(4149,11946,-5,'Hampton Bays, New York 11946',2890,3799);
INSERT INTO "django_geo_db_zipcode" VALUES(4150,11947,-5,'Jamesport, New York 11947',2891,3800);
INSERT INTO "django_geo_db_zipcode" VALUES(4151,11948,-5,'Laurel, New York 11948',2892,3801);
INSERT INTO "django_geo_db_zipcode" VALUES(4152,11949,-5,'Manorville, New York 11949',2893,3802);
INSERT INTO "django_geo_db_zipcode" VALUES(4153,11950,-5,'Mastic, New York 11950',2894,3803);
INSERT INTO "django_geo_db_zipcode" VALUES(4154,11951,-5,'Mastic Beach, New York 11951',2895,3804);
INSERT INTO "django_geo_db_zipcode" VALUES(4155,11952,-5,'Mattituck, New York 11952',2896,3805);
INSERT INTO "django_geo_db_zipcode" VALUES(4156,11953,-5,'Middle Island, New York 11953',2897,3806);
INSERT INTO "django_geo_db_zipcode" VALUES(4157,11954,-5,'Montauk, New York 11954',2898,3807);
INSERT INTO "django_geo_db_zipcode" VALUES(4158,11955,-5,'Moriches, New York 11955',2899,3808);
INSERT INTO "django_geo_db_zipcode" VALUES(4159,11956,-5,'New Suffolk, New York 11956',2900,3809);
INSERT INTO "django_geo_db_zipcode" VALUES(4160,11957,-5,'Orient, New York 11957',2901,3810);
INSERT INTO "django_geo_db_zipcode" VALUES(4161,11958,-5,'Peconic, New York 11958',2902,3811);
INSERT INTO "django_geo_db_zipcode" VALUES(4162,11959,-5,'Quogue, New York 11959',2903,3812);
INSERT INTO "django_geo_db_zipcode" VALUES(4163,11960,-5,'Remsenburg, New York 11960',2904,3813);
INSERT INTO "django_geo_db_zipcode" VALUES(4164,11961,-5,'Ridge, New York 11961',2905,3814);
INSERT INTO "django_geo_db_zipcode" VALUES(4165,11962,-5,'Sagaponack, New York 11962',2906,3815);
INSERT INTO "django_geo_db_zipcode" VALUES(4166,11963,-5,'Sag Harbor, New York 11963',2907,3816);
INSERT INTO "django_geo_db_zipcode" VALUES(4167,11964,-5,'Shelter Island, New York 11964',2908,3817);
INSERT INTO "django_geo_db_zipcode" VALUES(4168,11965,-5,'Shelter Island Heights, New York 11965',2909,3818);
INSERT INTO "django_geo_db_zipcode" VALUES(4169,11967,-5,'Shirley, New York 11967',2910,3819);
INSERT INTO "django_geo_db_zipcode" VALUES(4170,11968,-5,'Southampton, New York 11968',2911,3820);
INSERT INTO "django_geo_db_zipcode" VALUES(4171,11969,-5,'Southampton, New York 11969',2911,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4172,11970,-5,'South Jamesport, New York 11970',2912,3821);
INSERT INTO "django_geo_db_zipcode" VALUES(4173,11971,-5,'Southold, New York 11971',2913,3822);
INSERT INTO "django_geo_db_zipcode" VALUES(4174,11972,-5,'Speonk, New York 11972',2914,3823);
INSERT INTO "django_geo_db_zipcode" VALUES(4175,11973,-5,'Upton, New York 11973',2915,295);
INSERT INTO "django_geo_db_zipcode" VALUES(4176,11975,-5,'Wainscott, New York 11975',2916,3824);
INSERT INTO "django_geo_db_zipcode" VALUES(4177,11976,-5,'Water Mill, New York 11976',2917,3825);
INSERT INTO "django_geo_db_zipcode" VALUES(4178,11977,-5,'Westhampton, New York 11977',2918,3826);
INSERT INTO "django_geo_db_zipcode" VALUES(4179,11978,-5,'Westhampton Beach, New York 11978',2919,3827);
INSERT INTO "django_geo_db_zipcode" VALUES(4180,11980,-5,'Yaphank, New York 11980',2920,3828);
INSERT INTO "django_geo_db_zipcode" VALUES(4181,12007,-5,'Alcove, New York 12007',2921,3829);
INSERT INTO "django_geo_db_zipcode" VALUES(4182,12008,-5,'Alplaus, New York 12008',2922,3830);
INSERT INTO "django_geo_db_zipcode" VALUES(4183,12009,-5,'Altamont, New York 12009',2923,3831);
INSERT INTO "django_geo_db_zipcode" VALUES(4184,12010,-5,'Amsterdam, New York 12010',2924,3832);
INSERT INTO "django_geo_db_zipcode" VALUES(4185,12015,-5,'Athens, New York 12015',2925,3833);
INSERT INTO "django_geo_db_zipcode" VALUES(4186,12016,-5,'Auriesville, New York 12016',2926,3834);
INSERT INTO "django_geo_db_zipcode" VALUES(4187,12017,-5,'Austerlitz, New York 12017',2927,3835);
INSERT INTO "django_geo_db_zipcode" VALUES(4188,12018,-5,'Averill Park, New York 12018',2928,3836);
INSERT INTO "django_geo_db_zipcode" VALUES(4189,12019,-5,'Ballston Lake, New York 12019',2929,3837);
INSERT INTO "django_geo_db_zipcode" VALUES(4190,12020,-5,'Ballston Spa, New York 12020',2930,3838);
INSERT INTO "django_geo_db_zipcode" VALUES(4191,12022,-5,'Berlin, New York 12022',2931,3839);
INSERT INTO "django_geo_db_zipcode" VALUES(4192,12023,-5,'Berne, New York 12023',2932,3840);
INSERT INTO "django_geo_db_zipcode" VALUES(4193,12024,-5,'Brainard, New York 12024',2933,3841);
INSERT INTO "django_geo_db_zipcode" VALUES(4194,12025,-5,'Broadalbin, New York 12025',2934,3842);
INSERT INTO "django_geo_db_zipcode" VALUES(4195,12027,-5,'Burnt Hills, New York 12027',2935,3843);
INSERT INTO "django_geo_db_zipcode" VALUES(4196,12028,-5,'Buskirk, New York 12028',2936,3844);
INSERT INTO "django_geo_db_zipcode" VALUES(4197,12029,-5,'Canaan, New York 12029',2937,3845);
INSERT INTO "django_geo_db_zipcode" VALUES(4198,12031,-5,'Carlisle, New York 12031',2938,3846);
INSERT INTO "django_geo_db_zipcode" VALUES(4199,12032,-5,'Caroga Lake, New York 12032',2939,3847);
INSERT INTO "django_geo_db_zipcode" VALUES(4200,12033,-5,'Castleton On Hudson, New York 12033',2940,3848);
INSERT INTO "django_geo_db_zipcode" VALUES(4201,12035,-5,'Central Bridge, New York 12035',2941,3849);
INSERT INTO "django_geo_db_zipcode" VALUES(4202,12036,-5,'Charlotteville, New York 12036',2942,3850);
INSERT INTO "django_geo_db_zipcode" VALUES(4203,12037,-5,'Chatham, New York 12037',2943,3851);
INSERT INTO "django_geo_db_zipcode" VALUES(4204,12040,-5,'Cherry Plain, New York 12040',2944,3852);
INSERT INTO "django_geo_db_zipcode" VALUES(4205,12041,-5,'Clarksville, New York 12041',2945,3853);
INSERT INTO "django_geo_db_zipcode" VALUES(4206,12042,-5,'Climax, New York 12042',2946,3854);
INSERT INTO "django_geo_db_zipcode" VALUES(4207,12043,-5,'Cobleskill, New York 12043',2947,3855);
INSERT INTO "django_geo_db_zipcode" VALUES(4208,12045,-5,'Coeymans, New York 12045',2948,3856);
INSERT INTO "django_geo_db_zipcode" VALUES(4209,12046,-5,'Coeymans Hollow, New York 12046',2949,3857);
INSERT INTO "django_geo_db_zipcode" VALUES(4210,12047,-5,'Cohoes, New York 12047',2950,3858);
INSERT INTO "django_geo_db_zipcode" VALUES(4211,12050,-5,'Columbiaville, New York 12050',2951,3859);
INSERT INTO "django_geo_db_zipcode" VALUES(4212,12051,-5,'Coxsackie, New York 12051',2952,3860);
INSERT INTO "django_geo_db_zipcode" VALUES(4213,12052,-5,'Cropseyville, New York 12052',2953,3861);
INSERT INTO "django_geo_db_zipcode" VALUES(4214,12053,-5,'Delanson, New York 12053',2954,3862);
INSERT INTO "django_geo_db_zipcode" VALUES(4215,12054,-5,'Delmar, New York 12054',2955,3863);
INSERT INTO "django_geo_db_zipcode" VALUES(4216,12055,-5,'Dormansville, New York 12055',2956,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4217,12056,-5,'Duanesburg, New York 12056',2957,3865);
INSERT INTO "django_geo_db_zipcode" VALUES(4218,12057,-5,'Eagle Bridge, New York 12057',2958,3866);
INSERT INTO "django_geo_db_zipcode" VALUES(4219,12058,-5,'Earlton, New York 12058',2959,3867);
INSERT INTO "django_geo_db_zipcode" VALUES(4220,12059,-5,'East Berne, New York 12059',2960,3868);
INSERT INTO "django_geo_db_zipcode" VALUES(4221,12060,-5,'East Chatham, New York 12060',2961,3869);
INSERT INTO "django_geo_db_zipcode" VALUES(4222,12061,-5,'East Greenbush, New York 12061',2962,3870);
INSERT INTO "django_geo_db_zipcode" VALUES(4223,12062,-5,'East Nassau, New York 12062',2963,3871);
INSERT INTO "django_geo_db_zipcode" VALUES(4224,12063,-5,'East Schodack, New York 12063',2964,3872);
INSERT INTO "django_geo_db_zipcode" VALUES(4225,12064,-5,'East Worcester, New York 12064',2965,3873);
INSERT INTO "django_geo_db_zipcode" VALUES(4226,12065,-5,'Clifton Park, New York 12065',2966,3874);
INSERT INTO "django_geo_db_zipcode" VALUES(4227,12066,-5,'Esperance, New York 12066',2967,3875);
INSERT INTO "django_geo_db_zipcode" VALUES(4228,12067,-5,'Feura Bush, New York 12067',2968,3876);
INSERT INTO "django_geo_db_zipcode" VALUES(4229,12068,-5,'Fonda, New York 12068',2969,3877);
INSERT INTO "django_geo_db_zipcode" VALUES(4230,12069,-5,'Fort Hunter, New York 12069',2970,3878);
INSERT INTO "django_geo_db_zipcode" VALUES(4231,12070,-5,'Fort Johnson, New York 12070',2971,3879);
INSERT INTO "django_geo_db_zipcode" VALUES(4232,12071,-5,'Fultonham, New York 12071',2972,3880);
INSERT INTO "django_geo_db_zipcode" VALUES(4233,12072,-5,'Fultonville, New York 12072',2973,3881);
INSERT INTO "django_geo_db_zipcode" VALUES(4234,12073,-5,'Gallupville, New York 12073',2974,3882);
INSERT INTO "django_geo_db_zipcode" VALUES(4235,12074,-5,'Galway, New York 12074',2975,3883);
INSERT INTO "django_geo_db_zipcode" VALUES(4236,12075,-5,'Ghent, New York 12075',2976,3884);
INSERT INTO "django_geo_db_zipcode" VALUES(4237,12076,-5,'Gilboa, New York 12076',2977,3885);
INSERT INTO "django_geo_db_zipcode" VALUES(4238,12077,-5,'Glenmont, New York 12077',2978,3886);
INSERT INTO "django_geo_db_zipcode" VALUES(4239,12078,-5,'Gloversville, New York 12078',2979,3887);
INSERT INTO "django_geo_db_zipcode" VALUES(4240,12081,-5,'Nassau, New York 12081',2980,3888);
INSERT INTO "django_geo_db_zipcode" VALUES(4241,12082,-5,'Grafton, New York 12082',2981,3889);
INSERT INTO "django_geo_db_zipcode" VALUES(4242,12083,-5,'Greenville, New York 12083',2627,3890);
INSERT INTO "django_geo_db_zipcode" VALUES(4243,12084,-5,'Guilderland, New York 12084',2982,3891);
INSERT INTO "django_geo_db_zipcode" VALUES(4244,12085,-5,'Guilderland Center, New York 12085',2983,3892);
INSERT INTO "django_geo_db_zipcode" VALUES(4245,12086,-5,'Hagaman, New York 12086',2984,3893);
INSERT INTO "django_geo_db_zipcode" VALUES(4246,12087,-5,'Hannacroix, New York 12087',2985,3894);
INSERT INTO "django_geo_db_zipcode" VALUES(4247,12089,-5,'Hoosick, New York 12089',2986,3895);
INSERT INTO "django_geo_db_zipcode" VALUES(4248,12090,-5,'Hoosick Falls, New York 12090',2987,3896);
INSERT INTO "django_geo_db_zipcode" VALUES(4249,12092,-5,'Howes Cave, New York 12092',2988,3897);
INSERT INTO "django_geo_db_zipcode" VALUES(4250,12093,-5,'Jefferson, New York 12093',2989,3898);
INSERT INTO "django_geo_db_zipcode" VALUES(4251,12094,-5,'Johnsonville, New York 12094',2990,3899);
INSERT INTO "django_geo_db_zipcode" VALUES(4252,12095,-5,'Johnstown, New York 12095',2991,3900);
INSERT INTO "django_geo_db_zipcode" VALUES(4253,12103,-5,'Knox, New York 12103',2992,3901);
INSERT INTO "django_geo_db_zipcode" VALUES(4254,12106,-5,'Kinderhook, New York 12106',2993,3902);
INSERT INTO "django_geo_db_zipcode" VALUES(4255,12107,-5,'Knox, New York 12107',2992,3903);
INSERT INTO "django_geo_db_zipcode" VALUES(4256,12108,-5,'Lake Pleasant, New York 12108',2994,3904);
INSERT INTO "django_geo_db_zipcode" VALUES(4257,12110,-5,'Latham, New York 12110',2995,3905);
INSERT INTO "django_geo_db_zipcode" VALUES(4258,12111,-5,'Latham, New York 12111',2995,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4259,12115,-5,'Malden Bridge, New York 12115',2996,3906);
INSERT INTO "django_geo_db_zipcode" VALUES(4260,12116,-5,'Maryland, New York 12116',2997,3907);
INSERT INTO "django_geo_db_zipcode" VALUES(4261,12117,-5,'Mayfield, New York 12117',2998,3908);
INSERT INTO "django_geo_db_zipcode" VALUES(4262,12118,-5,'Mechanicville, New York 12118',2999,3909);
INSERT INTO "django_geo_db_zipcode" VALUES(4263,12120,-5,'Medusa, New York 12120',3000,3910);
INSERT INTO "django_geo_db_zipcode" VALUES(4264,12121,-5,'Melrose, New York 12121',3001,3911);
INSERT INTO "django_geo_db_zipcode" VALUES(4265,12122,-5,'Middleburgh, New York 12122',3002,3912);
INSERT INTO "django_geo_db_zipcode" VALUES(4266,12123,-5,'Nassau, New York 12123',2980,3913);
INSERT INTO "django_geo_db_zipcode" VALUES(4267,12124,-5,'New Baltimore, New York 12124',3003,3914);
INSERT INTO "django_geo_db_zipcode" VALUES(4268,12125,-5,'New Lebanon, New York 12125',3004,3915);
INSERT INTO "django_geo_db_zipcode" VALUES(4269,12128,-5,'Newtonville, New York 12128',3005,3916);
INSERT INTO "django_geo_db_zipcode" VALUES(4270,12130,-5,'Niverville, New York 12130',3006,3917);
INSERT INTO "django_geo_db_zipcode" VALUES(4271,12131,-5,'North Blenheim, New York 12131',3007,3918);
INSERT INTO "django_geo_db_zipcode" VALUES(4272,12132,-5,'North Chatham, New York 12132',3008,3919);
INSERT INTO "django_geo_db_zipcode" VALUES(4273,12133,-5,'North Hoosick, New York 12133',3009,3920);
INSERT INTO "django_geo_db_zipcode" VALUES(4274,12134,-5,'Northville, New York 12134',3010,3921);
INSERT INTO "django_geo_db_zipcode" VALUES(4275,12136,-5,'Old Chatham, New York 12136',3011,3922);
INSERT INTO "django_geo_db_zipcode" VALUES(4276,12137,-5,'Pattersonville, New York 12137',3012,3923);
INSERT INTO "django_geo_db_zipcode" VALUES(4277,12138,-5,'Petersburg, New York 12138',3013,3924);
INSERT INTO "django_geo_db_zipcode" VALUES(4278,12139,-5,'Piseco, New York 12139',3014,3925);
INSERT INTO "django_geo_db_zipcode" VALUES(4279,12140,-5,'Poestenkill, New York 12140',3015,3926);
INSERT INTO "django_geo_db_zipcode" VALUES(4280,12141,-5,'Quaker Street, New York 12141',3016,3927);
INSERT INTO "django_geo_db_zipcode" VALUES(4281,12143,-5,'Ravena, New York 12143',3017,3928);
INSERT INTO "django_geo_db_zipcode" VALUES(4282,12144,-5,'Rensselaer, New York 12144',3018,3929);
INSERT INTO "django_geo_db_zipcode" VALUES(4283,12147,-5,'Rensselaerville, New York 12147',3019,3930);
INSERT INTO "django_geo_db_zipcode" VALUES(4284,12148,-5,'Rexford, New York 12148',3020,3931);
INSERT INTO "django_geo_db_zipcode" VALUES(4285,12149,-5,'Richmondville, New York 12149',3021,3932);
INSERT INTO "django_geo_db_zipcode" VALUES(4286,12150,-5,'Rotterdam Junction, New York 12150',3022,3933);
INSERT INTO "django_geo_db_zipcode" VALUES(4287,12151,-5,'Round Lake, New York 12151',3023,3934);
INSERT INTO "django_geo_db_zipcode" VALUES(4288,12153,-5,'Sand Lake, New York 12153',3024,3935);
INSERT INTO "django_geo_db_zipcode" VALUES(4289,12154,-5,'Schaghticoke, New York 12154',3025,3936);
INSERT INTO "django_geo_db_zipcode" VALUES(4290,12155,-5,'Schenevus, New York 12155',3026,3937);
INSERT INTO "django_geo_db_zipcode" VALUES(4291,12156,-5,'Schodack Landing, New York 12156',3027,3938);
INSERT INTO "django_geo_db_zipcode" VALUES(4292,12157,-5,'Schoharie, New York 12157',3028,3939);
INSERT INTO "django_geo_db_zipcode" VALUES(4293,12158,-5,'Selkirk, New York 12158',3029,3940);
INSERT INTO "django_geo_db_zipcode" VALUES(4294,12159,-5,'Slingerlands, New York 12159',3030,3941);
INSERT INTO "django_geo_db_zipcode" VALUES(4295,12160,-5,'Sloansville, New York 12160',3031,3942);
INSERT INTO "django_geo_db_zipcode" VALUES(4296,12161,-5,'South Bethlehem, New York 12161',3032,3943);
INSERT INTO "django_geo_db_zipcode" VALUES(4297,12162,-5,'South Schodack, New York 12162',3033,3944);
INSERT INTO "django_geo_db_zipcode" VALUES(4298,12164,-5,'Speculator, New York 12164',3034,3945);
INSERT INTO "django_geo_db_zipcode" VALUES(4299,12165,-5,'Spencertown, New York 12165',3035,3946);
INSERT INTO "django_geo_db_zipcode" VALUES(4300,12166,-5,'Sprakers, New York 12166',3036,3947);
INSERT INTO "django_geo_db_zipcode" VALUES(4301,12167,-5,'Stamford, New York 12167',3037,3948);
INSERT INTO "django_geo_db_zipcode" VALUES(4302,12168,-5,'Stephentown, New York 12168',3038,3949);
INSERT INTO "django_geo_db_zipcode" VALUES(4303,12169,-5,'Stephentown, New York 12169',3038,3950);
INSERT INTO "django_geo_db_zipcode" VALUES(4304,12170,-5,'Stillwater, New York 12170',3039,3951);
INSERT INTO "django_geo_db_zipcode" VALUES(4305,12172,-5,'Stottville, New York 12172',3040,3952);
INSERT INTO "django_geo_db_zipcode" VALUES(4306,12173,-5,'Stuyvesant, New York 12173',3041,3953);
INSERT INTO "django_geo_db_zipcode" VALUES(4307,12174,-5,'Stuyvesant Falls, New York 12174',3042,3954);
INSERT INTO "django_geo_db_zipcode" VALUES(4308,12175,-5,'Summit, New York 12175',3043,3955);
INSERT INTO "django_geo_db_zipcode" VALUES(4309,12176,-5,'Surprise, New York 12176',3044,3956);
INSERT INTO "django_geo_db_zipcode" VALUES(4310,12177,-5,'Tribes Hill, New York 12177',3045,3957);
INSERT INTO "django_geo_db_zipcode" VALUES(4311,12179,-5,'Troy, New York 12179',3046,3958);
INSERT INTO "django_geo_db_zipcode" VALUES(4312,12180,-5,'Troy, New York 12180',3046,3959);
INSERT INTO "django_geo_db_zipcode" VALUES(4313,12181,-5,'Troy, New York 12181',3046,3960);
INSERT INTO "django_geo_db_zipcode" VALUES(4314,12182,-5,'Troy, New York 12182',3046,3961);
INSERT INTO "django_geo_db_zipcode" VALUES(4315,12183,-5,'Troy, New York 12183',3046,3962);
INSERT INTO "django_geo_db_zipcode" VALUES(4316,12184,-5,'Valatie, New York 12184',3047,3963);
INSERT INTO "django_geo_db_zipcode" VALUES(4317,12185,-5,'Valley Falls, New York 12185',3048,3964);
INSERT INTO "django_geo_db_zipcode" VALUES(4318,12186,-5,'Voorheesville, New York 12186',3049,3965);
INSERT INTO "django_geo_db_zipcode" VALUES(4319,12187,-5,'Warnerville, New York 12187',3050,3966);
INSERT INTO "django_geo_db_zipcode" VALUES(4320,12188,-5,'Waterford, New York 12188',3051,3967);
INSERT INTO "django_geo_db_zipcode" VALUES(4321,12189,-5,'Watervliet, New York 12189',3052,3968);
INSERT INTO "django_geo_db_zipcode" VALUES(4322,12190,-5,'Wells, New York 12190',3053,3969);
INSERT INTO "django_geo_db_zipcode" VALUES(4323,12192,-5,'West Coxsackie, New York 12192',3054,3970);
INSERT INTO "django_geo_db_zipcode" VALUES(4324,12193,-5,'Westerlo, New York 12193',3055,3971);
INSERT INTO "django_geo_db_zipcode" VALUES(4325,12194,-5,'West Fulton, New York 12194',3056,3972);
INSERT INTO "django_geo_db_zipcode" VALUES(4326,12195,-5,'West Lebanon, New York 12195',3057,3973);
INSERT INTO "django_geo_db_zipcode" VALUES(4327,12196,-5,'West Sand Lake, New York 12196',3058,3974);
INSERT INTO "django_geo_db_zipcode" VALUES(4328,12197,-5,'Worcester, New York 12197',3059,3975);
INSERT INTO "django_geo_db_zipcode" VALUES(4329,12198,-5,'Wynantskill, New York 12198',3060,3976);
INSERT INTO "django_geo_db_zipcode" VALUES(4330,12201,-5,'Albany, New York 12201',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4331,12202,-5,'Albany, New York 12202',3061,3977);
INSERT INTO "django_geo_db_zipcode" VALUES(4332,12203,-5,'Albany, New York 12203',3061,3978);
INSERT INTO "django_geo_db_zipcode" VALUES(4333,12204,-5,'Albany, New York 12204',3061,3979);
INSERT INTO "django_geo_db_zipcode" VALUES(4334,12205,-5,'Albany, New York 12205',3061,3980);
INSERT INTO "django_geo_db_zipcode" VALUES(4335,12206,-5,'Albany, New York 12206',3061,3981);
INSERT INTO "django_geo_db_zipcode" VALUES(4336,12207,-5,'Albany, New York 12207',3061,3982);
INSERT INTO "django_geo_db_zipcode" VALUES(4337,12208,-5,'Albany, New York 12208',3061,3983);
INSERT INTO "django_geo_db_zipcode" VALUES(4338,12209,-5,'Albany, New York 12209',3061,3984);
INSERT INTO "django_geo_db_zipcode" VALUES(4339,12210,-5,'Albany, New York 12210',3061,3985);
INSERT INTO "django_geo_db_zipcode" VALUES(4340,12211,-5,'Albany, New York 12211',3061,3986);
INSERT INTO "django_geo_db_zipcode" VALUES(4341,12212,-5,'Albany, New York 12212',3061,3987);
INSERT INTO "django_geo_db_zipcode" VALUES(4342,12214,-5,'Albany, New York 12214',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4343,12220,-5,'Albany, New York 12220',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4344,12222,-5,'Albany, New York 12222',3061,3988);
INSERT INTO "django_geo_db_zipcode" VALUES(4345,12223,-5,'Albany, New York 12223',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4346,12224,-5,'Albany, New York 12224',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4347,12225,-5,'Albany, New York 12225',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4348,12226,-5,'Albany, New York 12226',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4349,12227,-5,'Albany, New York 12227',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4350,12228,-5,'Albany, New York 12228',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4351,12229,-5,'Albany, New York 12229',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4352,12230,-5,'Albany, New York 12230',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4353,12231,-5,'Albany, New York 12231',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4354,12232,-5,'Albany, New York 12232',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4355,12233,-5,'Albany, New York 12233',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4356,12234,-5,'Albany, New York 12234',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4357,12235,-5,'Albany, New York 12235',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4358,12236,-5,'Albany, New York 12236',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4359,12237,-5,'Albany, New York 12237',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4360,12238,-5,'Albany, New York 12238',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4361,12239,-5,'Albany, New York 12239',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4362,12240,-5,'Albany, New York 12240',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4363,12241,-5,'Albany, New York 12241',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4364,12242,-5,'Albany, New York 12242',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4365,12243,-5,'Albany, New York 12243',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4366,12244,-5,'Albany, New York 12244',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4367,12245,-5,'Albany, New York 12245',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4368,12246,-5,'Albany, New York 12246',3061,3989);
INSERT INTO "django_geo_db_zipcode" VALUES(4369,12247,-5,'Albany, New York 12247',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4370,12248,-5,'Albany, New York 12248',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4371,12249,-5,'Albany, New York 12249',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4372,12250,-5,'Albany, New York 12250',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4373,12252,-5,'Albany, New York 12252',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4374,12255,-5,'Albany, New York 12255',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4375,12256,-5,'Albany, New York 12256',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4376,12257,-5,'Albany, New York 12257',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4377,12260,-5,'Albany, New York 12260',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4378,12261,-5,'Albany, New York 12261',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4379,12262,-5,'Albany, New York 12262',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4380,12288,-5,'Albany, New York 12288',3061,3864);
INSERT INTO "django_geo_db_zipcode" VALUES(4381,12301,-5,'Schenectady, New York 12301',3062,3990);
INSERT INTO "django_geo_db_zipcode" VALUES(4382,12302,-5,'Schenectady, New York 12302',3062,3991);
INSERT INTO "django_geo_db_zipcode" VALUES(4383,12303,-5,'Schenectady, New York 12303',3062,3992);
INSERT INTO "django_geo_db_zipcode" VALUES(4384,12304,-5,'Schenectady, New York 12304',3062,3993);
INSERT INTO "django_geo_db_zipcode" VALUES(4385,12305,-5,'Schenectady, New York 12305',3062,3994);
INSERT INTO "django_geo_db_zipcode" VALUES(4386,12306,-5,'Schenectady, New York 12306',3062,3995);
INSERT INTO "django_geo_db_zipcode" VALUES(4387,12307,-5,'Schenectady, New York 12307',3062,3996);
INSERT INTO "django_geo_db_zipcode" VALUES(4388,12308,-5,'Schenectady, New York 12308',3062,3997);
INSERT INTO "django_geo_db_zipcode" VALUES(4389,12309,-5,'Schenectady, New York 12309',3062,3998);
INSERT INTO "django_geo_db_zipcode" VALUES(4390,12325,-5,'Schenectady, New York 12325',3062,3990);
INSERT INTO "django_geo_db_zipcode" VALUES(4391,12345,-5,'Schenectady, New York 12345',3062,3990);
INSERT INTO "django_geo_db_zipcode" VALUES(4392,12401,-5,'Kingston, New York 12401',3063,3999);
INSERT INTO "django_geo_db_zipcode" VALUES(4393,12402,-5,'Kingston, New York 12402',3063,4000);
INSERT INTO "django_geo_db_zipcode" VALUES(4394,12404,-5,'Accord, New York 12404',3064,4001);
INSERT INTO "django_geo_db_zipcode" VALUES(4395,12405,-5,'Acra, New York 12405',3065,4002);
INSERT INTO "django_geo_db_zipcode" VALUES(4396,12406,-5,'Arkville, New York 12406',3066,4003);
INSERT INTO "django_geo_db_zipcode" VALUES(4397,12407,-5,'Ashland, New York 12407',3067,4004);
INSERT INTO "django_geo_db_zipcode" VALUES(4398,12409,-5,'Bearsville, New York 12409',3068,4005);
INSERT INTO "django_geo_db_zipcode" VALUES(4399,12410,-5,'Big Indian, New York 12410',3069,4006);
INSERT INTO "django_geo_db_zipcode" VALUES(4400,12411,-5,'Bloomington, New York 12411',3070,4007);
INSERT INTO "django_geo_db_zipcode" VALUES(4401,12412,-5,'Boiceville, New York 12412',3071,4008);
INSERT INTO "django_geo_db_zipcode" VALUES(4402,12413,-5,'Cairo, New York 12413',3072,4009);
INSERT INTO "django_geo_db_zipcode" VALUES(4403,12414,-5,'Catskill, New York 12414',3073,4010);
INSERT INTO "django_geo_db_zipcode" VALUES(4404,12416,-5,'Chichester, New York 12416',3074,4011);
INSERT INTO "django_geo_db_zipcode" VALUES(4405,12417,-5,'Connelly, New York 12417',3075,4012);
INSERT INTO "django_geo_db_zipcode" VALUES(4406,12418,-5,'Cornwallville, New York 12418',3076,4013);
INSERT INTO "django_geo_db_zipcode" VALUES(4407,12419,-5,'Cottekill, New York 12419',3077,4014);
INSERT INTO "django_geo_db_zipcode" VALUES(4408,12420,-5,'Cragsmoor, New York 12420',3078,4015);
INSERT INTO "django_geo_db_zipcode" VALUES(4409,12421,-5,'Denver, New York 12421',3079,4016);
INSERT INTO "django_geo_db_zipcode" VALUES(4410,12422,-5,'Durham, New York 12422',3080,4017);
INSERT INTO "django_geo_db_zipcode" VALUES(4411,12423,-5,'East Durham, New York 12423',3081,4018);
INSERT INTO "django_geo_db_zipcode" VALUES(4412,12424,-5,'East Jewett, New York 12424',3082,4019);
INSERT INTO "django_geo_db_zipcode" VALUES(4413,12427,-5,'Elka Park, New York 12427',3083,4020);
INSERT INTO "django_geo_db_zipcode" VALUES(4414,12428,-5,'Ellenville, New York 12428',3084,4021);
INSERT INTO "django_geo_db_zipcode" VALUES(4415,12429,-5,'Esopus, New York 12429',3085,4022);
INSERT INTO "django_geo_db_zipcode" VALUES(4416,12430,-5,'Fleischmanns, New York 12430',3086,4023);
INSERT INTO "django_geo_db_zipcode" VALUES(4417,12431,-5,'Freehold, New York 12431',3087,4024);
INSERT INTO "django_geo_db_zipcode" VALUES(4418,12432,-5,'Glasco, New York 12432',3088,4025);
INSERT INTO "django_geo_db_zipcode" VALUES(4419,12433,-5,'Glenford, New York 12433',3089,4026);
INSERT INTO "django_geo_db_zipcode" VALUES(4420,12434,-5,'Grand Gorge, New York 12434',3090,4027);
INSERT INTO "django_geo_db_zipcode" VALUES(4421,12435,-5,'Greenfield Park, New York 12435',3091,4028);
INSERT INTO "django_geo_db_zipcode" VALUES(4422,12436,-5,'Haines Falls, New York 12436',3092,4029);
INSERT INTO "django_geo_db_zipcode" VALUES(4423,12438,-5,'Halcottsville, New York 12438',3093,4030);
INSERT INTO "django_geo_db_zipcode" VALUES(4424,12439,-5,'Hensonville, New York 12439',3094,4031);
INSERT INTO "django_geo_db_zipcode" VALUES(4425,12440,-5,'High Falls, New York 12440',3095,4032);
INSERT INTO "django_geo_db_zipcode" VALUES(4426,12441,-5,'Highmount, New York 12441',3096,4000);
INSERT INTO "django_geo_db_zipcode" VALUES(4427,12442,-5,'Hunter, New York 12442',3097,4033);
INSERT INTO "django_geo_db_zipcode" VALUES(4428,12443,-5,'Hurley, New York 12443',3098,4034);
INSERT INTO "django_geo_db_zipcode" VALUES(4429,12444,-5,'Jewett, New York 12444',3099,4035);
INSERT INTO "django_geo_db_zipcode" VALUES(4430,12446,-5,'Kerhonkson, New York 12446',3100,4036);
INSERT INTO "django_geo_db_zipcode" VALUES(4431,12447,-5,'Saugerties, New York 12447',3101,4037);
INSERT INTO "django_geo_db_zipcode" VALUES(4432,12448,-5,'Lake Hill, New York 12448',3102,4038);
INSERT INTO "django_geo_db_zipcode" VALUES(4433,12449,-5,'Lake Katrine, New York 12449',3103,4039);
INSERT INTO "django_geo_db_zipcode" VALUES(4434,12450,-5,'Lanesville, New York 12450',3104,4040);
INSERT INTO "django_geo_db_zipcode" VALUES(4435,12451,-5,'Leeds, New York 12451',3105,4041);
INSERT INTO "django_geo_db_zipcode" VALUES(4436,12452,-5,'Lexington, New York 12452',3106,4042);
INSERT INTO "django_geo_db_zipcode" VALUES(4437,12453,-5,'Malden On Hudson, New York 12453',3107,4043);
INSERT INTO "django_geo_db_zipcode" VALUES(4438,12454,-5,'Maplecrest, New York 12454',3108,4044);
INSERT INTO "django_geo_db_zipcode" VALUES(4439,12455,-5,'Margaretville, New York 12455',3109,4045);
INSERT INTO "django_geo_db_zipcode" VALUES(4440,12456,-5,'Mount Marion, New York 12456',3110,4046);
INSERT INTO "django_geo_db_zipcode" VALUES(4441,12457,-5,'Mount Tremper, New York 12457',3111,4047);
INSERT INTO "django_geo_db_zipcode" VALUES(4442,12458,-5,'Napanoch, New York 12458',3112,4048);
INSERT INTO "django_geo_db_zipcode" VALUES(4443,12459,-5,'New Kingston, New York 12459',3113,4049);
INSERT INTO "django_geo_db_zipcode" VALUES(4444,12460,-5,'Oak Hill, New York 12460',3114,4050);
INSERT INTO "django_geo_db_zipcode" VALUES(4445,12461,-5,'Olivebridge, New York 12461',3115,4051);
INSERT INTO "django_geo_db_zipcode" VALUES(4446,12463,-5,'Palenville, New York 12463',3116,4052);
INSERT INTO "django_geo_db_zipcode" VALUES(4447,12464,-5,'Phoenicia, New York 12464',3117,4053);
INSERT INTO "django_geo_db_zipcode" VALUES(4448,12465,-5,'Pine Hill, New York 12465',3118,4054);
INSERT INTO "django_geo_db_zipcode" VALUES(4449,12466,-5,'Port Ewen, New York 12466',3119,4055);
INSERT INTO "django_geo_db_zipcode" VALUES(4450,12468,-5,'Prattsville, New York 12468',3120,4056);
INSERT INTO "django_geo_db_zipcode" VALUES(4451,12469,-5,'Preston Hollow, New York 12469',3121,4057);
INSERT INTO "django_geo_db_zipcode" VALUES(4452,12470,-5,'Purling, New York 12470',3122,4058);
INSERT INTO "django_geo_db_zipcode" VALUES(4453,12471,-5,'Rifton, New York 12471',3123,4059);
INSERT INTO "django_geo_db_zipcode" VALUES(4454,12472,-5,'Rosendale, New York 12472',3124,4060);
INSERT INTO "django_geo_db_zipcode" VALUES(4455,12473,-5,'Round Top, New York 12473',3125,4061);
INSERT INTO "django_geo_db_zipcode" VALUES(4456,12474,-5,'Roxbury, New York 12474',3126,4062);
INSERT INTO "django_geo_db_zipcode" VALUES(4457,12475,-5,'Ruby, New York 12475',3127,4063);
INSERT INTO "django_geo_db_zipcode" VALUES(4458,12477,-5,'Saugerties, New York 12477',3101,4064);
INSERT INTO "django_geo_db_zipcode" VALUES(4459,12480,-5,'Shandaken, New York 12480',3128,4065);
INSERT INTO "django_geo_db_zipcode" VALUES(4460,12481,-5,'Shokan, New York 12481',3129,4066);
INSERT INTO "django_geo_db_zipcode" VALUES(4461,12482,-5,'South Cairo, New York 12482',3130,4067);
INSERT INTO "django_geo_db_zipcode" VALUES(4462,12483,-5,'Spring Glen, New York 12483',3131,4068);
INSERT INTO "django_geo_db_zipcode" VALUES(4463,12484,-5,'Stone Ridge, New York 12484',3132,4069);
INSERT INTO "django_geo_db_zipcode" VALUES(4464,12485,-5,'Tannersville, New York 12485',3133,4070);
INSERT INTO "django_geo_db_zipcode" VALUES(4465,12486,-5,'Tillson, New York 12486',3134,4071);
INSERT INTO "django_geo_db_zipcode" VALUES(4466,12487,-5,'Ulster Park, New York 12487',3135,4072);
INSERT INTO "django_geo_db_zipcode" VALUES(4467,12489,-5,'Wawarsing, New York 12489',3136,4073);
INSERT INTO "django_geo_db_zipcode" VALUES(4468,12490,-5,'West Camp, New York 12490',3137,4074);
INSERT INTO "django_geo_db_zipcode" VALUES(4469,12491,-5,'West Hurley, New York 12491',3138,4075);
INSERT INTO "django_geo_db_zipcode" VALUES(4470,12492,-5,'West Kill, New York 12492',3139,4076);
INSERT INTO "django_geo_db_zipcode" VALUES(4471,12493,-5,'West Park, New York 12493',3140,4077);
INSERT INTO "django_geo_db_zipcode" VALUES(4472,12494,-5,'West Shokan, New York 12494',3141,4078);
INSERT INTO "django_geo_db_zipcode" VALUES(4473,12495,-5,'Willow, New York 12495',3142,4079);
INSERT INTO "django_geo_db_zipcode" VALUES(4474,12496,-5,'Windham, New York 12496',3143,4080);
INSERT INTO "django_geo_db_zipcode" VALUES(4475,12498,-5,'Woodstock, New York 12498',3144,4081);
INSERT INTO "django_geo_db_zipcode" VALUES(4476,12501,-5,'Amenia, New York 12501',3145,4082);
INSERT INTO "django_geo_db_zipcode" VALUES(4477,12502,-5,'Ancram, New York 12502',3146,4083);
INSERT INTO "django_geo_db_zipcode" VALUES(4478,12503,-5,'Ancramdale, New York 12503',3147,4084);
INSERT INTO "django_geo_db_zipcode" VALUES(4479,12504,-5,'Annandale On Hudson, New York 12504',3148,4085);
INSERT INTO "django_geo_db_zipcode" VALUES(4480,12506,-5,'Bangall, New York 12506',3149,4086);
INSERT INTO "django_geo_db_zipcode" VALUES(4481,12507,-5,'Barrytown, New York 12507',3150,4087);
INSERT INTO "django_geo_db_zipcode" VALUES(4482,12508,-5,'Beacon, New York 12508',3151,4088);
INSERT INTO "django_geo_db_zipcode" VALUES(4483,12509,-5,'La Grange, New York 12509',3152,4089);
INSERT INTO "django_geo_db_zipcode" VALUES(4484,12510,-5,'Billings, New York 12510',3153,4086);
INSERT INTO "django_geo_db_zipcode" VALUES(4485,12511,-5,'Castle Point, New York 12511',3154,4086);
INSERT INTO "django_geo_db_zipcode" VALUES(4486,12512,-5,'Chelsea, New York 12512',3155,4090);
INSERT INTO "django_geo_db_zipcode" VALUES(4487,12513,-5,'Claverack, New York 12513',3156,4091);
INSERT INTO "django_geo_db_zipcode" VALUES(4488,12514,-5,'Clinton Corners, New York 12514',3157,4092);
INSERT INTO "django_geo_db_zipcode" VALUES(4489,12515,-5,'Clintondale, New York 12515',3158,4093);
INSERT INTO "django_geo_db_zipcode" VALUES(4490,12516,-5,'Copake, New York 12516',3159,4094);
INSERT INTO "django_geo_db_zipcode" VALUES(4491,12517,-5,'Copake Falls, New York 12517',3160,4095);
INSERT INTO "django_geo_db_zipcode" VALUES(4492,12518,-5,'Cornwall, New York 12518',3161,4096);
INSERT INTO "django_geo_db_zipcode" VALUES(4493,12520,-5,'Cornwall On Hudson, New York 12520',3162,4097);
INSERT INTO "django_geo_db_zipcode" VALUES(4494,12521,-5,'Craryville, New York 12521',3163,4098);
INSERT INTO "django_geo_db_zipcode" VALUES(4495,12522,-5,'Dover Plains, New York 12522',3164,4099);
INSERT INTO "django_geo_db_zipcode" VALUES(4496,12523,-5,'Elizaville, New York 12523',3165,4100);
INSERT INTO "django_geo_db_zipcode" VALUES(4497,12524,-5,'Fishkill, New York 12524',3166,4101);
INSERT INTO "django_geo_db_zipcode" VALUES(4498,12525,-5,'Gardiner, New York 12525',3167,4102);
INSERT INTO "django_geo_db_zipcode" VALUES(4499,12526,-5,'Germantown, New York 12526',3168,4103);
INSERT INTO "django_geo_db_zipcode" VALUES(4500,12527,-5,'Glenham, New York 12527',3169,4104);
INSERT INTO "django_geo_db_zipcode" VALUES(4501,12528,-5,'Highland, New York 12528',3170,4105);
INSERT INTO "django_geo_db_zipcode" VALUES(4502,12529,-5,'Hillsdale, New York 12529',3171,4106);
INSERT INTO "django_geo_db_zipcode" VALUES(4503,12530,-5,'Hollowville, New York 12530',3172,4107);
INSERT INTO "django_geo_db_zipcode" VALUES(4504,12531,-5,'Holmes, New York 12531',3173,4108);
INSERT INTO "django_geo_db_zipcode" VALUES(4505,12533,-5,'Hopewell Junction, New York 12533',3174,4109);
INSERT INTO "django_geo_db_zipcode" VALUES(4506,12534,-5,'Hudson, New York 12534',3175,4110);
INSERT INTO "django_geo_db_zipcode" VALUES(4507,12537,-5,'Hughsonville, New York 12537',3176,4111);
INSERT INTO "django_geo_db_zipcode" VALUES(4508,12538,-5,'Hyde Park, New York 12538',3177,4112);
INSERT INTO "django_geo_db_zipcode" VALUES(4509,12540,-5,'Lagrangeville, New York 12540',3178,4113);
INSERT INTO "django_geo_db_zipcode" VALUES(4510,12541,-5,'Livingston, New York 12541',3179,4114);
INSERT INTO "django_geo_db_zipcode" VALUES(4511,12542,-5,'Marlboro, New York 12542',3180,4115);
INSERT INTO "django_geo_db_zipcode" VALUES(4512,12543,-5,'Maybrook, New York 12543',3181,4116);
INSERT INTO "django_geo_db_zipcode" VALUES(4513,12544,-5,'Mellenville, New York 12544',3182,4117);
INSERT INTO "django_geo_db_zipcode" VALUES(4514,12545,-5,'Millbrook, New York 12545',3183,4118);
INSERT INTO "django_geo_db_zipcode" VALUES(4515,12546,-5,'Millerton, New York 12546',3184,4119);
INSERT INTO "django_geo_db_zipcode" VALUES(4516,12547,-5,'Milton, New York 12547',3185,4120);
INSERT INTO "django_geo_db_zipcode" VALUES(4517,12548,-5,'Modena, New York 12548',3186,4121);
INSERT INTO "django_geo_db_zipcode" VALUES(4518,12549,-5,'Montgomery, New York 12549',3187,4122);
INSERT INTO "django_geo_db_zipcode" VALUES(4519,12550,-5,'Newburgh, New York 12550',3188,4123);
INSERT INTO "django_geo_db_zipcode" VALUES(4520,12551,-5,'Newburgh, New York 12551',3188,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(4521,12552,-5,'Newburgh, New York 12552',3188,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(4522,12553,-5,'New Windsor, New York 12553',3189,4124);
INSERT INTO "django_geo_db_zipcode" VALUES(4523,12555,-5,'Mid Hudson, New York 12555',3190,3488);
INSERT INTO "django_geo_db_zipcode" VALUES(4524,12557,-5,'Newburgh, New York 12557',3188,4125);
INSERT INTO "django_geo_db_zipcode" VALUES(4525,12561,-5,'New Paltz, New York 12561',3191,4126);
INSERT INTO "django_geo_db_zipcode" VALUES(4526,12563,-5,'Patterson, New York 12563',3192,4127);
INSERT INTO "django_geo_db_zipcode" VALUES(4527,12564,-5,'Pawling, New York 12564',3193,4128);
INSERT INTO "django_geo_db_zipcode" VALUES(4528,12565,-5,'Philmont, New York 12565',3194,4129);
INSERT INTO "django_geo_db_zipcode" VALUES(4529,12566,-5,'Pine Bush, New York 12566',3195,4130);
INSERT INTO "django_geo_db_zipcode" VALUES(4530,12567,-5,'Pine Plains, New York 12567',3196,4131);
INSERT INTO "django_geo_db_zipcode" VALUES(4531,12568,-5,'Plattekill, New York 12568',3197,4132);
INSERT INTO "django_geo_db_zipcode" VALUES(4532,12569,-5,'Pleasant Valley, New York 12569',3198,4133);
INSERT INTO "django_geo_db_zipcode" VALUES(4533,12570,-5,'Poughquag, New York 12570',3199,4134);
INSERT INTO "django_geo_db_zipcode" VALUES(4534,12571,-5,'Red Hook, New York 12571',3200,4135);
INSERT INTO "django_geo_db_zipcode" VALUES(4535,12572,-5,'Rhinebeck, New York 12572',3201,4136);
INSERT INTO "django_geo_db_zipcode" VALUES(4536,12574,-5,'Rhinecliff, New York 12574',3202,4137);
INSERT INTO "django_geo_db_zipcode" VALUES(4537,12575,-5,'Rock Tavern, New York 12575',3203,4138);
INSERT INTO "django_geo_db_zipcode" VALUES(4538,12577,-5,'Salisbury Mills, New York 12577',3204,4139);
INSERT INTO "django_geo_db_zipcode" VALUES(4539,12578,-5,'Salt Point, New York 12578',3205,4140);
INSERT INTO "django_geo_db_zipcode" VALUES(4540,12580,-5,'Staatsburg, New York 12580',3206,4141);
INSERT INTO "django_geo_db_zipcode" VALUES(4541,12581,-5,'Stanfordville, New York 12581',3207,4142);
INSERT INTO "django_geo_db_zipcode" VALUES(4542,12582,-5,'Stormville, New York 12582',3208,4143);
INSERT INTO "django_geo_db_zipcode" VALUES(4543,12583,-5,'Tivoli, New York 12583',3209,4144);
INSERT INTO "django_geo_db_zipcode" VALUES(4544,12584,-5,'Vails Gate, New York 12584',3210,4145);
INSERT INTO "django_geo_db_zipcode" VALUES(4545,12585,-5,'Verbank, New York 12585',3211,4146);
INSERT INTO "django_geo_db_zipcode" VALUES(4546,12586,-5,'Walden, New York 12586',3212,4147);
INSERT INTO "django_geo_db_zipcode" VALUES(4547,12588,-5,'Walker Valley, New York 12588',3213,4000);
INSERT INTO "django_geo_db_zipcode" VALUES(4548,12589,-5,'Wallkill, New York 12589',2674,4148);
INSERT INTO "django_geo_db_zipcode" VALUES(4549,12590,-5,'Wappingers Falls, New York 12590',3214,4149);
INSERT INTO "django_geo_db_zipcode" VALUES(4550,12592,-5,'Wassaic, New York 12592',3215,4150);
INSERT INTO "django_geo_db_zipcode" VALUES(4551,12593,-5,'West Copake, New York 12593',3216,4151);
INSERT INTO "django_geo_db_zipcode" VALUES(4552,12594,-5,'Wingdale, New York 12594',3217,4152);
INSERT INTO "django_geo_db_zipcode" VALUES(4553,12601,-5,'Poughkeepsie, New York 12601',3218,4153);
INSERT INTO "django_geo_db_zipcode" VALUES(4554,12602,-5,'Poughkeepsie, New York 12602',3218,4086);
INSERT INTO "django_geo_db_zipcode" VALUES(4555,12603,-5,'Poughkeepsie, New York 12603',3218,4154);
INSERT INTO "django_geo_db_zipcode" VALUES(4556,12604,-5,'Poughkeepsie, New York 12604',3218,4086);
INSERT INTO "django_geo_db_zipcode" VALUES(4557,12697,-5,'Moira, New York 12697',3219,4155);
INSERT INTO "django_geo_db_zipcode" VALUES(4558,12701,-5,'Monticello, New York 12701',3220,4156);
INSERT INTO "django_geo_db_zipcode" VALUES(4559,12710,-5,'Neversink, New York 12710',3221,4157);
INSERT INTO "django_geo_db_zipcode" VALUES(4560,12719,-5,'Barryville, New York 12719',3222,4158);
INSERT INTO "django_geo_db_zipcode" VALUES(4561,12720,-5,'Bethel, New York 12720',3223,4159);
INSERT INTO "django_geo_db_zipcode" VALUES(4562,12721,-5,'Bloomingburg, New York 12721',3224,4160);
INSERT INTO "django_geo_db_zipcode" VALUES(4563,12722,-5,'Burlingham, New York 12722',3225,4161);
INSERT INTO "django_geo_db_zipcode" VALUES(4564,12723,-5,'Callicoon, New York 12723',3226,4162);
INSERT INTO "django_geo_db_zipcode" VALUES(4565,12724,-5,'Callicoon Center, New York 12724',3227,4163);
INSERT INTO "django_geo_db_zipcode" VALUES(4566,12725,-5,'Claryville, New York 12725',3228,4164);
INSERT INTO "django_geo_db_zipcode" VALUES(4567,12726,-5,'Cochecton, New York 12726',3229,4165);
INSERT INTO "django_geo_db_zipcode" VALUES(4568,12727,-5,'Cochecton Center, New York 12727',3230,4166);
INSERT INTO "django_geo_db_zipcode" VALUES(4569,12729,-5,'Cuddebackville, New York 12729',3231,4167);
INSERT INTO "django_geo_db_zipcode" VALUES(4570,12732,-5,'Eldred, New York 12732',3232,4168);
INSERT INTO "django_geo_db_zipcode" VALUES(4571,12733,-5,'Fallsburg, New York 12733',3233,4169);
INSERT INTO "django_geo_db_zipcode" VALUES(4572,12734,-5,'Ferndale, New York 12734',3234,4170);
INSERT INTO "django_geo_db_zipcode" VALUES(4573,12736,-5,'Fremont Center, New York 12736',3235,4171);
INSERT INTO "django_geo_db_zipcode" VALUES(4574,12737,-5,'Glen Spey, New York 12737',3236,4172);
INSERT INTO "django_geo_db_zipcode" VALUES(4575,12738,-5,'Glen Wild, New York 12738',3237,4173);
INSERT INTO "django_geo_db_zipcode" VALUES(4576,12739,-5,'Godeffroy, New York 12739',3238,4174);
INSERT INTO "django_geo_db_zipcode" VALUES(4577,12740,-5,'Grahamsville, New York 12740',3239,4175);
INSERT INTO "django_geo_db_zipcode" VALUES(4578,12741,-5,'Hankins, New York 12741',3240,4176);
INSERT INTO "django_geo_db_zipcode" VALUES(4579,12742,-5,'Harris, New York 12742',3241,4177);
INSERT INTO "django_geo_db_zipcode" VALUES(4580,12743,-5,'Highland Lake, New York 12743',3242,4178);
INSERT INTO "django_geo_db_zipcode" VALUES(4581,12745,-5,'Hortonville, New York 12745',3243,4179);
INSERT INTO "django_geo_db_zipcode" VALUES(4582,12746,-5,'Huguenot, New York 12746',3244,4180);
INSERT INTO "django_geo_db_zipcode" VALUES(4583,12747,-5,'Hurleyville, New York 12747',3245,4181);
INSERT INTO "django_geo_db_zipcode" VALUES(4584,12748,-5,'Jeffersonville, New York 12748',3246,4182);
INSERT INTO "django_geo_db_zipcode" VALUES(4585,12749,-5,'Kauneonga Lake, New York 12749',3247,4183);
INSERT INTO "django_geo_db_zipcode" VALUES(4586,12750,-5,'Kenoza Lake, New York 12750',3248,4184);
INSERT INTO "django_geo_db_zipcode" VALUES(4587,12751,-5,'Kiamesha Lake, New York 12751',3249,4185);
INSERT INTO "django_geo_db_zipcode" VALUES(4588,12752,-5,'Lake Huntington, New York 12752',3250,4186);
INSERT INTO "django_geo_db_zipcode" VALUES(4589,12754,-5,'Liberty, New York 12754',3251,4187);
INSERT INTO "django_geo_db_zipcode" VALUES(4590,12755,-5,'Ellenburg, New York 12755',3252,4188);
INSERT INTO "django_geo_db_zipcode" VALUES(4591,12756,-5,'Livingston Manor, New York 12756',3253,4189);
INSERT INTO "django_geo_db_zipcode" VALUES(4592,12758,-5,'Livingston Manor, New York 12758',3253,4190);
INSERT INTO "django_geo_db_zipcode" VALUES(4593,12759,-5,'Loch Sheldrake, New York 12759',3254,4191);
INSERT INTO "django_geo_db_zipcode" VALUES(4594,12760,-5,'Long Eddy, New York 12760',3255,4192);
INSERT INTO "django_geo_db_zipcode" VALUES(4595,12762,-5,'Mongaup Valley, New York 12762',3256,4193);
INSERT INTO "django_geo_db_zipcode" VALUES(4596,12763,-5,'Mountain Dale, New York 12763',3257,4194);
INSERT INTO "django_geo_db_zipcode" VALUES(4597,12764,-5,'Narrowsburg, New York 12764',3258,4195);
INSERT INTO "django_geo_db_zipcode" VALUES(4598,12765,-5,'Neversink, New York 12765',3221,4196);
INSERT INTO "django_geo_db_zipcode" VALUES(4599,12766,-5,'North Branch, New York 12766',3259,4197);
INSERT INTO "django_geo_db_zipcode" VALUES(4600,12767,-5,'Obernburg, New York 12767',3260,4161);
INSERT INTO "django_geo_db_zipcode" VALUES(4601,12768,-5,'Parksville, New York 12768',3261,4198);
INSERT INTO "django_geo_db_zipcode" VALUES(4602,12769,-5,'Phillipsport, New York 12769',3262,4199);
INSERT INTO "django_geo_db_zipcode" VALUES(4603,12770,-5,'Pond Eddy, New York 12770',3263,4200);
INSERT INTO "django_geo_db_zipcode" VALUES(4604,12771,-5,'Port Jervis, New York 12771',3264,4201);
INSERT INTO "django_geo_db_zipcode" VALUES(4605,12775,-5,'Rock Hill, New York 12775',3265,4202);
INSERT INTO "django_geo_db_zipcode" VALUES(4606,12776,-5,'Roscoe, New York 12776',3266,4203);
INSERT INTO "django_geo_db_zipcode" VALUES(4607,12777,-5,'Forestburgh, New York 12777',3267,4204);
INSERT INTO "django_geo_db_zipcode" VALUES(4608,12778,-5,'Smallwood, New York 12778',3268,4205);
INSERT INTO "django_geo_db_zipcode" VALUES(4609,12779,-5,'South Fallsburg, New York 12779',3269,4206);
INSERT INTO "django_geo_db_zipcode" VALUES(4610,12780,-5,'Sparrow Bush, New York 12780',3270,4207);
INSERT INTO "django_geo_db_zipcode" VALUES(4611,12781,-5,'Summitville, New York 12781',3271,4161);
INSERT INTO "django_geo_db_zipcode" VALUES(4612,12782,-5,'Sundown, New York 12782',3272,4208);
INSERT INTO "django_geo_db_zipcode" VALUES(4613,12783,-5,'Swan Lake, New York 12783',3273,4209);
INSERT INTO "django_geo_db_zipcode" VALUES(4614,12784,-5,'Thompsonville, New York 12784',3274,4210);
INSERT INTO "django_geo_db_zipcode" VALUES(4615,12785,-5,'Westbrookville, New York 12785',3275,4211);
INSERT INTO "django_geo_db_zipcode" VALUES(4616,12786,-5,'White Lake, New York 12786',3276,4212);
INSERT INTO "django_geo_db_zipcode" VALUES(4617,12787,-5,'White Sulphur Springs, New York 12787',3277,4213);
INSERT INTO "django_geo_db_zipcode" VALUES(4618,12788,-5,'Woodbourne, New York 12788',3278,4214);
INSERT INTO "django_geo_db_zipcode" VALUES(4619,12789,-5,'Woodridge, New York 12789',3279,4215);
INSERT INTO "django_geo_db_zipcode" VALUES(4620,12790,-5,'Wurtsboro, New York 12790',3280,4216);
INSERT INTO "django_geo_db_zipcode" VALUES(4621,12791,-5,'Youngsville, New York 12791',3281,4217);
INSERT INTO "django_geo_db_zipcode" VALUES(4622,12792,-5,'Yulan, New York 12792',3282,4218);
INSERT INTO "django_geo_db_zipcode" VALUES(4623,12793,-5,'Bethel, New York 12793',3223,4219);
INSERT INTO "django_geo_db_zipcode" VALUES(4624,12801,-5,'Glens Falls, New York 12801',3283,4220);
INSERT INTO "django_geo_db_zipcode" VALUES(4625,12803,-5,'South Glens Falls, New York 12803',3284,4221);
INSERT INTO "django_geo_db_zipcode" VALUES(4626,12804,-5,'Queensbury, New York 12804',3285,4222);
INSERT INTO "django_geo_db_zipcode" VALUES(4627,12805,-5,'Argyle, New York 12805',3286,4223);
INSERT INTO "django_geo_db_zipcode" VALUES(4628,12807,-5,'New Baltimore, New York 12807',3003,4224);
INSERT INTO "django_geo_db_zipcode" VALUES(4629,12808,-5,'Adirondack, New York 12808',3287,4225);
INSERT INTO "django_geo_db_zipcode" VALUES(4630,12809,-5,'Argyle, New York 12809',3286,4226);
INSERT INTO "django_geo_db_zipcode" VALUES(4631,12810,-5,'Athol, New York 12810',3288,4227);
INSERT INTO "django_geo_db_zipcode" VALUES(4632,12811,-5,'Bakers Mills, New York 12811',3289,4228);
INSERT INTO "django_geo_db_zipcode" VALUES(4633,12812,-5,'Blue Mountain Lake, New York 12812',3290,4229);
INSERT INTO "django_geo_db_zipcode" VALUES(4634,12814,-5,'Bolton Landing, New York 12814',3291,4230);
INSERT INTO "django_geo_db_zipcode" VALUES(4635,12815,-5,'Brant Lake, New York 12815',3292,4231);
INSERT INTO "django_geo_db_zipcode" VALUES(4636,12816,-5,'Cambridge, New York 12816',3293,4232);
INSERT INTO "django_geo_db_zipcode" VALUES(4637,12817,-5,'Chestertown, New York 12817',3294,4233);
INSERT INTO "django_geo_db_zipcode" VALUES(4638,12819,-5,'Clemons, New York 12819',3295,4234);
INSERT INTO "django_geo_db_zipcode" VALUES(4639,12820,-5,'Cleverdale, New York 12820',3296,4235);
INSERT INTO "django_geo_db_zipcode" VALUES(4640,12821,-5,'Comstock, New York 12821',3297,4236);
INSERT INTO "django_geo_db_zipcode" VALUES(4641,12822,-5,'Corinth, New York 12822',3298,4237);
INSERT INTO "django_geo_db_zipcode" VALUES(4642,12823,-5,'Cossayuna, New York 12823',3299,4238);
INSERT INTO "django_geo_db_zipcode" VALUES(4643,12824,-5,'Diamond Point, New York 12824',3300,4239);
INSERT INTO "django_geo_db_zipcode" VALUES(4644,12825,-5,'Queensbury, New York 12825',3285,4240);
INSERT INTO "django_geo_db_zipcode" VALUES(4645,12827,-5,'Fort Ann, New York 12827',3301,4241);
INSERT INTO "django_geo_db_zipcode" VALUES(4646,12828,-5,'Fort Edward, New York 12828',3302,4242);
INSERT INTO "django_geo_db_zipcode" VALUES(4647,12830,-5,'Wilton, New York 12830',3303,4243);
INSERT INTO "django_geo_db_zipcode" VALUES(4648,12831,-5,'Gansevoort, New York 12831',3304,4244);
INSERT INTO "django_geo_db_zipcode" VALUES(4649,12832,-5,'Granville, New York 12832',3305,4245);
INSERT INTO "django_geo_db_zipcode" VALUES(4650,12833,-5,'Greenfield Center, New York 12833',3306,4246);
INSERT INTO "django_geo_db_zipcode" VALUES(4651,12834,-5,'Greenwich, New York 12834',3307,4247);
INSERT INTO "django_geo_db_zipcode" VALUES(4652,12835,-5,'Hadley, New York 12835',3308,4248);
INSERT INTO "django_geo_db_zipcode" VALUES(4653,12836,-5,'Hague, New York 12836',3309,4249);
INSERT INTO "django_geo_db_zipcode" VALUES(4654,12837,-5,'Hampton, New York 12837',3310,4250);
INSERT INTO "django_geo_db_zipcode" VALUES(4655,12838,-5,'Hartford, New York 12838',3311,4251);
INSERT INTO "django_geo_db_zipcode" VALUES(4656,12839,-5,'Hudson Falls, New York 12839',3312,4252);
INSERT INTO "django_geo_db_zipcode" VALUES(4657,12841,-5,'Huletts Landing, New York 12841',3313,4253);
INSERT INTO "django_geo_db_zipcode" VALUES(4658,12842,-5,'Indian Lake, New York 12842',3314,4254);
INSERT INTO "django_geo_db_zipcode" VALUES(4659,12843,-5,'Johnsburg, New York 12843',3315,4255);
INSERT INTO "django_geo_db_zipcode" VALUES(4660,12844,-5,'Kattskill Bay, New York 12844',3316,4256);
INSERT INTO "django_geo_db_zipcode" VALUES(4661,12845,-5,'Lake George, New York 12845',3317,4257);
INSERT INTO "django_geo_db_zipcode" VALUES(4662,12846,-5,'Lake Luzerne, New York 12846',3318,4258);
INSERT INTO "django_geo_db_zipcode" VALUES(4663,12847,-5,'Long Lake, New York 12847',3319,4259);
INSERT INTO "django_geo_db_zipcode" VALUES(4664,12848,-5,'Middle Falls, New York 12848',3320,4260);
INSERT INTO "django_geo_db_zipcode" VALUES(4665,12849,-5,'Middle Granville, New York 12849',3321,4261);
INSERT INTO "django_geo_db_zipcode" VALUES(4666,12850,-5,'Middle Grove, New York 12850',3322,4262);
INSERT INTO "django_geo_db_zipcode" VALUES(4667,12851,-5,'Minerva, New York 12851',3323,4263);
INSERT INTO "django_geo_db_zipcode" VALUES(4668,12852,-5,'Newcomb, New York 12852',3324,4264);
INSERT INTO "django_geo_db_zipcode" VALUES(4669,12853,-5,'North Creek, New York 12853',3325,4265);
INSERT INTO "django_geo_db_zipcode" VALUES(4670,12854,-5,'North Granville, New York 12854',3326,4266);
INSERT INTO "django_geo_db_zipcode" VALUES(4671,12855,-5,'North Hudson, New York 12855',3327,4267);
INSERT INTO "django_geo_db_zipcode" VALUES(4672,12856,-5,'North River, New York 12856',3328,4268);
INSERT INTO "django_geo_db_zipcode" VALUES(4673,12857,-5,'Olmstedville, New York 12857',3329,4269);
INSERT INTO "django_geo_db_zipcode" VALUES(4674,12858,-5,'Paradox, New York 12858',3330,4270);
INSERT INTO "django_geo_db_zipcode" VALUES(4675,12859,-5,'Porter Corners, New York 12859',3331,4271);
INSERT INTO "django_geo_db_zipcode" VALUES(4676,12860,-5,'Pottersville, New York 12860',3332,4272);
INSERT INTO "django_geo_db_zipcode" VALUES(4677,12861,-5,'Putnam Station, New York 12861',3333,4273);
INSERT INTO "django_geo_db_zipcode" VALUES(4678,12862,-5,'Riparius, New York 12862',3334,4274);
INSERT INTO "django_geo_db_zipcode" VALUES(4679,12863,-5,'Rock City Falls, New York 12863',3335,4275);
INSERT INTO "django_geo_db_zipcode" VALUES(4680,12864,-5,'Sabael, New York 12864',3336,4276);
INSERT INTO "django_geo_db_zipcode" VALUES(4681,12865,-5,'Salem, New York 12865',3337,4277);
INSERT INTO "django_geo_db_zipcode" VALUES(4682,12866,-5,'Saratoga Springs, New York 12866',3338,4278);
INSERT INTO "django_geo_db_zipcode" VALUES(4683,12870,-5,'Schroon Lake, New York 12870',3339,4279);
INSERT INTO "django_geo_db_zipcode" VALUES(4684,12871,-5,'Schuylerville, New York 12871',3340,4280);
INSERT INTO "django_geo_db_zipcode" VALUES(4685,12872,-5,'Severance, New York 12872',3341,4281);
INSERT INTO "django_geo_db_zipcode" VALUES(4686,12873,-5,'Shushan, New York 12873',3342,4282);
INSERT INTO "django_geo_db_zipcode" VALUES(4687,12874,-5,'Silver Bay, New York 12874',3343,4283);
INSERT INTO "django_geo_db_zipcode" VALUES(4688,12877,-5,'Whitehall, New York 12877',3344,4284);
INSERT INTO "django_geo_db_zipcode" VALUES(4689,12878,-5,'Stony Creek, New York 12878',3345,4285);
INSERT INTO "django_geo_db_zipcode" VALUES(4690,12879,-5,'Newcomb, New York 12879',3324,4281);
INSERT INTO "django_geo_db_zipcode" VALUES(4691,12883,-5,'Ticonderoga, New York 12883',3346,4286);
INSERT INTO "django_geo_db_zipcode" VALUES(4692,12884,-5,'Victory Mills, New York 12884',3347,4287);
INSERT INTO "django_geo_db_zipcode" VALUES(4693,12885,-5,'Warrensburg, New York 12885',3348,4288);
INSERT INTO "django_geo_db_zipcode" VALUES(4694,12886,-5,'Wevertown, New York 12886',3349,4289);
INSERT INTO "django_geo_db_zipcode" VALUES(4695,12887,-5,'Whitehall, New York 12887',3344,4290);
INSERT INTO "django_geo_db_zipcode" VALUES(4696,12901,-5,'Plattsburgh, New York 12901',3350,4291);
INSERT INTO "django_geo_db_zipcode" VALUES(4697,12903,-5,'Plattsburgh, New York 12903',3350,4292);
INSERT INTO "django_geo_db_zipcode" VALUES(4698,12910,-5,'Altona, New York 12910',3351,4293);
INSERT INTO "django_geo_db_zipcode" VALUES(4699,12911,-5,'Keeseville, New York 12911',3352,4294);
INSERT INTO "django_geo_db_zipcode" VALUES(4700,12912,-5,'Au Sable Forks, New York 12912',3353,4295);
INSERT INTO "django_geo_db_zipcode" VALUES(4701,12913,-5,'Bloomingdale, New York 12913',3354,4296);
INSERT INTO "django_geo_db_zipcode" VALUES(4702,12914,-5,'Bombay, New York 12914',3355,4297);
INSERT INTO "django_geo_db_zipcode" VALUES(4703,12915,-5,'Brainardsville, New York 12915',3356,4298);
INSERT INTO "django_geo_db_zipcode" VALUES(4704,12916,-5,'Brushton, New York 12916',3357,4299);
INSERT INTO "django_geo_db_zipcode" VALUES(4705,12917,-5,'Burke, New York 12917',3358,4300);
INSERT INTO "django_geo_db_zipcode" VALUES(4706,12918,-5,'Cadyville, New York 12918',3359,4301);
INSERT INTO "django_geo_db_zipcode" VALUES(4707,12919,-5,'Champlain, New York 12919',3360,4302);
INSERT INTO "django_geo_db_zipcode" VALUES(4708,12920,-5,'Chateaugay, New York 12920',3361,4303);
INSERT INTO "django_geo_db_zipcode" VALUES(4709,12921,-5,'Chazy, New York 12921',3362,4304);
INSERT INTO "django_geo_db_zipcode" VALUES(4710,12922,-5,'Childwold, New York 12922',3363,4305);
INSERT INTO "django_geo_db_zipcode" VALUES(4711,12923,-5,'Churubusco, New York 12923',3364,4306);
INSERT INTO "django_geo_db_zipcode" VALUES(4712,12924,-5,'Keeseville, New York 12924',3352,4307);
INSERT INTO "django_geo_db_zipcode" VALUES(4713,12926,-5,'Constable, New York 12926',3365,4308);
INSERT INTO "django_geo_db_zipcode" VALUES(4714,12927,-5,'Cranberry Lake, New York 12927',3366,4309);
INSERT INTO "django_geo_db_zipcode" VALUES(4715,12928,-5,'Crown Point, New York 12928',3367,4310);
INSERT INTO "django_geo_db_zipcode" VALUES(4716,12929,-5,'Dannemora, New York 12929',3368,4311);
INSERT INTO "django_geo_db_zipcode" VALUES(4717,12930,-5,'Dickinson Center, New York 12930',3369,4312);
INSERT INTO "django_geo_db_zipcode" VALUES(4718,12932,-5,'Elizabethtown, New York 12932',3370,4313);
INSERT INTO "django_geo_db_zipcode" VALUES(4719,12933,-5,'Ellenburg, New York 12933',3252,4314);
INSERT INTO "django_geo_db_zipcode" VALUES(4720,12934,-5,'Ellenburg Center, New York 12934',3371,4315);
INSERT INTO "django_geo_db_zipcode" VALUES(4721,12935,-5,'Ellenburg Depot, New York 12935',3372,4316);
INSERT INTO "django_geo_db_zipcode" VALUES(4722,12936,-5,'Essex, New York 12936',3373,4317);
INSERT INTO "django_geo_db_zipcode" VALUES(4723,12937,-5,'Fort Covington, New York 12937',3374,4318);
INSERT INTO "django_geo_db_zipcode" VALUES(4724,12938,-5,'Pleasant Valley, New York 12938',3198,4319);
INSERT INTO "django_geo_db_zipcode" VALUES(4725,12939,-5,'Gabriels, New York 12939',3375,4298);
INSERT INTO "django_geo_db_zipcode" VALUES(4726,12941,-5,'Jay, New York 12941',3376,4320);
INSERT INTO "django_geo_db_zipcode" VALUES(4727,12942,-5,'Keene, New York 12942',3377,4321);
INSERT INTO "django_geo_db_zipcode" VALUES(4728,12943,-5,'Keene Valley, New York 12943',3378,4322);
INSERT INTO "django_geo_db_zipcode" VALUES(4729,12944,-5,'Keeseville, New York 12944',3352,4323);
INSERT INTO "django_geo_db_zipcode" VALUES(4730,12945,-5,'Lake Clear, New York 12945',3379,4324);
INSERT INTO "django_geo_db_zipcode" VALUES(4731,12946,-5,'Lake Placid, New York 12946',3380,4325);
INSERT INTO "django_geo_db_zipcode" VALUES(4732,12949,-5,'Lawrenceville, New York 12949',3381,4326);
INSERT INTO "django_geo_db_zipcode" VALUES(4733,12950,-5,'Lewis, New York 12950',3382,4327);
INSERT INTO "django_geo_db_zipcode" VALUES(4734,12952,-5,'Lyon Mountain, New York 12952',3383,4328);
INSERT INTO "django_geo_db_zipcode" VALUES(4735,12953,-5,'Malone, New York 12953',3384,4329);
INSERT INTO "django_geo_db_zipcode" VALUES(4736,12955,-5,'Lyon Mountain, New York 12955',3383,4330);
INSERT INTO "django_geo_db_zipcode" VALUES(4737,12956,-5,'Mineville, New York 12956',3385,4331);
INSERT INTO "django_geo_db_zipcode" VALUES(4738,12957,-5,'Moira, New York 12957',3219,4332);
INSERT INTO "django_geo_db_zipcode" VALUES(4739,12958,-5,'Mooers, New York 12958',3386,4333);
INSERT INTO "django_geo_db_zipcode" VALUES(4740,12959,-5,'Mooers Forks, New York 12959',3387,4334);
INSERT INTO "django_geo_db_zipcode" VALUES(4741,12960,-5,'Moriah, New York 12960',3388,4335);
INSERT INTO "django_geo_db_zipcode" VALUES(4742,12961,-5,'Moriah Center, New York 12961',3389,4336);
INSERT INTO "django_geo_db_zipcode" VALUES(4743,12962,-5,'Morrisonville, New York 12962',3390,4337);
INSERT INTO "django_geo_db_zipcode" VALUES(4744,12964,-5,'New Russia, New York 12964',3391,4338);
INSERT INTO "django_geo_db_zipcode" VALUES(4745,12965,-5,'Nicholville, New York 12965',3392,4339);
INSERT INTO "django_geo_db_zipcode" VALUES(4746,12966,-5,'North Bangor, New York 12966',3393,4340);
INSERT INTO "django_geo_db_zipcode" VALUES(4747,12967,-5,'North Lawrence, New York 12967',3394,4341);
INSERT INTO "django_geo_db_zipcode" VALUES(4748,12969,-5,'Owls Head, New York 12969',3395,4342);
INSERT INTO "django_geo_db_zipcode" VALUES(4749,12970,-5,'Paul Smiths, New York 12970',3396,4343);
INSERT INTO "django_geo_db_zipcode" VALUES(4750,12972,-5,'Peru, New York 12972',3397,4344);
INSERT INTO "django_geo_db_zipcode" VALUES(4751,12973,-5,'Piercefield, New York 12973',3398,4345);
INSERT INTO "django_geo_db_zipcode" VALUES(4752,12974,-5,'Port Henry, New York 12974',3399,4346);
INSERT INTO "django_geo_db_zipcode" VALUES(4753,12975,-5,'Port Kent, New York 12975',3400,4347);
INSERT INTO "django_geo_db_zipcode" VALUES(4754,12976,-5,'Rainbow Lake, New York 12976',3401,4298);
INSERT INTO "django_geo_db_zipcode" VALUES(4755,12977,-5,'Ray Brook, New York 12977',3402,4281);
INSERT INTO "django_geo_db_zipcode" VALUES(4756,12978,-5,'Redford, New York 12978',3403,4348);
INSERT INTO "django_geo_db_zipcode" VALUES(4757,12979,-5,'Rouses Point, New York 12979',3404,4349);
INSERT INTO "django_geo_db_zipcode" VALUES(4758,12980,-5,'Saint Regis Falls, New York 12980',3405,4350);
INSERT INTO "django_geo_db_zipcode" VALUES(4759,12981,-5,'Saranac, New York 12981',3406,4351);
INSERT INTO "django_geo_db_zipcode" VALUES(4760,12983,-5,'Saranac Lake, New York 12983',3407,4352);
INSERT INTO "django_geo_db_zipcode" VALUES(4761,12985,-5,'Schuyler Falls, New York 12985',3408,4353);
INSERT INTO "django_geo_db_zipcode" VALUES(4762,12986,-5,'Tupper Lake, New York 12986',3409,4354);
INSERT INTO "django_geo_db_zipcode" VALUES(4763,12987,-5,'Upper Jay, New York 12987',3410,4355);
INSERT INTO "django_geo_db_zipcode" VALUES(4764,12989,-5,'Vermontville, New York 12989',3411,4356);
INSERT INTO "django_geo_db_zipcode" VALUES(4765,12992,-5,'West Chazy, New York 12992',3412,4357);
INSERT INTO "django_geo_db_zipcode" VALUES(4766,12993,-5,'Westport, New York 12993',3413,4358);
INSERT INTO "django_geo_db_zipcode" VALUES(4767,12995,-5,'Whippleville, New York 12995',3414,4359);
INSERT INTO "django_geo_db_zipcode" VALUES(4768,12996,-5,'Willsboro, New York 12996',3415,4360);
INSERT INTO "django_geo_db_zipcode" VALUES(4769,12997,-5,'Wilmington, New York 12997',3416,4281);
INSERT INTO "django_geo_db_zipcode" VALUES(4770,12998,-5,'Witherbee, New York 12998',3417,4361);
INSERT INTO "django_geo_db_zipcode" VALUES(4771,13020,-5,'Apulia Station, New York 13020',3418,4362);
INSERT INTO "django_geo_db_zipcode" VALUES(4772,13021,-5,'Auburn, New York 13021',3419,4363);
INSERT INTO "django_geo_db_zipcode" VALUES(4773,13022,-5,'Auburn, New York 13022',3419,4364);
INSERT INTO "django_geo_db_zipcode" VALUES(4774,13024,-5,'Auburn, New York 13024',3419,4364);
INSERT INTO "django_geo_db_zipcode" VALUES(4775,13026,-5,'Aurora, New York 13026',3420,4365);
INSERT INTO "django_geo_db_zipcode" VALUES(4776,13027,-5,'Baldwinsville, New York 13027',3421,4366);
INSERT INTO "django_geo_db_zipcode" VALUES(4777,13028,-5,'Bernhards Bay, New York 13028',3422,4367);
INSERT INTO "django_geo_db_zipcode" VALUES(4778,13029,-5,'Brewerton, New York 13029',3423,4368);
INSERT INTO "django_geo_db_zipcode" VALUES(4779,13030,-5,'Bridgeport, New York 13030',3424,4369);
INSERT INTO "django_geo_db_zipcode" VALUES(4780,13031,-5,'Camillus, New York 13031',3425,4370);
INSERT INTO "django_geo_db_zipcode" VALUES(4781,13032,-5,'Canastota, New York 13032',3426,4371);
INSERT INTO "django_geo_db_zipcode" VALUES(4782,13033,-5,'Cato, New York 13033',3427,4372);
INSERT INTO "django_geo_db_zipcode" VALUES(4783,13034,-5,'Cayuga, New York 13034',3428,4373);
INSERT INTO "django_geo_db_zipcode" VALUES(4784,13035,-5,'Cazenovia, New York 13035',3429,4374);
INSERT INTO "django_geo_db_zipcode" VALUES(4785,13036,-5,'Central Square, New York 13036',3430,4375);
INSERT INTO "django_geo_db_zipcode" VALUES(4786,13037,-5,'Chittenango, New York 13037',3431,4376);
INSERT INTO "django_geo_db_zipcode" VALUES(4787,13039,-5,'Cicero, New York 13039',3432,4377);
INSERT INTO "django_geo_db_zipcode" VALUES(4788,13040,-5,'Cincinnatus, New York 13040',3433,4378);
INSERT INTO "django_geo_db_zipcode" VALUES(4789,13041,-5,'Clay, New York 13041',3434,4379);
INSERT INTO "django_geo_db_zipcode" VALUES(4790,13042,-5,'Cleveland, New York 13042',3435,4380);
INSERT INTO "django_geo_db_zipcode" VALUES(4791,13043,-5,'Clockville, New York 13043',3436,4381);
INSERT INTO "django_geo_db_zipcode" VALUES(4792,13044,-5,'Constantia, New York 13044',3437,4382);
INSERT INTO "django_geo_db_zipcode" VALUES(4793,13045,-5,'Cortland, New York 13045',3438,4383);
INSERT INTO "django_geo_db_zipcode" VALUES(4794,13051,-5,'Delphi Falls, New York 13051',3439,4384);
INSERT INTO "django_geo_db_zipcode" VALUES(4795,13052,-5,'De Ruyter, New York 13052',3440,4385);
INSERT INTO "django_geo_db_zipcode" VALUES(4796,13053,-5,'Dryden, New York 13053',3441,4386);
INSERT INTO "django_geo_db_zipcode" VALUES(4797,13054,-5,'Durhamville, New York 13054',3442,4387);
INSERT INTO "django_geo_db_zipcode" VALUES(4798,13056,-5,'East Homer, New York 13056',3443,4388);
INSERT INTO "django_geo_db_zipcode" VALUES(4799,13057,-5,'East Syracuse, New York 13057',3444,4389);
INSERT INTO "django_geo_db_zipcode" VALUES(4800,13060,-5,'Elbridge, New York 13060',3445,4390);
INSERT INTO "django_geo_db_zipcode" VALUES(4801,13061,-5,'Erieville, New York 13061',3446,4391);
INSERT INTO "django_geo_db_zipcode" VALUES(4802,13062,-5,'Etna, New York 13062',3447,4392);
INSERT INTO "django_geo_db_zipcode" VALUES(4803,13063,-5,'Fabius, New York 13063',3448,4393);
INSERT INTO "django_geo_db_zipcode" VALUES(4804,13064,-5,'Fair Haven, New York 13064',3449,4394);
INSERT INTO "django_geo_db_zipcode" VALUES(4805,13065,-5,'Fayette, New York 13065',3450,4395);
INSERT INTO "django_geo_db_zipcode" VALUES(4806,13066,-5,'Fayetteville, New York 13066',3451,4396);
INSERT INTO "django_geo_db_zipcode" VALUES(4807,13068,-5,'Freeville, New York 13068',3452,4397);
INSERT INTO "django_geo_db_zipcode" VALUES(4808,13069,-5,'Fulton, New York 13069',3453,4398);
INSERT INTO "django_geo_db_zipcode" VALUES(4809,13071,-5,'Genoa, New York 13071',3454,4399);
INSERT INTO "django_geo_db_zipcode" VALUES(4810,13072,-5,'Georgetown, New York 13072',3455,4400);
INSERT INTO "django_geo_db_zipcode" VALUES(4811,13073,-5,'Groton, New York 13073',3456,4401);
INSERT INTO "django_geo_db_zipcode" VALUES(4812,13074,-5,'Hannibal, New York 13074',3457,4402);
INSERT INTO "django_geo_db_zipcode" VALUES(4813,13076,-5,'Hastings, New York 13076',3458,4403);
INSERT INTO "django_geo_db_zipcode" VALUES(4814,13077,-5,'Homer, New York 13077',3459,4404);
INSERT INTO "django_geo_db_zipcode" VALUES(4815,13078,-5,'Jamesville, New York 13078',3460,4405);
INSERT INTO "django_geo_db_zipcode" VALUES(4816,13080,-5,'Jordan, New York 13080',3461,4406);
INSERT INTO "django_geo_db_zipcode" VALUES(4817,13081,-5,'King Ferry, New York 13081',3462,4407);
INSERT INTO "django_geo_db_zipcode" VALUES(4818,13082,-5,'Kirkville, New York 13082',3463,4408);
INSERT INTO "django_geo_db_zipcode" VALUES(4819,13083,-5,'Lacona, New York 13083',3464,4409);
INSERT INTO "django_geo_db_zipcode" VALUES(4820,13084,-5,'La Fayette, New York 13084',3465,4410);
INSERT INTO "django_geo_db_zipcode" VALUES(4821,13087,-5,'Little York, New York 13087',3466,4411);
INSERT INTO "django_geo_db_zipcode" VALUES(4822,13088,-5,'Liverpool, New York 13088',3467,4412);
INSERT INTO "django_geo_db_zipcode" VALUES(4823,13089,-5,'Liverpool, New York 13089',3467,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4824,13090,-5,'Liverpool, New York 13090',3467,4414);
INSERT INTO "django_geo_db_zipcode" VALUES(4825,13092,-5,'Locke, New York 13092',3468,4415);
INSERT INTO "django_geo_db_zipcode" VALUES(4826,13093,-5,'Lycoming, New York 13093',3469,4394);
INSERT INTO "django_geo_db_zipcode" VALUES(4827,13101,-5,'McGraw, New York 13101',3470,4416);
INSERT INTO "django_geo_db_zipcode" VALUES(4828,13102,-5,'McLean, New York 13102',3471,4417);
INSERT INTO "django_geo_db_zipcode" VALUES(4829,13103,-5,'Mallory, New York 13103',3472,4418);
INSERT INTO "django_geo_db_zipcode" VALUES(4830,13104,-5,'Manlius, New York 13104',3473,4419);
INSERT INTO "django_geo_db_zipcode" VALUES(4831,13107,-5,'Maple View, New York 13107',3474,4420);
INSERT INTO "django_geo_db_zipcode" VALUES(4832,13108,-5,'Marcellus, New York 13108',3475,4421);
INSERT INTO "django_geo_db_zipcode" VALUES(4833,13110,-5,'Marietta, New York 13110',3476,4422);
INSERT INTO "django_geo_db_zipcode" VALUES(4834,13111,-5,'Martville, New York 13111',3477,4423);
INSERT INTO "django_geo_db_zipcode" VALUES(4835,13112,-5,'Memphis, New York 13112',3478,4424);
INSERT INTO "django_geo_db_zipcode" VALUES(4836,13113,-5,'Meridian, New York 13113',3479,4425);
INSERT INTO "django_geo_db_zipcode" VALUES(4837,13114,-5,'Mexico, New York 13114',3480,4426);
INSERT INTO "django_geo_db_zipcode" VALUES(4838,13115,-5,'Minetto, New York 13115',3481,4427);
INSERT INTO "django_geo_db_zipcode" VALUES(4839,13116,-5,'Minoa, New York 13116',3482,4428);
INSERT INTO "django_geo_db_zipcode" VALUES(4840,13117,-5,'Montezuma, New York 13117',3483,4429);
INSERT INTO "django_geo_db_zipcode" VALUES(4841,13118,-5,'Moravia, New York 13118',3484,4430);
INSERT INTO "django_geo_db_zipcode" VALUES(4842,13119,-5,'Mottville, New York 13119',3485,4431);
INSERT INTO "django_geo_db_zipcode" VALUES(4843,13120,-5,'Nedrow, New York 13120',3486,4432);
INSERT INTO "django_geo_db_zipcode" VALUES(4844,13121,-5,'New Haven, New York 13121',3487,4433);
INSERT INTO "django_geo_db_zipcode" VALUES(4845,13122,-5,'New Woodstock, New York 13122',3488,4434);
INSERT INTO "django_geo_db_zipcode" VALUES(4846,13123,-5,'North Bay, New York 13123',3489,4435);
INSERT INTO "django_geo_db_zipcode" VALUES(4847,13124,-5,'North Pitcher, New York 13124',3490,4436);
INSERT INTO "django_geo_db_zipcode" VALUES(4848,13126,-5,'Oswego, New York 13126',3491,4437);
INSERT INTO "django_geo_db_zipcode" VALUES(4849,13129,-5,'Georgetown, New York 13129',3455,4438);
INSERT INTO "django_geo_db_zipcode" VALUES(4850,13131,-5,'Parish, New York 13131',3492,4439);
INSERT INTO "django_geo_db_zipcode" VALUES(4851,13132,-5,'Pennellville, New York 13132',3493,4440);
INSERT INTO "django_geo_db_zipcode" VALUES(4852,13133,-5,'Colesville, New York 13133',3494,4441);
INSERT INTO "django_geo_db_zipcode" VALUES(4853,13134,-5,'Peterboro, New York 13134',3495,4442);
INSERT INTO "django_geo_db_zipcode" VALUES(4854,13135,-5,'Phoenix, New York 13135',3496,4443);
INSERT INTO "django_geo_db_zipcode" VALUES(4855,13136,-5,'Pitcher, New York 13136',3497,4444);
INSERT INTO "django_geo_db_zipcode" VALUES(4856,13137,-5,'Plainville, New York 13137',3498,4445);
INSERT INTO "django_geo_db_zipcode" VALUES(4857,13138,-5,'Pompey, New York 13138',3499,4446);
INSERT INTO "django_geo_db_zipcode" VALUES(4858,13139,-5,'Poplar Ridge, New York 13139',3500,4447);
INSERT INTO "django_geo_db_zipcode" VALUES(4859,13140,-5,'Port Byron, New York 13140',3501,4448);
INSERT INTO "django_geo_db_zipcode" VALUES(4860,13141,-5,'Preble, New York 13141',3502,4449);
INSERT INTO "django_geo_db_zipcode" VALUES(4861,13142,-5,'Pulaski, New York 13142',3503,4450);
INSERT INTO "django_geo_db_zipcode" VALUES(4862,13143,-5,'Red Creek, New York 13143',3504,4451);
INSERT INTO "django_geo_db_zipcode" VALUES(4863,13144,-5,'Richland, New York 13144',3505,4452);
INSERT INTO "django_geo_db_zipcode" VALUES(4864,13145,-5,'Sandy Creek, New York 13145',3506,4453);
INSERT INTO "django_geo_db_zipcode" VALUES(4865,13146,-5,'Savannah, New York 13146',3507,4454);
INSERT INTO "django_geo_db_zipcode" VALUES(4866,13147,-5,'Scipio Center, New York 13147',3508,4455);
INSERT INTO "django_geo_db_zipcode" VALUES(4867,13148,-5,'Seneca Falls, New York 13148',3509,4456);
INSERT INTO "django_geo_db_zipcode" VALUES(4868,13149,-5,'Preble, New York 13149',3502,4457);
INSERT INTO "django_geo_db_zipcode" VALUES(4869,13152,-5,'Skaneateles, New York 13152',3510,4458);
INSERT INTO "django_geo_db_zipcode" VALUES(4870,13153,-5,'Skaneateles Falls, New York 13153',3511,4459);
INSERT INTO "django_geo_db_zipcode" VALUES(4871,13154,-5,'South Butler, New York 13154',3512,4460);
INSERT INTO "django_geo_db_zipcode" VALUES(4872,13155,-5,'South Otselic, New York 13155',3513,4461);
INSERT INTO "django_geo_db_zipcode" VALUES(4873,13156,-5,'Sterling, New York 13156',3514,4462);
INSERT INTO "django_geo_db_zipcode" VALUES(4874,13157,-5,'Sylvan Beach, New York 13157',3515,4463);
INSERT INTO "django_geo_db_zipcode" VALUES(4875,13158,-5,'Truxton, New York 13158',3516,4464);
INSERT INTO "django_geo_db_zipcode" VALUES(4876,13159,-5,'Tully, New York 13159',3517,4465);
INSERT INTO "django_geo_db_zipcode" VALUES(4877,13160,-5,'Union Springs, New York 13160',3518,4466);
INSERT INTO "django_geo_db_zipcode" VALUES(4878,13162,-5,'Verona Beach, New York 13162',3519,4467);
INSERT INTO "django_geo_db_zipcode" VALUES(4879,13163,-5,'Wampsville, New York 13163',3520,4468);
INSERT INTO "django_geo_db_zipcode" VALUES(4880,13164,-5,'Warners, New York 13164',3521,4469);
INSERT INTO "django_geo_db_zipcode" VALUES(4881,13165,-5,'Waterloo, New York 13165',3522,4470);
INSERT INTO "django_geo_db_zipcode" VALUES(4882,13166,-5,'Weedsport, New York 13166',3523,4471);
INSERT INTO "django_geo_db_zipcode" VALUES(4883,13167,-5,'West Monroe, New York 13167',3524,4472);
INSERT INTO "django_geo_db_zipcode" VALUES(4884,13201,-5,'Syracuse, New York 13201',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4885,13202,-5,'Syracuse, New York 13202',3525,4473);
INSERT INTO "django_geo_db_zipcode" VALUES(4886,13203,-5,'Syracuse, New York 13203',3525,4474);
INSERT INTO "django_geo_db_zipcode" VALUES(4887,13204,-5,'Syracuse, New York 13204',3525,4475);
INSERT INTO "django_geo_db_zipcode" VALUES(4888,13205,-5,'Syracuse, New York 13205',3525,4476);
INSERT INTO "django_geo_db_zipcode" VALUES(4889,13206,-5,'Syracuse, New York 13206',3525,4477);
INSERT INTO "django_geo_db_zipcode" VALUES(4890,13207,-5,'Syracuse, New York 13207',3525,4478);
INSERT INTO "django_geo_db_zipcode" VALUES(4891,13208,-5,'Syracuse, New York 13208',3525,4479);
INSERT INTO "django_geo_db_zipcode" VALUES(4892,13209,-5,'Syracuse, New York 13209',3525,4480);
INSERT INTO "django_geo_db_zipcode" VALUES(4893,13210,-5,'Syracuse, New York 13210',3525,4481);
INSERT INTO "django_geo_db_zipcode" VALUES(4894,13211,-5,'Syracuse, New York 13211',3525,4482);
INSERT INTO "django_geo_db_zipcode" VALUES(4895,13212,-5,'Syracuse, New York 13212',3525,4483);
INSERT INTO "django_geo_db_zipcode" VALUES(4896,13214,-5,'Syracuse, New York 13214',3525,4484);
INSERT INTO "django_geo_db_zipcode" VALUES(4897,13215,-5,'Syracuse, New York 13215',3525,4485);
INSERT INTO "django_geo_db_zipcode" VALUES(4898,13217,-5,'Syracuse, New York 13217',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4899,13218,-5,'Syracuse, New York 13218',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4900,13219,-5,'Syracuse, New York 13219',3525,4486);
INSERT INTO "django_geo_db_zipcode" VALUES(4901,13220,-5,'Syracuse, New York 13220',3525,4487);
INSERT INTO "django_geo_db_zipcode" VALUES(4902,13221,-5,'Syracuse, New York 13221',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4903,13224,-5,'Syracuse, New York 13224',3525,4488);
INSERT INTO "django_geo_db_zipcode" VALUES(4904,13225,-5,'Syracuse, New York 13225',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4905,13244,-5,'Syracuse, New York 13244',3525,4489);
INSERT INTO "django_geo_db_zipcode" VALUES(4906,13250,-5,'Syracuse, New York 13250',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4907,13251,-5,'Syracuse, New York 13251',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4908,13252,-5,'Syracuse, New York 13252',3525,4490);
INSERT INTO "django_geo_db_zipcode" VALUES(4909,13260,-5,'Syracuse, New York 13260',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4910,13261,-5,'Syracuse, New York 13261',3525,4413);
INSERT INTO "django_geo_db_zipcode" VALUES(4911,13290,-5,'Syracuse, New York 13290',3525,4491);
INSERT INTO "django_geo_db_zipcode" VALUES(4912,13301,-5,'Alder Creek, New York 13301',3526,4492);
INSERT INTO "django_geo_db_zipcode" VALUES(4913,13302,-5,'Altmar, New York 13302',3527,4493);
INSERT INTO "django_geo_db_zipcode" VALUES(4914,13303,-5,'Ava, New York 13303',3528,4494);
INSERT INTO "django_geo_db_zipcode" VALUES(4915,13304,-5,'Barneveld, New York 13304',3529,4495);
INSERT INTO "django_geo_db_zipcode" VALUES(4916,13305,-5,'Beaver Falls, New York 13305',3530,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(4917,13308,-5,'Blossvale, New York 13308',3531,4497);
INSERT INTO "django_geo_db_zipcode" VALUES(4918,13309,-5,'Boonville, New York 13309',3532,4498);
INSERT INTO "django_geo_db_zipcode" VALUES(4919,13310,-5,'Bouckville, New York 13310',3533,4499);
INSERT INTO "django_geo_db_zipcode" VALUES(4920,13312,-5,'Brantingham, New York 13312',3534,4500);
INSERT INTO "django_geo_db_zipcode" VALUES(4921,13313,-5,'Bridgewater, New York 13313',3535,4501);
INSERT INTO "django_geo_db_zipcode" VALUES(4922,13314,-5,'Brookfield, New York 13314',3536,4502);
INSERT INTO "django_geo_db_zipcode" VALUES(4923,13315,-5,'Burlington Flats, New York 13315',3537,4503);
INSERT INTO "django_geo_db_zipcode" VALUES(4924,13316,-5,'Camden, New York 13316',3538,4504);
INSERT INTO "django_geo_db_zipcode" VALUES(4925,13317,-5,'Canajoharie, New York 13317',3539,4505);
INSERT INTO "django_geo_db_zipcode" VALUES(4926,13318,-5,'Cassville, New York 13318',3540,4506);
INSERT INTO "django_geo_db_zipcode" VALUES(4927,13319,-5,'Chadwicks, New York 13319',3541,4507);
INSERT INTO "django_geo_db_zipcode" VALUES(4928,13320,-5,'Cherry Valley, New York 13320',3542,4508);
INSERT INTO "django_geo_db_zipcode" VALUES(4929,13321,-5,'Clark Mills, New York 13321',3543,4509);
INSERT INTO "django_geo_db_zipcode" VALUES(4930,13322,-5,'Clayville, New York 13322',3544,4510);
INSERT INTO "django_geo_db_zipcode" VALUES(4931,13323,-5,'Clinton, New York 13323',3545,4511);
INSERT INTO "django_geo_db_zipcode" VALUES(4932,13324,-5,'Cold Brook, New York 13324',3546,4512);
INSERT INTO "django_geo_db_zipcode" VALUES(4933,13325,-5,'Constableville, New York 13325',3547,4513);
INSERT INTO "django_geo_db_zipcode" VALUES(4934,13326,-5,'Cooperstown, New York 13326',3548,4514);
INSERT INTO "django_geo_db_zipcode" VALUES(4935,13327,-5,'Croghan, New York 13327',3549,4515);
INSERT INTO "django_geo_db_zipcode" VALUES(4936,13328,-5,'Deansboro, New York 13328',3550,4516);
INSERT INTO "django_geo_db_zipcode" VALUES(4937,13329,-5,'Dolgeville, New York 13329',3551,4517);
INSERT INTO "django_geo_db_zipcode" VALUES(4938,13331,-5,'Eagle Bay, New York 13331',3552,4518);
INSERT INTO "django_geo_db_zipcode" VALUES(4939,13332,-5,'Earlville, New York 13332',3553,4519);
INSERT INTO "django_geo_db_zipcode" VALUES(4940,13333,-5,'East Springfield, New York 13333',3554,4520);
INSERT INTO "django_geo_db_zipcode" VALUES(4941,13334,-5,'Eaton, New York 13334',3555,4521);
INSERT INTO "django_geo_db_zipcode" VALUES(4942,13335,-5,'Edmeston, New York 13335',3556,4522);
INSERT INTO "django_geo_db_zipcode" VALUES(4943,13337,-5,'Fly Creek, New York 13337',3557,4523);
INSERT INTO "django_geo_db_zipcode" VALUES(4944,13338,-5,'Forestport, New York 13338',3558,4524);
INSERT INTO "django_geo_db_zipcode" VALUES(4945,13339,-5,'Fort Plain, New York 13339',3559,4525);
INSERT INTO "django_geo_db_zipcode" VALUES(4946,13340,-5,'Frankfort, New York 13340',3560,4526);
INSERT INTO "django_geo_db_zipcode" VALUES(4947,13341,-5,'Franklin Springs, New York 13341',3561,4527);
INSERT INTO "django_geo_db_zipcode" VALUES(4948,13342,-5,'Garrattsville, New York 13342',3562,4528);
INSERT INTO "django_geo_db_zipcode" VALUES(4949,13343,-5,'Glenfield, New York 13343',3563,4529);
INSERT INTO "django_geo_db_zipcode" VALUES(4950,13345,-5,'Greig, New York 13345',3564,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(4951,13346,-5,'Hamilton, New York 13346',3565,4530);
INSERT INTO "django_geo_db_zipcode" VALUES(4952,13348,-5,'Hartwick, New York 13348',3566,4531);
INSERT INTO "django_geo_db_zipcode" VALUES(4953,13350,-5,'Herkimer, New York 13350',3567,4532);
INSERT INTO "django_geo_db_zipcode" VALUES(4954,13352,-5,'Hinckley, New York 13352',3568,4533);
INSERT INTO "django_geo_db_zipcode" VALUES(4955,13353,-5,'Hoffmeister, New York 13353',3569,4534);
INSERT INTO "django_geo_db_zipcode" VALUES(4956,13354,-5,'Holland Patent, New York 13354',3570,4535);
INSERT INTO "django_geo_db_zipcode" VALUES(4957,13355,-5,'Hubbardsville, New York 13355',3571,4536);
INSERT INTO "django_geo_db_zipcode" VALUES(4958,13357,-5,'Ilion, New York 13357',3572,4537);
INSERT INTO "django_geo_db_zipcode" VALUES(4959,13360,-5,'Inlet, New York 13360',3573,4538);
INSERT INTO "django_geo_db_zipcode" VALUES(4960,13361,-5,'Jordanville, New York 13361',3574,4539);
INSERT INTO "django_geo_db_zipcode" VALUES(4961,13362,-5,'Knoxboro, New York 13362',3575,4540);
INSERT INTO "django_geo_db_zipcode" VALUES(4962,13363,-5,'Lee Center, New York 13363',3576,4541);
INSERT INTO "django_geo_db_zipcode" VALUES(4963,13364,-5,'Leonardsville, New York 13364',3577,4542);
INSERT INTO "django_geo_db_zipcode" VALUES(4964,13365,-5,'Little Falls, New York 13365',3578,4543);
INSERT INTO "django_geo_db_zipcode" VALUES(4965,13367,-5,'Lowville, New York 13367',3579,4544);
INSERT INTO "django_geo_db_zipcode" VALUES(4966,13368,-5,'Lyons Falls, New York 13368',3580,4545);
INSERT INTO "django_geo_db_zipcode" VALUES(4967,13388,-5,'Webb, New York 13388',3581,4546);
INSERT INTO "django_geo_db_zipcode" VALUES(4968,13396,-5,'Madison, New York 13396',3582,4547);
INSERT INTO "django_geo_db_zipcode" VALUES(4969,13401,-5,'McConnellsville, New York 13401',3583,4548);
INSERT INTO "django_geo_db_zipcode" VALUES(4970,13402,-5,'Madison, New York 13402',3582,4549);
INSERT INTO "django_geo_db_zipcode" VALUES(4971,13403,-5,'Marcy, New York 13403',3584,4550);
INSERT INTO "django_geo_db_zipcode" VALUES(4972,13404,-5,'Martinsburg, New York 13404',3585,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(4973,13406,-5,'Middleville, New York 13406',3586,4551);
INSERT INTO "django_geo_db_zipcode" VALUES(4974,13407,-5,'Mohawk, New York 13407',3587,4552);
INSERT INTO "django_geo_db_zipcode" VALUES(4975,13408,-5,'Morrisville, New York 13408',3588,4553);
INSERT INTO "django_geo_db_zipcode" VALUES(4976,13409,-5,'Munnsville, New York 13409',3589,4554);
INSERT INTO "django_geo_db_zipcode" VALUES(4977,13410,-5,'Nelliston, New York 13410',3590,4555);
INSERT INTO "django_geo_db_zipcode" VALUES(4978,13411,-5,'New Berlin, New York 13411',3591,4556);
INSERT INTO "django_geo_db_zipcode" VALUES(4979,13413,-5,'New Hartford, New York 13413',3592,4557);
INSERT INTO "django_geo_db_zipcode" VALUES(4980,13415,-5,'New Lisbon, New York 13415',3593,4558);
INSERT INTO "django_geo_db_zipcode" VALUES(4981,13416,-5,'Newport, New York 13416',3594,4559);
INSERT INTO "django_geo_db_zipcode" VALUES(4982,13417,-5,'New York Mills, New York 13417',3595,4560);
INSERT INTO "django_geo_db_zipcode" VALUES(4983,13418,-5,'North Brookfield, New York 13418',3596,4561);
INSERT INTO "django_geo_db_zipcode" VALUES(4984,13420,-5,'Old Forge, New York 13420',3597,4562);
INSERT INTO "django_geo_db_zipcode" VALUES(4985,13421,-5,'Oneida, New York 13421',3598,4563);
INSERT INTO "django_geo_db_zipcode" VALUES(4986,13424,-5,'Oriskany, New York 13424',3599,4564);
INSERT INTO "django_geo_db_zipcode" VALUES(4987,13425,-5,'Oriskany Falls, New York 13425',3600,4565);
INSERT INTO "django_geo_db_zipcode" VALUES(4988,13426,-5,'Orwell, New York 13426',3601,4566);
INSERT INTO "django_geo_db_zipcode" VALUES(4989,13428,-5,'Palatine Bridge, New York 13428',3602,4567);
INSERT INTO "django_geo_db_zipcode" VALUES(4990,13431,-5,'Poland, New York 13431',3603,4568);
INSERT INTO "django_geo_db_zipcode" VALUES(4991,13433,-5,'Port Leyden, New York 13433',3604,4569);
INSERT INTO "django_geo_db_zipcode" VALUES(4992,13435,-5,'Prospect, New York 13435',3605,4570);
INSERT INTO "django_geo_db_zipcode" VALUES(4993,13436,-5,'Raquette Lake, New York 13436',3606,4571);
INSERT INTO "django_geo_db_zipcode" VALUES(4994,13437,-5,'Redfield, New York 13437',3607,4572);
INSERT INTO "django_geo_db_zipcode" VALUES(4995,13438,-5,'Remsen, New York 13438',3608,4573);
INSERT INTO "django_geo_db_zipcode" VALUES(4996,13439,-5,'Richfield Springs, New York 13439',3609,4574);
INSERT INTO "django_geo_db_zipcode" VALUES(4997,13440,-5,'Rome, New York 13440',3610,4575);
INSERT INTO "django_geo_db_zipcode" VALUES(4998,13441,-5,'Rome, New York 13441',3610,4576);
INSERT INTO "django_geo_db_zipcode" VALUES(4999,13442,-5,'Rome, New York 13442',3610,4577);
INSERT INTO "django_geo_db_zipcode" VALUES(5000,13444,-5,'Plymouth, New York 13444',3611,4578);
INSERT INTO "django_geo_db_zipcode" VALUES(5001,13449,-5,'Rome, New York 13449',3610,4577);
INSERT INTO "django_geo_db_zipcode" VALUES(5002,13450,-5,'Roseboom, New York 13450',3612,4579);
INSERT INTO "django_geo_db_zipcode" VALUES(5003,13452,-5,'Saint Johnsville, New York 13452',3613,4580);
INSERT INTO "django_geo_db_zipcode" VALUES(5004,13453,-5,'Williamstown, New York 13453',3614,4581);
INSERT INTO "django_geo_db_zipcode" VALUES(5005,13454,-5,'Salisbury Center, New York 13454',3615,4582);
INSERT INTO "django_geo_db_zipcode" VALUES(5006,13455,-5,'Sangerfield, New York 13455',3616,4583);
INSERT INTO "django_geo_db_zipcode" VALUES(5007,13456,-5,'Sauquoit, New York 13456',3617,4584);
INSERT INTO "django_geo_db_zipcode" VALUES(5008,13457,-5,'Schuyler Lake, New York 13457',3618,4585);
INSERT INTO "django_geo_db_zipcode" VALUES(5009,13459,-5,'Sharon Springs, New York 13459',3619,4586);
INSERT INTO "django_geo_db_zipcode" VALUES(5010,13460,-5,'Sherburne, New York 13460',3620,4587);
INSERT INTO "django_geo_db_zipcode" VALUES(5011,13461,-5,'Sherrill, New York 13461',3621,4588);
INSERT INTO "django_geo_db_zipcode" VALUES(5012,13464,-5,'Smyrna, New York 13464',3622,4589);
INSERT INTO "django_geo_db_zipcode" VALUES(5013,13465,-5,'Solsville, New York 13465',3623,4542);
INSERT INTO "django_geo_db_zipcode" VALUES(5014,13468,-5,'Springfield Center, New York 13468',3624,4590);
INSERT INTO "django_geo_db_zipcode" VALUES(5015,13469,-5,'Stittville, New York 13469',3625,4591);
INSERT INTO "django_geo_db_zipcode" VALUES(5016,13470,-5,'Stratford, New York 13470',3626,4592);
INSERT INTO "django_geo_db_zipcode" VALUES(5017,13471,-5,'Taberg, New York 13471',3627,4593);
INSERT INTO "django_geo_db_zipcode" VALUES(5018,13472,-5,'Thendara, New York 13472',3628,4594);
INSERT INTO "django_geo_db_zipcode" VALUES(5019,13473,-5,'Turin, New York 13473',3629,4595);
INSERT INTO "django_geo_db_zipcode" VALUES(5020,13475,-5,'Van Hornesville, New York 13475',3630,4596);
INSERT INTO "django_geo_db_zipcode" VALUES(5021,13476,-5,'Vernon, New York 13476',3631,4597);
INSERT INTO "django_geo_db_zipcode" VALUES(5022,13477,-5,'Vernon Center, New York 13477',3632,4598);
INSERT INTO "django_geo_db_zipcode" VALUES(5023,13478,-5,'Verona, New York 13478',3633,4599);
INSERT INTO "django_geo_db_zipcode" VALUES(5024,13479,-5,'Washington Mills, New York 13479',3634,4600);
INSERT INTO "django_geo_db_zipcode" VALUES(5025,13480,-5,'Waterville, New York 13480',3635,4601);
INSERT INTO "django_geo_db_zipcode" VALUES(5026,13482,-5,'West Burlington, New York 13482',3636,4602);
INSERT INTO "django_geo_db_zipcode" VALUES(5027,13483,-5,'Westdale, New York 13483',3637,4603);
INSERT INTO "django_geo_db_zipcode" VALUES(5028,13484,-5,'West Eaton, New York 13484',3638,4604);
INSERT INTO "django_geo_db_zipcode" VALUES(5029,13485,-5,'West Edmeston, New York 13485',3639,4605);
INSERT INTO "django_geo_db_zipcode" VALUES(5030,13486,-5,'Westernville, New York 13486',3640,4606);
INSERT INTO "django_geo_db_zipcode" VALUES(5031,13488,-5,'Westford, New York 13488',3641,4607);
INSERT INTO "django_geo_db_zipcode" VALUES(5032,13489,-5,'West Leyden, New York 13489',3642,4608);
INSERT INTO "django_geo_db_zipcode" VALUES(5033,13490,-5,'Westmoreland, New York 13490',3643,4609);
INSERT INTO "django_geo_db_zipcode" VALUES(5034,13491,-5,'West Winfield, New York 13491',3644,4610);
INSERT INTO "django_geo_db_zipcode" VALUES(5035,13492,-5,'Whitesboro, New York 13492',3645,4611);
INSERT INTO "django_geo_db_zipcode" VALUES(5036,13493,-5,'Williamstown, New York 13493',3614,4612);
INSERT INTO "django_geo_db_zipcode" VALUES(5037,13494,-5,'Woodgate, New York 13494',3646,4613);
INSERT INTO "django_geo_db_zipcode" VALUES(5038,13495,-5,'Yorkville, New York 13495',3647,4614);
INSERT INTO "django_geo_db_zipcode" VALUES(5039,13501,-5,'Utica, New York 13501',3648,4615);
INSERT INTO "django_geo_db_zipcode" VALUES(5040,13502,-5,'Utica, New York 13502',3648,4616);
INSERT INTO "django_geo_db_zipcode" VALUES(5041,13503,-5,'Utica, New York 13503',3648,4617);
INSERT INTO "django_geo_db_zipcode" VALUES(5042,13504,-5,'Utica, New York 13504',3648,4618);
INSERT INTO "django_geo_db_zipcode" VALUES(5043,13505,-5,'Utica, New York 13505',3648,4619);
INSERT INTO "django_geo_db_zipcode" VALUES(5044,13550,-5,'Herkimer, New York 13550',3567,4620);
INSERT INTO "django_geo_db_zipcode" VALUES(5045,13562,-5,'Hermon, New York 13562',3649,4621);
INSERT INTO "django_geo_db_zipcode" VALUES(5046,13578,-5,'Pharsalia, New York 13578',3650,4622);
INSERT INTO "django_geo_db_zipcode" VALUES(5047,13599,-5,'Utica, New York 13599',3648,4577);
INSERT INTO "django_geo_db_zipcode" VALUES(5048,13601,-5,'Watertown, New York 13601',3651,4623);
INSERT INTO "django_geo_db_zipcode" VALUES(5049,13602,-5,'Fort Drum, New York 13602',3652,4624);
INSERT INTO "django_geo_db_zipcode" VALUES(5050,13603,-5,'Watertown, New York 13603',3651,4625);
INSERT INTO "django_geo_db_zipcode" VALUES(5051,13605,-5,'Adams, New York 13605',3653,4626);
INSERT INTO "django_geo_db_zipcode" VALUES(5052,13606,-5,'Adams Center, New York 13606',3654,4627);
INSERT INTO "django_geo_db_zipcode" VALUES(5053,13607,-5,'Alexandria Bay, New York 13607',3655,4628);
INSERT INTO "django_geo_db_zipcode" VALUES(5054,13608,-5,'Antwerp, New York 13608',3656,4629);
INSERT INTO "django_geo_db_zipcode" VALUES(5055,13610,-5,'Rodman, New York 13610',3657,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(5056,13611,-5,'Belleville, New York 13611',3658,4630);
INSERT INTO "django_geo_db_zipcode" VALUES(5057,13612,-5,'Black River, New York 13612',3659,4631);
INSERT INTO "django_geo_db_zipcode" VALUES(5058,13613,-5,'Brasher Falls, New York 13613',3660,4632);
INSERT INTO "django_geo_db_zipcode" VALUES(5059,13614,-5,'Brier Hill, New York 13614',3661,4633);
INSERT INTO "django_geo_db_zipcode" VALUES(5060,13615,-5,'Brownville, New York 13615',3662,4634);
INSERT INTO "django_geo_db_zipcode" VALUES(5061,13616,-5,'Calcium, New York 13616',3663,4635);
INSERT INTO "django_geo_db_zipcode" VALUES(5062,13617,-5,'Canton, New York 13617',3664,4636);
INSERT INTO "django_geo_db_zipcode" VALUES(5063,13618,-5,'Cape Vincent, New York 13618',3665,4637);
INSERT INTO "django_geo_db_zipcode" VALUES(5064,13619,-5,'Carthage, New York 13619',3666,4638);
INSERT INTO "django_geo_db_zipcode" VALUES(5065,13620,-5,'Castorland, New York 13620',3667,4639);
INSERT INTO "django_geo_db_zipcode" VALUES(5066,13621,-5,'Chase Mills, New York 13621',3668,4640);
INSERT INTO "django_geo_db_zipcode" VALUES(5067,13622,-5,'Chaumont, New York 13622',3669,4641);
INSERT INTO "django_geo_db_zipcode" VALUES(5068,13623,-5,'Chippewa Bay, New York 13623',3670,4642);
INSERT INTO "django_geo_db_zipcode" VALUES(5069,13624,-5,'Clayton, New York 13624',3671,4643);
INSERT INTO "django_geo_db_zipcode" VALUES(5070,13625,-5,'Colton, New York 13625',3672,4644);
INSERT INTO "django_geo_db_zipcode" VALUES(5071,13626,-5,'Copenhagen, New York 13626',3673,4645);
INSERT INTO "django_geo_db_zipcode" VALUES(5072,13627,-5,'Deer River, New York 13627',3674,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(5073,13628,-5,'Deferiet, New York 13628',3675,4646);
INSERT INTO "django_geo_db_zipcode" VALUES(5074,13630,-5,'De Kalb Junction, New York 13630',3676,4647);
INSERT INTO "django_geo_db_zipcode" VALUES(5075,13631,-5,'Denmark, New York 13631',3677,4496);
INSERT INTO "django_geo_db_zipcode" VALUES(5076,13632,-5,'Depauville, New York 13632',3678,4648);
INSERT INTO "django_geo_db_zipcode" VALUES(5077,13633,-5,'De Peyster, New York 13633',3679,4649);
INSERT INTO "django_geo_db_zipcode" VALUES(5078,13634,-5,'Dexter, New York 13634',3680,4650);
INSERT INTO "django_geo_db_zipcode" VALUES(5079,13635,-5,'Edwards, New York 13635',3681,4651);
INSERT INTO "django_geo_db_zipcode" VALUES(5080,13636,-5,'Ellisburg, New York 13636',3682,4652);
INSERT INTO "django_geo_db_zipcode" VALUES(5081,13637,-5,'Evans Mills, New York 13637',3683,4653);
INSERT INTO "django_geo_db_zipcode" VALUES(5082,13638,-5,'Felts Mills, New York 13638',3684,4654);
INSERT INTO "django_geo_db_zipcode" VALUES(5083,13639,-5,'Fine, New York 13639',3685,4655);
INSERT INTO "django_geo_db_zipcode" VALUES(5084,13640,-5,'Wellesley Island, New York 13640',3686,4656);
INSERT INTO "django_geo_db_zipcode" VALUES(5085,13641,-5,'Fishers Landing, New York 13641',3687,4657);
INSERT INTO "django_geo_db_zipcode" VALUES(5086,13642,-5,'Gouverneur, New York 13642',3688,4658);
INSERT INTO "django_geo_db_zipcode" VALUES(5087,13643,-5,'Great Bend, New York 13643',3689,4659);
INSERT INTO "django_geo_db_zipcode" VALUES(5088,13645,-5,'Hailesboro, New York 13645',3690,4660);
INSERT INTO "django_geo_db_zipcode" VALUES(5089,13646,-5,'Hammond, New York 13646',3691,4661);
INSERT INTO "django_geo_db_zipcode" VALUES(5090,13647,-5,'Hannawa Falls, New York 13647',3692,4662);
INSERT INTO "django_geo_db_zipcode" VALUES(5091,13648,-5,'Harrisville, New York 13648',3693,4663);
INSERT INTO "django_geo_db_zipcode" VALUES(5092,13649,-5,'Helena, New York 13649',3694,4664);
INSERT INTO "django_geo_db_zipcode" VALUES(5093,13650,-5,'Henderson, New York 13650',3695,4665);
INSERT INTO "django_geo_db_zipcode" VALUES(5094,13651,-5,'Henderson Harbor, New York 13651',3696,4666);
INSERT INTO "django_geo_db_zipcode" VALUES(5095,13652,-5,'Hermon, New York 13652',3649,4667);
INSERT INTO "django_geo_db_zipcode" VALUES(5096,13654,-5,'Heuvelton, New York 13654',3697,4668);
INSERT INTO "django_geo_db_zipcode" VALUES(5097,13655,-5,'Hogansburg, New York 13655',3698,4669);
INSERT INTO "django_geo_db_zipcode" VALUES(5098,13656,-5,'La Fargeville, New York 13656',3699,4670);
INSERT INTO "django_geo_db_zipcode" VALUES(5099,13657,-5,'Limerick, New York 13657',3700,4671);
INSERT INTO "django_geo_db_zipcode" VALUES(5100,13658,-5,'Lisbon, New York 13658',3701,4672);
INSERT INTO "django_geo_db_zipcode" VALUES(5101,13659,-5,'Lorraine, New York 13659',3702,4673);
INSERT INTO "django_geo_db_zipcode" VALUES(5102,13660,-5,'Madrid, New York 13660',3703,4674);
INSERT INTO "django_geo_db_zipcode" VALUES(5103,13661,-5,'Mannsville, New York 13661',3704,4675);
INSERT INTO "django_geo_db_zipcode" VALUES(5104,13662,-5,'Massena, New York 13662',3705,4676);
INSERT INTO "django_geo_db_zipcode" VALUES(5105,13664,-5,'Morristown, New York 13664',3706,4677);
INSERT INTO "django_geo_db_zipcode" VALUES(5106,13665,-5,'Natural Bridge, New York 13665',3707,4678);
INSERT INTO "django_geo_db_zipcode" VALUES(5107,13666,-5,'Newton Falls, New York 13666',3708,4660);
INSERT INTO "django_geo_db_zipcode" VALUES(5108,13667,-5,'Norfolk, New York 13667',3709,4679);
INSERT INTO "django_geo_db_zipcode" VALUES(5109,13668,-5,'Norwood, New York 13668',3710,4680);
INSERT INTO "django_geo_db_zipcode" VALUES(5110,13669,-5,'Ogdensburg, New York 13669',3711,4681);
INSERT INTO "django_geo_db_zipcode" VALUES(5111,13670,-5,'Oswegatchie, New York 13670',3712,4682);
INSERT INTO "django_geo_db_zipcode" VALUES(5112,13671,-5,'Oxbow, New York 13671',3713,4683);
INSERT INTO "django_geo_db_zipcode" VALUES(5113,13672,-5,'Parishville, New York 13672',3714,4684);
INSERT INTO "django_geo_db_zipcode" VALUES(5114,13673,-5,'Philadelphia, New York 13673',3715,4685);
INSERT INTO "django_geo_db_zipcode" VALUES(5115,13674,-5,'Pierrepont Manor, New York 13674',3716,4686);
INSERT INTO "django_geo_db_zipcode" VALUES(5116,13675,-5,'Plessis, New York 13675',3717,4687);
INSERT INTO "django_geo_db_zipcode" VALUES(5117,13676,-5,'Potsdam, New York 13676',3718,4688);
INSERT INTO "django_geo_db_zipcode" VALUES(5118,13677,-5,'Pyrites, New York 13677',3719,4689);
INSERT INTO "django_geo_db_zipcode" VALUES(5119,13678,-5,'Raymondville, New York 13678',3720,4690);
INSERT INTO "django_geo_db_zipcode" VALUES(5120,13679,-5,'Redwood, New York 13679',3721,4691);
INSERT INTO "django_geo_db_zipcode" VALUES(5121,13680,-5,'Rensselaer Falls, New York 13680',3722,4692);
INSERT INTO "django_geo_db_zipcode" VALUES(5122,13681,-5,'Richville, New York 13681',3723,4693);
INSERT INTO "django_geo_db_zipcode" VALUES(5123,13682,-5,'Rodman, New York 13682',3657,4694);
INSERT INTO "django_geo_db_zipcode" VALUES(5124,13683,-5,'Rooseveltown, New York 13683',3724,4660);
INSERT INTO "django_geo_db_zipcode" VALUES(5125,13684,-5,'Russell, New York 13684',3725,4695);
INSERT INTO "django_geo_db_zipcode" VALUES(5126,13685,-5,'Sackets Harbor, New York 13685',3726,4696);
INSERT INTO "django_geo_db_zipcode" VALUES(5127,13687,-5,'South Colton, New York 13687',3727,4697);
INSERT INTO "django_geo_db_zipcode" VALUES(5128,13688,-5,'South Rutland, New York 13688',3728,4698);
INSERT INTO "django_geo_db_zipcode" VALUES(5129,13690,-5,'Star Lake, New York 13690',3729,4699);
INSERT INTO "django_geo_db_zipcode" VALUES(5130,13691,-5,'Theresa, New York 13691',3730,4700);
INSERT INTO "django_geo_db_zipcode" VALUES(5131,13692,-5,'Thousand Island Park, New York 13692',3731,4701);
INSERT INTO "django_geo_db_zipcode" VALUES(5132,13693,-5,'Three Mile Bay, New York 13693',3732,4702);
INSERT INTO "django_geo_db_zipcode" VALUES(5133,13694,-5,'Waddington, New York 13694',3733,4703);
INSERT INTO "django_geo_db_zipcode" VALUES(5134,13695,-5,'Wanakena, New York 13695',3734,4704);
INSERT INTO "django_geo_db_zipcode" VALUES(5135,13696,-5,'West Stockholm, New York 13696',3735,4705);
INSERT INTO "django_geo_db_zipcode" VALUES(5136,13697,-5,'Winthrop, New York 13697',3736,4706);
INSERT INTO "django_geo_db_zipcode" VALUES(5137,13698,-5,'Ellisburg, New York 13698',3682,4707);
INSERT INTO "django_geo_db_zipcode" VALUES(5138,13699,-5,'Potsdam, New York 13699',3718,4708);
INSERT INTO "django_geo_db_zipcode" VALUES(5139,13730,-5,'Afton, New York 13730',3737,4709);
INSERT INTO "django_geo_db_zipcode" VALUES(5140,13731,-5,'Andes, New York 13731',3738,4710);
INSERT INTO "django_geo_db_zipcode" VALUES(5141,13732,-5,'Apalachin, New York 13732',3739,4711);
INSERT INTO "django_geo_db_zipcode" VALUES(5142,13733,-5,'Bainbridge, New York 13733',3740,4712);
INSERT INTO "django_geo_db_zipcode" VALUES(5143,13734,-5,'Barton, New York 13734',3741,4713);
INSERT INTO "django_geo_db_zipcode" VALUES(5144,13736,-5,'Berkshire, New York 13736',3742,4714);
INSERT INTO "django_geo_db_zipcode" VALUES(5145,13737,-5,'Bible School Park, New York 13737',3743,4715);
INSERT INTO "django_geo_db_zipcode" VALUES(5146,13738,-5,'Blodgett Mills, New York 13738',3744,4716);
INSERT INTO "django_geo_db_zipcode" VALUES(5147,13739,-5,'Bloomville, New York 13739',3745,4717);
INSERT INTO "django_geo_db_zipcode" VALUES(5148,13740,-5,'Bovina Center, New York 13740',3746,4718);
INSERT INTO "django_geo_db_zipcode" VALUES(5149,13743,-5,'Candor, New York 13743',3747,4719);
INSERT INTO "django_geo_db_zipcode" VALUES(5150,13744,-5,'Castle Creek, New York 13744',3748,4720);
INSERT INTO "django_geo_db_zipcode" VALUES(5151,13745,-5,'Chenango Bridge, New York 13745',3749,4721);
INSERT INTO "django_geo_db_zipcode" VALUES(5152,13746,-5,'Chenango Forks, New York 13746',3750,4722);
INSERT INTO "django_geo_db_zipcode" VALUES(5153,13747,-5,'Colliersville, New York 13747',3751,4723);
INSERT INTO "django_geo_db_zipcode" VALUES(5154,13748,-5,'Conklin, New York 13748',3752,4724);
INSERT INTO "django_geo_db_zipcode" VALUES(5155,13749,-5,'Corbettsville, New York 13749',3753,4725);
INSERT INTO "django_geo_db_zipcode" VALUES(5156,13750,-5,'Davenport, New York 13750',3754,4726);
INSERT INTO "django_geo_db_zipcode" VALUES(5157,13751,-5,'Davenport Center, New York 13751',3755,4727);
INSERT INTO "django_geo_db_zipcode" VALUES(5158,13752,-5,'De Lancey, New York 13752',3756,4728);
INSERT INTO "django_geo_db_zipcode" VALUES(5159,13753,-5,'Delhi, New York 13753',3757,4729);
INSERT INTO "django_geo_db_zipcode" VALUES(5160,13754,-5,'Deposit, New York 13754',3758,4730);
INSERT INTO "django_geo_db_zipcode" VALUES(5161,13755,-5,'Downsville, New York 13755',3759,4731);
INSERT INTO "django_geo_db_zipcode" VALUES(5162,13756,-5,'East Branch, New York 13756',3760,4732);
INSERT INTO "django_geo_db_zipcode" VALUES(5163,13757,-5,'East Meredith, New York 13757',3761,4733);
INSERT INTO "django_geo_db_zipcode" VALUES(5164,13758,-5,'East Pharsalia, New York 13758',3762,4734);
INSERT INTO "django_geo_db_zipcode" VALUES(5165,13760,-5,'Endicott, New York 13760',3763,4735);
INSERT INTO "django_geo_db_zipcode" VALUES(5166,13761,-5,'Endicott, New York 13761',3763,4725);
INSERT INTO "django_geo_db_zipcode" VALUES(5167,13762,-5,'Endwell, New York 13762',3764,4725);
INSERT INTO "django_geo_db_zipcode" VALUES(5168,13763,-5,'Endicott, New York 13763',3763,4725);
INSERT INTO "django_geo_db_zipcode" VALUES(5169,13766,-5,'Maine, New York 13766',3765,4736);
INSERT INTO "django_geo_db_zipcode" VALUES(5170,13774,-5,'Fishs Eddy, New York 13774',3766,4737);
INSERT INTO "django_geo_db_zipcode" VALUES(5171,13775,-5,'Franklin, New York 13775',3767,4738);
INSERT INTO "django_geo_db_zipcode" VALUES(5172,13776,-5,'Gilbertsville, New York 13776',3768,4739);
INSERT INTO "django_geo_db_zipcode" VALUES(5173,13777,-5,'Glen Aubrey, New York 13777',3769,4740);
INSERT INTO "django_geo_db_zipcode" VALUES(5174,13778,-5,'Greene, New York 13778',3770,4741);
INSERT INTO "django_geo_db_zipcode" VALUES(5175,13780,-5,'Guilford, New York 13780',3771,4742);
INSERT INTO "django_geo_db_zipcode" VALUES(5176,13782,-5,'Hamden, New York 13782',3772,4743);
INSERT INTO "django_geo_db_zipcode" VALUES(5177,13783,-5,'Hancock, New York 13783',3773,4744);
INSERT INTO "django_geo_db_zipcode" VALUES(5178,13784,-5,'Harford, New York 13784',3774,4745);
INSERT INTO "django_geo_db_zipcode" VALUES(5179,13786,-5,'Harpersfield, New York 13786',3775,4746);
INSERT INTO "django_geo_db_zipcode" VALUES(5180,13787,-5,'Harpursville, New York 13787',3776,4747);
INSERT INTO "django_geo_db_zipcode" VALUES(5181,13788,-5,'Hobart, New York 13788',3777,4748);
INSERT INTO "django_geo_db_zipcode" VALUES(5182,13790,-5,'Johnson City, New York 13790',3778,4749);
INSERT INTO "django_geo_db_zipcode" VALUES(5183,13792,-5,'Morris, New York 13792',3779,4750);
INSERT INTO "django_geo_db_zipcode" VALUES(5184,13794,-5,'Killawog, New York 13794',3780,4751);
INSERT INTO "django_geo_db_zipcode" VALUES(5185,13795,-5,'Kirkwood, New York 13795',3781,4752);
INSERT INTO "django_geo_db_zipcode" VALUES(5186,13796,-5,'Laurens, New York 13796',3782,4753);
INSERT INTO "django_geo_db_zipcode" VALUES(5187,13797,-5,'Lisle, New York 13797',3783,4754);
INSERT INTO "django_geo_db_zipcode" VALUES(5188,13801,-5,'McDonough, New York 13801',3784,4755);
INSERT INTO "django_geo_db_zipcode" VALUES(5189,13802,-5,'Maine, New York 13802',3765,4756);
INSERT INTO "django_geo_db_zipcode" VALUES(5190,13803,-5,'Marathon, New York 13803',3785,4757);
INSERT INTO "django_geo_db_zipcode" VALUES(5191,13804,-5,'Masonville, New York 13804',3786,4758);
INSERT INTO "django_geo_db_zipcode" VALUES(5192,13806,-5,'Meridale, New York 13806',3787,4030);
INSERT INTO "django_geo_db_zipcode" VALUES(5193,13807,-5,'Milford, New York 13807',3788,4759);
INSERT INTO "django_geo_db_zipcode" VALUES(5194,13808,-5,'Morris, New York 13808',3779,4760);
INSERT INTO "django_geo_db_zipcode" VALUES(5195,13809,-5,'Mount Upton, New York 13809',3789,4761);
INSERT INTO "django_geo_db_zipcode" VALUES(5196,13810,-5,'Mount Vision, New York 13810',3790,4762);
INSERT INTO "django_geo_db_zipcode" VALUES(5197,13811,-5,'Newark Valley, New York 13811',3791,4763);
INSERT INTO "django_geo_db_zipcode" VALUES(5198,13812,-5,'Nichols, New York 13812',3792,4764);
INSERT INTO "django_geo_db_zipcode" VALUES(5199,13813,-5,'Nineveh, New York 13813',3793,4765);
INSERT INTO "django_geo_db_zipcode" VALUES(5200,13814,-5,'North Norwich, New York 13814',3794,4766);
INSERT INTO "django_geo_db_zipcode" VALUES(5201,13815,-5,'Norwich, New York 13815',3795,4767);
INSERT INTO "django_geo_db_zipcode" VALUES(5202,13820,-5,'Oneonta, New York 13820',3796,4768);
INSERT INTO "django_geo_db_zipcode" VALUES(5203,13825,-5,'Otego, New York 13825',3797,4769);
INSERT INTO "django_geo_db_zipcode" VALUES(5204,13826,-5,'Ouaquaga, New York 13826',3798,4770);
INSERT INTO "django_geo_db_zipcode" VALUES(5205,13827,-5,'Owego, New York 13827',3799,4771);
INSERT INTO "django_geo_db_zipcode" VALUES(5206,13830,-5,'Oxford, New York 13830',3800,4772);
INSERT INTO "django_geo_db_zipcode" VALUES(5207,13832,-5,'Plymouth, New York 13832',3611,4773);
INSERT INTO "django_geo_db_zipcode" VALUES(5208,13833,-5,'Port Crane, New York 13833',3801,4774);
INSERT INTO "django_geo_db_zipcode" VALUES(5209,13834,-5,'Portlandville, New York 13834',3802,4775);
INSERT INTO "django_geo_db_zipcode" VALUES(5210,13835,-5,'Richford, New York 13835',3803,4776);
INSERT INTO "django_geo_db_zipcode" VALUES(5211,13837,-5,'Shinhopple, New York 13837',3804,4030);
INSERT INTO "django_geo_db_zipcode" VALUES(5212,13838,-5,'Sidney, New York 13838',3805,4777);
INSERT INTO "django_geo_db_zipcode" VALUES(5213,13839,-5,'Sidney Center, New York 13839',3806,4778);
INSERT INTO "django_geo_db_zipcode" VALUES(5214,13840,-5,'Smithboro, New York 13840',3807,4779);
INSERT INTO "django_geo_db_zipcode" VALUES(5215,13841,-5,'Smithville Flats, New York 13841',3808,4780);
INSERT INTO "django_geo_db_zipcode" VALUES(5216,13842,-5,'South Kortright, New York 13842',3809,4781);
INSERT INTO "django_geo_db_zipcode" VALUES(5217,13843,-5,'South New Berlin, New York 13843',3810,4782);
INSERT INTO "django_geo_db_zipcode" VALUES(5218,13844,-5,'South Plymouth, New York 13844',3811,4783);
INSERT INTO "django_geo_db_zipcode" VALUES(5219,13845,-5,'Tioga Center, New York 13845',3812,4784);
INSERT INTO "django_geo_db_zipcode" VALUES(5220,13846,-5,'Treadwell, New York 13846',3813,4785);
INSERT INTO "django_geo_db_zipcode" VALUES(5221,13847,-5,'Trout Creek, New York 13847',3814,4030);
INSERT INTO "django_geo_db_zipcode" VALUES(5222,13848,-5,'Tunnel, New York 13848',3815,4786);
INSERT INTO "django_geo_db_zipcode" VALUES(5223,13849,-5,'Unadilla, New York 13849',3816,4787);
INSERT INTO "django_geo_db_zipcode" VALUES(5224,13850,-5,'Vestal, New York 13850',3817,4788);
INSERT INTO "django_geo_db_zipcode" VALUES(5225,13851,-5,'Vestal, New York 13851',3817,4725);
INSERT INTO "django_geo_db_zipcode" VALUES(5226,13856,-5,'Walton, New York 13856',3818,4789);
INSERT INTO "django_geo_db_zipcode" VALUES(5227,13859,-5,'Wells Bridge, New York 13859',3819,4790);
INSERT INTO "django_geo_db_zipcode" VALUES(5228,13860,-5,'West Davenport, New York 13860',3820,4030);
INSERT INTO "django_geo_db_zipcode" VALUES(5229,13861,-5,'West Oneonta, New York 13861',3821,4791);
INSERT INTO "django_geo_db_zipcode" VALUES(5230,13862,-5,'Whitney Point, New York 13862',3822,4792);
INSERT INTO "django_geo_db_zipcode" VALUES(5231,13863,-5,'Willet, New York 13863',3823,4793);
INSERT INTO "django_geo_db_zipcode" VALUES(5232,13864,-5,'Willseyville, New York 13864',3824,4794);
INSERT INTO "django_geo_db_zipcode" VALUES(5233,13865,-5,'Windsor, New York 13865',3825,4795);
INSERT INTO "django_geo_db_zipcode" VALUES(5234,13901,-5,'Binghamton, New York 13901',3826,4796);
INSERT INTO "django_geo_db_zipcode" VALUES(5235,13902,-5,'Binghamton, New York 13902',3826,4797);
INSERT INTO "django_geo_db_zipcode" VALUES(5236,13903,-5,'Binghamton, New York 13903',3826,4798);
INSERT INTO "django_geo_db_zipcode" VALUES(5237,13904,-5,'Binghamton, New York 13904',3826,4799);
INSERT INTO "django_geo_db_zipcode" VALUES(5238,13905,-5,'Binghamton, New York 13905',3826,4800);
INSERT INTO "django_geo_db_zipcode" VALUES(5239,13942,-5,'Whitestown, New York 13942',3827,4801);
INSERT INTO "django_geo_db_zipcode" VALUES(5240,14001,-5,'Akron, New York 14001',3828,4802);
INSERT INTO "django_geo_db_zipcode" VALUES(5241,14003,-5,'Alabama, New York 14003',3829,4803);
INSERT INTO "django_geo_db_zipcode" VALUES(5242,14004,-5,'Alden, New York 14004',3830,4804);
INSERT INTO "django_geo_db_zipcode" VALUES(5243,14005,-5,'Alexander, New York 14005',3831,4805);
INSERT INTO "django_geo_db_zipcode" VALUES(5244,14006,-5,'Angola, New York 14006',3832,4806);
INSERT INTO "django_geo_db_zipcode" VALUES(5245,14008,-5,'Appleton, New York 14008',3833,4807);
INSERT INTO "django_geo_db_zipcode" VALUES(5246,14009,-5,'Arcade, New York 14009',3834,4808);
INSERT INTO "django_geo_db_zipcode" VALUES(5247,14010,-5,'Athol Springs, New York 14010',3835,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5248,14011,-5,'Attica, New York 14011',3836,4810);
INSERT INTO "django_geo_db_zipcode" VALUES(5249,14012,-5,'Barker, New York 14012',3837,4811);
INSERT INTO "django_geo_db_zipcode" VALUES(5250,14013,-5,'Basom, New York 14013',3838,4812);
INSERT INTO "django_geo_db_zipcode" VALUES(5251,14020,-5,'Batavia, New York 14020',3839,4813);
INSERT INTO "django_geo_db_zipcode" VALUES(5252,14021,-5,'Batavia, New York 14021',3839,4803);
INSERT INTO "django_geo_db_zipcode" VALUES(5253,14024,-5,'Bliss, New York 14024',3840,4814);
INSERT INTO "django_geo_db_zipcode" VALUES(5254,14025,-5,'Boston, New York 14025',3841,4815);
INSERT INTO "django_geo_db_zipcode" VALUES(5255,14026,-5,'Bowmansville, New York 14026',3842,4816);
INSERT INTO "django_geo_db_zipcode" VALUES(5256,14027,-5,'Brant, New York 14027',3843,4817);
INSERT INTO "django_geo_db_zipcode" VALUES(5257,14028,-5,'Burt, New York 14028',3844,4818);
INSERT INTO "django_geo_db_zipcode" VALUES(5258,14029,-5,'Centerville, New York 14029',3845,4819);
INSERT INTO "django_geo_db_zipcode" VALUES(5259,14030,-5,'Chaffee, New York 14030',3846,4820);
INSERT INTO "django_geo_db_zipcode" VALUES(5260,14031,-5,'Clarence, New York 14031',3847,4821);
INSERT INTO "django_geo_db_zipcode" VALUES(5261,14032,-5,'Clarence Center, New York 14032',3848,4822);
INSERT INTO "django_geo_db_zipcode" VALUES(5262,14033,-5,'Colden, New York 14033',3849,4823);
INSERT INTO "django_geo_db_zipcode" VALUES(5263,14034,-5,'Collins, New York 14034',3850,4824);
INSERT INTO "django_geo_db_zipcode" VALUES(5264,14035,-5,'Collins Center, New York 14035',3851,4825);
INSERT INTO "django_geo_db_zipcode" VALUES(5265,14036,-5,'Corfu, New York 14036',3852,4826);
INSERT INTO "django_geo_db_zipcode" VALUES(5266,14037,-5,'Cowlesville, New York 14037',3853,4827);
INSERT INTO "django_geo_db_zipcode" VALUES(5267,14038,-5,'Crittenden, New York 14038',3854,4828);
INSERT INTO "django_geo_db_zipcode" VALUES(5268,14039,-5,'Dale, New York 14039',3855,4829);
INSERT INTO "django_geo_db_zipcode" VALUES(5269,14040,-5,'Darien Center, New York 14040',3856,4830);
INSERT INTO "django_geo_db_zipcode" VALUES(5270,14041,-5,'Dayton, New York 14041',3857,4831);
INSERT INTO "django_geo_db_zipcode" VALUES(5271,14042,-5,'Delevan, New York 14042',3858,4832);
INSERT INTO "django_geo_db_zipcode" VALUES(5272,14043,-5,'Depew, New York 14043',3859,4833);
INSERT INTO "django_geo_db_zipcode" VALUES(5273,14047,-5,'Derby, New York 14047',3860,4834);
INSERT INTO "django_geo_db_zipcode" VALUES(5274,14048,-5,'Dunkirk, New York 14048',3861,4835);
INSERT INTO "django_geo_db_zipcode" VALUES(5275,14051,-5,'East Amherst, New York 14051',3862,4836);
INSERT INTO "django_geo_db_zipcode" VALUES(5276,14052,-5,'East Aurora, New York 14052',3863,4837);
INSERT INTO "django_geo_db_zipcode" VALUES(5277,14054,-5,'East Bethany, New York 14054',3864,4838);
INSERT INTO "django_geo_db_zipcode" VALUES(5278,14055,-5,'East Concord, New York 14055',3865,4839);
INSERT INTO "django_geo_db_zipcode" VALUES(5279,14056,-5,'East Pembroke, New York 14056',3866,4840);
INSERT INTO "django_geo_db_zipcode" VALUES(5280,14057,-5,'Eden, New York 14057',3867,4841);
INSERT INTO "django_geo_db_zipcode" VALUES(5281,14058,-5,'Elba, New York 14058',3868,4842);
INSERT INTO "django_geo_db_zipcode" VALUES(5282,14059,-5,'Elma, New York 14059',3869,4843);
INSERT INTO "django_geo_db_zipcode" VALUES(5283,14060,-5,'Farmersville Station, New York 14060',3870,4844);
INSERT INTO "django_geo_db_zipcode" VALUES(5284,14061,-5,'Farnham, New York 14061',3871,4845);
INSERT INTO "django_geo_db_zipcode" VALUES(5285,14062,-5,'Forestville, New York 14062',3872,4846);
INSERT INTO "django_geo_db_zipcode" VALUES(5286,14063,-5,'Fredonia, New York 14063',3873,4847);
INSERT INTO "django_geo_db_zipcode" VALUES(5287,14064,-5,'Rochester, New York 14064',3874,4848);
INSERT INTO "django_geo_db_zipcode" VALUES(5288,14065,-5,'Freedom, New York 14065',3875,4849);
INSERT INTO "django_geo_db_zipcode" VALUES(5289,14066,-5,'Gainesville, New York 14066',3876,4850);
INSERT INTO "django_geo_db_zipcode" VALUES(5290,14067,-5,'Gasport, New York 14067',3877,4851);
INSERT INTO "django_geo_db_zipcode" VALUES(5291,14068,-5,'Getzville, New York 14068',3878,4852);
INSERT INTO "django_geo_db_zipcode" VALUES(5292,14069,-5,'Glenwood, New York 14069',3879,4853);
INSERT INTO "django_geo_db_zipcode" VALUES(5293,14070,-5,'Gowanda, New York 14070',3880,4854);
INSERT INTO "django_geo_db_zipcode" VALUES(5294,14072,-5,'Grand Island, New York 14072',3881,4855);
INSERT INTO "django_geo_db_zipcode" VALUES(5295,14075,-5,'Hamburg, New York 14075',3882,4856);
INSERT INTO "django_geo_db_zipcode" VALUES(5296,14080,-5,'Holland, New York 14080',3883,4857);
INSERT INTO "django_geo_db_zipcode" VALUES(5297,14081,-5,'Irving, New York 14081',3884,4858);
INSERT INTO "django_geo_db_zipcode" VALUES(5298,14082,-5,'Java Center, New York 14082',3885,4859);
INSERT INTO "django_geo_db_zipcode" VALUES(5299,14083,-5,'Java Village, New York 14083',3886,4860);
INSERT INTO "django_geo_db_zipcode" VALUES(5300,14085,-5,'Lake View, New York 14085',3887,4861);
INSERT INTO "django_geo_db_zipcode" VALUES(5301,14086,-5,'Lancaster, New York 14086',3888,4862);
INSERT INTO "django_geo_db_zipcode" VALUES(5302,14091,-5,'Lawtons, New York 14091',3889,4863);
INSERT INTO "django_geo_db_zipcode" VALUES(5303,14092,-5,'Lewiston, New York 14092',3890,4864);
INSERT INTO "django_geo_db_zipcode" VALUES(5304,14094,-5,'Lockport, New York 14094',3891,4865);
INSERT INTO "django_geo_db_zipcode" VALUES(5305,14095,-5,'Lockport, New York 14095',3891,4866);
INSERT INTO "django_geo_db_zipcode" VALUES(5306,14098,-5,'Lyndonville, New York 14098',3892,4867);
INSERT INTO "django_geo_db_zipcode" VALUES(5307,14101,-5,'Machias, New York 14101',3893,4868);
INSERT INTO "django_geo_db_zipcode" VALUES(5308,14102,-5,'Marilla, New York 14102',3894,4869);
INSERT INTO "django_geo_db_zipcode" VALUES(5309,14103,-5,'Medina, New York 14103',3895,4870);
INSERT INTO "django_geo_db_zipcode" VALUES(5310,14105,-5,'Middleport, New York 14105',3896,4871);
INSERT INTO "django_geo_db_zipcode" VALUES(5311,14107,-5,'Model City, New York 14107',3897,4866);
INSERT INTO "django_geo_db_zipcode" VALUES(5312,14108,-5,'Newfane, New York 14108',3898,4872);
INSERT INTO "django_geo_db_zipcode" VALUES(5313,14109,-5,'Niagara University, New York 14109',3899,4866);
INSERT INTO "django_geo_db_zipcode" VALUES(5314,14110,-5,'North Boston, New York 14110',3900,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5315,14111,-5,'North Collins, New York 14111',3901,4873);
INSERT INTO "django_geo_db_zipcode" VALUES(5316,14112,-5,'North Evans, New York 14112',3902,4874);
INSERT INTO "django_geo_db_zipcode" VALUES(5317,14113,-5,'North Java, New York 14113',3903,4875);
INSERT INTO "django_geo_db_zipcode" VALUES(5318,14120,-5,'North Tonawanda, New York 14120',3904,4876);
INSERT INTO "django_geo_db_zipcode" VALUES(5319,14125,-5,'Oakfield, New York 14125',3905,4877);
INSERT INTO "django_geo_db_zipcode" VALUES(5320,14126,-5,'Olcott, New York 14126',3906,4878);
INSERT INTO "django_geo_db_zipcode" VALUES(5321,14127,-5,'Orchard Park, New York 14127',3907,4879);
INSERT INTO "django_geo_db_zipcode" VALUES(5322,14129,-5,'Perrysburg, New York 14129',3908,4880);
INSERT INTO "django_geo_db_zipcode" VALUES(5323,14130,-5,'Pike, New York 14130',3909,4881);
INSERT INTO "django_geo_db_zipcode" VALUES(5324,14131,-5,'Ransomville, New York 14131',3910,4882);
INSERT INTO "django_geo_db_zipcode" VALUES(5325,14132,-5,'Sanborn, New York 14132',3911,4883);
INSERT INTO "django_geo_db_zipcode" VALUES(5326,14133,-5,'Sandusky, New York 14133',3912,4884);
INSERT INTO "django_geo_db_zipcode" VALUES(5327,14134,-5,'Sardinia, New York 14134',3913,4885);
INSERT INTO "django_geo_db_zipcode" VALUES(5328,14135,-5,'Sheridan, New York 14135',3914,4886);
INSERT INTO "django_geo_db_zipcode" VALUES(5329,14136,-5,'Silver Creek, New York 14136',3915,4887);
INSERT INTO "django_geo_db_zipcode" VALUES(5330,14138,-5,'South Dayton, New York 14138',3916,4888);
INSERT INTO "django_geo_db_zipcode" VALUES(5331,14139,-5,'South Wales, New York 14139',3917,4889);
INSERT INTO "django_geo_db_zipcode" VALUES(5332,14140,-5,'Spring Brook, New York 14140',3918,4890);
INSERT INTO "django_geo_db_zipcode" VALUES(5333,14141,-5,'Springville, New York 14141',3919,4891);
INSERT INTO "django_geo_db_zipcode" VALUES(5334,14143,-5,'Stafford, New York 14143',3920,4892);
INSERT INTO "django_geo_db_zipcode" VALUES(5335,14144,-5,'Stella Niagara, New York 14144',3921,4893);
INSERT INTO "django_geo_db_zipcode" VALUES(5336,14145,-5,'Strykersville, New York 14145',3922,4894);
INSERT INTO "django_geo_db_zipcode" VALUES(5337,14150,-5,'Tonawanda, New York 14150',3923,4895);
INSERT INTO "django_geo_db_zipcode" VALUES(5338,14151,-5,'Tonawanda, New York 14151',3923,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5339,14166,-5,'Van Buren Point, New York 14166',3924,4896);
INSERT INTO "django_geo_db_zipcode" VALUES(5340,14167,-5,'Varysburg, New York 14167',3925,4897);
INSERT INTO "django_geo_db_zipcode" VALUES(5341,14168,-5,'Versailles, New York 14168',3926,4898);
INSERT INTO "django_geo_db_zipcode" VALUES(5342,14169,-5,'Wales Center, New York 14169',3927,4899);
INSERT INTO "django_geo_db_zipcode" VALUES(5343,14170,-5,'West Falls, New York 14170',3928,4900);
INSERT INTO "django_geo_db_zipcode" VALUES(5344,14171,-5,'West Valley, New York 14171',3929,4901);
INSERT INTO "django_geo_db_zipcode" VALUES(5345,14172,-5,'Wilson, New York 14172',3930,4902);
INSERT INTO "django_geo_db_zipcode" VALUES(5346,14173,-5,'Yorkshire, New York 14173',3931,4903);
INSERT INTO "django_geo_db_zipcode" VALUES(5347,14174,-5,'Youngstown, New York 14174',3932,4904);
INSERT INTO "django_geo_db_zipcode" VALUES(5348,14201,-5,'Buffalo, New York 14201',3933,4905);
INSERT INTO "django_geo_db_zipcode" VALUES(5349,14202,-5,'Buffalo, New York 14202',3933,4906);
INSERT INTO "django_geo_db_zipcode" VALUES(5350,14203,-5,'Buffalo, New York 14203',3933,4907);
INSERT INTO "django_geo_db_zipcode" VALUES(5351,14204,-5,'Buffalo, New York 14204',3933,4908);
INSERT INTO "django_geo_db_zipcode" VALUES(5352,14205,-5,'Buffalo, New York 14205',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5353,14206,-5,'Buffalo, New York 14206',3933,4909);
INSERT INTO "django_geo_db_zipcode" VALUES(5354,14207,-5,'Buffalo, New York 14207',3933,4910);
INSERT INTO "django_geo_db_zipcode" VALUES(5355,14208,-5,'Buffalo, New York 14208',3933,4911);
INSERT INTO "django_geo_db_zipcode" VALUES(5356,14209,-5,'Buffalo, New York 14209',3933,4912);
INSERT INTO "django_geo_db_zipcode" VALUES(5357,14210,-5,'Buffalo, New York 14210',3933,4913);
INSERT INTO "django_geo_db_zipcode" VALUES(5358,14211,-5,'Buffalo, New York 14211',3933,4914);
INSERT INTO "django_geo_db_zipcode" VALUES(5359,14212,-5,'Buffalo, New York 14212',3933,4915);
INSERT INTO "django_geo_db_zipcode" VALUES(5360,14213,-5,'Buffalo, New York 14213',3933,4916);
INSERT INTO "django_geo_db_zipcode" VALUES(5361,14214,-5,'Buffalo, New York 14214',3933,4917);
INSERT INTO "django_geo_db_zipcode" VALUES(5362,14215,-5,'Buffalo, New York 14215',3933,4918);
INSERT INTO "django_geo_db_zipcode" VALUES(5363,14216,-5,'Buffalo, New York 14216',3933,4919);
INSERT INTO "django_geo_db_zipcode" VALUES(5364,14217,-5,'Buffalo, New York 14217',3933,4920);
INSERT INTO "django_geo_db_zipcode" VALUES(5365,14218,-5,'Buffalo, New York 14218',3933,4921);
INSERT INTO "django_geo_db_zipcode" VALUES(5366,14219,-5,'Buffalo, New York 14219',3933,4922);
INSERT INTO "django_geo_db_zipcode" VALUES(5367,14220,-5,'Buffalo, New York 14220',3933,4923);
INSERT INTO "django_geo_db_zipcode" VALUES(5368,14221,-5,'Buffalo, New York 14221',3933,4924);
INSERT INTO "django_geo_db_zipcode" VALUES(5369,14222,-5,'Buffalo, New York 14222',3933,4925);
INSERT INTO "django_geo_db_zipcode" VALUES(5370,14223,-5,'Buffalo, New York 14223',3933,4926);
INSERT INTO "django_geo_db_zipcode" VALUES(5371,14224,-5,'Buffalo, New York 14224',3933,4927);
INSERT INTO "django_geo_db_zipcode" VALUES(5372,14225,-5,'Buffalo, New York 14225',3933,4928);
INSERT INTO "django_geo_db_zipcode" VALUES(5373,14226,-5,'Buffalo, New York 14226',3933,4929);
INSERT INTO "django_geo_db_zipcode" VALUES(5374,14227,-5,'Buffalo, New York 14227',3933,4930);
INSERT INTO "django_geo_db_zipcode" VALUES(5375,14228,-5,'Buffalo, New York 14228',3933,4931);
INSERT INTO "django_geo_db_zipcode" VALUES(5376,14231,-5,'Buffalo, New York 14231',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5377,14233,-5,'Buffalo, New York 14233',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5378,14240,-5,'Buffalo, New York 14240',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5379,14241,-5,'Buffalo, New York 14241',3933,4932);
INSERT INTO "django_geo_db_zipcode" VALUES(5380,14260,-5,'Buffalo, New York 14260',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5381,14261,-5,'Buffalo, New York 14261',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5382,14263,-5,'Buffalo, New York 14263',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5383,14264,-5,'Buffalo, New York 14264',3933,4933);
INSERT INTO "django_geo_db_zipcode" VALUES(5384,14265,-5,'Buffalo, New York 14265',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5385,14267,-5,'Buffalo, New York 14267',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5386,14269,-5,'Buffalo, New York 14269',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5387,14270,-5,'Buffalo, New York 14270',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5388,14272,-5,'Buffalo, New York 14272',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5389,14273,-5,'Buffalo, New York 14273',3933,4934);
INSERT INTO "django_geo_db_zipcode" VALUES(5390,14276,-5,'Buffalo, New York 14276',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5391,14280,-5,'Buffalo, New York 14280',3933,4809);
INSERT INTO "django_geo_db_zipcode" VALUES(5392,14301,-5,'Niagara Falls, New York 14301',3934,4935);
INSERT INTO "django_geo_db_zipcode" VALUES(5393,14302,-5,'Niagara Falls, New York 14302',3934,4866);
INSERT INTO "django_geo_db_zipcode" VALUES(5394,14303,-5,'Niagara Falls, New York 14303',3934,4936);
INSERT INTO "django_geo_db_zipcode" VALUES(5395,14304,-5,'Niagara Falls, New York 14304',3934,4937);
INSERT INTO "django_geo_db_zipcode" VALUES(5396,14305,-5,'Niagara Falls, New York 14305',3934,4938);
INSERT INTO "django_geo_db_zipcode" VALUES(5397,14410,-5,'Adams Basin, New York 14410',3935,4939);
INSERT INTO "django_geo_db_zipcode" VALUES(5398,14411,-5,'Albion, New York 14411',3936,4940);
INSERT INTO "django_geo_db_zipcode" VALUES(5399,14413,-5,'Alton, New York 14413',3937,4941);
INSERT INTO "django_geo_db_zipcode" VALUES(5400,14414,-5,'Avon, New York 14414',3938,4942);
INSERT INTO "django_geo_db_zipcode" VALUES(5401,14415,-5,'Bellona, New York 14415',3939,4943);
INSERT INTO "django_geo_db_zipcode" VALUES(5402,14416,-5,'Bergen, New York 14416',3940,4944);
INSERT INTO "django_geo_db_zipcode" VALUES(5403,14417,-5,'Geneseo, New York 14417',3941,4945);
INSERT INTO "django_geo_db_zipcode" VALUES(5404,14418,-5,'Branchport, New York 14418',3942,4946);
INSERT INTO "django_geo_db_zipcode" VALUES(5405,14420,-5,'Brockport, New York 14420',3943,4947);
INSERT INTO "django_geo_db_zipcode" VALUES(5406,14422,-5,'Byron, New York 14422',3944,4948);
INSERT INTO "django_geo_db_zipcode" VALUES(5407,14423,-5,'Caledonia, New York 14423',3945,4949);
INSERT INTO "django_geo_db_zipcode" VALUES(5408,14424,-5,'Canandaigua, New York 14424',3946,4950);
INSERT INTO "django_geo_db_zipcode" VALUES(5409,14425,-5,'Farmington, New York 14425',3947,4951);
INSERT INTO "django_geo_db_zipcode" VALUES(5410,14427,-5,'Castile, New York 14427',3948,4952);
INSERT INTO "django_geo_db_zipcode" VALUES(5411,14428,-5,'Churchville, New York 14428',3949,4953);
INSERT INTO "django_geo_db_zipcode" VALUES(5412,14429,-5,'Clarendon, New York 14429',3950,4954);
INSERT INTO "django_geo_db_zipcode" VALUES(5413,14430,-5,'Clarkson, New York 14430',3951,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5414,14432,-5,'Clifton Springs, New York 14432',3952,4956);
INSERT INTO "django_geo_db_zipcode" VALUES(5415,14433,-5,'Clyde, New York 14433',3953,4957);
INSERT INTO "django_geo_db_zipcode" VALUES(5416,14435,-5,'Conesus, New York 14435',3954,4958);
INSERT INTO "django_geo_db_zipcode" VALUES(5417,14437,-5,'Dansville, New York 14437',3955,4959);
INSERT INTO "django_geo_db_zipcode" VALUES(5418,14441,-5,'Dresden, New York 14441',3956,4960);
INSERT INTO "django_geo_db_zipcode" VALUES(5419,14443,-5,'East Bloomfield, New York 14443',3957,4961);
INSERT INTO "django_geo_db_zipcode" VALUES(5420,14445,-5,'East Rochester, New York 14445',3958,4962);
INSERT INTO "django_geo_db_zipcode" VALUES(5421,14449,-5,'East Williamson, New York 14449',3959,4963);
INSERT INTO "django_geo_db_zipcode" VALUES(5422,14450,-5,'Fairport, New York 14450',3960,4964);
INSERT INTO "django_geo_db_zipcode" VALUES(5423,14452,-5,'Fancher, New York 14452',3961,4954);
INSERT INTO "django_geo_db_zipcode" VALUES(5424,14453,-5,'Fishers, New York 14453',3962,4965);
INSERT INTO "django_geo_db_zipcode" VALUES(5425,14454,-5,'Geneseo, New York 14454',3941,4966);
INSERT INTO "django_geo_db_zipcode" VALUES(5426,14456,-5,'Geneva, New York 14456',3963,4967);
INSERT INTO "django_geo_db_zipcode" VALUES(5427,14458,-5,'Lima, New York 14458',3964,4968);
INSERT INTO "django_geo_db_zipcode" VALUES(5428,14461,-5,'Gorham, New York 14461',3965,4969);
INSERT INTO "django_geo_db_zipcode" VALUES(5429,14462,-5,'Groveland, New York 14462',3966,4970);
INSERT INTO "django_geo_db_zipcode" VALUES(5430,14463,-5,'Hall, New York 14463',3967,4971);
INSERT INTO "django_geo_db_zipcode" VALUES(5431,14464,-5,'Hamlin, New York 14464',3968,4972);
INSERT INTO "django_geo_db_zipcode" VALUES(5432,14466,-5,'Hemlock, New York 14466',3969,4973);
INSERT INTO "django_geo_db_zipcode" VALUES(5433,14467,-5,'Henrietta, New York 14467',3970,4974);
INSERT INTO "django_geo_db_zipcode" VALUES(5434,14468,-5,'Hilton, New York 14468',3971,4975);
INSERT INTO "django_geo_db_zipcode" VALUES(5435,14469,-5,'Bloomfield, New York 14469',3972,4976);
INSERT INTO "django_geo_db_zipcode" VALUES(5436,14470,-5,'Holley, New York 14470',3973,4977);
INSERT INTO "django_geo_db_zipcode" VALUES(5437,14471,-5,'Honeoye, New York 14471',3974,4978);
INSERT INTO "django_geo_db_zipcode" VALUES(5438,14472,-5,'Honeoye Falls, New York 14472',3975,4979);
INSERT INTO "django_geo_db_zipcode" VALUES(5439,14475,-5,'Ionia, New York 14475',3976,4980);
INSERT INTO "django_geo_db_zipcode" VALUES(5440,14476,-5,'Kendall, New York 14476',3977,4981);
INSERT INTO "django_geo_db_zipcode" VALUES(5441,14477,-5,'Kent, New York 14477',3978,4982);
INSERT INTO "django_geo_db_zipcode" VALUES(5442,14478,-5,'Keuka Park, New York 14478',3979,4983);
INSERT INTO "django_geo_db_zipcode" VALUES(5443,14479,-5,'Knowlesville, New York 14479',3980,4984);
INSERT INTO "django_geo_db_zipcode" VALUES(5444,14480,-5,'Lakeville, New York 14480',3981,4985);
INSERT INTO "django_geo_db_zipcode" VALUES(5445,14481,-5,'Leicester, New York 14481',3982,4986);
INSERT INTO "django_geo_db_zipcode" VALUES(5446,14482,-5,'Le Roy, New York 14482',3983,4987);
INSERT INTO "django_geo_db_zipcode" VALUES(5447,14484,-5,'Portage, New York 14484',3984,4988);
INSERT INTO "django_geo_db_zipcode" VALUES(5448,14485,-5,'Lima, New York 14485',3964,4989);
INSERT INTO "django_geo_db_zipcode" VALUES(5449,14486,-5,'Linwood, New York 14486',3985,4990);
INSERT INTO "django_geo_db_zipcode" VALUES(5450,14487,-5,'Livonia, New York 14487',3986,4991);
INSERT INTO "django_geo_db_zipcode" VALUES(5451,14488,-5,'Livonia Center, New York 14488',3987,4992);
INSERT INTO "django_geo_db_zipcode" VALUES(5452,14489,-5,'Lyons, New York 14489',3988,4993);
INSERT INTO "django_geo_db_zipcode" VALUES(5453,14502,-5,'Macedon, New York 14502',3989,4994);
INSERT INTO "django_geo_db_zipcode" VALUES(5454,14504,-5,'Manchester, New York 14504',3990,4995);
INSERT INTO "django_geo_db_zipcode" VALUES(5455,14505,-5,'Marion, New York 14505',3991,4996);
INSERT INTO "django_geo_db_zipcode" VALUES(5456,14506,-5,'Mendon, New York 14506',3992,4997);
INSERT INTO "django_geo_db_zipcode" VALUES(5457,14507,-5,'Middlesex, New York 14507',3993,4998);
INSERT INTO "django_geo_db_zipcode" VALUES(5458,14508,-5,'Morton, New York 14508',3994,4954);
INSERT INTO "django_geo_db_zipcode" VALUES(5459,14510,-5,'Mount Morris, New York 14510',3995,4999);
INSERT INTO "django_geo_db_zipcode" VALUES(5460,14511,-5,'Mumford, New York 14511',3996,5000);
INSERT INTO "django_geo_db_zipcode" VALUES(5461,14512,-5,'Naples, New York 14512',3997,5001);
INSERT INTO "django_geo_db_zipcode" VALUES(5462,14513,-5,'Newark, New York 14513',3998,5002);
INSERT INTO "django_geo_db_zipcode" VALUES(5463,14514,-5,'North Chili, New York 14514',3999,5003);
INSERT INTO "django_geo_db_zipcode" VALUES(5464,14515,-5,'North Greece, New York 14515',4000,5004);
INSERT INTO "django_geo_db_zipcode" VALUES(5465,14516,-5,'North Rose, New York 14516',4001,5005);
INSERT INTO "django_geo_db_zipcode" VALUES(5466,14517,-5,'Nunda, New York 14517',4002,5006);
INSERT INTO "django_geo_db_zipcode" VALUES(5467,14518,-5,'Oaks Corners, New York 14518',4003,5007);
INSERT INTO "django_geo_db_zipcode" VALUES(5468,14519,-5,'Ontario, New York 14519',4004,5008);
INSERT INTO "django_geo_db_zipcode" VALUES(5469,14520,-5,'Ontario Center, New York 14520',4005,5009);
INSERT INTO "django_geo_db_zipcode" VALUES(5470,14521,-5,'Ovid, New York 14521',4006,5010);
INSERT INTO "django_geo_db_zipcode" VALUES(5471,14522,-5,'Palmyra, New York 14522',4007,5011);
INSERT INTO "django_geo_db_zipcode" VALUES(5472,14525,-5,'Pavilion, New York 14525',4008,5012);
INSERT INTO "django_geo_db_zipcode" VALUES(5473,14526,-5,'Penfield, New York 14526',4009,5013);
INSERT INTO "django_geo_db_zipcode" VALUES(5474,14527,-5,'Penn Yan, New York 14527',4010,5014);
INSERT INTO "django_geo_db_zipcode" VALUES(5475,14529,-5,'Perkinsville, New York 14529',4011,5015);
INSERT INTO "django_geo_db_zipcode" VALUES(5476,14530,-5,'Perry, New York 14530',4012,5016);
INSERT INTO "django_geo_db_zipcode" VALUES(5477,14532,-5,'Phelps, New York 14532',4013,5017);
INSERT INTO "django_geo_db_zipcode" VALUES(5478,14533,-5,'Piffard, New York 14533',4014,5018);
INSERT INTO "django_geo_db_zipcode" VALUES(5479,14534,-5,'Pittsford, New York 14534',4015,5019);
INSERT INTO "django_geo_db_zipcode" VALUES(5480,14536,-5,'Portageville, New York 14536',4016,5020);
INSERT INTO "django_geo_db_zipcode" VALUES(5481,14537,-5,'Port Gibson, New York 14537',4017,5021);
INSERT INTO "django_geo_db_zipcode" VALUES(5482,14538,-5,'Pultneyville, New York 14538',4018,5022);
INSERT INTO "django_geo_db_zipcode" VALUES(5483,14539,-5,'Retsof, New York 14539',4019,5023);
INSERT INTO "django_geo_db_zipcode" VALUES(5484,14541,-5,'Romulus, New York 14541',4020,5024);
INSERT INTO "django_geo_db_zipcode" VALUES(5485,14542,-5,'Rose, New York 14542',4021,5025);
INSERT INTO "django_geo_db_zipcode" VALUES(5486,14543,-5,'Rush, New York 14543',4022,5026);
INSERT INTO "django_geo_db_zipcode" VALUES(5487,14544,-5,'Rushville, New York 14544',4023,5027);
INSERT INTO "django_geo_db_zipcode" VALUES(5488,14545,-5,'Scottsburg, New York 14545',4024,5028);
INSERT INTO "django_geo_db_zipcode" VALUES(5489,14546,-5,'Scottsville, New York 14546',4025,5029);
INSERT INTO "django_geo_db_zipcode" VALUES(5490,14547,-5,'Seneca Castle, New York 14547',4026,4969);
INSERT INTO "django_geo_db_zipcode" VALUES(5491,14548,-5,'Shortsville, New York 14548',4027,5030);
INSERT INTO "django_geo_db_zipcode" VALUES(5492,14549,-5,'Silver Lake, New York 14549',4028,5031);
INSERT INTO "django_geo_db_zipcode" VALUES(5493,14550,-5,'Silver Springs, New York 14550',4029,5032);
INSERT INTO "django_geo_db_zipcode" VALUES(5494,14551,-5,'Sodus, New York 14551',4030,5033);
INSERT INTO "django_geo_db_zipcode" VALUES(5495,14555,-5,'Sodus Point, New York 14555',4031,5034);
INSERT INTO "django_geo_db_zipcode" VALUES(5496,14556,-5,'Sonyea, New York 14556',4032,4992);
INSERT INTO "django_geo_db_zipcode" VALUES(5497,14557,-5,'South Byron, New York 14557',4033,5035);
INSERT INTO "django_geo_db_zipcode" VALUES(5498,14558,-5,'South Lima, New York 14558',4034,5036);
INSERT INTO "django_geo_db_zipcode" VALUES(5499,14559,-5,'Spencerport, New York 14559',4035,5037);
INSERT INTO "django_geo_db_zipcode" VALUES(5500,14560,-5,'Springwater, New York 14560',4036,5038);
INSERT INTO "django_geo_db_zipcode" VALUES(5501,14561,-5,'Stanley, New York 14561',4037,5039);
INSERT INTO "django_geo_db_zipcode" VALUES(5502,14563,-5,'Union Hill, New York 14563',4038,5009);
INSERT INTO "django_geo_db_zipcode" VALUES(5503,14564,-5,'Victor, New York 14564',4039,5040);
INSERT INTO "django_geo_db_zipcode" VALUES(5504,14568,-5,'Walworth, New York 14568',4040,5041);
INSERT INTO "django_geo_db_zipcode" VALUES(5505,14569,-5,'Warsaw, New York 14569',4041,5042);
INSERT INTO "django_geo_db_zipcode" VALUES(5506,14571,-5,'Waterport, New York 14571',4042,5043);
INSERT INTO "django_geo_db_zipcode" VALUES(5507,14572,-5,'Wayland, New York 14572',4043,5044);
INSERT INTO "django_geo_db_zipcode" VALUES(5508,14580,-5,'Webster, New York 14580',4044,5045);
INSERT INTO "django_geo_db_zipcode" VALUES(5509,14585,-5,'West Bloomfield, New York 14585',4045,5046);
INSERT INTO "django_geo_db_zipcode" VALUES(5510,14586,-5,'West Henrietta, New York 14586',4046,5047);
INSERT INTO "django_geo_db_zipcode" VALUES(5511,14588,-5,'Willard, New York 14588',4047,5048);
INSERT INTO "django_geo_db_zipcode" VALUES(5512,14589,-5,'Williamson, New York 14589',4048,5049);
INSERT INTO "django_geo_db_zipcode" VALUES(5513,14590,-5,'Wolcott, New York 14590',4049,5050);
INSERT INTO "django_geo_db_zipcode" VALUES(5514,14591,-5,'Wyoming, New York 14591',4050,5051);
INSERT INTO "django_geo_db_zipcode" VALUES(5515,14592,-5,'York, New York 14592',4051,5052);
INSERT INTO "django_geo_db_zipcode" VALUES(5516,14601,-5,'Rochester, New York 14601',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5517,14602,-5,'Rochester, New York 14602',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5518,14603,-5,'Rochester, New York 14603',3874,5053);
INSERT INTO "django_geo_db_zipcode" VALUES(5519,14604,-5,'Rochester, New York 14604',3874,5054);
INSERT INTO "django_geo_db_zipcode" VALUES(5520,14605,-5,'Rochester, New York 14605',3874,5055);
INSERT INTO "django_geo_db_zipcode" VALUES(5521,14606,-5,'Rochester, New York 14606',3874,5056);
INSERT INTO "django_geo_db_zipcode" VALUES(5522,14607,-5,'Rochester, New York 14607',3874,5057);
INSERT INTO "django_geo_db_zipcode" VALUES(5523,14608,-5,'Rochester, New York 14608',3874,5058);
INSERT INTO "django_geo_db_zipcode" VALUES(5524,14609,-5,'Rochester, New York 14609',3874,5059);
INSERT INTO "django_geo_db_zipcode" VALUES(5525,14610,-5,'Rochester, New York 14610',3874,5060);
INSERT INTO "django_geo_db_zipcode" VALUES(5526,14611,-5,'Rochester, New York 14611',3874,5061);
INSERT INTO "django_geo_db_zipcode" VALUES(5527,14612,-5,'Rochester, New York 14612',3874,5062);
INSERT INTO "django_geo_db_zipcode" VALUES(5528,14613,-5,'Rochester, New York 14613',3874,5063);
INSERT INTO "django_geo_db_zipcode" VALUES(5529,14614,-5,'Rochester, New York 14614',3874,5064);
INSERT INTO "django_geo_db_zipcode" VALUES(5530,14615,-5,'Rochester, New York 14615',3874,5065);
INSERT INTO "django_geo_db_zipcode" VALUES(5531,14616,-5,'Rochester, New York 14616',3874,5066);
INSERT INTO "django_geo_db_zipcode" VALUES(5532,14617,-5,'Rochester, New York 14617',3874,5067);
INSERT INTO "django_geo_db_zipcode" VALUES(5533,14618,-5,'Rochester, New York 14618',3874,5068);
INSERT INTO "django_geo_db_zipcode" VALUES(5534,14619,-5,'Rochester, New York 14619',3874,5069);
INSERT INTO "django_geo_db_zipcode" VALUES(5535,14620,-5,'Rochester, New York 14620',3874,5070);
INSERT INTO "django_geo_db_zipcode" VALUES(5536,14621,-5,'Rochester, New York 14621',3874,5071);
INSERT INTO "django_geo_db_zipcode" VALUES(5537,14622,-5,'Rochester, New York 14622',3874,5072);
INSERT INTO "django_geo_db_zipcode" VALUES(5538,14623,-5,'Rochester, New York 14623',3874,5073);
INSERT INTO "django_geo_db_zipcode" VALUES(5539,14624,-5,'Rochester, New York 14624',3874,5074);
INSERT INTO "django_geo_db_zipcode" VALUES(5540,14625,-5,'Rochester, New York 14625',3874,5075);
INSERT INTO "django_geo_db_zipcode" VALUES(5541,14626,-5,'Rochester, New York 14626',3874,5076);
INSERT INTO "django_geo_db_zipcode" VALUES(5542,14627,-5,'Rochester, New York 14627',3874,5077);
INSERT INTO "django_geo_db_zipcode" VALUES(5543,14638,-5,'Rochester, New York 14638',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5544,14639,-5,'Rochester, New York 14639',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5545,14642,-5,'Rochester, New York 14642',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5546,14643,-5,'Rochester, New York 14643',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5547,14644,-5,'Rochester, New York 14644',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5548,14645,-5,'Rochester, New York 14645',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5549,14646,-5,'Rochester, New York 14646',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5550,14647,-5,'Rochester, New York 14647',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5551,14649,-5,'Rochester, New York 14649',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5552,14650,-5,'Rochester, New York 14650',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5553,14651,-5,'Rochester, New York 14651',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5554,14652,-5,'Rochester, New York 14652',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5555,14653,-5,'Rochester, New York 14653',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5556,14660,-5,'Rochester, New York 14660',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5557,14664,-5,'Rochester, New York 14664',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5558,14673,-5,'Rochester, New York 14673',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5559,14683,-5,'Rochester, New York 14683',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5560,14692,-5,'Rochester, New York 14692',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5561,14694,-5,'Rochester, New York 14694',3874,4955);
INSERT INTO "django_geo_db_zipcode" VALUES(5562,14701,-5,'Jamestown, New York 14701',4052,5078);
INSERT INTO "django_geo_db_zipcode" VALUES(5563,14702,-5,'Jamestown, New York 14702',4052,5079);
INSERT INTO "django_geo_db_zipcode" VALUES(5564,14703,-5,'Jamestown, New York 14703',4052,5080);
INSERT INTO "django_geo_db_zipcode" VALUES(5565,14704,-5,'Jamestown, New York 14704',4052,5080);
INSERT INTO "django_geo_db_zipcode" VALUES(5566,14706,-5,'Allegany, New York 14706',4053,5081);
INSERT INTO "django_geo_db_zipcode" VALUES(5567,14707,-5,'Allentown, New York 14707',4054,5082);
INSERT INTO "django_geo_db_zipcode" VALUES(5568,14708,-5,'Alma, New York 14708',4055,5083);
INSERT INTO "django_geo_db_zipcode" VALUES(5569,14709,-5,'Angelica, New York 14709',4056,5084);
INSERT INTO "django_geo_db_zipcode" VALUES(5570,14710,-5,'Ashville, New York 14710',4057,5085);
INSERT INTO "django_geo_db_zipcode" VALUES(5571,14711,-5,'Belfast, New York 14711',4058,5086);
INSERT INTO "django_geo_db_zipcode" VALUES(5572,14712,-5,'Bemus Point, New York 14712',4059,5087);
INSERT INTO "django_geo_db_zipcode" VALUES(5573,14714,-5,'Black Creek, New York 14714',4060,5088);
INSERT INTO "django_geo_db_zipcode" VALUES(5574,14715,-5,'Bolivar, New York 14715',4061,5089);
INSERT INTO "django_geo_db_zipcode" VALUES(5575,14716,-5,'Brocton, New York 14716',4062,5090);
INSERT INTO "django_geo_db_zipcode" VALUES(5576,14717,-5,'Caneadea, New York 14717',4063,5091);
INSERT INTO "django_geo_db_zipcode" VALUES(5577,14718,-5,'Cassadaga, New York 14718',4064,5092);
INSERT INTO "django_geo_db_zipcode" VALUES(5578,14719,-5,'Cattaraugus, New York 14719',4065,5093);
INSERT INTO "django_geo_db_zipcode" VALUES(5579,14720,-5,'Celoron, New York 14720',4066,5094);
INSERT INTO "django_geo_db_zipcode" VALUES(5580,14721,-5,'Ceres, New York 14721',4067,5095);
INSERT INTO "django_geo_db_zipcode" VALUES(5581,14722,-5,'Chautauqua, New York 14722',4068,5096);
INSERT INTO "django_geo_db_zipcode" VALUES(5582,14723,-5,'Cherry Creek, New York 14723',4069,5097);
INSERT INTO "django_geo_db_zipcode" VALUES(5583,14724,-5,'Clymer, New York 14724',4070,5098);
INSERT INTO "django_geo_db_zipcode" VALUES(5584,14726,-5,'Conewango Valley, New York 14726',4071,5099);
INSERT INTO "django_geo_db_zipcode" VALUES(5585,14727,-5,'Cuba, New York 14727',4072,5100);
INSERT INTO "django_geo_db_zipcode" VALUES(5586,14728,-5,'Dewittville, New York 14728',4073,5101);
INSERT INTO "django_geo_db_zipcode" VALUES(5587,14729,-5,'East Otto, New York 14729',4074,5102);
INSERT INTO "django_geo_db_zipcode" VALUES(5588,14730,-5,'East Randolph, New York 14730',4075,5103);
INSERT INTO "django_geo_db_zipcode" VALUES(5589,14731,-5,'Ellicottville, New York 14731',4076,5104);
INSERT INTO "django_geo_db_zipcode" VALUES(5590,14732,-5,'Ellington, New York 14732',4077,5105);
INSERT INTO "django_geo_db_zipcode" VALUES(5591,14733,-5,'Falconer, New York 14733',4078,5106);
INSERT INTO "django_geo_db_zipcode" VALUES(5592,14735,-5,'Fillmore, New York 14735',4079,5107);
INSERT INTO "django_geo_db_zipcode" VALUES(5593,14736,-5,'Findley Lake, New York 14736',4080,5108);
INSERT INTO "django_geo_db_zipcode" VALUES(5594,14737,-5,'Franklinville, New York 14737',4081,5109);
INSERT INTO "django_geo_db_zipcode" VALUES(5595,14738,-5,'Frewsburg, New York 14738',4082,5110);
INSERT INTO "django_geo_db_zipcode" VALUES(5596,14739,-5,'Friendship, New York 14739',4083,5111);
INSERT INTO "django_geo_db_zipcode" VALUES(5597,14740,-5,'Gerry, New York 14740',4084,5112);
INSERT INTO "django_geo_db_zipcode" VALUES(5598,14741,-5,'Great Valley, New York 14741',4085,5113);
INSERT INTO "django_geo_db_zipcode" VALUES(5599,14742,-5,'Greenhurst, New York 14742',4086,5114);
INSERT INTO "django_geo_db_zipcode" VALUES(5600,14743,-5,'Hinsdale, New York 14743',4087,5115);
INSERT INTO "django_geo_db_zipcode" VALUES(5601,14744,-5,'Houghton, New York 14744',4088,5116);
INSERT INTO "django_geo_db_zipcode" VALUES(5602,14745,-5,'Hume, New York 14745',4089,5117);
INSERT INTO "django_geo_db_zipcode" VALUES(5603,14747,-5,'Kennedy, New York 14747',4090,5118);
INSERT INTO "django_geo_db_zipcode" VALUES(5604,14748,-5,'Kill Buck, New York 14748',4091,5119);
INSERT INTO "django_geo_db_zipcode" VALUES(5605,14750,-5,'Lakewood, New York 14750',4092,5120);
INSERT INTO "django_geo_db_zipcode" VALUES(5606,14751,-5,'Leon, New York 14751',4093,5121);
INSERT INTO "django_geo_db_zipcode" VALUES(5607,14752,-5,'Lily Dale, New York 14752',4094,5122);
INSERT INTO "django_geo_db_zipcode" VALUES(5608,14753,-5,'Limestone, New York 14753',4095,5123);
INSERT INTO "django_geo_db_zipcode" VALUES(5609,14754,-5,'Little Genesee, New York 14754',4096,5124);
INSERT INTO "django_geo_db_zipcode" VALUES(5610,14755,-5,'Little Valley, New York 14755',4097,5125);
INSERT INTO "django_geo_db_zipcode" VALUES(5611,14756,-5,'Maple Springs, New York 14756',4098,5126);
INSERT INTO "django_geo_db_zipcode" VALUES(5612,14757,-5,'Mayville, New York 14757',4099,5127);
INSERT INTO "django_geo_db_zipcode" VALUES(5613,14758,-5,'Niobe, New York 14758',4100,5080);
INSERT INTO "django_geo_db_zipcode" VALUES(5614,14760,-5,'Olean, New York 14760',4101,5128);
INSERT INTO "django_geo_db_zipcode" VALUES(5615,14766,-5,'Otto, New York 14766',4102,5129);
INSERT INTO "django_geo_db_zipcode" VALUES(5616,14767,-5,'Panama, New York 14767',4103,5130);
INSERT INTO "django_geo_db_zipcode" VALUES(5617,14769,-5,'Portland, New York 14769',4104,5131);
INSERT INTO "django_geo_db_zipcode" VALUES(5618,14770,-5,'Portville, New York 14770',4105,5132);
INSERT INTO "django_geo_db_zipcode" VALUES(5619,14771,-5,'Canadice, New York 14771',4106,5133);
INSERT INTO "django_geo_db_zipcode" VALUES(5620,14772,-5,'Randolph, New York 14772',4107,5134);
INSERT INTO "django_geo_db_zipcode" VALUES(5621,14774,-5,'Richburg, New York 14774',4108,5135);
INSERT INTO "django_geo_db_zipcode" VALUES(5622,14775,-5,'Ripley, New York 14775',4109,5136);
INSERT INTO "django_geo_db_zipcode" VALUES(5623,14776,-5,'Rossburg, New York 14776',4110,5137);
INSERT INTO "django_geo_db_zipcode" VALUES(5624,14777,-5,'Rushford, New York 14777',4111,5138);
INSERT INTO "django_geo_db_zipcode" VALUES(5625,14778,-5,'Saint Bonaventure, New York 14778',4112,5139);
INSERT INTO "django_geo_db_zipcode" VALUES(5626,14779,-5,'Salamanca, New York 14779',4113,5140);
INSERT INTO "django_geo_db_zipcode" VALUES(5627,14781,-5,'Sherman, New York 14781',4114,5141);
INSERT INTO "django_geo_db_zipcode" VALUES(5628,14782,-5,'Sinclairville, New York 14782',4115,5142);
INSERT INTO "django_geo_db_zipcode" VALUES(5629,14783,-5,'Steamburg, New York 14783',4116,5143);
INSERT INTO "django_geo_db_zipcode" VALUES(5630,14784,-5,'Stockton, New York 14784',4117,5144);
INSERT INTO "django_geo_db_zipcode" VALUES(5631,14785,-5,'Stow, New York 14785',4118,5145);
INSERT INTO "django_geo_db_zipcode" VALUES(5632,14786,-5,'West Clarksville, New York 14786',4119,5146);
INSERT INTO "django_geo_db_zipcode" VALUES(5633,14787,-5,'Westfield, New York 14787',4120,5147);
INSERT INTO "django_geo_db_zipcode" VALUES(5634,14788,-5,'Westons Mills, New York 14788',4121,5148);
INSERT INTO "django_geo_db_zipcode" VALUES(5635,14801,-5,'Addison, New York 14801',4122,5149);
INSERT INTO "django_geo_db_zipcode" VALUES(5636,14802,-5,'Alfred, New York 14802',4123,5150);
INSERT INTO "django_geo_db_zipcode" VALUES(5637,14803,-5,'Alfred Station, New York 14803',4124,5151);
INSERT INTO "django_geo_db_zipcode" VALUES(5638,14804,-5,'Almond, New York 14804',4125,5152);
INSERT INTO "django_geo_db_zipcode" VALUES(5639,14805,-5,'Alpine, New York 14805',4126,5153);
INSERT INTO "django_geo_db_zipcode" VALUES(5640,14806,-5,'Andover, New York 14806',4127,5154);
INSERT INTO "django_geo_db_zipcode" VALUES(5641,14807,-5,'Arkport, New York 14807',4128,5155);
INSERT INTO "django_geo_db_zipcode" VALUES(5642,14808,-5,'Atlanta, New York 14808',4129,5156);
INSERT INTO "django_geo_db_zipcode" VALUES(5643,14809,-5,'Avoca, New York 14809',4130,5157);
INSERT INTO "django_geo_db_zipcode" VALUES(5644,14810,-5,'Bath, New York 14810',4131,5158);
INSERT INTO "django_geo_db_zipcode" VALUES(5645,14812,-5,'Beaver Dams, New York 14812',4132,5159);
INSERT INTO "django_geo_db_zipcode" VALUES(5646,14813,-5,'Belmont, New York 14813',4133,5160);
INSERT INTO "django_geo_db_zipcode" VALUES(5647,14814,-5,'Big Flats, New York 14814',4134,5161);
INSERT INTO "django_geo_db_zipcode" VALUES(5648,14815,-5,'Bradford, New York 14815',4135,5162);
INSERT INTO "django_geo_db_zipcode" VALUES(5649,14816,-5,'Breesport, New York 14816',4136,5163);
INSERT INTO "django_geo_db_zipcode" VALUES(5650,14817,-5,'Brooktondale, New York 14817',4137,5164);
INSERT INTO "django_geo_db_zipcode" VALUES(5651,14818,-5,'Burdett, New York 14818',4138,5165);
INSERT INTO "django_geo_db_zipcode" VALUES(5652,14819,-5,'Cameron, New York 14819',4139,5166);
INSERT INTO "django_geo_db_zipcode" VALUES(5653,14820,-5,'Cameron Mills, New York 14820',4140,5167);
INSERT INTO "django_geo_db_zipcode" VALUES(5654,14821,-5,'Campbell, New York 14821',4141,5168);
INSERT INTO "django_geo_db_zipcode" VALUES(5655,14822,-5,'Canaseraga, New York 14822',4142,5169);
INSERT INTO "django_geo_db_zipcode" VALUES(5656,14823,-5,'Canisteo, New York 14823',4143,5170);
INSERT INTO "django_geo_db_zipcode" VALUES(5657,14824,-5,'Cayuta, New York 14824',4144,5171);
INSERT INTO "django_geo_db_zipcode" VALUES(5658,14825,-5,'Chemung, New York 14825',4145,5172);
INSERT INTO "django_geo_db_zipcode" VALUES(5659,14826,-5,'Cohocton, New York 14826',4146,5173);
INSERT INTO "django_geo_db_zipcode" VALUES(5660,14827,-5,'Coopers Plains, New York 14827',4147,5174);
INSERT INTO "django_geo_db_zipcode" VALUES(5661,14830,-5,'Corning, New York 14830',4148,5175);
INSERT INTO "django_geo_db_zipcode" VALUES(5662,14831,-5,'Corning, New York 14831',4148,5176);
INSERT INTO "django_geo_db_zipcode" VALUES(5663,14836,-5,'Dalton, New York 14836',4149,5177);
INSERT INTO "django_geo_db_zipcode" VALUES(5664,14837,-5,'Dundee, New York 14837',4150,5178);
INSERT INTO "django_geo_db_zipcode" VALUES(5665,14838,-5,'Erin, New York 14838',4151,5179);
INSERT INTO "django_geo_db_zipcode" VALUES(5666,14839,-5,'Greenwood, New York 14839',4152,5180);
INSERT INTO "django_geo_db_zipcode" VALUES(5667,14840,-5,'Hammondsport, New York 14840',4153,5181);
INSERT INTO "django_geo_db_zipcode" VALUES(5668,14841,-5,'Hector, New York 14841',4154,5182);
INSERT INTO "django_geo_db_zipcode" VALUES(5669,14842,-5,'Himrod, New York 14842',4155,5183);
INSERT INTO "django_geo_db_zipcode" VALUES(5670,14843,-5,'Hornell, New York 14843',4156,5184);
INSERT INTO "django_geo_db_zipcode" VALUES(5671,14844,-5,'Horseheads, New York 14844',4157,5185);
INSERT INTO "django_geo_db_zipcode" VALUES(5672,14845,-5,'Horseheads, New York 14845',4157,5186);
INSERT INTO "django_geo_db_zipcode" VALUES(5673,14846,-5,'Hunt, New York 14846',4158,5187);
INSERT INTO "django_geo_db_zipcode" VALUES(5674,14847,-5,'Interlaken, New York 14847',4159,5188);
INSERT INTO "django_geo_db_zipcode" VALUES(5675,14850,-5,'Ithaca, New York 14850',4160,5189);
INSERT INTO "django_geo_db_zipcode" VALUES(5676,14851,-5,'Ithaca, New York 14851',4160,5190);
INSERT INTO "django_geo_db_zipcode" VALUES(5677,14852,-5,'Ithaca, New York 14852',4160,5191);
INSERT INTO "django_geo_db_zipcode" VALUES(5678,14853,-5,'Ithaca, New York 14853',4160,5192);
INSERT INTO "django_geo_db_zipcode" VALUES(5679,14854,-5,'Jacksonville, New York 14854',4161,5193);
INSERT INTO "django_geo_db_zipcode" VALUES(5680,14855,-5,'Jasper, New York 14855',4162,5194);
INSERT INTO "django_geo_db_zipcode" VALUES(5681,14856,-5,'Kanona, New York 14856',4163,5195);
INSERT INTO "django_geo_db_zipcode" VALUES(5682,14857,-5,'Lakemont, New York 14857',4164,5196);
INSERT INTO "django_geo_db_zipcode" VALUES(5683,14858,-5,'Lindley, New York 14858',4165,5197);
INSERT INTO "django_geo_db_zipcode" VALUES(5684,14859,-5,'Lockwood, New York 14859',4166,5198);
INSERT INTO "django_geo_db_zipcode" VALUES(5685,14860,-5,'Lodi, New York 14860',4167,5199);
INSERT INTO "django_geo_db_zipcode" VALUES(5686,14861,-5,'Lowman, New York 14861',4168,5200);
INSERT INTO "django_geo_db_zipcode" VALUES(5687,14863,-5,'Mecklenburg, New York 14863',4169,5201);
INSERT INTO "django_geo_db_zipcode" VALUES(5688,14864,-5,'Millport, New York 14864',4170,5202);
INSERT INTO "django_geo_db_zipcode" VALUES(5689,14865,-5,'Montour Falls, New York 14865',4171,5203);
INSERT INTO "django_geo_db_zipcode" VALUES(5690,14867,-5,'Newfield, New York 14867',4172,5204);
INSERT INTO "django_geo_db_zipcode" VALUES(5691,14869,-5,'Odessa, New York 14869',4173,5205);
INSERT INTO "django_geo_db_zipcode" VALUES(5692,14870,-5,'Painted Post, New York 14870',4174,5206);
INSERT INTO "django_geo_db_zipcode" VALUES(5693,14871,-5,'Pine City, New York 14871',4175,5207);
INSERT INTO "django_geo_db_zipcode" VALUES(5694,14872,-5,'Pine Valley, New York 14872',4176,5208);
INSERT INTO "django_geo_db_zipcode" VALUES(5695,14873,-5,'Prattsburgh, New York 14873',4177,5209);
INSERT INTO "django_geo_db_zipcode" VALUES(5696,14874,-5,'Pulteney, New York 14874',4178,5210);
INSERT INTO "django_geo_db_zipcode" VALUES(5697,14876,-5,'Reading Center, New York 14876',4179,5211);
INSERT INTO "django_geo_db_zipcode" VALUES(5698,14877,-5,'Rexville, New York 14877',4180,5212);
INSERT INTO "django_geo_db_zipcode" VALUES(5699,14878,-5,'Rock Stream, New York 14878',4181,5213);
INSERT INTO "django_geo_db_zipcode" VALUES(5700,14879,-5,'Savona, New York 14879',4182,5214);
INSERT INTO "django_geo_db_zipcode" VALUES(5701,14880,-5,'Scio, New York 14880',4183,5215);
INSERT INTO "django_geo_db_zipcode" VALUES(5702,14881,-5,'Slaterville Springs, New York 14881',4184,5216);
INSERT INTO "django_geo_db_zipcode" VALUES(5703,14882,-5,'Lansing, New York 14882',4185,5217);
INSERT INTO "django_geo_db_zipcode" VALUES(5704,14883,-5,'Spencer, New York 14883',4186,5218);
INSERT INTO "django_geo_db_zipcode" VALUES(5705,14884,-5,'Swain, New York 14884',4187,5219);
INSERT INTO "django_geo_db_zipcode" VALUES(5706,14885,-5,'Troupsburg, New York 14885',4188,5220);
INSERT INTO "django_geo_db_zipcode" VALUES(5707,14886,-5,'Trumansburg, New York 14886',4189,5221);
INSERT INTO "django_geo_db_zipcode" VALUES(5708,14887,-5,'Tyrone, New York 14887',4190,5222);
INSERT INTO "django_geo_db_zipcode" VALUES(5709,14889,-5,'Van Etten, New York 14889',4191,5223);
INSERT INTO "django_geo_db_zipcode" VALUES(5710,14891,-5,'Watkins Glen, New York 14891',4192,5224);
INSERT INTO "django_geo_db_zipcode" VALUES(5711,14892,-5,'Waverly, New York 14892',4193,5225);
INSERT INTO "django_geo_db_zipcode" VALUES(5712,14893,-5,'Wayne, New York 14893',4194,5226);
INSERT INTO "django_geo_db_zipcode" VALUES(5713,14894,-5,'Wellsburg, New York 14894',4195,5227);
INSERT INTO "django_geo_db_zipcode" VALUES(5714,14895,-5,'Wellsville, New York 14895',4196,5228);
INSERT INTO "django_geo_db_zipcode" VALUES(5715,14897,-5,'Whitesville, New York 14897',4197,5229);
INSERT INTO "django_geo_db_zipcode" VALUES(5716,14898,-5,'Woodhull, New York 14898',4198,5230);
INSERT INTO "django_geo_db_zipcode" VALUES(5717,14901,-5,'Elmira, New York 14901',4199,5231);
INSERT INTO "django_geo_db_zipcode" VALUES(5718,14902,-5,'Elmira, New York 14902',4199,5232);
INSERT INTO "django_geo_db_zipcode" VALUES(5719,14903,-5,'Elmira, New York 14903',4199,5233);
INSERT INTO "django_geo_db_zipcode" VALUES(5720,14904,-5,'Elmira, New York 14904',4199,5234);
INSERT INTO "django_geo_db_zipcode" VALUES(5721,14905,-5,'Elmira, New York 14905',4199,5235);
INSERT INTO "django_geo_db_zipcode" VALUES(5722,14925,-5,'Elmira, New York 14925',4199,5232);
INSERT INTO "django_geo_db_zipcode" VALUES(5723,15001,-5,'Aliquippa, Pennsylvania 15001',4200,5236);
INSERT INTO "django_geo_db_zipcode" VALUES(5724,15003,-5,'Ambridge, Pennsylvania 15003',4201,5237);
INSERT INTO "django_geo_db_zipcode" VALUES(5725,15004,-5,'Atlasburg, Pennsylvania 15004',4202,5238);
INSERT INTO "django_geo_db_zipcode" VALUES(5726,15005,-5,'Baden, Pennsylvania 15005',4203,5239);
INSERT INTO "django_geo_db_zipcode" VALUES(5727,15006,-5,'Bairdford, Pennsylvania 15006',4204,5240);
INSERT INTO "django_geo_db_zipcode" VALUES(5728,15007,-5,'Bakerstown, Pennsylvania 15007',4205,5241);
INSERT INTO "django_geo_db_zipcode" VALUES(5729,15009,-5,'Beaver, Pennsylvania 15009',4206,5242);
INSERT INTO "django_geo_db_zipcode" VALUES(5730,15010,-5,'Beaver Falls, Pennsylvania 15010',4207,5243);
INSERT INTO "django_geo_db_zipcode" VALUES(5731,15012,-5,'Belle Vernon, Pennsylvania 15012',4208,5244);
INSERT INTO "django_geo_db_zipcode" VALUES(5732,15014,-5,'Brackenridge, Pennsylvania 15014',4209,5245);
INSERT INTO "django_geo_db_zipcode" VALUES(5733,15015,-5,'Bradfordwoods, Pennsylvania 15015',4210,5246);
INSERT INTO "django_geo_db_zipcode" VALUES(5734,15017,-5,'Bridgeville, Pennsylvania 15017',4211,5247);
INSERT INTO "django_geo_db_zipcode" VALUES(5735,15018,-5,'Buena Vista, Pennsylvania 15018',4212,5248);
INSERT INTO "django_geo_db_zipcode" VALUES(5736,15019,-5,'Bulger, Pennsylvania 15019',4213,5249);
INSERT INTO "django_geo_db_zipcode" VALUES(5737,15020,-5,'Bunola, Pennsylvania 15020',4214,5250);
INSERT INTO "django_geo_db_zipcode" VALUES(5738,15021,-5,'Burgettstown, Pennsylvania 15021',4215,5251);
INSERT INTO "django_geo_db_zipcode" VALUES(5739,15022,-5,'Charleroi, Pennsylvania 15022',4216,5252);
INSERT INTO "django_geo_db_zipcode" VALUES(5740,15024,-5,'Cheswick, Pennsylvania 15024',4217,5253);
INSERT INTO "django_geo_db_zipcode" VALUES(5741,15025,-5,'Clairton, Pennsylvania 15025',4218,5254);
INSERT INTO "django_geo_db_zipcode" VALUES(5742,15026,-5,'Clinton, Pennsylvania 15026',4219,5255);
INSERT INTO "django_geo_db_zipcode" VALUES(5743,15027,-5,'Conway, Pennsylvania 15027',4220,5256);
INSERT INTO "django_geo_db_zipcode" VALUES(5744,15028,-5,'Coulters, Pennsylvania 15028',4221,5257);
INSERT INTO "django_geo_db_zipcode" VALUES(5745,15030,-5,'Creighton, Pennsylvania 15030',4222,5258);
INSERT INTO "django_geo_db_zipcode" VALUES(5746,15031,-5,'Cuddy, Pennsylvania 15031',4223,5259);
INSERT INTO "django_geo_db_zipcode" VALUES(5747,15032,-5,'Curtisville, Pennsylvania 15032',4224,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5748,15033,-5,'Donora, Pennsylvania 15033',4225,5261);
INSERT INTO "django_geo_db_zipcode" VALUES(5749,15034,-5,'Dravosburg, Pennsylvania 15034',4226,5262);
INSERT INTO "django_geo_db_zipcode" VALUES(5750,15035,-5,'East McKeesport, Pennsylvania 15035',4227,5263);
INSERT INTO "django_geo_db_zipcode" VALUES(5751,15036,-5,'Eldersville, Pennsylvania 15036',4228,5264);
INSERT INTO "django_geo_db_zipcode" VALUES(5752,15037,-5,'Elizabeth, Pennsylvania 15037',4229,5265);
INSERT INTO "django_geo_db_zipcode" VALUES(5753,15038,-5,'Elrama, Pennsylvania 15038',4230,5266);
INSERT INTO "django_geo_db_zipcode" VALUES(5754,15042,-5,'Freedom, Pennsylvania 15042',4231,5267);
INSERT INTO "django_geo_db_zipcode" VALUES(5755,15043,-5,'Georgetown, Pennsylvania 15043',4232,5268);
INSERT INTO "django_geo_db_zipcode" VALUES(5756,15044,-5,'Gibsonia, Pennsylvania 15044',4233,5269);
INSERT INTO "django_geo_db_zipcode" VALUES(5757,15045,-5,'Glassport, Pennsylvania 15045',4234,5270);
INSERT INTO "django_geo_db_zipcode" VALUES(5758,15046,-5,'Crescent, Pennsylvania 15046',4235,5271);
INSERT INTO "django_geo_db_zipcode" VALUES(5759,15047,-5,'Greenock, Pennsylvania 15047',4236,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5760,15049,-5,'Harwick, Pennsylvania 15049',4237,5272);
INSERT INTO "django_geo_db_zipcode" VALUES(5761,15050,-5,'Hookstown, Pennsylvania 15050',4238,5273);
INSERT INTO "django_geo_db_zipcode" VALUES(5762,15051,-5,'Indianola, Pennsylvania 15051',4239,5274);
INSERT INTO "django_geo_db_zipcode" VALUES(5763,15052,-5,'Industry, Pennsylvania 15052',4240,5275);
INSERT INTO "django_geo_db_zipcode" VALUES(5764,15053,-5,'Joffre, Pennsylvania 15053',4241,5276);
INSERT INTO "django_geo_db_zipcode" VALUES(5765,15054,-5,'Langeloth, Pennsylvania 15054',4242,5277);
INSERT INTO "django_geo_db_zipcode" VALUES(5766,15055,-5,'Lawrence, Pennsylvania 15055',4243,5278);
INSERT INTO "django_geo_db_zipcode" VALUES(5767,15056,-5,'Leetsdale, Pennsylvania 15056',4244,5279);
INSERT INTO "django_geo_db_zipcode" VALUES(5768,15057,-5,'McDonald, Pennsylvania 15057',4245,5280);
INSERT INTO "django_geo_db_zipcode" VALUES(5769,15059,-5,'Midland, Pennsylvania 15059',4246,5281);
INSERT INTO "django_geo_db_zipcode" VALUES(5770,15060,-5,'Midway, Pennsylvania 15060',4247,5282);
INSERT INTO "django_geo_db_zipcode" VALUES(5771,15061,-5,'Monaca, Pennsylvania 15061',4248,5283);
INSERT INTO "django_geo_db_zipcode" VALUES(5772,15062,-5,'Monessen, Pennsylvania 15062',4249,5284);
INSERT INTO "django_geo_db_zipcode" VALUES(5773,15063,-5,'Monongahela, Pennsylvania 15063',4250,5285);
INSERT INTO "django_geo_db_zipcode" VALUES(5774,15064,-5,'Morgan, Pennsylvania 15064',4251,5286);
INSERT INTO "django_geo_db_zipcode" VALUES(5775,15065,-5,'Natrona Heights, Pennsylvania 15065',4252,5287);
INSERT INTO "django_geo_db_zipcode" VALUES(5776,15066,-5,'New Brighton, Pennsylvania 15066',4253,5288);
INSERT INTO "django_geo_db_zipcode" VALUES(5777,15067,-5,'New Eagle, Pennsylvania 15067',4254,5289);
INSERT INTO "django_geo_db_zipcode" VALUES(5778,15068,-5,'New Kensington, Pennsylvania 15068',4255,5290);
INSERT INTO "django_geo_db_zipcode" VALUES(5779,15069,-5,'New Kensington, Pennsylvania 15069',4255,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(5780,15071,-5,'Oakdale, Pennsylvania 15071',4256,5292);
INSERT INTO "django_geo_db_zipcode" VALUES(5781,15072,-5,'Pricedale, Pennsylvania 15072',4257,5293);
INSERT INTO "django_geo_db_zipcode" VALUES(5782,15074,-5,'Rochester, Pennsylvania 15074',4258,5294);
INSERT INTO "django_geo_db_zipcode" VALUES(5783,15075,-5,'Rural Ridge, Pennsylvania 15075',4259,5295);
INSERT INTO "django_geo_db_zipcode" VALUES(5784,15076,-5,'Russellton, Pennsylvania 15076',4260,5296);
INSERT INTO "django_geo_db_zipcode" VALUES(5785,15077,-5,'Shippingport, Pennsylvania 15077',4261,5297);
INSERT INTO "django_geo_db_zipcode" VALUES(5786,15078,-5,'Slovan, Pennsylvania 15078',4262,5298);
INSERT INTO "django_geo_db_zipcode" VALUES(5787,15081,-5,'South Heights, Pennsylvania 15081',4263,5299);
INSERT INTO "django_geo_db_zipcode" VALUES(5788,15082,-5,'Sturgeon, Pennsylvania 15082',4264,5300);
INSERT INTO "django_geo_db_zipcode" VALUES(5789,15083,-5,'Sutersville, Pennsylvania 15083',4265,5301);
INSERT INTO "django_geo_db_zipcode" VALUES(5790,15084,-5,'Tarentum, Pennsylvania 15084',4266,5302);
INSERT INTO "django_geo_db_zipcode" VALUES(5791,15085,-5,'Trafford, Pennsylvania 15085',4267,5303);
INSERT INTO "django_geo_db_zipcode" VALUES(5792,15086,-5,'Warrendale, Pennsylvania 15086',4268,5304);
INSERT INTO "django_geo_db_zipcode" VALUES(5793,15087,-5,'Webster, Pennsylvania 15087',4269,5305);
INSERT INTO "django_geo_db_zipcode" VALUES(5794,15088,-5,'West Elizabeth, Pennsylvania 15088',4270,5306);
INSERT INTO "django_geo_db_zipcode" VALUES(5795,15089,-5,'West Newton, Pennsylvania 15089',4271,5307);
INSERT INTO "django_geo_db_zipcode" VALUES(5796,15090,-5,'Wexford, Pennsylvania 15090',4272,5308);
INSERT INTO "django_geo_db_zipcode" VALUES(5797,15091,-5,'Wildwood, Pennsylvania 15091',4273,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5798,15095,-5,'Warrendale, Pennsylvania 15095',4268,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5799,15096,-5,'Warrendale, Pennsylvania 15096',4268,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5800,15101,-5,'Allison Park, Pennsylvania 15101',4274,5309);
INSERT INTO "django_geo_db_zipcode" VALUES(5801,15102,-5,'Bethel Park, Pennsylvania 15102',4275,5310);
INSERT INTO "django_geo_db_zipcode" VALUES(5802,15104,-5,'Braddock, Pennsylvania 15104',4276,5311);
INSERT INTO "django_geo_db_zipcode" VALUES(5803,15106,-5,'Carnegie, Pennsylvania 15106',4277,5312);
INSERT INTO "django_geo_db_zipcode" VALUES(5804,15108,-5,'Coraopolis, Pennsylvania 15108',4278,5313);
INSERT INTO "django_geo_db_zipcode" VALUES(5805,15110,-5,'Duquesne, Pennsylvania 15110',4279,5314);
INSERT INTO "django_geo_db_zipcode" VALUES(5806,15112,-5,'East Pittsburgh, Pennsylvania 15112',4280,5315);
INSERT INTO "django_geo_db_zipcode" VALUES(5807,15116,-5,'Glenshaw, Pennsylvania 15116',4281,5316);
INSERT INTO "django_geo_db_zipcode" VALUES(5808,15120,-5,'Homestead, Pennsylvania 15120',4282,5317);
INSERT INTO "django_geo_db_zipcode" VALUES(5809,15122,-5,'West Mifflin, Pennsylvania 15122',4283,5318);
INSERT INTO "django_geo_db_zipcode" VALUES(5810,15123,-5,'West Mifflin, Pennsylvania 15123',4283,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5811,15126,-5,'Imperial, Pennsylvania 15126',4284,5319);
INSERT INTO "django_geo_db_zipcode" VALUES(5812,15127,-5,'Ingomar, Pennsylvania 15127',4285,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5813,15129,-5,'Library, Pennsylvania 15129',4286,5320);
INSERT INTO "django_geo_db_zipcode" VALUES(5814,15130,-5,'McKeesport, Pennsylvania 15130',4287,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5815,15131,-5,'McKeesport, Pennsylvania 15131',4287,5321);
INSERT INTO "django_geo_db_zipcode" VALUES(5816,15132,-5,'McKeesport, Pennsylvania 15132',4287,5322);
INSERT INTO "django_geo_db_zipcode" VALUES(5817,15133,-5,'McKeesport, Pennsylvania 15133',4287,5323);
INSERT INTO "django_geo_db_zipcode" VALUES(5818,15134,-5,'McKeesport, Pennsylvania 15134',4287,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5819,15135,-5,'McKeesport, Pennsylvania 15135',4287,5324);
INSERT INTO "django_geo_db_zipcode" VALUES(5820,15136,-5,'McKees Rocks, Pennsylvania 15136',4288,5325);
INSERT INTO "django_geo_db_zipcode" VALUES(5821,15137,-5,'North Versailles, Pennsylvania 15137',4289,5326);
INSERT INTO "django_geo_db_zipcode" VALUES(5822,15139,-5,'Oakmont, Pennsylvania 15139',4290,5327);
INSERT INTO "django_geo_db_zipcode" VALUES(5823,15140,-5,'Pitcairn, Pennsylvania 15140',4291,5328);
INSERT INTO "django_geo_db_zipcode" VALUES(5824,15142,-5,'Presto, Pennsylvania 15142',4292,5329);
INSERT INTO "django_geo_db_zipcode" VALUES(5825,15143,-5,'Sewickley, Pennsylvania 15143',4293,5330);
INSERT INTO "django_geo_db_zipcode" VALUES(5826,15144,-5,'Springdale, Pennsylvania 15144',4294,5331);
INSERT INTO "django_geo_db_zipcode" VALUES(5827,15145,-5,'Turtle Creek, Pennsylvania 15145',4295,5332);
INSERT INTO "django_geo_db_zipcode" VALUES(5828,15146,-5,'Monroeville, Pennsylvania 15146',4296,5333);
INSERT INTO "django_geo_db_zipcode" VALUES(5829,15147,-5,'Verona, Pennsylvania 15147',4297,5334);
INSERT INTO "django_geo_db_zipcode" VALUES(5830,15148,-5,'Wilmerding, Pennsylvania 15148',4298,5335);
INSERT INTO "django_geo_db_zipcode" VALUES(5831,15163,-5,'North Apollo, Pennsylvania 15163',4299,5336);
INSERT INTO "django_geo_db_zipcode" VALUES(5832,15189,-5,'Sewickley, Pennsylvania 15189',4293,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5833,15201,-5,'Pittsburgh, Pennsylvania 15201',4300,5337);
INSERT INTO "django_geo_db_zipcode" VALUES(5834,15202,-5,'Pittsburgh, Pennsylvania 15202',4300,5338);
INSERT INTO "django_geo_db_zipcode" VALUES(5835,15203,-5,'Pittsburgh, Pennsylvania 15203',4300,5339);
INSERT INTO "django_geo_db_zipcode" VALUES(5836,15204,-5,'Pittsburgh, Pennsylvania 15204',4300,5340);
INSERT INTO "django_geo_db_zipcode" VALUES(5837,15205,-5,'Pittsburgh, Pennsylvania 15205',4300,5341);
INSERT INTO "django_geo_db_zipcode" VALUES(5838,15206,-5,'Pittsburgh, Pennsylvania 15206',4300,5342);
INSERT INTO "django_geo_db_zipcode" VALUES(5839,15207,-5,'Pittsburgh, Pennsylvania 15207',4300,5343);
INSERT INTO "django_geo_db_zipcode" VALUES(5840,15208,-5,'Pittsburgh, Pennsylvania 15208',4300,5344);
INSERT INTO "django_geo_db_zipcode" VALUES(5841,15209,-5,'Pittsburgh, Pennsylvania 15209',4300,5345);
INSERT INTO "django_geo_db_zipcode" VALUES(5842,15210,-5,'Pittsburgh, Pennsylvania 15210',4300,5346);
INSERT INTO "django_geo_db_zipcode" VALUES(5843,15211,-5,'Pittsburgh, Pennsylvania 15211',4300,5347);
INSERT INTO "django_geo_db_zipcode" VALUES(5844,15212,-5,'Pittsburgh, Pennsylvania 15212',4300,5348);
INSERT INTO "django_geo_db_zipcode" VALUES(5845,15213,-5,'Pittsburgh, Pennsylvania 15213',4300,5349);
INSERT INTO "django_geo_db_zipcode" VALUES(5846,15214,-5,'Pittsburgh, Pennsylvania 15214',4300,5350);
INSERT INTO "django_geo_db_zipcode" VALUES(5847,15215,-5,'Pittsburgh, Pennsylvania 15215',4300,5351);
INSERT INTO "django_geo_db_zipcode" VALUES(5848,15216,-5,'Pittsburgh, Pennsylvania 15216',4300,5352);
INSERT INTO "django_geo_db_zipcode" VALUES(5849,15217,-5,'Pittsburgh, Pennsylvania 15217',4300,5353);
INSERT INTO "django_geo_db_zipcode" VALUES(5850,15218,-5,'Pittsburgh, Pennsylvania 15218',4300,5354);
INSERT INTO "django_geo_db_zipcode" VALUES(5851,15219,-5,'Pittsburgh, Pennsylvania 15219',4300,5355);
INSERT INTO "django_geo_db_zipcode" VALUES(5852,15220,-5,'Pittsburgh, Pennsylvania 15220',4300,5356);
INSERT INTO "django_geo_db_zipcode" VALUES(5853,15221,-5,'Pittsburgh, Pennsylvania 15221',4300,5357);
INSERT INTO "django_geo_db_zipcode" VALUES(5854,15222,-5,'Pittsburgh, Pennsylvania 15222',4300,5358);
INSERT INTO "django_geo_db_zipcode" VALUES(5855,15223,-5,'Pittsburgh, Pennsylvania 15223',4300,5359);
INSERT INTO "django_geo_db_zipcode" VALUES(5856,15224,-5,'Pittsburgh, Pennsylvania 15224',4300,5360);
INSERT INTO "django_geo_db_zipcode" VALUES(5857,15225,-5,'Pittsburgh, Pennsylvania 15225',4300,5361);
INSERT INTO "django_geo_db_zipcode" VALUES(5858,15226,-5,'Pittsburgh, Pennsylvania 15226',4300,5362);
INSERT INTO "django_geo_db_zipcode" VALUES(5859,15227,-5,'Pittsburgh, Pennsylvania 15227',4300,5363);
INSERT INTO "django_geo_db_zipcode" VALUES(5860,15228,-5,'Pittsburgh, Pennsylvania 15228',4300,5364);
INSERT INTO "django_geo_db_zipcode" VALUES(5861,15229,-5,'Pittsburgh, Pennsylvania 15229',4300,5365);
INSERT INTO "django_geo_db_zipcode" VALUES(5862,15230,-5,'Pittsburgh, Pennsylvania 15230',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5863,15231,-5,'Pittsburgh, Pennsylvania 15231',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5864,15232,-5,'Pittsburgh, Pennsylvania 15232',4300,5366);
INSERT INTO "django_geo_db_zipcode" VALUES(5865,15233,-5,'Pittsburgh, Pennsylvania 15233',4300,5367);
INSERT INTO "django_geo_db_zipcode" VALUES(5866,15234,-5,'Pittsburgh, Pennsylvania 15234',4300,5368);
INSERT INTO "django_geo_db_zipcode" VALUES(5867,15235,-5,'Pittsburgh, Pennsylvania 15235',4300,5369);
INSERT INTO "django_geo_db_zipcode" VALUES(5868,15236,-5,'Pittsburgh, Pennsylvania 15236',4300,5370);
INSERT INTO "django_geo_db_zipcode" VALUES(5869,15237,-5,'Pittsburgh, Pennsylvania 15237',4300,5371);
INSERT INTO "django_geo_db_zipcode" VALUES(5870,15238,-5,'Pittsburgh, Pennsylvania 15238',4300,5372);
INSERT INTO "django_geo_db_zipcode" VALUES(5871,15239,-5,'Pittsburgh, Pennsylvania 15239',4300,5373);
INSERT INTO "django_geo_db_zipcode" VALUES(5872,15240,-5,'Pittsburgh, Pennsylvania 15240',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5873,15241,-5,'Pittsburgh, Pennsylvania 15241',4300,5374);
INSERT INTO "django_geo_db_zipcode" VALUES(5874,15242,-5,'Pittsburgh, Pennsylvania 15242',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5875,15243,-5,'Pittsburgh, Pennsylvania 15243',4300,5375);
INSERT INTO "django_geo_db_zipcode" VALUES(5876,15244,-5,'Pittsburgh, Pennsylvania 15244',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5877,15246,-5,'Pittsburgh, Pennsylvania 15246',4300,5376);
INSERT INTO "django_geo_db_zipcode" VALUES(5878,15250,-5,'Pittsburgh, Pennsylvania 15250',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5879,15251,-5,'Pittsburgh, Pennsylvania 15251',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5880,15252,-5,'Pittsburgh, Pennsylvania 15252',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5881,15253,-5,'Pittsburgh, Pennsylvania 15253',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5882,15254,-5,'Pittsburgh, Pennsylvania 15254',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5883,15255,-5,'Pittsburgh, Pennsylvania 15255',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5884,15257,-5,'Pittsburgh, Pennsylvania 15257',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5885,15258,-5,'Pittsburgh, Pennsylvania 15258',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5886,15259,-5,'Pittsburgh, Pennsylvania 15259',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5887,15260,-5,'Pittsburgh, Pennsylvania 15260',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5888,15261,-5,'Pittsburgh, Pennsylvania 15261',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5889,15262,-5,'Pittsburgh, Pennsylvania 15262',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5890,15263,-5,'Pittsburgh, Pennsylvania 15263',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5891,15264,-5,'Pittsburgh, Pennsylvania 15264',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5892,15265,-5,'Pittsburgh, Pennsylvania 15265',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5893,15266,-5,'Pittsburgh, Pennsylvania 15266',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5894,15267,-5,'Pittsburgh, Pennsylvania 15267',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5895,15268,-5,'Pittsburgh, Pennsylvania 15268',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5896,15270,-5,'Pittsburgh, Pennsylvania 15270',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5897,15272,-5,'Pittsburgh, Pennsylvania 15272',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5898,15274,-5,'Pittsburgh, Pennsylvania 15274',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5899,15275,-5,'Pittsburgh, Pennsylvania 15275',4300,5377);
INSERT INTO "django_geo_db_zipcode" VALUES(5900,15276,-5,'Pittsburgh, Pennsylvania 15276',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5901,15277,-5,'Pittsburgh, Pennsylvania 15277',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5902,15278,-5,'Pittsburgh, Pennsylvania 15278',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5903,15279,-5,'Pittsburgh, Pennsylvania 15279',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5904,15281,-5,'Pittsburgh, Pennsylvania 15281',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5905,15282,-5,'Pittsburgh, Pennsylvania 15282',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5906,15283,-5,'Pittsburgh, Pennsylvania 15283',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5907,15285,-5,'Pittsburgh, Pennsylvania 15285',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5908,15286,-5,'Pittsburgh, Pennsylvania 15286',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5909,15290,-5,'Pittsburgh, Pennsylvania 15290',4300,5260);
INSERT INTO "django_geo_db_zipcode" VALUES(5910,15298,-5,'Pittsburgh, Pennsylvania 15298',4300,5378);
INSERT INTO "django_geo_db_zipcode" VALUES(5911,15301,-5,'Washington, Pennsylvania 15301',4301,5379);
INSERT INTO "django_geo_db_zipcode" VALUES(5912,15310,-5,'Aleppo, Pennsylvania 15310',4302,5380);
INSERT INTO "django_geo_db_zipcode" VALUES(5913,15311,-5,'Amity, Pennsylvania 15311',4303,5381);
INSERT INTO "django_geo_db_zipcode" VALUES(5914,15312,-5,'Avella, Pennsylvania 15312',4304,5382);
INSERT INTO "django_geo_db_zipcode" VALUES(5915,15313,-5,'Beallsville, Pennsylvania 15313',4305,5383);
INSERT INTO "django_geo_db_zipcode" VALUES(5916,15314,-5,'Bentleyville, Pennsylvania 15314',4306,5384);
INSERT INTO "django_geo_db_zipcode" VALUES(5917,15315,-5,'Bobtown, Pennsylvania 15315',4307,5385);
INSERT INTO "django_geo_db_zipcode" VALUES(5918,15316,-5,'Brave, Pennsylvania 15316',4308,5386);
INSERT INTO "django_geo_db_zipcode" VALUES(5919,15317,-5,'Canonsburg, Pennsylvania 15317',4309,5387);
INSERT INTO "django_geo_db_zipcode" VALUES(5920,15320,-5,'Carmichaels, Pennsylvania 15320',4310,5388);
INSERT INTO "django_geo_db_zipcode" VALUES(5921,15321,-5,'Cecil, Pennsylvania 15321',4311,5389);
INSERT INTO "django_geo_db_zipcode" VALUES(5922,15322,-5,'Clarksville, Pennsylvania 15322',4312,5390);
INSERT INTO "django_geo_db_zipcode" VALUES(5923,15323,-5,'Claysville, Pennsylvania 15323',4313,5391);
INSERT INTO "django_geo_db_zipcode" VALUES(5924,15324,-5,'Cokeburg, Pennsylvania 15324',4314,5392);
INSERT INTO "django_geo_db_zipcode" VALUES(5925,15325,-5,'Crucible, Pennsylvania 15325',4315,5393);
INSERT INTO "django_geo_db_zipcode" VALUES(5926,15327,-5,'Dilliner, Pennsylvania 15327',4316,5394);
INSERT INTO "django_geo_db_zipcode" VALUES(5927,15329,-5,'Prosperity, Pennsylvania 15329',4317,5395);
INSERT INTO "django_geo_db_zipcode" VALUES(5928,15330,-5,'Eighty Four, Pennsylvania 15330',4318,5396);
INSERT INTO "django_geo_db_zipcode" VALUES(5929,15331,-5,'Ellsworth, Pennsylvania 15331',4319,5397);
INSERT INTO "django_geo_db_zipcode" VALUES(5930,15332,-5,'Finleyville, Pennsylvania 15332',4320,5398);
INSERT INTO "django_geo_db_zipcode" VALUES(5931,15333,-5,'Fredericktown, Pennsylvania 15333',4321,5399);
INSERT INTO "django_geo_db_zipcode" VALUES(5932,15334,-5,'Garards Fort, Pennsylvania 15334',4322,5400);
INSERT INTO "django_geo_db_zipcode" VALUES(5933,15336,-5,'Gastonville, Pennsylvania 15336',4323,5401);
INSERT INTO "django_geo_db_zipcode" VALUES(5934,15337,-5,'Graysville, Pennsylvania 15337',4324,5402);
INSERT INTO "django_geo_db_zipcode" VALUES(5935,15338,-5,'Greensboro, Pennsylvania 15338',4325,5403);
INSERT INTO "django_geo_db_zipcode" VALUES(5936,15339,-5,'Hendersonville, Pennsylvania 15339',4326,5404);
INSERT INTO "django_geo_db_zipcode" VALUES(5937,15340,-5,'Hickory, Pennsylvania 15340',4327,5405);
INSERT INTO "django_geo_db_zipcode" VALUES(5938,15341,-5,'Holbrook, Pennsylvania 15341',4328,5406);
INSERT INTO "django_geo_db_zipcode" VALUES(5939,15342,-5,'Houston, Pennsylvania 15342',4329,5407);
INSERT INTO "django_geo_db_zipcode" VALUES(5940,15344,-5,'Jefferson, Pennsylvania 15344',4330,5408);
INSERT INTO "django_geo_db_zipcode" VALUES(5941,15345,-5,'Marianna, Pennsylvania 15345',4331,5409);
INSERT INTO "django_geo_db_zipcode" VALUES(5942,15346,-5,'Mather, Pennsylvania 15346',4332,5410);
INSERT INTO "django_geo_db_zipcode" VALUES(5943,15347,-5,'Meadow Lands, Pennsylvania 15347',4333,5411);
INSERT INTO "django_geo_db_zipcode" VALUES(5944,15348,-5,'Millsboro, Pennsylvania 15348',4334,5412);
INSERT INTO "django_geo_db_zipcode" VALUES(5945,15349,-5,'Mount Morris, Pennsylvania 15349',4335,5413);
INSERT INTO "django_geo_db_zipcode" VALUES(5946,15350,-5,'Muse, Pennsylvania 15350',4336,5414);
INSERT INTO "django_geo_db_zipcode" VALUES(5947,15351,-5,'Nemacolin, Pennsylvania 15351',4337,5415);
INSERT INTO "django_geo_db_zipcode" VALUES(5948,15352,-5,'New Freeport, Pennsylvania 15352',4338,5416);
INSERT INTO "django_geo_db_zipcode" VALUES(5949,15353,-5,'Nineveh, Pennsylvania 15353',4339,5417);
INSERT INTO "django_geo_db_zipcode" VALUES(5950,15354,-5,'Pine Bank, Pennsylvania 15354',4340,5418);
INSERT INTO "django_geo_db_zipcode" VALUES(5951,15355,-5,'Centerville, Pennsylvania 15355',4341,5419);
INSERT INTO "django_geo_db_zipcode" VALUES(5952,15357,-5,'Rices Landing, Pennsylvania 15357',4342,5420);
INSERT INTO "django_geo_db_zipcode" VALUES(5953,15358,-5,'Richeyville, Pennsylvania 15358',4343,5421);
INSERT INTO "django_geo_db_zipcode" VALUES(5954,15359,-5,'Rogersville, Pennsylvania 15359',4344,5422);
INSERT INTO "django_geo_db_zipcode" VALUES(5955,15360,-5,'Scenery Hill, Pennsylvania 15360',4345,5423);
INSERT INTO "django_geo_db_zipcode" VALUES(5956,15361,-5,'Southview, Pennsylvania 15361',4346,5424);
INSERT INTO "django_geo_db_zipcode" VALUES(5957,15362,-5,'Spraggs, Pennsylvania 15362',4347,5425);
INSERT INTO "django_geo_db_zipcode" VALUES(5958,15363,-5,'Strabane, Pennsylvania 15363',4348,5426);
INSERT INTO "django_geo_db_zipcode" VALUES(5959,15364,-5,'Sycamore, Pennsylvania 15364',4349,5427);
INSERT INTO "django_geo_db_zipcode" VALUES(5960,15365,-5,'Taylorstown, Pennsylvania 15365',4350,5428);
INSERT INTO "django_geo_db_zipcode" VALUES(5961,15366,-5,'Van Voorhis, Pennsylvania 15366',4351,5429);
INSERT INTO "django_geo_db_zipcode" VALUES(5962,15367,-5,'Venetia, Pennsylvania 15367',4352,5430);
INSERT INTO "django_geo_db_zipcode" VALUES(5963,15368,-5,'Vestaburg, Pennsylvania 15368',4353,5431);
INSERT INTO "django_geo_db_zipcode" VALUES(5964,15370,-5,'Waynesburg, Pennsylvania 15370',4354,5432);
INSERT INTO "django_geo_db_zipcode" VALUES(5965,15376,-5,'West Alexander, Pennsylvania 15376',4355,5433);
INSERT INTO "django_geo_db_zipcode" VALUES(5966,15377,-5,'West Finley, Pennsylvania 15377',4356,5434);
INSERT INTO "django_geo_db_zipcode" VALUES(5967,15378,-5,'Westland, Pennsylvania 15378',4357,5435);
INSERT INTO "django_geo_db_zipcode" VALUES(5968,15379,-5,'West Middletown, Pennsylvania 15379',4358,5436);
INSERT INTO "django_geo_db_zipcode" VALUES(5969,15380,-5,'Wind Ridge, Pennsylvania 15380',4359,5437);
INSERT INTO "django_geo_db_zipcode" VALUES(5970,15401,-5,'Uniontown, Pennsylvania 15401',4360,5438);
INSERT INTO "django_geo_db_zipcode" VALUES(5971,15410,-5,'Adah, Pennsylvania 15410',4361,5439);
INSERT INTO "django_geo_db_zipcode" VALUES(5972,15411,-5,'Addison, Pennsylvania 15411',4362,5440);
INSERT INTO "django_geo_db_zipcode" VALUES(5973,15412,-5,'Allenport, Pennsylvania 15412',4363,5441);
INSERT INTO "django_geo_db_zipcode" VALUES(5974,15413,-5,'Allison, Pennsylvania 15413',4364,5442);
INSERT INTO "django_geo_db_zipcode" VALUES(5975,15415,-5,'Brier Hill, Pennsylvania 15415',4365,5443);
INSERT INTO "django_geo_db_zipcode" VALUES(5976,15416,-5,'Brownfield, Pennsylvania 15416',4366,5444);
INSERT INTO "django_geo_db_zipcode" VALUES(5977,15417,-5,'Brownsville, Pennsylvania 15417',4367,5445);
INSERT INTO "django_geo_db_zipcode" VALUES(5978,15419,-5,'California, Pennsylvania 15419',4368,5446);
INSERT INTO "django_geo_db_zipcode" VALUES(5979,15420,-5,'Cardale, Pennsylvania 15420',4369,5447);
INSERT INTO "django_geo_db_zipcode" VALUES(5980,15421,-5,'Chalk Hill, Pennsylvania 15421',4370,5448);
INSERT INTO "django_geo_db_zipcode" VALUES(5981,15422,-5,'Chestnut Ridge, Pennsylvania 15422',4371,5449);
INSERT INTO "django_geo_db_zipcode" VALUES(5982,15423,-5,'Coal Center, Pennsylvania 15423',4372,5450);
INSERT INTO "django_geo_db_zipcode" VALUES(5983,15424,-5,'Confluence, Pennsylvania 15424',4373,5451);
INSERT INTO "django_geo_db_zipcode" VALUES(5984,15425,-5,'Connellsville, Pennsylvania 15425',4374,5452);
INSERT INTO "django_geo_db_zipcode" VALUES(5985,15427,-5,'Daisytown, Pennsylvania 15427',4375,5453);
INSERT INTO "django_geo_db_zipcode" VALUES(5986,15428,-5,'Dawson, Pennsylvania 15428',4376,5454);
INSERT INTO "django_geo_db_zipcode" VALUES(5987,15429,-5,'Denbo, Pennsylvania 15429',4377,5455);
INSERT INTO "django_geo_db_zipcode" VALUES(5988,15430,-5,'Dickerson Run, Pennsylvania 15430',4378,5456);
INSERT INTO "django_geo_db_zipcode" VALUES(5989,15431,-5,'Dunbar, Pennsylvania 15431',4379,5457);
INSERT INTO "django_geo_db_zipcode" VALUES(5990,15432,-5,'Dunlevy, Pennsylvania 15432',4380,5458);
INSERT INTO "django_geo_db_zipcode" VALUES(5991,15433,-5,'East Millsboro, Pennsylvania 15433',4381,5459);
INSERT INTO "django_geo_db_zipcode" VALUES(5992,15434,-5,'Elco, Pennsylvania 15434',4382,5460);
INSERT INTO "django_geo_db_zipcode" VALUES(5993,15435,-5,'Fairbank, Pennsylvania 15435',4383,5461);
INSERT INTO "django_geo_db_zipcode" VALUES(5994,15436,-5,'Fairchance, Pennsylvania 15436',4384,5462);
INSERT INTO "django_geo_db_zipcode" VALUES(5995,15437,-5,'Farmington, Pennsylvania 15437',4385,5463);
INSERT INTO "django_geo_db_zipcode" VALUES(5996,15438,-5,'Fayette City, Pennsylvania 15438',4386,5464);
INSERT INTO "django_geo_db_zipcode" VALUES(5997,15439,-5,'Gans, Pennsylvania 15439',4387,5465);
INSERT INTO "django_geo_db_zipcode" VALUES(5998,15440,-5,'Gibbon Glade, Pennsylvania 15440',4388,5466);
INSERT INTO "django_geo_db_zipcode" VALUES(5999,15442,-5,'Grindstone, Pennsylvania 15442',4389,5467);
INSERT INTO "django_geo_db_zipcode" VALUES(6000,15443,-5,'Hibbs, Pennsylvania 15443',4390,5468);
INSERT INTO "django_geo_db_zipcode" VALUES(6001,15444,-5,'Hiller, Pennsylvania 15444',4391,5469);
INSERT INTO "django_geo_db_zipcode" VALUES(6002,15445,-5,'Hopwood, Pennsylvania 15445',4392,5470);
INSERT INTO "django_geo_db_zipcode" VALUES(6003,15446,-5,'Indian Head, Pennsylvania 15446',4393,5471);
INSERT INTO "django_geo_db_zipcode" VALUES(6004,15447,-5,'Isabella, Pennsylvania 15447',4394,5472);
INSERT INTO "django_geo_db_zipcode" VALUES(6005,15448,-5,'Jacobs Creek, Pennsylvania 15448',4395,5473);
INSERT INTO "django_geo_db_zipcode" VALUES(6006,15449,-5,'Keisterville, Pennsylvania 15449',4396,5474);
INSERT INTO "django_geo_db_zipcode" VALUES(6007,15450,-5,'La Belle, Pennsylvania 15450',4397,5475);
INSERT INTO "django_geo_db_zipcode" VALUES(6008,15451,-5,'Lake Lynn, Pennsylvania 15451',4398,5476);
INSERT INTO "django_geo_db_zipcode" VALUES(6009,15454,-5,'Leckrone, Pennsylvania 15454',4399,5477);
INSERT INTO "django_geo_db_zipcode" VALUES(6010,15455,-5,'Leisenring, Pennsylvania 15455',4400,5478);
INSERT INTO "django_geo_db_zipcode" VALUES(6011,15456,-5,'Lemont Furnace, Pennsylvania 15456',4401,5479);
INSERT INTO "django_geo_db_zipcode" VALUES(6012,15458,-5,'McClellandtown, Pennsylvania 15458',4402,5480);
INSERT INTO "django_geo_db_zipcode" VALUES(6013,15459,-5,'Markleysburg, Pennsylvania 15459',4403,5481);
INSERT INTO "django_geo_db_zipcode" VALUES(6014,15460,-5,'Martin, Pennsylvania 15460',4404,5482);
INSERT INTO "django_geo_db_zipcode" VALUES(6015,15461,-5,'Masontown, Pennsylvania 15461',4405,5483);
INSERT INTO "django_geo_db_zipcode" VALUES(6016,15462,-5,'Melcroft, Pennsylvania 15462',4406,5484);
INSERT INTO "django_geo_db_zipcode" VALUES(6017,15463,-5,'Merrittstown, Pennsylvania 15463',4407,5485);
INSERT INTO "django_geo_db_zipcode" VALUES(6018,15464,-5,'Mill Run, Pennsylvania 15464',4408,5486);
INSERT INTO "django_geo_db_zipcode" VALUES(6019,15465,-5,'Mount Braddock, Pennsylvania 15465',4409,5444);
INSERT INTO "django_geo_db_zipcode" VALUES(6020,15466,-5,'Newell, Pennsylvania 15466',4410,5487);
INSERT INTO "django_geo_db_zipcode" VALUES(6021,15467,-5,'New Geneva, Pennsylvania 15467',4411,5444);
INSERT INTO "django_geo_db_zipcode" VALUES(6022,15468,-5,'New Salem, Pennsylvania 15468',4412,5488);
INSERT INTO "django_geo_db_zipcode" VALUES(6023,15469,-5,'Normalville, Pennsylvania 15469',4413,5489);
INSERT INTO "django_geo_db_zipcode" VALUES(6024,15470,-5,'Ohiopyle, Pennsylvania 15470',4414,5490);
INSERT INTO "django_geo_db_zipcode" VALUES(6025,15471,-5,'German, Pennsylvania 15471',4415,5491);
INSERT INTO "django_geo_db_zipcode" VALUES(6026,15472,-5,'Oliver, Pennsylvania 15472',4416,5492);
INSERT INTO "django_geo_db_zipcode" VALUES(6027,15473,-5,'Perryopolis, Pennsylvania 15473',4417,5493);
INSERT INTO "django_geo_db_zipcode" VALUES(6028,15474,-5,'Point Marion, Pennsylvania 15474',4418,5494);
INSERT INTO "django_geo_db_zipcode" VALUES(6029,15475,-5,'Republic, Pennsylvania 15475',4419,5495);
INSERT INTO "django_geo_db_zipcode" VALUES(6030,15476,-5,'Ronco, Pennsylvania 15476',4420,5496);
INSERT INTO "django_geo_db_zipcode" VALUES(6031,15477,-5,'Roscoe, Pennsylvania 15477',4421,5497);
INSERT INTO "django_geo_db_zipcode" VALUES(6032,15478,-5,'Smithfield, Pennsylvania 15478',4422,5498);
INSERT INTO "django_geo_db_zipcode" VALUES(6033,15479,-5,'Smithton, Pennsylvania 15479',4423,5499);
INSERT INTO "django_geo_db_zipcode" VALUES(6034,15480,-5,'Smock, Pennsylvania 15480',4424,5500);
INSERT INTO "django_geo_db_zipcode" VALUES(6035,15482,-5,'Star Junction, Pennsylvania 15482',4425,5501);
INSERT INTO "django_geo_db_zipcode" VALUES(6036,15483,-5,'Stockdale, Pennsylvania 15483',4426,5502);
INSERT INTO "django_geo_db_zipcode" VALUES(6037,15484,-5,'Uledi, Pennsylvania 15484',4427,5503);
INSERT INTO "django_geo_db_zipcode" VALUES(6038,15485,-5,'Ursina, Pennsylvania 15485',4428,5504);
INSERT INTO "django_geo_db_zipcode" VALUES(6039,15486,-5,'Vanderbilt, Pennsylvania 15486',4429,5505);
INSERT INTO "django_geo_db_zipcode" VALUES(6040,15488,-5,'Waltersburg, Pennsylvania 15488',4430,5506);
INSERT INTO "django_geo_db_zipcode" VALUES(6041,15489,-5,'West Leisenring, Pennsylvania 15489',4431,5507);
INSERT INTO "django_geo_db_zipcode" VALUES(6042,15490,-5,'White, Pennsylvania 15490',4432,5508);
INSERT INTO "django_geo_db_zipcode" VALUES(6043,15492,-5,'Wickhaven, Pennsylvania 15492',4433,5509);
INSERT INTO "django_geo_db_zipcode" VALUES(6044,15493,-5,'Perry, Pennsylvania 15493',4434,5510);
INSERT INTO "django_geo_db_zipcode" VALUES(6045,15501,-5,'Somerset, Pennsylvania 15501',4435,5511);
INSERT INTO "django_geo_db_zipcode" VALUES(6046,15502,-5,'Hidden Valley, Pennsylvania 15502',4436,5512);
INSERT INTO "django_geo_db_zipcode" VALUES(6047,15510,-5,'Somerset, Pennsylvania 15510',4435,5513);
INSERT INTO "django_geo_db_zipcode" VALUES(6048,15520,-5,'Acosta, Pennsylvania 15520',4437,5514);
INSERT INTO "django_geo_db_zipcode" VALUES(6049,15521,-5,'Alum Bank, Pennsylvania 15521',4438,5515);
INSERT INTO "django_geo_db_zipcode" VALUES(6050,15522,-5,'Bedford, Pennsylvania 15522',4439,5516);
INSERT INTO "django_geo_db_zipcode" VALUES(6051,15530,-5,'Berlin, Pennsylvania 15530',4440,5517);
INSERT INTO "django_geo_db_zipcode" VALUES(6052,15531,-5,'Boswell, Pennsylvania 15531',4441,5518);
INSERT INTO "django_geo_db_zipcode" VALUES(6053,15532,-5,'Boynton, Pennsylvania 15532',4442,5519);
INSERT INTO "django_geo_db_zipcode" VALUES(6054,15533,-5,'Breezewood, Pennsylvania 15533',4443,5520);
INSERT INTO "django_geo_db_zipcode" VALUES(6055,15534,-5,'Buffalo Mills, Pennsylvania 15534',4444,5521);
INSERT INTO "django_geo_db_zipcode" VALUES(6056,15535,-5,'Clearville, Pennsylvania 15535',4445,5522);
INSERT INTO "django_geo_db_zipcode" VALUES(6057,15536,-5,'Crystal Spring, Pennsylvania 15536',4446,5523);
INSERT INTO "django_geo_db_zipcode" VALUES(6058,15537,-5,'Everett, Pennsylvania 15537',4447,5524);
INSERT INTO "django_geo_db_zipcode" VALUES(6059,15538,-5,'Fairhope, Pennsylvania 15538',4448,5525);
INSERT INTO "django_geo_db_zipcode" VALUES(6060,15539,-5,'Fishertown, Pennsylvania 15539',4449,5526);
INSERT INTO "django_geo_db_zipcode" VALUES(6061,15540,-5,'Fort Hill, Pennsylvania 15540',4450,5527);
INSERT INTO "django_geo_db_zipcode" VALUES(6062,15541,-5,'Friedens, Pennsylvania 15541',4451,5528);
INSERT INTO "django_geo_db_zipcode" VALUES(6063,15542,-5,'Garrett, Pennsylvania 15542',4452,5529);
INSERT INTO "django_geo_db_zipcode" VALUES(6064,15544,-5,'Gray, Pennsylvania 15544',4453,5530);
INSERT INTO "django_geo_db_zipcode" VALUES(6065,15545,-5,'Hyndman, Pennsylvania 15545',4454,5531);
INSERT INTO "django_geo_db_zipcode" VALUES(6066,15546,-5,'Jenners, Pennsylvania 15546',4455,5532);
INSERT INTO "django_geo_db_zipcode" VALUES(6067,15547,-5,'Jennerstown, Pennsylvania 15547',4456,5533);
INSERT INTO "django_geo_db_zipcode" VALUES(6068,15548,-5,'Kantner, Pennsylvania 15548',4457,5534);
INSERT INTO "django_geo_db_zipcode" VALUES(6069,15549,-5,'Listie, Pennsylvania 15549',4458,5535);
INSERT INTO "django_geo_db_zipcode" VALUES(6070,15550,-5,'Manns Choice, Pennsylvania 15550',4459,5536);
INSERT INTO "django_geo_db_zipcode" VALUES(6071,15551,-5,'Markleton, Pennsylvania 15551',4460,5537);
INSERT INTO "django_geo_db_zipcode" VALUES(6072,15552,-5,'Meyersdale, Pennsylvania 15552',4461,5538);
INSERT INTO "django_geo_db_zipcode" VALUES(6073,15553,-5,'New Baltimore, Pennsylvania 15553',4462,5539);
INSERT INTO "django_geo_db_zipcode" VALUES(6074,15554,-5,'New Paris, Pennsylvania 15554',4463,5540);
INSERT INTO "django_geo_db_zipcode" VALUES(6075,15555,-5,'Quecreek, Pennsylvania 15555',4464,5541);
INSERT INTO "django_geo_db_zipcode" VALUES(6076,15557,-5,'Rockwood, Pennsylvania 15557',4465,5542);
INSERT INTO "django_geo_db_zipcode" VALUES(6077,15558,-5,'Salisbury, Pennsylvania 15558',4466,5543);
INSERT INTO "django_geo_db_zipcode" VALUES(6078,15559,-5,'Schellsburg, Pennsylvania 15559',4467,5544);
INSERT INTO "django_geo_db_zipcode" VALUES(6079,15560,-5,'Shanksville, Pennsylvania 15560',4468,5545);
INSERT INTO "django_geo_db_zipcode" VALUES(6080,15561,-5,'Sipesville, Pennsylvania 15561',4469,5546);
INSERT INTO "django_geo_db_zipcode" VALUES(6081,15562,-5,'Springs, Pennsylvania 15562',4470,5547);
INSERT INTO "django_geo_db_zipcode" VALUES(6082,15563,-5,'Stoystown, Pennsylvania 15563',4471,5548);
INSERT INTO "django_geo_db_zipcode" VALUES(6083,15564,-5,'Wellersburg, Pennsylvania 15564',4472,5549);
INSERT INTO "django_geo_db_zipcode" VALUES(6084,15565,-5,'West Salisbury, Pennsylvania 15565',4473,5550);
INSERT INTO "django_geo_db_zipcode" VALUES(6085,15601,-5,'Greensburg, Pennsylvania 15601',4474,5551);
INSERT INTO "django_geo_db_zipcode" VALUES(6086,15605,-5,'Greensburg, Pennsylvania 15605',4474,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(6087,15606,-5,'Greensburg, Pennsylvania 15606',4474,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(6088,15610,-5,'Acme, Pennsylvania 15610',4475,5552);
INSERT INTO "django_geo_db_zipcode" VALUES(6089,15611,-5,'Adamsburg, Pennsylvania 15611',4476,5553);
INSERT INTO "django_geo_db_zipcode" VALUES(6090,15612,-5,'Alverton, Pennsylvania 15612',4477,5554);
INSERT INTO "django_geo_db_zipcode" VALUES(6091,15613,-5,'Apollo, Pennsylvania 15613',4478,5555);
INSERT INTO "django_geo_db_zipcode" VALUES(6092,15615,-5,'Ardara, Pennsylvania 15615',4479,5556);
INSERT INTO "django_geo_db_zipcode" VALUES(6093,15616,-5,'Armbrust, Pennsylvania 15616',4480,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(6094,15617,-5,'Arona, Pennsylvania 15617',4481,5557);
INSERT INTO "django_geo_db_zipcode" VALUES(6095,15618,-5,'Avonmore, Pennsylvania 15618',4482,5558);
INSERT INTO "django_geo_db_zipcode" VALUES(6096,15619,-5,'Bovard, Pennsylvania 15619',4483,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(6097,15620,-5,'Bradenville, Pennsylvania 15620',4484,5559);
INSERT INTO "django_geo_db_zipcode" VALUES(6098,15621,-5,'Calumet, Pennsylvania 15621',4485,5291);
INSERT INTO "django_geo_db_zipcode" VALUES(6099,15622,-5,'Champion, Pennsylvania 15622',4486,5560);
INSERT INTO "django_geo_db_zipcode" VALUES(6100,15623,-5,'Claridge, Pennsylvania 15623',4487,5561);
INSERT INTO "django_geo_db_zipcode" VALUES(6101,15624,-5,'Crabtree, Pennsylvania 15624',4488,5562);
INSERT INTO "django_geo_db_zipcode" VALUES(6102,15625,-5,'Darragh, Pennsylvania 15625',4489,5563);
INSERT INTO "django_geo_db_zipcode" VALUES(6103,15626,-5,'Delmont, Pennsylvania 15626',4490,5564);
INSERT INTO "django_geo_db_zipcode" VALUES(6104,15627,-5,'Derry, Pennsylvania 15627',4491,5565);
INSERT INTO "django_geo_db_zipcode" VALUES(6105,15628,-5,'Donegal, Pennsylvania 15628',4492,5566);
INSERT INTO "django_geo_db_zipcode" VALUES(6106,15629,-5,'East Vandergrift, Pennsylvania 15629',4493,5567);
INSERT INTO "django_geo_db_zipcode" VALUES(6107,15630,-5,'Edmon, Pennsylvania 15630',4494,5568);
INSERT INTO "django_geo_db_zipcode" VALUES(6108,15631,-5,'Everson, Pennsylvania 15631',4495,5569);
INSERT INTO "django_geo_db_zipcode" VALUES(6109,15632,-5,'Export, Pennsylvania 15632',4496,5570);
INSERT INTO "django_geo_db_zipcode" VALUES(6110,15633,-5,'Forbes Road, Pennsylvania 15633',4497,5571);
INSERT INTO "django_geo_db_zipcode" VALUES(6111,15634,-5,'Grapeville, Pennsylvania 15634',4498,5572);
INSERT INTO "django_geo_db_zipcode" VALUES(6112,15635,-5,'Hannastown, Pennsylvania 15635',4499,5573);
INSERT INTO "django_geo_db_zipcode" VALUES(6113,15636,-5,'Harrison City, Pennsylvania 15636',4500,5574);
INSERT INTO "django_geo_db_zipcode" VALUES(6114,15637,-5,'Herminie, Pennsylvania 15637',4501,5575);
INSERT INTO "django_geo_db_zipcode" VALUES(6115,15638,-5,'Hostetter, Pennsylvania 15638',4502,5576);
INSERT INTO "django_geo_db_zipcode" VALUES(6116,15639,-5,'Hunker, Pennsylvania 15639',4503,5577);
INSERT INTO "django_geo_db_zipcode" VALUES(6117,15640,-5,'Hutchinson, Pennsylvania 15640',4504,5578);
INSERT INTO "django_geo_db_zipcode" VALUES(6118,15641,-5,'Hyde Park, Pennsylvania 15641',4505,5579);
INSERT INTO "django_geo_db_zipcode" VALUES(6119,15642,-5,'Irwin, Pennsylvania 15642',4506,5580);
INSERT INTO "django_geo_db_zipcode" VALUES(6120,15643,-5,'Hempfield, Pennsylvania 15643',4507,5581);
INSERT INTO "django_geo_db_zipcode" VALUES(6121,15644,-5,'Jeannette, Pennsylvania 15644',4508,5582);
INSERT INTO "django_geo_db_zipcode" VALUES(6122,15646,-5,'Jones Mills, Pennsylvania 15646',4509,5583);
INSERT INTO "django_geo_db_zipcode" VALUES(6123,15647,-5,'Larimer, Pennsylvania 15647',4510,5584);
INSERT INTO "django_geo_db_zipcode" VALUES(6124,15650,-5,'Latrobe, Pennsylvania 15650',4511,5585);
INSERT INTO "django_geo_db_zipcode" VALUES(6125,15655,-5,'Laughlintown, Pennsylvania 15655',4512,5586);
INSERT INTO "django_geo_db_zipcode" VALUES(6126,15656,-5,'Leechburg, Pennsylvania 15656',4513,5587);
INSERT INTO "django_geo_db_zipcode" VALUES(6127,15658,-5,'Ligonier, Pennsylvania 15658',4514,5588);
INSERT INTO "django_geo_db_zipcode" VALUES(6128,15660,-5,'Lowber, Pennsylvania 15660',4515,5589);
INSERT INTO "django_geo_db_zipcode" VALUES(6129,15661,-5,'Loyalhanna, Pennsylvania 15661',4516,5590);
INSERT INTO "django_geo_db_zipcode" VALUES(6130,15662,-5,'Luxor, Pennsylvania 15662',4517,5591);
INSERT INTO "django_geo_db_zipcode" VALUES(6131,15663,-5,'Madison, Pennsylvania 15663',4518,5592);
INSERT INTO "django_geo_db_zipcode" VALUES(6132,15664,-5,'Mammoth, Pennsylvania 15664',4519,5593);
INSERT INTO "django_geo_db_zipcode" VALUES(6133,15665,-5,'Manor, Pennsylvania 15665',4520,5594);
INSERT INTO "django_geo_db_zipcode" VALUES(6134,15666,-5,'Mount Pleasant, Pennsylvania 15666',4521,5595);
INSERT INTO "django_geo_db_zipcode" VALUES(6135,15668,-5,'Murrysville, Pennsylvania 15668',4522,5596);
INSERT INTO "django_geo_db_zipcode" VALUES(6136,15670,-5,'New Alexandria, Pennsylvania 15670',4523,5597);
INSERT INTO "django_geo_db_zipcode" VALUES(6137,15671,-5,'New Derry, Pennsylvania 15671',4524,5598);
INSERT INTO "django_geo_db_zipcode" VALUES(6138,15672,-5,'New Stanton, Pennsylvania 15672',4525,5599);
INSERT INTO "django_geo_db_zipcode" VALUES(6139,15673,-5,'North Apollo, Pennsylvania 15673',4299,5600);
INSERT INTO "django_geo_db_zipcode" VALUES(6140,15674,-5,'Norvelt, Pennsylvania 15674',4526,5601);
INSERT INTO "django_geo_db_zipcode" VALUES(6141,15675,-5,'Penn, Pennsylvania 15675',4527,5602);
INSERT INTO "django_geo_db_zipcode" VALUES(6142,15676,-5,'Pleasant Unity, Pennsylvania 15676',4528,5603);
INSERT INTO "django_geo_db_zipcode" VALUES(6143,15677,-5,'Rector, Pennsylvania 15677',4529,5604);
INSERT INTO "django_geo_db_zipcode" VALUES(6144,15678,-5,'Rillton, Pennsylvania 15678',4530,5605);
INSERT INTO "django_geo_db_zipcode" VALUES(6145,15679,-5,'Ruffs Dale, Pennsylvania 15679',4531,5606);
INSERT INTO "django_geo_db_zipcode" VALUES(6146,15680,-5,'Salina, Pennsylvania 15680',4532,5607);
INSERT INTO "django_geo_db_zipcode" VALUES(6147,15681,-5,'Saltsburg, Pennsylvania 15681',4533,5608);
INSERT INTO "django_geo_db_zipcode" VALUES(6148,15682,-5,'Schenley, Pennsylvania 15682',4534,5568);
INSERT INTO "django_geo_db_zipcode" VALUES(6149,15683,-5,'Scottdale, Pennsylvania 15683',4535,5609);
INSERT INTO "django_geo_db_zipcode" VALUES(6150,15684,-5,'Slickville, Pennsylvania 15684',4536,5610);
INSERT INTO "django_geo_db_zipcode" VALUES(6151,15685,-5,'Southwest, Pennsylvania 15685',4537,5611);
INSERT INTO "django_geo_db_zipcode" VALUES(6152,15686,-5,'Spring Church, Pennsylvania 15686',4538,5612);
INSERT INTO "django_geo_db_zipcode" VALUES(6153,15687,-5,'Stahlstown, Pennsylvania 15687',4539,5613);
INSERT INTO "django_geo_db_zipcode" VALUES(6154,15688,-5,'Tarrs, Pennsylvania 15688',4540,5614);
INSERT INTO "django_geo_db_zipcode" VALUES(6155,15689,-5,'United, Pennsylvania 15689',4541,5615);
INSERT INTO "django_geo_db_zipcode" VALUES(6156,15690,-5,'Vandergrift, Pennsylvania 15690',4542,5616);
INSERT INTO "django_geo_db_zipcode" VALUES(6157,15691,-5,'Wendel, Pennsylvania 15691',4543,5617);
INSERT INTO "django_geo_db_zipcode" VALUES(6158,15692,-5,'Westmoreland City, Pennsylvania 15692',4544,5618);
INSERT INTO "django_geo_db_zipcode" VALUES(6159,15693,-5,'Whitney, Pennsylvania 15693',4545,5619);
INSERT INTO "django_geo_db_zipcode" VALUES(6160,15695,-5,'Wyano, Pennsylvania 15695',4546,5620);
INSERT INTO "django_geo_db_zipcode" VALUES(6161,15696,-5,'Youngstown, Pennsylvania 15696',4547,5621);
INSERT INTO "django_geo_db_zipcode" VALUES(6162,15697,-5,'Youngwood, Pennsylvania 15697',4548,5622);
INSERT INTO "django_geo_db_zipcode" VALUES(6163,15698,-5,'Yukon, Pennsylvania 15698',4549,5623);
INSERT INTO "django_geo_db_zipcode" VALUES(6164,15701,-5,'Indiana, Pennsylvania 15701',4550,5624);
INSERT INTO "django_geo_db_zipcode" VALUES(6165,15705,-5,'Indiana, Pennsylvania 15705',4550,5625);
INSERT INTO "django_geo_db_zipcode" VALUES(6166,15710,-5,'Alverda, Pennsylvania 15710',4551,5626);
INSERT INTO "django_geo_db_zipcode" VALUES(6167,15711,-5,'Anita, Pennsylvania 15711',4552,5627);
INSERT INTO "django_geo_db_zipcode" VALUES(6168,15712,-5,'Arcadia, Pennsylvania 15712',4553,5628);
INSERT INTO "django_geo_db_zipcode" VALUES(6169,15713,-5,'Aultman, Pennsylvania 15713',4554,5629);
INSERT INTO "django_geo_db_zipcode" VALUES(6170,15714,-5,'Barnesboro, Pennsylvania 15714',4555,5630);
INSERT INTO "django_geo_db_zipcode" VALUES(6171,15715,-5,'Big Run, Pennsylvania 15715',4556,5631);
INSERT INTO "django_geo_db_zipcode" VALUES(6172,15716,-5,'Black Lick, Pennsylvania 15716',4557,5632);
INSERT INTO "django_geo_db_zipcode" VALUES(6173,15717,-5,'Blairsville, Pennsylvania 15717',4558,5633);
INSERT INTO "django_geo_db_zipcode" VALUES(6174,15720,-5,'Brush Valley, Pennsylvania 15720',4559,5634);
INSERT INTO "django_geo_db_zipcode" VALUES(6175,15721,-5,'Burnside, Pennsylvania 15721',4560,5635);
INSERT INTO "django_geo_db_zipcode" VALUES(6176,15722,-5,'Carrolltown, Pennsylvania 15722',4561,5636);
INSERT INTO "django_geo_db_zipcode" VALUES(6177,15723,-5,'Chambersville, Pennsylvania 15723',4562,5637);
INSERT INTO "django_geo_db_zipcode" VALUES(6178,15724,-5,'Cherry Tree, Pennsylvania 15724',4563,5638);
INSERT INTO "django_geo_db_zipcode" VALUES(6179,15725,-5,'Clarksburg, Pennsylvania 15725',4564,5639);
INSERT INTO "django_geo_db_zipcode" VALUES(6180,15727,-5,'Clune, Pennsylvania 15727',4565,5640);
INSERT INTO "django_geo_db_zipcode" VALUES(6181,15728,-5,'Clymer, Pennsylvania 15728',4566,5641);
INSERT INTO "django_geo_db_zipcode" VALUES(6182,15729,-5,'Commodore, Pennsylvania 15729',4567,5642);
INSERT INTO "django_geo_db_zipcode" VALUES(6183,15730,-5,'Coolspring, Pennsylvania 15730',4568,5643);
INSERT INTO "django_geo_db_zipcode" VALUES(6184,15731,-5,'Coral, Pennsylvania 15731',4569,5644);
INSERT INTO "django_geo_db_zipcode" VALUES(6185,15732,-5,'Creekside, Pennsylvania 15732',4570,5645);
INSERT INTO "django_geo_db_zipcode" VALUES(6186,15733,-5,'De Lancey, Pennsylvania 15733',4571,5646);
INSERT INTO "django_geo_db_zipcode" VALUES(6187,15734,-5,'Dixonville, Pennsylvania 15734',4572,5647);
INSERT INTO "django_geo_db_zipcode" VALUES(6188,15736,-5,'Elderton, Pennsylvania 15736',4573,5648);
INSERT INTO "django_geo_db_zipcode" VALUES(6189,15737,-5,'Elmora, Pennsylvania 15737',4574,5649);
INSERT INTO "django_geo_db_zipcode" VALUES(6190,15738,-5,'Emeigh, Pennsylvania 15738',4575,5650);
INSERT INTO "django_geo_db_zipcode" VALUES(6191,15739,-5,'Ernest, Pennsylvania 15739',4576,5651);
INSERT INTO "django_geo_db_zipcode" VALUES(6192,15740,-5,'Frostburg, Pennsylvania 15740',4577,5652);
INSERT INTO "django_geo_db_zipcode" VALUES(6193,15741,-5,'Gipsy, Pennsylvania 15741',4578,5653);
INSERT INTO "django_geo_db_zipcode" VALUES(6194,15742,-5,'Glen Campbell, Pennsylvania 15742',4579,5654);
INSERT INTO "django_geo_db_zipcode" VALUES(6195,15744,-5,'Hamilton, Pennsylvania 15744',4580,5655);
INSERT INTO "django_geo_db_zipcode" VALUES(6196,15745,-5,'Heilwood, Pennsylvania 15745',4581,5656);
INSERT INTO "django_geo_db_zipcode" VALUES(6197,15746,-5,'Hillsdale, Pennsylvania 15746',4582,5657);
INSERT INTO "django_geo_db_zipcode" VALUES(6198,15747,-5,'Home, Pennsylvania 15747',4583,5658);
INSERT INTO "django_geo_db_zipcode" VALUES(6199,15748,-5,'Homer City, Pennsylvania 15748',4584,5659);
INSERT INTO "django_geo_db_zipcode" VALUES(6200,15750,-5,'Josephine, Pennsylvania 15750',4585,5660);
INSERT INTO "django_geo_db_zipcode" VALUES(6201,15751,-5,'Juneau, Pennsylvania 15751',4586,5625);
INSERT INTO "django_geo_db_zipcode" VALUES(6202,15752,-5,'Kent, Pennsylvania 15752',4587,5661);
INSERT INTO "django_geo_db_zipcode" VALUES(6203,15753,-5,'La Jose, Pennsylvania 15753',4588,5662);
INSERT INTO "django_geo_db_zipcode" VALUES(6204,15754,-5,'Lucernemines, Pennsylvania 15754',4589,5663);
INSERT INTO "django_geo_db_zipcode" VALUES(6205,15756,-5,'McIntyre, Pennsylvania 15756',4590,5664);
INSERT INTO "django_geo_db_zipcode" VALUES(6206,15757,-5,'Mahaffey, Pennsylvania 15757',4591,5665);
INSERT INTO "django_geo_db_zipcode" VALUES(6207,15758,-5,'Marchand, Pennsylvania 15758',4592,5625);
INSERT INTO "django_geo_db_zipcode" VALUES(6208,15759,-5,'Marion Center, Pennsylvania 15759',4593,5666);
INSERT INTO "django_geo_db_zipcode" VALUES(6209,15760,-5,'Marsteller, Pennsylvania 15760',4594,5667);
INSERT INTO "django_geo_db_zipcode" VALUES(6210,15761,-5,'Mentcle, Pennsylvania 15761',4595,5668);
INSERT INTO "django_geo_db_zipcode" VALUES(6211,15762,-5,'Nicktown, Pennsylvania 15762',4596,5669);
INSERT INTO "django_geo_db_zipcode" VALUES(6212,15763,-5,'Northpoint, Pennsylvania 15763',4597,5670);
INSERT INTO "django_geo_db_zipcode" VALUES(6213,15764,-5,'Oliveburg, Pennsylvania 15764',4598,5671);
INSERT INTO "django_geo_db_zipcode" VALUES(6214,15765,-5,'Penn Run, Pennsylvania 15765',4599,5672);
INSERT INTO "django_geo_db_zipcode" VALUES(6215,15767,-5,'Punxsutawney, Pennsylvania 15767',4600,5673);
INSERT INTO "django_geo_db_zipcode" VALUES(6216,15770,-5,'Ringgold, Pennsylvania 15770',4601,5674);
INSERT INTO "django_geo_db_zipcode" VALUES(6217,15771,-5,'Rochester Mills, Pennsylvania 15771',4602,5675);
INSERT INTO "django_geo_db_zipcode" VALUES(6218,15772,-5,'Rossiter, Pennsylvania 15772',4603,5676);
INSERT INTO "django_geo_db_zipcode" VALUES(6219,15773,-5,'Saint Benedict, Pennsylvania 15773',4604,5677);
INSERT INTO "django_geo_db_zipcode" VALUES(6220,15774,-5,'Shelocta, Pennsylvania 15774',4605,5678);
INSERT INTO "django_geo_db_zipcode" VALUES(6221,15775,-5,'Spangler, Pennsylvania 15775',4606,5679);
INSERT INTO "django_geo_db_zipcode" VALUES(6222,15776,-5,'Sprankle Mills, Pennsylvania 15776',4607,5680);
INSERT INTO "django_geo_db_zipcode" VALUES(6223,15777,-5,'Starford, Pennsylvania 15777',4608,5681);
INSERT INTO "django_geo_db_zipcode" VALUES(6224,15778,-5,'Timblin, Pennsylvania 15778',4609,5682);
INSERT INTO "django_geo_db_zipcode" VALUES(6225,15779,-5,'Torrance, Pennsylvania 15779',4610,5683);
INSERT INTO "django_geo_db_zipcode" VALUES(6226,15780,-5,'Valier, Pennsylvania 15780',4611,5684);
INSERT INTO "django_geo_db_zipcode" VALUES(6227,15781,-5,'Walston, Pennsylvania 15781',4612,5685);
INSERT INTO "django_geo_db_zipcode" VALUES(6228,15783,-5,'West Lebanon, Pennsylvania 15783',4613,5686);
INSERT INTO "django_geo_db_zipcode" VALUES(6229,15784,-5,'Worthville, Pennsylvania 15784',4614,5687);
INSERT INTO "django_geo_db_zipcode" VALUES(6230,15801,-5,'Du Bois, Pennsylvania 15801',4615,5688);
INSERT INTO "django_geo_db_zipcode" VALUES(6231,15817,-5,'South Fayette, Pennsylvania 15817',4616,5689);
INSERT INTO "django_geo_db_zipcode" VALUES(6232,15821,-5,'Benezett, Pennsylvania 15821',4617,5690);
INSERT INTO "django_geo_db_zipcode" VALUES(6233,15822,-5,'Brandy Camp, Pennsylvania 15822',4618,5691);
INSERT INTO "django_geo_db_zipcode" VALUES(6234,15823,-5,'Brockport, Pennsylvania 15823',4619,5692);
INSERT INTO "django_geo_db_zipcode" VALUES(6235,15824,-5,'Brockway, Pennsylvania 15824',4620,5693);
INSERT INTO "django_geo_db_zipcode" VALUES(6236,15825,-5,'Brookville, Pennsylvania 15825',4621,5694);
INSERT INTO "django_geo_db_zipcode" VALUES(6237,15827,-5,'Byrnedale, Pennsylvania 15827',4622,5695);
INSERT INTO "django_geo_db_zipcode" VALUES(6238,15828,-5,'Clarington, Pennsylvania 15828',4623,5696);
INSERT INTO "django_geo_db_zipcode" VALUES(6239,15829,-5,'Corsica, Pennsylvania 15829',4624,5697);
INSERT INTO "django_geo_db_zipcode" VALUES(6240,15831,-5,'Dagus Mines, Pennsylvania 15831',4625,5698);
INSERT INTO "django_geo_db_zipcode" VALUES(6241,15832,-5,'Driftwood, Pennsylvania 15832',4626,5699);
INSERT INTO "django_geo_db_zipcode" VALUES(6242,15834,-5,'Emporium, Pennsylvania 15834',4627,5700);
INSERT INTO "django_geo_db_zipcode" VALUES(6243,15840,-5,'Falls Creek, Pennsylvania 15840',4628,5701);
INSERT INTO "django_geo_db_zipcode" VALUES(6244,15841,-5,'Force, Pennsylvania 15841',4629,5702);
INSERT INTO "django_geo_db_zipcode" VALUES(6245,15845,-5,'Johnsonburg, Pennsylvania 15845',4630,5703);
INSERT INTO "django_geo_db_zipcode" VALUES(6246,15846,-5,'Kersey, Pennsylvania 15846',4631,5704);
INSERT INTO "django_geo_db_zipcode" VALUES(6247,15847,-5,'Knox Dale, Pennsylvania 15847',4632,5705);
INSERT INTO "django_geo_db_zipcode" VALUES(6248,15848,-5,'Luthersburg, Pennsylvania 15848',4633,5706);
INSERT INTO "django_geo_db_zipcode" VALUES(6249,15849,-5,'Penfield, Pennsylvania 15849',4634,5707);
INSERT INTO "django_geo_db_zipcode" VALUES(6250,15851,-5,'Reynoldsville, Pennsylvania 15851',4635,5708);
INSERT INTO "django_geo_db_zipcode" VALUES(6251,15853,-5,'Ridgway, Pennsylvania 15853',4636,5709);
INSERT INTO "django_geo_db_zipcode" VALUES(6252,15856,-5,'Rockton, Pennsylvania 15856',4637,5710);
INSERT INTO "django_geo_db_zipcode" VALUES(6253,15857,-5,'Saint Marys, Pennsylvania 15857',4638,5711);
INSERT INTO "django_geo_db_zipcode" VALUES(6254,15860,-5,'Sigel, Pennsylvania 15860',4639,5712);
INSERT INTO "django_geo_db_zipcode" VALUES(6255,15861,-5,'Sinnamahoning, Pennsylvania 15861',4640,5713);
INSERT INTO "django_geo_db_zipcode" VALUES(6256,15863,-5,'Stump Creek, Pennsylvania 15863',4641,5714);
INSERT INTO "django_geo_db_zipcode" VALUES(6257,15864,-5,'Summerville, Pennsylvania 15864',4642,5715);
INSERT INTO "django_geo_db_zipcode" VALUES(6258,15865,-5,'Sykesville, Pennsylvania 15865',4643,5716);
INSERT INTO "django_geo_db_zipcode" VALUES(6259,15866,-5,'Troutville, Pennsylvania 15866',4644,5717);
INSERT INTO "django_geo_db_zipcode" VALUES(6260,15868,-5,'Weedville, Pennsylvania 15868',4645,5718);
INSERT INTO "django_geo_db_zipcode" VALUES(6261,15870,-5,'Wilcox, Pennsylvania 15870',4646,5719);
INSERT INTO "django_geo_db_zipcode" VALUES(6262,15874,-5,'Worthville, Pennsylvania 15874',4614,5720);
INSERT INTO "django_geo_db_zipcode" VALUES(6263,15901,-5,'Johnstown, Pennsylvania 15901',4647,5721);
INSERT INTO "django_geo_db_zipcode" VALUES(6264,15902,-5,'Johnstown, Pennsylvania 15902',4647,5722);
INSERT INTO "django_geo_db_zipcode" VALUES(6265,15904,-5,'Johnstown, Pennsylvania 15904',4647,5723);
INSERT INTO "django_geo_db_zipcode" VALUES(6266,15905,-5,'Johnstown, Pennsylvania 15905',4647,5724);
INSERT INTO "django_geo_db_zipcode" VALUES(6267,15906,-5,'Johnstown, Pennsylvania 15906',4647,5725);
INSERT INTO "django_geo_db_zipcode" VALUES(6268,15907,-5,'Johnstown, Pennsylvania 15907',4647,5726);
INSERT INTO "django_geo_db_zipcode" VALUES(6269,15909,-5,'Johnstown, Pennsylvania 15909',4647,5727);
INSERT INTO "django_geo_db_zipcode" VALUES(6270,15915,-5,'Johnstown, Pennsylvania 15915',4647,5728);
INSERT INTO "django_geo_db_zipcode" VALUES(6271,15920,-5,'Armagh, Pennsylvania 15920',4648,5729);
INSERT INTO "django_geo_db_zipcode" VALUES(6272,15921,-5,'Beaverdale, Pennsylvania 15921',4649,5730);
INSERT INTO "django_geo_db_zipcode" VALUES(6273,15922,-5,'Belsano, Pennsylvania 15922',4650,5728);
INSERT INTO "django_geo_db_zipcode" VALUES(6274,15923,-5,'Bolivar, Pennsylvania 15923',4651,5731);
INSERT INTO "django_geo_db_zipcode" VALUES(6275,15924,-5,'Cairnbrook, Pennsylvania 15924',4652,5732);
INSERT INTO "django_geo_db_zipcode" VALUES(6276,15925,-5,'Cassandra, Pennsylvania 15925',4653,5733);
INSERT INTO "django_geo_db_zipcode" VALUES(6277,15926,-5,'Central City, Pennsylvania 15926',4654,5734);
INSERT INTO "django_geo_db_zipcode" VALUES(6278,15927,-5,'Colver, Pennsylvania 15927',4655,5735);
INSERT INTO "django_geo_db_zipcode" VALUES(6279,15928,-5,'Davidsville, Pennsylvania 15928',4656,5736);
INSERT INTO "django_geo_db_zipcode" VALUES(6280,15929,-5,'Dilltown, Pennsylvania 15929',4657,5737);
INSERT INTO "django_geo_db_zipcode" VALUES(6281,15930,-5,'Dunlo, Pennsylvania 15930',4658,5738);
INSERT INTO "django_geo_db_zipcode" VALUES(6282,15931,-5,'Ebensburg, Pennsylvania 15931',4659,5739);
INSERT INTO "django_geo_db_zipcode" VALUES(6283,15934,-5,'Elton, Pennsylvania 15934',4660,5740);
INSERT INTO "django_geo_db_zipcode" VALUES(6284,15935,-5,'Hollsopple, Pennsylvania 15935',4661,5741);
INSERT INTO "django_geo_db_zipcode" VALUES(6285,15936,-5,'Hooversville, Pennsylvania 15936',4662,5742);
INSERT INTO "django_geo_db_zipcode" VALUES(6286,15937,-5,'Jerome, Pennsylvania 15937',4663,5743);
INSERT INTO "django_geo_db_zipcode" VALUES(6287,15938,-5,'Lilly, Pennsylvania 15938',4664,5744);
INSERT INTO "django_geo_db_zipcode" VALUES(6288,15940,-5,'Loretto, Pennsylvania 15940',4665,5745);
INSERT INTO "django_geo_db_zipcode" VALUES(6289,15942,-5,'Mineral Point, Pennsylvania 15942',4666,5746);
INSERT INTO "django_geo_db_zipcode" VALUES(6290,15943,-5,'Nanty Glo, Pennsylvania 15943',4667,5747);
INSERT INTO "django_geo_db_zipcode" VALUES(6291,15944,-5,'New Florence, Pennsylvania 15944',4668,5748);
INSERT INTO "django_geo_db_zipcode" VALUES(6292,15945,-5,'Parkhill, Pennsylvania 15945',4669,5749);
INSERT INTO "django_geo_db_zipcode" VALUES(6293,15946,-5,'Portage, Pennsylvania 15946',4670,5750);
INSERT INTO "django_geo_db_zipcode" VALUES(6294,15948,-5,'Revloc, Pennsylvania 15948',4671,5751);
INSERT INTO "django_geo_db_zipcode" VALUES(6295,15949,-5,'Robinson, Pennsylvania 15949',4672,5752);
INSERT INTO "django_geo_db_zipcode" VALUES(6296,15951,-5,'Saint Michael, Pennsylvania 15951',4673,5753);
INSERT INTO "django_geo_db_zipcode" VALUES(6297,15952,-5,'Salix, Pennsylvania 15952',4674,5754);
INSERT INTO "django_geo_db_zipcode" VALUES(6298,15953,-5,'Seanor, Pennsylvania 15953',4675,5755);
INSERT INTO "django_geo_db_zipcode" VALUES(6299,15954,-5,'Seward, Pennsylvania 15954',4676,5756);
INSERT INTO "django_geo_db_zipcode" VALUES(6300,15955,-5,'Sidman, Pennsylvania 15955',4677,5757);
INSERT INTO "django_geo_db_zipcode" VALUES(6301,15956,-5,'South Fork, Pennsylvania 15956',4678,5758);
INSERT INTO "django_geo_db_zipcode" VALUES(6302,15957,-5,'Strongstown, Pennsylvania 15957',4679,5759);
INSERT INTO "django_geo_db_zipcode" VALUES(6303,15958,-5,'Summerhill, Pennsylvania 15958',4680,5760);
INSERT INTO "django_geo_db_zipcode" VALUES(6304,15959,-5,'Tire Hill, Pennsylvania 15959',4681,5761);
INSERT INTO "django_geo_db_zipcode" VALUES(6305,15960,-5,'Twin Rocks, Pennsylvania 15960',4682,5762);
INSERT INTO "django_geo_db_zipcode" VALUES(6306,15961,-5,'Vintondale, Pennsylvania 15961',4683,5763);
INSERT INTO "django_geo_db_zipcode" VALUES(6307,15962,-5,'Wilmore, Pennsylvania 15962',4684,5764);
INSERT INTO "django_geo_db_zipcode" VALUES(6308,15963,-5,'Windber, Pennsylvania 15963',4685,5765);
INSERT INTO "django_geo_db_zipcode" VALUES(6309,15965,-5,'Wilmore, Pennsylvania 15965',4684,5766);
INSERT INTO "django_geo_db_zipcode" VALUES(6310,15973,-5,'Perry, Pennsylvania 15973',4434,5767);
INSERT INTO "django_geo_db_zipcode" VALUES(6311,16001,-5,'Butler, Pennsylvania 16001',4686,5768);
INSERT INTO "django_geo_db_zipcode" VALUES(6312,16002,-5,'Butler, Pennsylvania 16002',4686,5769);
INSERT INTO "django_geo_db_zipcode" VALUES(6313,16003,-5,'Butler, Pennsylvania 16003',4686,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6314,16006,-5,'Cranberry, Pennsylvania 16006',4687,5771);
INSERT INTO "django_geo_db_zipcode" VALUES(6315,16016,-5,'Boyers, Pennsylvania 16016',4688,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6316,16017,-5,'Boyers, Pennsylvania 16017',4688,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6317,16018,-5,'Boyers, Pennsylvania 16018',4688,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6318,16020,-5,'Boyers, Pennsylvania 16020',4688,5772);
INSERT INTO "django_geo_db_zipcode" VALUES(6319,16021,-5,'Branchton, Pennsylvania 16021',4689,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6320,16022,-5,'Bruin, Pennsylvania 16022',4690,5773);
INSERT INTO "django_geo_db_zipcode" VALUES(6321,16023,-5,'Cabot, Pennsylvania 16023',4691,5774);
INSERT INTO "django_geo_db_zipcode" VALUES(6322,16024,-5,'Callery, Pennsylvania 16024',4692,5775);
INSERT INTO "django_geo_db_zipcode" VALUES(6323,16025,-5,'Chicora, Pennsylvania 16025',4693,5776);
INSERT INTO "django_geo_db_zipcode" VALUES(6324,16027,-5,'Connoquenessing, Pennsylvania 16027',4694,5777);
INSERT INTO "django_geo_db_zipcode" VALUES(6325,16028,-5,'East Brady, Pennsylvania 16028',4695,5778);
INSERT INTO "django_geo_db_zipcode" VALUES(6326,16029,-5,'East Butler, Pennsylvania 16029',4696,5779);
INSERT INTO "django_geo_db_zipcode" VALUES(6327,16030,-5,'Eau Claire, Pennsylvania 16030',4697,5780);
INSERT INTO "django_geo_db_zipcode" VALUES(6328,16033,-5,'Evans City, Pennsylvania 16033',4698,5781);
INSERT INTO "django_geo_db_zipcode" VALUES(6329,16034,-5,'Fenelton, Pennsylvania 16034',4699,5782);
INSERT INTO "django_geo_db_zipcode" VALUES(6330,16035,-5,'Forestville, Pennsylvania 16035',4700,5783);
INSERT INTO "django_geo_db_zipcode" VALUES(6331,16036,-5,'Foxburg, Pennsylvania 16036',4701,5784);
INSERT INTO "django_geo_db_zipcode" VALUES(6332,16037,-5,'Harmony, Pennsylvania 16037',4702,5785);
INSERT INTO "django_geo_db_zipcode" VALUES(6333,16038,-5,'Harrisville, Pennsylvania 16038',4703,5786);
INSERT INTO "django_geo_db_zipcode" VALUES(6334,16039,-5,'Herman, Pennsylvania 16039',4704,5770);
INSERT INTO "django_geo_db_zipcode" VALUES(6335,16040,-5,'Hilliards, Pennsylvania 16040',4705,5787);
INSERT INTO "django_geo_db_zipcode" VALUES(6336,16041,-5,'Karns City, Pennsylvania 16041',4706,5788);
INSERT INTO "django_geo_db_zipcode" VALUES(6337,16045,-5,'Lyndora, Pennsylvania 16045',4707,5789);
INSERT INTO "django_geo_db_zipcode" VALUES(6338,16046,-5,'Mars, Pennsylvania 16046',4708,5790);
INSERT INTO "django_geo_db_zipcode" VALUES(6339,16048,-5,'North Washington, Pennsylvania 16048',4709,5791);
INSERT INTO "django_geo_db_zipcode" VALUES(6340,16049,-5,'Parker, Pennsylvania 16049',4710,5792);
INSERT INTO "django_geo_db_zipcode" VALUES(6341,16050,-5,'Petrolia, Pennsylvania 16050',4711,5793);
INSERT INTO "django_geo_db_zipcode" VALUES(6342,16051,-5,'Portersville, Pennsylvania 16051',4712,5794);
INSERT INTO "django_geo_db_zipcode" VALUES(6343,16052,-5,'Prospect, Pennsylvania 16052',4713,5795);
INSERT INTO "django_geo_db_zipcode" VALUES(6344,16053,-5,'Renfrew, Pennsylvania 16053',4714,5796);
INSERT INTO "django_geo_db_zipcode" VALUES(6345,16054,-5,'Saint Petersburg, Pennsylvania 16054',4715,5797);
INSERT INTO "django_geo_db_zipcode" VALUES(6346,16055,-5,'Sarver, Pennsylvania 16055',4716,5798);
INSERT INTO "django_geo_db_zipcode" VALUES(6347,16056,-5,'Saxonburg, Pennsylvania 16056',4717,5799);
INSERT INTO "django_geo_db_zipcode" VALUES(6348,16057,-5,'Slippery Rock, Pennsylvania 16057',4718,5800);
INSERT INTO "django_geo_db_zipcode" VALUES(6349,16058,-5,'Turkey City, Pennsylvania 16058',4719,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6350,16059,-5,'Valencia, Pennsylvania 16059',4720,5802);
INSERT INTO "django_geo_db_zipcode" VALUES(6351,16061,-5,'West Sunbury, Pennsylvania 16061',4721,5803);
INSERT INTO "django_geo_db_zipcode" VALUES(6352,16063,-5,'Zelienople, Pennsylvania 16063',4722,5804);
INSERT INTO "django_geo_db_zipcode" VALUES(6353,16066,-5,'Cranberry Twp, Pennsylvania 16066',4723,5805);
INSERT INTO "django_geo_db_zipcode" VALUES(6354,16101,-5,'New Castle, Pennsylvania 16101',4724,5806);
INSERT INTO "django_geo_db_zipcode" VALUES(6355,16102,-5,'New Castle, Pennsylvania 16102',4724,5807);
INSERT INTO "django_geo_db_zipcode" VALUES(6356,16103,-5,'New Castle, Pennsylvania 16103',4724,5808);
INSERT INTO "django_geo_db_zipcode" VALUES(6357,16105,-5,'New Castle, Pennsylvania 16105',4724,5809);
INSERT INTO "django_geo_db_zipcode" VALUES(6358,16107,-5,'New Castle, Pennsylvania 16107',4724,5808);
INSERT INTO "django_geo_db_zipcode" VALUES(6359,16108,-5,'New Castle, Pennsylvania 16108',4724,5808);
INSERT INTO "django_geo_db_zipcode" VALUES(6360,16110,-5,'Adamsville, Pennsylvania 16110',4725,5810);
INSERT INTO "django_geo_db_zipcode" VALUES(6361,16111,-5,'Atlantic, Pennsylvania 16111',4726,5811);
INSERT INTO "django_geo_db_zipcode" VALUES(6362,16112,-5,'Bessemer, Pennsylvania 16112',4727,5812);
INSERT INTO "django_geo_db_zipcode" VALUES(6363,16113,-5,'Clark, Pennsylvania 16113',4728,5813);
INSERT INTO "django_geo_db_zipcode" VALUES(6364,16114,-5,'Clarks Mills, Pennsylvania 16114',4729,5814);
INSERT INTO "django_geo_db_zipcode" VALUES(6365,16115,-5,'Darlington, Pennsylvania 16115',4730,5815);
INSERT INTO "django_geo_db_zipcode" VALUES(6366,16116,-5,'Edinburg, Pennsylvania 16116',4731,5816);
INSERT INTO "django_geo_db_zipcode" VALUES(6367,16117,-5,'Ellwood City, Pennsylvania 16117',4732,5817);
INSERT INTO "django_geo_db_zipcode" VALUES(6368,16120,-5,'Enon Valley, Pennsylvania 16120',4733,5818);
INSERT INTO "django_geo_db_zipcode" VALUES(6369,16121,-5,'Farrell, Pennsylvania 16121',4734,5819);
INSERT INTO "django_geo_db_zipcode" VALUES(6370,16123,-5,'Fombell, Pennsylvania 16123',4735,5820);
INSERT INTO "django_geo_db_zipcode" VALUES(6371,16124,-5,'Fredonia, Pennsylvania 16124',4736,5821);
INSERT INTO "django_geo_db_zipcode" VALUES(6372,16125,-5,'Greenville, Pennsylvania 16125',4737,5822);
INSERT INTO "django_geo_db_zipcode" VALUES(6373,16127,-5,'Grove City, Pennsylvania 16127',4738,5823);
INSERT INTO "django_geo_db_zipcode" VALUES(6374,16130,-5,'Hadley, Pennsylvania 16130',4739,5824);
INSERT INTO "django_geo_db_zipcode" VALUES(6375,16131,-5,'Hartstown, Pennsylvania 16131',4740,5825);
INSERT INTO "django_geo_db_zipcode" VALUES(6376,16132,-5,'Hillsville, Pennsylvania 16132',4741,5826);
INSERT INTO "django_geo_db_zipcode" VALUES(6377,16133,-5,'Jackson Center, Pennsylvania 16133',4742,5827);
INSERT INTO "django_geo_db_zipcode" VALUES(6378,16134,-5,'Jamestown, Pennsylvania 16134',4743,5828);
INSERT INTO "django_geo_db_zipcode" VALUES(6379,16136,-5,'Koppel, Pennsylvania 16136',4744,5829);
INSERT INTO "django_geo_db_zipcode" VALUES(6380,16137,-5,'Mercer, Pennsylvania 16137',4745,5830);
INSERT INTO "django_geo_db_zipcode" VALUES(6381,16140,-5,'New Bedford, Pennsylvania 16140',4746,5831);
INSERT INTO "django_geo_db_zipcode" VALUES(6382,16141,-5,'New Galilee, Pennsylvania 16141',4747,5832);
INSERT INTO "django_geo_db_zipcode" VALUES(6383,16142,-5,'New Wilmington, Pennsylvania 16142',4748,5833);
INSERT INTO "django_geo_db_zipcode" VALUES(6384,16143,-5,'Pulaski, Pennsylvania 16143',4749,5834);
INSERT INTO "django_geo_db_zipcode" VALUES(6385,16145,-5,'Sandy Lake, Pennsylvania 16145',4750,5835);
INSERT INTO "django_geo_db_zipcode" VALUES(6386,16146,-5,'Sharon, Pennsylvania 16146',4751,5836);
INSERT INTO "django_geo_db_zipcode" VALUES(6387,16148,-5,'Hermitage, Pennsylvania 16148',4752,5837);
INSERT INTO "django_geo_db_zipcode" VALUES(6388,16150,-5,'Sharpsville, Pennsylvania 16150',4753,5838);
INSERT INTO "django_geo_db_zipcode" VALUES(6389,16151,-5,'Sheakleyville, Pennsylvania 16151',4754,5839);
INSERT INTO "django_geo_db_zipcode" VALUES(6390,16153,-5,'Stoneboro, Pennsylvania 16153',4755,5840);
INSERT INTO "django_geo_db_zipcode" VALUES(6391,16154,-5,'Transfer, Pennsylvania 16154',4756,5841);
INSERT INTO "django_geo_db_zipcode" VALUES(6392,16155,-5,'Villa Maria, Pennsylvania 16155',4757,5842);
INSERT INTO "django_geo_db_zipcode" VALUES(6393,16156,-5,'Volant, Pennsylvania 16156',4758,5843);
INSERT INTO "django_geo_db_zipcode" VALUES(6394,16157,-5,'Wampum, Pennsylvania 16157',4759,5844);
INSERT INTO "django_geo_db_zipcode" VALUES(6395,16159,-5,'West Middlesex, Pennsylvania 16159',4760,5845);
INSERT INTO "django_geo_db_zipcode" VALUES(6396,16160,-5,'West Pittsburg, Pennsylvania 16160',4761,5846);
INSERT INTO "django_geo_db_zipcode" VALUES(6397,16161,-5,'Wheatland, Pennsylvania 16161',4762,5847);
INSERT INTO "django_geo_db_zipcode" VALUES(6398,16172,-5,'New Wilmington, Pennsylvania 16172',4748,5848);
INSERT INTO "django_geo_db_zipcode" VALUES(6399,16201,-5,'Kittanning, Pennsylvania 16201',4763,5849);
INSERT INTO "django_geo_db_zipcode" VALUES(6400,16210,-5,'Adrian, Pennsylvania 16210',4764,5850);
INSERT INTO "django_geo_db_zipcode" VALUES(6401,16211,-5,'Beyer, Pennsylvania 16211',4765,5625);
INSERT INTO "django_geo_db_zipcode" VALUES(6402,16212,-5,'Cadogan, Pennsylvania 16212',4766,5851);
INSERT INTO "django_geo_db_zipcode" VALUES(6403,16213,-5,'Callensburg, Pennsylvania 16213',4767,5852);
INSERT INTO "django_geo_db_zipcode" VALUES(6404,16214,-5,'Clarion, Pennsylvania 16214',4768,5853);
INSERT INTO "django_geo_db_zipcode" VALUES(6405,16215,-5,'Kittanning, Pennsylvania 16215',4763,5568);
INSERT INTO "django_geo_db_zipcode" VALUES(6406,16216,-5,'Climax, Pennsylvania 16216',4769,5568);
INSERT INTO "django_geo_db_zipcode" VALUES(6407,16217,-5,'Cooksburg, Pennsylvania 16217',4770,5854);
INSERT INTO "django_geo_db_zipcode" VALUES(6408,16218,-5,'Cowansville, Pennsylvania 16218',4771,5855);
INSERT INTO "django_geo_db_zipcode" VALUES(6409,16220,-5,'Crown, Pennsylvania 16220',4772,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6410,16221,-5,'Curllsville, Pennsylvania 16221',4773,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6411,16222,-5,'Dayton, Pennsylvania 16222',4774,5856);
INSERT INTO "django_geo_db_zipcode" VALUES(6412,16223,-5,'Distant, Pennsylvania 16223',4775,5857);
INSERT INTO "django_geo_db_zipcode" VALUES(6413,16224,-5,'Fairmount City, Pennsylvania 16224',4776,5858);
INSERT INTO "django_geo_db_zipcode" VALUES(6414,16225,-5,'Fisher, Pennsylvania 16225',4777,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6415,16226,-5,'Ford City, Pennsylvania 16226',4778,5859);
INSERT INTO "django_geo_db_zipcode" VALUES(6416,16228,-5,'Ford Cliff, Pennsylvania 16228',4779,5860);
INSERT INTO "django_geo_db_zipcode" VALUES(6417,16229,-5,'Freeport, Pennsylvania 16229',4780,5861);
INSERT INTO "django_geo_db_zipcode" VALUES(6418,16230,-5,'Hawthorn, Pennsylvania 16230',4781,5862);
INSERT INTO "django_geo_db_zipcode" VALUES(6419,16232,-5,'Knox, Pennsylvania 16232',4782,5863);
INSERT INTO "django_geo_db_zipcode" VALUES(6420,16233,-5,'Leeper, Pennsylvania 16233',4783,5864);
INSERT INTO "django_geo_db_zipcode" VALUES(6421,16234,-5,'Limestone, Pennsylvania 16234',4784,5865);
INSERT INTO "django_geo_db_zipcode" VALUES(6422,16235,-5,'Lucinda, Pennsylvania 16235',4785,5866);
INSERT INTO "django_geo_db_zipcode" VALUES(6423,16236,-5,'McGrann, Pennsylvania 16236',4786,5867);
INSERT INTO "django_geo_db_zipcode" VALUES(6424,16238,-5,'Manorville, Pennsylvania 16238',4787,5868);
INSERT INTO "django_geo_db_zipcode" VALUES(6425,16239,-5,'Marienville, Pennsylvania 16239',4788,5869);
INSERT INTO "django_geo_db_zipcode" VALUES(6426,16240,-5,'Mayport, Pennsylvania 16240',4789,5870);
INSERT INTO "django_geo_db_zipcode" VALUES(6427,16242,-5,'New Bethlehem, Pennsylvania 16242',4790,5871);
INSERT INTO "django_geo_db_zipcode" VALUES(6428,16244,-5,'Nu Mine, Pennsylvania 16244',4791,5872);
INSERT INTO "django_geo_db_zipcode" VALUES(6429,16245,-5,'Oak Ridge, Pennsylvania 16245',4792,5873);
INSERT INTO "django_geo_db_zipcode" VALUES(6430,16246,-5,'Plumville, Pennsylvania 16246',4793,5874);
INSERT INTO "django_geo_db_zipcode" VALUES(6431,16248,-5,'Rimersburg, Pennsylvania 16248',4794,5875);
INSERT INTO "django_geo_db_zipcode" VALUES(6432,16249,-5,'Rural Valley, Pennsylvania 16249',4795,5876);
INSERT INTO "django_geo_db_zipcode" VALUES(6433,16250,-5,'Sagamore, Pennsylvania 16250',4796,5877);
INSERT INTO "django_geo_db_zipcode" VALUES(6434,16253,-5,'Seminole, Pennsylvania 16253',4797,5878);
INSERT INTO "django_geo_db_zipcode" VALUES(6435,16254,-5,'Shippenville, Pennsylvania 16254',4798,5879);
INSERT INTO "django_geo_db_zipcode" VALUES(6436,16255,-5,'Sligo, Pennsylvania 16255',4799,5880);
INSERT INTO "django_geo_db_zipcode" VALUES(6437,16256,-5,'Smicksburg, Pennsylvania 16256',4800,5881);
INSERT INTO "django_geo_db_zipcode" VALUES(6438,16257,-5,'Snydersburg, Pennsylvania 16257',4801,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6439,16258,-5,'Strattanville, Pennsylvania 16258',4802,5882);
INSERT INTO "django_geo_db_zipcode" VALUES(6440,16259,-5,'Templeton, Pennsylvania 16259',4803,5883);
INSERT INTO "django_geo_db_zipcode" VALUES(6441,16260,-5,'Vowinckel, Pennsylvania 16260',4804,5884);
INSERT INTO "django_geo_db_zipcode" VALUES(6442,16261,-5,'Widnoon, Pennsylvania 16261',4805,5568);
INSERT INTO "django_geo_db_zipcode" VALUES(6443,16262,-5,'Worthington, Pennsylvania 16262',4806,5885);
INSERT INTO "django_geo_db_zipcode" VALUES(6444,16263,-5,'Yatesboro, Pennsylvania 16263',4807,5886);
INSERT INTO "django_geo_db_zipcode" VALUES(6445,16299,-5,'South Buffalo, Pennsylvania 16299',4808,5887);
INSERT INTO "django_geo_db_zipcode" VALUES(6446,16301,-5,'Oil City, Pennsylvania 16301',4809,5888);
INSERT INTO "django_geo_db_zipcode" VALUES(6447,16302,-5,'Oil City, Pennsylvania 16302',4809,5889);
INSERT INTO "django_geo_db_zipcode" VALUES(6448,16311,-5,'Carlton, Pennsylvania 16311',4810,5890);
INSERT INTO "django_geo_db_zipcode" VALUES(6449,16312,-5,'Chandlers Valley, Pennsylvania 16312',4811,5891);
INSERT INTO "django_geo_db_zipcode" VALUES(6450,16313,-5,'Clarendon, Pennsylvania 16313',4812,5892);
INSERT INTO "django_geo_db_zipcode" VALUES(6451,16314,-5,'Cochranton, Pennsylvania 16314',4813,5893);
INSERT INTO "django_geo_db_zipcode" VALUES(6452,16316,-5,'Conneaut Lake, Pennsylvania 16316',4814,5894);
INSERT INTO "django_geo_db_zipcode" VALUES(6453,16317,-5,'Cooperstown, Pennsylvania 16317',4815,5895);
INSERT INTO "django_geo_db_zipcode" VALUES(6454,16319,-5,'Cranberry, Pennsylvania 16319',4687,5896);
INSERT INTO "django_geo_db_zipcode" VALUES(6455,16321,-5,'East Hickory, Pennsylvania 16321',4816,5897);
INSERT INTO "django_geo_db_zipcode" VALUES(6456,16322,-5,'Endeavor, Pennsylvania 16322',4817,5898);
INSERT INTO "django_geo_db_zipcode" VALUES(6457,16323,-5,'Franklin, Pennsylvania 16323',4818,5899);
INSERT INTO "django_geo_db_zipcode" VALUES(6458,16326,-5,'Fryburg, Pennsylvania 16326',4819,5900);
INSERT INTO "django_geo_db_zipcode" VALUES(6459,16327,-5,'Guys Mills, Pennsylvania 16327',4820,5901);
INSERT INTO "django_geo_db_zipcode" VALUES(6460,16328,-5,'Hydetown, Pennsylvania 16328',4821,5902);
INSERT INTO "django_geo_db_zipcode" VALUES(6461,16329,-5,'Irvine, Pennsylvania 16329',4822,5903);
INSERT INTO "django_geo_db_zipcode" VALUES(6462,16331,-5,'Kossuth, Pennsylvania 16331',4823,5904);
INSERT INTO "django_geo_db_zipcode" VALUES(6463,16332,-5,'Lickingville, Pennsylvania 16332',4824,5905);
INSERT INTO "django_geo_db_zipcode" VALUES(6464,16333,-5,'Ludlow, Pennsylvania 16333',4825,5906);
INSERT INTO "django_geo_db_zipcode" VALUES(6465,16334,-5,'Marble, Pennsylvania 16334',4826,5907);
INSERT INTO "django_geo_db_zipcode" VALUES(6466,16335,-5,'Meadville, Pennsylvania 16335',4827,5908);
INSERT INTO "django_geo_db_zipcode" VALUES(6467,16340,-5,'Pittsfield, Pennsylvania 16340',4828,5909);
INSERT INTO "django_geo_db_zipcode" VALUES(6468,16341,-5,'Pleasantville, Pennsylvania 16341',4829,5910);
INSERT INTO "django_geo_db_zipcode" VALUES(6469,16342,-5,'Polk, Pennsylvania 16342',4830,5911);
INSERT INTO "django_geo_db_zipcode" VALUES(6470,16343,-5,'Reno, Pennsylvania 16343',4831,5912);
INSERT INTO "django_geo_db_zipcode" VALUES(6471,16344,-5,'Rouseville, Pennsylvania 16344',4832,5913);
INSERT INTO "django_geo_db_zipcode" VALUES(6472,16345,-5,'Russell, Pennsylvania 16345',4833,5914);
INSERT INTO "django_geo_db_zipcode" VALUES(6473,16346,-5,'Seneca, Pennsylvania 16346',4834,5915);
INSERT INTO "django_geo_db_zipcode" VALUES(6474,16347,-5,'Sheffield, Pennsylvania 16347',4835,5916);
INSERT INTO "django_geo_db_zipcode" VALUES(6475,16350,-5,'Sugar Grove, Pennsylvania 16350',4836,5917);
INSERT INTO "django_geo_db_zipcode" VALUES(6476,16351,-5,'Tidioute, Pennsylvania 16351',4837,5918);
INSERT INTO "django_geo_db_zipcode" VALUES(6477,16352,-5,'Tiona, Pennsylvania 16352',4838,5919);
INSERT INTO "django_geo_db_zipcode" VALUES(6478,16353,-5,'Tionesta, Pennsylvania 16353',4839,5920);
INSERT INTO "django_geo_db_zipcode" VALUES(6479,16354,-5,'Titusville, Pennsylvania 16354',4840,5921);
INSERT INTO "django_geo_db_zipcode" VALUES(6480,16355,-5,'East Fairfield, Pennsylvania 16355',4841,5922);
INSERT INTO "django_geo_db_zipcode" VALUES(6481,16360,-5,'Townville, Pennsylvania 16360',4842,5923);
INSERT INTO "django_geo_db_zipcode" VALUES(6482,16361,-5,'Tylersburg, Pennsylvania 16361',4843,5924);
INSERT INTO "django_geo_db_zipcode" VALUES(6483,16362,-5,'Utica, Pennsylvania 16362',4844,5925);
INSERT INTO "django_geo_db_zipcode" VALUES(6484,16364,-5,'Venus, Pennsylvania 16364',4845,5926);
INSERT INTO "django_geo_db_zipcode" VALUES(6485,16365,-5,'Warren, Pennsylvania 16365',4846,5927);
INSERT INTO "django_geo_db_zipcode" VALUES(6486,16366,-5,'Warren, Pennsylvania 16366',4846,5928);
INSERT INTO "django_geo_db_zipcode" VALUES(6487,16367,-5,'Warren, Pennsylvania 16367',4846,5928);
INSERT INTO "django_geo_db_zipcode" VALUES(6488,16368,-5,'Irvine, Pennsylvania 16368',4822,5928);
INSERT INTO "django_geo_db_zipcode" VALUES(6489,16369,-5,'Irvine, Pennsylvania 16369',4822,5928);
INSERT INTO "django_geo_db_zipcode" VALUES(6490,16370,-5,'West Hickory, Pennsylvania 16370',4847,5929);
INSERT INTO "django_geo_db_zipcode" VALUES(6491,16371,-5,'Youngsville, Pennsylvania 16371',4848,5930);
INSERT INTO "django_geo_db_zipcode" VALUES(6492,16372,-5,'Clintonville, Pennsylvania 16372',4849,5931);
INSERT INTO "django_geo_db_zipcode" VALUES(6493,16373,-5,'Emlenton, Pennsylvania 16373',4850,5932);
INSERT INTO "django_geo_db_zipcode" VALUES(6494,16374,-5,'Kennerdell, Pennsylvania 16374',4851,5933);
INSERT INTO "django_geo_db_zipcode" VALUES(6495,16375,-5,'Lamartine, Pennsylvania 16375',4852,5801);
INSERT INTO "django_geo_db_zipcode" VALUES(6496,16388,-5,'Meadville, Pennsylvania 16388',4827,5934);
INSERT INTO "django_geo_db_zipcode" VALUES(6497,16401,-5,'Albion, Pennsylvania 16401',4853,5935);
INSERT INTO "django_geo_db_zipcode" VALUES(6498,16402,-5,'Bear Lake, Pennsylvania 16402',4854,5936);
INSERT INTO "django_geo_db_zipcode" VALUES(6499,16403,-5,'Cambridge Springs, Pennsylvania 16403',4855,5937);
INSERT INTO "django_geo_db_zipcode" VALUES(6500,16404,-5,'Centerville, Pennsylvania 16404',4341,5938);
INSERT INTO "django_geo_db_zipcode" VALUES(6501,16405,-5,'Columbus, Pennsylvania 16405',4856,5939);
INSERT INTO "django_geo_db_zipcode" VALUES(6502,16406,-5,'Conneautville, Pennsylvania 16406',4857,5940);
INSERT INTO "django_geo_db_zipcode" VALUES(6503,16407,-5,'Corry, Pennsylvania 16407',4858,5941);
INSERT INTO "django_geo_db_zipcode" VALUES(6504,16410,-5,'Cranesville, Pennsylvania 16410',4859,5942);
INSERT INTO "django_geo_db_zipcode" VALUES(6505,16411,-5,'East Springfield, Pennsylvania 16411',4860,5943);
INSERT INTO "django_geo_db_zipcode" VALUES(6506,16412,-5,'Edinboro, Pennsylvania 16412',4861,5944);
INSERT INTO "django_geo_db_zipcode" VALUES(6507,16413,-5,'Elgin, Pennsylvania 16413',4862,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6508,16414,-5,'Bloomfield, Pennsylvania 16414',4863,5946);
INSERT INTO "django_geo_db_zipcode" VALUES(6509,16415,-5,'Fairview, Pennsylvania 16415',4864,5947);
INSERT INTO "django_geo_db_zipcode" VALUES(6510,16416,-5,'Garland, Pennsylvania 16416',4865,5948);
INSERT INTO "django_geo_db_zipcode" VALUES(6511,16417,-5,'Girard, Pennsylvania 16417',4866,5949);
INSERT INTO "django_geo_db_zipcode" VALUES(6512,16420,-5,'Grand Valley, Pennsylvania 16420',4867,5950);
INSERT INTO "django_geo_db_zipcode" VALUES(6513,16421,-5,'Harborcreek, Pennsylvania 16421',4868,5951);
INSERT INTO "django_geo_db_zipcode" VALUES(6514,16422,-5,'Harmonsburg, Pennsylvania 16422',4869,5952);
INSERT INTO "django_geo_db_zipcode" VALUES(6515,16423,-5,'Lake City, Pennsylvania 16423',4870,5953);
INSERT INTO "django_geo_db_zipcode" VALUES(6516,16424,-5,'Linesville, Pennsylvania 16424',4871,5954);
INSERT INTO "django_geo_db_zipcode" VALUES(6517,16426,-5,'McKean, Pennsylvania 16426',4872,5955);
INSERT INTO "django_geo_db_zipcode" VALUES(6518,16427,-5,'Mill Village, Pennsylvania 16427',4873,5956);
INSERT INTO "django_geo_db_zipcode" VALUES(6519,16428,-5,'North East, Pennsylvania 16428',4874,5957);
INSERT INTO "django_geo_db_zipcode" VALUES(6520,16430,-5,'North Springfield, Pennsylvania 16430',4875,5958);
INSERT INTO "django_geo_db_zipcode" VALUES(6521,16432,-5,'Riceville, Pennsylvania 16432',4876,5902);
INSERT INTO "django_geo_db_zipcode" VALUES(6522,16433,-5,'Saegertown, Pennsylvania 16433',4877,5959);
INSERT INTO "django_geo_db_zipcode" VALUES(6523,16434,-5,'Spartansburg, Pennsylvania 16434',4878,5960);
INSERT INTO "django_geo_db_zipcode" VALUES(6524,16435,-5,'Springboro, Pennsylvania 16435',4879,5961);
INSERT INTO "django_geo_db_zipcode" VALUES(6525,16436,-5,'Spring Creek, Pennsylvania 16436',4880,5962);
INSERT INTO "django_geo_db_zipcode" VALUES(6526,16438,-5,'Union City, Pennsylvania 16438',4881,5963);
INSERT INTO "django_geo_db_zipcode" VALUES(6527,16440,-5,'Venango, Pennsylvania 16440',4882,5964);
INSERT INTO "django_geo_db_zipcode" VALUES(6528,16441,-5,'Waterford, Pennsylvania 16441',4883,5965);
INSERT INTO "django_geo_db_zipcode" VALUES(6529,16442,-5,'Wattsburg, Pennsylvania 16442',4884,5966);
INSERT INTO "django_geo_db_zipcode" VALUES(6530,16443,-5,'West Springfield, Pennsylvania 16443',4885,5967);
INSERT INTO "django_geo_db_zipcode" VALUES(6531,16444,-5,'Edinboro, Pennsylvania 16444',4861,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6532,16475,-5,'Albion, Pennsylvania 16475',4853,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6533,16501,-5,'Erie, Pennsylvania 16501',4886,5968);
INSERT INTO "django_geo_db_zipcode" VALUES(6534,16502,-5,'Erie, Pennsylvania 16502',4886,5969);
INSERT INTO "django_geo_db_zipcode" VALUES(6535,16503,-5,'Erie, Pennsylvania 16503',4886,5970);
INSERT INTO "django_geo_db_zipcode" VALUES(6536,16504,-5,'Erie, Pennsylvania 16504',4886,5971);
INSERT INTO "django_geo_db_zipcode" VALUES(6537,16505,-5,'Erie, Pennsylvania 16505',4886,5972);
INSERT INTO "django_geo_db_zipcode" VALUES(6538,16506,-5,'Erie, Pennsylvania 16506',4886,5973);
INSERT INTO "django_geo_db_zipcode" VALUES(6539,16507,-5,'Erie, Pennsylvania 16507',4886,5974);
INSERT INTO "django_geo_db_zipcode" VALUES(6540,16508,-5,'Erie, Pennsylvania 16508',4886,5975);
INSERT INTO "django_geo_db_zipcode" VALUES(6541,16509,-5,'Erie, Pennsylvania 16509',4886,5976);
INSERT INTO "django_geo_db_zipcode" VALUES(6542,16510,-5,'Erie, Pennsylvania 16510',4886,5977);
INSERT INTO "django_geo_db_zipcode" VALUES(6543,16511,-5,'Erie, Pennsylvania 16511',4886,5978);
INSERT INTO "django_geo_db_zipcode" VALUES(6544,16512,-5,'Erie, Pennsylvania 16512',4886,5979);
INSERT INTO "django_geo_db_zipcode" VALUES(6545,16514,-5,'Erie, Pennsylvania 16514',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6546,16515,-5,'Erie, Pennsylvania 16515',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6547,16522,-5,'Erie, Pennsylvania 16522',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6548,16530,-5,'Erie, Pennsylvania 16530',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6549,16531,-5,'Erie, Pennsylvania 16531',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6550,16532,-5,'Erie, Pennsylvania 16532',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6551,16533,-5,'Erie, Pennsylvania 16533',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6552,16534,-5,'Erie, Pennsylvania 16534',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6553,16538,-5,'Erie, Pennsylvania 16538',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6554,16541,-5,'Erie, Pennsylvania 16541',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6555,16544,-5,'Erie, Pennsylvania 16544',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6556,16546,-5,'Erie, Pennsylvania 16546',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6557,16550,-5,'Erie, Pennsylvania 16550',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6558,16553,-5,'Erie, Pennsylvania 16553',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6559,16554,-5,'Erie, Pennsylvania 16554',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6560,16558,-5,'Erie, Pennsylvania 16558',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6561,16563,-5,'Erie, Pennsylvania 16563',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6562,16565,-5,'Erie, Pennsylvania 16565',4886,5945);
INSERT INTO "django_geo_db_zipcode" VALUES(6563,16601,-5,'Altoona, Pennsylvania 16601',4887,5980);
INSERT INTO "django_geo_db_zipcode" VALUES(6564,16602,-5,'Altoona, Pennsylvania 16602',4887,5981);
INSERT INTO "django_geo_db_zipcode" VALUES(6565,16603,-5,'Altoona, Pennsylvania 16603',4887,5982);
INSERT INTO "django_geo_db_zipcode" VALUES(6566,16611,-5,'Alexandria, Pennsylvania 16611',4888,5983);
INSERT INTO "django_geo_db_zipcode" VALUES(6567,16613,-5,'Ashville, Pennsylvania 16613',4889,5984);
INSERT INTO "django_geo_db_zipcode" VALUES(6568,16614,-5,'Bakers Summit, Pennsylvania 16614',4890,5985);
INSERT INTO "django_geo_db_zipcode" VALUES(6569,16616,-5,'Beccaria, Pennsylvania 16616',4891,5986);
INSERT INTO "django_geo_db_zipcode" VALUES(6570,16617,-5,'Bellwood, Pennsylvania 16617',4892,5987);
INSERT INTO "django_geo_db_zipcode" VALUES(6571,16619,-5,'Blandburg, Pennsylvania 16619',4893,5988);
INSERT INTO "django_geo_db_zipcode" VALUES(6572,16620,-5,'Brisbin, Pennsylvania 16620',4894,5989);
INSERT INTO "django_geo_db_zipcode" VALUES(6573,16621,-5,'Broad Top, Pennsylvania 16621',4895,5990);
INSERT INTO "django_geo_db_zipcode" VALUES(6574,16622,-5,'Calvin, Pennsylvania 16622',4896,5991);
INSERT INTO "django_geo_db_zipcode" VALUES(6575,16623,-5,'Cassville, Pennsylvania 16623',4897,5992);
INSERT INTO "django_geo_db_zipcode" VALUES(6576,16624,-5,'Chest Springs, Pennsylvania 16624',4898,5993);
INSERT INTO "django_geo_db_zipcode" VALUES(6577,16625,-5,'Claysburg, Pennsylvania 16625',4899,5994);
INSERT INTO "django_geo_db_zipcode" VALUES(6578,16627,-5,'Coalport, Pennsylvania 16627',4900,5995);
INSERT INTO "django_geo_db_zipcode" VALUES(6579,16629,-5,'Coupon, Pennsylvania 16629',4901,5996);
INSERT INTO "django_geo_db_zipcode" VALUES(6580,16630,-5,'Cresson, Pennsylvania 16630',4902,5997);
INSERT INTO "django_geo_db_zipcode" VALUES(6581,16631,-5,'Curryville, Pennsylvania 16631',4903,5998);
INSERT INTO "django_geo_db_zipcode" VALUES(6582,16633,-5,'Defiance, Pennsylvania 16633',4904,5999);
INSERT INTO "django_geo_db_zipcode" VALUES(6583,16634,-5,'Dudley, Pennsylvania 16634',4905,6000);
INSERT INTO "django_geo_db_zipcode" VALUES(6584,16635,-5,'Duncansville, Pennsylvania 16635',4906,6001);
INSERT INTO "django_geo_db_zipcode" VALUES(6585,16636,-5,'Dysart, Pennsylvania 16636',4907,6002);
INSERT INTO "django_geo_db_zipcode" VALUES(6586,16637,-5,'East Freedom, Pennsylvania 16637',4908,6003);
INSERT INTO "django_geo_db_zipcode" VALUES(6587,16638,-5,'Entriken, Pennsylvania 16638',4909,6004);
INSERT INTO "django_geo_db_zipcode" VALUES(6588,16639,-5,'Fallentimber, Pennsylvania 16639',4910,6005);
INSERT INTO "django_geo_db_zipcode" VALUES(6589,16640,-5,'Flinton, Pennsylvania 16640',4911,6006);
INSERT INTO "django_geo_db_zipcode" VALUES(6590,16641,-5,'Gallitzin, Pennsylvania 16641',4912,6007);
INSERT INTO "django_geo_db_zipcode" VALUES(6591,16644,-5,'Glasgow, Pennsylvania 16644',4913,6008);
INSERT INTO "django_geo_db_zipcode" VALUES(6592,16645,-5,'Glen Hope, Pennsylvania 16645',4914,6009);
INSERT INTO "django_geo_db_zipcode" VALUES(6593,16646,-5,'Hastings, Pennsylvania 16646',4915,6010);
INSERT INTO "django_geo_db_zipcode" VALUES(6594,16647,-5,'Hesston, Pennsylvania 16647',4916,6011);
INSERT INTO "django_geo_db_zipcode" VALUES(6595,16648,-5,'Hollidaysburg, Pennsylvania 16648',4917,6012);
INSERT INTO "django_geo_db_zipcode" VALUES(6596,16650,-5,'Hopewell, Pennsylvania 16650',4918,6013);
INSERT INTO "django_geo_db_zipcode" VALUES(6597,16651,-5,'Houtzdale, Pennsylvania 16651',4919,6014);
INSERT INTO "django_geo_db_zipcode" VALUES(6598,16652,-5,'Huntingdon, Pennsylvania 16652',4920,6015);
INSERT INTO "django_geo_db_zipcode" VALUES(6599,16654,-5,'Huntingdon, Pennsylvania 16654',4920,6016);
INSERT INTO "django_geo_db_zipcode" VALUES(6600,16655,-5,'Imler, Pennsylvania 16655',4921,6017);
INSERT INTO "django_geo_db_zipcode" VALUES(6601,16656,-5,'Irvona, Pennsylvania 16656',4922,6018);
INSERT INTO "django_geo_db_zipcode" VALUES(6602,16657,-5,'James Creek, Pennsylvania 16657',4923,6019);
INSERT INTO "django_geo_db_zipcode" VALUES(6603,16659,-5,'Loysburg, Pennsylvania 16659',4924,6020);
INSERT INTO "django_geo_db_zipcode" VALUES(6604,16660,-5,'McConnellstown, Pennsylvania 16660',4925,6016);
INSERT INTO "django_geo_db_zipcode" VALUES(6605,16661,-5,'Madera, Pennsylvania 16661',4926,6021);
INSERT INTO "django_geo_db_zipcode" VALUES(6606,16662,-5,'Martinsburg, Pennsylvania 16662',4927,6022);
INSERT INTO "django_geo_db_zipcode" VALUES(6607,16663,-5,'Morann, Pennsylvania 16663',4928,6023);
INSERT INTO "django_geo_db_zipcode" VALUES(6608,16664,-5,'New Enterprise, Pennsylvania 16664',4929,6024);
INSERT INTO "django_geo_db_zipcode" VALUES(6609,16665,-5,'Newry, Pennsylvania 16665',4930,6025);
INSERT INTO "django_geo_db_zipcode" VALUES(6610,16666,-5,'Osceola Mills, Pennsylvania 16666',4931,6026);
INSERT INTO "django_geo_db_zipcode" VALUES(6611,16667,-5,'Osterburg, Pennsylvania 16667',4932,6027);
INSERT INTO "django_geo_db_zipcode" VALUES(6612,16668,-5,'Patton, Pennsylvania 16668',4933,6028);
INSERT INTO "django_geo_db_zipcode" VALUES(6613,16669,-5,'Petersburg, Pennsylvania 16669',4934,6029);
INSERT INTO "django_geo_db_zipcode" VALUES(6614,16670,-5,'Queen, Pennsylvania 16670',4935,6030);
INSERT INTO "django_geo_db_zipcode" VALUES(6615,16671,-5,'Ramey, Pennsylvania 16671',4936,6031);
INSERT INTO "django_geo_db_zipcode" VALUES(6616,16672,-5,'Riddlesburg, Pennsylvania 16672',4937,6032);
INSERT INTO "django_geo_db_zipcode" VALUES(6617,16673,-5,'Roaring Spring, Pennsylvania 16673',4938,6033);
INSERT INTO "django_geo_db_zipcode" VALUES(6618,16674,-5,'Robertsdale, Pennsylvania 16674',4939,6034);
INSERT INTO "django_geo_db_zipcode" VALUES(6619,16675,-5,'Saint Boniface, Pennsylvania 16675',4940,6035);
INSERT INTO "django_geo_db_zipcode" VALUES(6620,16677,-5,'Sandy Ridge, Pennsylvania 16677',4941,6036);
INSERT INTO "django_geo_db_zipcode" VALUES(6621,16678,-5,'Saxton, Pennsylvania 16678',4942,6037);
INSERT INTO "django_geo_db_zipcode" VALUES(6622,16679,-5,'Six Mile Run, Pennsylvania 16679',4943,6038);
INSERT INTO "django_geo_db_zipcode" VALUES(6623,16680,-5,'Smithmill, Pennsylvania 16680',4944,6039);
INSERT INTO "django_geo_db_zipcode" VALUES(6624,16681,-5,'Smokerun, Pennsylvania 16681',4945,6040);
INSERT INTO "django_geo_db_zipcode" VALUES(6625,16682,-5,'Sproul, Pennsylvania 16682',4946,6041);
INSERT INTO "django_geo_db_zipcode" VALUES(6626,16683,-5,'Spruce Creek, Pennsylvania 16683',4947,6042);
INSERT INTO "django_geo_db_zipcode" VALUES(6627,16684,-5,'Tipton, Pennsylvania 16684',4948,6043);
INSERT INTO "django_geo_db_zipcode" VALUES(6628,16685,-5,'Todd, Pennsylvania 16685',4949,6044);
INSERT INTO "django_geo_db_zipcode" VALUES(6629,16686,-5,'Tyrone, Pennsylvania 16686',4950,6045);
INSERT INTO "django_geo_db_zipcode" VALUES(6630,16689,-5,'Waterfall, Pennsylvania 16689',4951,6046);
INSERT INTO "django_geo_db_zipcode" VALUES(6631,16691,-5,'Wells Tannery, Pennsylvania 16691',4952,6047);
INSERT INTO "django_geo_db_zipcode" VALUES(6632,16692,-5,'Westover, Pennsylvania 16692',4953,6048);
INSERT INTO "django_geo_db_zipcode" VALUES(6633,16693,-5,'Williamsburg, Pennsylvania 16693',4954,6049);
INSERT INTO "django_geo_db_zipcode" VALUES(6634,16694,-5,'Wood, Pennsylvania 16694',4955,6050);
INSERT INTO "django_geo_db_zipcode" VALUES(6635,16695,-5,'Woodbury, Pennsylvania 16695',4956,6051);
INSERT INTO "django_geo_db_zipcode" VALUES(6636,16698,-5,'Houtzdale, Pennsylvania 16698',4919,6052);
INSERT INTO "django_geo_db_zipcode" VALUES(6637,16699,-5,'Cresson, Pennsylvania 16699',4902,5728);
INSERT INTO "django_geo_db_zipcode" VALUES(6638,16701,-5,'Bradford, Pennsylvania 16701',4957,6053);
INSERT INTO "django_geo_db_zipcode" VALUES(6639,16720,-5,'Austin, Pennsylvania 16720',4958,6054);
INSERT INTO "django_geo_db_zipcode" VALUES(6640,16724,-5,'Crosby, Pennsylvania 16724',4959,6055);
INSERT INTO "django_geo_db_zipcode" VALUES(6641,16725,-5,'Custer City, Pennsylvania 16725',4960,6056);
INSERT INTO "django_geo_db_zipcode" VALUES(6642,16726,-5,'Cyclone, Pennsylvania 16726',4961,6057);
INSERT INTO "django_geo_db_zipcode" VALUES(6643,16727,-5,'Derrick City, Pennsylvania 16727',4962,6058);
INSERT INTO "django_geo_db_zipcode" VALUES(6644,16728,-5,'De Young, Pennsylvania 16728',4963,5691);
INSERT INTO "django_geo_db_zipcode" VALUES(6645,16729,-5,'Duke Center, Pennsylvania 16729',4964,6059);
INSERT INTO "django_geo_db_zipcode" VALUES(6646,16730,-5,'East Smethport, Pennsylvania 16730',4965,6060);
INSERT INTO "django_geo_db_zipcode" VALUES(6647,16731,-5,'Eldred, Pennsylvania 16731',4966,6061);
INSERT INTO "django_geo_db_zipcode" VALUES(6648,16732,-5,'Gifford, Pennsylvania 16732',4967,6062);
INSERT INTO "django_geo_db_zipcode" VALUES(6649,16733,-5,'Hazel Hurst, Pennsylvania 16733',4968,6063);
INSERT INTO "django_geo_db_zipcode" VALUES(6650,16734,-5,'James City, Pennsylvania 16734',4969,6064);
INSERT INTO "django_geo_db_zipcode" VALUES(6651,16735,-5,'Kane, Pennsylvania 16735',4970,6065);
INSERT INTO "django_geo_db_zipcode" VALUES(6652,16738,-5,'Lewis Run, Pennsylvania 16738',4971,6066);
INSERT INTO "django_geo_db_zipcode" VALUES(6653,16740,-5,'Mount Jewett, Pennsylvania 16740',4972,6067);
INSERT INTO "django_geo_db_zipcode" VALUES(6654,16743,-5,'Port Allegany, Pennsylvania 16743',4973,6068);
INSERT INTO "django_geo_db_zipcode" VALUES(6655,16744,-5,'Rew, Pennsylvania 16744',4974,6069);
INSERT INTO "django_geo_db_zipcode" VALUES(6656,16745,-5,'Rixford, Pennsylvania 16745',4975,6070);
INSERT INTO "django_geo_db_zipcode" VALUES(6657,16746,-5,'Roulette, Pennsylvania 16746',4976,6071);
INSERT INTO "django_geo_db_zipcode" VALUES(6658,16748,-5,'Shinglehouse, Pennsylvania 16748',4977,6072);
INSERT INTO "django_geo_db_zipcode" VALUES(6659,16749,-5,'Smethport, Pennsylvania 16749',4978,6073);
INSERT INTO "django_geo_db_zipcode" VALUES(6660,16750,-5,'Turtlepoint, Pennsylvania 16750',4979,6074);
INSERT INTO "django_geo_db_zipcode" VALUES(6661,16751,-5,'Westline, Pennsylvania 16751',4980,6075);
INSERT INTO "django_geo_db_zipcode" VALUES(6662,16801,-5,'State College, Pennsylvania 16801',4981,6076);
INSERT INTO "django_geo_db_zipcode" VALUES(6663,16802,-5,'University Park, Pennsylvania 16802',4982,6077);
INSERT INTO "django_geo_db_zipcode" VALUES(6664,16803,-5,'State College, Pennsylvania 16803',4981,6078);
INSERT INTO "django_geo_db_zipcode" VALUES(6665,16804,-5,'State College, Pennsylvania 16804',4981,6079);
INSERT INTO "django_geo_db_zipcode" VALUES(6666,16805,-5,'State College, Pennsylvania 16805',4981,6079);
INSERT INTO "django_geo_db_zipcode" VALUES(6667,16815,-5,'Potter, Pennsylvania 16815',4983,6080);
INSERT INTO "django_geo_db_zipcode" VALUES(6668,16820,-5,'Aaronsburg, Pennsylvania 16820',4984,6081);
INSERT INTO "django_geo_db_zipcode" VALUES(6669,16821,-5,'Allport, Pennsylvania 16821',4985,6052);
INSERT INTO "django_geo_db_zipcode" VALUES(6670,16822,-5,'Beech Creek, Pennsylvania 16822',4986,6082);
INSERT INTO "django_geo_db_zipcode" VALUES(6671,16823,-5,'Bellefonte, Pennsylvania 16823',4987,6083);
INSERT INTO "django_geo_db_zipcode" VALUES(6672,16825,-5,'Bigler, Pennsylvania 16825',4988,6084);
INSERT INTO "django_geo_db_zipcode" VALUES(6673,16826,-5,'Blanchard, Pennsylvania 16826',4989,6085);
INSERT INTO "django_geo_db_zipcode" VALUES(6674,16827,-5,'Boalsburg, Pennsylvania 16827',4990,6086);
INSERT INTO "django_geo_db_zipcode" VALUES(6675,16828,-5,'Centre Hall, Pennsylvania 16828',4991,6087);
INSERT INTO "django_geo_db_zipcode" VALUES(6676,16829,-5,'Clarence, Pennsylvania 16829',4992,6088);
INSERT INTO "django_geo_db_zipcode" VALUES(6677,16830,-5,'Clearfield, Pennsylvania 16830',4993,6089);
INSERT INTO "django_geo_db_zipcode" VALUES(6678,16832,-5,'Coburn, Pennsylvania 16832',4994,6090);
INSERT INTO "django_geo_db_zipcode" VALUES(6679,16833,-5,'Curwensville, Pennsylvania 16833',4995,6091);
INSERT INTO "django_geo_db_zipcode" VALUES(6680,16834,-5,'Drifting, Pennsylvania 16834',4996,6092);
INSERT INTO "django_geo_db_zipcode" VALUES(6681,16835,-5,'Fleming, Pennsylvania 16835',4997,6093);
INSERT INTO "django_geo_db_zipcode" VALUES(6682,16836,-5,'Frenchville, Pennsylvania 16836',4998,6094);
INSERT INTO "django_geo_db_zipcode" VALUES(6683,16837,-5,'Glen Richey, Pennsylvania 16837',4999,6095);
INSERT INTO "django_geo_db_zipcode" VALUES(6684,16838,-5,'Grampian, Pennsylvania 16838',5000,6096);
INSERT INTO "django_geo_db_zipcode" VALUES(6685,16839,-5,'Grassflat, Pennsylvania 16839',5001,6097);
INSERT INTO "django_geo_db_zipcode" VALUES(6686,16840,-5,'Hawk Run, Pennsylvania 16840',5002,6098);
INSERT INTO "django_geo_db_zipcode" VALUES(6687,16841,-5,'Howard, Pennsylvania 16841',5003,6099);
INSERT INTO "django_geo_db_zipcode" VALUES(6688,16843,-5,'Hyde, Pennsylvania 16843',5004,6100);
INSERT INTO "django_geo_db_zipcode" VALUES(6689,16844,-5,'Julian, Pennsylvania 16844',5005,6101);
INSERT INTO "django_geo_db_zipcode" VALUES(6690,16845,-5,'Karthaus, Pennsylvania 16845',5006,6102);
INSERT INTO "django_geo_db_zipcode" VALUES(6691,16847,-5,'Kylertown, Pennsylvania 16847',5007,6103);
INSERT INTO "django_geo_db_zipcode" VALUES(6692,16848,-5,'Lamar, Pennsylvania 16848',5008,6104);
INSERT INTO "django_geo_db_zipcode" VALUES(6693,16849,-5,'Lanse, Pennsylvania 16849',5009,6105);
INSERT INTO "django_geo_db_zipcode" VALUES(6694,16850,-5,'Lecontes Mills, Pennsylvania 16850',5010,6052);
INSERT INTO "django_geo_db_zipcode" VALUES(6695,16851,-5,'Lemont, Pennsylvania 16851',5011,6106);
INSERT INTO "django_geo_db_zipcode" VALUES(6696,16852,-5,'Madisonburg, Pennsylvania 16852',5012,6107);
INSERT INTO "django_geo_db_zipcode" VALUES(6697,16853,-5,'Milesburg, Pennsylvania 16853',5013,6108);
INSERT INTO "django_geo_db_zipcode" VALUES(6698,16854,-5,'Millheim, Pennsylvania 16854',5014,6109);
INSERT INTO "django_geo_db_zipcode" VALUES(6699,16855,-5,'Mineral Springs, Pennsylvania 16855',5015,6110);
INSERT INTO "django_geo_db_zipcode" VALUES(6700,16856,-5,'Mingoville, Pennsylvania 16856',5016,6111);
INSERT INTO "django_geo_db_zipcode" VALUES(6701,16858,-5,'Morrisdale, Pennsylvania 16858',5017,6112);
INSERT INTO "django_geo_db_zipcode" VALUES(6702,16859,-5,'Moshannon, Pennsylvania 16859',5018,6113);
INSERT INTO "django_geo_db_zipcode" VALUES(6703,16860,-5,'Munson, Pennsylvania 16860',5019,6114);
INSERT INTO "django_geo_db_zipcode" VALUES(6704,16861,-5,'New Millport, Pennsylvania 16861',5020,6115);
INSERT INTO "django_geo_db_zipcode" VALUES(6705,16863,-5,'Olanta, Pennsylvania 16863',5021,6116);
INSERT INTO "django_geo_db_zipcode" VALUES(6706,16864,-5,'Orviston, Pennsylvania 16864',5022,6117);
INSERT INTO "django_geo_db_zipcode" VALUES(6707,16865,-5,'Pennsylvania Furnace, Pennsylvania 16865',5023,6118);
INSERT INTO "django_geo_db_zipcode" VALUES(6708,16866,-5,'Philipsburg, Pennsylvania 16866',5024,6119);
INSERT INTO "django_geo_db_zipcode" VALUES(6709,16868,-5,'Pine Grove Mills, Pennsylvania 16868',5025,6120);
INSERT INTO "django_geo_db_zipcode" VALUES(6710,16870,-5,'Port Matilda, Pennsylvania 16870',5026,6121);
INSERT INTO "django_geo_db_zipcode" VALUES(6711,16871,-5,'Pottersdale, Pennsylvania 16871',5027,6122);
INSERT INTO "django_geo_db_zipcode" VALUES(6712,16872,-5,'Rebersburg, Pennsylvania 16872',5028,6123);
INSERT INTO "django_geo_db_zipcode" VALUES(6713,16873,-5,'Shawville, Pennsylvania 16873',5029,6052);
INSERT INTO "django_geo_db_zipcode" VALUES(6714,16874,-5,'Snow Shoe, Pennsylvania 16874',5030,6124);
INSERT INTO "django_geo_db_zipcode" VALUES(6715,16875,-5,'Spring Mills, Pennsylvania 16875',5031,6125);
INSERT INTO "django_geo_db_zipcode" VALUES(6716,16876,-5,'Wallaceton, Pennsylvania 16876',5032,6126);
INSERT INTO "django_geo_db_zipcode" VALUES(6717,16877,-5,'Warriors Mark, Pennsylvania 16877',5033,6127);
INSERT INTO "django_geo_db_zipcode" VALUES(6718,16878,-5,'West Decatur, Pennsylvania 16878',5034,6128);
INSERT INTO "django_geo_db_zipcode" VALUES(6719,16879,-5,'Winburne, Pennsylvania 16879',5035,6129);
INSERT INTO "django_geo_db_zipcode" VALUES(6720,16881,-5,'Woodland, Pennsylvania 16881',5036,6130);
INSERT INTO "django_geo_db_zipcode" VALUES(6721,16882,-5,'Woodward, Pennsylvania 16882',5037,6131);
INSERT INTO "django_geo_db_zipcode" VALUES(6722,16901,-5,'Wellsboro, Pennsylvania 16901',5038,6132);
INSERT INTO "django_geo_db_zipcode" VALUES(6723,16910,-5,'Alba, Pennsylvania 16910',5039,6133);
INSERT INTO "django_geo_db_zipcode" VALUES(6724,16911,-5,'Arnot, Pennsylvania 16911',5040,6134);
INSERT INTO "django_geo_db_zipcode" VALUES(6725,16912,-5,'Blossburg, Pennsylvania 16912',5041,6135);
INSERT INTO "django_geo_db_zipcode" VALUES(6726,16914,-5,'Columbia Cross Roads, Pennsylvania 16914',5042,6136);
INSERT INTO "django_geo_db_zipcode" VALUES(6727,16915,-5,'Coudersport, Pennsylvania 16915',5043,6137);
INSERT INTO "django_geo_db_zipcode" VALUES(6728,16917,-5,'Covington, Pennsylvania 16917',5044,6138);
INSERT INTO "django_geo_db_zipcode" VALUES(6729,16918,-5,'Cowanesque, Pennsylvania 16918',5045,6139);
INSERT INTO "django_geo_db_zipcode" VALUES(6730,16920,-5,'Elkland, Pennsylvania 16920',5046,6140);
INSERT INTO "django_geo_db_zipcode" VALUES(6731,16921,-5,'Gaines, Pennsylvania 16921',5047,6141);
INSERT INTO "django_geo_db_zipcode" VALUES(6732,16922,-5,'Galeton, Pennsylvania 16922',5048,6142);
INSERT INTO "django_geo_db_zipcode" VALUES(6733,16923,-5,'Genesee, Pennsylvania 16923',5049,6143);
INSERT INTO "django_geo_db_zipcode" VALUES(6734,16925,-5,'Gillett, Pennsylvania 16925',5050,6144);
INSERT INTO "django_geo_db_zipcode" VALUES(6735,16926,-5,'Granville Summit, Pennsylvania 16926',5051,6145);
INSERT INTO "django_geo_db_zipcode" VALUES(6736,16927,-5,'Harrison Valley, Pennsylvania 16927',5052,6146);
INSERT INTO "django_geo_db_zipcode" VALUES(6737,16928,-5,'Knoxville, Pennsylvania 16928',5053,6147);
INSERT INTO "django_geo_db_zipcode" VALUES(6738,16929,-5,'Lawrenceville, Pennsylvania 16929',5054,6148);
INSERT INTO "django_geo_db_zipcode" VALUES(6739,16930,-5,'Liberty, Pennsylvania 16930',5055,6149);
INSERT INTO "django_geo_db_zipcode" VALUES(6740,16932,-5,'Mainesburg, Pennsylvania 16932',5056,6150);
INSERT INTO "django_geo_db_zipcode" VALUES(6741,16933,-5,'Mansfield, Pennsylvania 16933',5057,6151);
INSERT INTO "django_geo_db_zipcode" VALUES(6742,16935,-5,'Middlebury Center, Pennsylvania 16935',5058,6152);
INSERT INTO "django_geo_db_zipcode" VALUES(6743,16936,-5,'Millerton, Pennsylvania 16936',5059,6153);
INSERT INTO "django_geo_db_zipcode" VALUES(6744,16937,-5,'Mills, Pennsylvania 16937',5060,6154);
INSERT INTO "django_geo_db_zipcode" VALUES(6745,16938,-5,'Morris, Pennsylvania 16938',5061,6155);
INSERT INTO "django_geo_db_zipcode" VALUES(6746,16939,-5,'Morris Run, Pennsylvania 16939',5062,6156);
INSERT INTO "django_geo_db_zipcode" VALUES(6747,16940,-5,'Nelson, Pennsylvania 16940',5063,6157);
INSERT INTO "django_geo_db_zipcode" VALUES(6748,16941,-5,'Genesee, Pennsylvania 16941',5049,6158);
INSERT INTO "django_geo_db_zipcode" VALUES(6749,16942,-5,'Osceola, Pennsylvania 16942',5064,6159);
INSERT INTO "django_geo_db_zipcode" VALUES(6750,16943,-5,'Sabinsville, Pennsylvania 16943',5065,6160);
INSERT INTO "django_geo_db_zipcode" VALUES(6751,16945,-5,'Sylvania, Pennsylvania 16945',5066,6133);
INSERT INTO "django_geo_db_zipcode" VALUES(6752,16946,-5,'Tioga, Pennsylvania 16946',5067,6161);
INSERT INTO "django_geo_db_zipcode" VALUES(6753,16947,-5,'Troy, Pennsylvania 16947',5068,6162);
INSERT INTO "django_geo_db_zipcode" VALUES(6754,16948,-5,'Ulysses, Pennsylvania 16948',5069,6163);
INSERT INTO "django_geo_db_zipcode" VALUES(6755,16950,-5,'Westfield, Pennsylvania 16950',5070,6164);
INSERT INTO "django_geo_db_zipcode" VALUES(6756,17001,-5,'Camp Hill, Pennsylvania 17001',5071,6165);
INSERT INTO "django_geo_db_zipcode" VALUES(6757,17002,-5,'Allensville, Pennsylvania 17002',5072,6166);
INSERT INTO "django_geo_db_zipcode" VALUES(6758,17003,-5,'Annville, Pennsylvania 17003',5073,6167);
INSERT INTO "django_geo_db_zipcode" VALUES(6759,17004,-5,'Belleville, Pennsylvania 17004',5074,6168);
INSERT INTO "django_geo_db_zipcode" VALUES(6760,17005,-5,'Berrysburg, Pennsylvania 17005',5075,6169);
INSERT INTO "django_geo_db_zipcode" VALUES(6761,17006,-5,'Blain, Pennsylvania 17006',5076,6170);
INSERT INTO "django_geo_db_zipcode" VALUES(6762,17007,-5,'Boiling Springs, Pennsylvania 17007',5077,6171);
INSERT INTO "django_geo_db_zipcode" VALUES(6763,17008,-5,'Bowmansdale, Pennsylvania 17008',5078,6172);
INSERT INTO "django_geo_db_zipcode" VALUES(6764,17009,-5,'Burnham, Pennsylvania 17009',5079,6173);
INSERT INTO "django_geo_db_zipcode" VALUES(6765,17010,-5,'Campbelltown, Pennsylvania 17010',5080,6174);
INSERT INTO "django_geo_db_zipcode" VALUES(6766,17011,-5,'Camp Hill, Pennsylvania 17011',5071,6175);
INSERT INTO "django_geo_db_zipcode" VALUES(6767,17012,-5,'Camp Hill, Pennsylvania 17012',5071,6176);
INSERT INTO "django_geo_db_zipcode" VALUES(6768,17013,-5,'Carlisle, Pennsylvania 17013',5081,6177);
INSERT INTO "django_geo_db_zipcode" VALUES(6769,17014,-5,'Cocolamus, Pennsylvania 17014',5082,6178);
INSERT INTO "django_geo_db_zipcode" VALUES(6770,17015,-5,'South Londonderry, Pennsylvania 17015',5083,6179);
INSERT INTO "django_geo_db_zipcode" VALUES(6771,17016,-5,'Cornwall, Pennsylvania 17016',5084,6180);
INSERT INTO "django_geo_db_zipcode" VALUES(6772,17017,-5,'Dalmatia, Pennsylvania 17017',5085,6181);
INSERT INTO "django_geo_db_zipcode" VALUES(6773,17018,-5,'Dauphin, Pennsylvania 17018',5086,6182);
INSERT INTO "django_geo_db_zipcode" VALUES(6774,17019,-5,'Dillsburg, Pennsylvania 17019',5087,6183);
INSERT INTO "django_geo_db_zipcode" VALUES(6775,17020,-5,'Duncannon, Pennsylvania 17020',5088,6184);
INSERT INTO "django_geo_db_zipcode" VALUES(6776,17021,-5,'East Waterford, Pennsylvania 17021',5089,6185);
INSERT INTO "django_geo_db_zipcode" VALUES(6777,17022,-5,'Elizabethtown, Pennsylvania 17022',5090,6186);
INSERT INTO "django_geo_db_zipcode" VALUES(6778,17023,-5,'Elizabethville, Pennsylvania 17023',5091,6187);
INSERT INTO "django_geo_db_zipcode" VALUES(6779,17024,-5,'Elliottsburg, Pennsylvania 17024',5092,6188);
INSERT INTO "django_geo_db_zipcode" VALUES(6780,17025,-5,'Enola, Pennsylvania 17025',5093,6189);
INSERT INTO "django_geo_db_zipcode" VALUES(6781,17026,-5,'Fredericksburg, Pennsylvania 17026',5094,6190);
INSERT INTO "django_geo_db_zipcode" VALUES(6782,17027,-5,'Grantham, Pennsylvania 17027',5095,6191);
INSERT INTO "django_geo_db_zipcode" VALUES(6783,17028,-5,'Grantville, Pennsylvania 17028',5096,6192);
INSERT INTO "django_geo_db_zipcode" VALUES(6784,17029,-5,'Granville, Pennsylvania 17029',5097,6193);
INSERT INTO "django_geo_db_zipcode" VALUES(6785,17030,-5,'Gratz, Pennsylvania 17030',5098,6194);
INSERT INTO "django_geo_db_zipcode" VALUES(6786,17031,-5,'Green Park, Pennsylvania 17031',5099,6195);
INSERT INTO "django_geo_db_zipcode" VALUES(6787,17032,-5,'Halifax, Pennsylvania 17032',5100,6196);
INSERT INTO "django_geo_db_zipcode" VALUES(6788,17033,-5,'Hershey, Pennsylvania 17033',5101,6197);
INSERT INTO "django_geo_db_zipcode" VALUES(6789,17034,-5,'Highspire, Pennsylvania 17034',5102,6198);
INSERT INTO "django_geo_db_zipcode" VALUES(6790,17035,-5,'Honey Grove, Pennsylvania 17035',5103,6199);
INSERT INTO "django_geo_db_zipcode" VALUES(6791,17036,-5,'Hummelstown, Pennsylvania 17036',5104,6200);
INSERT INTO "django_geo_db_zipcode" VALUES(6792,17037,-5,'Ickesburg, Pennsylvania 17037',5105,6201);
INSERT INTO "django_geo_db_zipcode" VALUES(6793,17038,-5,'Jonestown, Pennsylvania 17038',5106,6202);
INSERT INTO "django_geo_db_zipcode" VALUES(6794,17039,-5,'Kleinfeltersville, Pennsylvania 17039',5107,6203);
INSERT INTO "django_geo_db_zipcode" VALUES(6795,17040,-5,'Landisburg, Pennsylvania 17040',5108,6204);
INSERT INTO "django_geo_db_zipcode" VALUES(6796,17041,-5,'Lawn, Pennsylvania 17041',5109,6205);
INSERT INTO "django_geo_db_zipcode" VALUES(6797,17042,-5,'Lebanon, Pennsylvania 17042',5110,6206);
INSERT INTO "django_geo_db_zipcode" VALUES(6798,17043,-5,'Lemoyne, Pennsylvania 17043',5111,6207);
INSERT INTO "django_geo_db_zipcode" VALUES(6799,17044,-5,'Lewistown, Pennsylvania 17044',5112,6208);
INSERT INTO "django_geo_db_zipcode" VALUES(6800,17045,-5,'Liverpool, Pennsylvania 17045',5113,6209);
INSERT INTO "django_geo_db_zipcode" VALUES(6801,17046,-5,'Lebanon, Pennsylvania 17046',5110,6210);
INSERT INTO "django_geo_db_zipcode" VALUES(6802,17047,-5,'Loysville, Pennsylvania 17047',5114,6211);
INSERT INTO "django_geo_db_zipcode" VALUES(6803,17048,-5,'Lykens, Pennsylvania 17048',5115,6212);
INSERT INTO "django_geo_db_zipcode" VALUES(6804,17049,-5,'McAlisterville, Pennsylvania 17049',5116,6213);
INSERT INTO "django_geo_db_zipcode" VALUES(6805,17050,-5,'Mechanicsburg, Pennsylvania 17050',5117,6214);
INSERT INTO "django_geo_db_zipcode" VALUES(6806,17051,-5,'McVeytown, Pennsylvania 17051',5118,6215);
INSERT INTO "django_geo_db_zipcode" VALUES(6807,17052,-5,'Mapleton Depot, Pennsylvania 17052',5119,6216);
INSERT INTO "django_geo_db_zipcode" VALUES(6808,17053,-5,'Marysville, Pennsylvania 17053',5120,6217);
INSERT INTO "django_geo_db_zipcode" VALUES(6809,17054,-5,'Mattawana, Pennsylvania 17054',5121,6218);
INSERT INTO "django_geo_db_zipcode" VALUES(6810,17055,-5,'Mechanicsburg, Pennsylvania 17055',5117,6219);
INSERT INTO "django_geo_db_zipcode" VALUES(6811,17056,-5,'Mexico, Pennsylvania 17056',5122,6178);
INSERT INTO "django_geo_db_zipcode" VALUES(6812,17057,-5,'Middletown, Pennsylvania 17057',5123,6220);
INSERT INTO "django_geo_db_zipcode" VALUES(6813,17058,-5,'Mifflin, Pennsylvania 17058',5124,6221);
INSERT INTO "django_geo_db_zipcode" VALUES(6814,17059,-5,'Mifflintown, Pennsylvania 17059',5125,6222);
INSERT INTO "django_geo_db_zipcode" VALUES(6815,17060,-5,'Mill Creek, Pennsylvania 17060',5126,6223);
INSERT INTO "django_geo_db_zipcode" VALUES(6816,17061,-5,'Millersburg, Pennsylvania 17061',5127,6224);
INSERT INTO "django_geo_db_zipcode" VALUES(6817,17062,-5,'Millerstown, Pennsylvania 17062',5128,6225);
INSERT INTO "django_geo_db_zipcode" VALUES(6818,17063,-5,'Milroy, Pennsylvania 17063',5129,6226);
INSERT INTO "django_geo_db_zipcode" VALUES(6819,17064,-5,'Mount Gretna, Pennsylvania 17064',5130,6227);
INSERT INTO "django_geo_db_zipcode" VALUES(6820,17065,-5,'Mount Holly Springs, Pennsylvania 17065',5131,6228);
INSERT INTO "django_geo_db_zipcode" VALUES(6821,17066,-5,'Mount Union, Pennsylvania 17066',5132,6229);
INSERT INTO "django_geo_db_zipcode" VALUES(6822,17067,-5,'Myerstown, Pennsylvania 17067',5133,6230);
INSERT INTO "django_geo_db_zipcode" VALUES(6823,17068,-5,'New Bloomfield, Pennsylvania 17068',5134,6231);
INSERT INTO "django_geo_db_zipcode" VALUES(6824,17069,-5,'New Buffalo, Pennsylvania 17069',5135,6232);
INSERT INTO "django_geo_db_zipcode" VALUES(6825,17070,-5,'New Cumberland, Pennsylvania 17070',5136,6233);
INSERT INTO "django_geo_db_zipcode" VALUES(6826,17071,-5,'New Germantown, Pennsylvania 17071',5137,6195);
INSERT INTO "django_geo_db_zipcode" VALUES(6827,17072,-5,'New Kingstown, Pennsylvania 17072',5138,6234);
INSERT INTO "django_geo_db_zipcode" VALUES(6828,17073,-5,'Newmanstown, Pennsylvania 17073',5139,6235);
INSERT INTO "django_geo_db_zipcode" VALUES(6829,17074,-5,'Newport, Pennsylvania 17074',5140,6236);
INSERT INTO "django_geo_db_zipcode" VALUES(6830,17075,-5,'Newton Hamilton, Pennsylvania 17075',5141,6237);
INSERT INTO "django_geo_db_zipcode" VALUES(6831,17076,-5,'Oakland Mills, Pennsylvania 17076',5142,6238);
INSERT INTO "django_geo_db_zipcode" VALUES(6832,17077,-5,'Ono, Pennsylvania 17077',5143,6239);
INSERT INTO "django_geo_db_zipcode" VALUES(6833,17078,-5,'Palmyra, Pennsylvania 17078',5144,6240);
INSERT INTO "django_geo_db_zipcode" VALUES(6834,17080,-5,'Pillow, Pennsylvania 17080',5145,6241);
INSERT INTO "django_geo_db_zipcode" VALUES(6835,17081,-5,'Plainfield, Pennsylvania 17081',5146,6242);
INSERT INTO "django_geo_db_zipcode" VALUES(6836,17082,-5,'Port Royal, Pennsylvania 17082',5147,6243);
INSERT INTO "django_geo_db_zipcode" VALUES(6837,17083,-5,'Quentin, Pennsylvania 17083',5148,6244);
INSERT INTO "django_geo_db_zipcode" VALUES(6838,17084,-5,'Reedsville, Pennsylvania 17084',5149,6245);
INSERT INTO "django_geo_db_zipcode" VALUES(6839,17085,-5,'Rexmont, Pennsylvania 17085',5150,6246);
INSERT INTO "django_geo_db_zipcode" VALUES(6840,17086,-5,'Richfield, Pennsylvania 17086',5151,6247);
INSERT INTO "django_geo_db_zipcode" VALUES(6841,17087,-5,'Richland, Pennsylvania 17087',5152,6248);
INSERT INTO "django_geo_db_zipcode" VALUES(6842,17088,-5,'Schaefferstown, Pennsylvania 17088',5153,6249);
INSERT INTO "django_geo_db_zipcode" VALUES(6843,17089,-5,'Camp Hill, Pennsylvania 17089',5071,6250);
INSERT INTO "django_geo_db_zipcode" VALUES(6844,17090,-5,'Shermans Dale, Pennsylvania 17090',5154,6251);
INSERT INTO "django_geo_db_zipcode" VALUES(6845,17091,-5,'Camp Hill, Pennsylvania 17091',5071,6176);
INSERT INTO "django_geo_db_zipcode" VALUES(6846,17093,-5,'Summerdale, Pennsylvania 17093',5155,6252);
INSERT INTO "django_geo_db_zipcode" VALUES(6847,17094,-5,'Thompsontown, Pennsylvania 17094',5156,6253);
INSERT INTO "django_geo_db_zipcode" VALUES(6848,17097,-5,'Wiconisco, Pennsylvania 17097',5157,6254);
INSERT INTO "django_geo_db_zipcode" VALUES(6849,17098,-5,'Williamstown, Pennsylvania 17098',5158,6255);
INSERT INTO "django_geo_db_zipcode" VALUES(6850,17099,-5,'Yeagertown, Pennsylvania 17099',5159,6256);
INSERT INTO "django_geo_db_zipcode" VALUES(6851,17101,-5,'Harrisburg, Pennsylvania 17101',5160,6257);
INSERT INTO "django_geo_db_zipcode" VALUES(6852,17102,-5,'Harrisburg, Pennsylvania 17102',5160,6258);
INSERT INTO "django_geo_db_zipcode" VALUES(6853,17103,-5,'Harrisburg, Pennsylvania 17103',5160,6259);
INSERT INTO "django_geo_db_zipcode" VALUES(6854,17104,-5,'Harrisburg, Pennsylvania 17104',5160,6260);
INSERT INTO "django_geo_db_zipcode" VALUES(6855,17105,-5,'Harrisburg, Pennsylvania 17105',5160,6261);
INSERT INTO "django_geo_db_zipcode" VALUES(6856,17106,-5,'Harrisburg, Pennsylvania 17106',5160,6262);
INSERT INTO "django_geo_db_zipcode" VALUES(6857,17107,-5,'Harrisburg, Pennsylvania 17107',5160,6263);
INSERT INTO "django_geo_db_zipcode" VALUES(6858,17108,-5,'Harrisburg, Pennsylvania 17108',5160,6264);
INSERT INTO "django_geo_db_zipcode" VALUES(6859,17109,-5,'Harrisburg, Pennsylvania 17109',5160,6265);
INSERT INTO "django_geo_db_zipcode" VALUES(6860,17110,-5,'Harrisburg, Pennsylvania 17110',5160,6266);
INSERT INTO "django_geo_db_zipcode" VALUES(6861,17111,-5,'Harrisburg, Pennsylvania 17111',5160,6267);
INSERT INTO "django_geo_db_zipcode" VALUES(6862,17112,-5,'Harrisburg, Pennsylvania 17112',5160,6268);
INSERT INTO "django_geo_db_zipcode" VALUES(6863,17113,-5,'Harrisburg, Pennsylvania 17113',5160,6269);
INSERT INTO "django_geo_db_zipcode" VALUES(6864,17120,-5,'Harrisburg, Pennsylvania 17120',5160,6270);
INSERT INTO "django_geo_db_zipcode" VALUES(6865,17121,-5,'Harrisburg, Pennsylvania 17121',5160,6271);
INSERT INTO "django_geo_db_zipcode" VALUES(6866,17122,-5,'Harrisburg, Pennsylvania 17122',5160,6272);
INSERT INTO "django_geo_db_zipcode" VALUES(6867,17123,-5,'Harrisburg, Pennsylvania 17123',5160,6273);
INSERT INTO "django_geo_db_zipcode" VALUES(6868,17124,-5,'Harrisburg, Pennsylvania 17124',5160,6274);
INSERT INTO "django_geo_db_zipcode" VALUES(6869,17125,-5,'Harrisburg, Pennsylvania 17125',5160,6275);
INSERT INTO "django_geo_db_zipcode" VALUES(6870,17126,-5,'Harrisburg, Pennsylvania 17126',5160,6276);
INSERT INTO "django_geo_db_zipcode" VALUES(6871,17127,-5,'Harrisburg, Pennsylvania 17127',5160,6277);
INSERT INTO "django_geo_db_zipcode" VALUES(6872,17128,-5,'Harrisburg, Pennsylvania 17128',5160,6278);
INSERT INTO "django_geo_db_zipcode" VALUES(6873,17129,-5,'Harrisburg, Pennsylvania 17129',5160,6277);
INSERT INTO "django_geo_db_zipcode" VALUES(6874,17130,-5,'Harrisburg, Pennsylvania 17130',5160,6279);
INSERT INTO "django_geo_db_zipcode" VALUES(6875,17140,-5,'Harrisburg, Pennsylvania 17140',5160,6280);
INSERT INTO "django_geo_db_zipcode" VALUES(6876,17177,-5,'Harrisburg, Pennsylvania 17177',5160,6281);
INSERT INTO "django_geo_db_zipcode" VALUES(6877,17201,-5,'Chambersburg, Pennsylvania 17201',5161,6282);
INSERT INTO "django_geo_db_zipcode" VALUES(6878,17210,-5,'Amberson, Pennsylvania 17210',5162,6283);
INSERT INTO "django_geo_db_zipcode" VALUES(6879,17211,-5,'Artemas, Pennsylvania 17211',5163,6284);
INSERT INTO "django_geo_db_zipcode" VALUES(6880,17212,-5,'Big Cove Tannery, Pennsylvania 17212',5164,6285);
INSERT INTO "django_geo_db_zipcode" VALUES(6881,17213,-5,'Blairs Mills, Pennsylvania 17213',5165,6286);
INSERT INTO "django_geo_db_zipcode" VALUES(6882,17214,-5,'Blue Ridge Summit, Pennsylvania 17214',5166,6287);
INSERT INTO "django_geo_db_zipcode" VALUES(6883,17215,-5,'Burnt Cabins, Pennsylvania 17215',5167,6288);
INSERT INTO "django_geo_db_zipcode" VALUES(6884,17217,-5,'Concord, Pennsylvania 17217',5168,6289);
INSERT INTO "django_geo_db_zipcode" VALUES(6885,17219,-5,'Doylesburg, Pennsylvania 17219',5169,6290);
INSERT INTO "django_geo_db_zipcode" VALUES(6886,17220,-5,'Dry Run, Pennsylvania 17220',5170,6291);
INSERT INTO "django_geo_db_zipcode" VALUES(6887,17221,-5,'Fannettsburg, Pennsylvania 17221',5171,6292);
INSERT INTO "django_geo_db_zipcode" VALUES(6888,17222,-5,'Fayetteville, Pennsylvania 17222',5172,6293);
INSERT INTO "django_geo_db_zipcode" VALUES(6889,17223,-5,'Fort Littleton, Pennsylvania 17223',5173,6294);
INSERT INTO "django_geo_db_zipcode" VALUES(6890,17224,-5,'Fort Loudon, Pennsylvania 17224',5174,6295);
INSERT INTO "django_geo_db_zipcode" VALUES(6891,17225,-5,'Greencastle, Pennsylvania 17225',5175,6296);
INSERT INTO "django_geo_db_zipcode" VALUES(6892,17228,-5,'Harrisonville, Pennsylvania 17228',5176,6297);
INSERT INTO "django_geo_db_zipcode" VALUES(6893,17229,-5,'Hustontown, Pennsylvania 17229',5177,6298);
INSERT INTO "django_geo_db_zipcode" VALUES(6894,17231,-5,'Lemasters, Pennsylvania 17231',5178,6299);
INSERT INTO "django_geo_db_zipcode" VALUES(6895,17232,-5,'Lurgan, Pennsylvania 17232',5179,6300);
INSERT INTO "django_geo_db_zipcode" VALUES(6896,17233,-5,'McConnellsburg, Pennsylvania 17233',5180,6301);
INSERT INTO "django_geo_db_zipcode" VALUES(6897,17235,-5,'Marion, Pennsylvania 17235',5181,6302);
INSERT INTO "django_geo_db_zipcode" VALUES(6898,17236,-5,'Mercersburg, Pennsylvania 17236',5182,6303);
INSERT INTO "django_geo_db_zipcode" VALUES(6899,17237,-5,'Mont Alto, Pennsylvania 17237',5183,6304);
INSERT INTO "django_geo_db_zipcode" VALUES(6900,17238,-5,'Needmore, Pennsylvania 17238',5184,6305);
INSERT INTO "django_geo_db_zipcode" VALUES(6901,17239,-5,'Neelyton, Pennsylvania 17239',5185,6306);
INSERT INTO "django_geo_db_zipcode" VALUES(6902,17240,-5,'Newburg, Pennsylvania 17240',5186,6307);
INSERT INTO "django_geo_db_zipcode" VALUES(6903,17241,-5,'Newville, Pennsylvania 17241',5187,6308);
INSERT INTO "django_geo_db_zipcode" VALUES(6904,17243,-5,'Orbisonia, Pennsylvania 17243',5188,6309);
INSERT INTO "django_geo_db_zipcode" VALUES(6905,17244,-5,'Orrstown, Pennsylvania 17244',5189,6310);
INSERT INTO "django_geo_db_zipcode" VALUES(6906,17246,-5,'Pleasant Hall, Pennsylvania 17246',5190,6311);
INSERT INTO "django_geo_db_zipcode" VALUES(6907,17247,-5,'Quincy, Pennsylvania 17247',5191,6312);
INSERT INTO "django_geo_db_zipcode" VALUES(6908,17249,-5,'Rockhill Furnace, Pennsylvania 17249',5192,6313);
INSERT INTO "django_geo_db_zipcode" VALUES(6909,17250,-5,'Rouzerville, Pennsylvania 17250',5193,6314);
INSERT INTO "django_geo_db_zipcode" VALUES(6910,17251,-5,'Roxbury, Pennsylvania 17251',5194,6315);
INSERT INTO "django_geo_db_zipcode" VALUES(6911,17252,-5,'Saint Thomas, Pennsylvania 17252',5195,6316);
INSERT INTO "django_geo_db_zipcode" VALUES(6912,17253,-5,'Saltillo, Pennsylvania 17253',5196,6317);
INSERT INTO "django_geo_db_zipcode" VALUES(6913,17254,-5,'Scotland, Pennsylvania 17254',5197,6318);
INSERT INTO "django_geo_db_zipcode" VALUES(6914,17255,-5,'Shade Gap, Pennsylvania 17255',5198,6319);
INSERT INTO "django_geo_db_zipcode" VALUES(6915,17256,-5,'Shady Grove, Pennsylvania 17256',5199,6320);
INSERT INTO "django_geo_db_zipcode" VALUES(6916,17257,-5,'Shippensburg, Pennsylvania 17257',5200,6321);
INSERT INTO "django_geo_db_zipcode" VALUES(6917,17260,-5,'Shirleysburg, Pennsylvania 17260',5201,6322);
INSERT INTO "django_geo_db_zipcode" VALUES(6918,17261,-5,'South Mountain, Pennsylvania 17261',5202,6323);
INSERT INTO "django_geo_db_zipcode" VALUES(6919,17262,-5,'Spring Run, Pennsylvania 17262',5203,6324);
INSERT INTO "django_geo_db_zipcode" VALUES(6920,17263,-5,'State Line, Pennsylvania 17263',5204,6325);
INSERT INTO "django_geo_db_zipcode" VALUES(6921,17264,-5,'Three Springs, Pennsylvania 17264',5205,6326);
INSERT INTO "django_geo_db_zipcode" VALUES(6922,17265,-5,'Upperstrasburg, Pennsylvania 17265',5206,6327);
INSERT INTO "django_geo_db_zipcode" VALUES(6923,17266,-5,'Walnut Bottom, Pennsylvania 17266',5207,6328);
INSERT INTO "django_geo_db_zipcode" VALUES(6924,17267,-5,'Warfordsburg, Pennsylvania 17267',5208,6329);
INSERT INTO "django_geo_db_zipcode" VALUES(6925,17268,-5,'Waynesboro, Pennsylvania 17268',5209,6330);
INSERT INTO "django_geo_db_zipcode" VALUES(6926,17269,-5,'Brush Creek, Pennsylvania 17269',5210,6331);
INSERT INTO "django_geo_db_zipcode" VALUES(6927,17270,-5,'Williamson, Pennsylvania 17270',5211,6332);
INSERT INTO "django_geo_db_zipcode" VALUES(6928,17271,-5,'Willow Hill, Pennsylvania 17271',5212,6333);
INSERT INTO "django_geo_db_zipcode" VALUES(6929,17272,-5,'Zullinger, Pennsylvania 17272',5213,6334);
INSERT INTO "django_geo_db_zipcode" VALUES(6930,17275,-5,'Southampton, Pennsylvania 17275',5214,6335);
INSERT INTO "django_geo_db_zipcode" VALUES(6931,17294,-5,'Blue Ridge Summit, Pennsylvania 17294',5166,6336);
INSERT INTO "django_geo_db_zipcode" VALUES(6932,17301,-5,'Abbottstown, Pennsylvania 17301',5215,6337);
INSERT INTO "django_geo_db_zipcode" VALUES(6933,17302,-5,'Airville, Pennsylvania 17302',5216,6338);
INSERT INTO "django_geo_db_zipcode" VALUES(6934,17303,-5,'Arendtsville, Pennsylvania 17303',5217,6339);
INSERT INTO "django_geo_db_zipcode" VALUES(6935,17304,-5,'Aspers, Pennsylvania 17304',5218,6340);
INSERT INTO "django_geo_db_zipcode" VALUES(6936,17306,-5,'Bendersville, Pennsylvania 17306',5219,6341);
INSERT INTO "django_geo_db_zipcode" VALUES(6937,17307,-5,'Biglerville, Pennsylvania 17307',5220,6342);
INSERT INTO "django_geo_db_zipcode" VALUES(6938,17309,-5,'Brogue, Pennsylvania 17309',5221,6343);
INSERT INTO "django_geo_db_zipcode" VALUES(6939,17310,-5,'Cashtown, Pennsylvania 17310',5222,6344);
INSERT INTO "django_geo_db_zipcode" VALUES(6940,17311,-5,'Codorus, Pennsylvania 17311',5223,6345);
INSERT INTO "django_geo_db_zipcode" VALUES(6941,17312,-5,'Craley, Pennsylvania 17312',5224,6346);
INSERT INTO "django_geo_db_zipcode" VALUES(6942,17313,-5,'Dallastown, Pennsylvania 17313',5225,6347);
INSERT INTO "django_geo_db_zipcode" VALUES(6943,17314,-5,'Delta, Pennsylvania 17314',5226,6348);
INSERT INTO "django_geo_db_zipcode" VALUES(6944,17315,-5,'Dover, Pennsylvania 17315',5227,6349);
INSERT INTO "django_geo_db_zipcode" VALUES(6945,17316,-5,'East Berlin, Pennsylvania 17316',5228,6350);
INSERT INTO "django_geo_db_zipcode" VALUES(6946,17317,-5,'East Prospect, Pennsylvania 17317',5229,6351);
INSERT INTO "django_geo_db_zipcode" VALUES(6947,17318,-5,'Emigsville, Pennsylvania 17318',5230,6352);
INSERT INTO "django_geo_db_zipcode" VALUES(6948,17319,-5,'Etters, Pennsylvania 17319',5231,6353);
INSERT INTO "django_geo_db_zipcode" VALUES(6949,17320,-5,'Fairfield, Pennsylvania 17320',5232,6354);
INSERT INTO "django_geo_db_zipcode" VALUES(6950,17321,-5,'Fawn Grove, Pennsylvania 17321',5233,6355);
INSERT INTO "django_geo_db_zipcode" VALUES(6951,17322,-5,'Felton, Pennsylvania 17322',5234,6356);
INSERT INTO "django_geo_db_zipcode" VALUES(6952,17323,-5,'Franklintown, Pennsylvania 17323',5235,6357);
INSERT INTO "django_geo_db_zipcode" VALUES(6953,17324,-5,'Gardners, Pennsylvania 17324',5236,6358);
INSERT INTO "django_geo_db_zipcode" VALUES(6954,17325,-5,'Gettysburg, Pennsylvania 17325',5237,6359);
INSERT INTO "django_geo_db_zipcode" VALUES(6955,17326,-5,'Gettysburg, Pennsylvania 17326',5237,6360);
INSERT INTO "django_geo_db_zipcode" VALUES(6956,17327,-5,'Glen Rock, Pennsylvania 17327',5238,6361);
INSERT INTO "django_geo_db_zipcode" VALUES(6957,17329,-5,'Glenville, Pennsylvania 17329',5239,6362);
INSERT INTO "django_geo_db_zipcode" VALUES(6958,17331,-5,'Hanover, Pennsylvania 17331',5240,6363);
INSERT INTO "django_geo_db_zipcode" VALUES(6959,17332,-5,'Hanover, Pennsylvania 17332',5240,6364);
INSERT INTO "django_geo_db_zipcode" VALUES(6960,17333,-5,'Hanover, Pennsylvania 17333',5240,6365);
INSERT INTO "django_geo_db_zipcode" VALUES(6961,17337,-5,'Idaville, Pennsylvania 17337',5241,6366);
INSERT INTO "django_geo_db_zipcode" VALUES(6962,17339,-5,'Lewisberry, Pennsylvania 17339',5242,6367);
INSERT INTO "django_geo_db_zipcode" VALUES(6963,17340,-5,'Littlestown, Pennsylvania 17340',5243,6368);
INSERT INTO "django_geo_db_zipcode" VALUES(6964,17342,-5,'Loganville, Pennsylvania 17342',5244,6369);
INSERT INTO "django_geo_db_zipcode" VALUES(6965,17343,-5,'McKnightstown, Pennsylvania 17343',5245,6370);
INSERT INTO "django_geo_db_zipcode" VALUES(6966,17344,-5,'McSherrystown, Pennsylvania 17344',5246,6371);
INSERT INTO "django_geo_db_zipcode" VALUES(6967,17345,-5,'Manchester, Pennsylvania 17345',5247,6372);
INSERT INTO "django_geo_db_zipcode" VALUES(6968,17346,-5,'Menges Mills, Pennsylvania 17346',5248,6373);
INSERT INTO "django_geo_db_zipcode" VALUES(6969,17347,-5,'Mount Wolf, Pennsylvania 17347',5249,6374);
INSERT INTO "django_geo_db_zipcode" VALUES(6970,17349,-5,'New Freedom, Pennsylvania 17349',5250,6375);
INSERT INTO "django_geo_db_zipcode" VALUES(6971,17350,-5,'New Oxford, Pennsylvania 17350',5251,6376);
INSERT INTO "django_geo_db_zipcode" VALUES(6972,17352,-5,'New Park, Pennsylvania 17352',5252,6377);
INSERT INTO "django_geo_db_zipcode" VALUES(6973,17353,-5,'Orrtanna, Pennsylvania 17353',5253,6378);
INSERT INTO "django_geo_db_zipcode" VALUES(6974,17354,-5,'Porters Sideling, Pennsylvania 17354',5254,6379);
INSERT INTO "django_geo_db_zipcode" VALUES(6975,17355,-5,'Railroad, Pennsylvania 17355',5255,6380);
INSERT INTO "django_geo_db_zipcode" VALUES(6976,17356,-5,'Red Lion, Pennsylvania 17356',5256,6381);
INSERT INTO "django_geo_db_zipcode" VALUES(6977,17358,-5,'Rossville, Pennsylvania 17358',5257,6365);
INSERT INTO "django_geo_db_zipcode" VALUES(6978,17360,-5,'Seven Valleys, Pennsylvania 17360',5258,6382);
INSERT INTO "django_geo_db_zipcode" VALUES(6979,17361,-5,'Shrewsbury, Pennsylvania 17361',5259,6383);
INSERT INTO "django_geo_db_zipcode" VALUES(6980,17362,-5,'Spring Grove, Pennsylvania 17362',5260,6384);
INSERT INTO "django_geo_db_zipcode" VALUES(6981,17363,-5,'Stewartstown, Pennsylvania 17363',5261,6385);
INSERT INTO "django_geo_db_zipcode" VALUES(6982,17364,-5,'Thomasville, Pennsylvania 17364',5262,6386);
INSERT INTO "django_geo_db_zipcode" VALUES(6983,17365,-5,'Wellsville, Pennsylvania 17365',5263,6387);
INSERT INTO "django_geo_db_zipcode" VALUES(6984,17366,-5,'Windsor, Pennsylvania 17366',5264,6388);
INSERT INTO "django_geo_db_zipcode" VALUES(6985,17368,-5,'Wrightsville, Pennsylvania 17368',5265,6389);
INSERT INTO "django_geo_db_zipcode" VALUES(6986,17370,-5,'York Haven, Pennsylvania 17370',5266,6390);
INSERT INTO "django_geo_db_zipcode" VALUES(6987,17371,-5,'York New Salem, Pennsylvania 17371',5267,6391);
INSERT INTO "django_geo_db_zipcode" VALUES(6988,17372,-5,'York Springs, Pennsylvania 17372',5268,6392);
INSERT INTO "django_geo_db_zipcode" VALUES(6989,17375,-5,'Peach Glen, Pennsylvania 17375',5269,6360);
INSERT INTO "django_geo_db_zipcode" VALUES(6990,17401,-5,'York, Pennsylvania 17401',5270,6393);
INSERT INTO "django_geo_db_zipcode" VALUES(6991,17402,-5,'York, Pennsylvania 17402',5270,6394);
INSERT INTO "django_geo_db_zipcode" VALUES(6992,17403,-5,'York, Pennsylvania 17403',5270,6395);
INSERT INTO "django_geo_db_zipcode" VALUES(6993,17404,-5,'York, Pennsylvania 17404',5270,6396);
INSERT INTO "django_geo_db_zipcode" VALUES(6994,17405,-5,'York, Pennsylvania 17405',5270,6397);
INSERT INTO "django_geo_db_zipcode" VALUES(6995,17406,-5,'York, Pennsylvania 17406',5270,6398);
INSERT INTO "django_geo_db_zipcode" VALUES(6996,17407,-5,'York, Pennsylvania 17407',5270,6399);
INSERT INTO "django_geo_db_zipcode" VALUES(6997,17415,-5,'York, Pennsylvania 17415',5270,6365);
INSERT INTO "django_geo_db_zipcode" VALUES(6998,17501,-5,'Akron, Pennsylvania 17501',5271,6400);
INSERT INTO "django_geo_db_zipcode" VALUES(6999,17502,-5,'Bainbridge, Pennsylvania 17502',5272,6401);
INSERT INTO "django_geo_db_zipcode" VALUES(7000,17503,-5,'Bart, Pennsylvania 17503',5273,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7001,17504,-5,'Bausman, Pennsylvania 17504',5274,6403);
INSERT INTO "django_geo_db_zipcode" VALUES(7002,17505,-5,'Bird In Hand, Pennsylvania 17505',5275,6404);
INSERT INTO "django_geo_db_zipcode" VALUES(7003,17506,-5,'Blue Ball, Pennsylvania 17506',5276,6405);
INSERT INTO "django_geo_db_zipcode" VALUES(7004,17507,-5,'Bowmansville, Pennsylvania 17507',5277,6406);
INSERT INTO "django_geo_db_zipcode" VALUES(7005,17508,-5,'Brownstown, Pennsylvania 17508',5278,6407);
INSERT INTO "django_geo_db_zipcode" VALUES(7006,17509,-5,'Christiana, Pennsylvania 17509',5279,6408);
INSERT INTO "django_geo_db_zipcode" VALUES(7007,17511,-5,'Columbia, Pennsylvania 17511',5280,6409);
INSERT INTO "django_geo_db_zipcode" VALUES(7008,17512,-5,'Columbia, Pennsylvania 17512',5280,6410);
INSERT INTO "django_geo_db_zipcode" VALUES(7009,17516,-5,'Conestoga, Pennsylvania 17516',5281,6411);
INSERT INTO "django_geo_db_zipcode" VALUES(7010,17517,-5,'Denver, Pennsylvania 17517',5282,6412);
INSERT INTO "django_geo_db_zipcode" VALUES(7011,17518,-5,'Drumore, Pennsylvania 17518',5283,6413);
INSERT INTO "django_geo_db_zipcode" VALUES(7012,17519,-5,'East Earl, Pennsylvania 17519',5284,6414);
INSERT INTO "django_geo_db_zipcode" VALUES(7013,17520,-5,'East Petersburg, Pennsylvania 17520',5285,6415);
INSERT INTO "django_geo_db_zipcode" VALUES(7014,17521,-5,'Elm, Pennsylvania 17521',5286,6416);
INSERT INTO "django_geo_db_zipcode" VALUES(7015,17522,-5,'Ephrata, Pennsylvania 17522',5287,6417);
INSERT INTO "django_geo_db_zipcode" VALUES(7016,17527,-5,'Gap, Pennsylvania 17527',5288,6418);
INSERT INTO "django_geo_db_zipcode" VALUES(7017,17528,-5,'Goodville, Pennsylvania 17528',5289,6419);
INSERT INTO "django_geo_db_zipcode" VALUES(7018,17529,-5,'Gordonville, Pennsylvania 17529',5290,6420);
INSERT INTO "django_geo_db_zipcode" VALUES(7019,17532,-5,'Holtwood, Pennsylvania 17532',5291,6421);
INSERT INTO "django_geo_db_zipcode" VALUES(7020,17533,-5,'Hopeland, Pennsylvania 17533',5292,6422);
INSERT INTO "django_geo_db_zipcode" VALUES(7021,17534,-5,'Intercourse, Pennsylvania 17534',5293,6423);
INSERT INTO "django_geo_db_zipcode" VALUES(7022,17535,-5,'Kinzers, Pennsylvania 17535',5294,6424);
INSERT INTO "django_geo_db_zipcode" VALUES(7023,17536,-5,'Kirkwood, Pennsylvania 17536',5295,6425);
INSERT INTO "django_geo_db_zipcode" VALUES(7024,17537,-5,'Lampeter, Pennsylvania 17537',5296,6426);
INSERT INTO "django_geo_db_zipcode" VALUES(7025,17538,-5,'Landisville, Pennsylvania 17538',5297,6427);
INSERT INTO "django_geo_db_zipcode" VALUES(7026,17540,-5,'Leola, Pennsylvania 17540',5298,6428);
INSERT INTO "django_geo_db_zipcode" VALUES(7027,17543,-5,'Lititz, Pennsylvania 17543',5299,6429);
INSERT INTO "django_geo_db_zipcode" VALUES(7028,17545,-5,'Manheim, Pennsylvania 17545',5300,6430);
INSERT INTO "django_geo_db_zipcode" VALUES(7029,17547,-5,'Marietta, Pennsylvania 17547',5301,6431);
INSERT INTO "django_geo_db_zipcode" VALUES(7030,17549,-5,'Martindale, Pennsylvania 17549',5302,6432);
INSERT INTO "django_geo_db_zipcode" VALUES(7031,17550,-5,'Maytown, Pennsylvania 17550',5303,6433);
INSERT INTO "django_geo_db_zipcode" VALUES(7032,17551,-5,'Millersville, Pennsylvania 17551',5304,6434);
INSERT INTO "django_geo_db_zipcode" VALUES(7033,17552,-5,'Mount Joy, Pennsylvania 17552',5305,6435);
INSERT INTO "django_geo_db_zipcode" VALUES(7034,17554,-5,'Mountville, Pennsylvania 17554',5306,6436);
INSERT INTO "django_geo_db_zipcode" VALUES(7035,17555,-5,'Narvon, Pennsylvania 17555',5307,6437);
INSERT INTO "django_geo_db_zipcode" VALUES(7036,17557,-5,'New Holland, Pennsylvania 17557',5308,6438);
INSERT INTO "django_geo_db_zipcode" VALUES(7037,17560,-5,'New Providence, Pennsylvania 17560',5309,6439);
INSERT INTO "django_geo_db_zipcode" VALUES(7038,17562,-5,'Paradise, Pennsylvania 17562',5310,6440);
INSERT INTO "django_geo_db_zipcode" VALUES(7039,17563,-5,'Peach Bottom, Pennsylvania 17563',5311,6441);
INSERT INTO "django_geo_db_zipcode" VALUES(7040,17564,-5,'Penryn, Pennsylvania 17564',5312,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7041,17565,-5,'Pequea, Pennsylvania 17565',5313,6442);
INSERT INTO "django_geo_db_zipcode" VALUES(7042,17566,-5,'Quarryville, Pennsylvania 17566',5314,6443);
INSERT INTO "django_geo_db_zipcode" VALUES(7043,17567,-5,'Reamstown, Pennsylvania 17567',5315,6444);
INSERT INTO "django_geo_db_zipcode" VALUES(7044,17568,-5,'Refton, Pennsylvania 17568',5316,6445);
INSERT INTO "django_geo_db_zipcode" VALUES(7045,17569,-5,'Reinholds, Pennsylvania 17569',5317,6446);
INSERT INTO "django_geo_db_zipcode" VALUES(7046,17570,-5,'Rheems, Pennsylvania 17570',5318,6447);
INSERT INTO "django_geo_db_zipcode" VALUES(7047,17572,-5,'Ronks, Pennsylvania 17572',5319,6448);
INSERT INTO "django_geo_db_zipcode" VALUES(7048,17573,-5,'Ronks, Pennsylvania 17573',5319,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7049,17575,-5,'Silver Spring, Pennsylvania 17575',5320,6449);
INSERT INTO "django_geo_db_zipcode" VALUES(7050,17576,-5,'Smoketown, Pennsylvania 17576',5321,6450);
INSERT INTO "django_geo_db_zipcode" VALUES(7051,17577,-5,'Soudersburg, Pennsylvania 17577',5322,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7052,17578,-5,'Stevens, Pennsylvania 17578',5323,6451);
INSERT INTO "django_geo_db_zipcode" VALUES(7053,17579,-5,'Strasburg, Pennsylvania 17579',5324,6452);
INSERT INTO "django_geo_db_zipcode" VALUES(7054,17580,-5,'Talmage, Pennsylvania 17580',5325,6453);
INSERT INTO "django_geo_db_zipcode" VALUES(7055,17581,-5,'Terre Hill, Pennsylvania 17581',5326,6454);
INSERT INTO "django_geo_db_zipcode" VALUES(7056,17582,-5,'Washington Boro, Pennsylvania 17582',5327,6455);
INSERT INTO "django_geo_db_zipcode" VALUES(7057,17583,-5,'West Willow, Pennsylvania 17583',5328,6456);
INSERT INTO "django_geo_db_zipcode" VALUES(7058,17584,-5,'Willow Street, Pennsylvania 17584',5329,6457);
INSERT INTO "django_geo_db_zipcode" VALUES(7059,17585,-5,'Witmer, Pennsylvania 17585',5330,6458);
INSERT INTO "django_geo_db_zipcode" VALUES(7060,17601,-5,'Lancaster, Pennsylvania 17601',5331,6459);
INSERT INTO "django_geo_db_zipcode" VALUES(7061,17602,-5,'Lancaster, Pennsylvania 17602',5331,6460);
INSERT INTO "django_geo_db_zipcode" VALUES(7062,17603,-5,'Lancaster, Pennsylvania 17603',5331,6461);
INSERT INTO "django_geo_db_zipcode" VALUES(7063,17604,-5,'Lancaster, Pennsylvania 17604',5331,6462);
INSERT INTO "django_geo_db_zipcode" VALUES(7064,17605,-5,'Lancaster, Pennsylvania 17605',5331,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7065,17606,-5,'Lancaster, Pennsylvania 17606',5331,6463);
INSERT INTO "django_geo_db_zipcode" VALUES(7066,17607,-5,'Lancaster, Pennsylvania 17607',5331,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7067,17608,-5,'Lancaster, Pennsylvania 17608',5331,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7068,17699,-5,'Lancaster, Pennsylvania 17699',5331,6402);
INSERT INTO "django_geo_db_zipcode" VALUES(7069,17701,-5,'Williamsport, Pennsylvania 17701',5332,6464);
INSERT INTO "django_geo_db_zipcode" VALUES(7070,17702,-5,'Williamsport, Pennsylvania 17702',5332,6465);
INSERT INTO "django_geo_db_zipcode" VALUES(7071,17703,-5,'Williamsport, Pennsylvania 17703',5332,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7072,17705,-5,'Williamsport, Pennsylvania 17705',5332,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7073,17720,-5,'Antes Fort, Pennsylvania 17720',5333,6467);
INSERT INTO "django_geo_db_zipcode" VALUES(7074,17721,-5,'Avis, Pennsylvania 17721',5334,6468);
INSERT INTO "django_geo_db_zipcode" VALUES(7075,17722,-5,'Bodines, Pennsylvania 17722',5335,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7076,17723,-5,'Jersey Shore, Pennsylvania 17723',5336,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7077,17724,-5,'Canton, Pennsylvania 17724',5337,6469);
INSERT INTO "django_geo_db_zipcode" VALUES(7078,17726,-5,'Castanea, Pennsylvania 17726',5338,6470);
INSERT INTO "django_geo_db_zipcode" VALUES(7079,17727,-5,'Cedar Run, Pennsylvania 17727',5339,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7080,17728,-5,'Cogan Station, Pennsylvania 17728',5340,6471);
INSERT INTO "django_geo_db_zipcode" VALUES(7081,17729,-5,'Cross Fork, Pennsylvania 17729',5341,6472);
INSERT INTO "django_geo_db_zipcode" VALUES(7082,17730,-5,'Dewart, Pennsylvania 17730',5342,6473);
INSERT INTO "django_geo_db_zipcode" VALUES(7083,17731,-5,'Eagles Mere, Pennsylvania 17731',5343,6474);
INSERT INTO "django_geo_db_zipcode" VALUES(7084,17735,-5,'Grover, Pennsylvania 17735',5344,6133);
INSERT INTO "django_geo_db_zipcode" VALUES(7085,17737,-5,'Hughesville, Pennsylvania 17737',5345,6475);
INSERT INTO "django_geo_db_zipcode" VALUES(7086,17738,-5,'Hyner, Pennsylvania 17738',5346,6476);
INSERT INTO "django_geo_db_zipcode" VALUES(7087,17739,-5,'Jersey Mills, Pennsylvania 17739',5347,6477);
INSERT INTO "django_geo_db_zipcode" VALUES(7088,17740,-5,'Jersey Shore, Pennsylvania 17740',5336,6478);
INSERT INTO "django_geo_db_zipcode" VALUES(7089,17741,-5,'Watson, Pennsylvania 17741',5348,6479);
INSERT INTO "django_geo_db_zipcode" VALUES(7090,17742,-5,'Lairdsville, Pennsylvania 17742',5349,6480);
INSERT INTO "django_geo_db_zipcode" VALUES(7091,17743,-5,'Leroy, Pennsylvania 17743',5350,6133);
INSERT INTO "django_geo_db_zipcode" VALUES(7092,17744,-5,'Linden, Pennsylvania 17744',5351,6481);
INSERT INTO "django_geo_db_zipcode" VALUES(7093,17745,-5,'Lock Haven, Pennsylvania 17745',5352,6482);
INSERT INTO "django_geo_db_zipcode" VALUES(7094,17747,-5,'Loganton, Pennsylvania 17747',5353,6483);
INSERT INTO "django_geo_db_zipcode" VALUES(7095,17748,-5,'McElhattan, Pennsylvania 17748',5354,6484);
INSERT INTO "django_geo_db_zipcode" VALUES(7096,17749,-5,'McEwensville, Pennsylvania 17749',5355,6485);
INSERT INTO "django_geo_db_zipcode" VALUES(7097,17750,-5,'Mackeyville, Pennsylvania 17750',5356,6486);
INSERT INTO "django_geo_db_zipcode" VALUES(7098,17751,-5,'Mill Hall, Pennsylvania 17751',5357,6487);
INSERT INTO "django_geo_db_zipcode" VALUES(7099,17752,-5,'Montgomery, Pennsylvania 17752',5358,6488);
INSERT INTO "django_geo_db_zipcode" VALUES(7100,17754,-5,'Montoursville, Pennsylvania 17754',5359,6489);
INSERT INTO "django_geo_db_zipcode" VALUES(7101,17756,-5,'Muncy, Pennsylvania 17756',5360,6490);
INSERT INTO "django_geo_db_zipcode" VALUES(7102,17757,-5,'Wolf, Pennsylvania 17757',5361,6491);
INSERT INTO "django_geo_db_zipcode" VALUES(7103,17758,-5,'Muncy Valley, Pennsylvania 17758',5362,6492);
INSERT INTO "django_geo_db_zipcode" VALUES(7104,17759,-5,'Nisbet, Pennsylvania 17759',5363,6493);
INSERT INTO "django_geo_db_zipcode" VALUES(7105,17760,-5,'North Bend, Pennsylvania 17760',5364,6494);
INSERT INTO "django_geo_db_zipcode" VALUES(7106,17762,-5,'Picture Rocks, Pennsylvania 17762',5365,6495);
INSERT INTO "django_geo_db_zipcode" VALUES(7107,17763,-5,'Ralston, Pennsylvania 17763',5366,6496);
INSERT INTO "django_geo_db_zipcode" VALUES(7108,17764,-5,'Renovo, Pennsylvania 17764',5367,6497);
INSERT INTO "django_geo_db_zipcode" VALUES(7109,17765,-5,'Roaring Branch, Pennsylvania 17765',5368,6498);
INSERT INTO "django_geo_db_zipcode" VALUES(7110,17767,-5,'Salona, Pennsylvania 17767',5369,6499);
INSERT INTO "django_geo_db_zipcode" VALUES(7111,17768,-5,'Shunk, Pennsylvania 17768',5370,6500);
INSERT INTO "django_geo_db_zipcode" VALUES(7112,17769,-5,'Slate Run, Pennsylvania 17769',5371,6466);
INSERT INTO "django_geo_db_zipcode" VALUES(7113,17771,-5,'Trout Run, Pennsylvania 17771',5372,6501);
INSERT INTO "django_geo_db_zipcode" VALUES(7114,17772,-5,'Turbotville, Pennsylvania 17772',5373,6502);
INSERT INTO "django_geo_db_zipcode" VALUES(7115,17773,-5,'Tylersville, Pennsylvania 17773',5374,6503);
INSERT INTO "django_geo_db_zipcode" VALUES(7116,17774,-5,'Unityville, Pennsylvania 17774',5375,6504);
INSERT INTO "django_geo_db_zipcode" VALUES(7117,17776,-5,'Waterville, Pennsylvania 17776',5376,6505);
INSERT INTO "django_geo_db_zipcode" VALUES(7118,17777,-5,'Watsontown, Pennsylvania 17777',5377,6506);
INSERT INTO "django_geo_db_zipcode" VALUES(7119,17778,-5,'Westport, Pennsylvania 17778',5378,6507);
INSERT INTO "django_geo_db_zipcode" VALUES(7120,17779,-5,'Woolrich, Pennsylvania 17779',5379,6508);
INSERT INTO "django_geo_db_zipcode" VALUES(7121,17786,-5,'Penn, Pennsylvania 17786',4527,6509);
INSERT INTO "django_geo_db_zipcode" VALUES(7122,17801,-5,'Sunbury, Pennsylvania 17801',5380,6510);
INSERT INTO "django_geo_db_zipcode" VALUES(7123,17810,-5,'Allenwood, Pennsylvania 17810',5381,6511);
INSERT INTO "django_geo_db_zipcode" VALUES(7124,17812,-5,'Beaver Springs, Pennsylvania 17812',5382,6512);
INSERT INTO "django_geo_db_zipcode" VALUES(7125,17813,-5,'Beavertown, Pennsylvania 17813',5383,6513);
INSERT INTO "django_geo_db_zipcode" VALUES(7126,17814,-5,'Benton, Pennsylvania 17814',5384,6514);
INSERT INTO "django_geo_db_zipcode" VALUES(7127,17815,-5,'Bloomsburg, Pennsylvania 17815',5385,6515);
INSERT INTO "django_geo_db_zipcode" VALUES(7128,17820,-5,'Catawissa, Pennsylvania 17820',5386,6516);
INSERT INTO "django_geo_db_zipcode" VALUES(7129,17821,-5,'Danville, Pennsylvania 17821',5387,6517);
INSERT INTO "django_geo_db_zipcode" VALUES(7130,17822,-5,'Danville, Pennsylvania 17822',5387,6518);
INSERT INTO "django_geo_db_zipcode" VALUES(7131,17823,-5,'Dornsife, Pennsylvania 17823',5388,6519);
INSERT INTO "django_geo_db_zipcode" VALUES(7132,17824,-5,'Elysburg, Pennsylvania 17824',5389,6520);
INSERT INTO "django_geo_db_zipcode" VALUES(7133,17825,-5,'Excelsior, Pennsylvania 17825',5390,6521);
INSERT INTO "django_geo_db_zipcode" VALUES(7134,17827,-5,'Freeburg, Pennsylvania 17827',5391,6522);
INSERT INTO "django_geo_db_zipcode" VALUES(7135,17828,-5,'Gowen City, Pennsylvania 17828',5392,6523);
INSERT INTO "django_geo_db_zipcode" VALUES(7136,17829,-5,'Hartleton, Pennsylvania 17829',5393,6524);
INSERT INTO "django_geo_db_zipcode" VALUES(7137,17830,-5,'Herndon, Pennsylvania 17830',5394,6525);
INSERT INTO "django_geo_db_zipcode" VALUES(7138,17831,-5,'Hummels Wharf, Pennsylvania 17831',5395,6526);
INSERT INTO "django_geo_db_zipcode" VALUES(7139,17832,-5,'Marion Heights, Pennsylvania 17832',5396,6527);
INSERT INTO "django_geo_db_zipcode" VALUES(7140,17833,-5,'Kreamer, Pennsylvania 17833',5397,6528);
INSERT INTO "django_geo_db_zipcode" VALUES(7141,17834,-5,'Kulpmont, Pennsylvania 17834',5398,6529);
INSERT INTO "django_geo_db_zipcode" VALUES(7142,17835,-5,'Laurelton, Pennsylvania 17835',5399,6530);
INSERT INTO "django_geo_db_zipcode" VALUES(7143,17836,-5,'Leck Kill, Pennsylvania 17836',5400,6531);
INSERT INTO "django_geo_db_zipcode" VALUES(7144,17837,-5,'Lewisburg, Pennsylvania 17837',5401,6532);
INSERT INTO "django_geo_db_zipcode" VALUES(7145,17839,-5,'Light Street, Pennsylvania 17839',5402,6533);
INSERT INTO "django_geo_db_zipcode" VALUES(7146,17840,-5,'Locust Gap, Pennsylvania 17840',5403,6534);
INSERT INTO "django_geo_db_zipcode" VALUES(7147,17841,-5,'McClure, Pennsylvania 17841',5404,6535);
INSERT INTO "django_geo_db_zipcode" VALUES(7148,17842,-5,'Middleburg, Pennsylvania 17842',5405,6536);
INSERT INTO "django_geo_db_zipcode" VALUES(7149,17843,-5,'Beaver Springs, Pennsylvania 17843',5382,6537);
INSERT INTO "django_geo_db_zipcode" VALUES(7150,17844,-5,'Mifflinburg, Pennsylvania 17844',5406,6538);
INSERT INTO "django_geo_db_zipcode" VALUES(7151,17845,-5,'Millmont, Pennsylvania 17845',5407,6539);
INSERT INTO "django_geo_db_zipcode" VALUES(7152,17846,-5,'Millville, Pennsylvania 17846',5408,6540);
INSERT INTO "django_geo_db_zipcode" VALUES(7153,17847,-5,'Milton, Pennsylvania 17847',5409,6541);
INSERT INTO "django_geo_db_zipcode" VALUES(7154,17850,-5,'Montandon, Pennsylvania 17850',5410,6542);
INSERT INTO "django_geo_db_zipcode" VALUES(7155,17851,-5,'Mount Carmel, Pennsylvania 17851',5411,6543);
INSERT INTO "django_geo_db_zipcode" VALUES(7156,17853,-5,'Mount Pleasant Mills, Pennsylvania 17853',5412,6544);
INSERT INTO "django_geo_db_zipcode" VALUES(7157,17855,-5,'New Berlin, Pennsylvania 17855',5413,6545);
INSERT INTO "django_geo_db_zipcode" VALUES(7158,17856,-5,'New Columbia, Pennsylvania 17856',5414,6546);
INSERT INTO "django_geo_db_zipcode" VALUES(7159,17857,-5,'Northumberland, Pennsylvania 17857',5415,6547);
INSERT INTO "django_geo_db_zipcode" VALUES(7160,17858,-5,'Numidia, Pennsylvania 17858',5416,6548);
INSERT INTO "django_geo_db_zipcode" VALUES(7161,17859,-5,'Orangeville, Pennsylvania 17859',5417,6549);
INSERT INTO "django_geo_db_zipcode" VALUES(7162,17860,-5,'Paxinos, Pennsylvania 17860',5418,6550);
INSERT INTO "django_geo_db_zipcode" VALUES(7163,17861,-5,'Paxtonville, Pennsylvania 17861',5419,6551);
INSERT INTO "django_geo_db_zipcode" VALUES(7164,17862,-5,'Penns Creek, Pennsylvania 17862',5420,6552);
INSERT INTO "django_geo_db_zipcode" VALUES(7165,17864,-5,'Port Trevorton, Pennsylvania 17864',5421,6553);
INSERT INTO "django_geo_db_zipcode" VALUES(7166,17865,-5,'Potts Grove, Pennsylvania 17865',5422,6554);
INSERT INTO "django_geo_db_zipcode" VALUES(7167,17866,-5,'Coal Township, Pennsylvania 17866',5423,6555);
INSERT INTO "django_geo_db_zipcode" VALUES(7168,17867,-5,'Rebuck, Pennsylvania 17867',5424,6556);
INSERT INTO "django_geo_db_zipcode" VALUES(7169,17868,-5,'Riverside, Pennsylvania 17868',5425,6557);
INSERT INTO "django_geo_db_zipcode" VALUES(7170,17870,-5,'Selinsgrove, Pennsylvania 17870',5426,6558);
INSERT INTO "django_geo_db_zipcode" VALUES(7171,17872,-5,'Shamokin, Pennsylvania 17872',5427,6559);
INSERT INTO "django_geo_db_zipcode" VALUES(7172,17876,-5,'Shamokin Dam, Pennsylvania 17876',5428,6560);
INSERT INTO "django_geo_db_zipcode" VALUES(7173,17877,-5,'Snydertown, Pennsylvania 17877',5429,6561);
INSERT INTO "django_geo_db_zipcode" VALUES(7174,17878,-5,'Stillwater, Pennsylvania 17878',5430,6562);
INSERT INTO "django_geo_db_zipcode" VALUES(7175,17880,-5,'Swengel, Pennsylvania 17880',5431,6563);
INSERT INTO "django_geo_db_zipcode" VALUES(7176,17881,-5,'Trevorton, Pennsylvania 17881',5432,6564);
INSERT INTO "django_geo_db_zipcode" VALUES(7177,17882,-5,'Troxelville, Pennsylvania 17882',5433,6565);
INSERT INTO "django_geo_db_zipcode" VALUES(7178,17883,-5,'Vicksburg, Pennsylvania 17883',5434,6563);
INSERT INTO "django_geo_db_zipcode" VALUES(7179,17884,-5,'Washingtonville, Pennsylvania 17884',5435,6566);
INSERT INTO "django_geo_db_zipcode" VALUES(7180,17885,-5,'Weikert, Pennsylvania 17885',5436,6567);
INSERT INTO "django_geo_db_zipcode" VALUES(7181,17886,-5,'West Milton, Pennsylvania 17886',5437,6568);
INSERT INTO "django_geo_db_zipcode" VALUES(7182,17887,-5,'White Deer, Pennsylvania 17887',5438,6569);
INSERT INTO "django_geo_db_zipcode" VALUES(7183,17888,-5,'Wilburton, Pennsylvania 17888',5439,6570);
INSERT INTO "django_geo_db_zipcode" VALUES(7184,17889,-5,'Winfield, Pennsylvania 17889',5440,6571);
INSERT INTO "django_geo_db_zipcode" VALUES(7185,17901,-5,'Pottsville, Pennsylvania 17901',5441,6572);
INSERT INTO "django_geo_db_zipcode" VALUES(7186,17920,-5,'Aristes, Pennsylvania 17920',5442,6573);
INSERT INTO "django_geo_db_zipcode" VALUES(7187,17921,-5,'Ashland, Pennsylvania 17921',5443,6574);
INSERT INTO "django_geo_db_zipcode" VALUES(7188,17922,-5,'Auburn, Pennsylvania 17922',5444,6575);
INSERT INTO "django_geo_db_zipcode" VALUES(7189,17923,-5,'Branchdale, Pennsylvania 17923',5445,6576);
INSERT INTO "django_geo_db_zipcode" VALUES(7190,17925,-5,'Brockton, Pennsylvania 17925',5446,6577);
INSERT INTO "django_geo_db_zipcode" VALUES(7191,17927,-5,'Centralia, Pennsylvania 17927',5447,6578);
INSERT INTO "django_geo_db_zipcode" VALUES(7192,17929,-5,'Cressona, Pennsylvania 17929',5448,6579);
INSERT INTO "django_geo_db_zipcode" VALUES(7193,17930,-5,'Cumbola, Pennsylvania 17930',5449,6580);
INSERT INTO "django_geo_db_zipcode" VALUES(7194,17931,-5,'Frackville, Pennsylvania 17931',5450,6581);
INSERT INTO "django_geo_db_zipcode" VALUES(7195,17932,-5,'Frackville, Pennsylvania 17932',5450,6582);
INSERT INTO "django_geo_db_zipcode" VALUES(7196,17933,-5,'Friedensburg, Pennsylvania 17933',5451,6583);
INSERT INTO "django_geo_db_zipcode" VALUES(7197,17934,-5,'Gilberton, Pennsylvania 17934',5452,6584);
INSERT INTO "django_geo_db_zipcode" VALUES(7198,17935,-5,'Girardville, Pennsylvania 17935',5453,6585);
INSERT INTO "django_geo_db_zipcode" VALUES(7199,17936,-5,'Gordon, Pennsylvania 17936',5454,6586);
INSERT INTO "django_geo_db_zipcode" VALUES(7200,17938,-5,'Hegins, Pennsylvania 17938',5455,6587);
INSERT INTO "django_geo_db_zipcode" VALUES(7201,17941,-5,'Klingerstown, Pennsylvania 17941',5456,6588);
INSERT INTO "django_geo_db_zipcode" VALUES(7202,17942,-5,'Landingville, Pennsylvania 17942',5457,6589);
INSERT INTO "django_geo_db_zipcode" VALUES(7203,17943,-5,'Lavelle, Pennsylvania 17943',5458,6590);
INSERT INTO "django_geo_db_zipcode" VALUES(7204,17944,-5,'Llewellyn, Pennsylvania 17944',5459,6591);
INSERT INTO "django_geo_db_zipcode" VALUES(7205,17945,-5,'Locustdale, Pennsylvania 17945',5460,6592);
INSERT INTO "django_geo_db_zipcode" VALUES(7206,17946,-5,'Lost Creek, Pennsylvania 17946',5461,6593);
INSERT INTO "django_geo_db_zipcode" VALUES(7207,17948,-5,'Mahanoy City, Pennsylvania 17948',5462,6594);
INSERT INTO "django_geo_db_zipcode" VALUES(7208,17949,-5,'Mahanoy Plane, Pennsylvania 17949',5463,6595);
INSERT INTO "django_geo_db_zipcode" VALUES(7209,17951,-5,'Mar Lin, Pennsylvania 17951',5464,6596);
INSERT INTO "django_geo_db_zipcode" VALUES(7210,17952,-5,'Mary D, Pennsylvania 17952',5465,6597);
INSERT INTO "django_geo_db_zipcode" VALUES(7211,17953,-5,'Middleport, Pennsylvania 17953',5466,6598);
INSERT INTO "django_geo_db_zipcode" VALUES(7212,17954,-5,'Minersville, Pennsylvania 17954',5467,6599);
INSERT INTO "django_geo_db_zipcode" VALUES(7213,17957,-5,'Muir, Pennsylvania 17957',5468,6600);
INSERT INTO "django_geo_db_zipcode" VALUES(7214,17959,-5,'New Philadelphia, Pennsylvania 17959',5469,6601);
INSERT INTO "django_geo_db_zipcode" VALUES(7215,17960,-5,'New Ringgold, Pennsylvania 17960',5470,6602);
INSERT INTO "django_geo_db_zipcode" VALUES(7216,17961,-5,'Orwigsburg, Pennsylvania 17961',5471,6603);
INSERT INTO "django_geo_db_zipcode" VALUES(7217,17963,-5,'Pine Grove, Pennsylvania 17963',5472,6604);
INSERT INTO "django_geo_db_zipcode" VALUES(7218,17964,-5,'Pitman, Pennsylvania 17964',5473,6605);
INSERT INTO "django_geo_db_zipcode" VALUES(7219,17965,-5,'Port Carbon, Pennsylvania 17965',5474,6606);
INSERT INTO "django_geo_db_zipcode" VALUES(7220,17966,-5,'Ravine, Pennsylvania 17966',5475,6589);
INSERT INTO "django_geo_db_zipcode" VALUES(7221,17967,-5,'Ringtown, Pennsylvania 17967',5476,6607);
INSERT INTO "django_geo_db_zipcode" VALUES(7222,17968,-5,'Sacramento, Pennsylvania 17968',5477,6608);
INSERT INTO "django_geo_db_zipcode" VALUES(7223,17970,-5,'Saint Clair, Pennsylvania 17970',5478,6609);
INSERT INTO "django_geo_db_zipcode" VALUES(7224,17972,-5,'Schuylkill Haven, Pennsylvania 17972',5479,6610);
INSERT INTO "django_geo_db_zipcode" VALUES(7225,17974,-5,'Seltzer, Pennsylvania 17974',5480,6611);
INSERT INTO "django_geo_db_zipcode" VALUES(7226,17976,-5,'Shenandoah, Pennsylvania 17976',5481,6612);
INSERT INTO "django_geo_db_zipcode" VALUES(7227,17978,-5,'Spring Glen, Pennsylvania 17978',5482,6613);
INSERT INTO "django_geo_db_zipcode" VALUES(7228,17979,-5,'Summit Station, Pennsylvania 17979',5483,6614);
INSERT INTO "django_geo_db_zipcode" VALUES(7229,17980,-5,'Tower City, Pennsylvania 17980',5484,6615);
INSERT INTO "django_geo_db_zipcode" VALUES(7230,17981,-5,'Tremont, Pennsylvania 17981',5485,6616);
INSERT INTO "django_geo_db_zipcode" VALUES(7231,17982,-5,'Tuscarora, Pennsylvania 17982',5486,6617);
INSERT INTO "django_geo_db_zipcode" VALUES(7232,17983,-5,'Valley View, Pennsylvania 17983',5487,6618);
INSERT INTO "django_geo_db_zipcode" VALUES(7233,17985,-5,'Zion Grove, Pennsylvania 17985',5488,6619);
INSERT INTO "django_geo_db_zipcode" VALUES(7234,18001,-5,'Lehigh Valley, Pennsylvania 18001',5489,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7235,18002,-5,'Lehigh Valley, Pennsylvania 18002',5489,6621);
INSERT INTO "django_geo_db_zipcode" VALUES(7236,18003,-5,'Lehigh Valley, Pennsylvania 18003',5489,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7237,18010,-5,'Ackermanville, Pennsylvania 18010',5490,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7238,18011,-5,'Alburtis, Pennsylvania 18011',5491,6622);
INSERT INTO "django_geo_db_zipcode" VALUES(7239,18012,-5,'Aquashicola, Pennsylvania 18012',5492,6623);
INSERT INTO "django_geo_db_zipcode" VALUES(7240,18013,-5,'Bangor, Pennsylvania 18013',5493,6624);
INSERT INTO "django_geo_db_zipcode" VALUES(7241,18014,-5,'Bath, Pennsylvania 18014',5494,6625);
INSERT INTO "django_geo_db_zipcode" VALUES(7242,18015,-5,'Bethlehem, Pennsylvania 18015',5495,6626);
INSERT INTO "django_geo_db_zipcode" VALUES(7243,18016,-5,'Bethlehem, Pennsylvania 18016',5495,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7244,18017,-5,'Bethlehem, Pennsylvania 18017',5495,6627);
INSERT INTO "django_geo_db_zipcode" VALUES(7245,18018,-5,'Bethlehem, Pennsylvania 18018',5495,6628);
INSERT INTO "django_geo_db_zipcode" VALUES(7246,18020,-5,'Bethlehem, Pennsylvania 18020',5495,6629);
INSERT INTO "django_geo_db_zipcode" VALUES(7247,18021,-5,'Hazleton, Pennsylvania 18021',5496,6630);
INSERT INTO "django_geo_db_zipcode" VALUES(7248,18024,-5,'Bethlehem, Pennsylvania 18024',5495,6631);
INSERT INTO "django_geo_db_zipcode" VALUES(7249,18025,-5,'Bethlehem, Pennsylvania 18025',5495,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7250,18030,-5,'Bowmanstown, Pennsylvania 18030',5497,6632);
INSERT INTO "django_geo_db_zipcode" VALUES(7251,18031,-5,'Breinigsville, Pennsylvania 18031',5498,6633);
INSERT INTO "django_geo_db_zipcode" VALUES(7252,18032,-5,'Catasauqua, Pennsylvania 18032',5499,6634);
INSERT INTO "django_geo_db_zipcode" VALUES(7253,18034,-5,'Center Valley, Pennsylvania 18034',5500,6635);
INSERT INTO "django_geo_db_zipcode" VALUES(7254,18035,-5,'Cherryville, Pennsylvania 18035',5501,6636);
INSERT INTO "django_geo_db_zipcode" VALUES(7255,18036,-5,'Coopersburg, Pennsylvania 18036',5502,6637);
INSERT INTO "django_geo_db_zipcode" VALUES(7256,18037,-5,'Coplay, Pennsylvania 18037',5503,6638);
INSERT INTO "django_geo_db_zipcode" VALUES(7257,18038,-5,'Danielsville, Pennsylvania 18038',5504,6639);
INSERT INTO "django_geo_db_zipcode" VALUES(7258,18039,-5,'Durham, Pennsylvania 18039',5505,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7259,18040,-5,'Easton, Pennsylvania 18040',5506,6641);
INSERT INTO "django_geo_db_zipcode" VALUES(7260,18041,-5,'East Greenville, Pennsylvania 18041',5507,6642);
INSERT INTO "django_geo_db_zipcode" VALUES(7261,18042,-5,'Easton, Pennsylvania 18042',5506,6643);
INSERT INTO "django_geo_db_zipcode" VALUES(7262,18043,-5,'Easton, Pennsylvania 18043',5506,6644);
INSERT INTO "django_geo_db_zipcode" VALUES(7263,18044,-5,'Easton, Pennsylvania 18044',5506,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7264,18045,-5,'Easton, Pennsylvania 18045',5506,6645);
INSERT INTO "django_geo_db_zipcode" VALUES(7265,18046,-5,'East Texas, Pennsylvania 18046',5508,6646);
INSERT INTO "django_geo_db_zipcode" VALUES(7266,18049,-5,'Emmaus, Pennsylvania 18049',5509,6647);
INSERT INTO "django_geo_db_zipcode" VALUES(7267,18050,-5,'Flicksville, Pennsylvania 18050',5510,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7268,18051,-5,'Fogelsville, Pennsylvania 18051',5511,6648);
INSERT INTO "django_geo_db_zipcode" VALUES(7269,18052,-5,'Whitehall, Pennsylvania 18052',5512,6649);
INSERT INTO "django_geo_db_zipcode" VALUES(7270,18053,-5,'Germansville, Pennsylvania 18053',5513,6650);
INSERT INTO "django_geo_db_zipcode" VALUES(7271,18054,-5,'Green Lane, Pennsylvania 18054',5514,6651);
INSERT INTO "django_geo_db_zipcode" VALUES(7272,18055,-5,'Hellertown, Pennsylvania 18055',5515,6652);
INSERT INTO "django_geo_db_zipcode" VALUES(7273,18056,-5,'Hereford, Pennsylvania 18056',5516,6653);
INSERT INTO "django_geo_db_zipcode" VALUES(7274,18058,-5,'Kunkletown, Pennsylvania 18058',5517,6654);
INSERT INTO "django_geo_db_zipcode" VALUES(7275,18059,-5,'Laurys Station, Pennsylvania 18059',5518,6655);
INSERT INTO "django_geo_db_zipcode" VALUES(7276,18060,-5,'Limeport, Pennsylvania 18060',5519,6656);
INSERT INTO "django_geo_db_zipcode" VALUES(7277,18062,-5,'Macungie, Pennsylvania 18062',5520,6657);
INSERT INTO "django_geo_db_zipcode" VALUES(7278,18063,-5,'Martins Creek, Pennsylvania 18063',5521,6658);
INSERT INTO "django_geo_db_zipcode" VALUES(7279,18064,-5,'Nazareth, Pennsylvania 18064',5522,6659);
INSERT INTO "django_geo_db_zipcode" VALUES(7280,18065,-5,'Neffs, Pennsylvania 18065',5523,6660);
INSERT INTO "django_geo_db_zipcode" VALUES(7281,18066,-5,'New Tripoli, Pennsylvania 18066',5524,6661);
INSERT INTO "django_geo_db_zipcode" VALUES(7282,18067,-5,'Northampton, Pennsylvania 18067',5525,6662);
INSERT INTO "django_geo_db_zipcode" VALUES(7283,18068,-5,'Old Zionsville, Pennsylvania 18068',5526,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7284,18069,-5,'Orefield, Pennsylvania 18069',5527,6663);
INSERT INTO "django_geo_db_zipcode" VALUES(7285,18070,-5,'Palm, Pennsylvania 18070',5528,6664);
INSERT INTO "django_geo_db_zipcode" VALUES(7286,18071,-5,'Palmerton, Pennsylvania 18071',5529,6665);
INSERT INTO "django_geo_db_zipcode" VALUES(7287,18072,-5,'Pen Argyl, Pennsylvania 18072',5530,6666);
INSERT INTO "django_geo_db_zipcode" VALUES(7288,18073,-5,'Pennsburg, Pennsylvania 18073',5531,6667);
INSERT INTO "django_geo_db_zipcode" VALUES(7289,18074,-5,'Perkiomenville, Pennsylvania 18074',5532,6668);
INSERT INTO "django_geo_db_zipcode" VALUES(7290,18076,-5,'Red Hill, Pennsylvania 18076',5533,6669);
INSERT INTO "django_geo_db_zipcode" VALUES(7291,18077,-5,'Riegelsville, Pennsylvania 18077',5534,6670);
INSERT INTO "django_geo_db_zipcode" VALUES(7292,18078,-5,'Schnecksville, Pennsylvania 18078',5535,6671);
INSERT INTO "django_geo_db_zipcode" VALUES(7293,18079,-5,'Slatedale, Pennsylvania 18079',5536,6672);
INSERT INTO "django_geo_db_zipcode" VALUES(7294,18080,-5,'Slatington, Pennsylvania 18080',5537,6673);
INSERT INTO "django_geo_db_zipcode" VALUES(7295,18081,-5,'Springtown, Pennsylvania 18081',5538,6674);
INSERT INTO "django_geo_db_zipcode" VALUES(7296,18083,-5,'Stockertown, Pennsylvania 18083',5539,6675);
INSERT INTO "django_geo_db_zipcode" VALUES(7297,18084,-5,'Sumneytown, Pennsylvania 18084',5540,6676);
INSERT INTO "django_geo_db_zipcode" VALUES(7298,18085,-5,'Tatamy, Pennsylvania 18085',5541,6677);
INSERT INTO "django_geo_db_zipcode" VALUES(7299,18086,-5,'Treichlers, Pennsylvania 18086',5542,6678);
INSERT INTO "django_geo_db_zipcode" VALUES(7300,18087,-5,'Trexlertown, Pennsylvania 18087',5543,6679);
INSERT INTO "django_geo_db_zipcode" VALUES(7301,18088,-5,'Walnutport, Pennsylvania 18088',5544,6680);
INSERT INTO "django_geo_db_zipcode" VALUES(7302,18091,-5,'Wind Gap, Pennsylvania 18091',5545,6681);
INSERT INTO "django_geo_db_zipcode" VALUES(7303,18092,-5,'Zionsville, Pennsylvania 18092',5546,6682);
INSERT INTO "django_geo_db_zipcode" VALUES(7304,18096,-5,'South Whitehall, Pennsylvania 18096',5547,6683);
INSERT INTO "django_geo_db_zipcode" VALUES(7305,18098,-5,'Emmaus, Pennsylvania 18098',5509,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7306,18099,-5,'Emmaus, Pennsylvania 18099',5509,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7307,18101,-5,'Allentown, Pennsylvania 18101',5548,6684);
INSERT INTO "django_geo_db_zipcode" VALUES(7308,18102,-5,'Allentown, Pennsylvania 18102',5548,6685);
INSERT INTO "django_geo_db_zipcode" VALUES(7309,18103,-5,'Allentown, Pennsylvania 18103',5548,6686);
INSERT INTO "django_geo_db_zipcode" VALUES(7310,18104,-5,'Allentown, Pennsylvania 18104',5548,6687);
INSERT INTO "django_geo_db_zipcode" VALUES(7311,18105,-5,'Allentown, Pennsylvania 18105',5548,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7312,18106,-5,'Allentown, Pennsylvania 18106',5548,6688);
INSERT INTO "django_geo_db_zipcode" VALUES(7313,18109,-5,'Allentown, Pennsylvania 18109',5548,6620);
INSERT INTO "django_geo_db_zipcode" VALUES(7314,18160,-5,'Tunkhannock, Pennsylvania 18160',5549,6689);
INSERT INTO "django_geo_db_zipcode" VALUES(7315,18175,-5,'Allentown, Pennsylvania 18175',5548,6690);
INSERT INTO "django_geo_db_zipcode" VALUES(7316,18195,-5,'Allentown, Pennsylvania 18195',5548,6691);
INSERT INTO "django_geo_db_zipcode" VALUES(7317,18201,-5,'Hazleton, Pennsylvania 18201',5496,6692);
INSERT INTO "django_geo_db_zipcode" VALUES(7318,18202,-5,'Hazleton, Pennsylvania 18202',5496,6693);
INSERT INTO "django_geo_db_zipcode" VALUES(7319,18210,-5,'Albrightsville, Pennsylvania 18210',5550,6694);
INSERT INTO "django_geo_db_zipcode" VALUES(7320,18211,-5,'Andreas, Pennsylvania 18211',5551,6695);
INSERT INTO "django_geo_db_zipcode" VALUES(7321,18212,-5,'Ashfield, Pennsylvania 18212',5552,6696);
INSERT INTO "django_geo_db_zipcode" VALUES(7322,18214,-5,'Barnesville, Pennsylvania 18214',5553,6697);
INSERT INTO "django_geo_db_zipcode" VALUES(7323,18216,-5,'Beaver Meadows, Pennsylvania 18216',5554,6698);
INSERT INTO "django_geo_db_zipcode" VALUES(7324,18218,-5,'Coaldale, Pennsylvania 18218',5555,6699);
INSERT INTO "django_geo_db_zipcode" VALUES(7325,18219,-5,'Conyngham, Pennsylvania 18219',5556,6700);
INSERT INTO "django_geo_db_zipcode" VALUES(7326,18220,-5,'Delano, Pennsylvania 18220',5557,6701);
INSERT INTO "django_geo_db_zipcode" VALUES(7327,18221,-5,'Drifton, Pennsylvania 18221',5558,6702);
INSERT INTO "django_geo_db_zipcode" VALUES(7328,18222,-5,'Drums, Pennsylvania 18222',5559,6703);
INSERT INTO "django_geo_db_zipcode" VALUES(7329,18223,-5,'Ebervale, Pennsylvania 18223',5560,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7330,18224,-5,'Freeland, Pennsylvania 18224',5561,6705);
INSERT INTO "django_geo_db_zipcode" VALUES(7331,18225,-5,'Harleigh, Pennsylvania 18225',5562,6706);
INSERT INTO "django_geo_db_zipcode" VALUES(7332,18229,-5,'Jim Thorpe, Pennsylvania 18229',5563,6707);
INSERT INTO "django_geo_db_zipcode" VALUES(7333,18230,-5,'Junedale, Pennsylvania 18230',5564,6708);
INSERT INTO "django_geo_db_zipcode" VALUES(7334,18231,-5,'Kelayres, Pennsylvania 18231',5565,6709);
INSERT INTO "django_geo_db_zipcode" VALUES(7335,18232,-5,'Lansford, Pennsylvania 18232',5566,6710);
INSERT INTO "django_geo_db_zipcode" VALUES(7336,18234,-5,'Lattimer Mines, Pennsylvania 18234',5567,6711);
INSERT INTO "django_geo_db_zipcode" VALUES(7337,18235,-5,'Lehighton, Pennsylvania 18235',5568,6712);
INSERT INTO "django_geo_db_zipcode" VALUES(7338,18237,-5,'Mcadoo, Pennsylvania 18237',5569,6713);
INSERT INTO "django_geo_db_zipcode" VALUES(7339,18239,-5,'Milnesville, Pennsylvania 18239',5570,6714);
INSERT INTO "django_geo_db_zipcode" VALUES(7340,18240,-5,'Nesquehoning, Pennsylvania 18240',5571,6715);
INSERT INTO "django_geo_db_zipcode" VALUES(7341,18241,-5,'Nuremberg, Pennsylvania 18241',5572,6716);
INSERT INTO "django_geo_db_zipcode" VALUES(7342,18242,-5,'Oneida, Pennsylvania 18242',5573,6717);
INSERT INTO "django_geo_db_zipcode" VALUES(7343,18243,-5,'Pardeesville, Pennsylvania 18243',5574,6718);
INSERT INTO "django_geo_db_zipcode" VALUES(7344,18244,-5,'Parryville, Pennsylvania 18244',5575,6719);
INSERT INTO "django_geo_db_zipcode" VALUES(7345,18245,-5,'Quakake, Pennsylvania 18245',5576,6720);
INSERT INTO "django_geo_db_zipcode" VALUES(7346,18246,-5,'Rock Glen, Pennsylvania 18246',5577,6721);
INSERT INTO "django_geo_db_zipcode" VALUES(7347,18247,-5,'Saint Johns, Pennsylvania 18247',5578,6722);
INSERT INTO "django_geo_db_zipcode" VALUES(7348,18248,-5,'Sheppton, Pennsylvania 18248',5579,6723);
INSERT INTO "django_geo_db_zipcode" VALUES(7349,18249,-5,'Sugarloaf, Pennsylvania 18249',5580,6724);
INSERT INTO "django_geo_db_zipcode" VALUES(7350,18250,-5,'Summit Hill, Pennsylvania 18250',5581,6725);
INSERT INTO "django_geo_db_zipcode" VALUES(7351,18251,-5,'Sybertsville, Pennsylvania 18251',5582,6726);
INSERT INTO "django_geo_db_zipcode" VALUES(7352,18252,-5,'Tamaqua, Pennsylvania 18252',5583,6727);
INSERT INTO "django_geo_db_zipcode" VALUES(7353,18254,-5,'Tresckow, Pennsylvania 18254',5584,6728);
INSERT INTO "django_geo_db_zipcode" VALUES(7354,18255,-5,'Weatherly, Pennsylvania 18255',5585,6729);
INSERT INTO "django_geo_db_zipcode" VALUES(7355,18256,-5,'Weston, Pennsylvania 18256',5586,6730);
INSERT INTO "django_geo_db_zipcode" VALUES(7356,18301,-5,'East Stroudsburg, Pennsylvania 18301',5587,6731);
INSERT INTO "django_geo_db_zipcode" VALUES(7357,18320,-5,'Analomink, Pennsylvania 18320',5588,6732);
INSERT INTO "django_geo_db_zipcode" VALUES(7358,18321,-5,'Bartonsville, Pennsylvania 18321',5589,6733);
INSERT INTO "django_geo_db_zipcode" VALUES(7359,18322,-5,'Brodheadsville, Pennsylvania 18322',5590,6734);
INSERT INTO "django_geo_db_zipcode" VALUES(7360,18323,-5,'Buck Hill Falls, Pennsylvania 18323',5591,6735);
INSERT INTO "django_geo_db_zipcode" VALUES(7361,18324,-5,'Bushkill, Pennsylvania 18324',5592,6736);
INSERT INTO "django_geo_db_zipcode" VALUES(7362,18325,-5,'Canadensis, Pennsylvania 18325',5593,6737);
INSERT INTO "django_geo_db_zipcode" VALUES(7363,18326,-5,'Cresco, Pennsylvania 18326',5594,6738);
INSERT INTO "django_geo_db_zipcode" VALUES(7364,18327,-5,'Delaware Water Gap, Pennsylvania 18327',5595,6739);
INSERT INTO "django_geo_db_zipcode" VALUES(7365,18328,-5,'Dingmans Ferry, Pennsylvania 18328',5596,6740);
INSERT INTO "django_geo_db_zipcode" VALUES(7366,18330,-5,'Effort, Pennsylvania 18330',5597,6741);
INSERT INTO "django_geo_db_zipcode" VALUES(7367,18331,-5,'Gilbert, Pennsylvania 18331',5598,6742);
INSERT INTO "django_geo_db_zipcode" VALUES(7368,18332,-5,'Henryville, Pennsylvania 18332',5599,6743);
INSERT INTO "django_geo_db_zipcode" VALUES(7369,18333,-5,'Kresgeville, Pennsylvania 18333',5600,6744);
INSERT INTO "django_geo_db_zipcode" VALUES(7370,18334,-5,'Long Pond, Pennsylvania 18334',5601,6745);
INSERT INTO "django_geo_db_zipcode" VALUES(7371,18335,-5,'Marshalls Creek, Pennsylvania 18335',5602,6746);
INSERT INTO "django_geo_db_zipcode" VALUES(7372,18336,-5,'Matamoras, Pennsylvania 18336',5603,6747);
INSERT INTO "django_geo_db_zipcode" VALUES(7373,18337,-5,'Milford, Pennsylvania 18337',5604,6748);
INSERT INTO "django_geo_db_zipcode" VALUES(7374,18340,-5,'Millrift, Pennsylvania 18340',5605,6749);
INSERT INTO "django_geo_db_zipcode" VALUES(7375,18341,-5,'Minisink Hills, Pennsylvania 18341',5606,6750);
INSERT INTO "django_geo_db_zipcode" VALUES(7376,18342,-5,'Mountainhome, Pennsylvania 18342',5607,6751);
INSERT INTO "django_geo_db_zipcode" VALUES(7377,18343,-5,'Mount Bethel, Pennsylvania 18343',5608,6752);
INSERT INTO "django_geo_db_zipcode" VALUES(7378,18344,-5,'Mount Pocono, Pennsylvania 18344',5609,6753);
INSERT INTO "django_geo_db_zipcode" VALUES(7379,18346,-5,'Pocono Summit, Pennsylvania 18346',5610,6754);
INSERT INTO "django_geo_db_zipcode" VALUES(7380,18347,-5,'Pocono Lake, Pennsylvania 18347',5611,6755);
INSERT INTO "django_geo_db_zipcode" VALUES(7381,18348,-5,'Pocono Lake Preserve, Pennsylvania 18348',5612,6756);
INSERT INTO "django_geo_db_zipcode" VALUES(7382,18349,-5,'Pocono Manor, Pennsylvania 18349',5613,6757);
INSERT INTO "django_geo_db_zipcode" VALUES(7383,18350,-5,'Pocono Pines, Pennsylvania 18350',5614,6758);
INSERT INTO "django_geo_db_zipcode" VALUES(7384,18351,-5,'Portland, Pennsylvania 18351',5615,6759);
INSERT INTO "django_geo_db_zipcode" VALUES(7385,18352,-5,'Reeders, Pennsylvania 18352',5616,6760);
INSERT INTO "django_geo_db_zipcode" VALUES(7386,18353,-5,'Saylorsburg, Pennsylvania 18353',5617,6761);
INSERT INTO "django_geo_db_zipcode" VALUES(7387,18354,-5,'Sciota, Pennsylvania 18354',5618,6762);
INSERT INTO "django_geo_db_zipcode" VALUES(7388,18355,-5,'Scotrun, Pennsylvania 18355',5619,6763);
INSERT INTO "django_geo_db_zipcode" VALUES(7389,18356,-5,'Shawnee On Delaware, Pennsylvania 18356',5620,6764);
INSERT INTO "django_geo_db_zipcode" VALUES(7390,18357,-5,'Skytop, Pennsylvania 18357',5621,6765);
INSERT INTO "django_geo_db_zipcode" VALUES(7391,18360,-5,'Stroudsburg, Pennsylvania 18360',5622,6766);
INSERT INTO "django_geo_db_zipcode" VALUES(7392,18370,-5,'Swiftwater, Pennsylvania 18370',5623,6767);
INSERT INTO "django_geo_db_zipcode" VALUES(7393,18371,-5,'Tamiment, Pennsylvania 18371',5624,6768);
INSERT INTO "django_geo_db_zipcode" VALUES(7394,18372,-5,'Tannersville, Pennsylvania 18372',5625,6769);
INSERT INTO "django_geo_db_zipcode" VALUES(7395,18373,-5,'Unity House, Pennsylvania 18373',5626,6768);
INSERT INTO "django_geo_db_zipcode" VALUES(7396,18377,-5,'Dingman, Pennsylvania 18377',5627,6770);
INSERT INTO "django_geo_db_zipcode" VALUES(7397,18401,-5,'Aldenville, Pennsylvania 18401',5628,6771);
INSERT INTO "django_geo_db_zipcode" VALUES(7398,18403,-5,'Archbald, Pennsylvania 18403',5629,6772);
INSERT INTO "django_geo_db_zipcode" VALUES(7399,18405,-5,'Beach Lake, Pennsylvania 18405',5630,6773);
INSERT INTO "django_geo_db_zipcode" VALUES(7400,18407,-5,'Carbondale, Pennsylvania 18407',5631,6774);
INSERT INTO "django_geo_db_zipcode" VALUES(7401,18410,-5,'Chinchilla, Pennsylvania 18410',5632,6775);
INSERT INTO "django_geo_db_zipcode" VALUES(7402,18411,-5,'Clarks Summit, Pennsylvania 18411',5633,6776);
INSERT INTO "django_geo_db_zipcode" VALUES(7403,18413,-5,'Clifford, Pennsylvania 18413',5634,6777);
INSERT INTO "django_geo_db_zipcode" VALUES(7404,18414,-5,'Dalton, Pennsylvania 18414',5635,6778);
INSERT INTO "django_geo_db_zipcode" VALUES(7405,18415,-5,'Damascus, Pennsylvania 18415',5636,6779);
INSERT INTO "django_geo_db_zipcode" VALUES(7406,18416,-5,'Elmhurst, Pennsylvania 18416',5637,6780);
INSERT INTO "django_geo_db_zipcode" VALUES(7407,18417,-5,'Equinunk, Pennsylvania 18417',5638,6781);
INSERT INTO "django_geo_db_zipcode" VALUES(7408,18419,-5,'Factoryville, Pennsylvania 18419',5639,6782);
INSERT INTO "django_geo_db_zipcode" VALUES(7409,18420,-5,'Fleetville, Pennsylvania 18420',5640,6783);
INSERT INTO "django_geo_db_zipcode" VALUES(7410,18421,-5,'Forest City, Pennsylvania 18421',5641,6784);
INSERT INTO "django_geo_db_zipcode" VALUES(7411,18424,-5,'Gouldsboro, Pennsylvania 18424',5642,6785);
INSERT INTO "django_geo_db_zipcode" VALUES(7412,18425,-5,'Greeley, Pennsylvania 18425',5643,6786);
INSERT INTO "django_geo_db_zipcode" VALUES(7413,18426,-5,'Greentown, Pennsylvania 18426',5644,6787);
INSERT INTO "django_geo_db_zipcode" VALUES(7414,18427,-5,'Hamlin, Pennsylvania 18427',5645,6788);
INSERT INTO "django_geo_db_zipcode" VALUES(7415,18428,-5,'Hawley, Pennsylvania 18428',5646,6789);
INSERT INTO "django_geo_db_zipcode" VALUES(7416,18430,-5,'Herrick Center, Pennsylvania 18430',5647,6790);
INSERT INTO "django_geo_db_zipcode" VALUES(7417,18431,-5,'Honesdale, Pennsylvania 18431',5648,6791);
INSERT INTO "django_geo_db_zipcode" VALUES(7418,18433,-5,'Jermyn, Pennsylvania 18433',5649,6792);
INSERT INTO "django_geo_db_zipcode" VALUES(7419,18434,-5,'Jessup, Pennsylvania 18434',5650,6793);
INSERT INTO "django_geo_db_zipcode" VALUES(7420,18435,-5,'Lackawaxen, Pennsylvania 18435',5651,6794);
INSERT INTO "django_geo_db_zipcode" VALUES(7421,18436,-5,'Lake Ariel, Pennsylvania 18436',5652,6795);
INSERT INTO "django_geo_db_zipcode" VALUES(7422,18437,-5,'Lake Como, Pennsylvania 18437',5653,6796);
INSERT INTO "django_geo_db_zipcode" VALUES(7423,18438,-5,'Lakeville, Pennsylvania 18438',5654,6797);
INSERT INTO "django_geo_db_zipcode" VALUES(7424,18439,-5,'Lakewood, Pennsylvania 18439',5655,6798);
INSERT INTO "django_geo_db_zipcode" VALUES(7425,18440,-5,'La Plume, Pennsylvania 18440',5656,6799);
INSERT INTO "django_geo_db_zipcode" VALUES(7426,18441,-5,'Lenoxville, Pennsylvania 18441',5657,6800);
INSERT INTO "django_geo_db_zipcode" VALUES(7427,18443,-5,'Milanville, Pennsylvania 18443',5658,6801);
INSERT INTO "django_geo_db_zipcode" VALUES(7428,18444,-5,'Moscow, Pennsylvania 18444',5659,6802);
INSERT INTO "django_geo_db_zipcode" VALUES(7429,18445,-5,'Newfoundland, Pennsylvania 18445',5660,6803);
INSERT INTO "django_geo_db_zipcode" VALUES(7430,18446,-5,'Nicholson, Pennsylvania 18446',5661,6804);
INSERT INTO "django_geo_db_zipcode" VALUES(7431,18447,-5,'Olyphant, Pennsylvania 18447',5662,6805);
INSERT INTO "django_geo_db_zipcode" VALUES(7432,18448,-5,'Olyphant, Pennsylvania 18448',5662,6806);
INSERT INTO "django_geo_db_zipcode" VALUES(7433,18449,-5,'Orson, Pennsylvania 18449',5663,6771);
INSERT INTO "django_geo_db_zipcode" VALUES(7434,18451,-5,'Paupack, Pennsylvania 18451',5664,6807);
INSERT INTO "django_geo_db_zipcode" VALUES(7435,18452,-5,'Peckville, Pennsylvania 18452',5665,6808);
INSERT INTO "django_geo_db_zipcode" VALUES(7436,18453,-5,'Pleasant Mount, Pennsylvania 18453',5666,6809);
INSERT INTO "django_geo_db_zipcode" VALUES(7437,18454,-5,'Poyntelle, Pennsylvania 18454',5667,6771);
INSERT INTO "django_geo_db_zipcode" VALUES(7438,18455,-5,'Preston Park, Pennsylvania 18455',5668,6810);
INSERT INTO "django_geo_db_zipcode" VALUES(7439,18456,-5,'Prompton, Pennsylvania 18456',5669,6811);
INSERT INTO "django_geo_db_zipcode" VALUES(7440,18457,-5,'Rowland, Pennsylvania 18457',5670,6812);
INSERT INTO "django_geo_db_zipcode" VALUES(7441,18458,-5,'Shohola, Pennsylvania 18458',5671,6813);
INSERT INTO "django_geo_db_zipcode" VALUES(7442,18459,-5,'South Canaan, Pennsylvania 18459',5672,6814);
INSERT INTO "django_geo_db_zipcode" VALUES(7443,18460,-5,'South Sterling, Pennsylvania 18460',5673,6815);
INSERT INTO "django_geo_db_zipcode" VALUES(7444,18461,-5,'Starlight, Pennsylvania 18461',5674,6816);
INSERT INTO "django_geo_db_zipcode" VALUES(7445,18462,-5,'Starrucca, Pennsylvania 18462',5675,6817);
INSERT INTO "django_geo_db_zipcode" VALUES(7446,18463,-5,'Sterling, Pennsylvania 18463',5676,6818);
INSERT INTO "django_geo_db_zipcode" VALUES(7447,18464,-5,'Tafton, Pennsylvania 18464',5677,6819);
INSERT INTO "django_geo_db_zipcode" VALUES(7448,18465,-5,'Thompson, Pennsylvania 18465',5678,6820);
INSERT INTO "django_geo_db_zipcode" VALUES(7449,18466,-5,'Tobyhanna, Pennsylvania 18466',5679,6821);
INSERT INTO "django_geo_db_zipcode" VALUES(7450,18469,-5,'Tyler Hill, Pennsylvania 18469',5680,6822);
INSERT INTO "django_geo_db_zipcode" VALUES(7451,18470,-5,'Union Dale, Pennsylvania 18470',5681,6823);
INSERT INTO "django_geo_db_zipcode" VALUES(7452,18471,-5,'Waverly, Pennsylvania 18471',5682,6824);
INSERT INTO "django_geo_db_zipcode" VALUES(7453,18472,-5,'Waymart, Pennsylvania 18472',5683,6825);
INSERT INTO "django_geo_db_zipcode" VALUES(7454,18473,-5,'White Mills, Pennsylvania 18473',5684,6826);
INSERT INTO "django_geo_db_zipcode" VALUES(7455,18501,-5,'Scranton, Pennsylvania 18501',5685,6827);
INSERT INTO "django_geo_db_zipcode" VALUES(7456,18502,-5,'Scranton, Pennsylvania 18502',5685,6828);
INSERT INTO "django_geo_db_zipcode" VALUES(7457,18503,-5,'Scranton, Pennsylvania 18503',5685,6829);
INSERT INTO "django_geo_db_zipcode" VALUES(7458,18504,-5,'Scranton, Pennsylvania 18504',5685,6830);
INSERT INTO "django_geo_db_zipcode" VALUES(7459,18505,-5,'Scranton, Pennsylvania 18505',5685,6831);
INSERT INTO "django_geo_db_zipcode" VALUES(7460,18507,-5,'Moosic, Pennsylvania 18507',5686,6832);
INSERT INTO "django_geo_db_zipcode" VALUES(7461,18508,-5,'Scranton, Pennsylvania 18508',5685,6833);
INSERT INTO "django_geo_db_zipcode" VALUES(7462,18509,-5,'Scranton, Pennsylvania 18509',5685,6834);
INSERT INTO "django_geo_db_zipcode" VALUES(7463,18510,-5,'Scranton, Pennsylvania 18510',5685,6835);
INSERT INTO "django_geo_db_zipcode" VALUES(7464,18512,-5,'Scranton, Pennsylvania 18512',5685,6836);
INSERT INTO "django_geo_db_zipcode" VALUES(7465,18514,-5,'Scranton, Pennsylvania 18514',5685,6827);
INSERT INTO "django_geo_db_zipcode" VALUES(7466,18515,-5,'Scranton, Pennsylvania 18515',5685,6837);
INSERT INTO "django_geo_db_zipcode" VALUES(7467,18517,-5,'Taylor, Pennsylvania 18517',5687,6838);
INSERT INTO "django_geo_db_zipcode" VALUES(7468,18518,-5,'Old Forge, Pennsylvania 18518',5688,6839);
INSERT INTO "django_geo_db_zipcode" VALUES(7469,18519,-5,'Dickson City, Pennsylvania 18519',5689,6840);
INSERT INTO "django_geo_db_zipcode" VALUES(7470,18522,-5,'Scranton, Pennsylvania 18522',5685,6827);
INSERT INTO "django_geo_db_zipcode" VALUES(7471,18540,-5,'Scranton, Pennsylvania 18540',5685,6827);
INSERT INTO "django_geo_db_zipcode" VALUES(7472,18577,-5,'Scranton, Pennsylvania 18577',5685,6827);
INSERT INTO "django_geo_db_zipcode" VALUES(7473,18601,-5,'Beach Haven, Pennsylvania 18601',5690,6841);
INSERT INTO "django_geo_db_zipcode" VALUES(7474,18602,-5,'Bear Creek, Pennsylvania 18602',5691,6842);
INSERT INTO "django_geo_db_zipcode" VALUES(7475,18603,-5,'Berwick, Pennsylvania 18603',5692,6843);
INSERT INTO "django_geo_db_zipcode" VALUES(7476,18610,-5,'Blakeslee, Pennsylvania 18610',5693,6844);
INSERT INTO "django_geo_db_zipcode" VALUES(7477,18611,-5,'Cambra, Pennsylvania 18611',5694,6845);
INSERT INTO "django_geo_db_zipcode" VALUES(7478,18612,-5,'Dallas, Pennsylvania 18612',5695,6846);
INSERT INTO "django_geo_db_zipcode" VALUES(7479,18614,-5,'Dushore, Pennsylvania 18614',5696,6847);
INSERT INTO "django_geo_db_zipcode" VALUES(7480,18615,-5,'Falls, Pennsylvania 18615',5697,6848);
INSERT INTO "django_geo_db_zipcode" VALUES(7481,18616,-5,'Forksville, Pennsylvania 18616',5698,6849);
INSERT INTO "django_geo_db_zipcode" VALUES(7482,18617,-5,'Glen Lyon, Pennsylvania 18617',5699,6850);
INSERT INTO "django_geo_db_zipcode" VALUES(7483,18618,-5,'Harveys Lake, Pennsylvania 18618',5700,6851);
INSERT INTO "django_geo_db_zipcode" VALUES(7484,18619,-5,'Hillsgrove, Pennsylvania 18619',5701,6852);
INSERT INTO "django_geo_db_zipcode" VALUES(7485,18621,-5,'Hunlock Creek, Pennsylvania 18621',5702,6853);
INSERT INTO "django_geo_db_zipcode" VALUES(7486,18622,-5,'Huntington Mills, Pennsylvania 18622',5703,6854);
INSERT INTO "django_geo_db_zipcode" VALUES(7487,18623,-5,'Laceyville, Pennsylvania 18623',5704,6855);
INSERT INTO "django_geo_db_zipcode" VALUES(7488,18624,-5,'Lake Harmony, Pennsylvania 18624',5705,6856);
INSERT INTO "django_geo_db_zipcode" VALUES(7489,18625,-5,'Lake Winola, Pennsylvania 18625',5706,6857);
INSERT INTO "django_geo_db_zipcode" VALUES(7490,18626,-5,'Laporte, Pennsylvania 18626',5707,6858);
INSERT INTO "django_geo_db_zipcode" VALUES(7491,18627,-5,'Lehman, Pennsylvania 18627',5708,6859);
INSERT INTO "django_geo_db_zipcode" VALUES(7492,18628,-5,'Lopez, Pennsylvania 18628',5709,6860);
INSERT INTO "django_geo_db_zipcode" VALUES(7493,18629,-5,'Mehoopany, Pennsylvania 18629',5710,6861);
INSERT INTO "django_geo_db_zipcode" VALUES(7494,18630,-5,'Meshoppen, Pennsylvania 18630',5711,6862);
INSERT INTO "django_geo_db_zipcode" VALUES(7495,18631,-5,'Mifflinville, Pennsylvania 18631',5712,6863);
INSERT INTO "django_geo_db_zipcode" VALUES(7496,18632,-5,'Mildred, Pennsylvania 18632',5713,6864);
INSERT INTO "django_geo_db_zipcode" VALUES(7497,18634,-5,'Nanticoke, Pennsylvania 18634',5714,6865);
INSERT INTO "django_geo_db_zipcode" VALUES(7498,18635,-5,'Nescopeck, Pennsylvania 18635',5715,6866);
INSERT INTO "django_geo_db_zipcode" VALUES(7499,18636,-5,'Noxen, Pennsylvania 18636',5716,6867);
INSERT INTO "django_geo_db_zipcode" VALUES(7500,18638,-5,'Solebury, Pennsylvania 18638',5717,6868);
INSERT INTO "django_geo_db_zipcode" VALUES(7501,18640,-5,'Pittston, Pennsylvania 18640',5718,6869);
INSERT INTO "django_geo_db_zipcode" VALUES(7502,18641,-5,'Pittston, Pennsylvania 18641',5718,6870);
INSERT INTO "django_geo_db_zipcode" VALUES(7503,18642,-5,'Duryea, Pennsylvania 18642',5719,6871);
INSERT INTO "django_geo_db_zipcode" VALUES(7504,18643,-5,'Pittston, Pennsylvania 18643',5718,6872);
INSERT INTO "django_geo_db_zipcode" VALUES(7505,18644,-5,'Wyoming, Pennsylvania 18644',5720,6873);
INSERT INTO "django_geo_db_zipcode" VALUES(7506,18651,-5,'Plymouth, Pennsylvania 18651',5721,6874);
INSERT INTO "django_geo_db_zipcode" VALUES(7507,18653,-5,'Ransom, Pennsylvania 18653',5722,6875);
INSERT INTO "django_geo_db_zipcode" VALUES(7508,18654,-5,'Shawanese, Pennsylvania 18654',5723,6876);
INSERT INTO "django_geo_db_zipcode" VALUES(7509,18655,-5,'Shickshinny, Pennsylvania 18655',5724,6877);
INSERT INTO "django_geo_db_zipcode" VALUES(7510,18656,-5,'Sweet Valley, Pennsylvania 18656',5725,6878);
INSERT INTO "django_geo_db_zipcode" VALUES(7511,18657,-5,'Tunkhannock, Pennsylvania 18657',5549,6879);
INSERT INTO "django_geo_db_zipcode" VALUES(7512,18660,-5,'Wapwallopen, Pennsylvania 18660',5726,6880);
INSERT INTO "django_geo_db_zipcode" VALUES(7513,18661,-5,'White Haven, Pennsylvania 18661',5727,6881);
INSERT INTO "django_geo_db_zipcode" VALUES(7514,18672,-5,'Bridgeton, Pennsylvania 18672',5728,6882);
INSERT INTO "django_geo_db_zipcode" VALUES(7515,18690,-5,'Dallas, Pennsylvania 18690',5695,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7516,18701,-5,'Wilkes Barre, Pennsylvania 18701',5729,6883);
INSERT INTO "django_geo_db_zipcode" VALUES(7517,18702,-5,'Wilkes Barre, Pennsylvania 18702',5729,6884);
INSERT INTO "django_geo_db_zipcode" VALUES(7518,18703,-5,'Wilkes Barre, Pennsylvania 18703',5729,6885);
INSERT INTO "django_geo_db_zipcode" VALUES(7519,18704,-5,'Kingston, Pennsylvania 18704',5730,6886);
INSERT INTO "django_geo_db_zipcode" VALUES(7520,18705,-5,'Wilkes Barre, Pennsylvania 18705',5729,6887);
INSERT INTO "django_geo_db_zipcode" VALUES(7521,18706,-5,'Wilkes Barre, Pennsylvania 18706',5729,6888);
INSERT INTO "django_geo_db_zipcode" VALUES(7522,18707,-5,'Mountain Top, Pennsylvania 18707',5731,6889);
INSERT INTO "django_geo_db_zipcode" VALUES(7523,18708,-5,'Shavertown, Pennsylvania 18708',5732,6890);
INSERT INTO "django_geo_db_zipcode" VALUES(7524,18709,-5,'Luzerne, Pennsylvania 18709',5733,6891);
INSERT INTO "django_geo_db_zipcode" VALUES(7525,18710,-5,'Wilkes Barre, Pennsylvania 18710',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7526,18711,-5,'Wilkes Barre, Pennsylvania 18711',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7527,18715,-5,'Almedia, Pennsylvania 18715',5734,6892);
INSERT INTO "django_geo_db_zipcode" VALUES(7528,18761,-5,'Wilkes Barre, Pennsylvania 18761',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7529,18762,-5,'Wilkes Barre, Pennsylvania 18762',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7530,18763,-5,'Wilkes Barre, Pennsylvania 18763',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7531,18764,-5,'Wilkes Barre, Pennsylvania 18764',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7532,18765,-5,'Wilkes Barre, Pennsylvania 18765',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7533,18766,-5,'Wilkes Barre, Pennsylvania 18766',5729,6893);
INSERT INTO "django_geo_db_zipcode" VALUES(7534,18767,-5,'Wilkes Barre, Pennsylvania 18767',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7535,18768,-5,'Wilkes Barre, Pennsylvania 18768',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7536,18769,-5,'Wilkes Barre, Pennsylvania 18769',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7537,18773,-5,'Wilkes Barre, Pennsylvania 18773',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7538,18774,-5,'Wilkes Barre, Pennsylvania 18774',5729,6704);
INSERT INTO "django_geo_db_zipcode" VALUES(7539,18801,-5,'Montrose, Pennsylvania 18801',5735,6894);
INSERT INTO "django_geo_db_zipcode" VALUES(7540,18810,-5,'Athens, Pennsylvania 18810',5736,6895);
INSERT INTO "django_geo_db_zipcode" VALUES(7541,18812,-5,'Brackney, Pennsylvania 18812',5737,6896);
INSERT INTO "django_geo_db_zipcode" VALUES(7542,18813,-5,'Brooklyn, Pennsylvania 18813',5738,6897);
INSERT INTO "django_geo_db_zipcode" VALUES(7543,18814,-5,'Burlington, Pennsylvania 18814',5739,6898);
INSERT INTO "django_geo_db_zipcode" VALUES(7544,18815,-5,'Camptown, Pennsylvania 18815',5740,6133);
INSERT INTO "django_geo_db_zipcode" VALUES(7545,18816,-5,'Dimock, Pennsylvania 18816',5741,6899);
INSERT INTO "django_geo_db_zipcode" VALUES(7546,18817,-5,'East Smithfield, Pennsylvania 18817',5742,6900);
INSERT INTO "django_geo_db_zipcode" VALUES(7547,18818,-5,'Friendsville, Pennsylvania 18818',5743,6901);
INSERT INTO "django_geo_db_zipcode" VALUES(7548,18820,-5,'Gibson, Pennsylvania 18820',5744,6902);
INSERT INTO "django_geo_db_zipcode" VALUES(7549,18821,-5,'Great Bend, Pennsylvania 18821',5745,6903);
INSERT INTO "django_geo_db_zipcode" VALUES(7550,18822,-5,'Hallstead, Pennsylvania 18822',5746,6904);
INSERT INTO "django_geo_db_zipcode" VALUES(7551,18823,-5,'Harford, Pennsylvania 18823',5747,6905);
INSERT INTO "django_geo_db_zipcode" VALUES(7552,18824,-5,'Hop Bottom, Pennsylvania 18824',5748,6906);
INSERT INTO "django_geo_db_zipcode" VALUES(7553,18825,-5,'Jackson, Pennsylvania 18825',5749,6907);
INSERT INTO "django_geo_db_zipcode" VALUES(7554,18826,-5,'Kingsley, Pennsylvania 18826',5750,6908);
INSERT INTO "django_geo_db_zipcode" VALUES(7555,18827,-5,'Lanesboro, Pennsylvania 18827',5751,6909);
INSERT INTO "django_geo_db_zipcode" VALUES(7556,18828,-5,'Lawton, Pennsylvania 18828',5752,6910);
INSERT INTO "django_geo_db_zipcode" VALUES(7557,18829,-5,'Le Raysville, Pennsylvania 18829',5753,6911);
INSERT INTO "django_geo_db_zipcode" VALUES(7558,18830,-5,'Little Meadows, Pennsylvania 18830',5754,6912);
INSERT INTO "django_geo_db_zipcode" VALUES(7559,18831,-5,'Milan, Pennsylvania 18831',5755,6913);
INSERT INTO "django_geo_db_zipcode" VALUES(7560,18832,-5,'Monroeton, Pennsylvania 18832',5756,6914);
INSERT INTO "django_geo_db_zipcode" VALUES(7561,18833,-5,'New Albany, Pennsylvania 18833',5757,6915);
INSERT INTO "django_geo_db_zipcode" VALUES(7562,18834,-5,'New Milford, Pennsylvania 18834',5758,6916);
INSERT INTO "django_geo_db_zipcode" VALUES(7563,18837,-5,'Rome, Pennsylvania 18837',5759,6917);
INSERT INTO "django_geo_db_zipcode" VALUES(7564,18839,-5,'Rushville, Pennsylvania 18839',5760,6918);
INSERT INTO "django_geo_db_zipcode" VALUES(7565,18840,-5,'Sayre, Pennsylvania 18840',5761,6919);
INSERT INTO "django_geo_db_zipcode" VALUES(7566,18842,-5,'South Gibson, Pennsylvania 18842',5762,6920);
INSERT INTO "django_geo_db_zipcode" VALUES(7567,18843,-5,'South Montrose, Pennsylvania 18843',5763,6921);
INSERT INTO "django_geo_db_zipcode" VALUES(7568,18844,-5,'Springville, Pennsylvania 18844',5764,6922);
INSERT INTO "django_geo_db_zipcode" VALUES(7569,18845,-5,'Stevensville, Pennsylvania 18845',5765,6923);
INSERT INTO "django_geo_db_zipcode" VALUES(7570,18846,-5,'Sugar Run, Pennsylvania 18846',5766,6924);
INSERT INTO "django_geo_db_zipcode" VALUES(7571,18847,-5,'Susquehanna, Pennsylvania 18847',5767,6925);
INSERT INTO "django_geo_db_zipcode" VALUES(7572,18848,-5,'Towanda, Pennsylvania 18848',5768,6926);
INSERT INTO "django_geo_db_zipcode" VALUES(7573,18850,-5,'Ulster, Pennsylvania 18850',5769,6927);
INSERT INTO "django_geo_db_zipcode" VALUES(7574,18851,-5,'Warren Center, Pennsylvania 18851',5770,6928);
INSERT INTO "django_geo_db_zipcode" VALUES(7575,18853,-5,'Wyalusing, Pennsylvania 18853',5771,6929);
INSERT INTO "django_geo_db_zipcode" VALUES(7576,18854,-5,'Wysox, Pennsylvania 18854',5772,6930);
INSERT INTO "django_geo_db_zipcode" VALUES(7577,18901,-5,'Doylestown, Pennsylvania 18901',5773,6931);
INSERT INTO "django_geo_db_zipcode" VALUES(7578,18903,-5,'Doylestown, Pennsylvania 18903',5773,6932);
INSERT INTO "django_geo_db_zipcode" VALUES(7579,18910,-5,'Bedminster, Pennsylvania 18910',5774,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7580,18911,-5,'Blooming Glen, Pennsylvania 18911',5775,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7581,18912,-5,'Buckingham, Pennsylvania 18912',5776,6933);
INSERT INTO "django_geo_db_zipcode" VALUES(7582,18913,-5,'Carversville, Pennsylvania 18913',5777,6934);
INSERT INTO "django_geo_db_zipcode" VALUES(7583,18914,-5,'Chalfont, Pennsylvania 18914',5778,6935);
INSERT INTO "django_geo_db_zipcode" VALUES(7584,18915,-5,'Colmar, Pennsylvania 18915',5779,6936);
INSERT INTO "django_geo_db_zipcode" VALUES(7585,18916,-5,'Danboro, Pennsylvania 18916',5780,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7586,18917,-5,'Dublin, Pennsylvania 18917',5781,6937);
INSERT INTO "django_geo_db_zipcode" VALUES(7587,18918,-5,'Earlington, Pennsylvania 18918',5782,6938);
INSERT INTO "django_geo_db_zipcode" VALUES(7588,18920,-5,'Erwinna, Pennsylvania 18920',5783,6939);
INSERT INTO "django_geo_db_zipcode" VALUES(7589,18921,-5,'Ferndale, Pennsylvania 18921',5784,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7590,18922,-5,'Forest Grove, Pennsylvania 18922',5785,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7591,18923,-5,'Fountainville, Pennsylvania 18923',5786,6940);
INSERT INTO "django_geo_db_zipcode" VALUES(7592,18924,-5,'Franconia, Pennsylvania 18924',5787,6941);
INSERT INTO "django_geo_db_zipcode" VALUES(7593,18925,-5,'Furlong, Pennsylvania 18925',5788,6942);
INSERT INTO "django_geo_db_zipcode" VALUES(7594,18926,-5,'Gardenville, Pennsylvania 18926',5789,6943);
INSERT INTO "django_geo_db_zipcode" VALUES(7595,18927,-5,'Hilltown, Pennsylvania 18927',5790,6944);
INSERT INTO "django_geo_db_zipcode" VALUES(7596,18928,-5,'Holicong, Pennsylvania 18928',5791,6945);
INSERT INTO "django_geo_db_zipcode" VALUES(7597,18929,-5,'Jamison, Pennsylvania 18929',5792,6946);
INSERT INTO "django_geo_db_zipcode" VALUES(7598,18930,-5,'Kintnersville, Pennsylvania 18930',5793,6947);
INSERT INTO "django_geo_db_zipcode" VALUES(7599,18931,-5,'Lahaska, Pennsylvania 18931',5794,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7600,18932,-5,'Line Lexington, Pennsylvania 18932',5795,6948);
INSERT INTO "django_geo_db_zipcode" VALUES(7601,18933,-5,'Lumberville, Pennsylvania 18933',5796,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7602,18934,-5,'Mechanicsville, Pennsylvania 18934',5797,6949);
INSERT INTO "django_geo_db_zipcode" VALUES(7603,18935,-5,'Milford Square, Pennsylvania 18935',5798,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7604,18936,-5,'Montgomeryville, Pennsylvania 18936',5799,6950);
INSERT INTO "django_geo_db_zipcode" VALUES(7605,18938,-5,'New Hope, Pennsylvania 18938',5800,6951);
INSERT INTO "django_geo_db_zipcode" VALUES(7606,18940,-5,'Newtown, Pennsylvania 18940',5801,6952);
INSERT INTO "django_geo_db_zipcode" VALUES(7607,18942,-5,'Ottsville, Pennsylvania 18942',5802,6953);
INSERT INTO "django_geo_db_zipcode" VALUES(7608,18943,-5,'Penns Park, Pennsylvania 18943',5803,6954);
INSERT INTO "django_geo_db_zipcode" VALUES(7609,18944,-5,'Perkasie, Pennsylvania 18944',5804,6955);
INSERT INTO "django_geo_db_zipcode" VALUES(7610,18945,-5,'Plumstead, Pennsylvania 18945',5805,6956);
INSERT INTO "django_geo_db_zipcode" VALUES(7611,18946,-5,'Pineville, Pennsylvania 18946',5806,6957);
INSERT INTO "django_geo_db_zipcode" VALUES(7612,18947,-5,'Pipersville, Pennsylvania 18947',5807,6958);
INSERT INTO "django_geo_db_zipcode" VALUES(7613,18949,-5,'Plumsteadville, Pennsylvania 18949',5808,6959);
INSERT INTO "django_geo_db_zipcode" VALUES(7614,18950,-5,'Point Pleasant, Pennsylvania 18950',5809,6960);
INSERT INTO "django_geo_db_zipcode" VALUES(7615,18951,-5,'Quakertown, Pennsylvania 18951',5810,6961);
INSERT INTO "django_geo_db_zipcode" VALUES(7616,18953,-5,'Revere, Pennsylvania 18953',5811,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7617,18954,-5,'Richboro, Pennsylvania 18954',5812,6962);
INSERT INTO "django_geo_db_zipcode" VALUES(7618,18955,-5,'Richlandtown, Pennsylvania 18955',5813,6963);
INSERT INTO "django_geo_db_zipcode" VALUES(7619,18956,-5,'Rushland, Pennsylvania 18956',5814,6964);
INSERT INTO "django_geo_db_zipcode" VALUES(7620,18957,-5,'Salford, Pennsylvania 18957',5815,6965);
INSERT INTO "django_geo_db_zipcode" VALUES(7621,18958,-5,'Salfordville, Pennsylvania 18958',5816,6966);
INSERT INTO "django_geo_db_zipcode" VALUES(7622,18960,-5,'Sellersville, Pennsylvania 18960',5817,6967);
INSERT INTO "django_geo_db_zipcode" VALUES(7623,18962,-5,'Silverdale, Pennsylvania 18962',5818,6968);
INSERT INTO "django_geo_db_zipcode" VALUES(7624,18963,-5,'Solebury, Pennsylvania 18963',5717,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7625,18964,-5,'Souderton, Pennsylvania 18964',5819,6969);
INSERT INTO "django_geo_db_zipcode" VALUES(7626,18966,-5,'Southampton, Pennsylvania 18966',5214,6970);
INSERT INTO "django_geo_db_zipcode" VALUES(7627,18968,-5,'Spinnerstown, Pennsylvania 18968',5820,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7628,18969,-5,'Telford, Pennsylvania 18969',5821,6971);
INSERT INTO "django_geo_db_zipcode" VALUES(7629,18970,-5,'Trumbauersville, Pennsylvania 18970',5822,6972);
INSERT INTO "django_geo_db_zipcode" VALUES(7630,18971,-5,'Tylersport, Pennsylvania 18971',5823,6973);
INSERT INTO "django_geo_db_zipcode" VALUES(7631,18972,-5,'Upper Black Eddy, Pennsylvania 18972',5824,6974);
INSERT INTO "django_geo_db_zipcode" VALUES(7632,18974,-5,'Warminster, Pennsylvania 18974',5825,6975);
INSERT INTO "django_geo_db_zipcode" VALUES(7633,18976,-5,'Warrington, Pennsylvania 18976',5826,6976);
INSERT INTO "django_geo_db_zipcode" VALUES(7634,18977,-5,'Washington Crossing, Pennsylvania 18977',5827,6977);
INSERT INTO "django_geo_db_zipcode" VALUES(7635,18979,-5,'Woxall, Pennsylvania 18979',5828,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7636,18980,-5,'Wycombe, Pennsylvania 18980',5829,6979);
INSERT INTO "django_geo_db_zipcode" VALUES(7637,18981,-5,'Zionhill, Pennsylvania 18981',5830,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7638,18991,-5,'Warminster, Pennsylvania 18991',5825,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7639,19001,-5,'Abington, Pennsylvania 19001',5831,6980);
INSERT INTO "django_geo_db_zipcode" VALUES(7640,19002,-5,'Ambler, Pennsylvania 19002',5832,6981);
INSERT INTO "django_geo_db_zipcode" VALUES(7641,19003,-5,'Ardmore, Pennsylvania 19003',5833,6982);
INSERT INTO "django_geo_db_zipcode" VALUES(7642,19004,-5,'Bala Cynwyd, Pennsylvania 19004',5834,6983);
INSERT INTO "django_geo_db_zipcode" VALUES(7643,19006,-5,'Huntingdon Valley, Pennsylvania 19006',5835,6984);
INSERT INTO "django_geo_db_zipcode" VALUES(7644,19007,-5,'Bristol, Pennsylvania 19007',5836,6985);
INSERT INTO "django_geo_db_zipcode" VALUES(7645,19008,-5,'Broomall, Pennsylvania 19008',5837,6986);
INSERT INTO "django_geo_db_zipcode" VALUES(7646,19009,-5,'Bryn Athyn, Pennsylvania 19009',5838,6987);
INSERT INTO "django_geo_db_zipcode" VALUES(7647,19010,-5,'Bryn Mawr, Pennsylvania 19010',5839,6988);
INSERT INTO "django_geo_db_zipcode" VALUES(7648,19012,-5,'Cheltenham, Pennsylvania 19012',5840,6989);
INSERT INTO "django_geo_db_zipcode" VALUES(7649,19013,-5,'Chester, Pennsylvania 19013',5841,6990);
INSERT INTO "django_geo_db_zipcode" VALUES(7650,19014,-5,'Aston, Pennsylvania 19014',5842,6991);
INSERT INTO "django_geo_db_zipcode" VALUES(7651,19015,-5,'Brookhaven, Pennsylvania 19015',5843,6992);
INSERT INTO "django_geo_db_zipcode" VALUES(7652,19016,-5,'Chester, Pennsylvania 19016',5841,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7653,19017,-5,'Chester Heights, Pennsylvania 19017',5844,6994);
INSERT INTO "django_geo_db_zipcode" VALUES(7654,19018,-5,'Primos, Pennsylvania 19018',5845,6995);
INSERT INTO "django_geo_db_zipcode" VALUES(7655,19019,-5,'Philadelphia, Pennsylvania 19019',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7656,19020,-5,'Bensalem, Pennsylvania 19020',5847,6997);
INSERT INTO "django_geo_db_zipcode" VALUES(7657,19021,-5,'Croydon, Pennsylvania 19021',5848,6998);
INSERT INTO "django_geo_db_zipcode" VALUES(7658,19022,-5,'Crum Lynne, Pennsylvania 19022',5849,6999);
INSERT INTO "django_geo_db_zipcode" VALUES(7659,19023,-5,'Darby, Pennsylvania 19023',5850,7000);
INSERT INTO "django_geo_db_zipcode" VALUES(7660,19025,-5,'Dresher, Pennsylvania 19025',5851,7001);
INSERT INTO "django_geo_db_zipcode" VALUES(7661,19026,-5,'Drexel Hill, Pennsylvania 19026',5852,7002);
INSERT INTO "django_geo_db_zipcode" VALUES(7662,19027,-5,'Elkins Park, Pennsylvania 19027',5853,7003);
INSERT INTO "django_geo_db_zipcode" VALUES(7663,19028,-5,'Edgemont, Pennsylvania 19028',5854,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7664,19029,-5,'Essington, Pennsylvania 19029',5855,7004);
INSERT INTO "django_geo_db_zipcode" VALUES(7665,19030,-5,'Fairless Hills, Pennsylvania 19030',5856,7005);
INSERT INTO "django_geo_db_zipcode" VALUES(7666,19031,-5,'Flourtown, Pennsylvania 19031',5857,7006);
INSERT INTO "django_geo_db_zipcode" VALUES(7667,19032,-5,'Folcroft, Pennsylvania 19032',5858,7007);
INSERT INTO "django_geo_db_zipcode" VALUES(7668,19033,-5,'Folsom, Pennsylvania 19033',5859,7008);
INSERT INTO "django_geo_db_zipcode" VALUES(7669,19034,-5,'Fort Washington, Pennsylvania 19034',5860,7009);
INSERT INTO "django_geo_db_zipcode" VALUES(7670,19035,-5,'Gladwyne, Pennsylvania 19035',5861,7010);
INSERT INTO "django_geo_db_zipcode" VALUES(7671,19036,-5,'Glenolden, Pennsylvania 19036',5862,7011);
INSERT INTO "django_geo_db_zipcode" VALUES(7672,19037,-5,'Glen Riddle Lima, Pennsylvania 19037',5863,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7673,19038,-5,'Glenside, Pennsylvania 19038',5864,7012);
INSERT INTO "django_geo_db_zipcode" VALUES(7674,19039,-5,'Gradyville, Pennsylvania 19039',5865,7013);
INSERT INTO "django_geo_db_zipcode" VALUES(7675,19040,-5,'Hatboro, Pennsylvania 19040',5866,7014);
INSERT INTO "django_geo_db_zipcode" VALUES(7676,19041,-5,'Haverford, Pennsylvania 19041',5867,7015);
INSERT INTO "django_geo_db_zipcode" VALUES(7677,19043,-5,'Holmes, Pennsylvania 19043',5868,7016);
INSERT INTO "django_geo_db_zipcode" VALUES(7678,19044,-5,'Horsham, Pennsylvania 19044',5869,7017);
INSERT INTO "django_geo_db_zipcode" VALUES(7679,19046,-5,'Jenkintown, Pennsylvania 19046',5870,7018);
INSERT INTO "django_geo_db_zipcode" VALUES(7680,19047,-5,'Langhorne, Pennsylvania 19047',5871,7019);
INSERT INTO "django_geo_db_zipcode" VALUES(7681,19048,-5,'Langhorne, Pennsylvania 19048',5871,7020);
INSERT INTO "django_geo_db_zipcode" VALUES(7682,19049,-5,'Langhorne, Pennsylvania 19049',5871,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7683,19050,-5,'Lansdowne, Pennsylvania 19050',5872,7021);
INSERT INTO "django_geo_db_zipcode" VALUES(7684,19052,-5,'Lenni, Pennsylvania 19052',5873,7022);
INSERT INTO "django_geo_db_zipcode" VALUES(7685,19053,-5,'Feasterville Trevose, Pennsylvania 19053',5874,7023);
INSERT INTO "django_geo_db_zipcode" VALUES(7686,19054,-5,'Levittown, Pennsylvania 19054',5875,7024);
INSERT INTO "django_geo_db_zipcode" VALUES(7687,19055,-5,'Levittown, Pennsylvania 19055',5875,7025);
INSERT INTO "django_geo_db_zipcode" VALUES(7688,19056,-5,'Levittown, Pennsylvania 19056',5875,7026);
INSERT INTO "django_geo_db_zipcode" VALUES(7689,19057,-5,'Levittown, Pennsylvania 19057',5875,7027);
INSERT INTO "django_geo_db_zipcode" VALUES(7690,19058,-5,'Levittown, Pennsylvania 19058',5875,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7691,19059,-5,'Levittown, Pennsylvania 19059',5875,6640);
INSERT INTO "django_geo_db_zipcode" VALUES(7692,19061,-5,'Marcus Hook, Pennsylvania 19061',5876,7028);
INSERT INTO "django_geo_db_zipcode" VALUES(7693,19063,-5,'Media, Pennsylvania 19063',5877,7029);
INSERT INTO "django_geo_db_zipcode" VALUES(7694,19064,-5,'Springfield, Pennsylvania 19064',5878,7030);
INSERT INTO "django_geo_db_zipcode" VALUES(7695,19065,-5,'Media, Pennsylvania 19065',5877,7031);
INSERT INTO "django_geo_db_zipcode" VALUES(7696,19066,-5,'Merion Station, Pennsylvania 19066',5879,7032);
INSERT INTO "django_geo_db_zipcode" VALUES(7697,19067,-5,'Morrisville, Pennsylvania 19067',5880,7033);
INSERT INTO "django_geo_db_zipcode" VALUES(7698,19070,-5,'Morton, Pennsylvania 19070',5881,7034);
INSERT INTO "django_geo_db_zipcode" VALUES(7699,19072,-5,'Narberth, Pennsylvania 19072',5882,7035);
INSERT INTO "django_geo_db_zipcode" VALUES(7700,19073,-5,'Newtown Square, Pennsylvania 19073',5883,7036);
INSERT INTO "django_geo_db_zipcode" VALUES(7701,19074,-5,'Norwood, Pennsylvania 19074',5884,7037);
INSERT INTO "django_geo_db_zipcode" VALUES(7702,19075,-5,'Oreland, Pennsylvania 19075',5885,7038);
INSERT INTO "django_geo_db_zipcode" VALUES(7703,19076,-5,'Prospect Park, Pennsylvania 19076',5886,7039);
INSERT INTO "django_geo_db_zipcode" VALUES(7704,19078,-5,'Ridley Park, Pennsylvania 19078',5887,7040);
INSERT INTO "django_geo_db_zipcode" VALUES(7705,19079,-5,'Sharon Hill, Pennsylvania 19079',5888,7041);
INSERT INTO "django_geo_db_zipcode" VALUES(7706,19080,-5,'Wayne, Pennsylvania 19080',5889,7042);
INSERT INTO "django_geo_db_zipcode" VALUES(7707,19081,-5,'Swarthmore, Pennsylvania 19081',5890,7043);
INSERT INTO "django_geo_db_zipcode" VALUES(7708,19082,-5,'Upper Darby, Pennsylvania 19082',5891,7044);
INSERT INTO "django_geo_db_zipcode" VALUES(7709,19083,-5,'Havertown, Pennsylvania 19083',5892,7045);
INSERT INTO "django_geo_db_zipcode" VALUES(7710,19085,-5,'Villanova, Pennsylvania 19085',5893,7046);
INSERT INTO "django_geo_db_zipcode" VALUES(7711,19086,-5,'Wallingford, Pennsylvania 19086',5894,7047);
INSERT INTO "django_geo_db_zipcode" VALUES(7712,19087,-5,'Wayne, Pennsylvania 19087',5889,7048);
INSERT INTO "django_geo_db_zipcode" VALUES(7713,19088,-5,'Wayne, Pennsylvania 19088',5889,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7714,19089,-5,'Wayne, Pennsylvania 19089',5889,7049);
INSERT INTO "django_geo_db_zipcode" VALUES(7715,19090,-5,'Willow Grove, Pennsylvania 19090',5895,7050);
INSERT INTO "django_geo_db_zipcode" VALUES(7716,19091,-5,'Media, Pennsylvania 19091',5877,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7717,19092,-5,'Philadelphia, Pennsylvania 19092',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7718,19093,-5,'Philadelphia, Pennsylvania 19093',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7719,19094,-5,'Woodlyn, Pennsylvania 19094',5896,7051);
INSERT INTO "django_geo_db_zipcode" VALUES(7720,19095,-5,'Wyncote, Pennsylvania 19095',5897,7052);
INSERT INTO "django_geo_db_zipcode" VALUES(7721,19096,-5,'Wynnewood, Pennsylvania 19096',5898,7053);
INSERT INTO "django_geo_db_zipcode" VALUES(7722,19098,-5,'Holmes, Pennsylvania 19098',5868,7054);
INSERT INTO "django_geo_db_zipcode" VALUES(7723,19099,-5,'Philadelphia, Pennsylvania 19099',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7724,19101,-5,'Philadelphia, Pennsylvania 19101',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7725,19102,-5,'Philadelphia, Pennsylvania 19102',5846,7055);
INSERT INTO "django_geo_db_zipcode" VALUES(7726,19103,-5,'Philadelphia, Pennsylvania 19103',5846,7056);
INSERT INTO "django_geo_db_zipcode" VALUES(7727,19104,-5,'Philadelphia, Pennsylvania 19104',5846,7057);
INSERT INTO "django_geo_db_zipcode" VALUES(7728,19105,-5,'Philadelphia, Pennsylvania 19105',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7729,19106,-5,'Philadelphia, Pennsylvania 19106',5846,7058);
INSERT INTO "django_geo_db_zipcode" VALUES(7730,19107,-5,'Philadelphia, Pennsylvania 19107',5846,7059);
INSERT INTO "django_geo_db_zipcode" VALUES(7731,19108,-5,'Philadelphia, Pennsylvania 19108',5846,7060);
INSERT INTO "django_geo_db_zipcode" VALUES(7732,19109,-5,'Philadelphia, Pennsylvania 19109',5846,7061);
INSERT INTO "django_geo_db_zipcode" VALUES(7733,19110,-5,'Philadelphia, Pennsylvania 19110',5846,7062);
INSERT INTO "django_geo_db_zipcode" VALUES(7734,19111,-5,'Philadelphia, Pennsylvania 19111',5846,7063);
INSERT INTO "django_geo_db_zipcode" VALUES(7735,19112,-5,'Philadelphia, Pennsylvania 19112',5846,7064);
INSERT INTO "django_geo_db_zipcode" VALUES(7736,19113,-5,'Philadelphia, Pennsylvania 19113',5846,7065);
INSERT INTO "django_geo_db_zipcode" VALUES(7737,19114,-5,'Philadelphia, Pennsylvania 19114',5846,7066);
INSERT INTO "django_geo_db_zipcode" VALUES(7738,19115,-5,'Philadelphia, Pennsylvania 19115',5846,7067);
INSERT INTO "django_geo_db_zipcode" VALUES(7739,19116,-5,'Philadelphia, Pennsylvania 19116',5846,7068);
INSERT INTO "django_geo_db_zipcode" VALUES(7740,19118,-5,'Philadelphia, Pennsylvania 19118',5846,7069);
INSERT INTO "django_geo_db_zipcode" VALUES(7741,19119,-5,'Philadelphia, Pennsylvania 19119',5846,7070);
INSERT INTO "django_geo_db_zipcode" VALUES(7742,19120,-5,'Philadelphia, Pennsylvania 19120',5846,7071);
INSERT INTO "django_geo_db_zipcode" VALUES(7743,19121,-5,'Philadelphia, Pennsylvania 19121',5846,7072);
INSERT INTO "django_geo_db_zipcode" VALUES(7744,19122,-5,'Philadelphia, Pennsylvania 19122',5846,7073);
INSERT INTO "django_geo_db_zipcode" VALUES(7745,19123,-5,'Philadelphia, Pennsylvania 19123',5846,7074);
INSERT INTO "django_geo_db_zipcode" VALUES(7746,19124,-5,'Philadelphia, Pennsylvania 19124',5846,7075);
INSERT INTO "django_geo_db_zipcode" VALUES(7747,19125,-5,'Philadelphia, Pennsylvania 19125',5846,7076);
INSERT INTO "django_geo_db_zipcode" VALUES(7748,19126,-5,'Philadelphia, Pennsylvania 19126',5846,7077);
INSERT INTO "django_geo_db_zipcode" VALUES(7749,19127,-5,'Philadelphia, Pennsylvania 19127',5846,7078);
INSERT INTO "django_geo_db_zipcode" VALUES(7750,19128,-5,'Philadelphia, Pennsylvania 19128',5846,7079);
INSERT INTO "django_geo_db_zipcode" VALUES(7751,19129,-5,'Philadelphia, Pennsylvania 19129',5846,7080);
INSERT INTO "django_geo_db_zipcode" VALUES(7752,19130,-5,'Philadelphia, Pennsylvania 19130',5846,7081);
INSERT INTO "django_geo_db_zipcode" VALUES(7753,19131,-5,'Philadelphia, Pennsylvania 19131',5846,7082);
INSERT INTO "django_geo_db_zipcode" VALUES(7754,19132,-5,'Philadelphia, Pennsylvania 19132',5846,7083);
INSERT INTO "django_geo_db_zipcode" VALUES(7755,19133,-5,'Philadelphia, Pennsylvania 19133',5846,7084);
INSERT INTO "django_geo_db_zipcode" VALUES(7756,19134,-5,'Philadelphia, Pennsylvania 19134',5846,7085);
INSERT INTO "django_geo_db_zipcode" VALUES(7757,19135,-5,'Philadelphia, Pennsylvania 19135',5846,7086);
INSERT INTO "django_geo_db_zipcode" VALUES(7758,19136,-5,'Philadelphia, Pennsylvania 19136',5846,7087);
INSERT INTO "django_geo_db_zipcode" VALUES(7759,19137,-5,'Philadelphia, Pennsylvania 19137',5846,7088);
INSERT INTO "django_geo_db_zipcode" VALUES(7760,19138,-5,'Philadelphia, Pennsylvania 19138',5846,7089);
INSERT INTO "django_geo_db_zipcode" VALUES(7761,19139,-5,'Philadelphia, Pennsylvania 19139',5846,7090);
INSERT INTO "django_geo_db_zipcode" VALUES(7762,19140,-5,'Philadelphia, Pennsylvania 19140',5846,7091);
INSERT INTO "django_geo_db_zipcode" VALUES(7763,19141,-5,'Philadelphia, Pennsylvania 19141',5846,7092);
INSERT INTO "django_geo_db_zipcode" VALUES(7764,19142,-5,'Philadelphia, Pennsylvania 19142',5846,7093);
INSERT INTO "django_geo_db_zipcode" VALUES(7765,19143,-5,'Philadelphia, Pennsylvania 19143',5846,7094);
INSERT INTO "django_geo_db_zipcode" VALUES(7766,19144,-5,'Philadelphia, Pennsylvania 19144',5846,7095);
INSERT INTO "django_geo_db_zipcode" VALUES(7767,19145,-5,'Philadelphia, Pennsylvania 19145',5846,7096);
INSERT INTO "django_geo_db_zipcode" VALUES(7768,19146,-5,'Philadelphia, Pennsylvania 19146',5846,7097);
INSERT INTO "django_geo_db_zipcode" VALUES(7769,19147,-5,'Philadelphia, Pennsylvania 19147',5846,7098);
INSERT INTO "django_geo_db_zipcode" VALUES(7770,19148,-5,'Philadelphia, Pennsylvania 19148',5846,7099);
INSERT INTO "django_geo_db_zipcode" VALUES(7771,19149,-5,'Philadelphia, Pennsylvania 19149',5846,7100);
INSERT INTO "django_geo_db_zipcode" VALUES(7772,19150,-5,'Philadelphia, Pennsylvania 19150',5846,7101);
INSERT INTO "django_geo_db_zipcode" VALUES(7773,19151,-5,'Philadelphia, Pennsylvania 19151',5846,7102);
INSERT INTO "django_geo_db_zipcode" VALUES(7774,19152,-5,'Philadelphia, Pennsylvania 19152',5846,7103);
INSERT INTO "django_geo_db_zipcode" VALUES(7775,19153,-5,'Philadelphia, Pennsylvania 19153',5846,7104);
INSERT INTO "django_geo_db_zipcode" VALUES(7776,19154,-5,'Philadelphia, Pennsylvania 19154',5846,7105);
INSERT INTO "django_geo_db_zipcode" VALUES(7777,19155,-5,'Philadelphia, Pennsylvania 19155',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7778,19156,-5,'Centerport, Pennsylvania 19156',5899,7106);
INSERT INTO "django_geo_db_zipcode" VALUES(7779,19160,-5,'Philadelphia, Pennsylvania 19160',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7780,19161,-5,'Philadelphia, Pennsylvania 19161',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7781,19162,-5,'Philadelphia, Pennsylvania 19162',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7782,19170,-5,'Philadelphia, Pennsylvania 19170',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7783,19171,-5,'Philadelphia, Pennsylvania 19171',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7784,19172,-5,'Philadelphia, Pennsylvania 19172',5846,7107);
INSERT INTO "django_geo_db_zipcode" VALUES(7785,19173,-5,'Philadelphia, Pennsylvania 19173',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7786,19175,-5,'Philadelphia, Pennsylvania 19175',5846,7108);
INSERT INTO "django_geo_db_zipcode" VALUES(7787,19177,-5,'Philadelphia, Pennsylvania 19177',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7788,19178,-5,'Philadelphia, Pennsylvania 19178',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7789,19179,-5,'Philadelphia, Pennsylvania 19179',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7790,19181,-5,'Philadelphia, Pennsylvania 19181',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7791,19182,-5,'Philadelphia, Pennsylvania 19182',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7792,19183,-5,'Philadelphia, Pennsylvania 19183',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7793,19184,-5,'Philadelphia, Pennsylvania 19184',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7794,19185,-5,'Philadelphia, Pennsylvania 19185',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7795,19187,-5,'Philadelphia, Pennsylvania 19187',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7796,19188,-5,'Philadelphia, Pennsylvania 19188',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7797,19191,-5,'Philadelphia, Pennsylvania 19191',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7798,19192,-5,'Philadelphia, Pennsylvania 19192',5846,7109);
INSERT INTO "django_geo_db_zipcode" VALUES(7799,19193,-5,'Philadelphia, Pennsylvania 19193',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7800,19194,-5,'Philadelphia, Pennsylvania 19194',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7801,19196,-5,'Philadelphia, Pennsylvania 19196',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7802,19197,-5,'Philadelphia, Pennsylvania 19197',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7803,19244,-5,'Philadelphia, Pennsylvania 19244',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7804,19255,-5,'Philadelphia, Pennsylvania 19255',5846,6996);
INSERT INTO "django_geo_db_zipcode" VALUES(7805,19301,-5,'Paoli, Pennsylvania 19301',5900,7110);
INSERT INTO "django_geo_db_zipcode" VALUES(7806,19310,-5,'Atglen, Pennsylvania 19310',5901,7111);
INSERT INTO "django_geo_db_zipcode" VALUES(7807,19311,-5,'Avondale, Pennsylvania 19311',5902,7112);
INSERT INTO "django_geo_db_zipcode" VALUES(7808,19312,-5,'Berwyn, Pennsylvania 19312',5903,7113);
INSERT INTO "django_geo_db_zipcode" VALUES(7809,19316,-5,'Brandamore, Pennsylvania 19316',5904,7114);
INSERT INTO "django_geo_db_zipcode" VALUES(7810,19317,-5,'Chadds Ford, Pennsylvania 19317',5905,7115);
INSERT INTO "django_geo_db_zipcode" VALUES(7811,19318,-5,'Chatham, Pennsylvania 19318',5906,7116);
INSERT INTO "django_geo_db_zipcode" VALUES(7812,19319,-5,'Cheyney, Pennsylvania 19319',5907,7117);
INSERT INTO "django_geo_db_zipcode" VALUES(7813,19320,-5,'Coatesville, Pennsylvania 19320',5908,7118);
INSERT INTO "django_geo_db_zipcode" VALUES(7814,19330,-5,'Cochranville, Pennsylvania 19330',5909,7119);
INSERT INTO "django_geo_db_zipcode" VALUES(7815,19331,-5,'Concordville, Pennsylvania 19331',5910,7120);
INSERT INTO "django_geo_db_zipcode" VALUES(7816,19333,-5,'Devon, Pennsylvania 19333',5911,7121);
INSERT INTO "django_geo_db_zipcode" VALUES(7817,19335,-5,'Downingtown, Pennsylvania 19335',5912,7122);
INSERT INTO "django_geo_db_zipcode" VALUES(7818,19339,-5,'Concordville, Pennsylvania 19339',5910,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7819,19340,-5,'Concordville, Pennsylvania 19340',5910,6993);
INSERT INTO "django_geo_db_zipcode" VALUES(7820,19341,-5,'Exton, Pennsylvania 19341',5913,7123);
INSERT INTO "django_geo_db_zipcode" VALUES(7821,19342,-5,'Glen Mills, Pennsylvania 19342',5914,7124);
INSERT INTO "django_geo_db_zipcode" VALUES(7822,19343,-5,'Glenmoore, Pennsylvania 19343',5915,7125);
INSERT INTO "django_geo_db_zipcode" VALUES(7823,19344,-5,'Honey Brook, Pennsylvania 19344',5916,7126);
INSERT INTO "django_geo_db_zipcode" VALUES(7824,19345,-5,'Immaculata, Pennsylvania 19345',5917,7127);
INSERT INTO "django_geo_db_zipcode" VALUES(7825,19346,-5,'Kelton, Pennsylvania 19346',5918,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7826,19347,-5,'Kemblesville, Pennsylvania 19347',5919,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7827,19348,-5,'Kennett Square, Pennsylvania 19348',5920,7129);
INSERT INTO "django_geo_db_zipcode" VALUES(7828,19350,-5,'Landenberg, Pennsylvania 19350',5921,7130);
INSERT INTO "django_geo_db_zipcode" VALUES(7829,19351,-5,'Lewisville, Pennsylvania 19351',5922,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7830,19352,-5,'Lincoln University, Pennsylvania 19352',5923,7131);
INSERT INTO "django_geo_db_zipcode" VALUES(7831,19353,-5,'Lionville, Pennsylvania 19353',5924,7132);
INSERT INTO "django_geo_db_zipcode" VALUES(7832,19354,-5,'Lyndell, Pennsylvania 19354',5925,7133);
INSERT INTO "django_geo_db_zipcode" VALUES(7833,19355,-5,'Malvern, Pennsylvania 19355',5926,7134);
INSERT INTO "django_geo_db_zipcode" VALUES(7834,19357,-5,'Mendenhall, Pennsylvania 19357',5927,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7835,19358,-5,'Modena, Pennsylvania 19358',5928,7135);
INSERT INTO "django_geo_db_zipcode" VALUES(7836,19360,-5,'New London, Pennsylvania 19360',5929,7136);
INSERT INTO "django_geo_db_zipcode" VALUES(7837,19362,-5,'Nottingham, Pennsylvania 19362',5930,7137);
INSERT INTO "django_geo_db_zipcode" VALUES(7838,19363,-5,'Oxford, Pennsylvania 19363',5931,7138);
INSERT INTO "django_geo_db_zipcode" VALUES(7839,19365,-5,'Parkesburg, Pennsylvania 19365',5932,7139);
INSERT INTO "django_geo_db_zipcode" VALUES(7840,19366,-5,'Pocopson, Pennsylvania 19366',5933,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7841,19367,-5,'Pomeroy, Pennsylvania 19367',5934,7140);
INSERT INTO "django_geo_db_zipcode" VALUES(7842,19369,-5,'Sadsburyville, Pennsylvania 19369',5935,7141);
INSERT INTO "django_geo_db_zipcode" VALUES(7843,19370,-5,'Steelville, Pennsylvania 19370',5936,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7844,19371,-5,'Suplee, Pennsylvania 19371',5937,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7845,19372,-5,'Thorndale, Pennsylvania 19372',5938,7142);
INSERT INTO "django_geo_db_zipcode" VALUES(7846,19373,-5,'Thornton, Pennsylvania 19373',5939,7143);
INSERT INTO "django_geo_db_zipcode" VALUES(7847,19374,-5,'Toughkenamon, Pennsylvania 19374',5940,7144);
INSERT INTO "django_geo_db_zipcode" VALUES(7848,19375,-5,'Unionville, Pennsylvania 19375',5941,7145);
INSERT INTO "django_geo_db_zipcode" VALUES(7849,19376,-5,'Wagontown, Pennsylvania 19376',5942,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7850,19380,-5,'West Chester, Pennsylvania 19380',5943,7146);
INSERT INTO "django_geo_db_zipcode" VALUES(7851,19381,-5,'West Chester, Pennsylvania 19381',5943,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7852,19382,-5,'West Chester, Pennsylvania 19382',5943,7147);
INSERT INTO "django_geo_db_zipcode" VALUES(7853,19383,-5,'West Chester, Pennsylvania 19383',5943,7148);
INSERT INTO "django_geo_db_zipcode" VALUES(7854,19390,-5,'West Grove, Pennsylvania 19390',5944,7149);
INSERT INTO "django_geo_db_zipcode" VALUES(7855,19395,-5,'Westtown, Pennsylvania 19395',5945,7150);
INSERT INTO "django_geo_db_zipcode" VALUES(7856,19397,-5,'Southeastern, Pennsylvania 19397',5946,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7857,19398,-5,'Southeastern, Pennsylvania 19398',5946,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7858,19399,-5,'Southeastern, Pennsylvania 19399',5946,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7859,19401,-5,'Norristown, Pennsylvania 19401',5947,7151);
INSERT INTO "django_geo_db_zipcode" VALUES(7860,19403,-5,'Norristown, Pennsylvania 19403',5947,7152);
INSERT INTO "django_geo_db_zipcode" VALUES(7861,19404,-5,'Norristown, Pennsylvania 19404',5947,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7862,19405,-5,'Bridgeport, Pennsylvania 19405',5948,7153);
INSERT INTO "django_geo_db_zipcode" VALUES(7863,19406,-5,'King Of Prussia, Pennsylvania 19406',5949,7154);
INSERT INTO "django_geo_db_zipcode" VALUES(7864,19407,-5,'Audubon, Pennsylvania 19407',5950,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7865,19408,-5,'Eagleville, Pennsylvania 19408',5951,7155);
INSERT INTO "django_geo_db_zipcode" VALUES(7866,19409,-5,'Fairview Village, Pennsylvania 19409',5952,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7867,19420,-5,'Arcola, Pennsylvania 19420',5953,7156);
INSERT INTO "django_geo_db_zipcode" VALUES(7868,19421,-5,'Birchrunville, Pennsylvania 19421',5954,7157);
INSERT INTO "django_geo_db_zipcode" VALUES(7869,19422,-5,'Blue Bell, Pennsylvania 19422',5955,7158);
INSERT INTO "django_geo_db_zipcode" VALUES(7870,19423,-5,'Cedars, Pennsylvania 19423',5956,7159);
INSERT INTO "django_geo_db_zipcode" VALUES(7871,19424,-5,'Blue Bell, Pennsylvania 19424',5955,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7872,19425,-5,'Chester Springs, Pennsylvania 19425',5957,7160);
INSERT INTO "django_geo_db_zipcode" VALUES(7873,19426,-5,'Collegeville, Pennsylvania 19426',5958,7161);
INSERT INTO "django_geo_db_zipcode" VALUES(7874,19428,-5,'Conshohocken, Pennsylvania 19428',5959,7162);
INSERT INTO "django_geo_db_zipcode" VALUES(7875,19429,-5,'Conshohocken, Pennsylvania 19429',5959,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7876,19430,-5,'Creamery, Pennsylvania 19430',5960,7163);
INSERT INTO "django_geo_db_zipcode" VALUES(7877,19432,-5,'Devault, Pennsylvania 19432',5961,7164);
INSERT INTO "django_geo_db_zipcode" VALUES(7878,19435,-5,'Frederick, Pennsylvania 19435',5962,7165);
INSERT INTO "django_geo_db_zipcode" VALUES(7879,19436,-5,'Gwynedd, Pennsylvania 19436',5963,7166);
INSERT INTO "django_geo_db_zipcode" VALUES(7880,19437,-5,'Gwynedd Valley, Pennsylvania 19437',5964,7167);
INSERT INTO "django_geo_db_zipcode" VALUES(7881,19438,-5,'Harleysville, Pennsylvania 19438',5965,7168);
INSERT INTO "django_geo_db_zipcode" VALUES(7882,19440,-5,'Hatfield, Pennsylvania 19440',5966,7169);
INSERT INTO "django_geo_db_zipcode" VALUES(7883,19441,-5,'Harleysville, Pennsylvania 19441',5965,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7884,19442,-5,'Kimberton, Pennsylvania 19442',5967,7170);
INSERT INTO "django_geo_db_zipcode" VALUES(7885,19443,-5,'Kulpsville, Pennsylvania 19443',5968,7171);
INSERT INTO "django_geo_db_zipcode" VALUES(7886,19444,-5,'Lafayette Hill, Pennsylvania 19444',5969,7172);
INSERT INTO "django_geo_db_zipcode" VALUES(7887,19446,-5,'Lansdale, Pennsylvania 19446',5970,7173);
INSERT INTO "django_geo_db_zipcode" VALUES(7888,19450,-5,'Lederach, Pennsylvania 19450',5971,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7889,19451,-5,'Mainland, Pennsylvania 19451',5972,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7890,19452,-5,'Miquon, Pennsylvania 19452',5973,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7891,19453,-5,'Mont Clare, Pennsylvania 19453',5974,7174);
INSERT INTO "django_geo_db_zipcode" VALUES(7892,19454,-5,'North Wales, Pennsylvania 19454',5975,7175);
INSERT INTO "django_geo_db_zipcode" VALUES(7893,19455,-5,'North Wales, Pennsylvania 19455',5975,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7894,19456,-5,'Oaks, Pennsylvania 19456',5976,7176);
INSERT INTO "django_geo_db_zipcode" VALUES(7895,19457,-5,'Parker Ford, Pennsylvania 19457',5977,7177);
INSERT INTO "django_geo_db_zipcode" VALUES(7896,19460,-5,'Phoenixville, Pennsylvania 19460',5978,7178);
INSERT INTO "django_geo_db_zipcode" VALUES(7897,19462,-5,'Plymouth Meeting, Pennsylvania 19462',5979,7179);
INSERT INTO "django_geo_db_zipcode" VALUES(7898,19464,-5,'Pottstown, Pennsylvania 19464',5980,7180);
INSERT INTO "django_geo_db_zipcode" VALUES(7899,19465,-5,'Pottstown, Pennsylvania 19465',5980,7181);
INSERT INTO "django_geo_db_zipcode" VALUES(7900,19468,-5,'Royersford, Pennsylvania 19468',5981,7182);
INSERT INTO "django_geo_db_zipcode" VALUES(7901,19470,-5,'Saint Peters, Pennsylvania 19470',5982,7183);
INSERT INTO "django_geo_db_zipcode" VALUES(7902,19472,-5,'Sassamansville, Pennsylvania 19472',5983,7184);
INSERT INTO "django_geo_db_zipcode" VALUES(7903,19473,-5,'Schwenksville, Pennsylvania 19473',5984,7185);
INSERT INTO "django_geo_db_zipcode" VALUES(7904,19474,-5,'Skippack, Pennsylvania 19474',5985,7186);
INSERT INTO "django_geo_db_zipcode" VALUES(7905,19475,-5,'Spring City, Pennsylvania 19475',5986,7187);
INSERT INTO "django_geo_db_zipcode" VALUES(7906,19477,-5,'Spring House, Pennsylvania 19477',5987,7188);
INSERT INTO "django_geo_db_zipcode" VALUES(7907,19478,-5,'Spring Mount, Pennsylvania 19478',5988,7189);
INSERT INTO "django_geo_db_zipcode" VALUES(7908,19480,-5,'Uwchland, Pennsylvania 19480',5989,7190);
INSERT INTO "django_geo_db_zipcode" VALUES(7909,19481,-5,'Valley Forge, Pennsylvania 19481',5990,7191);
INSERT INTO "django_geo_db_zipcode" VALUES(7910,19482,-5,'Valley Forge, Pennsylvania 19482',5990,7192);
INSERT INTO "django_geo_db_zipcode" VALUES(7911,19483,-5,'Valley Forge, Pennsylvania 19483',5990,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7912,19484,-5,'Valley Forge, Pennsylvania 19484',5990,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7913,19485,-5,'Valley Forge, Pennsylvania 19485',5990,6978);
INSERT INTO "django_geo_db_zipcode" VALUES(7914,19486,-5,'West Point, Pennsylvania 19486',5991,7193);
INSERT INTO "django_geo_db_zipcode" VALUES(7915,19487,-5,'King Of Prussia, Pennsylvania 19487',5949,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7916,19488,-5,'Norristown, Pennsylvania 19488',5947,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7917,19489,-5,'Norristown, Pennsylvania 19489',5947,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7918,19490,-5,'Worcester, Pennsylvania 19490',5992,7194);
INSERT INTO "django_geo_db_zipcode" VALUES(7919,19492,-5,'Zieglerville, Pennsylvania 19492',5993,7195);
INSERT INTO "django_geo_db_zipcode" VALUES(7920,19493,-5,'Valley Forge, Pennsylvania 19493',5990,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7921,19494,-5,'Valley Forge, Pennsylvania 19494',5990,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7922,19495,-5,'Valley Forge, Pennsylvania 19495',5990,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7923,19496,-5,'Valley Forge, Pennsylvania 19496',5990,7128);
INSERT INTO "django_geo_db_zipcode" VALUES(7924,19501,-5,'Adamstown, Pennsylvania 19501',5994,7196);
INSERT INTO "django_geo_db_zipcode" VALUES(7925,19503,-5,'Bally, Pennsylvania 19503',5995,7197);
INSERT INTO "django_geo_db_zipcode" VALUES(7926,19504,-5,'Barto, Pennsylvania 19504',5996,7198);
INSERT INTO "django_geo_db_zipcode" VALUES(7927,19505,-5,'Bechtelsville, Pennsylvania 19505',5997,7199);
INSERT INTO "django_geo_db_zipcode" VALUES(7928,19506,-5,'Bernville, Pennsylvania 19506',5998,7200);
INSERT INTO "django_geo_db_zipcode" VALUES(7929,19507,-5,'Bethel, Pennsylvania 19507',5999,7201);
INSERT INTO "django_geo_db_zipcode" VALUES(7930,19508,-5,'Birdsboro, Pennsylvania 19508',6000,7202);
INSERT INTO "django_geo_db_zipcode" VALUES(7931,19510,-5,'Blandon, Pennsylvania 19510',6001,7203);
INSERT INTO "django_geo_db_zipcode" VALUES(7932,19511,-5,'Bowers, Pennsylvania 19511',6002,7204);
INSERT INTO "django_geo_db_zipcode" VALUES(7933,19512,-5,'Boyertown, Pennsylvania 19512',6003,7205);
INSERT INTO "django_geo_db_zipcode" VALUES(7934,19516,-5,'Centerport, Pennsylvania 19516',5899,7206);
INSERT INTO "django_geo_db_zipcode" VALUES(7935,19517,-5,'Dauberville, Pennsylvania 19517',6004,7207);
INSERT INTO "django_geo_db_zipcode" VALUES(7936,19518,-5,'Douglassville, Pennsylvania 19518',6005,7208);
INSERT INTO "django_geo_db_zipcode" VALUES(7937,19519,-5,'Earlville, Pennsylvania 19519',6006,7209);
INSERT INTO "django_geo_db_zipcode" VALUES(7938,19520,-5,'Elverson, Pennsylvania 19520',6007,7210);
INSERT INTO "django_geo_db_zipcode" VALUES(7939,19522,-5,'Fleetwood, Pennsylvania 19522',6008,7211);
INSERT INTO "django_geo_db_zipcode" VALUES(7940,19523,-5,'Geigertown, Pennsylvania 19523',6009,7212);
INSERT INTO "django_geo_db_zipcode" VALUES(7941,19524,-5,'Robeson, Pennsylvania 19524',6010,7213);
INSERT INTO "django_geo_db_zipcode" VALUES(7942,19525,-5,'Gilbertsville, Pennsylvania 19525',6011,7214);
INSERT INTO "django_geo_db_zipcode" VALUES(7943,19526,-5,'Hamburg, Pennsylvania 19526',6012,7215);
INSERT INTO "django_geo_db_zipcode" VALUES(7944,19529,-5,'Kempton, Pennsylvania 19529',6013,7216);
INSERT INTO "django_geo_db_zipcode" VALUES(7945,19530,-5,'Kutztown, Pennsylvania 19530',6014,7217);
INSERT INTO "django_geo_db_zipcode" VALUES(7946,19533,-5,'Leesport, Pennsylvania 19533',6015,7218);
INSERT INTO "django_geo_db_zipcode" VALUES(7947,19534,-5,'Lenhartsville, Pennsylvania 19534',6016,7219);
INSERT INTO "django_geo_db_zipcode" VALUES(7948,19535,-5,'Limekiln, Pennsylvania 19535',6017,7220);
INSERT INTO "django_geo_db_zipcode" VALUES(7949,19536,-5,'Lyon Station, Pennsylvania 19536',6018,7221);
INSERT INTO "django_geo_db_zipcode" VALUES(7950,19538,-5,'Maxatawny, Pennsylvania 19538',6019,7222);
INSERT INTO "django_geo_db_zipcode" VALUES(7951,19539,-5,'Mertztown, Pennsylvania 19539',6020,7223);
INSERT INTO "django_geo_db_zipcode" VALUES(7952,19540,-5,'Mohnton, Pennsylvania 19540',6021,7224);
INSERT INTO "django_geo_db_zipcode" VALUES(7953,19541,-5,'Mohrsville, Pennsylvania 19541',6022,7225);
INSERT INTO "django_geo_db_zipcode" VALUES(7954,19542,-5,'Monocacy Station, Pennsylvania 19542',6023,7226);
INSERT INTO "django_geo_db_zipcode" VALUES(7955,19543,-5,'Morgantown, Pennsylvania 19543',6024,7227);
INSERT INTO "django_geo_db_zipcode" VALUES(7956,19544,-5,'Mount Aetna, Pennsylvania 19544',6025,7228);
INSERT INTO "django_geo_db_zipcode" VALUES(7957,19545,-5,'New Berlinville, Pennsylvania 19545',6026,7229);
INSERT INTO "django_geo_db_zipcode" VALUES(7958,19546,-5,'Cumru, Pennsylvania 19546',6027,7230);
INSERT INTO "django_geo_db_zipcode" VALUES(7959,19547,-5,'Oley, Pennsylvania 19547',6028,7231);
INSERT INTO "django_geo_db_zipcode" VALUES(7960,19548,-5,'Pine Forge, Pennsylvania 19548',6029,7207);
INSERT INTO "django_geo_db_zipcode" VALUES(7961,19549,-5,'Port Clinton, Pennsylvania 19549',6030,7232);
INSERT INTO "django_geo_db_zipcode" VALUES(7962,19550,-5,'Rehrersburg, Pennsylvania 19550',6031,7233);
INSERT INTO "django_geo_db_zipcode" VALUES(7963,19551,-5,'Robesonia, Pennsylvania 19551',6032,7234);
INSERT INTO "django_geo_db_zipcode" VALUES(7964,19554,-5,'Shartlesville, Pennsylvania 19554',6033,7235);
INSERT INTO "django_geo_db_zipcode" VALUES(7965,19555,-5,'Shoemakersville, Pennsylvania 19555',6034,7236);
INSERT INTO "django_geo_db_zipcode" VALUES(7966,19557,-5,'Stony Run, Pennsylvania 19557',6035,7237);
INSERT INTO "django_geo_db_zipcode" VALUES(7967,19559,-5,'Strausstown, Pennsylvania 19559',6036,7238);
INSERT INTO "django_geo_db_zipcode" VALUES(7968,19560,-5,'Temple, Pennsylvania 19560',6037,7239);
INSERT INTO "django_geo_db_zipcode" VALUES(7969,19562,-5,'Topton, Pennsylvania 19562',6038,7240);
INSERT INTO "django_geo_db_zipcode" VALUES(7970,19564,-5,'Virginville, Pennsylvania 19564',6039,7241);
INSERT INTO "django_geo_db_zipcode" VALUES(7971,19565,-5,'Wernersville, Pennsylvania 19565',6040,7242);
INSERT INTO "django_geo_db_zipcode" VALUES(7972,19567,-5,'Womelsdorf, Pennsylvania 19567',6041,7243);
INSERT INTO "django_geo_db_zipcode" VALUES(7973,19601,-5,'Reading, Pennsylvania 19601',6042,7244);
INSERT INTO "django_geo_db_zipcode" VALUES(7974,19602,-5,'Reading, Pennsylvania 19602',6042,7245);
INSERT INTO "django_geo_db_zipcode" VALUES(7975,19603,-5,'Reading, Pennsylvania 19603',6042,7246);
INSERT INTO "django_geo_db_zipcode" VALUES(7976,19604,-5,'Reading, Pennsylvania 19604',6042,7247);
INSERT INTO "django_geo_db_zipcode" VALUES(7977,19605,-5,'Reading, Pennsylvania 19605',6042,7248);
INSERT INTO "django_geo_db_zipcode" VALUES(7978,19606,-5,'Reading, Pennsylvania 19606',6042,7249);
INSERT INTO "django_geo_db_zipcode" VALUES(7979,19607,-5,'Reading, Pennsylvania 19607',6042,7250);
INSERT INTO "django_geo_db_zipcode" VALUES(7980,19608,-5,'Reading, Pennsylvania 19608',6042,7251);
INSERT INTO "django_geo_db_zipcode" VALUES(7981,19609,-5,'Reading, Pennsylvania 19609',6042,7252);
INSERT INTO "django_geo_db_zipcode" VALUES(7982,19610,-5,'Reading, Pennsylvania 19610',6042,7253);
INSERT INTO "django_geo_db_zipcode" VALUES(7983,19611,-5,'Reading, Pennsylvania 19611',6042,7254);
INSERT INTO "django_geo_db_zipcode" VALUES(7984,19612,-5,'Reading, Pennsylvania 19612',6042,7255);
INSERT INTO "django_geo_db_zipcode" VALUES(7985,19640,-5,'Reading, Pennsylvania 19640',6042,7207);
INSERT INTO "django_geo_db_zipcode" VALUES(7986,19650,-5,'Alsace, Pennsylvania 19650',6043,7256);
INSERT INTO "django_geo_db_zipcode" VALUES(7987,19685,-5,'Muhlenberg, Pennsylvania 19685',6044,7257);
INSERT INTO "django_geo_db_zipcode" VALUES(7988,19700,-5,'Delaware City, Delaware 19700',6045,7258);
INSERT INTO "django_geo_db_zipcode" VALUES(7989,19701,-5,'Bear, Delaware 19701',6046,7259);
INSERT INTO "django_geo_db_zipcode" VALUES(7990,19702,-5,'Newark, Delaware 19702',6047,7260);
INSERT INTO "django_geo_db_zipcode" VALUES(7991,19703,-5,'Claymont, Delaware 19703',6048,7261);
INSERT INTO "django_geo_db_zipcode" VALUES(7992,19706,-5,'Delaware City, Delaware 19706',6045,7262);
INSERT INTO "django_geo_db_zipcode" VALUES(7993,19707,-5,'Hockessin, Delaware 19707',6049,7263);
INSERT INTO "django_geo_db_zipcode" VALUES(7994,19708,-5,'Kirkwood, Delaware 19708',6050,7264);
INSERT INTO "django_geo_db_zipcode" VALUES(7995,19709,-5,'Middletown, Delaware 19709',6051,7265);
INSERT INTO "django_geo_db_zipcode" VALUES(7996,19710,-5,'Montchanin, Delaware 19710',6052,7266);
INSERT INTO "django_geo_db_zipcode" VALUES(7997,19711,-5,'Newark, Delaware 19711',6047,7267);
INSERT INTO "django_geo_db_zipcode" VALUES(7998,19712,-5,'Newark, Delaware 19712',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(7999,19713,-5,'Newark, Delaware 19713',6047,7269);
INSERT INTO "django_geo_db_zipcode" VALUES(8000,19714,-5,'Newark, Delaware 19714',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8001,19715,-5,'Newark, Delaware 19715',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8002,19716,-5,'Newark, Delaware 19716',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8003,19717,-5,'Newark, Delaware 19717',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8004,19718,-5,'Newark, Delaware 19718',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8005,19720,-5,'New Castle, Delaware 19720',6053,7270);
INSERT INTO "django_geo_db_zipcode" VALUES(8006,19721,-5,'New Castle, Delaware 19721',6053,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8007,19725,-5,'Newark, Delaware 19725',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8008,19726,-5,'Newark, Delaware 19726',6047,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8009,19730,-5,'Odessa, Delaware 19730',6054,7271);
INSERT INTO "django_geo_db_zipcode" VALUES(8010,19731,-5,'Port Penn, Delaware 19731',6055,7272);
INSERT INTO "django_geo_db_zipcode" VALUES(8011,19732,-5,'Rockland, Delaware 19732',6056,7273);
INSERT INTO "django_geo_db_zipcode" VALUES(8012,19733,-5,'Saint Georges, Delaware 19733',6057,7274);
INSERT INTO "django_geo_db_zipcode" VALUES(8013,19734,-5,'Townsend, Delaware 19734',6058,7275);
INSERT INTO "django_geo_db_zipcode" VALUES(8014,19735,-5,'Winterthur, Delaware 19735',6059,7276);
INSERT INTO "django_geo_db_zipcode" VALUES(8015,19736,-5,'Yorklyn, Delaware 19736',6060,7277);
INSERT INTO "django_geo_db_zipcode" VALUES(8016,19743,-5,'Spring Mount, Pennsylvania 19743',5988,7278);
INSERT INTO "django_geo_db_zipcode" VALUES(8017,19766,-5,'Delaware City, Delaware 19766',6045,7279);
INSERT INTO "django_geo_db_zipcode" VALUES(8018,19801,-5,'Wilmington, Delaware 19801',6061,7280);
INSERT INTO "django_geo_db_zipcode" VALUES(8019,19802,-5,'Wilmington, Delaware 19802',6061,7281);
INSERT INTO "django_geo_db_zipcode" VALUES(8020,19803,-5,'Wilmington, Delaware 19803',6061,7282);
INSERT INTO "django_geo_db_zipcode" VALUES(8021,19804,-5,'Wilmington, Delaware 19804',6061,7283);
INSERT INTO "django_geo_db_zipcode" VALUES(8022,19805,-5,'Wilmington, Delaware 19805',6061,7284);
INSERT INTO "django_geo_db_zipcode" VALUES(8023,19806,-5,'Wilmington, Delaware 19806',6061,7285);
INSERT INTO "django_geo_db_zipcode" VALUES(8024,19807,-5,'Wilmington, Delaware 19807',6061,7286);
INSERT INTO "django_geo_db_zipcode" VALUES(8025,19808,-5,'Wilmington, Delaware 19808',6061,7287);
INSERT INTO "django_geo_db_zipcode" VALUES(8026,19809,-5,'Wilmington, Delaware 19809',6061,7288);
INSERT INTO "django_geo_db_zipcode" VALUES(8027,19810,-5,'Wilmington, Delaware 19810',6061,7289);
INSERT INTO "django_geo_db_zipcode" VALUES(8028,19814,-5,'Newport, Delaware 19814',6062,7290);
INSERT INTO "django_geo_db_zipcode" VALUES(8029,19815,-5,'Amity, Pennsylvania 19815',4303,7291);
INSERT INTO "django_geo_db_zipcode" VALUES(8030,19850,-5,'Wilmington, Delaware 19850',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8031,19853,-5,'Schuylkill, Pennsylvania 19853',6063,7292);
INSERT INTO "django_geo_db_zipcode" VALUES(8032,19880,-5,'Wilmington, Delaware 19880',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8033,19884,-5,'Wilmington, Delaware 19884',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8034,19885,-5,'Wilmington, Delaware 19885',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8035,19886,-5,'Wilmington, Delaware 19886',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8036,19887,-5,'Wilmington, Delaware 19887',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8037,19889,-5,'Wilmington, Delaware 19889',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8038,19890,-5,'Wilmington, Delaware 19890',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8039,19891,-5,'Wilmington, Delaware 19891',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8040,19892,-5,'Wilmington, Delaware 19892',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8041,19893,-5,'Wilmington, Delaware 19893',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8042,19894,-5,'Wilmington, Delaware 19894',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8043,19895,-5,'Wilmington, Delaware 19895',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8044,19896,-5,'Wilmington, Delaware 19896',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8045,19897,-5,'Wilmington, Delaware 19897',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8046,19898,-5,'Wilmington, Delaware 19898',6061,7268);
INSERT INTO "django_geo_db_zipcode" VALUES(8047,19899,-5,'Wilmington, Delaware 19899',6061,7293);
INSERT INTO "django_geo_db_zipcode" VALUES(8048,19901,-5,'Dover, Delaware 19901',6064,7294);
INSERT INTO "django_geo_db_zipcode" VALUES(8049,19902,-5,'Dover AFB, Delaware 19902',6065,7295);
INSERT INTO "django_geo_db_zipcode" VALUES(8050,19903,-5,'Dover, Delaware 19903',6064,7296);
INSERT INTO "django_geo_db_zipcode" VALUES(8051,19904,-5,'Dover, Delaware 19904',6064,7297);
INSERT INTO "django_geo_db_zipcode" VALUES(8052,19905,-5,'Dover, Delaware 19905',6064,7296);
INSERT INTO "django_geo_db_zipcode" VALUES(8053,19925,-5,'Upper Uwchlan, Pennsylvania 19925',6066,7298);
INSERT INTO "django_geo_db_zipcode" VALUES(8054,19930,-5,'Bethany Beach, Delaware 19930',6067,7299);
INSERT INTO "django_geo_db_zipcode" VALUES(8055,19931,-5,'Bethel, Delaware 19931',6068,7300);
INSERT INTO "django_geo_db_zipcode" VALUES(8056,19933,-5,'Bridgeville, Delaware 19933',6069,7301);
INSERT INTO "django_geo_db_zipcode" VALUES(8057,19934,-5,'Camden Wyoming, Delaware 19934',6070,7302);
INSERT INTO "django_geo_db_zipcode" VALUES(8058,19936,-5,'Cheswold, Delaware 19936',6071,7303);
INSERT INTO "django_geo_db_zipcode" VALUES(8059,19938,-5,'Clayton, Delaware 19938',6072,7304);
INSERT INTO "django_geo_db_zipcode" VALUES(8060,19939,-5,'Dagsboro, Delaware 19939',6073,7305);
INSERT INTO "django_geo_db_zipcode" VALUES(8061,19940,-5,'Delmar, Delaware 19940',6074,7306);
INSERT INTO "django_geo_db_zipcode" VALUES(8062,19941,-5,'Ellendale, Delaware 19941',6075,7307);
INSERT INTO "django_geo_db_zipcode" VALUES(8063,19942,-5,'Farmington, Delaware 19942',6076,7308);
INSERT INTO "django_geo_db_zipcode" VALUES(8064,19943,-5,'Felton, Delaware 19943',6077,7309);
INSERT INTO "django_geo_db_zipcode" VALUES(8065,19944,-5,'Fenwick Island, Delaware 19944',6078,7310);
INSERT INTO "django_geo_db_zipcode" VALUES(8066,19945,-5,'Frankford, Delaware 19945',6079,7311);
INSERT INTO "django_geo_db_zipcode" VALUES(8067,19946,-5,'Frederica, Delaware 19946',6080,7312);
INSERT INTO "django_geo_db_zipcode" VALUES(8068,19947,-5,'Georgetown, Delaware 19947',6081,7313);
INSERT INTO "django_geo_db_zipcode" VALUES(8069,19950,-5,'Greenwood, Delaware 19950',6082,7314);
INSERT INTO "django_geo_db_zipcode" VALUES(8070,19951,-5,'Harbeson, Delaware 19951',6083,7315);
INSERT INTO "django_geo_db_zipcode" VALUES(8071,19952,-5,'Harrington, Delaware 19952',6084,7316);
INSERT INTO "django_geo_db_zipcode" VALUES(8072,19953,-5,'Hartly, Delaware 19953',6085,7317);
INSERT INTO "django_geo_db_zipcode" VALUES(8073,19954,-5,'Houston, Delaware 19954',6086,7318);
INSERT INTO "django_geo_db_zipcode" VALUES(8074,19955,-5,'Kenton, Delaware 19955',6087,7319);
INSERT INTO "django_geo_db_zipcode" VALUES(8075,19956,-5,'Laurel, Delaware 19956',6088,7320);
INSERT INTO "django_geo_db_zipcode" VALUES(8076,19958,-5,'Lewes, Delaware 19958',6089,7321);
INSERT INTO "django_geo_db_zipcode" VALUES(8077,19960,-5,'Lincoln, Delaware 19960',6090,7322);
INSERT INTO "django_geo_db_zipcode" VALUES(8078,19961,-5,'Little Creek, Delaware 19961',6091,7323);
INSERT INTO "django_geo_db_zipcode" VALUES(8079,19962,-5,'Magnolia, Delaware 19962',6092,7324);
INSERT INTO "django_geo_db_zipcode" VALUES(8080,19963,-5,'Milford, Delaware 19963',6093,7325);
INSERT INTO "django_geo_db_zipcode" VALUES(8081,19964,-5,'Marydel, Delaware 19964',6094,7326);
INSERT INTO "django_geo_db_zipcode" VALUES(8082,19966,-5,'Millsboro, Delaware 19966',6095,7327);
INSERT INTO "django_geo_db_zipcode" VALUES(8083,19967,-5,'Millville, Delaware 19967',6096,7328);
INSERT INTO "django_geo_db_zipcode" VALUES(8084,19968,-5,'Milton, Delaware 19968',6097,7329);
INSERT INTO "django_geo_db_zipcode" VALUES(8085,19969,-5,'Nassau, Delaware 19969',6098,7330);
INSERT INTO "django_geo_db_zipcode" VALUES(8086,19970,-5,'Ocean View, Delaware 19970',6099,7331);
INSERT INTO "django_geo_db_zipcode" VALUES(8087,19971,-5,'Rehoboth Beach, Delaware 19971',6100,7332);
INSERT INTO "django_geo_db_zipcode" VALUES(8088,19973,-5,'Seaford, Delaware 19973',6101,7333);
INSERT INTO "django_geo_db_zipcode" VALUES(8089,19975,-5,'Selbyville, Delaware 19975',6102,7334);
INSERT INTO "django_geo_db_zipcode" VALUES(8090,19977,-5,'Smyrna, Delaware 19977',6103,7335);
INSERT INTO "django_geo_db_zipcode" VALUES(8091,19979,-5,'Viola, Delaware 19979',6104,7336);
INSERT INTO "django_geo_db_zipcode" VALUES(8092,19980,-5,'Woodside, Delaware 19980',6105,7337);
INSERT INTO "django_geo_db_zipcode" VALUES(8093,19999,-5,'Bethany Beach, Delaware 19999',6067,7338);
INSERT INTO "django_geo_db_zipcode" VALUES(8094,20001,-5,'Washington, District of Columbia 20001',6106,7339);
INSERT INTO "django_geo_db_zipcode" VALUES(8095,20002,-5,'Washington, District of Columbia 20002',6106,7340);
INSERT INTO "django_geo_db_zipcode" VALUES(8096,20003,-5,'Washington, District of Columbia 20003',6106,7341);
INSERT INTO "django_geo_db_zipcode" VALUES(8097,20004,-5,'Washington, District of Columbia 20004',6106,7342);
INSERT INTO "django_geo_db_zipcode" VALUES(8098,20005,-5,'Washington, District of Columbia 20005',6106,7343);
INSERT INTO "django_geo_db_zipcode" VALUES(8099,20006,-5,'Washington, District of Columbia 20006',6106,7344);
INSERT INTO "django_geo_db_zipcode" VALUES(8100,20007,-5,'Washington, District of Columbia 20007',6106,7345);
INSERT INTO "django_geo_db_zipcode" VALUES(8101,20008,-5,'Washington, District of Columbia 20008',6106,7346);
INSERT INTO "django_geo_db_zipcode" VALUES(8102,20009,-5,'Washington, District of Columbia 20009',6106,7347);
INSERT INTO "django_geo_db_zipcode" VALUES(8103,20010,-5,'Washington, District of Columbia 20010',6106,7348);
INSERT INTO "django_geo_db_zipcode" VALUES(8104,20011,-5,'Washington, District of Columbia 20011',6106,7349);
INSERT INTO "django_geo_db_zipcode" VALUES(8105,20012,-5,'Washington, District of Columbia 20012',6106,7350);
INSERT INTO "django_geo_db_zipcode" VALUES(8106,20013,-5,'Washington, District of Columbia 20013',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8107,20015,-5,'Washington, District of Columbia 20015',6106,7352);
INSERT INTO "django_geo_db_zipcode" VALUES(8108,20016,-5,'Washington, District of Columbia 20016',6106,7353);
INSERT INTO "django_geo_db_zipcode" VALUES(8109,20017,-5,'Washington, District of Columbia 20017',6106,7354);
INSERT INTO "django_geo_db_zipcode" VALUES(8110,20018,-5,'Washington, District of Columbia 20018',6106,7355);
INSERT INTO "django_geo_db_zipcode" VALUES(8111,20019,-5,'Washington, District of Columbia 20019',6106,7356);
INSERT INTO "django_geo_db_zipcode" VALUES(8112,20020,-5,'Washington, District of Columbia 20020',6106,7357);
INSERT INTO "django_geo_db_zipcode" VALUES(8113,20024,-5,'Washington, District of Columbia 20024',6106,7358);
INSERT INTO "django_geo_db_zipcode" VALUES(8114,20026,-5,'Washington, District of Columbia 20026',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8115,20029,-5,'Washington, District of Columbia 20029',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8116,20030,-5,'Washington, District of Columbia 20030',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8117,20032,-5,'Washington, District of Columbia 20032',6106,7359);
INSERT INTO "django_geo_db_zipcode" VALUES(8118,20033,-5,'Washington, District of Columbia 20033',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8119,20035,-5,'Washington, District of Columbia 20035',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8120,20036,-5,'Washington, District of Columbia 20036',6106,7360);
INSERT INTO "django_geo_db_zipcode" VALUES(8121,20037,-5,'Washington, District of Columbia 20037',6106,7361);
INSERT INTO "django_geo_db_zipcode" VALUES(8122,20038,-5,'Washington, District of Columbia 20038',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8123,20039,-5,'Washington, District of Columbia 20039',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8124,20040,-5,'Washington, District of Columbia 20040',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8125,20041,-5,'Washington, District of Columbia 20041',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8126,20042,-5,'Washington, District of Columbia 20042',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8127,20043,-5,'Washington, District of Columbia 20043',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8128,20044,-5,'Washington, District of Columbia 20044',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8129,20045,-5,'Washington, District of Columbia 20045',6106,7362);
INSERT INTO "django_geo_db_zipcode" VALUES(8130,20046,-5,'Washington, District of Columbia 20046',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8131,20047,-5,'Washington, District of Columbia 20047',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8132,20049,-5,'Washington, District of Columbia 20049',6106,7363);
INSERT INTO "django_geo_db_zipcode" VALUES(8133,20050,-5,'Washington, District of Columbia 20050',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8134,20051,-5,'Washington, District of Columbia 20051',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8135,20052,-5,'Washington, District of Columbia 20052',6106,7364);
INSERT INTO "django_geo_db_zipcode" VALUES(8136,20053,-5,'Washington, District of Columbia 20053',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8137,20055,-5,'Washington, District of Columbia 20055',6106,7365);
INSERT INTO "django_geo_db_zipcode" VALUES(8138,20056,-5,'Washington, District of Columbia 20056',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8139,20057,-5,'Washington, District of Columbia 20057',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8140,20058,-5,'Washington, District of Columbia 20058',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8141,20059,-5,'Washington, District of Columbia 20059',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8142,20060,-5,'Washington, District of Columbia 20060',6106,7366);
INSERT INTO "django_geo_db_zipcode" VALUES(8143,20061,-5,'Washington, District of Columbia 20061',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8144,20062,-5,'Washington, District of Columbia 20062',6106,7367);
INSERT INTO "django_geo_db_zipcode" VALUES(8145,20063,-5,'Washington, District of Columbia 20063',6106,7368);
INSERT INTO "django_geo_db_zipcode" VALUES(8146,20064,-5,'Washington, District of Columbia 20064',6106,7369);
INSERT INTO "django_geo_db_zipcode" VALUES(8147,20065,-5,'Washington, District of Columbia 20065',6106,7370);
INSERT INTO "django_geo_db_zipcode" VALUES(8148,20066,-5,'Washington, District of Columbia 20066',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8149,20067,-5,'Washington, District of Columbia 20067',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8150,20068,-5,'Washington, District of Columbia 20068',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8151,20069,-5,'Washington, District of Columbia 20069',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8152,20070,-5,'Washington, District of Columbia 20070',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8153,20071,-5,'Washington, District of Columbia 20071',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8154,20073,-5,'Washington, District of Columbia 20073',6106,7371);
INSERT INTO "django_geo_db_zipcode" VALUES(8155,20074,-5,'Washington, District of Columbia 20074',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8156,20075,-5,'Washington, District of Columbia 20075',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8157,20076,-5,'Washington, District of Columbia 20076',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8158,20077,-5,'Washington, District of Columbia 20077',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8159,20078,-5,'Washington, District of Columbia 20078',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8160,20080,-5,'Washington, District of Columbia 20080',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8161,20081,-5,'Washington, District of Columbia 20081',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8162,20082,-5,'Washington, District of Columbia 20082',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8163,20088,-5,'Washington, District of Columbia 20088',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8164,20090,-5,'Washington, District of Columbia 20090',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8165,20091,-5,'Washington, District of Columbia 20091',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8166,20097,-5,'Washington, District of Columbia 20097',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8167,20098,-5,'Washington, District of Columbia 20098',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8168,20099,-5,'Washington, District of Columbia 20099',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8169,20101,-5,'Dulles, Virginia 20101',6107,7372);
INSERT INTO "django_geo_db_zipcode" VALUES(8170,20102,-5,'Dulles, Virginia 20102',6107,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8171,20103,-5,'Dulles, Virginia 20103',6107,7374);
INSERT INTO "django_geo_db_zipcode" VALUES(8172,20104,-5,'Dulles, Virginia 20104',6107,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8173,20105,-5,'Aldie, Virginia 20105',6108,7375);
INSERT INTO "django_geo_db_zipcode" VALUES(8174,20106,-5,'Amissville, Virginia 20106',6109,7376);
INSERT INTO "django_geo_db_zipcode" VALUES(8175,20107,-5,'Arcola, Virginia 20107',6110,7377);
INSERT INTO "django_geo_db_zipcode" VALUES(8176,20108,-5,'Manassas, Virginia 20108',6111,7378);
INSERT INTO "django_geo_db_zipcode" VALUES(8177,20109,-5,'Manassas, Virginia 20109',6111,7379);
INSERT INTO "django_geo_db_zipcode" VALUES(8178,20110,-5,'Manassas, Virginia 20110',6111,7380);
INSERT INTO "django_geo_db_zipcode" VALUES(8179,20111,-5,'Manassas, Virginia 20111',6111,7381);
INSERT INTO "django_geo_db_zipcode" VALUES(8180,20112,-5,'Manassas, Virginia 20112',6111,7382);
INSERT INTO "django_geo_db_zipcode" VALUES(8181,20113,-5,'Manassas, Virginia 20113',6111,7383);
INSERT INTO "django_geo_db_zipcode" VALUES(8182,20115,-5,'Marshall, Virginia 20115',6112,7384);
INSERT INTO "django_geo_db_zipcode" VALUES(8183,20116,-5,'Marshall, Virginia 20116',6112,7385);
INSERT INTO "django_geo_db_zipcode" VALUES(8184,20117,-5,'Middleburg, Virginia 20117',6113,7386);
INSERT INTO "django_geo_db_zipcode" VALUES(8185,20118,-5,'Middleburg, Virginia 20118',6113,7387);
INSERT INTO "django_geo_db_zipcode" VALUES(8186,20119,-5,'Catlett, Virginia 20119',6114,7388);
INSERT INTO "django_geo_db_zipcode" VALUES(8187,20120,-5,'Centreville, Virginia 20120',6115,7389);
INSERT INTO "django_geo_db_zipcode" VALUES(8188,20121,-5,'Centreville, Virginia 20121',6115,7390);
INSERT INTO "django_geo_db_zipcode" VALUES(8189,20122,-5,'Centreville, Virginia 20122',6115,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8190,20124,-5,'Clifton, Virginia 20124',6116,7392);
INSERT INTO "django_geo_db_zipcode" VALUES(8191,20128,-5,'Orlean, Virginia 20128',6117,7393);
INSERT INTO "django_geo_db_zipcode" VALUES(8192,20129,-5,'Paeonian Springs, Virginia 20129',6118,7394);
INSERT INTO "django_geo_db_zipcode" VALUES(8193,20130,-5,'Paris, Virginia 20130',6119,7395);
INSERT INTO "django_geo_db_zipcode" VALUES(8194,20131,-5,'Philomont, Virginia 20131',6120,7396);
INSERT INTO "django_geo_db_zipcode" VALUES(8195,20132,-5,'Purcellville, Virginia 20132',6121,7397);
INSERT INTO "django_geo_db_zipcode" VALUES(8196,20134,-5,'Purcellville, Virginia 20134',6121,7398);
INSERT INTO "django_geo_db_zipcode" VALUES(8197,20135,-5,'Bluemont, Virginia 20135',6122,7399);
INSERT INTO "django_geo_db_zipcode" VALUES(8198,20136,-5,'Bristow, Virginia 20136',6123,7400);
INSERT INTO "django_geo_db_zipcode" VALUES(8199,20137,-5,'Broad Run, Virginia 20137',6124,7401);
INSERT INTO "django_geo_db_zipcode" VALUES(8200,20138,-5,'Calverton, Virginia 20138',6125,7402);
INSERT INTO "django_geo_db_zipcode" VALUES(8201,20139,-5,'Casanova, Virginia 20139',6126,7403);
INSERT INTO "django_geo_db_zipcode" VALUES(8202,20140,-5,'Rectortown, Virginia 20140',6127,7404);
INSERT INTO "django_geo_db_zipcode" VALUES(8203,20141,-5,'Round Hill, Virginia 20141',6128,7405);
INSERT INTO "django_geo_db_zipcode" VALUES(8204,20142,-5,'Round Hill, Virginia 20142',6128,7406);
INSERT INTO "django_geo_db_zipcode" VALUES(8205,20143,-5,'Catharpin, Virginia 20143',6129,7407);
INSERT INTO "django_geo_db_zipcode" VALUES(8206,20144,-5,'Delaplane, Virginia 20144',6130,7408);
INSERT INTO "django_geo_db_zipcode" VALUES(8207,20146,-5,'Ashburn, Virginia 20146',6131,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8208,20147,-5,'Ashburn, Virginia 20147',6131,7409);
INSERT INTO "django_geo_db_zipcode" VALUES(8209,20148,-5,'Ashburn, Virginia 20148',6131,7410);
INSERT INTO "django_geo_db_zipcode" VALUES(8210,20149,-5,'Ashburn, Virginia 20149',6131,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8211,20151,-5,'Chantilly, Virginia 20151',6132,7411);
INSERT INTO "django_geo_db_zipcode" VALUES(8212,20152,-5,'Chantilly, Virginia 20152',6132,7412);
INSERT INTO "django_geo_db_zipcode" VALUES(8213,20153,-5,'Chantilly, Virginia 20153',6132,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8214,20155,-5,'Gainesville, Virginia 20155',6133,7413);
INSERT INTO "django_geo_db_zipcode" VALUES(8215,20156,-5,'Gainesville, Virginia 20156',6133,7414);
INSERT INTO "django_geo_db_zipcode" VALUES(8216,20158,-5,'Hamilton, Virginia 20158',6134,7415);
INSERT INTO "django_geo_db_zipcode" VALUES(8217,20159,-5,'Hamilton, Virginia 20159',6134,7416);
INSERT INTO "django_geo_db_zipcode" VALUES(8218,20160,-5,'Lincoln, Virginia 20160',6135,7417);
INSERT INTO "django_geo_db_zipcode" VALUES(8219,20163,-5,'Sterling, Virginia 20163',6136,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8220,20164,-5,'Sterling, Virginia 20164',6136,7418);
INSERT INTO "django_geo_db_zipcode" VALUES(8221,20165,-5,'Sterling, Virginia 20165',6136,7419);
INSERT INTO "django_geo_db_zipcode" VALUES(8222,20166,-5,'Sterling, Virginia 20166',6136,7420);
INSERT INTO "django_geo_db_zipcode" VALUES(8223,20167,-5,'Sterling, Virginia 20167',6136,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8224,20168,-5,'Haymarket, Virginia 20168',6137,7414);
INSERT INTO "django_geo_db_zipcode" VALUES(8225,20169,-5,'Haymarket, Virginia 20169',6137,7421);
INSERT INTO "django_geo_db_zipcode" VALUES(8226,20170,-5,'Herndon, Virginia 20170',6138,7422);
INSERT INTO "django_geo_db_zipcode" VALUES(8227,20171,-5,'Herndon, Virginia 20171',6138,7423);
INSERT INTO "django_geo_db_zipcode" VALUES(8228,20172,-5,'Herndon, Virginia 20172',6138,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8229,20175,-5,'Leesburg, Virginia 20175',6139,7424);
INSERT INTO "django_geo_db_zipcode" VALUES(8230,20176,-5,'Leesburg, Virginia 20176',6139,7425);
INSERT INTO "django_geo_db_zipcode" VALUES(8231,20177,-5,'Leesburg, Virginia 20177',6139,7426);
INSERT INTO "django_geo_db_zipcode" VALUES(8232,20178,-5,'Leesburg, Virginia 20178',6139,7427);
INSERT INTO "django_geo_db_zipcode" VALUES(8233,20180,-5,'Lovettsville, Virginia 20180',6140,7428);
INSERT INTO "django_geo_db_zipcode" VALUES(8234,20181,-5,'Nokesville, Virginia 20181',6141,7429);
INSERT INTO "django_geo_db_zipcode" VALUES(8235,20182,-5,'Nokesville, Virginia 20182',6141,7430);
INSERT INTO "django_geo_db_zipcode" VALUES(8236,20184,-5,'Upperville, Virginia 20184',6142,7431);
INSERT INTO "django_geo_db_zipcode" VALUES(8237,20185,-5,'Upperville, Virginia 20185',6142,7432);
INSERT INTO "django_geo_db_zipcode" VALUES(8238,20186,-5,'Warrenton, Virginia 20186',6143,7433);
INSERT INTO "django_geo_db_zipcode" VALUES(8239,20187,-5,'Warrenton, Virginia 20187',6143,7434);
INSERT INTO "django_geo_db_zipcode" VALUES(8240,20188,-5,'Warrenton, Virginia 20188',6143,7435);
INSERT INTO "django_geo_db_zipcode" VALUES(8241,20190,-5,'Reston, Virginia 20190',6144,7436);
INSERT INTO "django_geo_db_zipcode" VALUES(8242,20191,-5,'Reston, Virginia 20191',6144,7437);
INSERT INTO "django_geo_db_zipcode" VALUES(8243,20192,-5,'Herndon, Virginia 20192',6138,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8244,20193,-5,'Reston, Virginia 20193',6144,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8245,20194,-5,'Reston, Virginia 20194',6144,7438);
INSERT INTO "django_geo_db_zipcode" VALUES(8246,20195,-5,'Reston, Virginia 20195',6144,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8247,20196,-5,'Reston, Virginia 20196',6144,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(8248,20197,-5,'Waterford, Virginia 20197',6145,7439);
INSERT INTO "django_geo_db_zipcode" VALUES(8249,20198,-5,'The Plains, Virginia 20198',6146,7440);
INSERT INTO "django_geo_db_zipcode" VALUES(8250,20199,-5,'Dulles, Virginia 20199',6107,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(8251,20201,-5,'Washington, District of Columbia 20201',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8252,20202,-5,'Washington, District of Columbia 20202',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8253,20203,-5,'Washington, District of Columbia 20203',6106,7368);
INSERT INTO "django_geo_db_zipcode" VALUES(8254,20204,-5,'Washington, District of Columbia 20204',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8255,20206,-5,'Washington, District of Columbia 20206',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8256,20207,-5,'Washington, District of Columbia 20207',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8257,20208,-5,'Washington, District of Columbia 20208',6106,7441);
INSERT INTO "django_geo_db_zipcode" VALUES(8258,20210,-5,'Washington, District of Columbia 20210',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8259,20211,-5,'Washington, District of Columbia 20211',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8260,20212,-5,'Washington, District of Columbia 20212',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8261,20213,-5,'Washington, District of Columbia 20213',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8262,20214,-5,'Washington, District of Columbia 20214',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8263,20215,-5,'Washington, District of Columbia 20215',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8264,20216,-5,'Washington, District of Columbia 20216',6106,7442);
INSERT INTO "django_geo_db_zipcode" VALUES(8265,20217,-5,'Washington, District of Columbia 20217',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8266,20218,-5,'Washington, District of Columbia 20218',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8267,20219,-5,'Washington, District of Columbia 20219',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8268,20220,-5,'Washington, District of Columbia 20220',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8269,20221,-5,'Washington, District of Columbia 20221',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8270,20222,-5,'Washington, District of Columbia 20222',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8271,20223,-5,'Washington, District of Columbia 20223',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8272,20224,-5,'Washington, District of Columbia 20224',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8273,20226,-5,'Washington, District of Columbia 20226',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8274,20227,-5,'Washington, District of Columbia 20227',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8275,20228,-5,'Washington, District of Columbia 20228',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8276,20229,-5,'Washington, District of Columbia 20229',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8277,20230,-5,'Washington, District of Columbia 20230',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8278,20231,-5,'Washington, District of Columbia 20231',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8279,20232,-5,'Washington, District of Columbia 20232',6106,7443);
INSERT INTO "django_geo_db_zipcode" VALUES(8280,20233,-5,'Washington, District of Columbia 20233',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8281,20235,-5,'Washington, District of Columbia 20235',6106,7444);
INSERT INTO "django_geo_db_zipcode" VALUES(8282,20238,-5,'Washington, District of Columbia 20238',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8283,20239,-5,'Washington, District of Columbia 20239',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8284,20240,-5,'Washington, District of Columbia 20240',6106,7445);
INSERT INTO "django_geo_db_zipcode" VALUES(8285,20241,-5,'Washington, District of Columbia 20241',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8286,20242,-5,'Washington, District of Columbia 20242',6106,7446);
INSERT INTO "django_geo_db_zipcode" VALUES(8287,20244,-5,'Washington, District of Columbia 20244',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8288,20245,-5,'Washington, District of Columbia 20245',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8289,20250,-5,'Washington, District of Columbia 20250',6106,7447);
INSERT INTO "django_geo_db_zipcode" VALUES(8290,20251,-5,'Washington, District of Columbia 20251',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8291,20254,-5,'Washington, District of Columbia 20254',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8292,20260,-5,'Washington, District of Columbia 20260',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8293,20261,-5,'Washington, District of Columbia 20261',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8294,20262,-5,'Washington, District of Columbia 20262',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8295,20265,-5,'Washington, District of Columbia 20265',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8296,20266,-5,'Washington, District of Columbia 20266',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8297,20268,-5,'Washington, District of Columbia 20268',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8298,20270,-5,'Washington, District of Columbia 20270',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8299,20277,-5,'Washington, District of Columbia 20277',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8300,20289,-5,'Washington, District of Columbia 20289',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8301,20299,-5,'Washington, District of Columbia 20299',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8302,20301,-5,'Washington, District of Columbia 20301',6106,7448);
INSERT INTO "django_geo_db_zipcode" VALUES(8303,20303,-5,'Washington, District of Columbia 20303',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8304,20306,-5,'Washington, District of Columbia 20306',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8305,20307,-5,'Washington, District of Columbia 20307',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8306,20310,-5,'Washington, District of Columbia 20310',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8307,20314,-5,'Washington, District of Columbia 20314',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8308,20315,-5,'Washington, District of Columbia 20315',6106,7449);
INSERT INTO "django_geo_db_zipcode" VALUES(8309,20317,-5,'Washington, District of Columbia 20317',6106,7450);
INSERT INTO "django_geo_db_zipcode" VALUES(8310,20318,-5,'Washington, District of Columbia 20318',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8311,20319,-5,'Washington, District of Columbia 20319',6106,7451);
INSERT INTO "django_geo_db_zipcode" VALUES(8312,20330,-5,'Washington, District of Columbia 20330',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8313,20332,-5,'Washington, District of Columbia 20332',6106,7452);
INSERT INTO "django_geo_db_zipcode" VALUES(8314,20336,-5,'Washington, District of Columbia 20336',6106,7453);
INSERT INTO "django_geo_db_zipcode" VALUES(8315,20337,-5,'Washington, District of Columbia 20337',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8316,20338,-5,'Washington, District of Columbia 20338',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8317,20340,-5,'Washington, District of Columbia 20340',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8318,20350,-5,'Washington, District of Columbia 20350',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8319,20370,-5,'Washington, District of Columbia 20370',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8320,20372,-5,'Washington, District of Columbia 20372',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8321,20373,-5,'Washington, District of Columbia 20373',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8322,20374,-5,'Washington, District of Columbia 20374',6106,7454);
INSERT INTO "django_geo_db_zipcode" VALUES(8323,20375,-5,'Washington, District of Columbia 20375',6106,7455);
INSERT INTO "django_geo_db_zipcode" VALUES(8324,20380,-5,'Washington, District of Columbia 20380',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8325,20388,-5,'Washington, District of Columbia 20388',6106,7456);
INSERT INTO "django_geo_db_zipcode" VALUES(8326,20389,-5,'Washington, District of Columbia 20389',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8327,20390,-5,'Washington, District of Columbia 20390',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8328,20391,-5,'Washington, District of Columbia 20391',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8329,20392,-5,'Washington, District of Columbia 20392',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8330,20393,-5,'Washington, District of Columbia 20393',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8331,20394,-5,'Washington, District of Columbia 20394',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8332,20395,-5,'Washington, District of Columbia 20395',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8333,20398,-5,'Washington, District of Columbia 20398',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8334,20401,-5,'Washington, District of Columbia 20401',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8335,20402,-5,'Washington, District of Columbia 20402',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8336,20403,-5,'Washington, District of Columbia 20403',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8337,20404,-5,'Washington, District of Columbia 20404',6106,7457);
INSERT INTO "django_geo_db_zipcode" VALUES(8338,20405,-5,'Washington, District of Columbia 20405',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8339,20406,-5,'Washington, District of Columbia 20406',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8340,20407,-5,'Washington, District of Columbia 20407',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8341,20408,-5,'Washington, District of Columbia 20408',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8342,20409,-5,'Washington, District of Columbia 20409',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8343,20410,-5,'Washington, District of Columbia 20410',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8344,20411,-5,'Washington, District of Columbia 20411',6106,7458);
INSERT INTO "django_geo_db_zipcode" VALUES(8345,20412,-5,'Washington, District of Columbia 20412',6106,7459);
INSERT INTO "django_geo_db_zipcode" VALUES(8346,20413,-5,'Washington, District of Columbia 20413',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8347,20414,-5,'Washington, District of Columbia 20414',6106,7458);
INSERT INTO "django_geo_db_zipcode" VALUES(8348,20415,-5,'Washington, District of Columbia 20415',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8349,20416,-5,'Washington, District of Columbia 20416',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8350,20418,-5,'Washington, District of Columbia 20418',6106,7460);
INSERT INTO "django_geo_db_zipcode" VALUES(8351,20419,-5,'Washington, District of Columbia 20419',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8352,20420,-5,'Washington, District of Columbia 20420',6106,7461);
INSERT INTO "django_geo_db_zipcode" VALUES(8353,20421,-5,'Washington, District of Columbia 20421',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8354,20422,-5,'Washington, District of Columbia 20422',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8355,20423,-5,'Washington, District of Columbia 20423',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8356,20424,-5,'Washington, District of Columbia 20424',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8357,20425,-5,'Washington, District of Columbia 20425',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8358,20426,-5,'Washington, District of Columbia 20426',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8359,20427,-5,'Washington, District of Columbia 20427',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8360,20428,-5,'Washington, District of Columbia 20428',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8361,20429,-5,'Washington, District of Columbia 20429',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8362,20431,-5,'Washington, District of Columbia 20431',6106,7462);
INSERT INTO "django_geo_db_zipcode" VALUES(8363,20433,-5,'Washington, District of Columbia 20433',6106,7463);
INSERT INTO "django_geo_db_zipcode" VALUES(8364,20434,-5,'Washington, District of Columbia 20434',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8365,20435,-5,'Washington, District of Columbia 20435',6106,7464);
INSERT INTO "django_geo_db_zipcode" VALUES(8366,20436,-5,'Washington, District of Columbia 20436',6106,7465);
INSERT INTO "django_geo_db_zipcode" VALUES(8367,20437,-5,'Washington, District of Columbia 20437',6106,7466);
INSERT INTO "django_geo_db_zipcode" VALUES(8368,20439,-5,'Washington, District of Columbia 20439',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8369,20440,-5,'Washington, District of Columbia 20440',6106,7467);
INSERT INTO "django_geo_db_zipcode" VALUES(8370,20441,-5,'Washington, District of Columbia 20441',6106,7468);
INSERT INTO "django_geo_db_zipcode" VALUES(8371,20442,-5,'Washington, District of Columbia 20442',6106,7469);
INSERT INTO "django_geo_db_zipcode" VALUES(8372,20444,-5,'Washington, District of Columbia 20444',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8373,20447,-5,'Washington, District of Columbia 20447',6106,7470);
INSERT INTO "django_geo_db_zipcode" VALUES(8374,20451,-5,'Washington, District of Columbia 20451',6106,7471);
INSERT INTO "django_geo_db_zipcode" VALUES(8375,20453,-5,'Washington, District of Columbia 20453',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8376,20456,-5,'Washington, District of Columbia 20456',6106,7472);
INSERT INTO "django_geo_db_zipcode" VALUES(8377,20460,-5,'Washington, District of Columbia 20460',6106,7473);
INSERT INTO "django_geo_db_zipcode" VALUES(8378,20463,-5,'Washington, District of Columbia 20463',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8379,20468,-5,'Washington, District of Columbia 20468',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8380,20469,-5,'Washington, District of Columbia 20469',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8381,20470,-5,'Washington, District of Columbia 20470',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8382,20472,-5,'Washington, District of Columbia 20472',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8383,20500,-5,'Washington, District of Columbia 20500',6106,7474);
INSERT INTO "django_geo_db_zipcode" VALUES(8384,20501,-5,'Washington, District of Columbia 20501',6106,7475);
INSERT INTO "django_geo_db_zipcode" VALUES(8385,20502,-5,'Washington, District of Columbia 20502',6106,7475);
INSERT INTO "django_geo_db_zipcode" VALUES(8386,20503,-5,'Washington, District of Columbia 20503',6106,7476);
INSERT INTO "django_geo_db_zipcode" VALUES(8387,20504,-5,'Washington, District of Columbia 20504',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8388,20505,-5,'Washington, District of Columbia 20505',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8389,20506,-5,'Washington, District of Columbia 20506',6106,7477);
INSERT INTO "django_geo_db_zipcode" VALUES(8390,20507,-5,'Washington, District of Columbia 20507',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8391,20508,-5,'Washington, District of Columbia 20508',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8392,20510,-5,'Washington, District of Columbia 20510',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8393,20515,-5,'Washington, District of Columbia 20515',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8394,20520,-5,'Washington, District of Columbia 20520',6106,7478);
INSERT INTO "django_geo_db_zipcode" VALUES(8395,20521,-5,'Washington, District of Columbia 20521',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8396,20522,-5,'Washington, District of Columbia 20522',6106,7478);
INSERT INTO "django_geo_db_zipcode" VALUES(8397,20523,-5,'Washington, District of Columbia 20523',6106,7479);
INSERT INTO "django_geo_db_zipcode" VALUES(8398,20524,-5,'Washington, District of Columbia 20524',6106,7480);
INSERT INTO "django_geo_db_zipcode" VALUES(8399,20525,-5,'Washington, District of Columbia 20525',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8400,20526,-5,'Washington, District of Columbia 20526',6106,7481);
INSERT INTO "django_geo_db_zipcode" VALUES(8401,20527,-5,'Washington, District of Columbia 20527',6106,7482);
INSERT INTO "django_geo_db_zipcode" VALUES(8402,20530,-5,'Washington, District of Columbia 20530',6106,7483);
INSERT INTO "django_geo_db_zipcode" VALUES(8403,20531,-5,'Washington, District of Columbia 20531',6106,7484);
INSERT INTO "django_geo_db_zipcode" VALUES(8404,20532,-5,'Washington, District of Columbia 20532',6106,7485);
INSERT INTO "django_geo_db_zipcode" VALUES(8405,20533,-5,'Washington, District of Columbia 20533',6106,7486);
INSERT INTO "django_geo_db_zipcode" VALUES(8406,20534,-5,'Washington, District of Columbia 20534',6106,7487);
INSERT INTO "django_geo_db_zipcode" VALUES(8407,20535,-5,'Washington, District of Columbia 20535',6106,7488);
INSERT INTO "django_geo_db_zipcode" VALUES(8408,20536,-5,'Washington, District of Columbia 20536',6106,7489);
INSERT INTO "django_geo_db_zipcode" VALUES(8409,20537,-5,'Washington, District of Columbia 20537',6106,7488);
INSERT INTO "django_geo_db_zipcode" VALUES(8410,20538,-5,'Washington, District of Columbia 20538',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8411,20539,-5,'Washington, District of Columbia 20539',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8412,20540,-5,'Washington, District of Columbia 20540',6106,7490);
INSERT INTO "django_geo_db_zipcode" VALUES(8413,20541,-5,'Washington, District of Columbia 20541',6106,7490);
INSERT INTO "django_geo_db_zipcode" VALUES(8414,20542,-5,'Washington, District of Columbia 20542',6106,7491);
INSERT INTO "django_geo_db_zipcode" VALUES(8415,20543,-5,'Washington, District of Columbia 20543',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8416,20544,-5,'Washington, District of Columbia 20544',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8417,20546,-5,'Washington, District of Columbia 20546',6106,7492);
INSERT INTO "django_geo_db_zipcode" VALUES(8418,20547,-5,'Washington, District of Columbia 20547',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8419,20548,-5,'Washington, District of Columbia 20548',6106,7493);
INSERT INTO "django_geo_db_zipcode" VALUES(8420,20549,-5,'Washington, District of Columbia 20549',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8421,20550,-5,'Washington, District of Columbia 20550',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8422,20551,-5,'Washington, District of Columbia 20551',6106,7494);
INSERT INTO "django_geo_db_zipcode" VALUES(8423,20552,-5,'Washington, District of Columbia 20552',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8424,20553,-5,'Washington, District of Columbia 20553',6106,7495);
INSERT INTO "django_geo_db_zipcode" VALUES(8425,20554,-5,'Washington, District of Columbia 20554',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8426,20555,-5,'Washington, District of Columbia 20555',6106,7496);
INSERT INTO "django_geo_db_zipcode" VALUES(8427,20557,-5,'Washington, District of Columbia 20557',6106,7490);
INSERT INTO "django_geo_db_zipcode" VALUES(8428,20558,-5,'Washington, District of Columbia 20558',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8429,20559,-5,'Washington, District of Columbia 20559',6106,7490);
INSERT INTO "django_geo_db_zipcode" VALUES(8430,20560,-5,'Washington, District of Columbia 20560',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8431,20565,-5,'Washington, District of Columbia 20565',6106,7497);
INSERT INTO "django_geo_db_zipcode" VALUES(8432,20566,-5,'Washington, District of Columbia 20566',6106,7498);
INSERT INTO "django_geo_db_zipcode" VALUES(8433,20570,-5,'Washington, District of Columbia 20570',6106,7499);
INSERT INTO "django_geo_db_zipcode" VALUES(8434,20571,-5,'Washington, District of Columbia 20571',6106,7500);
INSERT INTO "django_geo_db_zipcode" VALUES(8435,20572,-5,'Washington, District of Columbia 20572',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8436,20573,-5,'Washington, District of Columbia 20573',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8437,20575,-5,'Washington, District of Columbia 20575',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8438,20576,-5,'Washington, District of Columbia 20576',6106,7501);
INSERT INTO "django_geo_db_zipcode" VALUES(8439,20577,-5,'Washington, District of Columbia 20577',6106,7502);
INSERT INTO "django_geo_db_zipcode" VALUES(8440,20578,-5,'Washington, District of Columbia 20578',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8441,20579,-5,'Washington, District of Columbia 20579',6106,7503);
INSERT INTO "django_geo_db_zipcode" VALUES(8442,20580,-5,'Washington, District of Columbia 20580',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8443,20581,-5,'Washington, District of Columbia 20581',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8444,20585,-5,'Washington, District of Columbia 20585',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8445,20586,-5,'Washington, District of Columbia 20586',6106,7504);
INSERT INTO "django_geo_db_zipcode" VALUES(8446,20590,-5,'Washington, District of Columbia 20590',6106,7458);
INSERT INTO "django_geo_db_zipcode" VALUES(8447,20591,-5,'Washington, District of Columbia 20591',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8448,20593,-5,'Washington, District of Columbia 20593',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8449,20594,-5,'Washington, District of Columbia 20594',6106,7505);
INSERT INTO "django_geo_db_zipcode" VALUES(8450,20597,-5,'Washington, District of Columbia 20597',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8451,20599,-5,'Washington, District of Columbia 20599',6106,7351);
INSERT INTO "django_geo_db_zipcode" VALUES(8452,20601,-5,'Waldorf, Maryland 20601',6147,7506);
INSERT INTO "django_geo_db_zipcode" VALUES(8453,20602,-5,'Waldorf, Maryland 20602',6147,7507);
INSERT INTO "django_geo_db_zipcode" VALUES(8454,20603,-5,'Waldorf, Maryland 20603',6147,7508);
INSERT INTO "django_geo_db_zipcode" VALUES(8455,20604,-5,'Waldorf, Maryland 20604',6147,7509);
INSERT INTO "django_geo_db_zipcode" VALUES(8456,20606,-5,'Abell, Maryland 20606',6148,7510);
INSERT INTO "django_geo_db_zipcode" VALUES(8457,20607,-5,'Accokeek, Maryland 20607',6149,7511);
INSERT INTO "django_geo_db_zipcode" VALUES(8458,20608,-5,'Aquasco, Maryland 20608',6150,7512);
INSERT INTO "django_geo_db_zipcode" VALUES(8459,20609,-5,'Avenue, Maryland 20609',6151,7513);
INSERT INTO "django_geo_db_zipcode" VALUES(8460,20610,-5,'Barstow, Maryland 20610',6152,7514);
INSERT INTO "django_geo_db_zipcode" VALUES(8461,20611,-5,'Bel Alton, Maryland 20611',6153,7515);
INSERT INTO "django_geo_db_zipcode" VALUES(8462,20612,-5,'Benedict, Maryland 20612',6154,7516);
INSERT INTO "django_geo_db_zipcode" VALUES(8463,20613,-5,'Brandywine, Maryland 20613',6155,7517);
INSERT INTO "django_geo_db_zipcode" VALUES(8464,20615,-5,'Broomes Island, Maryland 20615',6156,7518);
INSERT INTO "django_geo_db_zipcode" VALUES(8465,20616,-5,'Bryans Road, Maryland 20616',6157,7519);
INSERT INTO "django_geo_db_zipcode" VALUES(8466,20617,-5,'Bryantown, Maryland 20617',6158,7520);
INSERT INTO "django_geo_db_zipcode" VALUES(8467,20618,-5,'Bushwood, Maryland 20618',6159,7521);
INSERT INTO "django_geo_db_zipcode" VALUES(8468,20619,-5,'California, Maryland 20619',6160,7522);
INSERT INTO "django_geo_db_zipcode" VALUES(8469,20620,-5,'Callaway, Maryland 20620',6161,7523);
INSERT INTO "django_geo_db_zipcode" VALUES(8470,20621,-5,'Chaptico, Maryland 20621',6162,7524);
INSERT INTO "django_geo_db_zipcode" VALUES(8471,20622,-5,'Charlotte Hall, Maryland 20622',6163,7525);
INSERT INTO "django_geo_db_zipcode" VALUES(8472,20623,-5,'Cheltenham, Maryland 20623',6164,7526);
INSERT INTO "django_geo_db_zipcode" VALUES(8473,20624,-5,'Clements, Maryland 20624',6165,7527);
INSERT INTO "django_geo_db_zipcode" VALUES(8474,20625,-5,'Cobb Island, Maryland 20625',6166,7528);
INSERT INTO "django_geo_db_zipcode" VALUES(8475,20626,-5,'Coltons Point, Maryland 20626',6167,7529);
INSERT INTO "django_geo_db_zipcode" VALUES(8476,20627,-5,'Compton, Maryland 20627',6168,7530);
INSERT INTO "django_geo_db_zipcode" VALUES(8477,20628,-5,'Dameron, Maryland 20628',6169,7531);
INSERT INTO "django_geo_db_zipcode" VALUES(8478,20629,-5,'Dowell, Maryland 20629',6170,7532);
INSERT INTO "django_geo_db_zipcode" VALUES(8479,20630,-5,'Drayden, Maryland 20630',6171,7533);
INSERT INTO "django_geo_db_zipcode" VALUES(8480,20632,-5,'Faulkner, Maryland 20632',6172,7534);
INSERT INTO "django_geo_db_zipcode" VALUES(8481,20634,-5,'Great Mills, Maryland 20634',6173,7535);
INSERT INTO "django_geo_db_zipcode" VALUES(8482,20635,-5,'Helen, Maryland 20635',6174,7536);
INSERT INTO "django_geo_db_zipcode" VALUES(8483,20636,-5,'Hollywood, Maryland 20636',6175,7537);
INSERT INTO "django_geo_db_zipcode" VALUES(8484,20637,-5,'Hughesville, Maryland 20637',6176,7538);
INSERT INTO "django_geo_db_zipcode" VALUES(8485,20639,-5,'Huntingtown, Maryland 20639',6177,7539);
INSERT INTO "django_geo_db_zipcode" VALUES(8486,20640,-5,'Indian Head, Maryland 20640',6178,7540);
INSERT INTO "django_geo_db_zipcode" VALUES(8487,20643,-5,'Ironsides, Maryland 20643',6179,7541);
INSERT INTO "django_geo_db_zipcode" VALUES(8488,20645,-5,'Issue, Maryland 20645',6180,7542);
INSERT INTO "django_geo_db_zipcode" VALUES(8489,20646,-5,'La Plata, Maryland 20646',6181,7543);
INSERT INTO "django_geo_db_zipcode" VALUES(8490,20650,-5,'Leonardtown, Maryland 20650',6182,7544);
INSERT INTO "django_geo_db_zipcode" VALUES(8491,20653,-5,'Lexington Park, Maryland 20653',6183,7545);
INSERT INTO "django_geo_db_zipcode" VALUES(8492,20656,-5,'Loveville, Maryland 20656',6184,7546);
INSERT INTO "django_geo_db_zipcode" VALUES(8493,20657,-5,'Lusby, Maryland 20657',6185,7547);
INSERT INTO "django_geo_db_zipcode" VALUES(8494,20658,-5,'Marbury, Maryland 20658',6186,7548);
INSERT INTO "django_geo_db_zipcode" VALUES(8495,20659,-5,'Mechanicsville, Maryland 20659',6187,7549);
INSERT INTO "django_geo_db_zipcode" VALUES(8496,20660,-5,'Morganza, Maryland 20660',6188,7550);
INSERT INTO "django_geo_db_zipcode" VALUES(8497,20661,-5,'Mount Victoria, Maryland 20661',6189,7551);
INSERT INTO "django_geo_db_zipcode" VALUES(8498,20662,-5,'Nanjemoy, Maryland 20662',6190,7552);
INSERT INTO "django_geo_db_zipcode" VALUES(8499,20664,-5,'Newburg, Maryland 20664',6191,7553);
INSERT INTO "django_geo_db_zipcode" VALUES(8500,20667,-5,'Park Hall, Maryland 20667',6192,7554);
INSERT INTO "django_geo_db_zipcode" VALUES(8501,20670,-5,'Patuxent River, Maryland 20670',6193,7555);
INSERT INTO "django_geo_db_zipcode" VALUES(8502,20674,-5,'Piney Point, Maryland 20674',6194,7556);
INSERT INTO "django_geo_db_zipcode" VALUES(8503,20675,-5,'Pomfret, Maryland 20675',6195,7557);
INSERT INTO "django_geo_db_zipcode" VALUES(8504,20676,-5,'Port Republic, Maryland 20676',6196,7558);
INSERT INTO "django_geo_db_zipcode" VALUES(8505,20677,-5,'Port Tobacco, Maryland 20677',6197,7559);
INSERT INTO "django_geo_db_zipcode" VALUES(8506,20678,-5,'Prince Frederick, Maryland 20678',6198,7560);
INSERT INTO "django_geo_db_zipcode" VALUES(8507,20680,-5,'Ridge, Maryland 20680',6199,7561);
INSERT INTO "django_geo_db_zipcode" VALUES(8508,20682,-5,'Rock Point, Maryland 20682',6200,7562);
INSERT INTO "django_geo_db_zipcode" VALUES(8509,20684,-5,'Saint Inigoes, Maryland 20684',6201,7563);
INSERT INTO "django_geo_db_zipcode" VALUES(8510,20685,-5,'Saint Leonard, Maryland 20685',6202,7564);
INSERT INTO "django_geo_db_zipcode" VALUES(8511,20686,-5,'Saint Marys City, Maryland 20686',6203,7565);
INSERT INTO "django_geo_db_zipcode" VALUES(8512,20687,-5,'Scotland, Maryland 20687',6204,7566);
INSERT INTO "django_geo_db_zipcode" VALUES(8513,20688,-5,'Solomons, Maryland 20688',6205,7567);
INSERT INTO "django_geo_db_zipcode" VALUES(8514,20689,-5,'Sunderland, Maryland 20689',6206,7568);
INSERT INTO "django_geo_db_zipcode" VALUES(8515,20690,-5,'Tall Timbers, Maryland 20690',6207,7569);
INSERT INTO "django_geo_db_zipcode" VALUES(8516,20692,-5,'Valley Lee, Maryland 20692',6208,7570);
INSERT INTO "django_geo_db_zipcode" VALUES(8517,20693,-5,'Welcome, Maryland 20693',6209,7571);
INSERT INTO "django_geo_db_zipcode" VALUES(8518,20695,-5,'White Plains, Maryland 20695',6210,7572);
INSERT INTO "django_geo_db_zipcode" VALUES(8519,20697,-5,'Southern Md Facility, Maryland 20697',6211,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8520,20701,-5,'Annapolis Junction, Maryland 20701',6212,7574);
INSERT INTO "django_geo_db_zipcode" VALUES(8521,20703,-5,'Lanham, Maryland 20703',6213,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8522,20704,-5,'Beltsville, Maryland 20704',6214,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8523,20705,-5,'Beltsville, Maryland 20705',6214,7575);
INSERT INTO "django_geo_db_zipcode" VALUES(8524,20706,-5,'Lanham, Maryland 20706',6213,7576);
INSERT INTO "django_geo_db_zipcode" VALUES(8525,20707,-5,'Laurel, Maryland 20707',6215,7577);
INSERT INTO "django_geo_db_zipcode" VALUES(8526,20708,-5,'Laurel, Maryland 20708',6215,7578);
INSERT INTO "django_geo_db_zipcode" VALUES(8527,20709,-5,'Laurel, Maryland 20709',6215,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8528,20710,-5,'Bladensburg, Maryland 20710',6216,7579);
INSERT INTO "django_geo_db_zipcode" VALUES(8529,20711,-5,'Lothian, Maryland 20711',6217,7580);
INSERT INTO "django_geo_db_zipcode" VALUES(8530,20712,-5,'Mount Rainier, Maryland 20712',6218,7581);
INSERT INTO "django_geo_db_zipcode" VALUES(8531,20714,-5,'North Beach, Maryland 20714',6219,7582);
INSERT INTO "django_geo_db_zipcode" VALUES(8532,20715,-5,'Bowie, Maryland 20715',6220,7583);
INSERT INTO "django_geo_db_zipcode" VALUES(8533,20716,-5,'Bowie, Maryland 20716',6220,7584);
INSERT INTO "django_geo_db_zipcode" VALUES(8534,20717,-5,'Bowie, Maryland 20717',6220,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8535,20718,-5,'Bowie, Maryland 20718',6220,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8536,20719,-5,'Bowie, Maryland 20719',6220,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8537,20720,-5,'Bowie, Maryland 20720',6220,7585);
INSERT INTO "django_geo_db_zipcode" VALUES(8538,20721,-5,'Bowie, Maryland 20721',6220,7586);
INSERT INTO "django_geo_db_zipcode" VALUES(8539,20722,-5,'Brentwood, Maryland 20722',6221,7587);
INSERT INTO "django_geo_db_zipcode" VALUES(8540,20723,-5,'Laurel, Maryland 20723',6215,7588);
INSERT INTO "django_geo_db_zipcode" VALUES(8541,20724,-5,'Laurel, Maryland 20724',6215,7589);
INSERT INTO "django_geo_db_zipcode" VALUES(8542,20725,-5,'Laurel, Maryland 20725',6215,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8543,20726,-5,'Laurel, Maryland 20726',6215,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8544,20731,-5,'Capitol Heights, Maryland 20731',6222,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8545,20732,-5,'Chesapeake Beach, Maryland 20732',6223,7590);
INSERT INTO "django_geo_db_zipcode" VALUES(8546,20733,-5,'Churchton, Maryland 20733',6224,7591);
INSERT INTO "django_geo_db_zipcode" VALUES(8547,20735,-5,'Clinton, Maryland 20735',6225,7592);
INSERT INTO "django_geo_db_zipcode" VALUES(8548,20736,-5,'Owings, Maryland 20736',6226,7593);
INSERT INTO "django_geo_db_zipcode" VALUES(8549,20737,-5,'Riverdale, Maryland 20737',6227,7594);
INSERT INTO "django_geo_db_zipcode" VALUES(8550,20738,-5,'Riverdale, Maryland 20738',6227,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8551,20740,-5,'College Park, Maryland 20740',6228,7595);
INSERT INTO "django_geo_db_zipcode" VALUES(8552,20741,-5,'College Park, Maryland 20741',6228,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8553,20742,-5,'College Park, Maryland 20742',6228,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8554,20743,-5,'Capitol Heights, Maryland 20743',6222,7596);
INSERT INTO "django_geo_db_zipcode" VALUES(8555,20744,-5,'Fort Washington, Maryland 20744',6229,7597);
INSERT INTO "django_geo_db_zipcode" VALUES(8556,20745,-5,'Oxon Hill, Maryland 20745',6230,7598);
INSERT INTO "django_geo_db_zipcode" VALUES(8557,20746,-5,'Suitland, Maryland 20746',6231,7599);
INSERT INTO "django_geo_db_zipcode" VALUES(8558,20747,-5,'District Heights, Maryland 20747',6232,7600);
INSERT INTO "django_geo_db_zipcode" VALUES(8559,20748,-5,'Temple Hills, Maryland 20748',6233,7601);
INSERT INTO "django_geo_db_zipcode" VALUES(8560,20749,-5,'Fort Washington, Maryland 20749',6229,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8561,20750,-5,'Oxon Hill, Maryland 20750',6230,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8562,20751,-5,'Deale, Maryland 20751',6234,7602);
INSERT INTO "django_geo_db_zipcode" VALUES(8563,20752,-5,'Suitland, Maryland 20752',6231,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8564,20753,-5,'District Heights, Maryland 20753',6232,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8565,20754,-5,'Dunkirk, Maryland 20754',6235,7603);
INSERT INTO "django_geo_db_zipcode" VALUES(8566,20755,-5,'Fort George G Meade, Maryland 20755',6236,7604);
INSERT INTO "django_geo_db_zipcode" VALUES(8567,20757,-5,'Temple Hills, Maryland 20757',6233,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8568,20758,-5,'Friendship, Maryland 20758',6237,7605);
INSERT INTO "django_geo_db_zipcode" VALUES(8569,20759,-5,'Fulton, Maryland 20759',6238,7606);
INSERT INTO "django_geo_db_zipcode" VALUES(8570,20762,-5,'Andrews Air Force Base, Maryland 20762',6239,7607);
INSERT INTO "django_geo_db_zipcode" VALUES(8571,20763,-5,'Savage, Maryland 20763',6240,7608);
INSERT INTO "django_geo_db_zipcode" VALUES(8572,20764,-5,'Shady Side, Maryland 20764',6241,7609);
INSERT INTO "django_geo_db_zipcode" VALUES(8573,20765,-5,'Galesville, Maryland 20765',6242,7610);
INSERT INTO "django_geo_db_zipcode" VALUES(8574,20768,-5,'Greenbelt, Maryland 20768',6243,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8575,20769,-5,'Glenn Dale, Maryland 20769',6244,7611);
INSERT INTO "django_geo_db_zipcode" VALUES(8576,20770,-5,'Greenbelt, Maryland 20770',6243,7612);
INSERT INTO "django_geo_db_zipcode" VALUES(8577,20771,-5,'Greenbelt, Maryland 20771',6243,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8578,20772,-5,'Upper Marlboro, Maryland 20772',6245,7613);
INSERT INTO "django_geo_db_zipcode" VALUES(8579,20773,-5,'Upper Marlboro, Maryland 20773',6245,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8580,20774,-5,'Upper Marlboro, Maryland 20774',6245,7614);
INSERT INTO "django_geo_db_zipcode" VALUES(8581,20775,-5,'Upper Marlboro, Maryland 20775',6245,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8582,20776,-5,'Harwood, Maryland 20776',6246,7615);
INSERT INTO "django_geo_db_zipcode" VALUES(8583,20777,-5,'Highland, Maryland 20777',6247,7616);
INSERT INTO "django_geo_db_zipcode" VALUES(8584,20778,-5,'West River, Maryland 20778',6248,7617);
INSERT INTO "django_geo_db_zipcode" VALUES(8585,20779,-5,'Tracys Landing, Maryland 20779',6249,7618);
INSERT INTO "django_geo_db_zipcode" VALUES(8586,20781,-5,'Hyattsville, Maryland 20781',6250,7619);
INSERT INTO "django_geo_db_zipcode" VALUES(8587,20782,-5,'Hyattsville, Maryland 20782',6250,7620);
INSERT INTO "django_geo_db_zipcode" VALUES(8588,20783,-5,'Hyattsville, Maryland 20783',6250,7621);
INSERT INTO "django_geo_db_zipcode" VALUES(8589,20784,-5,'Hyattsville, Maryland 20784',6250,7622);
INSERT INTO "django_geo_db_zipcode" VALUES(8590,20785,-5,'Hyattsville, Maryland 20785',6250,7623);
INSERT INTO "django_geo_db_zipcode" VALUES(8591,20787,-5,'Hyattsville, Maryland 20787',6250,7624);
INSERT INTO "django_geo_db_zipcode" VALUES(8592,20788,-5,'Hyattsville, Maryland 20788',6250,7625);
INSERT INTO "django_geo_db_zipcode" VALUES(8593,20790,-5,'Capitol Heights, Maryland 20790',6222,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8594,20791,-5,'Capitol Heights, Maryland 20791',6222,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8595,20794,-5,'Jessup, Maryland 20794',6251,7626);
INSERT INTO "django_geo_db_zipcode" VALUES(8596,20797,-5,'Southern Md Facility, Maryland 20797',6211,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8597,20799,-5,'Capitol Heights, Maryland 20799',6222,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8598,20812,-5,'Glen Echo, Maryland 20812',6252,7627);
INSERT INTO "django_geo_db_zipcode" VALUES(8599,20813,-5,'Bethesda, Maryland 20813',6253,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8600,20814,-5,'Bethesda, Maryland 20814',6253,7629);
INSERT INTO "django_geo_db_zipcode" VALUES(8601,20815,-5,'Chevy Chase, Maryland 20815',6254,7630);
INSERT INTO "django_geo_db_zipcode" VALUES(8602,20816,-5,'Bethesda, Maryland 20816',6253,7631);
INSERT INTO "django_geo_db_zipcode" VALUES(8603,20817,-5,'Bethesda, Maryland 20817',6253,7632);
INSERT INTO "django_geo_db_zipcode" VALUES(8604,20818,-5,'Cabin John, Maryland 20818',6255,7633);
INSERT INTO "django_geo_db_zipcode" VALUES(8605,20824,-5,'Bethesda, Maryland 20824',6253,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8606,20825,-5,'Chevy Chase, Maryland 20825',6254,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8607,20827,-5,'Bethesda, Maryland 20827',6253,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8608,20830,-5,'Olney, Maryland 20830',6256,7634);
INSERT INTO "django_geo_db_zipcode" VALUES(8609,20831,-5,'Chesapeake Beach, Maryland 20831',6223,7635);
INSERT INTO "django_geo_db_zipcode" VALUES(8610,20832,-5,'Olney, Maryland 20832',6256,7636);
INSERT INTO "django_geo_db_zipcode" VALUES(8611,20833,-5,'Brookeville, Maryland 20833',6257,7637);
INSERT INTO "django_geo_db_zipcode" VALUES(8612,20837,-5,'Poolesville, Maryland 20837',6258,7638);
INSERT INTO "django_geo_db_zipcode" VALUES(8613,20838,-5,'Barnesville, Maryland 20838',6259,7639);
INSERT INTO "django_geo_db_zipcode" VALUES(8614,20839,-5,'Beallsville, Maryland 20839',6260,7640);
INSERT INTO "django_geo_db_zipcode" VALUES(8615,20841,-5,'Boyds, Maryland 20841',6261,7641);
INSERT INTO "django_geo_db_zipcode" VALUES(8616,20842,-5,'Dickerson, Maryland 20842',6262,7642);
INSERT INTO "django_geo_db_zipcode" VALUES(8617,20847,-5,'Rockville, Maryland 20847',6263,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8618,20848,-5,'Rockville, Maryland 20848',6263,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8619,20849,-5,'Rockville, Maryland 20849',6263,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8620,20850,-5,'Rockville, Maryland 20850',6263,7643);
INSERT INTO "django_geo_db_zipcode" VALUES(8621,20851,-5,'Rockville, Maryland 20851',6263,7644);
INSERT INTO "django_geo_db_zipcode" VALUES(8622,20852,-5,'Rockville, Maryland 20852',6263,7645);
INSERT INTO "django_geo_db_zipcode" VALUES(8623,20853,-5,'Rockville, Maryland 20853',6263,7646);
INSERT INTO "django_geo_db_zipcode" VALUES(8624,20854,-5,'Potomac, Maryland 20854',6264,7647);
INSERT INTO "django_geo_db_zipcode" VALUES(8625,20855,-5,'Derwood, Maryland 20855',6265,7648);
INSERT INTO "django_geo_db_zipcode" VALUES(8626,20857,-5,'Rockville, Maryland 20857',6263,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8627,20859,-5,'Potomac, Maryland 20859',6264,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8628,20860,-5,'Sandy Spring, Maryland 20860',6266,7649);
INSERT INTO "django_geo_db_zipcode" VALUES(8629,20861,-5,'Ashton, Maryland 20861',6267,7650);
INSERT INTO "django_geo_db_zipcode" VALUES(8630,20862,-5,'Brinklow, Maryland 20862',6268,7651);
INSERT INTO "django_geo_db_zipcode" VALUES(8631,20866,-5,'Burtonsville, Maryland 20866',6269,7652);
INSERT INTO "django_geo_db_zipcode" VALUES(8632,20868,-5,'Spencerville, Maryland 20868',6270,7653);
INSERT INTO "django_geo_db_zipcode" VALUES(8633,20871,-5,'Clarksburg, Maryland 20871',6271,7654);
INSERT INTO "django_geo_db_zipcode" VALUES(8634,20872,-5,'Damascus, Maryland 20872',6272,7655);
INSERT INTO "django_geo_db_zipcode" VALUES(8635,20874,-5,'Germantown, Maryland 20874',6273,7656);
INSERT INTO "django_geo_db_zipcode" VALUES(8636,20875,-5,'Germantown, Maryland 20875',6273,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8637,20876,-5,'Germantown, Maryland 20876',6273,7657);
INSERT INTO "django_geo_db_zipcode" VALUES(8638,20877,-5,'Gaithersburg, Maryland 20877',6274,7658);
INSERT INTO "django_geo_db_zipcode" VALUES(8639,20878,-5,'Gaithersburg, Maryland 20878',6274,7659);
INSERT INTO "django_geo_db_zipcode" VALUES(8640,20879,-5,'Gaithersburg, Maryland 20879',6274,7660);
INSERT INTO "django_geo_db_zipcode" VALUES(8641,20880,-5,'Washington Grove, Maryland 20880',6275,7661);
INSERT INTO "django_geo_db_zipcode" VALUES(8642,20882,-5,'Gaithersburg, Maryland 20882',6274,7662);
INSERT INTO "django_geo_db_zipcode" VALUES(8643,20884,-5,'Gaithersburg, Maryland 20884',6274,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8644,20885,-5,'Gaithersburg, Maryland 20885',6274,7663);
INSERT INTO "django_geo_db_zipcode" VALUES(8645,20886,-5,'Montgomery Village, Maryland 20886',6276,7664);
INSERT INTO "django_geo_db_zipcode" VALUES(8646,20889,-5,'Bethesda, Maryland 20889',6253,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8647,20891,-5,'Kensington, Maryland 20891',6277,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8648,20892,-5,'Bethesda, Maryland 20892',6253,7665);
INSERT INTO "django_geo_db_zipcode" VALUES(8649,20894,-5,'Bethesda, Maryland 20894',6253,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8650,20895,-5,'Kensington, Maryland 20895',6277,7666);
INSERT INTO "django_geo_db_zipcode" VALUES(8651,20896,-5,'Garrett Park, Maryland 20896',6278,7667);
INSERT INTO "django_geo_db_zipcode" VALUES(8652,20897,-5,'Suburb Maryland Fac, Maryland 20897',6279,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8653,20898,-5,'Gaithersburg, Maryland 20898',6274,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8654,20899,-5,'Gaithersburg, Maryland 20899',6274,7668);
INSERT INTO "django_geo_db_zipcode" VALUES(8655,20901,-5,'Silver Spring, Maryland 20901',6280,7669);
INSERT INTO "django_geo_db_zipcode" VALUES(8656,20902,-5,'Silver Spring, Maryland 20902',6280,7670);
INSERT INTO "django_geo_db_zipcode" VALUES(8657,20903,-5,'Silver Spring, Maryland 20903',6280,7671);
INSERT INTO "django_geo_db_zipcode" VALUES(8658,20904,-5,'Silver Spring, Maryland 20904',6280,7672);
INSERT INTO "django_geo_db_zipcode" VALUES(8659,20905,-5,'Silver Spring, Maryland 20905',6280,7673);
INSERT INTO "django_geo_db_zipcode" VALUES(8660,20906,-5,'Silver Spring, Maryland 20906',6280,7674);
INSERT INTO "django_geo_db_zipcode" VALUES(8661,20907,-5,'Silver Spring, Maryland 20907',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8662,20908,-5,'Silver Spring, Maryland 20908',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8663,20910,-5,'Silver Spring, Maryland 20910',6280,7675);
INSERT INTO "django_geo_db_zipcode" VALUES(8664,20911,-5,'Silver Spring, Maryland 20911',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8665,20912,-5,'Takoma Park, Maryland 20912',6281,7676);
INSERT INTO "django_geo_db_zipcode" VALUES(8666,20913,-5,'Takoma Park, Maryland 20913',6281,7573);
INSERT INTO "django_geo_db_zipcode" VALUES(8667,20914,-5,'Silver Spring, Maryland 20914',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8668,20915,-5,'Silver Spring, Maryland 20915',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8669,20916,-5,'Silver Spring, Maryland 20916',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8670,20918,-5,'Silver Spring, Maryland 20918',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8671,20997,-5,'Silver Spring, Maryland 20997',6280,7628);
INSERT INTO "django_geo_db_zipcode" VALUES(8672,21001,-5,'Aberdeen, Maryland 21001',6282,7677);
INSERT INTO "django_geo_db_zipcode" VALUES(8673,21002,-5,'Perryman, Maryland 21002',6283,7678);
INSERT INTO "django_geo_db_zipcode" VALUES(8674,21004,-5,'Bel Air South, Maryland 21004',6284,7679);
INSERT INTO "django_geo_db_zipcode" VALUES(8675,21005,-5,'Aberdeen Proving Ground, Maryland 21005',6285,7680);
INSERT INTO "django_geo_db_zipcode" VALUES(8676,21009,-5,'Abingdon, Maryland 21009',6286,7681);
INSERT INTO "django_geo_db_zipcode" VALUES(8677,21010,-5,'Gunpowder, Maryland 21010',6287,7682);
INSERT INTO "django_geo_db_zipcode" VALUES(8678,21012,-5,'Arnold, Maryland 21012',6288,7683);
INSERT INTO "django_geo_db_zipcode" VALUES(8679,21013,-5,'Baldwin, Maryland 21013',6289,7684);
INSERT INTO "django_geo_db_zipcode" VALUES(8680,21014,-5,'Bel Air, Maryland 21014',6290,7685);
INSERT INTO "django_geo_db_zipcode" VALUES(8681,21015,-5,'Bel Air, Maryland 21015',6290,7686);
INSERT INTO "django_geo_db_zipcode" VALUES(8682,21017,-5,'Belcamp, Maryland 21017',6291,7687);
INSERT INTO "django_geo_db_zipcode" VALUES(8683,21018,-5,'Benson, Maryland 21018',6292,7688);
INSERT INTO "django_geo_db_zipcode" VALUES(8684,21020,-5,'Boring, Maryland 21020',6293,7689);
INSERT INTO "django_geo_db_zipcode" VALUES(8685,21022,-5,'Brooklandville, Maryland 21022',6294,7690);
INSERT INTO "django_geo_db_zipcode" VALUES(8686,21023,-5,'Butler, Maryland 21023',6295,7691);
INSERT INTO "django_geo_db_zipcode" VALUES(8687,21027,-5,'Chase, Maryland 21027',6296,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8688,21028,-5,'Churchville, Maryland 21028',6297,7693);
INSERT INTO "django_geo_db_zipcode" VALUES(8689,21029,-5,'Clarksville, Maryland 21029',6298,7694);
INSERT INTO "django_geo_db_zipcode" VALUES(8690,21030,-5,'Cockeysville, Maryland 21030',6299,7695);
INSERT INTO "django_geo_db_zipcode" VALUES(8691,21031,-5,'Hunt Valley, Maryland 21031',6300,7696);
INSERT INTO "django_geo_db_zipcode" VALUES(8692,21032,-5,'Crownsville, Maryland 21032',6301,7697);
INSERT INTO "django_geo_db_zipcode" VALUES(8693,21034,-5,'Darlington, Maryland 21034',6302,7698);
INSERT INTO "django_geo_db_zipcode" VALUES(8694,21035,-5,'Davidsonville, Maryland 21035',6303,7699);
INSERT INTO "django_geo_db_zipcode" VALUES(8695,21036,-5,'Dayton, Maryland 21036',6304,7700);
INSERT INTO "django_geo_db_zipcode" VALUES(8696,21037,-5,'Edgewater, Maryland 21037',6305,7701);
INSERT INTO "django_geo_db_zipcode" VALUES(8697,21040,-5,'Edgewood, Maryland 21040',6306,7702);
INSERT INTO "django_geo_db_zipcode" VALUES(8698,21041,-5,'Ellicott City, Maryland 21041',6307,7703);
INSERT INTO "django_geo_db_zipcode" VALUES(8699,21042,-5,'Ellicott City, Maryland 21042',6307,7704);
INSERT INTO "django_geo_db_zipcode" VALUES(8700,21043,-5,'Ellicott City, Maryland 21043',6307,7705);
INSERT INTO "django_geo_db_zipcode" VALUES(8701,21044,-5,'Columbia, Maryland 21044',6308,7706);
INSERT INTO "django_geo_db_zipcode" VALUES(8702,21045,-5,'Columbia, Maryland 21045',6308,7707);
INSERT INTO "django_geo_db_zipcode" VALUES(8703,21046,-5,'Columbia, Maryland 21046',6308,7708);
INSERT INTO "django_geo_db_zipcode" VALUES(8704,21047,-5,'Fallston, Maryland 21047',6309,7709);
INSERT INTO "django_geo_db_zipcode" VALUES(8705,21048,-5,'Finksburg, Maryland 21048',6310,7710);
INSERT INTO "django_geo_db_zipcode" VALUES(8706,21050,-5,'Forest Hill, Maryland 21050',6311,7711);
INSERT INTO "django_geo_db_zipcode" VALUES(8707,21051,-5,'Fork, Maryland 21051',6312,7712);
INSERT INTO "django_geo_db_zipcode" VALUES(8708,21052,-5,'Fort Howard, Maryland 21052',6313,7713);
INSERT INTO "django_geo_db_zipcode" VALUES(8709,21053,-5,'Freeland, Maryland 21053',6314,7714);
INSERT INTO "django_geo_db_zipcode" VALUES(8710,21054,-5,'Gambrills, Maryland 21054',6315,7715);
INSERT INTO "django_geo_db_zipcode" VALUES(8711,21055,-5,'Garrison, Maryland 21055',6316,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8712,21056,-5,'Gibson Island, Maryland 21056',6317,7716);
INSERT INTO "django_geo_db_zipcode" VALUES(8713,21057,-5,'Glen Arm, Maryland 21057',6318,7717);
INSERT INTO "django_geo_db_zipcode" VALUES(8714,21060,-5,'Glen Burnie, Maryland 21060',6319,7718);
INSERT INTO "django_geo_db_zipcode" VALUES(8715,21061,-5,'Glen Burnie, Maryland 21061',6319,7719);
INSERT INTO "django_geo_db_zipcode" VALUES(8716,21062,-5,'Glen Burnie, Maryland 21062',6319,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8717,21071,-5,'Glyndon, Maryland 21071',6320,7721);
INSERT INTO "django_geo_db_zipcode" VALUES(8718,21074,-5,'Hampstead, Maryland 21074',6321,7722);
INSERT INTO "django_geo_db_zipcode" VALUES(8719,21075,-5,'Elkridge, Maryland 21075',6322,7723);
INSERT INTO "django_geo_db_zipcode" VALUES(8720,21076,-5,'Hanover, Maryland 21076',6323,7724);
INSERT INTO "django_geo_db_zipcode" VALUES(8721,21077,-5,'Harmans, Maryland 21077',6324,7725);
INSERT INTO "django_geo_db_zipcode" VALUES(8722,21078,-5,'Havre De Grace, Maryland 21078',6325,7726);
INSERT INTO "django_geo_db_zipcode" VALUES(8723,21080,-5,'Henryton, Maryland 21080',6326,7727);
INSERT INTO "django_geo_db_zipcode" VALUES(8724,21082,-5,'Hydes, Maryland 21082',6327,7728);
INSERT INTO "django_geo_db_zipcode" VALUES(8725,21084,-5,'Jarrettsville, Maryland 21084',6328,7729);
INSERT INTO "django_geo_db_zipcode" VALUES(8726,21085,-5,'Joppa, Maryland 21085',6329,7730);
INSERT INTO "django_geo_db_zipcode" VALUES(8727,21087,-5,'Kingsville, Maryland 21087',6330,7731);
INSERT INTO "django_geo_db_zipcode" VALUES(8728,21088,-5,'Lineboro, Maryland 21088',6331,7727);
INSERT INTO "django_geo_db_zipcode" VALUES(8729,21090,-5,'Linthicum Heights, Maryland 21090',6332,7732);
INSERT INTO "django_geo_db_zipcode" VALUES(8730,21092,-5,'Long Green, Maryland 21092',6333,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8731,21093,-5,'Lutherville Timonium, Maryland 21093',6334,7733);
INSERT INTO "django_geo_db_zipcode" VALUES(8732,21094,-5,'Lutherville Timonium, Maryland 21094',6334,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8733,21098,-5,'Hanover, Maryland 21098',6323,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8734,21102,-5,'Manchester, Maryland 21102',6335,7734);
INSERT INTO "django_geo_db_zipcode" VALUES(8735,21104,-5,'Marriottsville, Maryland 21104',6336,7735);
INSERT INTO "django_geo_db_zipcode" VALUES(8736,21105,-5,'Maryland Line, Maryland 21105',6337,7736);
INSERT INTO "django_geo_db_zipcode" VALUES(8737,21106,-5,'Mayo, Maryland 21106',6338,7737);
INSERT INTO "django_geo_db_zipcode" VALUES(8738,21108,-5,'Millersville, Maryland 21108',6339,7738);
INSERT INTO "django_geo_db_zipcode" VALUES(8739,21111,-5,'Monkton, Maryland 21111',6340,7739);
INSERT INTO "django_geo_db_zipcode" VALUES(8740,21113,-5,'Odenton, Maryland 21113',6341,7740);
INSERT INTO "django_geo_db_zipcode" VALUES(8741,21114,-5,'Crofton, Maryland 21114',6342,7741);
INSERT INTO "django_geo_db_zipcode" VALUES(8742,21117,-5,'Owings Mills, Maryland 21117',6343,7742);
INSERT INTO "django_geo_db_zipcode" VALUES(8743,21120,-5,'Parkton, Maryland 21120',6344,7743);
INSERT INTO "django_geo_db_zipcode" VALUES(8744,21122,-5,'Pasadena, Maryland 21122',6345,7744);
INSERT INTO "django_geo_db_zipcode" VALUES(8745,21123,-5,'Pasadena, Maryland 21123',6345,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8746,21128,-5,'Perry Hall, Maryland 21128',6346,7745);
INSERT INTO "django_geo_db_zipcode" VALUES(8747,21130,-5,'Perryman, Maryland 21130',6283,7746);
INSERT INTO "django_geo_db_zipcode" VALUES(8748,21131,-5,'Phoenix, Maryland 21131',6347,7747);
INSERT INTO "django_geo_db_zipcode" VALUES(8749,21132,-5,'Pylesville, Maryland 21132',6348,7748);
INSERT INTO "django_geo_db_zipcode" VALUES(8750,21133,-5,'Randallstown, Maryland 21133',6349,7749);
INSERT INTO "django_geo_db_zipcode" VALUES(8751,21136,-5,'Reisterstown, Maryland 21136',6350,7750);
INSERT INTO "django_geo_db_zipcode" VALUES(8752,21139,-5,'Riderwood, Maryland 21139',6351,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8753,21140,-5,'Riva, Maryland 21140',6352,7751);
INSERT INTO "django_geo_db_zipcode" VALUES(8754,21144,-5,'Severn, Maryland 21144',6353,7752);
INSERT INTO "django_geo_db_zipcode" VALUES(8755,21146,-5,'Severna Park, Maryland 21146',6354,7753);
INSERT INTO "django_geo_db_zipcode" VALUES(8756,21150,-5,'Simpsonville, Maryland 21150',6355,7703);
INSERT INTO "django_geo_db_zipcode" VALUES(8757,21152,-5,'Sparks Glencoe, Maryland 21152',6356,7754);
INSERT INTO "django_geo_db_zipcode" VALUES(8758,21153,-5,'Stevenson, Maryland 21153',6357,7755);
INSERT INTO "django_geo_db_zipcode" VALUES(8759,21154,-5,'Street, Maryland 21154',6358,7756);
INSERT INTO "django_geo_db_zipcode" VALUES(8760,21155,-5,'Upperco, Maryland 21155',6359,7757);
INSERT INTO "django_geo_db_zipcode" VALUES(8761,21156,-5,'Upper Falls, Maryland 21156',6360,7758);
INSERT INTO "django_geo_db_zipcode" VALUES(8762,21157,-5,'Westminster, Maryland 21157',6361,7759);
INSERT INTO "django_geo_db_zipcode" VALUES(8763,21158,-5,'Westminster, Maryland 21158',6361,7760);
INSERT INTO "django_geo_db_zipcode" VALUES(8764,21160,-5,'Whiteford, Maryland 21160',6362,7761);
INSERT INTO "django_geo_db_zipcode" VALUES(8765,21161,-5,'White Hall, Maryland 21161',6363,7762);
INSERT INTO "django_geo_db_zipcode" VALUES(8766,21162,-5,'White Marsh, Maryland 21162',6364,7763);
INSERT INTO "django_geo_db_zipcode" VALUES(8767,21163,-5,'Woodstock, Maryland 21163',6365,7764);
INSERT INTO "django_geo_db_zipcode" VALUES(8768,21176,-5,'New Windsor, Maryland 21176',6366,7765);
INSERT INTO "django_geo_db_zipcode" VALUES(8769,21201,-5,'Baltimore, Maryland 21201',6367,7766);
INSERT INTO "django_geo_db_zipcode" VALUES(8770,21202,-5,'Baltimore, Maryland 21202',6367,7767);
INSERT INTO "django_geo_db_zipcode" VALUES(8771,21203,-5,'Baltimore, Maryland 21203',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8772,21204,-5,'Towson, Maryland 21204',6368,7769);
INSERT INTO "django_geo_db_zipcode" VALUES(8773,21205,-5,'Baltimore, Maryland 21205',6367,7770);
INSERT INTO "django_geo_db_zipcode" VALUES(8774,21206,-5,'Baltimore, Maryland 21206',6367,7771);
INSERT INTO "django_geo_db_zipcode" VALUES(8775,21207,-5,'Gwynn Oak, Maryland 21207',6369,7772);
INSERT INTO "django_geo_db_zipcode" VALUES(8776,21208,-5,'Pikesville, Maryland 21208',6370,7773);
INSERT INTO "django_geo_db_zipcode" VALUES(8777,21209,-5,'Baltimore, Maryland 21209',6367,7774);
INSERT INTO "django_geo_db_zipcode" VALUES(8778,21210,-5,'Baltimore, Maryland 21210',6367,7775);
INSERT INTO "django_geo_db_zipcode" VALUES(8779,21211,-5,'Baltimore, Maryland 21211',6367,7776);
INSERT INTO "django_geo_db_zipcode" VALUES(8780,21212,-5,'Baltimore, Maryland 21212',6367,7777);
INSERT INTO "django_geo_db_zipcode" VALUES(8781,21213,-5,'Baltimore, Maryland 21213',6367,7778);
INSERT INTO "django_geo_db_zipcode" VALUES(8782,21214,-5,'Baltimore, Maryland 21214',6367,7779);
INSERT INTO "django_geo_db_zipcode" VALUES(8783,21215,-5,'Baltimore, Maryland 21215',6367,7780);
INSERT INTO "django_geo_db_zipcode" VALUES(8784,21216,-5,'Baltimore, Maryland 21216',6367,7781);
INSERT INTO "django_geo_db_zipcode" VALUES(8785,21217,-5,'Baltimore, Maryland 21217',6367,7782);
INSERT INTO "django_geo_db_zipcode" VALUES(8786,21218,-5,'Baltimore, Maryland 21218',6367,7783);
INSERT INTO "django_geo_db_zipcode" VALUES(8787,21219,-5,'Sparrows Point, Maryland 21219',6371,7784);
INSERT INTO "django_geo_db_zipcode" VALUES(8788,21220,-5,'Middle River, Maryland 21220',6372,7785);
INSERT INTO "django_geo_db_zipcode" VALUES(8789,21221,-5,'Essex, Maryland 21221',6373,7786);
INSERT INTO "django_geo_db_zipcode" VALUES(8790,21222,-5,'Dundalk, Maryland 21222',6374,7787);
INSERT INTO "django_geo_db_zipcode" VALUES(8791,21223,-5,'Baltimore, Maryland 21223',6367,7788);
INSERT INTO "django_geo_db_zipcode" VALUES(8792,21224,-5,'Baltimore, Maryland 21224',6367,7789);
INSERT INTO "django_geo_db_zipcode" VALUES(8793,21225,-5,'Brooklyn, Maryland 21225',6375,7790);
INSERT INTO "django_geo_db_zipcode" VALUES(8794,21226,-5,'Curtis Bay, Maryland 21226',6376,7791);
INSERT INTO "django_geo_db_zipcode" VALUES(8795,21227,-5,'Halethorpe, Maryland 21227',6377,7792);
INSERT INTO "django_geo_db_zipcode" VALUES(8796,21228,-5,'Catonsville, Maryland 21228',6378,7793);
INSERT INTO "django_geo_db_zipcode" VALUES(8797,21229,-5,'Baltimore, Maryland 21229',6367,7794);
INSERT INTO "django_geo_db_zipcode" VALUES(8798,21230,-5,'Baltimore, Maryland 21230',6367,7795);
INSERT INTO "django_geo_db_zipcode" VALUES(8799,21231,-5,'Baltimore, Maryland 21231',6367,7796);
INSERT INTO "django_geo_db_zipcode" VALUES(8800,21233,-5,'Baltimore, Maryland 21233',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8801,21234,-5,'Parkville, Maryland 21234',6379,7797);
INSERT INTO "django_geo_db_zipcode" VALUES(8802,21235,-5,'Baltimore, Maryland 21235',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8803,21236,-5,'Nottingham, Maryland 21236',6380,7798);
INSERT INTO "django_geo_db_zipcode" VALUES(8804,21237,-5,'Rosedale, Maryland 21237',6381,7799);
INSERT INTO "django_geo_db_zipcode" VALUES(8805,21239,-5,'Baltimore, Maryland 21239',6367,7800);
INSERT INTO "django_geo_db_zipcode" VALUES(8806,21240,-5,'Baltimore, Maryland 21240',6367,7801);
INSERT INTO "django_geo_db_zipcode" VALUES(8807,21241,-5,'Baltimore, Maryland 21241',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8808,21244,-5,'Windsor Mill, Maryland 21244',6382,7802);
INSERT INTO "django_geo_db_zipcode" VALUES(8809,21250,-5,'Baltimore, Maryland 21250',6367,7803);
INSERT INTO "django_geo_db_zipcode" VALUES(8810,21251,-5,'Baltimore, Maryland 21251',6367,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8811,21252,-5,'Baltimore, Maryland 21252',6367,7804);
INSERT INTO "django_geo_db_zipcode" VALUES(8812,21260,-5,'Baltimore, Maryland 21260',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8813,21263,-5,'Baltimore, Maryland 21263',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8814,21264,-5,'Baltimore, Maryland 21264',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8815,21265,-5,'Baltimore, Maryland 21265',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8816,21268,-5,'Baltimore, Maryland 21268',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8817,21270,-5,'Baltimore, Maryland 21270',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8818,21273,-5,'Baltimore, Maryland 21273',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8819,21274,-5,'Baltimore, Maryland 21274',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8820,21275,-5,'Baltimore, Maryland 21275',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8821,21278,-5,'Baltimore, Maryland 21278',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8822,21279,-5,'Baltimore, Maryland 21279',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8823,21280,-5,'Baltimore, Maryland 21280',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8824,21281,-5,'Baltimore, Maryland 21281',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8825,21282,-5,'Baltimore, Maryland 21282',6367,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8826,21283,-5,'Baltimore, Maryland 21283',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8827,21284,-5,'Baltimore, Maryland 21284',6367,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8828,21285,-5,'Baltimore, Maryland 21285',6367,7692);
INSERT INTO "django_geo_db_zipcode" VALUES(8829,21286,-5,'Towson, Maryland 21286',6368,7805);
INSERT INTO "django_geo_db_zipcode" VALUES(8830,21287,-5,'Baltimore, Maryland 21287',6367,7806);
INSERT INTO "django_geo_db_zipcode" VALUES(8831,21288,-5,'Baltimore, Maryland 21288',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8832,21289,-5,'Baltimore, Maryland 21289',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8833,21290,-5,'Baltimore, Maryland 21290',6367,7807);
INSERT INTO "django_geo_db_zipcode" VALUES(8834,21297,-5,'Baltimore, Maryland 21297',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8835,21298,-5,'Baltimore, Maryland 21298',6367,7768);
INSERT INTO "django_geo_db_zipcode" VALUES(8836,21401,-5,'Annapolis, Maryland 21401',6383,7808);
INSERT INTO "django_geo_db_zipcode" VALUES(8837,21402,-5,'Annapolis, Maryland 21402',6383,7809);
INSERT INTO "django_geo_db_zipcode" VALUES(8838,21403,-5,'Annapolis, Maryland 21403',6383,7810);
INSERT INTO "django_geo_db_zipcode" VALUES(8839,21404,-5,'Annapolis, Maryland 21404',6383,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8840,21405,-5,'Annapolis, Maryland 21405',6383,7811);
INSERT INTO "django_geo_db_zipcode" VALUES(8841,21411,-5,'Annapolis, Maryland 21411',6383,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8842,21412,-5,'Annapolis, Maryland 21412',6383,7720);
INSERT INTO "django_geo_db_zipcode" VALUES(8843,21501,-5,'Cumberland, Maryland 21501',6384,7812);
INSERT INTO "django_geo_db_zipcode" VALUES(8844,21502,-5,'Cumberland, Maryland 21502',6384,7813);
INSERT INTO "django_geo_db_zipcode" VALUES(8845,21503,-5,'Cumberland, Maryland 21503',6384,7812);
INSERT INTO "django_geo_db_zipcode" VALUES(8846,21504,-5,'Cumberland, Maryland 21504',6384,7812);
INSERT INTO "django_geo_db_zipcode" VALUES(8847,21505,-5,'Cumberland, Maryland 21505',6384,7814);
INSERT INTO "django_geo_db_zipcode" VALUES(8848,21520,-5,'Accident, Maryland 21520',6385,7815);
INSERT INTO "django_geo_db_zipcode" VALUES(8849,21521,-5,'Barton, Maryland 21521',6386,7816);
INSERT INTO "django_geo_db_zipcode" VALUES(8850,21522,-5,'Bittinger, Maryland 21522',6387,7817);
INSERT INTO "django_geo_db_zipcode" VALUES(8851,21523,-5,'Bloomington, Maryland 21523',6388,7818);
INSERT INTO "django_geo_db_zipcode" VALUES(8852,21524,-5,'Corriganville, Maryland 21524',6389,7819);
INSERT INTO "django_geo_db_zipcode" VALUES(8853,21528,-5,'Eckhart Mines, Maryland 21528',6390,7820);
INSERT INTO "django_geo_db_zipcode" VALUES(8854,21529,-5,'Ellerslie, Maryland 21529',6391,7821);
INSERT INTO "django_geo_db_zipcode" VALUES(8855,21530,-5,'Flintstone, Maryland 21530',6392,7822);
INSERT INTO "django_geo_db_zipcode" VALUES(8856,21531,-5,'Friendsville, Maryland 21531',6393,7823);
INSERT INTO "django_geo_db_zipcode" VALUES(8857,21532,-5,'Frostburg, Maryland 21532',6394,7824);
INSERT INTO "django_geo_db_zipcode" VALUES(8858,21536,-5,'Grantsville, Maryland 21536',6395,7825);
INSERT INTO "django_geo_db_zipcode" VALUES(8859,21538,-5,'Kitzmiller, Maryland 21538',6396,7826);
INSERT INTO "django_geo_db_zipcode" VALUES(8860,21539,-5,'Lonaconing, Maryland 21539',6397,7827);
INSERT INTO "django_geo_db_zipcode" VALUES(8861,21540,-5,'Luke, Maryland 21540',6398,7828);
INSERT INTO "django_geo_db_zipcode" VALUES(8862,21541,-5,'McHenry, Maryland 21541',6399,7829);
INSERT INTO "django_geo_db_zipcode" VALUES(8863,21542,-5,'Midland, Maryland 21542',6400,7830);
INSERT INTO "django_geo_db_zipcode" VALUES(8864,21543,-5,'Midlothian, Maryland 21543',6401,7831);
INSERT INTO "django_geo_db_zipcode" VALUES(8865,21545,-5,'Mount Savage, Maryland 21545',6402,7832);
INSERT INTO "django_geo_db_zipcode" VALUES(8866,21550,-5,'Oakland, Maryland 21550',6403,7833);
INSERT INTO "django_geo_db_zipcode" VALUES(8867,21555,-5,'Oldtown, Maryland 21555',6404,7834);
INSERT INTO "django_geo_db_zipcode" VALUES(8868,21556,-5,'Pinto, Maryland 21556',6405,7835);
INSERT INTO "django_geo_db_zipcode" VALUES(8869,21557,-5,'Rawlings, Maryland 21557',6406,7836);
INSERT INTO "django_geo_db_zipcode" VALUES(8870,21560,-5,'Spring Gap, Maryland 21560',6407,7837);
INSERT INTO "django_geo_db_zipcode" VALUES(8871,21561,-5,'Swanton, Maryland 21561',6408,7838);
INSERT INTO "django_geo_db_zipcode" VALUES(8872,21562,-5,'Westernport, Maryland 21562',6409,7839);
INSERT INTO "django_geo_db_zipcode" VALUES(8873,21601,-5,'Easton, Maryland 21601',6410,7840);
INSERT INTO "django_geo_db_zipcode" VALUES(8874,21606,-5,'Easton, Maryland 21606',6410,7841);
INSERT INTO "django_geo_db_zipcode" VALUES(8875,21607,-5,'Barclay, Maryland 21607',6411,7842);
INSERT INTO "django_geo_db_zipcode" VALUES(8876,21609,-5,'Bethlehem, Maryland 21609',6412,7843);
INSERT INTO "django_geo_db_zipcode" VALUES(8877,21610,-5,'Betterton, Maryland 21610',6413,7844);
INSERT INTO "django_geo_db_zipcode" VALUES(8878,21612,-5,'Bozman, Maryland 21612',6414,7845);
INSERT INTO "django_geo_db_zipcode" VALUES(8879,21613,-5,'Cambridge, Maryland 21613',6415,7846);
INSERT INTO "django_geo_db_zipcode" VALUES(8880,21617,-5,'Centreville, Maryland 21617',6416,7847);
INSERT INTO "django_geo_db_zipcode" VALUES(8881,21619,-5,'Chester, Maryland 21619',6417,7848);
INSERT INTO "django_geo_db_zipcode" VALUES(8882,21620,-5,'Chestertown, Maryland 21620',6418,7849);
INSERT INTO "django_geo_db_zipcode" VALUES(8883,21622,-5,'Church Creek, Maryland 21622',6419,7850);
INSERT INTO "django_geo_db_zipcode" VALUES(8884,21623,-5,'Church Hill, Maryland 21623',6420,7851);
INSERT INTO "django_geo_db_zipcode" VALUES(8885,21624,-5,'Claiborne, Maryland 21624',6421,7852);
INSERT INTO "django_geo_db_zipcode" VALUES(8886,21625,-5,'Cordova, Maryland 21625',6422,7853);
INSERT INTO "django_geo_db_zipcode" VALUES(8887,21626,-5,'Crapo, Maryland 21626',6423,7854);
INSERT INTO "django_geo_db_zipcode" VALUES(8888,21627,-5,'Crocheron, Maryland 21627',6424,7855);
INSERT INTO "django_geo_db_zipcode" VALUES(8889,21628,-5,'Crumpton, Maryland 21628',6425,7856);
INSERT INTO "django_geo_db_zipcode" VALUES(8890,21629,-5,'Denton, Maryland 21629',6426,7857);
INSERT INTO "django_geo_db_zipcode" VALUES(8891,21631,-5,'East New Market, Maryland 21631',6427,7858);
INSERT INTO "django_geo_db_zipcode" VALUES(8892,21632,-5,'Federalsburg, Maryland 21632',6428,7859);
INSERT INTO "django_geo_db_zipcode" VALUES(8893,21634,-5,'Fishing Creek, Maryland 21634',6429,7860);
INSERT INTO "django_geo_db_zipcode" VALUES(8894,21635,-5,'Galena, Maryland 21635',6430,7861);
INSERT INTO "django_geo_db_zipcode" VALUES(8895,21636,-5,'Goldsboro, Maryland 21636',6431,7862);
INSERT INTO "django_geo_db_zipcode" VALUES(8896,21638,-5,'Grasonville, Maryland 21638',6432,7863);
INSERT INTO "django_geo_db_zipcode" VALUES(8897,21639,-5,'Greensboro, Maryland 21639',6433,7864);
INSERT INTO "django_geo_db_zipcode" VALUES(8898,21640,-5,'Henderson, Maryland 21640',6434,7865);
INSERT INTO "django_geo_db_zipcode" VALUES(8899,21641,-5,'Hillsboro, Maryland 21641',6435,7866);
INSERT INTO "django_geo_db_zipcode" VALUES(8900,21643,-5,'Hurlock, Maryland 21643',6436,7867);
INSERT INTO "django_geo_db_zipcode" VALUES(8901,21644,-5,'Ingleside, Maryland 21644',6437,7868);
INSERT INTO "django_geo_db_zipcode" VALUES(8902,21645,-5,'Kennedyville, Maryland 21645',6438,7869);
INSERT INTO "django_geo_db_zipcode" VALUES(8903,21647,-5,'Mcdaniel, Maryland 21647',6439,7870);
INSERT INTO "django_geo_db_zipcode" VALUES(8904,21648,-5,'Madison, Maryland 21648',6440,7871);
INSERT INTO "django_geo_db_zipcode" VALUES(8905,21649,-5,'Marydel, Maryland 21649',6441,7872);
INSERT INTO "django_geo_db_zipcode" VALUES(8906,21650,-5,'Massey, Maryland 21650',6442,7873);
INSERT INTO "django_geo_db_zipcode" VALUES(8907,21651,-5,'Millington, Maryland 21651',6443,7874);
INSERT INTO "django_geo_db_zipcode" VALUES(8908,21652,-5,'Neavitt, Maryland 21652',6444,7875);
INSERT INTO "django_geo_db_zipcode" VALUES(8909,21653,-5,'Newcomb, Maryland 21653',6445,7876);
INSERT INTO "django_geo_db_zipcode" VALUES(8910,21654,-5,'Oxford, Maryland 21654',6446,7877);
INSERT INTO "django_geo_db_zipcode" VALUES(8911,21655,-5,'Preston, Maryland 21655',6447,7878);
INSERT INTO "django_geo_db_zipcode" VALUES(8912,21656,-5,'Price, Maryland 21656',6448,7879);
INSERT INTO "django_geo_db_zipcode" VALUES(8913,21657,-5,'Queen Anne, Maryland 21657',6449,7880);
INSERT INTO "django_geo_db_zipcode" VALUES(8914,21658,-5,'Queenstown, Maryland 21658',6450,7881);
INSERT INTO "django_geo_db_zipcode" VALUES(8915,21659,-5,'Rhodesdale, Maryland 21659',6451,7882);
INSERT INTO "django_geo_db_zipcode" VALUES(8916,21660,-5,'Ridgely, Maryland 21660',6452,7883);
INSERT INTO "django_geo_db_zipcode" VALUES(8917,21661,-5,'Rock Hall, Maryland 21661',6453,7884);
INSERT INTO "django_geo_db_zipcode" VALUES(8918,21662,-5,'Royal Oak, Maryland 21662',6454,7885);
INSERT INTO "django_geo_db_zipcode" VALUES(8919,21663,-5,'Saint Michaels, Maryland 21663',6455,7886);
INSERT INTO "django_geo_db_zipcode" VALUES(8920,21664,-5,'Secretary, Maryland 21664',6456,7887);
INSERT INTO "django_geo_db_zipcode" VALUES(8921,21665,-5,'Sherwood, Maryland 21665',6457,7888);
INSERT INTO "django_geo_db_zipcode" VALUES(8922,21666,-5,'Stevensville, Maryland 21666',6458,7889);
INSERT INTO "django_geo_db_zipcode" VALUES(8923,21667,-5,'Still Pond, Maryland 21667',6459,7890);
INSERT INTO "django_geo_db_zipcode" VALUES(8924,21668,-5,'Sudlersville, Maryland 21668',6460,7891);
INSERT INTO "django_geo_db_zipcode" VALUES(8925,21669,-5,'Taylors Island, Maryland 21669',6461,7892);
INSERT INTO "django_geo_db_zipcode" VALUES(8926,21670,-5,'Templeville, Maryland 21670',6462,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8927,21671,-5,'Tilghman, Maryland 21671',6463,7894);
INSERT INTO "django_geo_db_zipcode" VALUES(8928,21672,-5,'Toddville, Maryland 21672',6464,7895);
INSERT INTO "django_geo_db_zipcode" VALUES(8929,21673,-5,'Trappe, Maryland 21673',6465,7896);
INSERT INTO "django_geo_db_zipcode" VALUES(8930,21675,-5,'Wingate, Maryland 21675',6466,7897);
INSERT INTO "django_geo_db_zipcode" VALUES(8931,21676,-5,'Wittman, Maryland 21676',6467,7898);
INSERT INTO "django_geo_db_zipcode" VALUES(8932,21677,-5,'Woolford, Maryland 21677',6468,7899);
INSERT INTO "django_geo_db_zipcode" VALUES(8933,21678,-5,'Worton, Maryland 21678',6469,7900);
INSERT INTO "django_geo_db_zipcode" VALUES(8934,21679,-5,'Wye Mills, Maryland 21679',6470,7901);
INSERT INTO "django_geo_db_zipcode" VALUES(8935,21681,-5,'Ridgely, Maryland 21681',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8936,21682,-5,'Ridgely, Maryland 21682',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8937,21683,-5,'Ridgely, Maryland 21683',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8938,21684,-5,'Ridgely, Maryland 21684',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8939,21685,-5,'Ridgely, Maryland 21685',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8940,21686,-5,'Ridgely, Maryland 21686',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8941,21687,-5,'Ridgely, Maryland 21687',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8942,21688,-5,'Ridgely, Maryland 21688',6452,7893);
INSERT INTO "django_geo_db_zipcode" VALUES(8943,21690,-5,'Chestertown, Maryland 21690',6418,7879);
INSERT INTO "django_geo_db_zipcode" VALUES(8944,21701,-5,'Frederick, Maryland 21701',6471,7902);
INSERT INTO "django_geo_db_zipcode" VALUES(8945,21702,-5,'Frederick, Maryland 21702',6471,7903);
INSERT INTO "django_geo_db_zipcode" VALUES(8946,21703,-5,'Frederick, Maryland 21703',6471,7904);
INSERT INTO "django_geo_db_zipcode" VALUES(8947,21704,-5,'Frederick, Maryland 21704',6471,7905);
INSERT INTO "django_geo_db_zipcode" VALUES(8948,21705,-5,'Frederick, Maryland 21705',6471,7906);
INSERT INTO "django_geo_db_zipcode" VALUES(8949,21709,-5,'Frederick, Maryland 21709',6471,7906);
INSERT INTO "django_geo_db_zipcode" VALUES(8950,21710,-5,'Adamstown, Maryland 21710',6472,7907);
INSERT INTO "django_geo_db_zipcode" VALUES(8951,21711,-5,'Big Pool, Maryland 21711',6473,7908);
INSERT INTO "django_geo_db_zipcode" VALUES(8952,21713,-5,'Boonsboro, Maryland 21713',6474,7909);
INSERT INTO "django_geo_db_zipcode" VALUES(8953,21714,-5,'Braddock Heights, Maryland 21714',6475,7910);
INSERT INTO "django_geo_db_zipcode" VALUES(8954,21715,-5,'Brownsville, Maryland 21715',6476,7911);
INSERT INTO "django_geo_db_zipcode" VALUES(8955,21716,-5,'Brunswick, Maryland 21716',6477,7912);
INSERT INTO "django_geo_db_zipcode" VALUES(8956,21717,-5,'Buckeystown, Maryland 21717',6478,7913);
INSERT INTO "django_geo_db_zipcode" VALUES(8957,21718,-5,'Burkittsville, Maryland 21718',6479,7914);
INSERT INTO "django_geo_db_zipcode" VALUES(8958,21719,-5,'Cascade, Maryland 21719',6480,7915);
INSERT INTO "django_geo_db_zipcode" VALUES(8959,21720,-5,'Cavetown, Maryland 21720',6481,7916);
INSERT INTO "django_geo_db_zipcode" VALUES(8960,21721,-5,'Chewsville, Maryland 21721',6482,7917);
INSERT INTO "django_geo_db_zipcode" VALUES(8961,21722,-5,'Clear Spring, Maryland 21722',6483,7918);
INSERT INTO "django_geo_db_zipcode" VALUES(8962,21723,-5,'Cooksville, Maryland 21723',6484,7919);
INSERT INTO "django_geo_db_zipcode" VALUES(8963,21727,-5,'Emmitsburg, Maryland 21727',6485,7920);
INSERT INTO "django_geo_db_zipcode" VALUES(8964,21733,-5,'Fairplay, Maryland 21733',6486,7921);
INSERT INTO "django_geo_db_zipcode" VALUES(8965,21734,-5,'Funkstown, Maryland 21734',6487,7922);
INSERT INTO "django_geo_db_zipcode" VALUES(8966,21736,-5,'Gapland, Maryland 21736',6488,7923);
INSERT INTO "django_geo_db_zipcode" VALUES(8967,21737,-5,'Glenelg, Maryland 21737',6489,7924);
INSERT INTO "django_geo_db_zipcode" VALUES(8968,21738,-5,'Glenwood, Maryland 21738',6490,7925);
INSERT INTO "django_geo_db_zipcode" VALUES(8969,21740,-5,'Hagerstown, Maryland 21740',6491,7926);
INSERT INTO "django_geo_db_zipcode" VALUES(8970,21741,-5,'Hagerstown, Maryland 21741',6491,7927);
INSERT INTO "django_geo_db_zipcode" VALUES(8971,21742,-5,'Hagerstown, Maryland 21742',6491,7928);
INSERT INTO "django_geo_db_zipcode" VALUES(8972,21746,-5,'Hagerstown, Maryland 21746',6491,7929);
INSERT INTO "django_geo_db_zipcode" VALUES(8973,21747,-5,'Hagerstown, Maryland 21747',6491,7923);
INSERT INTO "django_geo_db_zipcode" VALUES(8974,21748,-5,'Hagerstown, Maryland 21748',6491,7923);
INSERT INTO "django_geo_db_zipcode" VALUES(8975,21749,-5,'Hagerstown, Maryland 21749',6491,7923);
INSERT INTO "django_geo_db_zipcode" VALUES(8976,21750,-5,'Hancock, Maryland 21750',6492,7930);
INSERT INTO "django_geo_db_zipcode" VALUES(8977,21754,-5,'Ijamsville, Maryland 21754',6493,7931);
INSERT INTO "django_geo_db_zipcode" VALUES(8978,21755,-5,'Jefferson, Maryland 21755',6494,7932);
INSERT INTO "django_geo_db_zipcode" VALUES(8979,21756,-5,'Keedysville, Maryland 21756',6495,7933);
INSERT INTO "django_geo_db_zipcode" VALUES(8980,21757,-5,'Keymar, Maryland 21757',6496,7934);
INSERT INTO "django_geo_db_zipcode" VALUES(8981,21758,-5,'Knoxville, Maryland 21758',6497,7935);
INSERT INTO "django_geo_db_zipcode" VALUES(8982,21759,-5,'Ladiesburg, Maryland 21759',6498,7936);
INSERT INTO "django_geo_db_zipcode" VALUES(8983,21762,-5,'Libertytown, Maryland 21762',6499,7937);
INSERT INTO "django_geo_db_zipcode" VALUES(8984,21764,-5,'Linwood, Maryland 21764',6500,7727);
INSERT INTO "django_geo_db_zipcode" VALUES(8985,21765,-5,'Lisbon, Maryland 21765',6501,7938);
INSERT INTO "django_geo_db_zipcode" VALUES(8986,21766,-5,'Little Orleans, Maryland 21766',6502,7939);
INSERT INTO "django_geo_db_zipcode" VALUES(8987,21767,-5,'Maugansville, Maryland 21767',6503,7940);
INSERT INTO "django_geo_db_zipcode" VALUES(8988,21769,-5,'Middletown, Maryland 21769',6504,7941);
INSERT INTO "django_geo_db_zipcode" VALUES(8989,21770,-5,'Monrovia, Maryland 21770',6505,7942);
INSERT INTO "django_geo_db_zipcode" VALUES(8990,21771,-5,'Mount Airy, Maryland 21771',6506,7943);
INSERT INTO "django_geo_db_zipcode" VALUES(8991,21773,-5,'Myersville, Maryland 21773',6507,7944);
INSERT INTO "django_geo_db_zipcode" VALUES(8992,21774,-5,'New Market, Maryland 21774',6508,7945);
INSERT INTO "django_geo_db_zipcode" VALUES(8993,21775,-5,'New Midway, Maryland 21775',6509,7946);
INSERT INTO "django_geo_db_zipcode" VALUES(8994,21776,-5,'New Windsor, Maryland 21776',6366,7947);
INSERT INTO "django_geo_db_zipcode" VALUES(8995,21777,-5,'Point Of Rocks, Maryland 21777',6510,7948);
INSERT INTO "django_geo_db_zipcode" VALUES(8996,21778,-5,'Rocky Ridge, Maryland 21778',6511,7949);
INSERT INTO "django_geo_db_zipcode" VALUES(8997,21779,-5,'Rohrersville, Maryland 21779',6512,7950);
INSERT INTO "django_geo_db_zipcode" VALUES(8998,21780,-5,'Sabillasville, Maryland 21780',6513,7951);
INSERT INTO "django_geo_db_zipcode" VALUES(8999,21781,-5,'Saint James, Maryland 21781',6514,7952);
INSERT INTO "django_geo_db_zipcode" VALUES(9000,21782,-5,'Sharpsburg, Maryland 21782',6515,7953);
INSERT INTO "django_geo_db_zipcode" VALUES(9001,21783,-5,'Smithsburg, Maryland 21783',6516,7954);
INSERT INTO "django_geo_db_zipcode" VALUES(9002,21784,-5,'Sykesville, Maryland 21784',6517,7955);
INSERT INTO "django_geo_db_zipcode" VALUES(9003,21787,-5,'Taneytown, Maryland 21787',6518,7956);
INSERT INTO "django_geo_db_zipcode" VALUES(9004,21788,-5,'Thurmont, Maryland 21788',6519,7957);
INSERT INTO "django_geo_db_zipcode" VALUES(9005,21790,-5,'Tuscarora, Maryland 21790',6520,7958);
INSERT INTO "django_geo_db_zipcode" VALUES(9006,21791,-5,'Union Bridge, Maryland 21791',6521,7959);
INSERT INTO "django_geo_db_zipcode" VALUES(9007,21792,-5,'Unionville, Maryland 21792',6522,7906);
INSERT INTO "django_geo_db_zipcode" VALUES(9008,21793,-5,'Walkersville, Maryland 21793',6523,7960);
INSERT INTO "django_geo_db_zipcode" VALUES(9009,21794,-5,'West Friendship, Maryland 21794',6524,7961);
INSERT INTO "django_geo_db_zipcode" VALUES(9010,21795,-5,'Williamsport, Maryland 21795',6525,7962);
INSERT INTO "django_geo_db_zipcode" VALUES(9011,21797,-5,'Woodbine, Maryland 21797',6526,7963);
INSERT INTO "django_geo_db_zipcode" VALUES(9012,21798,-5,'Woodsboro, Maryland 21798',6527,7964);
INSERT INTO "django_geo_db_zipcode" VALUES(9013,21801,-5,'Salisbury, Maryland 21801',6528,7965);
INSERT INTO "django_geo_db_zipcode" VALUES(9014,21802,-5,'Salisbury, Maryland 21802',6528,7966);
INSERT INTO "django_geo_db_zipcode" VALUES(9015,21803,-5,'Salisbury, Maryland 21803',6528,7966);
INSERT INTO "django_geo_db_zipcode" VALUES(9016,21804,-5,'Salisbury, Maryland 21804',6528,7967);
INSERT INTO "django_geo_db_zipcode" VALUES(9017,21810,-5,'Allen, Maryland 21810',6529,7968);
INSERT INTO "django_geo_db_zipcode" VALUES(9018,21811,-5,'Berlin, Maryland 21811',6530,7969);
INSERT INTO "django_geo_db_zipcode" VALUES(9019,21813,-5,'Bishopville, Maryland 21813',6531,7970);
INSERT INTO "django_geo_db_zipcode" VALUES(9020,21814,-5,'Bivalve, Maryland 21814',6532,7971);
INSERT INTO "django_geo_db_zipcode" VALUES(9021,21817,-5,'Crisfield, Maryland 21817',6533,7972);
INSERT INTO "django_geo_db_zipcode" VALUES(9022,21821,-5,'Deal Island, Maryland 21821',6534,7973);
INSERT INTO "django_geo_db_zipcode" VALUES(9023,21822,-5,'Eden, Maryland 21822',6535,7974);
INSERT INTO "django_geo_db_zipcode" VALUES(9024,21824,-5,'Ewell, Maryland 21824',6536,7975);
INSERT INTO "django_geo_db_zipcode" VALUES(9025,21826,-5,'Fruitland, Maryland 21826',6537,7976);
INSERT INTO "django_geo_db_zipcode" VALUES(9026,21829,-5,'Girdletree, Maryland 21829',6538,7977);
INSERT INTO "django_geo_db_zipcode" VALUES(9027,21830,-5,'Hebron, Maryland 21830',6539,7978);
INSERT INTO "django_geo_db_zipcode" VALUES(9028,21831,-5,'Hebron, Maryland 21831',6539,7979);
INSERT INTO "django_geo_db_zipcode" VALUES(9029,21835,-5,'Linkwood, Maryland 21835',6540,7980);
INSERT INTO "django_geo_db_zipcode" VALUES(9030,21836,-5,'Manokin, Maryland 21836',6541,7981);
INSERT INTO "django_geo_db_zipcode" VALUES(9031,21837,-5,'Mardela Springs, Maryland 21837',6542,7982);
INSERT INTO "django_geo_db_zipcode" VALUES(9032,21838,-5,'Marion Station, Maryland 21838',6543,7983);
INSERT INTO "django_geo_db_zipcode" VALUES(9033,21840,-5,'Nanticoke, Maryland 21840',6544,7984);
INSERT INTO "django_geo_db_zipcode" VALUES(9034,21841,-5,'Newark, Maryland 21841',6545,7985);
INSERT INTO "django_geo_db_zipcode" VALUES(9035,21842,-5,'Ocean City, Maryland 21842',6546,7986);
INSERT INTO "django_geo_db_zipcode" VALUES(9036,21843,-5,'Ocean City, Maryland 21843',6546,7987);
INSERT INTO "django_geo_db_zipcode" VALUES(9037,21849,-5,'Parsonsburg, Maryland 21849',6547,7988);
INSERT INTO "django_geo_db_zipcode" VALUES(9038,21850,-5,'Pittsville, Maryland 21850',6548,7989);
INSERT INTO "django_geo_db_zipcode" VALUES(9039,21851,-5,'Pocomoke City, Maryland 21851',6549,7990);
INSERT INTO "django_geo_db_zipcode" VALUES(9040,21852,-5,'Powellville, Maryland 21852',6550,7966);
INSERT INTO "django_geo_db_zipcode" VALUES(9041,21853,-5,'Princess Anne, Maryland 21853',6551,7991);
INSERT INTO "django_geo_db_zipcode" VALUES(9042,21856,-5,'Quantico, Maryland 21856',6552,7992);
INSERT INTO "django_geo_db_zipcode" VALUES(9043,21857,-5,'Rehobeth, Maryland 21857',6553,7993);
INSERT INTO "django_geo_db_zipcode" VALUES(9044,21861,-5,'Sharptown, Maryland 21861',6554,7994);
INSERT INTO "django_geo_db_zipcode" VALUES(9045,21862,-5,'Showell, Maryland 21862',6555,7995);
INSERT INTO "django_geo_db_zipcode" VALUES(9046,21863,-5,'Snow Hill, Maryland 21863',6556,7996);
INSERT INTO "django_geo_db_zipcode" VALUES(9047,21864,-5,'Stockton, Maryland 21864',6557,7997);
INSERT INTO "django_geo_db_zipcode" VALUES(9048,21865,-5,'Tyaskin, Maryland 21865',6558,7998);
INSERT INTO "django_geo_db_zipcode" VALUES(9049,21866,-5,'Tylerton, Maryland 21866',6559,7999);
INSERT INTO "django_geo_db_zipcode" VALUES(9050,21867,-5,'Upper Fairmount, Maryland 21867',6560,8000);
INSERT INTO "django_geo_db_zipcode" VALUES(9051,21868,-5,'Fairmount, Maryland 21868',6561,8001);
INSERT INTO "django_geo_db_zipcode" VALUES(9052,21869,-5,'Vienna, Maryland 21869',6562,8002);
INSERT INTO "django_geo_db_zipcode" VALUES(9053,21870,-5,'Wenona, Maryland 21870',6563,7993);
INSERT INTO "django_geo_db_zipcode" VALUES(9054,21871,-5,'Westover, Maryland 21871',6564,8003);
INSERT INTO "django_geo_db_zipcode" VALUES(9055,21872,-5,'Whaleyville, Maryland 21872',6565,8004);
INSERT INTO "django_geo_db_zipcode" VALUES(9056,21874,-5,'Willards, Maryland 21874',6566,8005);
INSERT INTO "django_geo_db_zipcode" VALUES(9057,21875,-5,'Delmar, Maryland 21875',6567,8006);
INSERT INTO "django_geo_db_zipcode" VALUES(9058,21890,-5,'Westover, Maryland 21890',6564,7993);
INSERT INTO "django_geo_db_zipcode" VALUES(9059,21901,-5,'North East, Maryland 21901',6568,8007);
INSERT INTO "django_geo_db_zipcode" VALUES(9060,21902,-5,'Perry Point, Maryland 21902',6569,8008);
INSERT INTO "django_geo_db_zipcode" VALUES(9061,21903,-5,'Perryville, Maryland 21903',6570,8009);
INSERT INTO "django_geo_db_zipcode" VALUES(9062,21904,-5,'Port Deposit, Maryland 21904',6571,8010);
INSERT INTO "django_geo_db_zipcode" VALUES(9063,21911,-5,'Rising Sun, Maryland 21911',6572,8011);
INSERT INTO "django_geo_db_zipcode" VALUES(9064,21912,-5,'Warwick, Maryland 21912',6573,8012);
INSERT INTO "django_geo_db_zipcode" VALUES(9065,21913,-5,'Cecilton, Maryland 21913',6574,8013);
INSERT INTO "django_geo_db_zipcode" VALUES(9066,21914,-5,'Charlestown, Maryland 21914',6575,8014);
INSERT INTO "django_geo_db_zipcode" VALUES(9067,21915,-5,'Chesapeake City, Maryland 21915',6576,8015);
INSERT INTO "django_geo_db_zipcode" VALUES(9068,21916,-5,'Childs, Maryland 21916',6577,8016);
INSERT INTO "django_geo_db_zipcode" VALUES(9069,21917,-5,'Colora, Maryland 21917',6578,8017);
INSERT INTO "django_geo_db_zipcode" VALUES(9070,21918,-5,'Conowingo, Maryland 21918',6579,8018);
INSERT INTO "django_geo_db_zipcode" VALUES(9071,21919,-5,'Earleville, Maryland 21919',6580,8019);
INSERT INTO "django_geo_db_zipcode" VALUES(9072,21920,-5,'Elk Mills, Maryland 21920',6581,8020);
INSERT INTO "django_geo_db_zipcode" VALUES(9073,21921,-5,'Elkton, Maryland 21921',6582,8021);
INSERT INTO "django_geo_db_zipcode" VALUES(9074,21922,-5,'Elkton, Maryland 21922',6582,8022);
INSERT INTO "django_geo_db_zipcode" VALUES(9075,21930,-5,'Georgetown, Maryland 21930',6583,8023);
INSERT INTO "django_geo_db_zipcode" VALUES(9076,22002,-5,'Amissville, Virginia 22002',6109,8024);
INSERT INTO "django_geo_db_zipcode" VALUES(9077,22003,-5,'Annandale, Virginia 22003',6584,8025);
INSERT INTO "django_geo_db_zipcode" VALUES(9078,22009,-5,'Burke, Virginia 22009',6585,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9079,22015,-5,'Burke, Virginia 22015',6585,8026);
INSERT INTO "django_geo_db_zipcode" VALUES(9080,22026,-5,'Dumfries, Virginia 22026',6586,8027);
INSERT INTO "django_geo_db_zipcode" VALUES(9081,22027,-5,'Dunn Loring, Virginia 22027',6587,8028);
INSERT INTO "django_geo_db_zipcode" VALUES(9082,22030,-5,'Fairfax, Virginia 22030',6588,8029);
INSERT INTO "django_geo_db_zipcode" VALUES(9083,22031,-5,'Fairfax, Virginia 22031',6588,8030);
INSERT INTO "django_geo_db_zipcode" VALUES(9084,22032,-5,'Fairfax, Virginia 22032',6588,8031);
INSERT INTO "django_geo_db_zipcode" VALUES(9085,22033,-5,'Fairfax, Virginia 22033',6588,8032);
INSERT INTO "django_geo_db_zipcode" VALUES(9086,22034,-5,'Fairfax, Virginia 22034',6588,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9087,22035,-5,'Fairfax, Virginia 22035',6588,8033);
INSERT INTO "django_geo_db_zipcode" VALUES(9088,22036,-5,'Fairfax, Virginia 22036',6588,8034);
INSERT INTO "django_geo_db_zipcode" VALUES(9089,22037,-5,'Fairfax, Virginia 22037',6588,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9090,22038,-5,'Fairfax, Virginia 22038',6588,8035);
INSERT INTO "django_geo_db_zipcode" VALUES(9091,22039,-5,'Fairfax Station, Virginia 22039',6589,8036);
INSERT INTO "django_geo_db_zipcode" VALUES(9092,22040,-5,'Falls Church, Virginia 22040',6590,8037);
INSERT INTO "django_geo_db_zipcode" VALUES(9093,22041,-5,'Falls Church, Virginia 22041',6590,8038);
INSERT INTO "django_geo_db_zipcode" VALUES(9094,22042,-5,'Falls Church, Virginia 22042',6590,8039);
INSERT INTO "django_geo_db_zipcode" VALUES(9095,22043,-5,'Falls Church, Virginia 22043',6590,8040);
INSERT INTO "django_geo_db_zipcode" VALUES(9096,22044,-5,'Falls Church, Virginia 22044',6590,8041);
INSERT INTO "django_geo_db_zipcode" VALUES(9097,22046,-5,'Falls Church, Virginia 22046',6590,8042);
INSERT INTO "django_geo_db_zipcode" VALUES(9098,22047,-5,'Falls Church, Virginia 22047',6590,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9099,22060,-5,'Fort Belvoir, Virginia 22060',6591,8043);
INSERT INTO "django_geo_db_zipcode" VALUES(9100,22066,-5,'Great Falls, Virginia 22066',6592,8044);
INSERT INTO "django_geo_db_zipcode" VALUES(9101,22067,-5,'Greenway, Virginia 22067',6593,8045);
INSERT INTO "django_geo_db_zipcode" VALUES(9102,22079,-5,'Lorton, Virginia 22079',6594,8046);
INSERT INTO "django_geo_db_zipcode" VALUES(9103,22081,-5,'Merrifield, Virginia 22081',6595,8047);
INSERT INTO "django_geo_db_zipcode" VALUES(9104,22082,-5,'Merrifield, Virginia 22082',6595,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9105,22092,-5,'Herndon, Virginia 22092',6138,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9106,22093,-5,'Ashburn, Virginia 22093',6131,7373);
INSERT INTO "django_geo_db_zipcode" VALUES(9107,22095,-5,'Herndon, Virginia 22095',6138,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9108,22096,-5,'Reston, Virginia 22096',6144,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9109,22101,-5,'McLean, Virginia 22101',6596,8048);
INSERT INTO "django_geo_db_zipcode" VALUES(9110,22102,-5,'McLean, Virginia 22102',6596,8049);
INSERT INTO "django_geo_db_zipcode" VALUES(9111,22103,-5,'West Mclean, Virginia 22103',6597,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9112,22106,-5,'McLean, Virginia 22106',6596,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9113,22109,-5,'McLean, Virginia 22109',6596,8050);
INSERT INTO "django_geo_db_zipcode" VALUES(9114,22116,-5,'Merrifield, Virginia 22116',6595,8051);
INSERT INTO "django_geo_db_zipcode" VALUES(9115,22118,-5,'Merrifield, Virginia 22118',6595,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9116,22119,-5,'Merrifield, Virginia 22119',6595,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9117,22120,-5,'Merrifield, Virginia 22120',6595,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9118,22121,-5,'Mount Vernon, Virginia 22121',6598,8052);
INSERT INTO "django_geo_db_zipcode" VALUES(9119,22122,-5,'Newington, Virginia 22122',6599,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9120,22124,-5,'Oakton, Virginia 22124',6600,8053);
INSERT INTO "django_geo_db_zipcode" VALUES(9121,22125,-5,'Occoquan, Virginia 22125',6601,8054);
INSERT INTO "django_geo_db_zipcode" VALUES(9122,22134,-5,'Quantico, Virginia 22134',6602,8055);
INSERT INTO "django_geo_db_zipcode" VALUES(9123,22135,-5,'Quantico, Virginia 22135',6602,7414);
INSERT INTO "django_geo_db_zipcode" VALUES(9124,22150,-5,'Springfield, Virginia 22150',6603,8056);
INSERT INTO "django_geo_db_zipcode" VALUES(9125,22151,-5,'Springfield, Virginia 22151',6603,8057);
INSERT INTO "django_geo_db_zipcode" VALUES(9126,22152,-5,'Springfield, Virginia 22152',6603,8058);
INSERT INTO "django_geo_db_zipcode" VALUES(9127,22153,-5,'Springfield, Virginia 22153',6603,8059);
INSERT INTO "django_geo_db_zipcode" VALUES(9128,22156,-5,'Springfield, Virginia 22156',6603,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9129,22158,-5,'Springfield, Virginia 22158',6603,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9130,22159,-5,'Springfield, Virginia 22159',6603,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9131,22160,-5,'Springfield, Virginia 22160',6603,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9132,22161,-5,'Springfield, Virginia 22161',6603,8060);
INSERT INTO "django_geo_db_zipcode" VALUES(9133,22172,-5,'Triangle, Virginia 22172',6604,8061);
INSERT INTO "django_geo_db_zipcode" VALUES(9134,22180,-5,'Vienna, Virginia 22180',6605,8062);
INSERT INTO "django_geo_db_zipcode" VALUES(9135,22181,-5,'Vienna, Virginia 22181',6605,8063);
INSERT INTO "django_geo_db_zipcode" VALUES(9136,22182,-5,'Vienna, Virginia 22182',6605,8064);
INSERT INTO "django_geo_db_zipcode" VALUES(9137,22183,-5,'Vienna, Virginia 22183',6605,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9138,22184,-5,'Vienna, Virginia 22184',6605,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9139,22185,-5,'Vienna, Virginia 22185',6605,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9140,22191,-5,'Woodbridge, Virginia 22191',6606,8065);
INSERT INTO "django_geo_db_zipcode" VALUES(9141,22192,-5,'Woodbridge, Virginia 22192',6606,8066);
INSERT INTO "django_geo_db_zipcode" VALUES(9142,22193,-5,'Woodbridge, Virginia 22193',6606,8067);
INSERT INTO "django_geo_db_zipcode" VALUES(9143,22194,-5,'Woodbridge, Virginia 22194',6606,7414);
INSERT INTO "django_geo_db_zipcode" VALUES(9144,22195,-5,'Woodbridge, Virginia 22195',6606,7414);
INSERT INTO "django_geo_db_zipcode" VALUES(9145,22199,-5,'Lorton, Virginia 22199',6594,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9146,22201,-5,'Arlington, Virginia 22201',6607,8068);
INSERT INTO "django_geo_db_zipcode" VALUES(9147,22202,-5,'Arlington, Virginia 22202',6607,8069);
INSERT INTO "django_geo_db_zipcode" VALUES(9148,22203,-5,'Arlington, Virginia 22203',6607,8070);
INSERT INTO "django_geo_db_zipcode" VALUES(9149,22204,-5,'Arlington, Virginia 22204',6607,8071);
INSERT INTO "django_geo_db_zipcode" VALUES(9150,22205,-5,'Arlington, Virginia 22205',6607,8072);
INSERT INTO "django_geo_db_zipcode" VALUES(9151,22206,-5,'Arlington, Virginia 22206',6607,8073);
INSERT INTO "django_geo_db_zipcode" VALUES(9152,22207,-5,'Arlington, Virginia 22207',6607,8074);
INSERT INTO "django_geo_db_zipcode" VALUES(9153,22209,-5,'Arlington, Virginia 22209',6607,8075);
INSERT INTO "django_geo_db_zipcode" VALUES(9154,22210,-5,'Arlington, Virginia 22210',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9155,22211,-5,'Ft Myer, Virginia 22211',6608,8077);
INSERT INTO "django_geo_db_zipcode" VALUES(9156,22212,-5,'Arlington, Virginia 22212',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9157,22213,-5,'Arlington, Virginia 22213',6607,8078);
INSERT INTO "django_geo_db_zipcode" VALUES(9158,22214,-5,'Arlington, Virginia 22214',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9159,22215,-5,'Arlington, Virginia 22215',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9160,22216,-5,'Arlington, Virginia 22216',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9161,22217,-5,'Arlington, Virginia 22217',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9162,22218,-5,'Arlington, Virginia 22218',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9163,22219,-5,'Arlington, Virginia 22219',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9164,22222,-5,'Arlington, Virginia 22222',6607,8079);
INSERT INTO "django_geo_db_zipcode" VALUES(9165,22223,-5,'Arlington, Virginia 22223',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9166,22225,-5,'Arlington, Virginia 22225',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9167,22226,-5,'Arlington, Virginia 22226',6607,8080);
INSERT INTO "django_geo_db_zipcode" VALUES(9168,22227,-5,'Arlington, Virginia 22227',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9169,22229,-5,'Arlington, Virginia 22229',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9170,22230,-5,'Arlington, Virginia 22230',6607,8081);
INSERT INTO "django_geo_db_zipcode" VALUES(9171,22234,-5,'Arlington, Virginia 22234',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9172,22240,-5,'Arlington, Virginia 22240',6607,8082);
INSERT INTO "django_geo_db_zipcode" VALUES(9173,22241,-5,'Arlington, Virginia 22241',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9174,22242,-5,'Arlington, Virginia 22242',6607,8083);
INSERT INTO "django_geo_db_zipcode" VALUES(9175,22243,-5,'Arlington, Virginia 22243',6607,8084);
INSERT INTO "django_geo_db_zipcode" VALUES(9176,22244,-5,'Arlington, Virginia 22244',6607,8085);
INSERT INTO "django_geo_db_zipcode" VALUES(9177,22245,-5,'Arlington, Virginia 22245',6607,8086);
INSERT INTO "django_geo_db_zipcode" VALUES(9178,22246,-5,'Arlington, Virginia 22246',6607,8076);
INSERT INTO "django_geo_db_zipcode" VALUES(9179,22301,-5,'Alexandria, Virginia 22301',6609,8087);
INSERT INTO "django_geo_db_zipcode" VALUES(9180,22302,-5,'Alexandria, Virginia 22302',6609,8088);
INSERT INTO "django_geo_db_zipcode" VALUES(9181,22303,-5,'Alexandria, Virginia 22303',6609,8089);
INSERT INTO "django_geo_db_zipcode" VALUES(9182,22304,-5,'Alexandria, Virginia 22304',6609,8090);
INSERT INTO "django_geo_db_zipcode" VALUES(9183,22305,-5,'Alexandria, Virginia 22305',6609,8091);
INSERT INTO "django_geo_db_zipcode" VALUES(9184,22306,-5,'Alexandria, Virginia 22306',6609,8092);
INSERT INTO "django_geo_db_zipcode" VALUES(9185,22307,-5,'Alexandria, Virginia 22307',6609,8093);
INSERT INTO "django_geo_db_zipcode" VALUES(9186,22308,-5,'Alexandria, Virginia 22308',6609,8094);
INSERT INTO "django_geo_db_zipcode" VALUES(9187,22309,-5,'Alexandria, Virginia 22309',6609,8095);
INSERT INTO "django_geo_db_zipcode" VALUES(9188,22310,-5,'Alexandria, Virginia 22310',6609,8096);
INSERT INTO "django_geo_db_zipcode" VALUES(9189,22311,-5,'Alexandria, Virginia 22311',6609,8097);
INSERT INTO "django_geo_db_zipcode" VALUES(9190,22312,-5,'Alexandria, Virginia 22312',6609,8098);
INSERT INTO "django_geo_db_zipcode" VALUES(9191,22313,-5,'Alexandria, Virginia 22313',6609,8099);
INSERT INTO "django_geo_db_zipcode" VALUES(9192,22314,-5,'Alexandria, Virginia 22314',6609,8100);
INSERT INTO "django_geo_db_zipcode" VALUES(9193,22315,-5,'Alexandria, Virginia 22315',6609,8101);
INSERT INTO "django_geo_db_zipcode" VALUES(9194,22320,-5,'Alexandria, Virginia 22320',6609,8102);
INSERT INTO "django_geo_db_zipcode" VALUES(9195,22321,-5,'Alexandria, Virginia 22321',6609,7391);
INSERT INTO "django_geo_db_zipcode" VALUES(9196,22331,-5,'Alexandria, Virginia 22331',6609,8103);
INSERT INTO "django_geo_db_zipcode" VALUES(9197,22332,-5,'Alexandria, Virginia 22332',6609,8104);
INSERT INTO "django_geo_db_zipcode" VALUES(9198,22333,-5,'Alexandria, Virginia 22333',6609,8099);
INSERT INTO "django_geo_db_zipcode" VALUES(9199,22334,-5,'Alexandria, Virginia 22334',6609,8099);
INSERT INTO "django_geo_db_zipcode" VALUES(9200,22336,-5,'Alexandria, Virginia 22336',6609,8099);
INSERT INTO "django_geo_db_zipcode" VALUES(9201,22393,-5,'Fishersville, Virginia 22393',6610,8105);
INSERT INTO "django_geo_db_zipcode" VALUES(9202,22401,-5,'Fredericksburg, Virginia 22401',6611,8106);
INSERT INTO "django_geo_db_zipcode" VALUES(9203,22402,-5,'Fredericksburg, Virginia 22402',6611,8107);
INSERT INTO "django_geo_db_zipcode" VALUES(9204,22403,-5,'Fredericksburg, Virginia 22403',6611,8108);
INSERT INTO "django_geo_db_zipcode" VALUES(9205,22404,-5,'Fredericksburg, Virginia 22404',6611,8109);
INSERT INTO "django_geo_db_zipcode" VALUES(9206,22405,-5,'Fredericksburg, Virginia 22405',6611,8110);
INSERT INTO "django_geo_db_zipcode" VALUES(9207,22406,-5,'Fredericksburg, Virginia 22406',6611,8111);
INSERT INTO "django_geo_db_zipcode" VALUES(9208,22407,-5,'Fredericksburg, Virginia 22407',6611,8112);
INSERT INTO "django_geo_db_zipcode" VALUES(9209,22408,-5,'Fredericksburg, Virginia 22408',6611,8113);
INSERT INTO "django_geo_db_zipcode" VALUES(9210,22412,-5,'Fredericksburg, Virginia 22412',6611,8114);
INSERT INTO "django_geo_db_zipcode" VALUES(9211,22427,-5,'Bowling Green, Virginia 22427',6612,8115);
INSERT INTO "django_geo_db_zipcode" VALUES(9212,22428,-5,'Bowling Green, Virginia 22428',6612,8116);
INSERT INTO "django_geo_db_zipcode" VALUES(9213,22430,-5,'Brooke, Virginia 22430',6613,8117);
INSERT INTO "django_geo_db_zipcode" VALUES(9214,22432,-5,'Burgess, Virginia 22432',6614,8118);
INSERT INTO "django_geo_db_zipcode" VALUES(9215,22433,-5,'Burr Hill, Virginia 22433',6615,8119);
INSERT INTO "django_geo_db_zipcode" VALUES(9216,22435,-5,'Callao, Virginia 22435',6616,8120);
INSERT INTO "django_geo_db_zipcode" VALUES(9217,22436,-5,'Caret, Virginia 22436',6617,8121);
INSERT INTO "django_geo_db_zipcode" VALUES(9218,22437,-5,'Center Cross, Virginia 22437',6618,8122);
INSERT INTO "django_geo_db_zipcode" VALUES(9219,22438,-5,'Champlain, Virginia 22438',6619,8123);
INSERT INTO "django_geo_db_zipcode" VALUES(9220,22442,-5,'Coles Point, Virginia 22442',6620,8124);
INSERT INTO "django_geo_db_zipcode" VALUES(9221,22443,-5,'Colonial Beach, Virginia 22443',6621,8125);
INSERT INTO "django_geo_db_zipcode" VALUES(9222,22446,-5,'Corbin, Virginia 22446',6622,8126);
INSERT INTO "django_geo_db_zipcode" VALUES(9223,22448,-5,'Dahlgren, Virginia 22448',6623,8127);
INSERT INTO "django_geo_db_zipcode" VALUES(9224,22451,-5,'Dogue, Virginia 22451',6624,8128);
INSERT INTO "django_geo_db_zipcode" VALUES(9225,22454,-5,'Dunnsville, Virginia 22454',6625,8129);
INSERT INTO "django_geo_db_zipcode" VALUES(9226,22456,-5,'Edwardsville, Virginia 22456',6626,8130);
INSERT INTO "django_geo_db_zipcode" VALUES(9227,22460,-5,'Farnham, Virginia 22460',6627,8131);
INSERT INTO "django_geo_db_zipcode" VALUES(9228,22463,-5,'Garrisonville, Virginia 22463',6628,8132);
INSERT INTO "django_geo_db_zipcode" VALUES(9229,22469,-5,'Hague, Virginia 22469',6629,8133);
INSERT INTO "django_geo_db_zipcode" VALUES(9230,22471,-5,'Hartwood, Virginia 22471',6630,8134);
INSERT INTO "django_geo_db_zipcode" VALUES(9231,22472,-5,'Haynesville, Virginia 22472',6631,8135);
INSERT INTO "django_geo_db_zipcode" VALUES(9232,22473,-5,'Heathsville, Virginia 22473',6632,8136);
INSERT INTO "django_geo_db_zipcode" VALUES(9233,22476,-5,'Hustle, Virginia 22476',6633,8137);
INSERT INTO "django_geo_db_zipcode" VALUES(9234,22480,-5,'Irvington, Virginia 22480',6634,8138);
INSERT INTO "django_geo_db_zipcode" VALUES(9235,22481,-5,'Jersey, Virginia 22481',6635,8128);
INSERT INTO "django_geo_db_zipcode" VALUES(9236,22482,-5,'Kilmarnock, Virginia 22482',6636,8139);
INSERT INTO "django_geo_db_zipcode" VALUES(9237,22485,-5,'King George, Virginia 22485',6637,8140);
INSERT INTO "django_geo_db_zipcode" VALUES(9238,22486,-5,'Irvington, Virginia 22486',6634,8141);
INSERT INTO "django_geo_db_zipcode" VALUES(9239,22488,-5,'Kinsale, Virginia 22488',6638,8142);
INSERT INTO "django_geo_db_zipcode" VALUES(9240,22501,-5,'Ladysmith, Virginia 22501',6639,8143);
INSERT INTO "django_geo_db_zipcode" VALUES(9241,22503,-5,'Lancaster, Virginia 22503',6640,8144);
INSERT INTO "django_geo_db_zipcode" VALUES(9242,22504,-5,'Laneview, Virginia 22504',6641,8145);
INSERT INTO "django_geo_db_zipcode" VALUES(9243,22507,-5,'Lively, Virginia 22507',6642,8146);
INSERT INTO "django_geo_db_zipcode" VALUES(9244,22508,-5,'Locust Grove, Virginia 22508',6643,8147);
INSERT INTO "django_geo_db_zipcode" VALUES(9245,22509,-5,'Loretto, Virginia 22509',6644,8148);
INSERT INTO "django_geo_db_zipcode" VALUES(9246,22511,-5,'Lottsburg, Virginia 22511',6645,8149);
INSERT INTO "django_geo_db_zipcode" VALUES(9247,22513,-5,'Merry Point, Virginia 22513',6646,8150);
INSERT INTO "django_geo_db_zipcode" VALUES(9248,22514,-5,'Milford, Virginia 22514',6647,8151);
INSERT INTO "django_geo_db_zipcode" VALUES(9249,22517,-5,'Mollusk, Virginia 22517',6648,8152);
INSERT INTO "django_geo_db_zipcode" VALUES(9250,22520,-5,'Montross, Virginia 22520',6649,8153);
INSERT INTO "django_geo_db_zipcode" VALUES(9251,22523,-5,'Morattico, Virginia 22523',6650,8154);
INSERT INTO "django_geo_db_zipcode" VALUES(9252,22524,-5,'Mount Holly, Virginia 22524',6651,8155);
INSERT INTO "django_geo_db_zipcode" VALUES(9253,22526,-5,'Ninde, Virginia 22526',6652,8128);
INSERT INTO "django_geo_db_zipcode" VALUES(9254,22528,-5,'Nuttsville, Virginia 22528',6653,8156);
INSERT INTO "django_geo_db_zipcode" VALUES(9255,22529,-5,'Oldhams, Virginia 22529',6654,8157);
INSERT INTO "django_geo_db_zipcode" VALUES(9256,22530,-5,'Ophelia, Virginia 22530',6655,8158);
INSERT INTO "django_geo_db_zipcode" VALUES(9257,22534,-5,'Partlow, Virginia 22534',6656,8159);
INSERT INTO "django_geo_db_zipcode" VALUES(9258,22535,-5,'Port Royal, Virginia 22535',6657,8160);
INSERT INTO "django_geo_db_zipcode" VALUES(9259,22538,-5,'Rappahannock Academy, Virginia 22538',6658,8161);
INSERT INTO "django_geo_db_zipcode" VALUES(9260,22539,-5,'Reedville, Virginia 22539',6659,8162);
INSERT INTO "django_geo_db_zipcode" VALUES(9261,22542,-5,'Rhoadesville, Virginia 22542',6660,8163);
INSERT INTO "django_geo_db_zipcode" VALUES(9262,22544,-5,'Rollins Fork, Virginia 22544',6661,8128);
INSERT INTO "django_geo_db_zipcode" VALUES(9263,22545,-5,'Ruby, Virginia 22545',6662,8164);
INSERT INTO "django_geo_db_zipcode" VALUES(9264,22546,-5,'Ruther Glen, Virginia 22546',6663,8165);
INSERT INTO "django_geo_db_zipcode" VALUES(9265,22547,-5,'Sealston, Virginia 22547',6664,8128);
INSERT INTO "django_geo_db_zipcode" VALUES(9266,22548,-5,'Sharps, Virginia 22548',6665,8166);
INSERT INTO "django_geo_db_zipcode" VALUES(9267,22552,-5,'Sparta, Virginia 22552',6666,8167);
INSERT INTO "django_geo_db_zipcode" VALUES(9268,22553,-5,'Spotsylvania, Virginia 22553',6667,8168);
INSERT INTO "django_geo_db_zipcode" VALUES(9269,22554,-5,'Stafford, Virginia 22554',6668,8169);
INSERT INTO "django_geo_db_zipcode" VALUES(9270,22555,-5,'Stafford, Virginia 22555',6668,8108);
INSERT INTO "django_geo_db_zipcode" VALUES(9271,22558,-5,'Stratford, Virginia 22558',6669,8124);
INSERT INTO "django_geo_db_zipcode" VALUES(9272,22560,-5,'Tappahannock, Virginia 22560',6670,8170);
INSERT INTO "django_geo_db_zipcode" VALUES(9273,22565,-5,'Thornburg, Virginia 22565',6671,8171);
INSERT INTO "django_geo_db_zipcode" VALUES(9274,22567,-5,'Unionville, Virginia 22567',6672,8172);
INSERT INTO "django_geo_db_zipcode" VALUES(9275,22570,-5,'Village, Virginia 22570',6673,8173);
INSERT INTO "django_geo_db_zipcode" VALUES(9276,22572,-5,'Warsaw, Virginia 22572',6674,8174);
INSERT INTO "django_geo_db_zipcode" VALUES(9277,22576,-5,'Weems, Virginia 22576',6675,8175);
INSERT INTO "django_geo_db_zipcode" VALUES(9278,22577,-5,'Sandy Point, Virginia 22577',6676,8176);
INSERT INTO "django_geo_db_zipcode" VALUES(9279,22578,-5,'White Stone, Virginia 22578',6677,8177);
INSERT INTO "django_geo_db_zipcode" VALUES(9280,22579,-5,'Wicomico Church, Virginia 22579',6678,8178);
INSERT INTO "django_geo_db_zipcode" VALUES(9281,22580,-5,'Woodford, Virginia 22580',6679,8179);
INSERT INTO "django_geo_db_zipcode" VALUES(9282,22581,-5,'Zacata, Virginia 22581',6680,8124);
INSERT INTO "django_geo_db_zipcode" VALUES(9283,22601,-5,'Winchester, Virginia 22601',6681,8180);
INSERT INTO "django_geo_db_zipcode" VALUES(9284,22602,-5,'Winchester, Virginia 22602',6681,8181);
INSERT INTO "django_geo_db_zipcode" VALUES(9285,22603,-5,'Winchester, Virginia 22603',6681,8182);
INSERT INTO "django_geo_db_zipcode" VALUES(9286,22604,-5,'Winchester, Virginia 22604',6681,8183);
INSERT INTO "django_geo_db_zipcode" VALUES(9287,22606,-5,'Newport News, Virginia 22606',6682,8184);
INSERT INTO "django_geo_db_zipcode" VALUES(9288,22610,-5,'Bentonville, Virginia 22610',6683,8185);
INSERT INTO "django_geo_db_zipcode" VALUES(9289,22611,-5,'Berryville, Virginia 22611',6684,8186);
INSERT INTO "django_geo_db_zipcode" VALUES(9290,22620,-5,'Boyce, Virginia 22620',6685,8187);
INSERT INTO "django_geo_db_zipcode" VALUES(9291,22622,-5,'Brucetown, Virginia 22622',6686,8188);
INSERT INTO "django_geo_db_zipcode" VALUES(9292,22623,-5,'Chester Gap, Virginia 22623',6687,8189);
INSERT INTO "django_geo_db_zipcode" VALUES(9293,22624,-5,'Clear Brook, Virginia 22624',6688,8190);
INSERT INTO "django_geo_db_zipcode" VALUES(9294,22625,-5,'Cross Junction, Virginia 22625',6689,8191);
INSERT INTO "django_geo_db_zipcode" VALUES(9295,22626,-5,'Fishers Hill, Virginia 22626',6690,8192);
INSERT INTO "django_geo_db_zipcode" VALUES(9296,22627,-5,'Flint Hill, Virginia 22627',6691,8193);
INSERT INTO "django_geo_db_zipcode" VALUES(9297,22630,-5,'Front Royal, Virginia 22630',6692,8194);
INSERT INTO "django_geo_db_zipcode" VALUES(9298,22637,-5,'Gore, Virginia 22637',6693,8195);
INSERT INTO "django_geo_db_zipcode" VALUES(9299,22638,-5,'Winchester, Virginia 22638',6681,8196);
INSERT INTO "django_geo_db_zipcode" VALUES(9300,22639,-5,'Hume, Virginia 22639',6694,8197);
INSERT INTO "django_geo_db_zipcode" VALUES(9301,22640,-5,'Huntly, Virginia 22640',6695,8198);
INSERT INTO "django_geo_db_zipcode" VALUES(9302,22641,-5,'Strasburg, Virginia 22641',6696,8199);
INSERT INTO "django_geo_db_zipcode" VALUES(9303,22642,-5,'Linden, Virginia 22642',6697,8200);
INSERT INTO "django_geo_db_zipcode" VALUES(9304,22643,-5,'Markham, Virginia 22643',6698,8201);
INSERT INTO "django_geo_db_zipcode" VALUES(9305,22644,-5,'Maurertown, Virginia 22644',6699,8202);
INSERT INTO "django_geo_db_zipcode" VALUES(9306,22645,-5,'Middletown, Virginia 22645',6700,8203);
INSERT INTO "django_geo_db_zipcode" VALUES(9307,22646,-5,'Millwood, Virginia 22646',6701,8204);
INSERT INTO "django_geo_db_zipcode" VALUES(9308,22649,-5,'Middletown, Virginia 22649',6700,8205);
INSERT INTO "django_geo_db_zipcode" VALUES(9309,22650,-5,'Rileyville, Virginia 22650',6702,8206);
INSERT INTO "django_geo_db_zipcode" VALUES(9310,22651,-5,'Front Royal, Virginia 22651',6692,8207);
INSERT INTO "django_geo_db_zipcode" VALUES(9311,22652,-5,'Fort Valley, Virginia 22652',6703,8208);
INSERT INTO "django_geo_db_zipcode" VALUES(9312,22654,-5,'Star Tannery, Virginia 22654',6704,8209);
INSERT INTO "django_geo_db_zipcode" VALUES(9313,22655,-5,'Stephens City, Virginia 22655',6705,8210);
INSERT INTO "django_geo_db_zipcode" VALUES(9314,22656,-5,'Stephenson, Virginia 22656',6706,8211);
INSERT INTO "django_geo_db_zipcode" VALUES(9315,22657,-5,'Strasburg, Virginia 22657',6696,8212);
INSERT INTO "django_geo_db_zipcode" VALUES(9316,22660,-5,'Toms Brook, Virginia 22660',6707,8213);
INSERT INTO "django_geo_db_zipcode" VALUES(9317,22663,-5,'White Post, Virginia 22663',6708,8214);
INSERT INTO "django_geo_db_zipcode" VALUES(9318,22664,-5,'Woodstock, Virginia 22664',6709,8215);
INSERT INTO "django_geo_db_zipcode" VALUES(9319,22701,-5,'Culpeper, Virginia 22701',6710,8216);
INSERT INTO "django_geo_db_zipcode" VALUES(9320,22709,-5,'Aroda, Virginia 22709',6711,8217);
INSERT INTO "django_geo_db_zipcode" VALUES(9321,22711,-5,'Banco, Virginia 22711',6712,8218);
INSERT INTO "django_geo_db_zipcode" VALUES(9322,22712,-5,'Bealeton, Virginia 22712',6713,8219);
INSERT INTO "django_geo_db_zipcode" VALUES(9323,22713,-5,'Boston, Virginia 22713',6714,8220);
INSERT INTO "django_geo_db_zipcode" VALUES(9324,22714,-5,'Brandy Station, Virginia 22714',6715,8221);
INSERT INTO "django_geo_db_zipcode" VALUES(9325,22715,-5,'Brightwood, Virginia 22715',6716,8222);
INSERT INTO "django_geo_db_zipcode" VALUES(9326,22716,-5,'Castleton, Virginia 22716',6717,8223);
INSERT INTO "django_geo_db_zipcode" VALUES(9327,22718,-5,'Elkwood, Virginia 22718',6718,8224);
INSERT INTO "django_geo_db_zipcode" VALUES(9328,22719,-5,'Etlan, Virginia 22719',6719,8225);
INSERT INTO "django_geo_db_zipcode" VALUES(9329,22720,-5,'Goldvein, Virginia 22720',6720,8226);
INSERT INTO "django_geo_db_zipcode" VALUES(9330,22721,-5,'Graves Mill, Virginia 22721',6721,8227);
INSERT INTO "django_geo_db_zipcode" VALUES(9331,22722,-5,'Haywood, Virginia 22722',6722,8228);
INSERT INTO "django_geo_db_zipcode" VALUES(9332,22723,-5,'Hood, Virginia 22723',6723,8229);
INSERT INTO "django_geo_db_zipcode" VALUES(9333,22724,-5,'Jeffersonton, Virginia 22724',6724,8230);
INSERT INTO "django_geo_db_zipcode" VALUES(9334,22725,-5,'Leon, Virginia 22725',6725,8227);
INSERT INTO "django_geo_db_zipcode" VALUES(9335,22726,-5,'Lignum, Virginia 22726',6726,8231);
INSERT INTO "django_geo_db_zipcode" VALUES(9336,22727,-5,'Madison, Virginia 22727',6727,8232);
INSERT INTO "django_geo_db_zipcode" VALUES(9337,22728,-5,'Midland, Virginia 22728',6728,8233);
INSERT INTO "django_geo_db_zipcode" VALUES(9338,22729,-5,'Mitchells, Virginia 22729',6729,8234);
INSERT INTO "django_geo_db_zipcode" VALUES(9339,22730,-5,'Oakpark, Virginia 22730',6730,8235);
INSERT INTO "django_geo_db_zipcode" VALUES(9340,22731,-5,'Pratts, Virginia 22731',6731,8236);
INSERT INTO "django_geo_db_zipcode" VALUES(9341,22732,-5,'Radiant, Virginia 22732',6732,8237);
INSERT INTO "django_geo_db_zipcode" VALUES(9342,22733,-5,'Rapidan, Virginia 22733',6733,8238);
INSERT INTO "django_geo_db_zipcode" VALUES(9343,22734,-5,'Remington, Virginia 22734',6734,8239);
INSERT INTO "django_geo_db_zipcode" VALUES(9344,22735,-5,'Reva, Virginia 22735',6735,8240);
INSERT INTO "django_geo_db_zipcode" VALUES(9345,22736,-5,'Richardsville, Virginia 22736',6736,8241);
INSERT INTO "django_geo_db_zipcode" VALUES(9346,22737,-5,'Rixeyville, Virginia 22737',6737,8242);
INSERT INTO "django_geo_db_zipcode" VALUES(9347,22738,-5,'Rochelle, Virginia 22738',6738,8243);
INSERT INTO "django_geo_db_zipcode" VALUES(9348,22739,-5,'Somerville, Virginia 22739',6739,8244);
INSERT INTO "django_geo_db_zipcode" VALUES(9349,22740,-5,'Sperryville, Virginia 22740',6740,8245);
INSERT INTO "django_geo_db_zipcode" VALUES(9350,22741,-5,'Stevensburg, Virginia 22741',6741,8246);
INSERT INTO "django_geo_db_zipcode" VALUES(9351,22742,-5,'Sumerduck, Virginia 22742',6742,8247);
INSERT INTO "django_geo_db_zipcode" VALUES(9352,22743,-5,'Syria, Virginia 22743',6743,8248);
INSERT INTO "django_geo_db_zipcode" VALUES(9353,22746,-5,'Viewtown, Virginia 22746',6744,8249);
INSERT INTO "django_geo_db_zipcode" VALUES(9354,22747,-5,'Washington, Virginia 22747',6745,8250);
INSERT INTO "django_geo_db_zipcode" VALUES(9355,22748,-5,'Wolftown, Virginia 22748',6746,8251);
INSERT INTO "django_geo_db_zipcode" VALUES(9356,22749,-5,'Woodville, Virginia 22749',6747,8252);
INSERT INTO "django_geo_db_zipcode" VALUES(9357,22801,-5,'Harrisonburg, Virginia 22801',6748,8253);
INSERT INTO "django_geo_db_zipcode" VALUES(9358,22802,-5,'Harrisonburg, Virginia 22802',6748,8254);
INSERT INTO "django_geo_db_zipcode" VALUES(9359,22807,-5,'Harrisonburg, Virginia 22807',6748,8255);
INSERT INTO "django_geo_db_zipcode" VALUES(9360,22810,-5,'Basye, Virginia 22810',6749,8256);
INSERT INTO "django_geo_db_zipcode" VALUES(9361,22811,-5,'Bergton, Virginia 22811',6750,8257);
INSERT INTO "django_geo_db_zipcode" VALUES(9362,22812,-5,'Bridgewater, Virginia 22812',6751,8258);
INSERT INTO "django_geo_db_zipcode" VALUES(9363,22815,-5,'Broadway, Virginia 22815',6752,8259);
INSERT INTO "django_geo_db_zipcode" VALUES(9364,22820,-5,'Criders, Virginia 22820',6753,8260);
INSERT INTO "django_geo_db_zipcode" VALUES(9365,22821,-5,'Dayton, Virginia 22821',6754,8261);
INSERT INTO "django_geo_db_zipcode" VALUES(9366,22824,-5,'Edinburg, Virginia 22824',6755,8262);
INSERT INTO "django_geo_db_zipcode" VALUES(9367,22827,-5,'Elkton, Virginia 22827',6756,8263);
INSERT INTO "django_geo_db_zipcode" VALUES(9368,22830,-5,'Fulks Run, Virginia 22830',6757,8264);
INSERT INTO "django_geo_db_zipcode" VALUES(9369,22831,-5,'Hinton, Virginia 22831',6758,8265);
INSERT INTO "django_geo_db_zipcode" VALUES(9370,22832,-5,'Keezletown, Virginia 22832',6759,8266);
INSERT INTO "django_geo_db_zipcode" VALUES(9371,22833,-5,'Lacey Spring, Virginia 22833',6760,8267);
INSERT INTO "django_geo_db_zipcode" VALUES(9372,22834,-5,'Linville, Virginia 22834',6761,8268);
INSERT INTO "django_geo_db_zipcode" VALUES(9373,22835,-5,'Luray, Virginia 22835',6762,8269);
INSERT INTO "django_geo_db_zipcode" VALUES(9374,22840,-5,'McGaheysville, Virginia 22840',6763,8270);
INSERT INTO "django_geo_db_zipcode" VALUES(9375,22841,-5,'Mount Crawford, Virginia 22841',6764,8271);
INSERT INTO "django_geo_db_zipcode" VALUES(9376,22842,-5,'Mount Jackson, Virginia 22842',6765,8272);
INSERT INTO "django_geo_db_zipcode" VALUES(9377,22843,-5,'Mount Solon, Virginia 22843',6766,8273);
INSERT INTO "django_geo_db_zipcode" VALUES(9378,22844,-5,'New Market, Virginia 22844',6767,8274);
INSERT INTO "django_geo_db_zipcode" VALUES(9379,22845,-5,'Orkney Springs, Virginia 22845',6768,8275);
INSERT INTO "django_geo_db_zipcode" VALUES(9380,22846,-5,'Penn Laird, Virginia 22846',6769,8276);
INSERT INTO "django_geo_db_zipcode" VALUES(9381,22847,-5,'Quicksburg, Virginia 22847',6770,8277);
INSERT INTO "django_geo_db_zipcode" VALUES(9382,22848,-5,'Pleasant Valley, Virginia 22848',6771,8278);
INSERT INTO "django_geo_db_zipcode" VALUES(9383,22849,-5,'Shenandoah, Virginia 22849',6772,8279);
INSERT INTO "django_geo_db_zipcode" VALUES(9384,22850,-5,'Singers Glen, Virginia 22850',6773,8280);
INSERT INTO "django_geo_db_zipcode" VALUES(9385,22851,-5,'Stanley, Virginia 22851',6774,8281);
INSERT INTO "django_geo_db_zipcode" VALUES(9386,22853,-5,'Timberville, Virginia 22853',6775,8282);
INSERT INTO "django_geo_db_zipcode" VALUES(9387,22865,-5,'Luray, Virginia 22865',6762,8283);
INSERT INTO "django_geo_db_zipcode" VALUES(9388,22875,-5,'Luray, Virginia 22875',6762,8284);
INSERT INTO "django_geo_db_zipcode" VALUES(9389,22880,-5,'Waynesboro, Virginia 22880',6776,8285);
INSERT INTO "django_geo_db_zipcode" VALUES(9390,22901,-5,'Charlottesville, Virginia 22901',6777,8286);
INSERT INTO "django_geo_db_zipcode" VALUES(9391,22902,-5,'Charlottesville, Virginia 22902',6777,8287);
INSERT INTO "django_geo_db_zipcode" VALUES(9392,22903,-5,'Charlottesville, Virginia 22903',6777,8288);
INSERT INTO "django_geo_db_zipcode" VALUES(9393,22904,-5,'Charlottesville, Virginia 22904',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9394,22905,-5,'Charlottesville, Virginia 22905',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9395,22906,-5,'Charlottesville, Virginia 22906',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9396,22907,-5,'Charlottesville, Virginia 22907',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9397,22908,-5,'Charlottesville, Virginia 22908',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9398,22909,-5,'Charlottesville, Virginia 22909',6777,8290);
INSERT INTO "django_geo_db_zipcode" VALUES(9399,22910,-5,'Charlottesville, Virginia 22910',6777,8289);
INSERT INTO "django_geo_db_zipcode" VALUES(9400,22911,-5,'Charlottesville, Virginia 22911',6777,8291);
INSERT INTO "django_geo_db_zipcode" VALUES(9401,22920,-5,'Afton, Virginia 22920',6778,8292);
INSERT INTO "django_geo_db_zipcode" VALUES(9402,22922,-5,'Arrington, Virginia 22922',6779,8293);
INSERT INTO "django_geo_db_zipcode" VALUES(9403,22923,-5,'Barboursville, Virginia 22923',6780,8294);
INSERT INTO "django_geo_db_zipcode" VALUES(9404,22924,-5,'Batesville, Virginia 22924',6781,8295);
INSERT INTO "django_geo_db_zipcode" VALUES(9405,22931,-5,'Covesville, Virginia 22931',6782,8296);
INSERT INTO "django_geo_db_zipcode" VALUES(9406,22932,-5,'Crozet, Virginia 22932',6783,8297);
INSERT INTO "django_geo_db_zipcode" VALUES(9407,22935,-5,'Dyke, Virginia 22935',6784,8298);
INSERT INTO "django_geo_db_zipcode" VALUES(9408,22936,-5,'Earlysville, Virginia 22936',6785,8299);
INSERT INTO "django_geo_db_zipcode" VALUES(9409,22937,-5,'Esmont, Virginia 22937',6786,8300);
INSERT INTO "django_geo_db_zipcode" VALUES(9410,22938,-5,'Faber, Virginia 22938',6787,8301);
INSERT INTO "django_geo_db_zipcode" VALUES(9411,22939,-5,'Fishersville, Virginia 22939',6610,8302);
INSERT INTO "django_geo_db_zipcode" VALUES(9412,22940,-5,'Free Union, Virginia 22940',6788,8303);
INSERT INTO "django_geo_db_zipcode" VALUES(9413,22942,-5,'Gordonsville, Virginia 22942',6789,8304);
INSERT INTO "django_geo_db_zipcode" VALUES(9414,22943,-5,'Greenwood, Virginia 22943',6790,8305);
INSERT INTO "django_geo_db_zipcode" VALUES(9415,22945,-5,'Ivy, Virginia 22945',6791,8306);
INSERT INTO "django_geo_db_zipcode" VALUES(9416,22946,-5,'Keene, Virginia 22946',6792,8307);
INSERT INTO "django_geo_db_zipcode" VALUES(9417,22947,-5,'Keswick, Virginia 22947',6793,8308);
INSERT INTO "django_geo_db_zipcode" VALUES(9418,22948,-5,'Locust Dale, Virginia 22948',6794,8309);
INSERT INTO "django_geo_db_zipcode" VALUES(9419,22949,-5,'Lovingston, Virginia 22949',6795,8310);
INSERT INTO "django_geo_db_zipcode" VALUES(9420,22952,-5,'Lyndhurst, Virginia 22952',6796,8311);
INSERT INTO "django_geo_db_zipcode" VALUES(9421,22953,-5,'Madison Mills, Virginia 22953',6797,8227);
INSERT INTO "django_geo_db_zipcode" VALUES(9422,22954,-5,'Massies Mill, Virginia 22954',6798,8312);
INSERT INTO "django_geo_db_zipcode" VALUES(9423,22957,-5,'Montpelier Station, Virginia 22957',6799,8313);
INSERT INTO "django_geo_db_zipcode" VALUES(9424,22958,-5,'Nellysford, Virginia 22958',6800,8314);
INSERT INTO "django_geo_db_zipcode" VALUES(9425,22959,-5,'North Garden, Virginia 22959',6801,8315);
INSERT INTO "django_geo_db_zipcode" VALUES(9426,22960,-5,'Orange, Virginia 22960',6802,8316);
INSERT INTO "django_geo_db_zipcode" VALUES(9427,22963,-5,'Palmyra, Virginia 22963',6803,8317);
INSERT INTO "django_geo_db_zipcode" VALUES(9428,22964,-5,'Piney River, Virginia 22964',6804,8318);
INSERT INTO "django_geo_db_zipcode" VALUES(9429,22965,-5,'Quinque, Virginia 22965',6805,8319);
INSERT INTO "django_geo_db_zipcode" VALUES(9430,22967,-5,'Roseland, Virginia 22967',6806,8320);
INSERT INTO "django_geo_db_zipcode" VALUES(9431,22968,-5,'Ruckersville, Virginia 22968',6807,8321);
INSERT INTO "django_geo_db_zipcode" VALUES(9432,22969,-5,'Schuyler, Virginia 22969',6808,8322);
INSERT INTO "django_geo_db_zipcode" VALUES(9433,22971,-5,'Shipman, Virginia 22971',6809,8323);
INSERT INTO "django_geo_db_zipcode" VALUES(9434,22972,-5,'Somerset, Virginia 22972',6810,8324);
INSERT INTO "django_geo_db_zipcode" VALUES(9435,22973,-5,'Stanardsville, Virginia 22973',6811,8325);
INSERT INTO "django_geo_db_zipcode" VALUES(9436,22974,-5,'Troy, Virginia 22974',6812,8326);
INSERT INTO "django_geo_db_zipcode" VALUES(9437,22976,-5,'Tyro, Virginia 22976',6813,8327);
INSERT INTO "django_geo_db_zipcode" VALUES(9438,22980,-5,'Waynesboro, Virginia 22980',6776,8328);
INSERT INTO "django_geo_db_zipcode" VALUES(9439,22987,-5,'White Hall, Virginia 22987',6814,8329);
INSERT INTO "django_geo_db_zipcode" VALUES(9440,22989,-5,'Woodberry Forest, Virginia 22989',6815,8330);
INSERT INTO "django_geo_db_zipcode" VALUES(9441,23001,-5,'Achilles, Virginia 23001',6816,8331);
INSERT INTO "django_geo_db_zipcode" VALUES(9442,23002,-5,'Amelia Court House, Virginia 23002',6817,8332);
INSERT INTO "django_geo_db_zipcode" VALUES(9443,23003,-5,'Ark, Virginia 23003',6818,8333);
INSERT INTO "django_geo_db_zipcode" VALUES(9444,23004,-5,'Arvonia, Virginia 23004',6819,8334);
INSERT INTO "django_geo_db_zipcode" VALUES(9445,23005,-5,'Ashland, Virginia 23005',6820,8335);
INSERT INTO "django_geo_db_zipcode" VALUES(9446,23009,-5,'Aylett, Virginia 23009',6821,8336);
INSERT INTO "django_geo_db_zipcode" VALUES(9447,23011,-5,'Barhamsville, Virginia 23011',6822,8337);
INSERT INTO "django_geo_db_zipcode" VALUES(9448,23014,-5,'Beaumont, Virginia 23014',6823,8338);
INSERT INTO "django_geo_db_zipcode" VALUES(9449,23015,-5,'Beaverdam, Virginia 23015',6824,8339);
INSERT INTO "django_geo_db_zipcode" VALUES(9450,23017,-5,'Bellamy, Virginia 23017',6825,8340);
INSERT INTO "django_geo_db_zipcode" VALUES(9451,23018,-5,'Bena, Virginia 23018',6826,8340);
INSERT INTO "django_geo_db_zipcode" VALUES(9452,23021,-5,'Bohannon, Virginia 23021',6827,8341);
INSERT INTO "django_geo_db_zipcode" VALUES(9453,23022,-5,'Bremo Bluff, Virginia 23022',6828,8342);
INSERT INTO "django_geo_db_zipcode" VALUES(9454,23023,-5,'Bruington, Virginia 23023',6829,8343);
INSERT INTO "django_geo_db_zipcode" VALUES(9455,23024,-5,'Bumpass, Virginia 23024',6830,8344);
INSERT INTO "django_geo_db_zipcode" VALUES(9456,23025,-5,'Cardinal, Virginia 23025',6831,8345);
INSERT INTO "django_geo_db_zipcode" VALUES(9457,23027,-5,'Cartersville, Virginia 23027',6832,8346);
INSERT INTO "django_geo_db_zipcode" VALUES(9458,23030,-5,'Charles City, Virginia 23030',6833,8347);
INSERT INTO "django_geo_db_zipcode" VALUES(9459,23031,-5,'Christchurch, Virginia 23031',6834,8348);
INSERT INTO "django_geo_db_zipcode" VALUES(9460,23032,-5,'Church View, Virginia 23032',6835,8349);
INSERT INTO "django_geo_db_zipcode" VALUES(9461,23035,-5,'Cobbs Creek, Virginia 23035',6836,8350);
INSERT INTO "django_geo_db_zipcode" VALUES(9462,23038,-5,'Columbia, Virginia 23038',6837,8351);
INSERT INTO "django_geo_db_zipcode" VALUES(9463,23039,-5,'Crozier, Virginia 23039',6838,8352);
INSERT INTO "django_geo_db_zipcode" VALUES(9464,23040,-5,'Cumberland, Virginia 23040',6839,8353);
INSERT INTO "django_geo_db_zipcode" VALUES(9465,23043,-5,'Deltaville, Virginia 23043',6840,8354);
INSERT INTO "django_geo_db_zipcode" VALUES(9466,23045,-5,'Diggs, Virginia 23045',6841,8355);
INSERT INTO "django_geo_db_zipcode" VALUES(9467,23047,-5,'Doswell, Virginia 23047',6842,8356);
INSERT INTO "django_geo_db_zipcode" VALUES(9468,23050,-5,'Dutton, Virginia 23050',6843,8357);
INSERT INTO "django_geo_db_zipcode" VALUES(9469,23054,-5,'Fife, Virginia 23054',6844,8338);
INSERT INTO "django_geo_db_zipcode" VALUES(9470,23055,-5,'Fork Union, Virginia 23055',6845,8358);
INSERT INTO "django_geo_db_zipcode" VALUES(9471,23056,-5,'Foster, Virginia 23056',6846,8359);
INSERT INTO "django_geo_db_zipcode" VALUES(9472,23058,-5,'Glen Allen, Virginia 23058',6847,8360);
INSERT INTO "django_geo_db_zipcode" VALUES(9473,23059,-5,'Glen Allen, Virginia 23059',6847,8361);
INSERT INTO "django_geo_db_zipcode" VALUES(9474,23060,-5,'Glen Allen, Virginia 23060',6847,8362);
INSERT INTO "django_geo_db_zipcode" VALUES(9475,23061,-5,'Gloucester, Virginia 23061',6848,8363);
INSERT INTO "django_geo_db_zipcode" VALUES(9476,23062,-5,'Gloucester Point, Virginia 23062',6849,8364);
INSERT INTO "django_geo_db_zipcode" VALUES(9477,23063,-5,'Goochland, Virginia 23063',6850,8365);
INSERT INTO "django_geo_db_zipcode" VALUES(9478,23064,-5,'Grimstead, Virginia 23064',6851,8366);
INSERT INTO "django_geo_db_zipcode" VALUES(9479,23065,-5,'Gum Spring, Virginia 23065',6852,8367);
INSERT INTO "django_geo_db_zipcode" VALUES(9480,23066,-5,'Gwynn, Virginia 23066',6853,8368);
INSERT INTO "django_geo_db_zipcode" VALUES(9481,23067,-5,'Hadensville, Virginia 23067',6854,8369);
INSERT INTO "django_geo_db_zipcode" VALUES(9482,23068,-5,'Hallieford, Virginia 23068',6855,8370);
INSERT INTO "django_geo_db_zipcode" VALUES(9483,23069,-5,'Hanover, Virginia 23069',6856,8371);
INSERT INTO "django_geo_db_zipcode" VALUES(9484,23070,-5,'Hardyville, Virginia 23070',6857,8372);
INSERT INTO "django_geo_db_zipcode" VALUES(9485,23071,-5,'Hartfield, Virginia 23071',6858,8373);
INSERT INTO "django_geo_db_zipcode" VALUES(9486,23072,-5,'Hayes, Virginia 23072',6859,8374);
INSERT INTO "django_geo_db_zipcode" VALUES(9487,23075,-5,'Highland Springs, Virginia 23075',6860,8375);
INSERT INTO "django_geo_db_zipcode" VALUES(9488,23076,-5,'Hudgins, Virginia 23076',6861,8376);
INSERT INTO "django_geo_db_zipcode" VALUES(9489,23079,-5,'Jamaica, Virginia 23079',6862,8377);
INSERT INTO "django_geo_db_zipcode" VALUES(9490,23081,-5,'Jamestown, Virginia 23081',6863,8378);
INSERT INTO "django_geo_db_zipcode" VALUES(9491,23083,-5,'Jetersville, Virginia 23083',6864,8379);
INSERT INTO "django_geo_db_zipcode" VALUES(9492,23084,-5,'Kents Store, Virginia 23084',6865,8380);
INSERT INTO "django_geo_db_zipcode" VALUES(9493,23085,-5,'King And Queen Court Hous, Virginia 23085',6866,8381);
INSERT INTO "django_geo_db_zipcode" VALUES(9494,23086,-5,'King William, Virginia 23086',6867,8382);
INSERT INTO "django_geo_db_zipcode" VALUES(9495,23089,-5,'Lanexa, Virginia 23089',6868,8383);
INSERT INTO "django_geo_db_zipcode" VALUES(9496,23090,-5,'Lightfoot, Virginia 23090',6869,8384);
INSERT INTO "django_geo_db_zipcode" VALUES(9497,23091,-5,'Little Plymouth, Virginia 23091',6870,8385);
INSERT INTO "django_geo_db_zipcode" VALUES(9498,23092,-5,'Locust Hill, Virginia 23092',6871,8386);
INSERT INTO "django_geo_db_zipcode" VALUES(9499,23093,-5,'Louisa, Virginia 23093',6872,8387);
INSERT INTO "django_geo_db_zipcode" VALUES(9500,23101,-5,'Macon, Virginia 23101',6873,8388);
INSERT INTO "django_geo_db_zipcode" VALUES(9501,23102,-5,'Maidens, Virginia 23102',6874,8389);
INSERT INTO "django_geo_db_zipcode" VALUES(9502,23103,-5,'Manakin Sabot, Virginia 23103',6875,8390);
INSERT INTO "django_geo_db_zipcode" VALUES(9503,23104,-5,'Gloucester Point, Virginia 23104',6849,8391);
INSERT INTO "django_geo_db_zipcode" VALUES(9504,23105,-5,'Mannboro, Virginia 23105',6876,8392);
INSERT INTO "django_geo_db_zipcode" VALUES(9505,23106,-5,'Manquin, Virginia 23106',6877,8393);
INSERT INTO "django_geo_db_zipcode" VALUES(9506,23107,-5,'Maryus, Virginia 23107',6878,8394);
INSERT INTO "django_geo_db_zipcode" VALUES(9507,23108,-5,'Mascot, Virginia 23108',6879,8395);
INSERT INTO "django_geo_db_zipcode" VALUES(9508,23109,-5,'Mathews, Virginia 23109',6880,8396);
INSERT INTO "django_geo_db_zipcode" VALUES(9509,23110,-5,'Mattaponi, Virginia 23110',6881,8397);
INSERT INTO "django_geo_db_zipcode" VALUES(9510,23111,-5,'Mechanicsville, Virginia 23111',6882,8398);
INSERT INTO "django_geo_db_zipcode" VALUES(9511,23112,-5,'Midlothian, Virginia 23112',6883,8399);
INSERT INTO "django_geo_db_zipcode" VALUES(9512,23113,-5,'Midlothian, Virginia 23113',6883,8400);
INSERT INTO "django_geo_db_zipcode" VALUES(9513,23115,-5,'Millers Tavern, Virginia 23115',6884,8401);
INSERT INTO "django_geo_db_zipcode" VALUES(9514,23116,-5,'Mechanicsville, Virginia 23116',6882,8402);
INSERT INTO "django_geo_db_zipcode" VALUES(9515,23117,-5,'Mineral, Virginia 23117',6885,8403);
INSERT INTO "django_geo_db_zipcode" VALUES(9516,23119,-5,'Moon, Virginia 23119',6886,8404);
INSERT INTO "django_geo_db_zipcode" VALUES(9517,23120,-5,'Moseley, Virginia 23120',6887,8405);
INSERT INTO "django_geo_db_zipcode" VALUES(9518,23123,-5,'New Canton, Virginia 23123',6888,8406);
INSERT INTO "django_geo_db_zipcode" VALUES(9519,23124,-5,'New Kent, Virginia 23124',6889,8407);
INSERT INTO "django_geo_db_zipcode" VALUES(9520,23125,-5,'New Point, Virginia 23125',6890,8408);
INSERT INTO "django_geo_db_zipcode" VALUES(9521,23126,-5,'Newtown, Virginia 23126',6891,8409);
INSERT INTO "django_geo_db_zipcode" VALUES(9522,23127,-5,'Norge, Virginia 23127',6892,8410);
INSERT INTO "django_geo_db_zipcode" VALUES(9523,23128,-5,'North, Virginia 23128',6893,8411);
INSERT INTO "django_geo_db_zipcode" VALUES(9524,23129,-5,'Oilville, Virginia 23129',6894,8412);
INSERT INTO "django_geo_db_zipcode" VALUES(9525,23130,-5,'Onemo, Virginia 23130',6895,8413);
INSERT INTO "django_geo_db_zipcode" VALUES(9526,23131,-5,'Ordinary, Virginia 23131',6896,8414);
INSERT INTO "django_geo_db_zipcode" VALUES(9527,23138,-5,'Port Haywood, Virginia 23138',6897,8415);
INSERT INTO "django_geo_db_zipcode" VALUES(9528,23139,-5,'Powhatan, Virginia 23139',6898,8416);
INSERT INTO "django_geo_db_zipcode" VALUES(9529,23140,-5,'Providence Forge, Virginia 23140',6899,8417);
INSERT INTO "django_geo_db_zipcode" VALUES(9530,23141,-5,'Quinton, Virginia 23141',6900,8418);
INSERT INTO "django_geo_db_zipcode" VALUES(9531,23146,-5,'Rockville, Virginia 23146',6901,8419);
INSERT INTO "django_geo_db_zipcode" VALUES(9532,23147,-5,'Ruthville, Virginia 23147',6902,8420);
INSERT INTO "django_geo_db_zipcode" VALUES(9533,23148,-5,'Saint Stephens Church, Virginia 23148',6903,8421);
INSERT INTO "django_geo_db_zipcode" VALUES(9534,23149,-5,'Saluda, Virginia 23149',6904,8422);
INSERT INTO "django_geo_db_zipcode" VALUES(9535,23150,-5,'Sandston, Virginia 23150',6905,8423);
INSERT INTO "django_geo_db_zipcode" VALUES(9536,23153,-5,'Sandy Hook, Virginia 23153',6906,8424);
INSERT INTO "django_geo_db_zipcode" VALUES(9537,23154,-5,'Schley, Virginia 23154',6907,8340);
INSERT INTO "django_geo_db_zipcode" VALUES(9538,23155,-5,'Severn, Virginia 23155',6908,8340);
INSERT INTO "django_geo_db_zipcode" VALUES(9539,23156,-5,'Shacklefords, Virginia 23156',6909,8425);
INSERT INTO "django_geo_db_zipcode" VALUES(9540,23160,-5,'State Farm, Virginia 23160',6910,8338);
INSERT INTO "django_geo_db_zipcode" VALUES(9541,23161,-5,'Stevensville, Virginia 23161',6911,8426);
INSERT INTO "django_geo_db_zipcode" VALUES(9542,23162,-5,'Studley, Virginia 23162',6912,8427);
INSERT INTO "django_geo_db_zipcode" VALUES(9543,23163,-5,'Susan, Virginia 23163',6913,8428);
INSERT INTO "django_geo_db_zipcode" VALUES(9544,23168,-5,'Toano, Virginia 23168',6914,8429);
INSERT INTO "django_geo_db_zipcode" VALUES(9545,23169,-5,'Topping, Virginia 23169',6915,8430);
INSERT INTO "django_geo_db_zipcode" VALUES(9546,23170,-5,'Trevilians, Virginia 23170',6916,8431);
INSERT INTO "django_geo_db_zipcode" VALUES(9547,23173,-5,'University Of Richmond, Virginia 23173',6917,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9548,23175,-5,'Urbanna, Virginia 23175',6918,8433);
INSERT INTO "django_geo_db_zipcode" VALUES(9549,23176,-5,'Wake, Virginia 23176',6919,8434);
INSERT INTO "django_geo_db_zipcode" VALUES(9550,23177,-5,'Walkerton, Virginia 23177',6920,8435);
INSERT INTO "django_geo_db_zipcode" VALUES(9551,23178,-5,'Ware Neck, Virginia 23178',6921,8436);
INSERT INTO "django_geo_db_zipcode" VALUES(9552,23180,-5,'Water View, Virginia 23180',6922,8437);
INSERT INTO "django_geo_db_zipcode" VALUES(9553,23181,-5,'West Point, Virginia 23181',6923,8438);
INSERT INTO "django_geo_db_zipcode" VALUES(9554,23183,-5,'White Marsh, Virginia 23183',6924,8439);
INSERT INTO "django_geo_db_zipcode" VALUES(9555,23184,-5,'Wicomico, Virginia 23184',6925,8440);
INSERT INTO "django_geo_db_zipcode" VALUES(9556,23185,-5,'Williamsburg, Virginia 23185',6926,8441);
INSERT INTO "django_geo_db_zipcode" VALUES(9557,23186,-5,'Williamsburg, Virginia 23186',6926,8442);
INSERT INTO "django_geo_db_zipcode" VALUES(9558,23187,-5,'Williamsburg, Virginia 23187',6926,8410);
INSERT INTO "django_geo_db_zipcode" VALUES(9559,23188,-5,'Williamsburg, Virginia 23188',6926,8443);
INSERT INTO "django_geo_db_zipcode" VALUES(9560,23190,-5,'Woods Cross Roads, Virginia 23190',6927,8444);
INSERT INTO "django_geo_db_zipcode" VALUES(9561,23191,-5,'Zanoni, Virginia 23191',6928,8340);
INSERT INTO "django_geo_db_zipcode" VALUES(9562,23192,-5,'Montpelier, Virginia 23192',6929,8445);
INSERT INTO "django_geo_db_zipcode" VALUES(9563,23201,-5,'Richmond, Virginia 23201',6930,8446);
INSERT INTO "django_geo_db_zipcode" VALUES(9564,23218,-5,'Richmond, Virginia 23218',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9565,23219,-5,'Richmond, Virginia 23219',6930,8447);
INSERT INTO "django_geo_db_zipcode" VALUES(9566,23220,-5,'Richmond, Virginia 23220',6930,8448);
INSERT INTO "django_geo_db_zipcode" VALUES(9567,23221,-5,'Richmond, Virginia 23221',6930,8449);
INSERT INTO "django_geo_db_zipcode" VALUES(9568,23222,-5,'Richmond, Virginia 23222',6930,8450);
INSERT INTO "django_geo_db_zipcode" VALUES(9569,23223,-5,'Richmond, Virginia 23223',6930,8451);
INSERT INTO "django_geo_db_zipcode" VALUES(9570,23224,-5,'Richmond, Virginia 23224',6930,8452);
INSERT INTO "django_geo_db_zipcode" VALUES(9571,23225,-5,'Richmond, Virginia 23225',6930,8453);
INSERT INTO "django_geo_db_zipcode" VALUES(9572,23226,-5,'Richmond, Virginia 23226',6930,8454);
INSERT INTO "django_geo_db_zipcode" VALUES(9573,23227,-5,'Richmond, Virginia 23227',6930,8455);
INSERT INTO "django_geo_db_zipcode" VALUES(9574,23228,-5,'Richmond, Virginia 23228',6930,8456);
INSERT INTO "django_geo_db_zipcode" VALUES(9575,23229,-5,'Richmond, Virginia 23229',6930,8457);
INSERT INTO "django_geo_db_zipcode" VALUES(9576,23230,-5,'Richmond, Virginia 23230',6930,8458);
INSERT INTO "django_geo_db_zipcode" VALUES(9577,23231,-5,'Richmond, Virginia 23231',6930,8459);
INSERT INTO "django_geo_db_zipcode" VALUES(9578,23232,-5,'Richmond, Virginia 23232',6930,8460);
INSERT INTO "django_geo_db_zipcode" VALUES(9579,23233,-5,'Richmond, Virginia 23233',6930,8461);
INSERT INTO "django_geo_db_zipcode" VALUES(9580,23234,-5,'Richmond, Virginia 23234',6930,8462);
INSERT INTO "django_geo_db_zipcode" VALUES(9581,23235,-5,'Richmond, Virginia 23235',6930,8463);
INSERT INTO "django_geo_db_zipcode" VALUES(9582,23236,-5,'Richmond, Virginia 23236',6930,8464);
INSERT INTO "django_geo_db_zipcode" VALUES(9583,23237,-5,'Richmond, Virginia 23237',6930,8465);
INSERT INTO "django_geo_db_zipcode" VALUES(9584,23238,-5,'Richmond, Virginia 23238',6930,8338);
INSERT INTO "django_geo_db_zipcode" VALUES(9585,23240,-5,'Richmond, Virginia 23240',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9586,23241,-5,'Richmond, Virginia 23241',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9587,23242,-5,'Richmond, Virginia 23242',6930,8360);
INSERT INTO "django_geo_db_zipcode" VALUES(9588,23249,-5,'Richmond, Virginia 23249',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9589,23250,-5,'Richmond, Virginia 23250',6930,8466);
INSERT INTO "django_geo_db_zipcode" VALUES(9590,23255,-5,'Richmond, Virginia 23255',6930,8360);
INSERT INTO "django_geo_db_zipcode" VALUES(9591,23260,-5,'Richmond, Virginia 23260',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9592,23261,-5,'Richmond, Virginia 23261',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9593,23266,-5,'Richmond, Virginia 23266',6930,8467);
INSERT INTO "django_geo_db_zipcode" VALUES(9594,23269,-5,'Richmond, Virginia 23269',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9595,23270,-5,'Richmond, Virginia 23270',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9596,23272,-5,'Richmond, Virginia 23272',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9597,23273,-5,'Richmond, Virginia 23273',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9598,23274,-5,'Richmond, Virginia 23274',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9599,23275,-5,'Richmond, Virginia 23275',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9600,23276,-5,'Richmond, Virginia 23276',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9601,23278,-5,'Richmond, Virginia 23278',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9602,23279,-5,'Richmond, Virginia 23279',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9603,23280,-5,'Richmond, Virginia 23280',6930,8468);
INSERT INTO "django_geo_db_zipcode" VALUES(9604,23282,-5,'Richmond, Virginia 23282',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9605,23284,-5,'Richmond, Virginia 23284',6930,8469);
INSERT INTO "django_geo_db_zipcode" VALUES(9606,23285,-5,'Richmond, Virginia 23285',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9607,23286,-5,'Richmond, Virginia 23286',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9608,23288,-5,'Richmond, Virginia 23288',6930,8360);
INSERT INTO "django_geo_db_zipcode" VALUES(9609,23289,-5,'Richmond, Virginia 23289',6930,8360);
INSERT INTO "django_geo_db_zipcode" VALUES(9610,23290,-5,'Richmond, Virginia 23290',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9611,23291,-5,'Richmond, Virginia 23291',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9612,23292,-5,'Richmond, Virginia 23292',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9613,23293,-5,'Richmond, Virginia 23293',6930,8432);
INSERT INTO "django_geo_db_zipcode" VALUES(9614,23294,-5,'Richmond, Virginia 23294',6930,8470);
INSERT INTO "django_geo_db_zipcode" VALUES(9615,23297,-5,'Richmond, Virginia 23297',6930,8471);
INSERT INTO "django_geo_db_zipcode" VALUES(9616,23298,-5,'Richmond, Virginia 23298',6930,8472);
INSERT INTO "django_geo_db_zipcode" VALUES(9617,23301,-5,'Accomac, Virginia 23301',6931,8473);
INSERT INTO "django_geo_db_zipcode" VALUES(9618,23302,-5,'Assawoman, Virginia 23302',6932,8474);
INSERT INTO "django_geo_db_zipcode" VALUES(9619,23303,-5,'Atlantic, Virginia 23303',6933,8475);
INSERT INTO "django_geo_db_zipcode" VALUES(9620,23304,-5,'Battery Park, Virginia 23304',6934,8476);
INSERT INTO "django_geo_db_zipcode" VALUES(9621,23306,-5,'Belle Haven, Virginia 23306',6935,8477);
INSERT INTO "django_geo_db_zipcode" VALUES(9622,23307,-5,'Birdsnest, Virginia 23307',6936,8478);
INSERT INTO "django_geo_db_zipcode" VALUES(9623,23308,-5,'Bloxom, Virginia 23308',6937,8479);
INSERT INTO "django_geo_db_zipcode" VALUES(9624,23310,-5,'Cape Charles, Virginia 23310',6938,8480);
INSERT INTO "django_geo_db_zipcode" VALUES(9625,23313,-5,'Capeville, Virginia 23313',6939,8481);
INSERT INTO "django_geo_db_zipcode" VALUES(9626,23314,-5,'Carrollton, Virginia 23314',6940,8482);
INSERT INTO "django_geo_db_zipcode" VALUES(9627,23315,-5,'Carrsville, Virginia 23315',6941,8483);
INSERT INTO "django_geo_db_zipcode" VALUES(9628,23316,-5,'Cheriton, Virginia 23316',6942,8484);
INSERT INTO "django_geo_db_zipcode" VALUES(9629,23320,-5,'Chesapeake, Virginia 23320',6943,8485);
INSERT INTO "django_geo_db_zipcode" VALUES(9630,23321,-5,'Chesapeake, Virginia 23321',6943,8486);
INSERT INTO "django_geo_db_zipcode" VALUES(9631,23322,-5,'Chesapeake, Virginia 23322',6943,8487);
INSERT INTO "django_geo_db_zipcode" VALUES(9632,23323,-5,'Chesapeake, Virginia 23323',6943,8488);
INSERT INTO "django_geo_db_zipcode" VALUES(9633,23324,-5,'Chesapeake, Virginia 23324',6943,8489);
INSERT INTO "django_geo_db_zipcode" VALUES(9634,23325,-5,'Chesapeake, Virginia 23325',6943,8490);
INSERT INTO "django_geo_db_zipcode" VALUES(9635,23326,-5,'Chesapeake, Virginia 23326',6943,8491);
INSERT INTO "django_geo_db_zipcode" VALUES(9636,23327,-5,'Chesapeake, Virginia 23327',6943,8492);
INSERT INTO "django_geo_db_zipcode" VALUES(9637,23328,-5,'Chesapeake, Virginia 23328',6943,8492);
INSERT INTO "django_geo_db_zipcode" VALUES(9638,23336,-5,'Chincoteague Island, Virginia 23336',6944,8493);
INSERT INTO "django_geo_db_zipcode" VALUES(9639,23337,-5,'Wallops Island, Virginia 23337',6945,8494);
INSERT INTO "django_geo_db_zipcode" VALUES(9640,23341,-5,'Craddockville, Virginia 23341',6946,8495);
INSERT INTO "django_geo_db_zipcode" VALUES(9641,23345,-5,'Davis Wharf, Virginia 23345',6947,8496);
INSERT INTO "django_geo_db_zipcode" VALUES(9642,23347,-5,'Eastville, Virginia 23347',6948,8497);
INSERT INTO "django_geo_db_zipcode" VALUES(9643,23350,-5,'Exmore, Virginia 23350',6949,8498);
INSERT INTO "django_geo_db_zipcode" VALUES(9644,23351,-5,'Exmore, Virginia 23351',6949,8499);
INSERT INTO "django_geo_db_zipcode" VALUES(9645,23354,-5,'Franktown, Virginia 23354',6950,8500);
INSERT INTO "django_geo_db_zipcode" VALUES(9646,23356,-5,'Greenbackville, Virginia 23356',6951,8501);
INSERT INTO "django_geo_db_zipcode" VALUES(9647,23357,-5,'Greenbush, Virginia 23357',6952,8502);
INSERT INTO "django_geo_db_zipcode" VALUES(9648,23358,-5,'Hacksneck, Virginia 23358',6953,8503);
INSERT INTO "django_geo_db_zipcode" VALUES(9649,23359,-5,'Hallwood, Virginia 23359',6954,8504);
INSERT INTO "django_geo_db_zipcode" VALUES(9650,23380,-5,'Exmore, Virginia 23380',6949,8505);
INSERT INTO "django_geo_db_zipcode" VALUES(9651,23389,-5,'Harborton, Virginia 23389',6955,8506);
INSERT INTO "django_geo_db_zipcode" VALUES(9652,23395,-5,'Horntown, Virginia 23395',6956,8507);
INSERT INTO "django_geo_db_zipcode" VALUES(9653,23396,-5,'Oak Hall, Virginia 23396',6957,8508);
INSERT INTO "django_geo_db_zipcode" VALUES(9654,23397,-5,'Isle Of Wight, Virginia 23397',6958,8509);
INSERT INTO "django_geo_db_zipcode" VALUES(9655,23398,-5,'Jamesville, Virginia 23398',6959,8510);
INSERT INTO "django_geo_db_zipcode" VALUES(9656,23399,-5,'Jenkins Bridge, Virginia 23399',6960,8511);
INSERT INTO "django_geo_db_zipcode" VALUES(9657,23401,-5,'Keller, Virginia 23401',6961,8512);
INSERT INTO "django_geo_db_zipcode" VALUES(9658,23404,-5,'Locustville, Virginia 23404',6962,8513);
INSERT INTO "django_geo_db_zipcode" VALUES(9659,23405,-5,'Machipongo, Virginia 23405',6963,8514);
INSERT INTO "django_geo_db_zipcode" VALUES(9660,23407,-5,'Mappsville, Virginia 23407',6964,8515);
INSERT INTO "django_geo_db_zipcode" VALUES(9661,23408,-5,'Marionville, Virginia 23408',6965,8516);
INSERT INTO "django_geo_db_zipcode" VALUES(9662,23409,-5,'Mears, Virginia 23409',6966,8517);
INSERT INTO "django_geo_db_zipcode" VALUES(9663,23410,-5,'Melfa, Virginia 23410',6967,8518);
INSERT INTO "django_geo_db_zipcode" VALUES(9664,23412,-5,'Modest Town, Virginia 23412',6968,8519);
INSERT INTO "django_geo_db_zipcode" VALUES(9665,23413,-5,'Nassawadox, Virginia 23413',6969,8520);
INSERT INTO "django_geo_db_zipcode" VALUES(9666,23414,-5,'Nelsonia, Virginia 23414',6970,8521);
INSERT INTO "django_geo_db_zipcode" VALUES(9667,23415,-5,'New Church, Virginia 23415',6971,8522);
INSERT INTO "django_geo_db_zipcode" VALUES(9668,23416,-5,'Oak Hall, Virginia 23416',6957,8523);
INSERT INTO "django_geo_db_zipcode" VALUES(9669,23417,-5,'Onancock, Virginia 23417',6972,8524);
INSERT INTO "django_geo_db_zipcode" VALUES(9670,23418,-5,'Onley, Virginia 23418',6973,8525);
INSERT INTO "django_geo_db_zipcode" VALUES(9671,23419,-5,'Oyster, Virginia 23419',6974,8526);
INSERT INTO "django_geo_db_zipcode" VALUES(9672,23420,-5,'Painter, Virginia 23420',6975,8527);
INSERT INTO "django_geo_db_zipcode" VALUES(9673,23421,-5,'Parksley, Virginia 23421',6976,8528);
INSERT INTO "django_geo_db_zipcode" VALUES(9674,23422,-5,'Pungoteague, Virginia 23422',6977,8529);
INSERT INTO "django_geo_db_zipcode" VALUES(9675,23423,-5,'Quinby, Virginia 23423',6978,8530);
INSERT INTO "django_geo_db_zipcode" VALUES(9676,23424,-5,'Rescue, Virginia 23424',6979,8531);
INSERT INTO "django_geo_db_zipcode" VALUES(9677,23426,-5,'Sanford, Virginia 23426',6980,8532);
INSERT INTO "django_geo_db_zipcode" VALUES(9678,23427,-5,'Saxis, Virginia 23427',6981,8533);
INSERT INTO "django_geo_db_zipcode" VALUES(9679,23429,-5,'Seaview, Virginia 23429',6982,8534);
INSERT INTO "django_geo_db_zipcode" VALUES(9680,23430,-5,'Smithfield, Virginia 23430',6983,8535);
INSERT INTO "django_geo_db_zipcode" VALUES(9681,23431,-5,'Smithfield, Virginia 23431',6983,8509);
INSERT INTO "django_geo_db_zipcode" VALUES(9682,23432,-5,'Suffolk, Virginia 23432',6984,8536);
INSERT INTO "django_geo_db_zipcode" VALUES(9683,23433,-5,'Suffolk, Virginia 23433',6984,8537);
INSERT INTO "django_geo_db_zipcode" VALUES(9684,23434,-5,'Suffolk, Virginia 23434',6984,8538);
INSERT INTO "django_geo_db_zipcode" VALUES(9685,23435,-5,'Suffolk, Virginia 23435',6984,8539);
INSERT INTO "django_geo_db_zipcode" VALUES(9686,23436,-5,'Suffolk, Virginia 23436',6984,8540);
INSERT INTO "django_geo_db_zipcode" VALUES(9687,23437,-5,'Suffolk, Virginia 23437',6984,8541);
INSERT INTO "django_geo_db_zipcode" VALUES(9688,23438,-5,'Suffolk, Virginia 23438',6984,8542);
INSERT INTO "django_geo_db_zipcode" VALUES(9689,23439,-5,'Suffolk, Virginia 23439',6984,8543);
INSERT INTO "django_geo_db_zipcode" VALUES(9690,23440,-5,'Tangier, Virginia 23440',6985,8544);
INSERT INTO "django_geo_db_zipcode" VALUES(9691,23441,-5,'Tasley, Virginia 23441',6986,8545);
INSERT INTO "django_geo_db_zipcode" VALUES(9692,23442,-5,'Temperanceville, Virginia 23442',6987,8546);
INSERT INTO "django_geo_db_zipcode" VALUES(9693,23443,-5,'Townsend, Virginia 23443',6988,8547);
INSERT INTO "django_geo_db_zipcode" VALUES(9694,23450,-5,'Virginia Beach, Virginia 23450',6989,8548);
INSERT INTO "django_geo_db_zipcode" VALUES(9695,23451,-5,'Virginia Beach, Virginia 23451',6989,8549);
INSERT INTO "django_geo_db_zipcode" VALUES(9696,23452,-5,'Virginia Beach, Virginia 23452',6989,8550);
INSERT INTO "django_geo_db_zipcode" VALUES(9697,23453,-5,'Virginia Beach, Virginia 23453',6989,8551);
INSERT INTO "django_geo_db_zipcode" VALUES(9698,23454,-5,'Virginia Beach, Virginia 23454',6989,8552);
INSERT INTO "django_geo_db_zipcode" VALUES(9699,23455,-5,'Virginia Beach, Virginia 23455',6989,8553);
INSERT INTO "django_geo_db_zipcode" VALUES(9700,23456,-5,'Virginia Beach, Virginia 23456',6989,8554);
INSERT INTO "django_geo_db_zipcode" VALUES(9701,23457,-5,'Virginia Beach, Virginia 23457',6989,8555);
INSERT INTO "django_geo_db_zipcode" VALUES(9702,23458,-5,'Virginia Beach, Virginia 23458',6989,8556);
INSERT INTO "django_geo_db_zipcode" VALUES(9703,23459,-5,'Virginia Beach, Virginia 23459',6989,8557);
INSERT INTO "django_geo_db_zipcode" VALUES(9704,23460,-5,'Virginia Beach, Virginia 23460',6989,8558);
INSERT INTO "django_geo_db_zipcode" VALUES(9705,23461,-5,'Virginia Beach, Virginia 23461',6989,8559);
INSERT INTO "django_geo_db_zipcode" VALUES(9706,23462,-5,'Virginia Beach, Virginia 23462',6989,8560);
INSERT INTO "django_geo_db_zipcode" VALUES(9707,23463,-5,'Virginia Beach, Virginia 23463',6989,8561);
INSERT INTO "django_geo_db_zipcode" VALUES(9708,23464,-5,'Virginia Beach, Virginia 23464',6989,8562);
INSERT INTO "django_geo_db_zipcode" VALUES(9709,23465,-5,'Virginia Beach, Virginia 23465',6989,8563);
INSERT INTO "django_geo_db_zipcode" VALUES(9710,23466,-5,'Virginia Beach, Virginia 23466',6989,8561);
INSERT INTO "django_geo_db_zipcode" VALUES(9711,23467,-5,'Virginia Beach, Virginia 23467',6989,8561);
INSERT INTO "django_geo_db_zipcode" VALUES(9712,23468,-5,'Virginia Beach, Virginia 23468',6989,8564);
INSERT INTO "django_geo_db_zipcode" VALUES(9713,23471,-5,'Virginia Beach, Virginia 23471',6989,8561);
INSERT INTO "django_geo_db_zipcode" VALUES(9714,23472,-5,'Gloucester Point, Virginia 23472',6849,8565);
INSERT INTO "django_geo_db_zipcode" VALUES(9715,23479,-5,'Virginia Beach, Virginia 23479',6989,8561);
INSERT INTO "django_geo_db_zipcode" VALUES(9716,23480,-5,'Wachapreague, Virginia 23480',6990,8566);
INSERT INTO "django_geo_db_zipcode" VALUES(9717,23482,-5,'Wardtown, Virginia 23482',6991,8567);
INSERT INTO "django_geo_db_zipcode" VALUES(9718,23483,-5,'Wattsville, Virginia 23483',6992,8568);
INSERT INTO "django_geo_db_zipcode" VALUES(9719,23486,-5,'Willis Wharf, Virginia 23486',6993,8569);
INSERT INTO "django_geo_db_zipcode" VALUES(9720,23487,-5,'Windsor, Virginia 23487',6994,8570);
INSERT INTO "django_geo_db_zipcode" VALUES(9721,23488,-5,'Withams, Virginia 23488',6995,8571);
INSERT INTO "django_geo_db_zipcode" VALUES(9722,23501,-5,'Norfolk, Virginia 23501',6996,8572);
INSERT INTO "django_geo_db_zipcode" VALUES(9723,23502,-5,'Norfolk, Virginia 23502',6996,8573);
INSERT INTO "django_geo_db_zipcode" VALUES(9724,23503,-5,'Norfolk, Virginia 23503',6996,8574);
INSERT INTO "django_geo_db_zipcode" VALUES(9725,23504,-5,'Norfolk, Virginia 23504',6996,8575);
INSERT INTO "django_geo_db_zipcode" VALUES(9726,23505,-5,'Norfolk, Virginia 23505',6996,8576);
INSERT INTO "django_geo_db_zipcode" VALUES(9727,23506,-5,'Norfolk, Virginia 23506',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9728,23507,-5,'Norfolk, Virginia 23507',6996,8578);
INSERT INTO "django_geo_db_zipcode" VALUES(9729,23508,-5,'Norfolk, Virginia 23508',6996,8579);
INSERT INTO "django_geo_db_zipcode" VALUES(9730,23509,-5,'Norfolk, Virginia 23509',6996,8580);
INSERT INTO "django_geo_db_zipcode" VALUES(9731,23510,-5,'Norfolk, Virginia 23510',6996,8581);
INSERT INTO "django_geo_db_zipcode" VALUES(9732,23511,-5,'Norfolk, Virginia 23511',6996,8582);
INSERT INTO "django_geo_db_zipcode" VALUES(9733,23512,-5,'Norfolk, Virginia 23512',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9734,23513,-5,'Norfolk, Virginia 23513',6996,8583);
INSERT INTO "django_geo_db_zipcode" VALUES(9735,23514,-5,'Norfolk, Virginia 23514',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9736,23515,-5,'Norfolk, Virginia 23515',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9737,23517,-5,'Norfolk, Virginia 23517',6996,8584);
INSERT INTO "django_geo_db_zipcode" VALUES(9738,23518,-5,'Norfolk, Virginia 23518',6996,8585);
INSERT INTO "django_geo_db_zipcode" VALUES(9739,23519,-5,'Norfolk, Virginia 23519',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9740,23520,-5,'Norfolk, Virginia 23520',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9741,23521,-5,'Norfolk, Virginia 23521',6996,8586);
INSERT INTO "django_geo_db_zipcode" VALUES(9742,23523,-5,'Norfolk, Virginia 23523',6996,8587);
INSERT INTO "django_geo_db_zipcode" VALUES(9743,23529,-5,'Norfolk, Virginia 23529',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9744,23530,-5,'Norfolk, Virginia 23530',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9745,23541,-5,'Norfolk, Virginia 23541',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9746,23551,-5,'Norfolk, Virginia 23551',6996,8577);
INSERT INTO "django_geo_db_zipcode" VALUES(9747,23601,-5,'Newport News, Virginia 23601',6682,8588);
INSERT INTO "django_geo_db_zipcode" VALUES(9748,23602,-5,'Newport News, Virginia 23602',6682,8589);
INSERT INTO "django_geo_db_zipcode" VALUES(9749,23603,-5,'Newport News, Virginia 23603',6682,8590);
INSERT INTO "django_geo_db_zipcode" VALUES(9750,23604,-5,'Fort Eustis, Virginia 23604',6997,8591);
INSERT INTO "django_geo_db_zipcode" VALUES(9751,23605,-5,'Newport News, Virginia 23605',6682,8592);
INSERT INTO "django_geo_db_zipcode" VALUES(9752,23606,-5,'Newport News, Virginia 23606',6682,8593);
INSERT INTO "django_geo_db_zipcode" VALUES(9753,23607,-5,'Newport News, Virginia 23607',6682,8594);
INSERT INTO "django_geo_db_zipcode" VALUES(9754,23608,-5,'Newport News, Virginia 23608',6682,8595);
INSERT INTO "django_geo_db_zipcode" VALUES(9755,23609,-5,'Newport News, Virginia 23609',6682,8596);
INSERT INTO "django_geo_db_zipcode" VALUES(9756,23612,-5,'Newport News, Virginia 23612',6682,8596);
INSERT INTO "django_geo_db_zipcode" VALUES(9757,23620,-5,'Franklin, Virginia 23620',6998,8597);
INSERT INTO "django_geo_db_zipcode" VALUES(9758,23628,-5,'Newport News, Virginia 23628',6682,8596);
INSERT INTO "django_geo_db_zipcode" VALUES(9759,23630,-5,'Hampton, Virginia 23630',6999,8598);
INSERT INTO "django_geo_db_zipcode" VALUES(9760,23631,-5,'Hampton, Virginia 23631',6999,8598);
INSERT INTO "django_geo_db_zipcode" VALUES(9761,23642,-5,'Virginia Beach, Virginia 23642',6989,8599);
INSERT INTO "django_geo_db_zipcode" VALUES(9762,23651,-5,'Fort Monroe, Virginia 23651',7000,8600);
INSERT INTO "django_geo_db_zipcode" VALUES(9763,23653,-5,'Hampton, Virginia 23653',6999,8598);
INSERT INTO "django_geo_db_zipcode" VALUES(9764,23661,-5,'Hampton, Virginia 23661',6999,8601);
INSERT INTO "django_geo_db_zipcode" VALUES(9765,23662,-5,'Poquoson, Virginia 23662',7001,8602);
INSERT INTO "django_geo_db_zipcode" VALUES(9766,23663,-5,'Hampton, Virginia 23663',6999,8603);
INSERT INTO "django_geo_db_zipcode" VALUES(9767,23664,-5,'Hampton, Virginia 23664',6999,8604);
INSERT INTO "django_geo_db_zipcode" VALUES(9768,23665,-5,'Hampton, Virginia 23665',6999,8605);
INSERT INTO "django_geo_db_zipcode" VALUES(9769,23666,-5,'Hampton, Virginia 23666',6999,8606);
INSERT INTO "django_geo_db_zipcode" VALUES(9770,23667,-5,'Hampton, Virginia 23667',6999,8607);
INSERT INTO "django_geo_db_zipcode" VALUES(9771,23668,-5,'Hampton, Virginia 23668',6999,8608);
INSERT INTO "django_geo_db_zipcode" VALUES(9772,23669,-5,'Hampton, Virginia 23669',6999,8609);
INSERT INTO "django_geo_db_zipcode" VALUES(9773,23670,-5,'Hampton, Virginia 23670',6999,8598);
INSERT INTO "django_geo_db_zipcode" VALUES(9774,23681,-5,'Hampton, Virginia 23681',6999,8598);
INSERT INTO "django_geo_db_zipcode" VALUES(9775,23690,-5,'Yorktown, Virginia 23690',7002,8610);
INSERT INTO "django_geo_db_zipcode" VALUES(9776,23691,-5,'Yorktown, Virginia 23691',7002,8611);
INSERT INTO "django_geo_db_zipcode" VALUES(9777,23692,-5,'Yorktown, Virginia 23692',7002,8612);
INSERT INTO "django_geo_db_zipcode" VALUES(9778,23693,-5,'Yorktown, Virginia 23693',7002,8613);
INSERT INTO "django_geo_db_zipcode" VALUES(9779,23694,-5,'Lackey, Virginia 23694',7003,8614);
INSERT INTO "django_geo_db_zipcode" VALUES(9780,23696,-5,'Seaford, Virginia 23696',7004,8615);
INSERT INTO "django_geo_db_zipcode" VALUES(9781,23701,-5,'Portsmouth, Virginia 23701',7005,8616);
INSERT INTO "django_geo_db_zipcode" VALUES(9782,23702,-5,'Portsmouth, Virginia 23702',7005,8617);
INSERT INTO "django_geo_db_zipcode" VALUES(9783,23703,-5,'Portsmouth, Virginia 23703',7005,8618);
INSERT INTO "django_geo_db_zipcode" VALUES(9784,23704,-5,'Portsmouth, Virginia 23704',7005,8619);
INSERT INTO "django_geo_db_zipcode" VALUES(9785,23705,-5,'Portsmouth, Virginia 23705',7005,8620);
INSERT INTO "django_geo_db_zipcode" VALUES(9786,23707,-5,'Portsmouth, Virginia 23707',7005,8621);
INSERT INTO "django_geo_db_zipcode" VALUES(9787,23708,-5,'Portsmouth, Virginia 23708',7005,8622);
INSERT INTO "django_geo_db_zipcode" VALUES(9788,23709,-5,'Portsmouth, Virginia 23709',7005,8620);
INSERT INTO "django_geo_db_zipcode" VALUES(9789,23801,-5,'Fort Lee, Virginia 23801',7006,8623);
INSERT INTO "django_geo_db_zipcode" VALUES(9790,23803,-5,'Petersburg, Virginia 23803',7007,8624);
INSERT INTO "django_geo_db_zipcode" VALUES(9791,23804,-5,'Petersburg, Virginia 23804',7007,8625);
INSERT INTO "django_geo_db_zipcode" VALUES(9792,23805,-5,'Petersburg, Virginia 23805',7007,8626);
INSERT INTO "django_geo_db_zipcode" VALUES(9793,23806,-5,'Petersburg, Virginia 23806',7007,8625);
INSERT INTO "django_geo_db_zipcode" VALUES(9794,23810,-5,'Cape Charles, Virginia 23810',6938,8627);
INSERT INTO "django_geo_db_zipcode" VALUES(9795,23814,-5,'Gloucester Point, Virginia 23814',6849,8628);
INSERT INTO "django_geo_db_zipcode" VALUES(9796,23821,-5,'Alberta, Virginia 23821',7008,8629);
INSERT INTO "django_geo_db_zipcode" VALUES(9797,23822,-5,'Ammon, Virginia 23822',7009,8630);
INSERT INTO "django_geo_db_zipcode" VALUES(9798,23824,-5,'Blackstone, Virginia 23824',7010,8631);
INSERT INTO "django_geo_db_zipcode" VALUES(9799,23827,-5,'Boykins, Virginia 23827',7011,8632);
INSERT INTO "django_geo_db_zipcode" VALUES(9800,23828,-5,'Branchville, Virginia 23828',7012,8633);
INSERT INTO "django_geo_db_zipcode" VALUES(9801,23829,-5,'Capron, Virginia 23829',7013,8634);
INSERT INTO "django_geo_db_zipcode" VALUES(9802,23830,-5,'Carson, Virginia 23830',7014,8635);
INSERT INTO "django_geo_db_zipcode" VALUES(9803,23831,-5,'Chester, Virginia 23831',7015,8636);
INSERT INTO "django_geo_db_zipcode" VALUES(9804,23832,-5,'Chesterfield, Virginia 23832',7016,8637);
INSERT INTO "django_geo_db_zipcode" VALUES(9805,23833,-5,'Church Road, Virginia 23833',7017,8638);
INSERT INTO "django_geo_db_zipcode" VALUES(9806,23834,-5,'Colonial Heights, Virginia 23834',7018,8639);
INSERT INTO "django_geo_db_zipcode" VALUES(9807,23836,-5,'Chester, Virginia 23836',7015,8640);
INSERT INTO "django_geo_db_zipcode" VALUES(9808,23837,-5,'Courtland, Virginia 23837',7019,8641);
INSERT INTO "django_geo_db_zipcode" VALUES(9809,23838,-5,'Chesterfield, Virginia 23838',7016,8642);
INSERT INTO "django_geo_db_zipcode" VALUES(9810,23839,-5,'Dendron, Virginia 23839',7020,8643);
INSERT INTO "django_geo_db_zipcode" VALUES(9811,23840,-5,'Dewitt, Virginia 23840',7021,8644);
INSERT INTO "django_geo_db_zipcode" VALUES(9812,23841,-5,'Dinwiddie, Virginia 23841',7022,8645);
INSERT INTO "django_geo_db_zipcode" VALUES(9813,23842,-5,'Disputanta, Virginia 23842',7023,8646);
INSERT INTO "django_geo_db_zipcode" VALUES(9814,23843,-5,'Dolphin, Virginia 23843',7024,8647);
INSERT INTO "django_geo_db_zipcode" VALUES(9815,23844,-5,'Drewryville, Virginia 23844',7025,8648);
INSERT INTO "django_geo_db_zipcode" VALUES(9816,23845,-5,'Ebony, Virginia 23845',7026,8649);
INSERT INTO "django_geo_db_zipcode" VALUES(9817,23846,-5,'Elberon, Virginia 23846',7027,8650);
INSERT INTO "django_geo_db_zipcode" VALUES(9818,23847,-5,'Emporia, Virginia 23847',7028,8651);
INSERT INTO "django_geo_db_zipcode" VALUES(9819,23850,-5,'Ford, Virginia 23850',7029,8652);
INSERT INTO "django_geo_db_zipcode" VALUES(9820,23851,-5,'Franklin, Virginia 23851',6998,8653);
INSERT INTO "django_geo_db_zipcode" VALUES(9821,23856,-5,'Freeman, Virginia 23856',7030,8654);
INSERT INTO "django_geo_db_zipcode" VALUES(9822,23857,-5,'Gasburg, Virginia 23857',7031,8655);
INSERT INTO "django_geo_db_zipcode" VALUES(9823,23860,-5,'Hopewell, Virginia 23860',7032,8656);
INSERT INTO "django_geo_db_zipcode" VALUES(9824,23866,-5,'Ivor, Virginia 23866',7033,8657);
INSERT INTO "django_geo_db_zipcode" VALUES(9825,23867,-5,'Jarratt, Virginia 23867',7034,8658);
INSERT INTO "django_geo_db_zipcode" VALUES(9826,23868,-5,'Lawrenceville, Virginia 23868',7035,8659);
INSERT INTO "django_geo_db_zipcode" VALUES(9827,23870,-5,'Jarratt, Virginia 23870',7034,8660);
INSERT INTO "django_geo_db_zipcode" VALUES(9828,23872,-5,'McKenney, Virginia 23872',7036,8661);
INSERT INTO "django_geo_db_zipcode" VALUES(9829,23873,-5,'Meredithville, Virginia 23873',7037,8662);
INSERT INTO "django_geo_db_zipcode" VALUES(9830,23874,-5,'Newsoms, Virginia 23874',7038,8663);
INSERT INTO "django_geo_db_zipcode" VALUES(9831,23875,-5,'Prince George, Virginia 23875',7039,8664);
INSERT INTO "django_geo_db_zipcode" VALUES(9832,23876,-5,'Rawlings, Virginia 23876',7040,8665);
INSERT INTO "django_geo_db_zipcode" VALUES(9833,23878,-5,'Sedley, Virginia 23878',7041,8666);
INSERT INTO "django_geo_db_zipcode" VALUES(9834,23879,-5,'Skippers, Virginia 23879',7042,8667);
INSERT INTO "django_geo_db_zipcode" VALUES(9835,23881,-5,'Spring Grove, Virginia 23881',7043,8668);
INSERT INTO "django_geo_db_zipcode" VALUES(9836,23882,-5,'Stony Creek, Virginia 23882',7044,8669);
INSERT INTO "django_geo_db_zipcode" VALUES(9837,23883,-5,'Surry, Virginia 23883',7045,8670);
INSERT INTO "django_geo_db_zipcode" VALUES(9838,23884,-5,'Sussex, Virginia 23884',7046,8671);
INSERT INTO "django_geo_db_zipcode" VALUES(9839,23885,-5,'Sutherland, Virginia 23885',7047,8672);
INSERT INTO "django_geo_db_zipcode" VALUES(9840,23887,-5,'Valentines, Virginia 23887',7048,8673);
INSERT INTO "django_geo_db_zipcode" VALUES(9841,23888,-5,'Wakefield, Virginia 23888',7049,8674);
INSERT INTO "django_geo_db_zipcode" VALUES(9842,23889,-5,'Warfield, Virginia 23889',7050,8675);
INSERT INTO "django_geo_db_zipcode" VALUES(9843,23890,-5,'Waverly, Virginia 23890',7051,8676);
INSERT INTO "django_geo_db_zipcode" VALUES(9844,23891,-5,'Waverly, Virginia 23891',7051,8677);
INSERT INTO "django_geo_db_zipcode" VALUES(9845,23893,-5,'White Plains, Virginia 23893',7052,8678);
INSERT INTO "django_geo_db_zipcode" VALUES(9846,23894,-5,'Wilsons, Virginia 23894',7053,8679);
INSERT INTO "django_geo_db_zipcode" VALUES(9847,23897,-5,'Yale, Virginia 23897',7054,8680);
INSERT INTO "django_geo_db_zipcode" VALUES(9848,23898,-5,'Zuni, Virginia 23898',7055,8681);
INSERT INTO "django_geo_db_zipcode" VALUES(9849,23899,-5,'Claremont, Virginia 23899',7056,8682);
INSERT INTO "django_geo_db_zipcode" VALUES(9850,23901,-5,'Farmville, Virginia 23901',7057,8683);
INSERT INTO "django_geo_db_zipcode" VALUES(9851,23909,-5,'Farmville, Virginia 23909',7057,8684);
INSERT INTO "django_geo_db_zipcode" VALUES(9852,23915,-5,'Baskerville, Virginia 23915',7058,8685);
INSERT INTO "django_geo_db_zipcode" VALUES(9853,23917,-5,'Boydton, Virginia 23917',7059,8686);
INSERT INTO "django_geo_db_zipcode" VALUES(9854,23919,-5,'Bracey, Virginia 23919',7060,8687);
INSERT INTO "django_geo_db_zipcode" VALUES(9855,23920,-5,'Brodnax, Virginia 23920',7061,8688);
INSERT INTO "django_geo_db_zipcode" VALUES(9856,23921,-5,'Buckingham, Virginia 23921',7062,8689);
INSERT INTO "django_geo_db_zipcode" VALUES(9857,23922,-5,'Burkeville, Virginia 23922',7063,8690);
INSERT INTO "django_geo_db_zipcode" VALUES(9858,23923,-5,'Charlotte Court House, Virginia 23923',7064,8691);
INSERT INTO "django_geo_db_zipcode" VALUES(9859,23924,-5,'Chase City, Virginia 23924',7065,8692);
INSERT INTO "django_geo_db_zipcode" VALUES(9860,23927,-5,'Clarksville, Virginia 23927',7066,8693);
INSERT INTO "django_geo_db_zipcode" VALUES(9861,23930,-5,'Crewe, Virginia 23930',7067,8694);
INSERT INTO "django_geo_db_zipcode" VALUES(9862,23934,-5,'Cullen, Virginia 23934',7068,8695);
INSERT INTO "django_geo_db_zipcode" VALUES(9863,23936,-5,'Dillwyn, Virginia 23936',7069,8696);
INSERT INTO "django_geo_db_zipcode" VALUES(9864,23937,-5,'Drakes Branch, Virginia 23937',7070,8697);
INSERT INTO "django_geo_db_zipcode" VALUES(9865,23938,-5,'Dundas, Virginia 23938',7071,8698);
INSERT INTO "django_geo_db_zipcode" VALUES(9866,23939,-5,'Evergreen, Virginia 23939',7072,8699);
INSERT INTO "django_geo_db_zipcode" VALUES(9867,23941,-5,'Fort Mitchell, Virginia 23941',7073,8700);
INSERT INTO "django_geo_db_zipcode" VALUES(9868,23942,-5,'Green Bay, Virginia 23942',7074,8701);
INSERT INTO "django_geo_db_zipcode" VALUES(9869,23943,-5,'Hampden Sydney, Virginia 23943',7075,8702);
INSERT INTO "django_geo_db_zipcode" VALUES(9870,23944,-5,'Kenbridge, Virginia 23944',7076,8703);
INSERT INTO "django_geo_db_zipcode" VALUES(9871,23947,-5,'Keysville, Virginia 23947',7077,8704);
INSERT INTO "django_geo_db_zipcode" VALUES(9872,23950,-5,'La Crosse, Virginia 23950',7078,8705);
INSERT INTO "django_geo_db_zipcode" VALUES(9873,23952,-5,'Lunenburg, Virginia 23952',7079,8706);
INSERT INTO "django_geo_db_zipcode" VALUES(9874,23954,-5,'Meherrin, Virginia 23954',7080,8707);
INSERT INTO "django_geo_db_zipcode" VALUES(9875,23955,-5,'Nottoway, Virginia 23955',7081,8708);
INSERT INTO "django_geo_db_zipcode" VALUES(9876,23958,-5,'Pamplin, Virginia 23958',7082,8709);
INSERT INTO "django_geo_db_zipcode" VALUES(9877,23959,-5,'Phenix, Virginia 23959',7083,8710);
INSERT INTO "django_geo_db_zipcode" VALUES(9878,23960,-5,'Prospect, Virginia 23960',7084,8711);
INSERT INTO "django_geo_db_zipcode" VALUES(9879,23962,-5,'Randolph, Virginia 23962',7085,8712);
INSERT INTO "django_geo_db_zipcode" VALUES(9880,23963,-5,'Red House, Virginia 23963',7086,8713);
INSERT INTO "django_geo_db_zipcode" VALUES(9881,23964,-5,'Red Oak, Virginia 23964',7087,8714);
INSERT INTO "django_geo_db_zipcode" VALUES(9882,23966,-5,'Rice, Virginia 23966',7088,8715);
INSERT INTO "django_geo_db_zipcode" VALUES(9883,23967,-5,'Saxe, Virginia 23967',7089,8716);
INSERT INTO "django_geo_db_zipcode" VALUES(9884,23968,-5,'Skipwith, Virginia 23968',7090,8717);
INSERT INTO "django_geo_db_zipcode" VALUES(9885,23970,-5,'South Hill, Virginia 23970',7091,8718);
INSERT INTO "django_geo_db_zipcode" VALUES(9886,23974,-5,'Victoria, Virginia 23974',7092,8719);
INSERT INTO "django_geo_db_zipcode" VALUES(9887,23976,-5,'Wylliesburg, Virginia 23976',7093,8720);
INSERT INTO "django_geo_db_zipcode" VALUES(9888,23999,-5,'Richmond, Virginia 23999',6930,8721);
INSERT INTO "django_geo_db_zipcode" VALUES(9889,24001,-5,'Roanoke, Virginia 24001',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9890,24002,-5,'Roanoke, Virginia 24002',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9891,24003,-5,'Roanoke, Virginia 24003',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9892,24004,-5,'Roanoke, Virginia 24004',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9893,24005,-5,'Roanoke, Virginia 24005',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9894,24006,-5,'Roanoke, Virginia 24006',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9895,24007,-5,'Roanoke, Virginia 24007',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9896,24008,-5,'Roanoke, Virginia 24008',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9897,24009,-5,'Roanoke, Virginia 24009',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9898,24010,-5,'Roanoke, Virginia 24010',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9899,24011,-5,'Roanoke, Virginia 24011',7094,8723);
INSERT INTO "django_geo_db_zipcode" VALUES(9900,24012,-5,'Roanoke, Virginia 24012',7094,8724);
INSERT INTO "django_geo_db_zipcode" VALUES(9901,24013,-5,'Roanoke, Virginia 24013',7094,8725);
INSERT INTO "django_geo_db_zipcode" VALUES(9902,24014,-5,'Roanoke, Virginia 24014',7094,8726);
INSERT INTO "django_geo_db_zipcode" VALUES(9903,24015,-5,'Roanoke, Virginia 24015',7094,8727);
INSERT INTO "django_geo_db_zipcode" VALUES(9904,24016,-5,'Roanoke, Virginia 24016',7094,8728);
INSERT INTO "django_geo_db_zipcode" VALUES(9905,24017,-5,'Roanoke, Virginia 24017',7094,8729);
INSERT INTO "django_geo_db_zipcode" VALUES(9906,24018,-5,'Roanoke, Virginia 24018',7094,8730);
INSERT INTO "django_geo_db_zipcode" VALUES(9907,24019,-5,'Roanoke, Virginia 24019',7094,8731);
INSERT INTO "django_geo_db_zipcode" VALUES(9908,24020,-5,'Roanoke, Virginia 24020',7094,8732);
INSERT INTO "django_geo_db_zipcode" VALUES(9909,24022,-5,'Roanoke, Virginia 24022',7094,8733);
INSERT INTO "django_geo_db_zipcode" VALUES(9910,24023,-5,'Roanoke, Virginia 24023',7094,8734);
INSERT INTO "django_geo_db_zipcode" VALUES(9911,24024,-5,'Roanoke, Virginia 24024',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9912,24025,-5,'Roanoke, Virginia 24025',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9913,24026,-5,'Roanoke, Virginia 24026',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9914,24027,-5,'Roanoke, Virginia 24027',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9915,24028,-5,'Roanoke, Virginia 24028',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9916,24029,-5,'Roanoke, Virginia 24029',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9917,24030,-5,'Roanoke, Virginia 24030',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9918,24031,-5,'Roanoke, Virginia 24031',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9919,24032,-5,'Roanoke, Virginia 24032',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9920,24033,-5,'Roanoke, Virginia 24033',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9921,24034,-5,'Roanoke, Virginia 24034',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9922,24035,-5,'Roanoke, Virginia 24035',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9923,24036,-5,'Roanoke, Virginia 24036',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9924,24037,-5,'Roanoke, Virginia 24037',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9925,24038,-5,'Roanoke, Virginia 24038',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9926,24040,-5,'Roanoke, Virginia 24040',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9927,24042,-5,'Roanoke, Virginia 24042',7094,8735);
INSERT INTO "django_geo_db_zipcode" VALUES(9928,24043,-5,'Roanoke, Virginia 24043',7094,8736);
INSERT INTO "django_geo_db_zipcode" VALUES(9929,24044,-5,'Roanoke, Virginia 24044',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9930,24045,-5,'Roanoke, Virginia 24045',7094,8737);
INSERT INTO "django_geo_db_zipcode" VALUES(9931,24048,-5,'Roanoke, Virginia 24048',7094,8722);
INSERT INTO "django_geo_db_zipcode" VALUES(9932,24050,-5,'Roanoke, Virginia 24050',7094,8738);
INSERT INTO "django_geo_db_zipcode" VALUES(9933,24053,-5,'Ararat, Virginia 24053',7095,8739);
INSERT INTO "django_geo_db_zipcode" VALUES(9934,24054,-5,'Axton, Virginia 24054',7096,8740);
INSERT INTO "django_geo_db_zipcode" VALUES(9935,24055,-5,'Bassett, Virginia 24055',7097,8741);
INSERT INTO "django_geo_db_zipcode" VALUES(9936,24058,-5,'Belspring, Virginia 24058',7098,8742);
INSERT INTO "django_geo_db_zipcode" VALUES(9937,24059,-5,'Bent Mountain, Virginia 24059',7099,8743);
INSERT INTO "django_geo_db_zipcode" VALUES(9938,24060,-5,'Blacksburg, Virginia 24060',7100,8744);
INSERT INTO "django_geo_db_zipcode" VALUES(9939,24061,-5,'Blacksburg, Virginia 24061',7100,8745);
INSERT INTO "django_geo_db_zipcode" VALUES(9940,24062,-5,'Blacksburg, Virginia 24062',7100,8746);
INSERT INTO "django_geo_db_zipcode" VALUES(9941,24063,-5,'Blacksburg, Virginia 24063',7100,8746);
INSERT INTO "django_geo_db_zipcode" VALUES(9942,24064,-5,'Blue Ridge, Virginia 24064',7101,8747);
INSERT INTO "django_geo_db_zipcode" VALUES(9943,24065,-5,'Boones Mill, Virginia 24065',7102,8748);
INSERT INTO "django_geo_db_zipcode" VALUES(9944,24066,-5,'Buchanan, Virginia 24066',7103,8749);
INSERT INTO "django_geo_db_zipcode" VALUES(9945,24067,-5,'Callaway, Virginia 24067',7104,8750);
INSERT INTO "django_geo_db_zipcode" VALUES(9946,24068,-5,'Christiansburg, Virginia 24068',7105,8751);
INSERT INTO "django_geo_db_zipcode" VALUES(9947,24069,-5,'Cascade, Virginia 24069',7106,8752);
INSERT INTO "django_geo_db_zipcode" VALUES(9948,24070,-5,'Catawba, Virginia 24070',7107,8753);
INSERT INTO "django_geo_db_zipcode" VALUES(9949,24072,-5,'Check, Virginia 24072',7108,8754);
INSERT INTO "django_geo_db_zipcode" VALUES(9950,24073,-5,'Christiansburg, Virginia 24073',7105,8755);
INSERT INTO "django_geo_db_zipcode" VALUES(9951,24076,-5,'Claudville, Virginia 24076',7109,8756);
INSERT INTO "django_geo_db_zipcode" VALUES(9952,24077,-5,'Cloverdale, Virginia 24077',7110,8757);
INSERT INTO "django_geo_db_zipcode" VALUES(9953,24078,-5,'Collinsville, Virginia 24078',7111,8758);
INSERT INTO "django_geo_db_zipcode" VALUES(9954,24079,-5,'Copper Hill, Virginia 24079',7112,8759);
INSERT INTO "django_geo_db_zipcode" VALUES(9955,24082,-5,'Critz, Virginia 24082',7113,8760);
INSERT INTO "django_geo_db_zipcode" VALUES(9956,24083,-5,'Daleville, Virginia 24083',7114,8761);
INSERT INTO "django_geo_db_zipcode" VALUES(9957,24084,-5,'Dublin, Virginia 24084',7115,8762);
INSERT INTO "django_geo_db_zipcode" VALUES(9958,24085,-5,'Eagle Rock, Virginia 24085',7116,8763);
INSERT INTO "django_geo_db_zipcode" VALUES(9959,24086,-5,'Eggleston, Virginia 24086',7117,8764);
INSERT INTO "django_geo_db_zipcode" VALUES(9960,24087,-5,'Elliston, Virginia 24087',7118,8765);
INSERT INTO "django_geo_db_zipcode" VALUES(9961,24088,-5,'Ferrum, Virginia 24088',7119,8766);
INSERT INTO "django_geo_db_zipcode" VALUES(9962,24089,-5,'Fieldale, Virginia 24089',7120,8767);
INSERT INTO "django_geo_db_zipcode" VALUES(9963,24090,-5,'Fincastle, Virginia 24090',7121,8768);
INSERT INTO "django_geo_db_zipcode" VALUES(9964,24091,-5,'Floyd, Virginia 24091',7122,8769);
INSERT INTO "django_geo_db_zipcode" VALUES(9965,24092,-5,'Glade Hill, Virginia 24092',7123,8770);
INSERT INTO "django_geo_db_zipcode" VALUES(9966,24093,-5,'Glen Lyn, Virginia 24093',7124,8771);
INSERT INTO "django_geo_db_zipcode" VALUES(9967,24094,-5,'Goldbond, Virginia 24094',7125,8772);
INSERT INTO "django_geo_db_zipcode" VALUES(9968,24095,-5,'Goodview, Virginia 24095',7126,8773);
INSERT INTO "django_geo_db_zipcode" VALUES(9969,24101,-5,'Hardy, Virginia 24101',7127,8774);
INSERT INTO "django_geo_db_zipcode" VALUES(9970,24102,-5,'Henry, Virginia 24102',7128,8775);
INSERT INTO "django_geo_db_zipcode" VALUES(9971,24104,-5,'Huddleston, Virginia 24104',7129,8776);
INSERT INTO "django_geo_db_zipcode" VALUES(9972,24105,-5,'Indian Valley, Virginia 24105',7130,8777);
INSERT INTO "django_geo_db_zipcode" VALUES(9973,24111,-5,'McCoy, Virginia 24111',7131,8746);
INSERT INTO "django_geo_db_zipcode" VALUES(9974,24112,-5,'Martinsville, Virginia 24112',7132,8778);
INSERT INTO "django_geo_db_zipcode" VALUES(9975,24113,-5,'Martinsville, Virginia 24113',7132,8779);
INSERT INTO "django_geo_db_zipcode" VALUES(9976,24114,-5,'Martinsville, Virginia 24114',7132,8779);
INSERT INTO "django_geo_db_zipcode" VALUES(9977,24115,-5,'Martinsville, Virginia 24115',7132,8779);
INSERT INTO "django_geo_db_zipcode" VALUES(9978,24120,-5,'Meadows Of Dan, Virginia 24120',7133,8780);
INSERT INTO "django_geo_db_zipcode" VALUES(9979,24121,-5,'Moneta, Virginia 24121',7134,8781);
INSERT INTO "django_geo_db_zipcode" VALUES(9980,24122,-5,'Montvale, Virginia 24122',7135,8782);
INSERT INTO "django_geo_db_zipcode" VALUES(9981,24124,-5,'Narrows, Virginia 24124',7136,8783);
INSERT INTO "django_geo_db_zipcode" VALUES(9982,24126,-5,'Newbern, Virginia 24126',7137,8784);
INSERT INTO "django_geo_db_zipcode" VALUES(9983,24127,-5,'New Castle, Virginia 24127',7138,8785);
INSERT INTO "django_geo_db_zipcode" VALUES(9984,24128,-5,'Newport, Virginia 24128',7139,8786);
INSERT INTO "django_geo_db_zipcode" VALUES(9985,24129,-5,'New River, Virginia 24129',7140,8787);
INSERT INTO "django_geo_db_zipcode" VALUES(9986,24130,-5,'Oriskany, Virginia 24130',7141,8738);
INSERT INTO "django_geo_db_zipcode" VALUES(9987,24131,-5,'Paint Bank, Virginia 24131',7142,8788);
INSERT INTO "django_geo_db_zipcode" VALUES(9988,24132,-5,'Parrott, Virginia 24132',7143,8789);
INSERT INTO "django_geo_db_zipcode" VALUES(9989,24133,-5,'Patrick Springs, Virginia 24133',7144,8790);
INSERT INTO "django_geo_db_zipcode" VALUES(9990,24134,-5,'Pearisburg, Virginia 24134',7145,8791);
INSERT INTO "django_geo_db_zipcode" VALUES(9991,24136,-5,'Pembroke, Virginia 24136',7146,8792);
INSERT INTO "django_geo_db_zipcode" VALUES(9992,24137,-5,'Penhook, Virginia 24137',7147,8793);
INSERT INTO "django_geo_db_zipcode" VALUES(9993,24138,-5,'Pilot, Virginia 24138',7148,8794);
INSERT INTO "django_geo_db_zipcode" VALUES(9994,24139,-5,'Pittsville, Virginia 24139',7149,8795);
INSERT INTO "django_geo_db_zipcode" VALUES(9995,24141,-5,'Radford, Virginia 24141',7150,8796);
INSERT INTO "django_geo_db_zipcode" VALUES(9996,24142,-5,'Radford, Virginia 24142',7150,8797);
INSERT INTO "django_geo_db_zipcode" VALUES(9997,24143,-5,'Radford, Virginia 24143',7150,8798);
INSERT INTO "django_geo_db_zipcode" VALUES(9998,24146,-5,'Redwood, Virginia 24146',7151,8799);
INSERT INTO "django_geo_db_zipcode" VALUES(9999,24147,-5,'Rich Creek, Virginia 24147',7152,8800);
INSERT INTO "django_geo_db_zipcode" VALUES(10000,24148,-5,'Ridgeway, Virginia 24148',7153,8801);
INSERT INTO "django_geo_db_zipcode" VALUES(10001,24149,-5,'Riner, Virginia 24149',7154,8802);
INSERT INTO "django_geo_db_zipcode" VALUES(10002,24150,-5,'Ripplemead, Virginia 24150',7155,8803);
INSERT INTO "django_geo_db_zipcode" VALUES(10003,24151,-5,'Rocky Mount, Virginia 24151',7156,8804);
INSERT INTO "django_geo_db_zipcode" VALUES(10004,24153,-5,'Salem, Virginia 24153',7157,8805);
INSERT INTO "django_geo_db_zipcode" VALUES(10005,24155,-5,'Salem, Virginia 24155',7157,8806);
INSERT INTO "django_geo_db_zipcode" VALUES(10006,24156,-5,'Salem, Virginia 24156',7157,8806);
INSERT INTO "django_geo_db_zipcode" VALUES(10007,24157,-5,'Salem, Virginia 24157',7157,8806);
INSERT INTO "django_geo_db_zipcode" VALUES(10008,24161,-5,'Sandy Level, Virginia 24161',7158,8807);
INSERT INTO "django_geo_db_zipcode" VALUES(10009,24162,-5,'Shawsville, Virginia 24162',7159,8808);
INSERT INTO "django_geo_db_zipcode" VALUES(10010,24165,-5,'Spencer, Virginia 24165',7160,8809);
INSERT INTO "django_geo_db_zipcode" VALUES(10011,24167,-5,'Staffordsville, Virginia 24167',7161,8810);
INSERT INTO "django_geo_db_zipcode" VALUES(10012,24168,-5,'Stanleytown, Virginia 24168',7162,8811);
INSERT INTO "django_geo_db_zipcode" VALUES(10013,24171,-5,'Stuart, Virginia 24171',7163,8812);
INSERT INTO "django_geo_db_zipcode" VALUES(10014,24174,-5,'Thaxton, Virginia 24174',7164,8813);
INSERT INTO "django_geo_db_zipcode" VALUES(10015,24175,-5,'Troutville, Virginia 24175',7165,8814);
INSERT INTO "django_geo_db_zipcode" VALUES(10016,24176,-5,'Union Hall, Virginia 24176',7166,8815);
INSERT INTO "django_geo_db_zipcode" VALUES(10017,24177,-5,'Vesta, Virginia 24177',7167,8816);
INSERT INTO "django_geo_db_zipcode" VALUES(10018,24178,-5,'Villamont, Virginia 24178',7168,8817);
INSERT INTO "django_geo_db_zipcode" VALUES(10019,24179,-5,'Vinton, Virginia 24179',7169,8818);
INSERT INTO "django_geo_db_zipcode" VALUES(10020,24184,-5,'Wirtz, Virginia 24184',7170,8819);
INSERT INTO "django_geo_db_zipcode" VALUES(10021,24185,-5,'Woolwine, Virginia 24185',7171,8820);
INSERT INTO "django_geo_db_zipcode" VALUES(10022,24201,-5,'Bristol, Virginia 24201',7172,8821);
INSERT INTO "django_geo_db_zipcode" VALUES(10023,24202,-5,'Bristol, Virginia 24202',7172,8822);
INSERT INTO "django_geo_db_zipcode" VALUES(10024,24203,-5,'Bristol, Virginia 24203',7172,8823);
INSERT INTO "django_geo_db_zipcode" VALUES(10025,24209,-5,'Bristol, Virginia 24209',7172,8823);
INSERT INTO "django_geo_db_zipcode" VALUES(10026,24210,-5,'Abingdon, Virginia 24210',7173,8824);
INSERT INTO "django_geo_db_zipcode" VALUES(10027,24211,-5,'Abingdon, Virginia 24211',7173,8825);
INSERT INTO "django_geo_db_zipcode" VALUES(10028,24212,-5,'Abingdon, Virginia 24212',7173,8826);
INSERT INTO "django_geo_db_zipcode" VALUES(10029,24215,-5,'Andover, Virginia 24215',7174,8827);
INSERT INTO "django_geo_db_zipcode" VALUES(10030,24216,-5,'Appalachia, Virginia 24216',7175,8828);
INSERT INTO "django_geo_db_zipcode" VALUES(10031,24217,-5,'Bee, Virginia 24217',7176,8829);
INSERT INTO "django_geo_db_zipcode" VALUES(10032,24218,-5,'Ben Hur, Virginia 24218',7177,8830);
INSERT INTO "django_geo_db_zipcode" VALUES(10033,24219,-5,'Big Stone Gap, Virginia 24219',7178,8831);
INSERT INTO "django_geo_db_zipcode" VALUES(10034,24220,-5,'Birchleaf, Virginia 24220',7179,8832);
INSERT INTO "django_geo_db_zipcode" VALUES(10035,24221,-5,'Blackwater, Virginia 24221',7180,8833);
INSERT INTO "django_geo_db_zipcode" VALUES(10036,24224,-5,'Castlewood, Virginia 24224',7181,8834);
INSERT INTO "django_geo_db_zipcode" VALUES(10037,24225,-5,'Cleveland, Virginia 24225',7182,8835);
INSERT INTO "django_geo_db_zipcode" VALUES(10038,24226,-5,'Clinchco, Virginia 24226',7183,8836);
INSERT INTO "django_geo_db_zipcode" VALUES(10039,24228,-5,'Clintwood, Virginia 24228',7184,8837);
INSERT INTO "django_geo_db_zipcode" VALUES(10040,24230,-5,'Coeburn, Virginia 24230',7185,8838);
INSERT INTO "django_geo_db_zipcode" VALUES(10041,24236,-5,'Damascus, Virginia 24236',7186,8839);
INSERT INTO "django_geo_db_zipcode" VALUES(10042,24237,-5,'Dante, Virginia 24237',7187,8840);
INSERT INTO "django_geo_db_zipcode" VALUES(10043,24239,-5,'Davenport, Virginia 24239',7188,8841);
INSERT INTO "django_geo_db_zipcode" VALUES(10044,24243,-5,'Dryden, Virginia 24243',7189,8842);
INSERT INTO "django_geo_db_zipcode" VALUES(10045,24244,-5,'Duffield, Virginia 24244',7190,8843);
INSERT INTO "django_geo_db_zipcode" VALUES(10046,24245,-5,'Dungannon, Virginia 24245',7191,8844);
INSERT INTO "django_geo_db_zipcode" VALUES(10047,24246,-5,'East Stone Gap, Virginia 24246',7192,8845);
INSERT INTO "django_geo_db_zipcode" VALUES(10048,24248,-5,'Ewing, Virginia 24248',7193,8846);
INSERT INTO "django_geo_db_zipcode" VALUES(10049,24250,-5,'Fort Blackmore, Virginia 24250',7194,8847);
INSERT INTO "django_geo_db_zipcode" VALUES(10050,24251,-5,'Gate City, Virginia 24251',7195,8848);
INSERT INTO "django_geo_db_zipcode" VALUES(10051,24256,-5,'Haysi, Virginia 24256',7196,8849);
INSERT INTO "django_geo_db_zipcode" VALUES(10052,24258,-5,'Hiltons, Virginia 24258',7197,8850);
INSERT INTO "django_geo_db_zipcode" VALUES(10053,24260,-5,'Honaker, Virginia 24260',7198,8851);
INSERT INTO "django_geo_db_zipcode" VALUES(10054,24263,-5,'Jonesville, Virginia 24263',7199,8852);
INSERT INTO "django_geo_db_zipcode" VALUES(10055,24265,-5,'Keokee, Virginia 24265',7200,8853);
INSERT INTO "django_geo_db_zipcode" VALUES(10056,24266,-5,'Lebanon, Virginia 24266',7201,8854);
INSERT INTO "django_geo_db_zipcode" VALUES(10057,24269,-5,'McClure, Virginia 24269',7202,8855);
INSERT INTO "django_geo_db_zipcode" VALUES(10058,24270,-5,'Mendota, Virginia 24270',7203,8856);
INSERT INTO "django_geo_db_zipcode" VALUES(10059,24271,-5,'Nickelsville, Virginia 24271',7204,8857);
INSERT INTO "django_geo_db_zipcode" VALUES(10060,24272,-5,'Nora, Virginia 24272',7205,8858);
INSERT INTO "django_geo_db_zipcode" VALUES(10061,24273,-5,'Norton, Virginia 24273',7206,8859);
INSERT INTO "django_geo_db_zipcode" VALUES(10062,24274,-5,'Pound, Virginia 24274',7207,8860);
INSERT INTO "django_geo_db_zipcode" VALUES(10063,24277,-5,'Pennington Gap, Virginia 24277',7208,8861);
INSERT INTO "django_geo_db_zipcode" VALUES(10064,24279,-5,'Pound, Virginia 24279',7207,8862);
INSERT INTO "django_geo_db_zipcode" VALUES(10065,24280,-5,'Rosedale, Virginia 24280',7209,8863);
INSERT INTO "django_geo_db_zipcode" VALUES(10066,24281,-5,'Rose Hill, Virginia 24281',7210,8864);
INSERT INTO "django_geo_db_zipcode" VALUES(10067,24282,-5,'Saint Charles, Virginia 24282',7211,8865);
INSERT INTO "django_geo_db_zipcode" VALUES(10068,24283,-5,'Saint Paul, Virginia 24283',7212,8866);
INSERT INTO "django_geo_db_zipcode" VALUES(10069,24285,-5,'Stonega, Virginia 24285',7213,8867);
INSERT INTO "django_geo_db_zipcode" VALUES(10070,24289,-5,'Trammel, Virginia 24289',7214,8868);
INSERT INTO "django_geo_db_zipcode" VALUES(10071,24290,-5,'Weber City, Virginia 24290',7215,8869);
INSERT INTO "django_geo_db_zipcode" VALUES(10072,24292,-5,'Whitetop, Virginia 24292',7216,8870);
INSERT INTO "django_geo_db_zipcode" VALUES(10073,24293,-5,'Wise, Virginia 24293',7217,8871);
INSERT INTO "django_geo_db_zipcode" VALUES(10074,24301,-5,'Pulaski, Virginia 24301',7218,8872);
INSERT INTO "django_geo_db_zipcode" VALUES(10075,24311,-5,'Atkins, Virginia 24311',7219,8873);
INSERT INTO "django_geo_db_zipcode" VALUES(10076,24312,-5,'Austinville, Virginia 24312',7220,8874);
INSERT INTO "django_geo_db_zipcode" VALUES(10077,24313,-5,'Barren Springs, Virginia 24313',7221,8875);
INSERT INTO "django_geo_db_zipcode" VALUES(10078,24314,-5,'Bastian, Virginia 24314',7222,8876);
INSERT INTO "django_geo_db_zipcode" VALUES(10079,24315,-5,'Bland, Virginia 24315',7223,8877);
INSERT INTO "django_geo_db_zipcode" VALUES(10080,24316,-5,'Broadford, Virginia 24316',7224,8878);
INSERT INTO "django_geo_db_zipcode" VALUES(10081,24317,-5,'Cana, Virginia 24317',7225,8879);
INSERT INTO "django_geo_db_zipcode" VALUES(10082,24318,-5,'Ceres, Virginia 24318',7226,8880);
INSERT INTO "django_geo_db_zipcode" VALUES(10083,24319,-5,'Chilhowie, Virginia 24319',7227,8881);
INSERT INTO "django_geo_db_zipcode" VALUES(10084,24322,-5,'Cripple Creek, Virginia 24322',7228,8882);
INSERT INTO "django_geo_db_zipcode" VALUES(10085,24323,-5,'Crockett, Virginia 24323',7229,8883);
INSERT INTO "django_geo_db_zipcode" VALUES(10086,24324,-5,'Draper, Virginia 24324',7230,8884);
INSERT INTO "django_geo_db_zipcode" VALUES(10087,24325,-5,'Dugspur, Virginia 24325',7231,8885);
INSERT INTO "django_geo_db_zipcode" VALUES(10088,24326,-5,'Elk Creek, Virginia 24326',7232,8886);
INSERT INTO "django_geo_db_zipcode" VALUES(10089,24327,-5,'Emory, Virginia 24327',7233,8887);
INSERT INTO "django_geo_db_zipcode" VALUES(10090,24328,-5,'Fancy Gap, Virginia 24328',7234,8888);
INSERT INTO "django_geo_db_zipcode" VALUES(10091,24330,-5,'Fries, Virginia 24330',7235,8889);
INSERT INTO "django_geo_db_zipcode" VALUES(10092,24333,-5,'Galax, Virginia 24333',7236,8890);
INSERT INTO "django_geo_db_zipcode" VALUES(10093,24338,-5,'Fries, Virginia 24338',7235,8891);
INSERT INTO "django_geo_db_zipcode" VALUES(10094,24340,-5,'Glade Spring, Virginia 24340',7237,8892);
INSERT INTO "django_geo_db_zipcode" VALUES(10095,24343,-5,'Hillsville, Virginia 24343',7238,8893);
INSERT INTO "django_geo_db_zipcode" VALUES(10096,24347,-5,'Hiwassee, Virginia 24347',7239,8894);
INSERT INTO "django_geo_db_zipcode" VALUES(10097,24348,-5,'Independence, Virginia 24348',7240,8895);
INSERT INTO "django_geo_db_zipcode" VALUES(10098,24350,-5,'Ivanhoe, Virginia 24350',7241,8896);
INSERT INTO "django_geo_db_zipcode" VALUES(10099,24351,-5,'Lambsburg, Virginia 24351',7242,8897);
INSERT INTO "django_geo_db_zipcode" VALUES(10100,24352,-5,'Laurel Fork, Virginia 24352',7243,8898);
INSERT INTO "django_geo_db_zipcode" VALUES(10101,24354,-5,'Marion, Virginia 24354',7244,8899);
INSERT INTO "django_geo_db_zipcode" VALUES(10102,24360,-5,'Max Meadows, Virginia 24360',7245,8900);
INSERT INTO "django_geo_db_zipcode" VALUES(10103,24361,-5,'Meadowview, Virginia 24361',7246,8901);
INSERT INTO "django_geo_db_zipcode" VALUES(10104,24363,-5,'Mouth Of Wilson, Virginia 24363',7247,8902);
INSERT INTO "django_geo_db_zipcode" VALUES(10105,24366,-5,'Rocky Gap, Virginia 24366',7248,8903);
INSERT INTO "django_geo_db_zipcode" VALUES(10106,24368,-5,'Rural Retreat, Virginia 24368',7249,8904);
INSERT INTO "django_geo_db_zipcode" VALUES(10107,24370,-5,'Saltville, Virginia 24370',7250,8905);
INSERT INTO "django_geo_db_zipcode" VALUES(10108,24373,-5,'Seven Mile Ford, Virginia 24373',7251,8906);
INSERT INTO "django_geo_db_zipcode" VALUES(10109,24374,-5,'Speedwell, Virginia 24374',7252,8907);
INSERT INTO "django_geo_db_zipcode" VALUES(10110,24375,-5,'Sugar Grove, Virginia 24375',7253,8908);
INSERT INTO "django_geo_db_zipcode" VALUES(10111,24377,-5,'Tannersville, Virginia 24377',7254,8909);
INSERT INTO "django_geo_db_zipcode" VALUES(10112,24378,-5,'Trout Dale, Virginia 24378',7255,8910);
INSERT INTO "django_geo_db_zipcode" VALUES(10113,24379,-5,'Volney, Virginia 24379',7256,8911);
INSERT INTO "django_geo_db_zipcode" VALUES(10114,24380,-5,'Willis, Virginia 24380',7257,8912);
INSERT INTO "django_geo_db_zipcode" VALUES(10115,24381,-5,'Woodlawn, Virginia 24381',7258,8913);
INSERT INTO "django_geo_db_zipcode" VALUES(10116,24382,-5,'Wytheville, Virginia 24382',7259,8914);
INSERT INTO "django_geo_db_zipcode" VALUES(10117,24401,-5,'Staunton, Virginia 24401',7260,8915);
INSERT INTO "django_geo_db_zipcode" VALUES(10118,24402,-5,'Staunton, Virginia 24402',7260,8916);
INSERT INTO "django_geo_db_zipcode" VALUES(10119,24407,-5,'Staunton, Virginia 24407',7260,8917);
INSERT INTO "django_geo_db_zipcode" VALUES(10120,24411,-5,'Augusta Springs, Virginia 24411',7261,8918);
INSERT INTO "django_geo_db_zipcode" VALUES(10121,24412,-5,'Bacova, Virginia 24412',7262,8919);
INSERT INTO "django_geo_db_zipcode" VALUES(10122,24413,-5,'Blue Grass, Virginia 24413',7263,8920);
INSERT INTO "django_geo_db_zipcode" VALUES(10123,24415,-5,'Brownsburg, Virginia 24415',7264,8921);
INSERT INTO "django_geo_db_zipcode" VALUES(10124,24416,-5,'Buena Vista, Virginia 24416',7265,8922);
INSERT INTO "django_geo_db_zipcode" VALUES(10125,24421,-5,'Churchville, Virginia 24421',7266,8923);
INSERT INTO "django_geo_db_zipcode" VALUES(10126,24422,-5,'Clifton Forge, Virginia 24422',7267,8924);
INSERT INTO "django_geo_db_zipcode" VALUES(10127,24426,-5,'Covington, Virginia 24426',7268,8925);
INSERT INTO "django_geo_db_zipcode" VALUES(10128,24430,-5,'Craigsville, Virginia 24430',7269,8926);
INSERT INTO "django_geo_db_zipcode" VALUES(10129,24431,-5,'Crimora, Virginia 24431',7270,8927);
INSERT INTO "django_geo_db_zipcode" VALUES(10130,24432,-5,'Deerfield, Virginia 24432',7271,8928);
INSERT INTO "django_geo_db_zipcode" VALUES(10131,24433,-5,'Doe Hill, Virginia 24433',7272,8929);
INSERT INTO "django_geo_db_zipcode" VALUES(10132,24435,-5,'Fairfield, Virginia 24435',7273,8930);
INSERT INTO "django_geo_db_zipcode" VALUES(10133,24437,-5,'Fort Defiance, Virginia 24437',7274,8931);
INSERT INTO "django_geo_db_zipcode" VALUES(10134,24438,-5,'Glen Wilton, Virginia 24438',7275,8738);
INSERT INTO "django_geo_db_zipcode" VALUES(10135,24439,-5,'Goshen, Virginia 24439',7276,8932);
INSERT INTO "django_geo_db_zipcode" VALUES(10136,24440,-5,'Greenville, Virginia 24440',7277,8933);
INSERT INTO "django_geo_db_zipcode" VALUES(10137,24441,-5,'Grottoes, Virginia 24441',7278,8934);
INSERT INTO "django_geo_db_zipcode" VALUES(10138,24442,-5,'Head Waters, Virginia 24442',7279,8935);
INSERT INTO "django_geo_db_zipcode" VALUES(10139,24444,-5,'Iron Gate, Virginia 24444',7280,8936);
INSERT INTO "django_geo_db_zipcode" VALUES(10140,24445,-5,'Hot Springs, Virginia 24445',7281,8937);
INSERT INTO "django_geo_db_zipcode" VALUES(10141,24448,-5,'Iron Gate, Virginia 24448',7280,8938);
INSERT INTO "django_geo_db_zipcode" VALUES(10142,24450,-5,'Lexington, Virginia 24450',7282,8939);
INSERT INTO "django_geo_db_zipcode" VALUES(10143,24457,-5,'Low Moor, Virginia 24457',7283,8940);
INSERT INTO "django_geo_db_zipcode" VALUES(10144,24458,-5,'McDowell, Virginia 24458',7284,8941);
INSERT INTO "django_geo_db_zipcode" VALUES(10145,24459,-5,'Middlebrook, Virginia 24459',7285,8942);
INSERT INTO "django_geo_db_zipcode" VALUES(10146,24460,-5,'Millboro, Virginia 24460',7286,8943);
INSERT INTO "django_geo_db_zipcode" VALUES(10147,24463,-5,'Mint Spring, Virginia 24463',7287,8944);
INSERT INTO "django_geo_db_zipcode" VALUES(10148,24464,-5,'Montebello, Virginia 24464',7288,8945);
INSERT INTO "django_geo_db_zipcode" VALUES(10149,24465,-5,'Monterey, Virginia 24465',7289,8946);
INSERT INTO "django_geo_db_zipcode" VALUES(10150,24467,-5,'Mount Sidney, Virginia 24467',7290,8947);
INSERT INTO "django_geo_db_zipcode" VALUES(10151,24468,-5,'Mustoe, Virginia 24468',7291,8948);
INSERT INTO "django_geo_db_zipcode" VALUES(10152,24469,-5,'New Hope, Virginia 24469',7292,8917);
INSERT INTO "django_geo_db_zipcode" VALUES(10153,24471,-5,'Port Republic, Virginia 24471',7293,8949);
INSERT INTO "django_geo_db_zipcode" VALUES(10154,24472,-5,'Raphine, Virginia 24472',7294,8950);
INSERT INTO "django_geo_db_zipcode" VALUES(10155,24473,-5,'Rockbridge Baths, Virginia 24473',7295,8951);
INSERT INTO "django_geo_db_zipcode" VALUES(10156,24474,-5,'Selma, Virginia 24474',7296,8952);
INSERT INTO "django_geo_db_zipcode" VALUES(10157,24475,-5,'Spottswood, Virginia 24475',7297,8953);
INSERT INTO "django_geo_db_zipcode" VALUES(10158,24476,-5,'Steeles Tavern, Virginia 24476',7298,8917);
INSERT INTO "django_geo_db_zipcode" VALUES(10159,24477,-5,'Stuarts Draft, Virginia 24477',7299,8954);
INSERT INTO "django_geo_db_zipcode" VALUES(10160,24479,-5,'Swoope, Virginia 24479',7300,8955);
INSERT INTO "django_geo_db_zipcode" VALUES(10161,24482,-5,'Verona, Virginia 24482',7301,8956);
INSERT INTO "django_geo_db_zipcode" VALUES(10162,24483,-5,'Vesuvius, Virginia 24483',7302,8957);
INSERT INTO "django_geo_db_zipcode" VALUES(10163,24484,-5,'Warm Springs, Virginia 24484',7303,8958);
INSERT INTO "django_geo_db_zipcode" VALUES(10164,24485,-5,'West Augusta, Virginia 24485',7304,8959);
INSERT INTO "django_geo_db_zipcode" VALUES(10165,24486,-5,'Weyers Cave, Virginia 24486',7305,8960);
INSERT INTO "django_geo_db_zipcode" VALUES(10166,24487,-5,'Williamsville, Virginia 24487',7306,8961);
INSERT INTO "django_geo_db_zipcode" VALUES(10167,24501,-5,'Lynchburg, Virginia 24501',7307,8962);
INSERT INTO "django_geo_db_zipcode" VALUES(10168,24502,-5,'Lynchburg, Virginia 24502',7307,8963);
INSERT INTO "django_geo_db_zipcode" VALUES(10169,24503,-5,'Lynchburg, Virginia 24503',7307,8964);
INSERT INTO "django_geo_db_zipcode" VALUES(10170,24504,-5,'Lynchburg, Virginia 24504',7307,8965);
INSERT INTO "django_geo_db_zipcode" VALUES(10171,24505,-5,'Lynchburg, Virginia 24505',7307,8966);
INSERT INTO "django_geo_db_zipcode" VALUES(10172,24506,-5,'Lynchburg, Virginia 24506',7307,8967);
INSERT INTO "django_geo_db_zipcode" VALUES(10173,24512,-5,'Lynchburg, Virginia 24512',7307,8968);
INSERT INTO "django_geo_db_zipcode" VALUES(10174,24513,-5,'Lynchburg, Virginia 24513',7307,8969);
INSERT INTO "django_geo_db_zipcode" VALUES(10175,24514,-5,'Lynchburg, Virginia 24514',7307,8966);
INSERT INTO "django_geo_db_zipcode" VALUES(10176,24515,-5,'Lynchburg, Virginia 24515',7307,8966);
INSERT INTO "django_geo_db_zipcode" VALUES(10177,24517,-5,'Altavista, Virginia 24517',7308,8970);
INSERT INTO "django_geo_db_zipcode" VALUES(10178,24520,-5,'Alton, Virginia 24520',7309,8971);
INSERT INTO "django_geo_db_zipcode" VALUES(10179,24521,-5,'Amherst, Virginia 24521',7310,8972);
INSERT INTO "django_geo_db_zipcode" VALUES(10180,24522,-5,'Appomattox, Virginia 24522',7311,8973);
INSERT INTO "django_geo_db_zipcode" VALUES(10181,24523,-5,'Bedford, Virginia 24523',7312,8974);
INSERT INTO "django_geo_db_zipcode" VALUES(10182,24526,-5,'Big Island, Virginia 24526',7313,8975);
INSERT INTO "django_geo_db_zipcode" VALUES(10183,24527,-5,'Blairs, Virginia 24527',7314,8976);
INSERT INTO "django_geo_db_zipcode" VALUES(10184,24528,-5,'Brookneal, Virginia 24528',7315,8977);
INSERT INTO "django_geo_db_zipcode" VALUES(10185,24529,-5,'Buffalo Junction, Virginia 24529',7316,8978);
INSERT INTO "django_geo_db_zipcode" VALUES(10186,24530,-5,'Callands, Virginia 24530',7317,8979);
INSERT INTO "django_geo_db_zipcode" VALUES(10187,24531,-5,'Chatham, Virginia 24531',7318,8980);
INSERT INTO "django_geo_db_zipcode" VALUES(10188,24533,-5,'Clifford, Virginia 24533',7319,8981);
INSERT INTO "django_geo_db_zipcode" VALUES(10189,24534,-5,'Clover, Virginia 24534',7320,8982);
INSERT INTO "django_geo_db_zipcode" VALUES(10190,24535,-5,'Cluster Springs, Virginia 24535',7321,8983);
INSERT INTO "django_geo_db_zipcode" VALUES(10191,24536,-5,'Coleman Falls, Virginia 24536',7322,8984);
INSERT INTO "django_geo_db_zipcode" VALUES(10192,24538,-5,'Concord, Virginia 24538',7323,8985);
INSERT INTO "django_geo_db_zipcode" VALUES(10193,24539,-5,'Crystal Hill, Virginia 24539',7324,8986);
INSERT INTO "django_geo_db_zipcode" VALUES(10194,24540,-5,'Danville, Virginia 24540',7325,8987);
INSERT INTO "django_geo_db_zipcode" VALUES(10195,24541,-5,'Danville, Virginia 24541',7325,8988);
INSERT INTO "django_geo_db_zipcode" VALUES(10196,24542,-5,'Danville, Virginia 24542',7325,8989);
INSERT INTO "django_geo_db_zipcode" VALUES(10197,24543,-5,'Danville, Virginia 24543',7325,8990);
INSERT INTO "django_geo_db_zipcode" VALUES(10198,24544,-5,'Danville, Virginia 24544',7325,8990);
INSERT INTO "django_geo_db_zipcode" VALUES(10199,24549,-5,'Dry Fork, Virginia 24549',7326,8991);
INSERT INTO "django_geo_db_zipcode" VALUES(10200,24550,-5,'Evington, Virginia 24550',7327,8992);
INSERT INTO "django_geo_db_zipcode" VALUES(10201,24551,-5,'Forest, Virginia 24551',7328,8993);
INSERT INTO "django_geo_db_zipcode" VALUES(10202,24553,-5,'Gladstone, Virginia 24553',7329,8994);
INSERT INTO "django_geo_db_zipcode" VALUES(10203,24554,-5,'Gladys, Virginia 24554',7330,8995);
INSERT INTO "django_geo_db_zipcode" VALUES(10204,24555,-5,'Glasgow, Virginia 24555',7331,8996);
INSERT INTO "django_geo_db_zipcode" VALUES(10205,24556,-5,'Goode, Virginia 24556',7332,8997);
INSERT INTO "django_geo_db_zipcode" VALUES(10206,24557,-5,'Gretna, Virginia 24557',7333,8998);
INSERT INTO "django_geo_db_zipcode" VALUES(10207,24558,-5,'Halifax, Virginia 24558',7334,8999);
INSERT INTO "django_geo_db_zipcode" VALUES(10208,24562,-5,'Howardsville, Virginia 24562',7335,9000);
INSERT INTO "django_geo_db_zipcode" VALUES(10209,24563,-5,'Hurt, Virginia 24563',7336,9001);
INSERT INTO "django_geo_db_zipcode" VALUES(10210,24565,-5,'Java, Virginia 24565',7337,9002);
INSERT INTO "django_geo_db_zipcode" VALUES(10211,24566,-5,'Keeling, Virginia 24566',7338,9003);
INSERT INTO "django_geo_db_zipcode" VALUES(10212,24569,-5,'Long Island, Virginia 24569',7339,9004);
INSERT INTO "django_geo_db_zipcode" VALUES(10213,24570,-5,'Lowry, Virginia 24570',7340,9005);
INSERT INTO "django_geo_db_zipcode" VALUES(10214,24571,-5,'Lynch Station, Virginia 24571',7341,9006);
INSERT INTO "django_geo_db_zipcode" VALUES(10215,24572,-5,'Madison Heights, Virginia 24572',7342,9007);
INSERT INTO "django_geo_db_zipcode" VALUES(10216,24574,-5,'Monroe, Virginia 24574',7343,9008);
INSERT INTO "django_geo_db_zipcode" VALUES(10217,24576,-5,'Naruna, Virginia 24576',7344,8969);
INSERT INTO "django_geo_db_zipcode" VALUES(10218,24577,-5,'Nathalie, Virginia 24577',7345,9009);
INSERT INTO "django_geo_db_zipcode" VALUES(10219,24578,-5,'Natural Bridge, Virginia 24578',7346,9010);
INSERT INTO "django_geo_db_zipcode" VALUES(10220,24579,-5,'Natural Bridge Station, Virginia 24579',7347,9011);
INSERT INTO "django_geo_db_zipcode" VALUES(10221,24580,-5,'Nelson, Virginia 24580',7348,9012);
INSERT INTO "django_geo_db_zipcode" VALUES(10222,24581,-5,'Norwood, Virginia 24581',7349,9013);
INSERT INTO "django_geo_db_zipcode" VALUES(10223,24585,-5,'Republican Grove, Virginia 24585',7350,9014);
INSERT INTO "django_geo_db_zipcode" VALUES(10224,24586,-5,'Ringgold, Virginia 24586',7351,9015);
INSERT INTO "django_geo_db_zipcode" VALUES(10225,24588,-5,'Rustburg, Virginia 24588',7352,9016);
INSERT INTO "django_geo_db_zipcode" VALUES(10226,24589,-5,'Scottsburg, Virginia 24589',7353,9017);
INSERT INTO "django_geo_db_zipcode" VALUES(10227,24590,-5,'Scottsville, Virginia 24590',7354,9018);
INSERT INTO "django_geo_db_zipcode" VALUES(10228,24592,-5,'South Boston, Virginia 24592',7355,9019);
INSERT INTO "django_geo_db_zipcode" VALUES(10229,24593,-5,'Spout Spring, Virginia 24593',7356,9020);
INSERT INTO "django_geo_db_zipcode" VALUES(10230,24594,-5,'Sutherlin, Virginia 24594',7357,9021);
INSERT INTO "django_geo_db_zipcode" VALUES(10231,24595,-5,'Sweet Briar, Virginia 24595',7358,9022);
INSERT INTO "django_geo_db_zipcode" VALUES(10232,24597,-5,'Vernon Hill, Virginia 24597',7359,9023);
INSERT INTO "django_geo_db_zipcode" VALUES(10233,24598,-5,'Virgilina, Virginia 24598',7360,9024);
INSERT INTO "django_geo_db_zipcode" VALUES(10234,24599,-5,'Wingina, Virginia 24599',7361,9025);
INSERT INTO "django_geo_db_zipcode" VALUES(10235,24601,-5,'Amonate, Virginia 24601',7362,9026);
INSERT INTO "django_geo_db_zipcode" VALUES(10236,24602,-5,'Bandy, Virginia 24602',7363,9027);
INSERT INTO "django_geo_db_zipcode" VALUES(10237,24603,-5,'Big Rock, Virginia 24603',7364,9028);
INSERT INTO "django_geo_db_zipcode" VALUES(10238,24604,-5,'Bishop, Virginia 24604',7365,9029);
INSERT INTO "django_geo_db_zipcode" VALUES(10239,24605,-5,'Bluefield, Virginia 24605',7366,9030);
INSERT INTO "django_geo_db_zipcode" VALUES(10240,24606,-5,'Boissevain, Virginia 24606',7367,9031);
INSERT INTO "django_geo_db_zipcode" VALUES(10241,24607,-5,'Breaks, Virginia 24607',7368,9032);
INSERT INTO "django_geo_db_zipcode" VALUES(10242,24608,-5,'Burkes Garden, Virginia 24608',7369,9033);
INSERT INTO "django_geo_db_zipcode" VALUES(10243,24609,-5,'Cedar Bluff, Virginia 24609',7370,9034);
INSERT INTO "django_geo_db_zipcode" VALUES(10244,24612,-5,'Doran, Virginia 24612',7371,9035);
INSERT INTO "django_geo_db_zipcode" VALUES(10245,24613,-5,'Falls Mills, Virginia 24613',7372,9036);
INSERT INTO "django_geo_db_zipcode" VALUES(10246,24614,-5,'Grundy, Virginia 24614',7373,9037);
INSERT INTO "django_geo_db_zipcode" VALUES(10247,24618,-5,'Harman, Virginia 24618',7374,9038);
INSERT INTO "django_geo_db_zipcode" VALUES(10248,24619,-5,'Horsepen, Virginia 24619',7375,9033);
INSERT INTO "django_geo_db_zipcode" VALUES(10249,24620,-5,'Hurley, Virginia 24620',7376,9039);
INSERT INTO "django_geo_db_zipcode" VALUES(10250,24622,-5,'Jewell Ridge, Virginia 24622',7377,9040);
INSERT INTO "django_geo_db_zipcode" VALUES(10251,24624,-5,'Keen Mountain, Virginia 24624',7378,9041);
INSERT INTO "django_geo_db_zipcode" VALUES(10252,24627,-5,'Mavisdale, Virginia 24627',7379,9038);
INSERT INTO "django_geo_db_zipcode" VALUES(10253,24628,-5,'Maxie, Virginia 24628',7380,9042);
INSERT INTO "django_geo_db_zipcode" VALUES(10254,24630,-5,'North Tazewell, Virginia 24630',7381,9043);
INSERT INTO "django_geo_db_zipcode" VALUES(10255,24631,-5,'Oakwood, Virginia 24631',7382,9044);
INSERT INTO "django_geo_db_zipcode" VALUES(10256,24634,-5,'Pilgrims Knob, Virginia 24634',7383,9045);
INSERT INTO "django_geo_db_zipcode" VALUES(10257,24635,-5,'Pocahontas, Virginia 24635',7384,9046);
INSERT INTO "django_geo_db_zipcode" VALUES(10258,24637,-5,'Pounding Mill, Virginia 24637',7385,9047);
INSERT INTO "django_geo_db_zipcode" VALUES(10259,24639,-5,'Raven, Virginia 24639',7386,9048);
INSERT INTO "django_geo_db_zipcode" VALUES(10260,24640,-5,'Red Ash, Virginia 24640',7387,9033);
INSERT INTO "django_geo_db_zipcode" VALUES(10261,24641,-5,'Richlands, Virginia 24641',7388,9049);
INSERT INTO "django_geo_db_zipcode" VALUES(10262,24646,-5,'Rowe, Virginia 24646',7389,9050);
INSERT INTO "django_geo_db_zipcode" VALUES(10263,24647,-5,'Shortt Gap, Virginia 24647',7390,9038);
INSERT INTO "django_geo_db_zipcode" VALUES(10264,24649,-5,'Swords Creek, Virginia 24649',7391,9051);
INSERT INTO "django_geo_db_zipcode" VALUES(10265,24651,-5,'Tazewell, Virginia 24651',7392,9052);
INSERT INTO "django_geo_db_zipcode" VALUES(10266,24656,-5,'Vansant, Virginia 24656',7393,9053);
INSERT INTO "django_geo_db_zipcode" VALUES(10267,24657,-5,'Whitewood, Virginia 24657',7394,9054);
INSERT INTO "django_geo_db_zipcode" VALUES(10268,24658,-5,'Wolford, Virginia 24658',7395,9038);
INSERT INTO "django_geo_db_zipcode" VALUES(10269,24701,-5,'Bluefield, West Virginia 24701',7396,9055);
INSERT INTO "django_geo_db_zipcode" VALUES(10270,24704,-5,'Bluefield, West Virginia 24704',7396,9056);
INSERT INTO "django_geo_db_zipcode" VALUES(10271,24712,-5,'Athens, West Virginia 24712',7397,9057);
INSERT INTO "django_geo_db_zipcode" VALUES(10272,24714,-5,'Beeson, West Virginia 24714',7398,9058);
INSERT INTO "django_geo_db_zipcode" VALUES(10273,24715,-5,'Bramwell, West Virginia 24715',7399,9059);
INSERT INTO "django_geo_db_zipcode" VALUES(10274,24716,-5,'Bud, West Virginia 24716',7400,9060);
INSERT INTO "django_geo_db_zipcode" VALUES(10275,24719,-5,'Covel, West Virginia 24719',7401,9061);
INSERT INTO "django_geo_db_zipcode" VALUES(10276,24724,-5,'Freeman, West Virginia 24724',7402,9062);
INSERT INTO "django_geo_db_zipcode" VALUES(10277,24726,-5,'Herndon, West Virginia 24726',7403,9063);
INSERT INTO "django_geo_db_zipcode" VALUES(10278,24729,-5,'Hiawatha, West Virginia 24729',7404,9064);
INSERT INTO "django_geo_db_zipcode" VALUES(10279,24731,-5,'Kegley, West Virginia 24731',7405,9065);
INSERT INTO "django_geo_db_zipcode" VALUES(10280,24732,-5,'Kellysville, West Virginia 24732',7406,9064);
INSERT INTO "django_geo_db_zipcode" VALUES(10281,24733,-5,'Lashmeet, West Virginia 24733',7407,9066);
INSERT INTO "django_geo_db_zipcode" VALUES(10282,24736,-5,'Matoaka, West Virginia 24736',7408,9067);
INSERT INTO "django_geo_db_zipcode" VALUES(10283,24737,-5,'Montcalm, West Virginia 24737',7409,9068);
INSERT INTO "django_geo_db_zipcode" VALUES(10284,24738,-5,'Nemours, West Virginia 24738',7410,9064);
INSERT INTO "django_geo_db_zipcode" VALUES(10285,24739,-5,'Oakvale, West Virginia 24739',7411,9069);
INSERT INTO "django_geo_db_zipcode" VALUES(10286,24740,-5,'Princeton, West Virginia 24740',7412,9070);
INSERT INTO "django_geo_db_zipcode" VALUES(10287,24747,-5,'Rock, West Virginia 24747',7413,9071);
INSERT INTO "django_geo_db_zipcode" VALUES(10288,24751,-5,'Wolfe, West Virginia 24751',7414,9064);
INSERT INTO "django_geo_db_zipcode" VALUES(10289,24801,-5,'Welch, West Virginia 24801',7415,9072);
INSERT INTO "django_geo_db_zipcode" VALUES(10290,24808,-5,'Anawalt, West Virginia 24808',7416,9073);
INSERT INTO "django_geo_db_zipcode" VALUES(10291,24811,-5,'Avondale, West Virginia 24811',7417,9074);
INSERT INTO "django_geo_db_zipcode" VALUES(10292,24813,-5,'Bartley, West Virginia 24813',7418,9075);
INSERT INTO "django_geo_db_zipcode" VALUES(10293,24815,-5,'Berwind, West Virginia 24815',7419,9076);
INSERT INTO "django_geo_db_zipcode" VALUES(10294,24816,-5,'Big Sandy, West Virginia 24816',7420,9077);
INSERT INTO "django_geo_db_zipcode" VALUES(10295,24817,-5,'Bradshaw, West Virginia 24817',7421,9078);
INSERT INTO "django_geo_db_zipcode" VALUES(10296,24818,-5,'Brenton, West Virginia 24818',7422,9079);
INSERT INTO "django_geo_db_zipcode" VALUES(10297,24820,-5,'Capels, West Virginia 24820',7423,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10298,24821,-5,'Caretta, West Virginia 24821',7424,9081);
INSERT INTO "django_geo_db_zipcode" VALUES(10299,24822,-5,'Clear Fork, West Virginia 24822',7425,9082);
INSERT INTO "django_geo_db_zipcode" VALUES(10300,24823,-5,'Coal Mountain, West Virginia 24823',7426,9083);
INSERT INTO "django_geo_db_zipcode" VALUES(10301,24824,-5,'Coalwood, West Virginia 24824',7427,9084);
INSERT INTO "django_geo_db_zipcode" VALUES(10302,24825,-5,'Crumpler, West Virginia 24825',7428,9085);
INSERT INTO "django_geo_db_zipcode" VALUES(10303,24826,-5,'Cucumber, West Virginia 24826',7429,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10304,24827,-5,'Cyclone, West Virginia 24827',7430,9086);
INSERT INTO "django_geo_db_zipcode" VALUES(10305,24828,-5,'Davy, West Virginia 24828',7431,9087);
INSERT INTO "django_geo_db_zipcode" VALUES(10306,24829,-5,'Eckman, West Virginia 24829',7432,9088);
INSERT INTO "django_geo_db_zipcode" VALUES(10307,24830,-5,'Elbert, West Virginia 24830',7433,9089);
INSERT INTO "django_geo_db_zipcode" VALUES(10308,24831,-5,'Elkhorn, West Virginia 24831',7434,9090);
INSERT INTO "django_geo_db_zipcode" VALUES(10309,24832,-5,'English, West Virginia 24832',7435,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10310,24834,-5,'Fanrock, West Virginia 24834',7436,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10311,24836,-5,'Gary, West Virginia 24836',7437,9092);
INSERT INTO "django_geo_db_zipcode" VALUES(10312,24839,-5,'Hanover, West Virginia 24839',7438,9093);
INSERT INTO "django_geo_db_zipcode" VALUES(10313,24841,-5,'Havaco, West Virginia 24841',7439,9094);
INSERT INTO "django_geo_db_zipcode" VALUES(10314,24842,-5,'Hemphill, West Virginia 24842',7440,9095);
INSERT INTO "django_geo_db_zipcode" VALUES(10315,24843,-5,'Hensley, West Virginia 24843',7441,9096);
INSERT INTO "django_geo_db_zipcode" VALUES(10316,24844,-5,'Iaeger, West Virginia 24844',7442,9097);
INSERT INTO "django_geo_db_zipcode" VALUES(10317,24845,-5,'Ikes Fork, West Virginia 24845',7443,9098);
INSERT INTO "django_geo_db_zipcode" VALUES(10318,24846,-5,'Isaban, West Virginia 24846',7444,9099);
INSERT INTO "django_geo_db_zipcode" VALUES(10319,24847,-5,'Itmann, West Virginia 24847',7445,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10320,24848,-5,'Jenkinjones, West Virginia 24848',7446,9100);
INSERT INTO "django_geo_db_zipcode" VALUES(10321,24849,-5,'Jesse, West Virginia 24849',7447,9101);
INSERT INTO "django_geo_db_zipcode" VALUES(10322,24850,-5,'Jolo, West Virginia 24850',7448,9102);
INSERT INTO "django_geo_db_zipcode" VALUES(10323,24851,-5,'Justice, West Virginia 24851',7449,9103);
INSERT INTO "django_geo_db_zipcode" VALUES(10324,24852,-5,'Keystone, West Virginia 24852',7450,9104);
INSERT INTO "django_geo_db_zipcode" VALUES(10325,24853,-5,'Kimball, West Virginia 24853',7451,9105);
INSERT INTO "django_geo_db_zipcode" VALUES(10326,24854,-5,'Kopperston, West Virginia 24854',7452,9106);
INSERT INTO "django_geo_db_zipcode" VALUES(10327,24855,-5,'Kyle, West Virginia 24855',7453,9107);
INSERT INTO "django_geo_db_zipcode" VALUES(10328,24856,-5,'Leckie, West Virginia 24856',7454,9108);
INSERT INTO "django_geo_db_zipcode" VALUES(10329,24857,-5,'Lynco, West Virginia 24857',7455,9109);
INSERT INTO "django_geo_db_zipcode" VALUES(10330,24859,-5,'Marianna, West Virginia 24859',7456,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10331,24860,-5,'Matheny, West Virginia 24860',7457,9110);
INSERT INTO "django_geo_db_zipcode" VALUES(10332,24861,-5,'Maybeury, West Virginia 24861',7458,9111);
INSERT INTO "django_geo_db_zipcode" VALUES(10333,24862,-5,'Mohawk, West Virginia 24862',7459,9112);
INSERT INTO "django_geo_db_zipcode" VALUES(10334,24866,-5,'Newhall, West Virginia 24866',7460,9113);
INSERT INTO "django_geo_db_zipcode" VALUES(10335,24867,-5,'New Richmond, West Virginia 24867',7461,9114);
INSERT INTO "django_geo_db_zipcode" VALUES(10336,24868,-5,'Northfork, West Virginia 24868',7462,9115);
INSERT INTO "django_geo_db_zipcode" VALUES(10337,24869,-5,'North Spring, West Virginia 24869',7463,9116);
INSERT INTO "django_geo_db_zipcode" VALUES(10338,24870,-5,'Oceana, West Virginia 24870',7464,9117);
INSERT INTO "django_geo_db_zipcode" VALUES(10339,24871,-5,'Pageton, West Virginia 24871',7465,9118);
INSERT INTO "django_geo_db_zipcode" VALUES(10340,24872,-5,'Panther, West Virginia 24872',7466,9119);
INSERT INTO "django_geo_db_zipcode" VALUES(10341,24873,-5,'Paynesville, West Virginia 24873',7467,9120);
INSERT INTO "django_geo_db_zipcode" VALUES(10342,24874,-5,'Pineville, West Virginia 24874',7468,9121);
INSERT INTO "django_geo_db_zipcode" VALUES(10343,24877,-5,'Powhatan, West Virginia 24877',7469,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10344,24878,-5,'Premier, West Virginia 24878',7470,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10345,24879,-5,'Raysal, West Virginia 24879',7471,9122);
INSERT INTO "django_geo_db_zipcode" VALUES(10346,24880,-5,'Rock View, West Virginia 24880',7472,9123);
INSERT INTO "django_geo_db_zipcode" VALUES(10347,24881,-5,'Roderfield, West Virginia 24881',7473,9124);
INSERT INTO "django_geo_db_zipcode" VALUES(10348,24882,-5,'Simon, West Virginia 24882',7474,9125);
INSERT INTO "django_geo_db_zipcode" VALUES(10349,24883,-5,'Skygusty, West Virginia 24883',7475,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10350,24884,-5,'Squire, West Virginia 24884',7476,9126);
INSERT INTO "django_geo_db_zipcode" VALUES(10351,24887,-5,'Switchback, West Virginia 24887',7477,9127);
INSERT INTO "django_geo_db_zipcode" VALUES(10352,24888,-5,'Thorpe, West Virginia 24888',7478,9128);
INSERT INTO "django_geo_db_zipcode" VALUES(10353,24889,-5,'Twin Branch, West Virginia 24889',7479,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10354,24892,-5,'War, West Virginia 24892',7480,9129);
INSERT INTO "django_geo_db_zipcode" VALUES(10355,24894,-5,'Warriormine, West Virginia 24894',7481,9130);
INSERT INTO "django_geo_db_zipcode" VALUES(10356,24895,-5,'Wilcoe, West Virginia 24895',7482,9131);
INSERT INTO "django_geo_db_zipcode" VALUES(10357,24896,-5,'Wolf Pen, West Virginia 24896',7483,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10358,24897,-5,'Worth, West Virginia 24897',7484,9132);
INSERT INTO "django_geo_db_zipcode" VALUES(10359,24898,-5,'Wyoming, West Virginia 24898',7485,9133);
INSERT INTO "django_geo_db_zipcode" VALUES(10360,24899,-5,'Yukon, West Virginia 24899',7486,9080);
INSERT INTO "django_geo_db_zipcode" VALUES(10361,24901,-5,'Lewisburg, West Virginia 24901',7487,9134);
INSERT INTO "django_geo_db_zipcode" VALUES(10362,24902,-5,'Fairlea, West Virginia 24902',7488,9135);
INSERT INTO "django_geo_db_zipcode" VALUES(10363,24910,-5,'Alderson, West Virginia 24910',7489,9136);
INSERT INTO "django_geo_db_zipcode" VALUES(10364,24915,-5,'Arbovale, West Virginia 24915',7490,9137);
INSERT INTO "django_geo_db_zipcode" VALUES(10365,24916,-5,'Asbury, West Virginia 24916',7491,9138);
INSERT INTO "django_geo_db_zipcode" VALUES(10366,24917,-5,'Auto, West Virginia 24917',7492,9139);
INSERT INTO "django_geo_db_zipcode" VALUES(10367,24918,-5,'Ballard, West Virginia 24918',7493,9140);
INSERT INTO "django_geo_db_zipcode" VALUES(10368,24919,-5,'Ballengee, West Virginia 24919',7494,9141);
INSERT INTO "django_geo_db_zipcode" VALUES(10369,24920,-5,'Bartow, West Virginia 24920',7495,9142);
INSERT INTO "django_geo_db_zipcode" VALUES(10370,24924,-5,'Buckeye, West Virginia 24924',7496,9143);
INSERT INTO "django_geo_db_zipcode" VALUES(10371,24925,-5,'Caldwell, West Virginia 24925',7497,9144);
INSERT INTO "django_geo_db_zipcode" VALUES(10372,24927,-5,'Cass, West Virginia 24927',7498,9145);
INSERT INTO "django_geo_db_zipcode" VALUES(10373,24931,-5,'Crawley, West Virginia 24931',7499,9146);
INSERT INTO "django_geo_db_zipcode" VALUES(10374,24934,-5,'Dunmore, West Virginia 24934',7500,9147);
INSERT INTO "django_geo_db_zipcode" VALUES(10375,24935,-5,'Forest Hill, West Virginia 24935',7501,9148);
INSERT INTO "django_geo_db_zipcode" VALUES(10376,24936,-5,'Fort Spring, West Virginia 24936',7502,9149);
INSERT INTO "django_geo_db_zipcode" VALUES(10377,24938,-5,'Frankford, West Virginia 24938',7503,9150);
INSERT INTO "django_geo_db_zipcode" VALUES(10378,24941,-5,'Gap Mills, West Virginia 24941',7504,9151);
INSERT INTO "django_geo_db_zipcode" VALUES(10379,24942,-5,'Glace, West Virginia 24942',7505,9152);
INSERT INTO "django_geo_db_zipcode" VALUES(10380,24943,-5,'Grassy Meadows, West Virginia 24943',7506,9153);
INSERT INTO "django_geo_db_zipcode" VALUES(10381,24944,-5,'Green Bank, West Virginia 24944',7507,9154);
INSERT INTO "django_geo_db_zipcode" VALUES(10382,24945,-5,'Greenville, West Virginia 24945',7508,9155);
INSERT INTO "django_geo_db_zipcode" VALUES(10383,24946,-5,'Hillsboro, West Virginia 24946',7509,9156);
INSERT INTO "django_geo_db_zipcode" VALUES(10384,24950,-5,'Kieffer, West Virginia 24950',7510,9157);
INSERT INTO "django_geo_db_zipcode" VALUES(10385,24951,-5,'Lindside, West Virginia 24951',7511,9158);
INSERT INTO "django_geo_db_zipcode" VALUES(10386,24954,-5,'Marlinton, West Virginia 24954',7512,9159);
INSERT INTO "django_geo_db_zipcode" VALUES(10387,24957,-5,'Maxwelton, West Virginia 24957',7513,9160);
INSERT INTO "django_geo_db_zipcode" VALUES(10388,24958,-5,'Meadow Bluff, West Virginia 24958',7514,9139);
INSERT INTO "django_geo_db_zipcode" VALUES(10389,24961,-5,'Neola, West Virginia 24961',7515,9139);
INSERT INTO "django_geo_db_zipcode" VALUES(10390,24962,-5,'Pence Springs, West Virginia 24962',7516,9161);
INSERT INTO "django_geo_db_zipcode" VALUES(10391,24963,-5,'Peterstown, West Virginia 24963',7517,9162);
INSERT INTO "django_geo_db_zipcode" VALUES(10392,24966,-5,'Renick, West Virginia 24966',7518,9163);
INSERT INTO "django_geo_db_zipcode" VALUES(10393,24970,-5,'Ronceverte, West Virginia 24970',7519,9164);
INSERT INTO "django_geo_db_zipcode" VALUES(10394,24971,-5,'Lewisburg, West Virginia 24971',7487,9165);
INSERT INTO "django_geo_db_zipcode" VALUES(10395,24974,-5,'Secondcreek, West Virginia 24974',7520,9166);
INSERT INTO "django_geo_db_zipcode" VALUES(10396,24976,-5,'Sinks Grove, West Virginia 24976',7521,9167);
INSERT INTO "django_geo_db_zipcode" VALUES(10397,24977,-5,'Smoot, West Virginia 24977',7522,9168);
INSERT INTO "django_geo_db_zipcode" VALUES(10398,24981,-5,'Talcott, West Virginia 24981',7523,9169);
INSERT INTO "django_geo_db_zipcode" VALUES(10399,24983,-5,'Union, West Virginia 24983',7524,9170);
INSERT INTO "django_geo_db_zipcode" VALUES(10400,24984,-5,'Waiteville, West Virginia 24984',7525,9171);
INSERT INTO "django_geo_db_zipcode" VALUES(10401,24985,-5,'Wayside, West Virginia 24985',7526,9172);
INSERT INTO "django_geo_db_zipcode" VALUES(10402,24986,-5,'White Sulphur Springs, West Virginia 24986',7527,9173);
INSERT INTO "django_geo_db_zipcode" VALUES(10403,24991,-5,'Williamsburg, West Virginia 24991',7528,9174);
INSERT INTO "django_geo_db_zipcode" VALUES(10404,24993,-5,'Wolfcreek, West Virginia 24993',7529,9152);
INSERT INTO "django_geo_db_zipcode" VALUES(10405,25002,-5,'Alloy, West Virginia 25002',7530,9175);
INSERT INTO "django_geo_db_zipcode" VALUES(10406,25003,-5,'Alum Creek, West Virginia 25003',7531,9176);
INSERT INTO "django_geo_db_zipcode" VALUES(10407,25004,-5,'Ameagle, West Virginia 25004',7532,9177);
INSERT INTO "django_geo_db_zipcode" VALUES(10408,25005,-5,'Amma, West Virginia 25005',7533,9178);
INSERT INTO "django_geo_db_zipcode" VALUES(10409,25007,-5,'Arnett, West Virginia 25007',7534,9179);
INSERT INTO "django_geo_db_zipcode" VALUES(10410,25008,-5,'Artie, West Virginia 25008',7535,9180);
INSERT INTO "django_geo_db_zipcode" VALUES(10411,25009,-5,'Ashford, West Virginia 25009',7536,9181);
INSERT INTO "django_geo_db_zipcode" VALUES(10412,25010,-5,'Bald Knob, West Virginia 25010',7537,9182);
INSERT INTO "django_geo_db_zipcode" VALUES(10413,25011,-5,'Bancroft, West Virginia 25011',7538,9183);
INSERT INTO "django_geo_db_zipcode" VALUES(10414,25015,-5,'Belle, West Virginia 25015',7539,9184);
INSERT INTO "django_geo_db_zipcode" VALUES(10415,25018,-5,'Bentree, West Virginia 25018',7540,9185);
INSERT INTO "django_geo_db_zipcode" VALUES(10416,25019,-5,'Bickmore, West Virginia 25019',7541,9186);
INSERT INTO "django_geo_db_zipcode" VALUES(10417,25021,-5,'Bim, West Virginia 25021',7542,9187);
INSERT INTO "django_geo_db_zipcode" VALUES(10418,25022,-5,'Blair, West Virginia 25022',7543,9188);
INSERT INTO "django_geo_db_zipcode" VALUES(10419,25024,-5,'Bloomingrose, West Virginia 25024',7544,9189);
INSERT INTO "django_geo_db_zipcode" VALUES(10420,25025,-5,'Blount, West Virginia 25025',7545,9190);
INSERT INTO "django_geo_db_zipcode" VALUES(10421,25026,-5,'Blue Creek, West Virginia 25026',7546,9191);
INSERT INTO "django_geo_db_zipcode" VALUES(10422,25028,-5,'Bob White, West Virginia 25028',7547,9192);
INSERT INTO "django_geo_db_zipcode" VALUES(10423,25030,-5,'Bomont, West Virginia 25030',7548,9193);
INSERT INTO "django_geo_db_zipcode" VALUES(10424,25031,-5,'Boomer, West Virginia 25031',7549,9194);
INSERT INTO "django_geo_db_zipcode" VALUES(10425,25033,-5,'Buffalo, West Virginia 25033',7550,9195);
INSERT INTO "django_geo_db_zipcode" VALUES(10426,25035,-5,'Cabin Creek, West Virginia 25035',7551,9196);
INSERT INTO "django_geo_db_zipcode" VALUES(10427,25036,-5,'Cannelton, West Virginia 25036',7552,9197);
INSERT INTO "django_geo_db_zipcode" VALUES(10428,25039,-5,'Cedar Grove, West Virginia 25039',7553,9198);
INSERT INTO "django_geo_db_zipcode" VALUES(10429,25040,-5,'Charlton Heights, West Virginia 25040',7554,9199);
INSERT INTO "django_geo_db_zipcode" VALUES(10430,25043,-5,'Clay, West Virginia 25043',7555,9200);
INSERT INTO "django_geo_db_zipcode" VALUES(10431,25044,-5,'Clear Creek, West Virginia 25044',7556,9201);
INSERT INTO "django_geo_db_zipcode" VALUES(10432,25045,-5,'Clendenin, West Virginia 25045',7557,9202);
INSERT INTO "django_geo_db_zipcode" VALUES(10433,25046,-5,'Clio, West Virginia 25046',7558,9203);
INSERT INTO "django_geo_db_zipcode" VALUES(10434,25047,-5,'Clothier, West Virginia 25047',7559,9204);
INSERT INTO "django_geo_db_zipcode" VALUES(10435,25048,-5,'Colcord, West Virginia 25048',7560,9205);
INSERT INTO "django_geo_db_zipcode" VALUES(10436,25049,-5,'Comfort, West Virginia 25049',7561,9206);
INSERT INTO "django_geo_db_zipcode" VALUES(10437,25051,-5,'Costa, West Virginia 25051',7562,9207);
INSERT INTO "django_geo_db_zipcode" VALUES(10438,25053,-5,'Danville, West Virginia 25053',7563,9208);
INSERT INTO "django_geo_db_zipcode" VALUES(10439,25054,-5,'Dawes, West Virginia 25054',7564,9209);
INSERT INTO "django_geo_db_zipcode" VALUES(10440,25057,-5,'Deep Water, West Virginia 25057',7565,9210);
INSERT INTO "django_geo_db_zipcode" VALUES(10441,25059,-5,'Dixie, West Virginia 25059',7566,9211);
INSERT INTO "django_geo_db_zipcode" VALUES(10442,25060,-5,'Dorothy, West Virginia 25060',7567,9212);
INSERT INTO "django_geo_db_zipcode" VALUES(10443,25061,-5,'Drybranch, West Virginia 25061',7568,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10444,25062,-5,'Dry Creek, West Virginia 25062',7569,9214);
INSERT INTO "django_geo_db_zipcode" VALUES(10445,25063,-5,'Duck, West Virginia 25063',7570,9215);
INSERT INTO "django_geo_db_zipcode" VALUES(10446,25064,-5,'Dunbar, West Virginia 25064',7571,9216);
INSERT INTO "django_geo_db_zipcode" VALUES(10447,25067,-5,'East Bank, West Virginia 25067',7572,9217);
INSERT INTO "django_geo_db_zipcode" VALUES(10448,25070,-5,'Eleanor, West Virginia 25070',7573,9218);
INSERT INTO "django_geo_db_zipcode" VALUES(10449,25071,-5,'Elkview, West Virginia 25071',7574,9219);
INSERT INTO "django_geo_db_zipcode" VALUES(10450,25075,-5,'Eskdale, West Virginia 25075',7575,9220);
INSERT INTO "django_geo_db_zipcode" VALUES(10451,25076,-5,'Ethel, West Virginia 25076',7576,9221);
INSERT INTO "django_geo_db_zipcode" VALUES(10452,25079,-5,'Falling Rock, West Virginia 25079',7577,9222);
INSERT INTO "django_geo_db_zipcode" VALUES(10453,25081,-5,'Foster, West Virginia 25081',7578,9223);
INSERT INTO "django_geo_db_zipcode" VALUES(10454,25082,-5,'Fraziers Bottom, West Virginia 25082',7579,9224);
INSERT INTO "django_geo_db_zipcode" VALUES(10455,25083,-5,'Gallagher, West Virginia 25083',7580,9225);
INSERT INTO "django_geo_db_zipcode" VALUES(10456,25085,-5,'Gauley Bridge, West Virginia 25085',7581,9226);
INSERT INTO "django_geo_db_zipcode" VALUES(10457,25086,-5,'Glasgow, West Virginia 25086',7582,9227);
INSERT INTO "django_geo_db_zipcode" VALUES(10458,25088,-5,'Glen, West Virginia 25088',7583,9228);
INSERT INTO "django_geo_db_zipcode" VALUES(10459,25090,-5,'Glen Ferris, West Virginia 25090',7584,9229);
INSERT INTO "django_geo_db_zipcode" VALUES(10460,25093,-5,'Gordon, West Virginia 25093',7585,9230);
INSERT INTO "django_geo_db_zipcode" VALUES(10461,25095,-5,'Grimms Landing, West Virginia 25095',7586,9231);
INSERT INTO "django_geo_db_zipcode" VALUES(10462,25102,-5,'Handley, West Virginia 25102',7587,9232);
INSERT INTO "django_geo_db_zipcode" VALUES(10463,25103,-5,'Hansford, West Virginia 25103',7588,9233);
INSERT INTO "django_geo_db_zipcode" VALUES(10464,25106,-5,'Henderson, West Virginia 25106',7589,9234);
INSERT INTO "django_geo_db_zipcode" VALUES(10465,25107,-5,'Hernshaw, West Virginia 25107',7590,9235);
INSERT INTO "django_geo_db_zipcode" VALUES(10466,25108,-5,'Hewett, West Virginia 25108',7591,9236);
INSERT INTO "django_geo_db_zipcode" VALUES(10467,25109,-5,'Hometown, West Virginia 25109',7592,9237);
INSERT INTO "django_geo_db_zipcode" VALUES(10468,25110,-5,'Hugheston, West Virginia 25110',7593,9238);
INSERT INTO "django_geo_db_zipcode" VALUES(10469,25111,-5,'Indore, West Virginia 25111',7594,9239);
INSERT INTO "django_geo_db_zipcode" VALUES(10470,25112,-5,'Institute, West Virginia 25112',7595,9240);
INSERT INTO "django_geo_db_zipcode" VALUES(10471,25113,-5,'Ivydale, West Virginia 25113',7596,9241);
INSERT INTO "django_geo_db_zipcode" VALUES(10472,25114,-5,'Jeffrey, West Virginia 25114',7597,9242);
INSERT INTO "django_geo_db_zipcode" VALUES(10473,25115,-5,'Kanawha Falls, West Virginia 25115',7598,9243);
INSERT INTO "django_geo_db_zipcode" VALUES(10474,25118,-5,'Kimberly, West Virginia 25118',7599,9244);
INSERT INTO "django_geo_db_zipcode" VALUES(10475,25119,-5,'Kincaid, West Virginia 25119',7600,9245);
INSERT INTO "django_geo_db_zipcode" VALUES(10476,25121,-5,'Lake, West Virginia 25121',7601,9246);
INSERT INTO "django_geo_db_zipcode" VALUES(10477,25122,-5,'Leewood, West Virginia 25122',7602,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10478,25123,-5,'Leon, West Virginia 25123',7603,9247);
INSERT INTO "django_geo_db_zipcode" VALUES(10479,25124,-5,'Liberty, West Virginia 25124',7604,9248);
INSERT INTO "django_geo_db_zipcode" VALUES(10480,25125,-5,'Lizemores, West Virginia 25125',7605,9249);
INSERT INTO "django_geo_db_zipcode" VALUES(10481,25126,-5,'London, West Virginia 25126',7606,9250);
INSERT INTO "django_geo_db_zipcode" VALUES(10482,25130,-5,'Madison, West Virginia 25130',7607,9251);
INSERT INTO "django_geo_db_zipcode" VALUES(10483,25132,-5,'Mammoth, West Virginia 25132',7608,9252);
INSERT INTO "django_geo_db_zipcode" VALUES(10484,25133,-5,'Maysel, West Virginia 25133',7609,9253);
INSERT INTO "django_geo_db_zipcode" VALUES(10485,25134,-5,'Miami, West Virginia 25134',7610,9254);
INSERT INTO "django_geo_db_zipcode" VALUES(10486,25136,-5,'Montgomery, West Virginia 25136',7611,9255);
INSERT INTO "django_geo_db_zipcode" VALUES(10487,25139,-5,'Mount Carbon, West Virginia 25139',7612,9256);
INSERT INTO "django_geo_db_zipcode" VALUES(10488,25140,-5,'Naoma, West Virginia 25140',7613,9257);
INSERT INTO "django_geo_db_zipcode" VALUES(10489,25141,-5,'Nebo, West Virginia 25141',7614,9258);
INSERT INTO "django_geo_db_zipcode" VALUES(10490,25142,-5,'Nellis, West Virginia 25142',7615,9230);
INSERT INTO "django_geo_db_zipcode" VALUES(10491,25143,-5,'Nitro, West Virginia 25143',7616,9259);
INSERT INTO "django_geo_db_zipcode" VALUES(10492,25147,-5,'Ohley, West Virginia 25147',7617,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10493,25148,-5,'Orgas, West Virginia 25148',7618,9260);
INSERT INTO "django_geo_db_zipcode" VALUES(10494,25149,-5,'Ottawa, West Virginia 25149',7619,9261);
INSERT INTO "django_geo_db_zipcode" VALUES(10495,25150,-5,'Ovapa, West Virginia 25150',7620,9262);
INSERT INTO "django_geo_db_zipcode" VALUES(10496,25152,-5,'Page, West Virginia 25152',7621,9263);
INSERT INTO "django_geo_db_zipcode" VALUES(10497,25154,-5,'Peytona, West Virginia 25154',7622,9264);
INSERT INTO "django_geo_db_zipcode" VALUES(10498,25156,-5,'Pinch, West Virginia 25156',7623,9265);
INSERT INTO "django_geo_db_zipcode" VALUES(10499,25159,-5,'Poca, West Virginia 25159',7624,9266);
INSERT INTO "django_geo_db_zipcode" VALUES(10500,25160,-5,'Pond Gap, West Virginia 25160',7625,9267);
INSERT INTO "django_geo_db_zipcode" VALUES(10501,25161,-5,'Powellton, West Virginia 25161',7626,9268);
INSERT INTO "django_geo_db_zipcode" VALUES(10502,25162,-5,'Pratt, West Virginia 25162',7627,9269);
INSERT INTO "django_geo_db_zipcode" VALUES(10503,25164,-5,'Procious, West Virginia 25164',7628,9270);
INSERT INTO "django_geo_db_zipcode" VALUES(10504,25165,-5,'Racine, West Virginia 25165',7629,9271);
INSERT INTO "django_geo_db_zipcode" VALUES(10505,25168,-5,'Red House, West Virginia 25168',7630,9272);
INSERT INTO "django_geo_db_zipcode" VALUES(10506,25169,-5,'Ridgeview, West Virginia 25169',7631,9273);
INSERT INTO "django_geo_db_zipcode" VALUES(10507,25173,-5,'Robson, West Virginia 25173',7632,9274);
INSERT INTO "django_geo_db_zipcode" VALUES(10508,25174,-5,'Rock Creek, West Virginia 25174',7633,9275);
INSERT INTO "django_geo_db_zipcode" VALUES(10509,25177,-5,'Saint Albans, West Virginia 25177',7634,9276);
INSERT INTO "django_geo_db_zipcode" VALUES(10510,25180,-5,'Saxon, West Virginia 25180',7635,9277);
INSERT INTO "django_geo_db_zipcode" VALUES(10511,25181,-5,'Seth, West Virginia 25181',7636,9278);
INSERT INTO "django_geo_db_zipcode" VALUES(10512,25182,-5,'Sharon, West Virginia 25182',7637,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10513,25183,-5,'Sharples, West Virginia 25183',7638,9279);
INSERT INTO "django_geo_db_zipcode" VALUES(10514,25185,-5,'Mount Olive, West Virginia 25185',7639,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10515,25186,-5,'Smithers, West Virginia 25186',7640,9281);
INSERT INTO "django_geo_db_zipcode" VALUES(10516,25187,-5,'Southside, West Virginia 25187',7641,9282);
INSERT INTO "django_geo_db_zipcode" VALUES(10517,25193,-5,'Sylvester, West Virginia 25193',7642,9283);
INSERT INTO "django_geo_db_zipcode" VALUES(10518,25201,-5,'Tad, West Virginia 25201',7643,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10519,25202,-5,'Tornado, West Virginia 25202',7644,9284);
INSERT INTO "django_geo_db_zipcode" VALUES(10520,25203,-5,'Turtle Creek, West Virginia 25203',7645,9285);
INSERT INTO "django_geo_db_zipcode" VALUES(10521,25204,-5,'Twilight, West Virginia 25204',7646,9286);
INSERT INTO "django_geo_db_zipcode" VALUES(10522,25205,-5,'Uneeda, West Virginia 25205',7647,9287);
INSERT INTO "django_geo_db_zipcode" VALUES(10523,25206,-5,'Van, West Virginia 25206',7648,9288);
INSERT INTO "django_geo_db_zipcode" VALUES(10524,25208,-5,'Wharton, West Virginia 25208',7649,9289);
INSERT INTO "django_geo_db_zipcode" VALUES(10525,25209,-5,'Whitesville, West Virginia 25209',7650,9290);
INSERT INTO "django_geo_db_zipcode" VALUES(10526,25211,-5,'Widen, West Virginia 25211',7651,9291);
INSERT INTO "django_geo_db_zipcode" VALUES(10527,25213,-5,'Winfield, West Virginia 25213',7652,9292);
INSERT INTO "django_geo_db_zipcode" VALUES(10528,25214,-5,'Winifrede, West Virginia 25214',7653,9293);
INSERT INTO "django_geo_db_zipcode" VALUES(10529,25231,-5,'Advent, West Virginia 25231',7654,9294);
INSERT INTO "django_geo_db_zipcode" VALUES(10530,25234,-5,'Arnoldsburg, West Virginia 25234',7655,9295);
INSERT INTO "django_geo_db_zipcode" VALUES(10531,25235,-5,'Chloe, West Virginia 25235',7656,9296);
INSERT INTO "django_geo_db_zipcode" VALUES(10532,25239,-5,'Cottageville, West Virginia 25239',7657,9297);
INSERT INTO "django_geo_db_zipcode" VALUES(10533,25241,-5,'Evans, West Virginia 25241',7658,9298);
INSERT INTO "django_geo_db_zipcode" VALUES(10534,25243,-5,'Gandeeville, West Virginia 25243',7659,9299);
INSERT INTO "django_geo_db_zipcode" VALUES(10535,25244,-5,'Gay, West Virginia 25244',7660,9300);
INSERT INTO "django_geo_db_zipcode" VALUES(10536,25245,-5,'Given, West Virginia 25245',7661,9301);
INSERT INTO "django_geo_db_zipcode" VALUES(10537,25247,-5,'Hartford, West Virginia 25247',7662,9302);
INSERT INTO "django_geo_db_zipcode" VALUES(10538,25248,-5,'Kenna, West Virginia 25248',7663,9303);
INSERT INTO "django_geo_db_zipcode" VALUES(10539,25250,-5,'Lakin, West Virginia 25250',7664,9231);
INSERT INTO "django_geo_db_zipcode" VALUES(10540,25251,-5,'Left Hand, West Virginia 25251',7665,9304);
INSERT INTO "django_geo_db_zipcode" VALUES(10541,25252,-5,'Le Roy, West Virginia 25252',7666,9305);
INSERT INTO "django_geo_db_zipcode" VALUES(10542,25253,-5,'Letart, West Virginia 25253',7667,9306);
INSERT INTO "django_geo_db_zipcode" VALUES(10543,25256,-5,'Linden, West Virginia 25256',7668,9203);
INSERT INTO "django_geo_db_zipcode" VALUES(10544,25258,-5,'Lockney, West Virginia 25258',7669,9307);
INSERT INTO "django_geo_db_zipcode" VALUES(10545,25259,-5,'Looneyville, West Virginia 25259',7670,9308);
INSERT INTO "django_geo_db_zipcode" VALUES(10546,25260,-5,'Mason, West Virginia 25260',7671,9309);
INSERT INTO "django_geo_db_zipcode" VALUES(10547,25261,-5,'Millstone, West Virginia 25261',7672,9310);
INSERT INTO "django_geo_db_zipcode" VALUES(10548,25262,-5,'Millwood, West Virginia 25262',7673,9311);
INSERT INTO "django_geo_db_zipcode" VALUES(10549,25264,-5,'Mount Alto, West Virginia 25264',7674,9312);
INSERT INTO "django_geo_db_zipcode" VALUES(10550,25265,-5,'New Haven, West Virginia 25265',7675,9313);
INSERT INTO "django_geo_db_zipcode" VALUES(10551,25266,-5,'Newton, West Virginia 25266',7676,9314);
INSERT INTO "django_geo_db_zipcode" VALUES(10552,25267,-5,'Normantown, West Virginia 25267',7677,9315);
INSERT INTO "django_geo_db_zipcode" VALUES(10553,25268,-5,'Orma, West Virginia 25268',7678,9316);
INSERT INTO "django_geo_db_zipcode" VALUES(10554,25270,-5,'Reedy, West Virginia 25270',7679,9317);
INSERT INTO "django_geo_db_zipcode" VALUES(10555,25271,-5,'Ripley, West Virginia 25271',7680,9318);
INSERT INTO "django_geo_db_zipcode" VALUES(10556,25275,-5,'Sandyville, West Virginia 25275',7681,9319);
INSERT INTO "django_geo_db_zipcode" VALUES(10557,25276,-5,'Spencer, West Virginia 25276',7682,9320);
INSERT INTO "django_geo_db_zipcode" VALUES(10558,25279,-5,'Statts Mills, West Virginia 25279',7683,9321);
INSERT INTO "django_geo_db_zipcode" VALUES(10559,25281,-5,'Tariff, West Virginia 25281',7684,9322);
INSERT INTO "django_geo_db_zipcode" VALUES(10560,25283,-5,'Valley Fork, West Virginia 25283',7685,9323);
INSERT INTO "django_geo_db_zipcode" VALUES(10561,25285,-5,'Wallback, West Virginia 25285',7686,9324);
INSERT INTO "django_geo_db_zipcode" VALUES(10562,25286,-5,'Walton, West Virginia 25286',7687,9325);
INSERT INTO "django_geo_db_zipcode" VALUES(10563,25287,-5,'West Columbia, West Virginia 25287',7688,9326);
INSERT INTO "django_geo_db_zipcode" VALUES(10564,25301,-5,'Charleston, West Virginia 25301',7689,9327);
INSERT INTO "django_geo_db_zipcode" VALUES(10565,25302,-5,'Charleston, West Virginia 25302',7689,9328);
INSERT INTO "django_geo_db_zipcode" VALUES(10566,25303,-5,'Charleston, West Virginia 25303',7689,9329);
INSERT INTO "django_geo_db_zipcode" VALUES(10567,25304,-5,'Charleston, West Virginia 25304',7689,9330);
INSERT INTO "django_geo_db_zipcode" VALUES(10568,25305,-5,'Charleston, West Virginia 25305',7689,9331);
INSERT INTO "django_geo_db_zipcode" VALUES(10569,25306,-5,'Charleston, West Virginia 25306',7689,9332);
INSERT INTO "django_geo_db_zipcode" VALUES(10570,25309,-5,'Charleston, West Virginia 25309',7689,9333);
INSERT INTO "django_geo_db_zipcode" VALUES(10571,25311,-5,'Charleston, West Virginia 25311',7689,9334);
INSERT INTO "django_geo_db_zipcode" VALUES(10572,25312,-5,'Charleston, West Virginia 25312',7689,9335);
INSERT INTO "django_geo_db_zipcode" VALUES(10573,25313,-5,'Charleston, West Virginia 25313',7689,9336);
INSERT INTO "django_geo_db_zipcode" VALUES(10574,25314,-5,'Charleston, West Virginia 25314',7689,9337);
INSERT INTO "django_geo_db_zipcode" VALUES(10575,25315,-5,'Charleston, West Virginia 25315',7689,9338);
INSERT INTO "django_geo_db_zipcode" VALUES(10576,25317,-5,'Charleston, West Virginia 25317',7689,9339);
INSERT INTO "django_geo_db_zipcode" VALUES(10577,25320,-5,'Charleston, West Virginia 25320',7689,9340);
INSERT INTO "django_geo_db_zipcode" VALUES(10578,25321,-5,'Charleston, West Virginia 25321',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10579,25322,-5,'Charleston, West Virginia 25322',7689,9341);
INSERT INTO "django_geo_db_zipcode" VALUES(10580,25323,-5,'Charleston, West Virginia 25323',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10581,25324,-5,'Charleston, West Virginia 25324',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10582,25325,-5,'Charleston, West Virginia 25325',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10583,25326,-5,'Charleston, West Virginia 25326',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10584,25327,-5,'Charleston, West Virginia 25327',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10585,25328,-5,'Charleston, West Virginia 25328',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10586,25329,-5,'Charleston, West Virginia 25329',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10587,25330,-5,'Charleston, West Virginia 25330',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10588,25331,-5,'Charleston, West Virginia 25331',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10589,25332,-5,'Charleston, West Virginia 25332',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10590,25333,-5,'Charleston, West Virginia 25333',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10591,25334,-5,'Charleston, West Virginia 25334',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10592,25335,-5,'Charleston, West Virginia 25335',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10593,25336,-5,'Charleston, West Virginia 25336',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10594,25337,-5,'Charleston, West Virginia 25337',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10595,25338,-5,'Charleston, West Virginia 25338',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10596,25339,-5,'Charleston, West Virginia 25339',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10597,25350,-5,'Charleston, West Virginia 25350',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10598,25356,-5,'Charleston, West Virginia 25356',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10599,25357,-5,'Charleston, West Virginia 25357',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10600,25358,-5,'Charleston, West Virginia 25358',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10601,25360,-5,'Charleston, West Virginia 25360',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10602,25361,-5,'Charleston, West Virginia 25361',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10603,25362,-5,'Charleston, West Virginia 25362',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10604,25364,-5,'Charleston, West Virginia 25364',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10605,25365,-5,'Charleston, West Virginia 25365',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10606,25375,-5,'Charleston, West Virginia 25375',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10607,25387,-5,'Charleston, West Virginia 25387',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10608,25389,-5,'Charleston, West Virginia 25389',7689,9342);
INSERT INTO "django_geo_db_zipcode" VALUES(10609,25392,-5,'Charleston, West Virginia 25392',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10610,25396,-5,'Charleston, West Virginia 25396',7689,9213);
INSERT INTO "django_geo_db_zipcode" VALUES(10611,25401,-5,'Martinsburg, West Virginia 25401',7690,9343);
INSERT INTO "django_geo_db_zipcode" VALUES(10612,25402,-5,'Martinsburg, West Virginia 25402',7690,9344);
INSERT INTO "django_geo_db_zipcode" VALUES(10613,25410,-5,'Bakerton, West Virginia 25410',7691,9345);
INSERT INTO "django_geo_db_zipcode" VALUES(10614,25411,-5,'Berkeley Springs, West Virginia 25411',7692,9346);
INSERT INTO "django_geo_db_zipcode" VALUES(10615,25413,-5,'Bunker Hill, West Virginia 25413',7693,9347);
INSERT INTO "django_geo_db_zipcode" VALUES(10616,25414,-5,'Charles Town, West Virginia 25414',7694,9348);
INSERT INTO "django_geo_db_zipcode" VALUES(10617,25419,-5,'Falling Waters, West Virginia 25419',7695,9349);
INSERT INTO "django_geo_db_zipcode" VALUES(10618,25420,-5,'Gerrardstown, West Virginia 25420',7696,9350);
INSERT INTO "django_geo_db_zipcode" VALUES(10619,25421,-5,'Glengary, West Virginia 25421',7697,9351);
INSERT INTO "django_geo_db_zipcode" VALUES(10620,25422,-5,'Great Cacapon, West Virginia 25422',7698,9352);
INSERT INTO "django_geo_db_zipcode" VALUES(10621,25423,-5,'Halltown, West Virginia 25423',7699,9345);
INSERT INTO "django_geo_db_zipcode" VALUES(10622,25425,-5,'Harpers Ferry, West Virginia 25425',7700,9353);
INSERT INTO "django_geo_db_zipcode" VALUES(10623,25427,-5,'Hedgesville, West Virginia 25427',7701,9354);
INSERT INTO "django_geo_db_zipcode" VALUES(10624,25428,-5,'Inwood, West Virginia 25428',7702,9355);
INSERT INTO "django_geo_db_zipcode" VALUES(10625,25429,-5,'Kearneysville, West Virginia 25429',7703,9356);
INSERT INTO "django_geo_db_zipcode" VALUES(10626,25430,-5,'Kearneysville, West Virginia 25430',7703,9357);
INSERT INTO "django_geo_db_zipcode" VALUES(10627,25431,-5,'Levels, West Virginia 25431',7704,9358);
INSERT INTO "django_geo_db_zipcode" VALUES(10628,25432,-5,'Millville, West Virginia 25432',7705,9345);
INSERT INTO "django_geo_db_zipcode" VALUES(10629,25434,-5,'Paw Paw, West Virginia 25434',7706,9359);
INSERT INTO "django_geo_db_zipcode" VALUES(10630,25437,-5,'Points, West Virginia 25437',7707,9360);
INSERT INTO "django_geo_db_zipcode" VALUES(10631,25438,-5,'Ranson, West Virginia 25438',7708,9361);
INSERT INTO "django_geo_db_zipcode" VALUES(10632,25440,-5,'Ridgeway, West Virginia 25440',7709,9362);
INSERT INTO "django_geo_db_zipcode" VALUES(10633,25441,-5,'Rippon, West Virginia 25441',7710,9363);
INSERT INTO "django_geo_db_zipcode" VALUES(10634,25442,-5,'Shenandoah Junction, West Virginia 25442',7711,9364);
INSERT INTO "django_geo_db_zipcode" VALUES(10635,25443,-5,'Shepherdstown, West Virginia 25443',7712,9365);
INSERT INTO "django_geo_db_zipcode" VALUES(10636,25444,-5,'Slanesville, West Virginia 25444',7713,9366);
INSERT INTO "django_geo_db_zipcode" VALUES(10637,25446,-5,'Summit Point, West Virginia 25446',7714,9367);
INSERT INTO "django_geo_db_zipcode" VALUES(10638,25501,-5,'Alkol, West Virginia 25501',7715,9368);
INSERT INTO "django_geo_db_zipcode" VALUES(10639,25502,-5,'Apple Grove, West Virginia 25502',7716,9369);
INSERT INTO "django_geo_db_zipcode" VALUES(10640,25503,-5,'Ashton, West Virginia 25503',7717,9370);
INSERT INTO "django_geo_db_zipcode" VALUES(10641,25504,-5,'Barboursville, West Virginia 25504',7718,9371);
INSERT INTO "django_geo_db_zipcode" VALUES(10642,25505,-5,'Big Creek, West Virginia 25505',7719,9372);
INSERT INTO "django_geo_db_zipcode" VALUES(10643,25506,-5,'Branchland, West Virginia 25506',7720,9373);
INSERT INTO "django_geo_db_zipcode" VALUES(10644,25507,-5,'Ceredo, West Virginia 25507',7721,9374);
INSERT INTO "django_geo_db_zipcode" VALUES(10645,25508,-5,'Chapmanville, West Virginia 25508',7722,9375);
INSERT INTO "django_geo_db_zipcode" VALUES(10646,25510,-5,'Culloden, West Virginia 25510',7723,9376);
INSERT INTO "django_geo_db_zipcode" VALUES(10647,25511,-5,'Dunlow, West Virginia 25511',7724,9377);
INSERT INTO "django_geo_db_zipcode" VALUES(10648,25512,-5,'East Lynn, West Virginia 25512',7725,9378);
INSERT INTO "django_geo_db_zipcode" VALUES(10649,25514,-5,'Fort Gay, West Virginia 25514',7726,9379);
INSERT INTO "django_geo_db_zipcode" VALUES(10650,25515,-5,'Gallipolis Ferry, West Virginia 25515',7727,9380);
INSERT INTO "django_geo_db_zipcode" VALUES(10651,25517,-5,'Genoa, West Virginia 25517',7728,9381);
INSERT INTO "django_geo_db_zipcode" VALUES(10652,25519,-5,'Glenhayes, West Virginia 25519',7729,9382);
INSERT INTO "django_geo_db_zipcode" VALUES(10653,25520,-5,'Glenwood, West Virginia 25520',7730,9383);
INSERT INTO "django_geo_db_zipcode" VALUES(10654,25521,-5,'Griffithsville, West Virginia 25521',7731,9384);
INSERT INTO "django_geo_db_zipcode" VALUES(10655,25523,-5,'Hamlin, West Virginia 25523',7732,9385);
INSERT INTO "django_geo_db_zipcode" VALUES(10656,25524,-5,'Harts, West Virginia 25524',7733,9386);
INSERT INTO "django_geo_db_zipcode" VALUES(10657,25526,-5,'Hurricane, West Virginia 25526',7734,9387);
INSERT INTO "django_geo_db_zipcode" VALUES(10658,25529,-5,'Julian, West Virginia 25529',7735,9388);
INSERT INTO "django_geo_db_zipcode" VALUES(10659,25530,-5,'Kenova, West Virginia 25530',7736,9389);
INSERT INTO "django_geo_db_zipcode" VALUES(10660,25534,-5,'Kiahsville, West Virginia 25534',7737,9390);
INSERT INTO "django_geo_db_zipcode" VALUES(10661,25535,-5,'Lavalette, West Virginia 25535',7738,9391);
INSERT INTO "django_geo_db_zipcode" VALUES(10662,25537,-5,'Lesage, West Virginia 25537',7739,9392);
INSERT INTO "django_geo_db_zipcode" VALUES(10663,25540,-5,'Midkiff, West Virginia 25540',7740,9393);
INSERT INTO "django_geo_db_zipcode" VALUES(10664,25541,-5,'Milton, West Virginia 25541',7741,9394);
INSERT INTO "django_geo_db_zipcode" VALUES(10665,25543,-5,'Shepherdstown, West Virginia 25543',7712,9395);
INSERT INTO "django_geo_db_zipcode" VALUES(10666,25544,-5,'Myra, West Virginia 25544',7742,9396);
INSERT INTO "django_geo_db_zipcode" VALUES(10667,25545,-5,'Ona, West Virginia 25545',7743,9397);
INSERT INTO "django_geo_db_zipcode" VALUES(10668,25547,-5,'Pecks Mill, West Virginia 25547',7744,9398);
INSERT INTO "django_geo_db_zipcode" VALUES(10669,25550,-5,'Point Pleasant, West Virginia 25550',7745,9399);
INSERT INTO "django_geo_db_zipcode" VALUES(10670,25555,-5,'Prichard, West Virginia 25555',7746,9400);
INSERT INTO "django_geo_db_zipcode" VALUES(10671,25557,-5,'Ranger, West Virginia 25557',7747,9401);
INSERT INTO "django_geo_db_zipcode" VALUES(10672,25559,-5,'Salt Rock, West Virginia 25559',7748,9402);
INSERT INTO "django_geo_db_zipcode" VALUES(10673,25560,-5,'Scott Depot, West Virginia 25560',7749,9403);
INSERT INTO "django_geo_db_zipcode" VALUES(10674,25562,-5,'Shoals, West Virginia 25562',7750,9404);
INSERT INTO "django_geo_db_zipcode" VALUES(10675,25564,-5,'Sod, West Virginia 25564',7751,9405);
INSERT INTO "django_geo_db_zipcode" VALUES(10676,25565,-5,'Spurlockville, West Virginia 25565',7752,9406);
INSERT INTO "django_geo_db_zipcode" VALUES(10677,25567,-5,'Sumerco, West Virginia 25567',7753,9407);
INSERT INTO "django_geo_db_zipcode" VALUES(10678,25569,-5,'Teays, West Virginia 25569',7754,9408);
INSERT INTO "django_geo_db_zipcode" VALUES(10679,25570,-5,'Wayne, West Virginia 25570',7755,9409);
INSERT INTO "django_geo_db_zipcode" VALUES(10680,25571,-5,'West Hamlin, West Virginia 25571',7756,9410);
INSERT INTO "django_geo_db_zipcode" VALUES(10681,25572,-5,'Woodville, West Virginia 25572',7757,9411);
INSERT INTO "django_geo_db_zipcode" VALUES(10682,25573,-5,'Yawkey, West Virginia 25573',7758,9412);
INSERT INTO "django_geo_db_zipcode" VALUES(10683,25601,-5,'Logan, West Virginia 25601',7759,9413);
INSERT INTO "django_geo_db_zipcode" VALUES(10684,25606,-5,'Accoville, West Virginia 25606',7760,9414);
INSERT INTO "django_geo_db_zipcode" VALUES(10685,25607,-5,'Amherstdale, West Virginia 25607',7761,9415);
INSERT INTO "django_geo_db_zipcode" VALUES(10686,25608,-5,'Baisden, West Virginia 25608',7762,9416);
INSERT INTO "django_geo_db_zipcode" VALUES(10687,25611,-5,'Bruno, West Virginia 25611',7763,9417);
INSERT INTO "django_geo_db_zipcode" VALUES(10688,25612,-5,'Chauncey, West Virginia 25612',7764,9418);
INSERT INTO "django_geo_db_zipcode" VALUES(10689,25614,-5,'Cora, West Virginia 25614',7765,9419);
INSERT INTO "django_geo_db_zipcode" VALUES(10690,25617,-5,'Davin, West Virginia 25617',7766,9420);
INSERT INTO "django_geo_db_zipcode" VALUES(10691,25621,-5,'Gilbert, West Virginia 25621',7767,9421);
INSERT INTO "django_geo_db_zipcode" VALUES(10692,25623,-5,'Hampden, West Virginia 25623',7768,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10693,25624,-5,'Henlawson, West Virginia 25624',7769,9423);
INSERT INTO "django_geo_db_zipcode" VALUES(10694,25625,-5,'Holden, West Virginia 25625',7770,9424);
INSERT INTO "django_geo_db_zipcode" VALUES(10695,25628,-5,'Kistler, West Virginia 25628',7771,9425);
INSERT INTO "django_geo_db_zipcode" VALUES(10696,25630,-5,'Lorado, West Virginia 25630',7772,9426);
INSERT INTO "django_geo_db_zipcode" VALUES(10697,25631,-5,'Amherstdale-Robinette, West Virginia 25631',7773,9427);
INSERT INTO "django_geo_db_zipcode" VALUES(10698,25632,-5,'Lyburn, West Virginia 25632',7774,9428);
INSERT INTO "django_geo_db_zipcode" VALUES(10699,25634,-5,'Mallory, West Virginia 25634',7775,9429);
INSERT INTO "django_geo_db_zipcode" VALUES(10700,25635,-5,'Man, West Virginia 25635',7776,9430);
INSERT INTO "django_geo_db_zipcode" VALUES(10701,25636,-5,'Monaville, West Virginia 25636',7777,9431);
INSERT INTO "django_geo_db_zipcode" VALUES(10702,25637,-5,'Mount Gay, West Virginia 25637',7778,9432);
INSERT INTO "django_geo_db_zipcode" VALUES(10703,25638,-5,'Omar, West Virginia 25638',7779,9433);
INSERT INTO "django_geo_db_zipcode" VALUES(10704,25639,-5,'Peach Creek, West Virginia 25639',7780,9434);
INSERT INTO "django_geo_db_zipcode" VALUES(10705,25644,-5,'Sarah Ann, West Virginia 25644',7781,9435);
INSERT INTO "django_geo_db_zipcode" VALUES(10706,25645,-5,'Stirrat, West Virginia 25645',7782,9419);
INSERT INTO "django_geo_db_zipcode" VALUES(10707,25646,-5,'Stollings, West Virginia 25646',7783,9436);
INSERT INTO "django_geo_db_zipcode" VALUES(10708,25647,-5,'Switzer, West Virginia 25647',7784,9437);
INSERT INTO "django_geo_db_zipcode" VALUES(10709,25649,-5,'Verdunville, West Virginia 25649',7785,9438);
INSERT INTO "django_geo_db_zipcode" VALUES(10710,25650,-5,'Verner, West Virginia 25650',7786,9439);
INSERT INTO "django_geo_db_zipcode" VALUES(10711,25651,-5,'Wharncliffe, West Virginia 25651',7787,9440);
INSERT INTO "django_geo_db_zipcode" VALUES(10712,25652,-5,'Whitman, West Virginia 25652',7788,9441);
INSERT INTO "django_geo_db_zipcode" VALUES(10713,25653,-5,'Wilkinson, West Virginia 25653',7789,9442);
INSERT INTO "django_geo_db_zipcode" VALUES(10714,25654,-5,'Yolyn, West Virginia 25654',7790,9443);
INSERT INTO "django_geo_db_zipcode" VALUES(10715,25661,-5,'Williamson, West Virginia 25661',7791,9444);
INSERT INTO "django_geo_db_zipcode" VALUES(10716,25665,-5,'Borderland, West Virginia 25665',7792,9445);
INSERT INTO "django_geo_db_zipcode" VALUES(10717,25666,-5,'Breeden, West Virginia 25666',7793,9446);
INSERT INTO "django_geo_db_zipcode" VALUES(10718,25667,-5,'Chattaroy, West Virginia 25667',7794,9447);
INSERT INTO "django_geo_db_zipcode" VALUES(10719,25669,-5,'Crum, West Virginia 25669',7795,9448);
INSERT INTO "django_geo_db_zipcode" VALUES(10720,25670,-5,'Delbarton, West Virginia 25670',7796,9449);
INSERT INTO "django_geo_db_zipcode" VALUES(10721,25671,-5,'Dingess, West Virginia 25671',7797,9450);
INSERT INTO "django_geo_db_zipcode" VALUES(10722,25672,-5,'Edgarton, West Virginia 25672',7798,9451);
INSERT INTO "django_geo_db_zipcode" VALUES(10723,25674,-5,'Kermit, West Virginia 25674',7799,9452);
INSERT INTO "django_geo_db_zipcode" VALUES(10724,25676,-5,'Lenore, West Virginia 25676',7800,9453);
INSERT INTO "django_geo_db_zipcode" VALUES(10725,25678,-5,'Matewan, West Virginia 25678',7801,9454);
INSERT INTO "django_geo_db_zipcode" VALUES(10726,25682,-5,'Meador, West Virginia 25682',7802,9455);
INSERT INTO "django_geo_db_zipcode" VALUES(10727,25685,-5,'Naugatuck, West Virginia 25685',7803,9456);
INSERT INTO "django_geo_db_zipcode" VALUES(10728,25686,-5,'Newtown, West Virginia 25686',7804,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10729,25687,-5,'Nolan, West Virginia 25687',7805,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10730,25688,-5,'North Matewan, West Virginia 25688',7806,9457);
INSERT INTO "django_geo_db_zipcode" VALUES(10731,25690,-5,'Ragland, West Virginia 25690',7807,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10732,25691,-5,'Rawl, West Virginia 25691',7808,9458);
INSERT INTO "django_geo_db_zipcode" VALUES(10733,25692,-5,'Red Jacket, West Virginia 25692',7809,9459);
INSERT INTO "django_geo_db_zipcode" VALUES(10734,25694,-5,'Thacker, West Virginia 25694',7810,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10735,25696,-5,'Varney, West Virginia 25696',7811,9460);
INSERT INTO "django_geo_db_zipcode" VALUES(10736,25697,-5,'Vulcan, West Virginia 25697',7812,9422);
INSERT INTO "django_geo_db_zipcode" VALUES(10737,25699,-5,'Wilsondale, West Virginia 25699',7813,9461);
INSERT INTO "django_geo_db_zipcode" VALUES(10738,25701,-5,'Huntington, West Virginia 25701',7814,9462);
INSERT INTO "django_geo_db_zipcode" VALUES(10739,25702,-5,'Huntington, West Virginia 25702',7814,9463);
INSERT INTO "django_geo_db_zipcode" VALUES(10740,25703,-5,'Huntington, West Virginia 25703',7814,9464);
INSERT INTO "django_geo_db_zipcode" VALUES(10741,25704,-5,'Huntington, West Virginia 25704',7814,9465);
INSERT INTO "django_geo_db_zipcode" VALUES(10742,25705,-5,'Huntington, West Virginia 25705',7814,9466);
INSERT INTO "django_geo_db_zipcode" VALUES(10743,25706,-5,'Huntington, West Virginia 25706',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10744,25707,-5,'Huntington, West Virginia 25707',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10745,25708,-5,'Huntington, West Virginia 25708',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10746,25709,-5,'Huntington, West Virginia 25709',7814,9382);
INSERT INTO "django_geo_db_zipcode" VALUES(10747,25710,-5,'Huntington, West Virginia 25710',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10748,25711,-5,'Huntington, West Virginia 25711',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10749,25712,-5,'Huntington, West Virginia 25712',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10750,25713,-5,'Huntington, West Virginia 25713',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10751,25714,-5,'Huntington, West Virginia 25714',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10752,25715,-5,'Huntington, West Virginia 25715',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10753,25716,-5,'Huntington, West Virginia 25716',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10754,25717,-5,'Huntington, West Virginia 25717',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10755,25718,-5,'Huntington, West Virginia 25718',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10756,25719,-5,'Huntington, West Virginia 25719',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10757,25720,-5,'Huntington, West Virginia 25720',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10758,25721,-5,'Huntington, West Virginia 25721',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10759,25722,-5,'Huntington, West Virginia 25722',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10760,25723,-5,'Huntington, West Virginia 25723',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10761,25724,-5,'Huntington, West Virginia 25724',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10762,25725,-5,'Huntington, West Virginia 25725',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10763,25726,-5,'Huntington, West Virginia 25726',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10764,25727,-5,'Huntington, West Virginia 25727',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10765,25728,-5,'Huntington, West Virginia 25728',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10766,25729,-5,'Huntington, West Virginia 25729',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10767,25755,-5,'Huntington, West Virginia 25755',7814,9468);
INSERT INTO "django_geo_db_zipcode" VALUES(10768,25770,-5,'Huntington, West Virginia 25770',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10769,25771,-5,'Huntington, West Virginia 25771',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10770,25772,-5,'Huntington, West Virginia 25772',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10771,25773,-5,'Huntington, West Virginia 25773',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10772,25774,-5,'Huntington, West Virginia 25774',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10773,25775,-5,'Huntington, West Virginia 25775',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10774,25776,-5,'Huntington, West Virginia 25776',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10775,25777,-5,'Huntington, West Virginia 25777',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10776,25778,-5,'Huntington, West Virginia 25778',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10777,25779,-5,'Huntington, West Virginia 25779',7814,9467);
INSERT INTO "django_geo_db_zipcode" VALUES(10778,25801,-5,'Beckley, West Virginia 25801',7815,9469);
INSERT INTO "django_geo_db_zipcode" VALUES(10779,25802,-5,'Beckley, West Virginia 25802',7815,9470);
INSERT INTO "django_geo_db_zipcode" VALUES(10780,25810,-5,'Allen Junction, West Virginia 25810',7816,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10781,25811,-5,'Amigo, West Virginia 25811',7817,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10782,25812,-5,'Ansted, West Virginia 25812',7818,9471);
INSERT INTO "django_geo_db_zipcode" VALUES(10783,25813,-5,'Beaver, West Virginia 25813',7819,9472);
INSERT INTO "django_geo_db_zipcode" VALUES(10784,25816,-5,'Blue Jay, West Virginia 25816',7820,9473);
INSERT INTO "django_geo_db_zipcode" VALUES(10785,25817,-5,'Bolt, West Virginia 25817',7821,9474);
INSERT INTO "django_geo_db_zipcode" VALUES(10786,25818,-5,'Bradley, West Virginia 25818',7822,9475);
INSERT INTO "django_geo_db_zipcode" VALUES(10787,25820,-5,'Camp Creek, West Virginia 25820',7823,9476);
INSERT INTO "django_geo_db_zipcode" VALUES(10788,25823,-5,'Coal City, West Virginia 25823',7824,9477);
INSERT INTO "django_geo_db_zipcode" VALUES(10789,25825,-5,'Cool Ridge, West Virginia 25825',7825,9478);
INSERT INTO "django_geo_db_zipcode" VALUES(10790,25826,-5,'Corinne, West Virginia 25826',7826,9479);
INSERT INTO "django_geo_db_zipcode" VALUES(10791,25827,-5,'Crab Orchard, West Virginia 25827',7827,9480);
INSERT INTO "django_geo_db_zipcode" VALUES(10792,25831,-5,'Danese, West Virginia 25831',7828,9481);
INSERT INTO "django_geo_db_zipcode" VALUES(10793,25832,-5,'Daniels, West Virginia 25832',7829,9482);
INSERT INTO "django_geo_db_zipcode" VALUES(10794,25833,-5,'Dothan, West Virginia 25833',7830,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10795,25836,-5,'Eccles, West Virginia 25836',7831,9483);
INSERT INTO "django_geo_db_zipcode" VALUES(10796,25837,-5,'Edmond, West Virginia 25837',7832,9484);
INSERT INTO "django_geo_db_zipcode" VALUES(10797,25839,-5,'Fairdale, West Virginia 25839',7833,9485);
INSERT INTO "django_geo_db_zipcode" VALUES(10798,25840,-5,'Fayetteville, West Virginia 25840',7834,9486);
INSERT INTO "django_geo_db_zipcode" VALUES(10799,25841,-5,'Flat Top, West Virginia 25841',7835,9487);
INSERT INTO "django_geo_db_zipcode" VALUES(10800,25843,-5,'Ghent, West Virginia 25843',7836,9488);
INSERT INTO "django_geo_db_zipcode" VALUES(10801,25844,-5,'Glen Daniel, West Virginia 25844',7837,9489);
INSERT INTO "django_geo_db_zipcode" VALUES(10802,25845,-5,'Glen Fork, West Virginia 25845',7838,9490);
INSERT INTO "django_geo_db_zipcode" VALUES(10803,25846,-5,'Glen Jean, West Virginia 25846',7839,9491);
INSERT INTO "django_geo_db_zipcode" VALUES(10804,25847,-5,'Glen Morgan, West Virginia 25847',7840,9492);
INSERT INTO "django_geo_db_zipcode" VALUES(10805,25848,-5,'Glen Rogers, West Virginia 25848',7841,9493);
INSERT INTO "django_geo_db_zipcode" VALUES(10806,25849,-5,'Glen White, West Virginia 25849',7842,9494);
INSERT INTO "django_geo_db_zipcode" VALUES(10807,25851,-5,'Harper, West Virginia 25851',7843,9495);
INSERT INTO "django_geo_db_zipcode" VALUES(10808,25853,-5,'Helen, West Virginia 25853',7844,9496);
INSERT INTO "django_geo_db_zipcode" VALUES(10809,25854,-5,'Hico, West Virginia 25854',7845,9497);
INSERT INTO "django_geo_db_zipcode" VALUES(10810,25855,-5,'Hilltop, West Virginia 25855',7846,9498);
INSERT INTO "django_geo_db_zipcode" VALUES(10811,25856,-5,'Jonben, West Virginia 25856',7847,9499);
INSERT INTO "django_geo_db_zipcode" VALUES(10812,25857,-5,'Josephine, West Virginia 25857',7848,9500);
INSERT INTO "django_geo_db_zipcode" VALUES(10813,25859,-5,'Kilsyth, West Virginia 25859',7849,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10814,25860,-5,'Lanark, West Virginia 25860',7850,9470);
INSERT INTO "django_geo_db_zipcode" VALUES(10815,25862,-5,'Lansing, West Virginia 25862',7851,9501);
INSERT INTO "django_geo_db_zipcode" VALUES(10816,25864,-5,'Layland, West Virginia 25864',7852,9502);
INSERT INTO "django_geo_db_zipcode" VALUES(10817,25865,-5,'Lester, West Virginia 25865',7853,9503);
INSERT INTO "django_geo_db_zipcode" VALUES(10818,25866,-5,'Lochgelly, West Virginia 25866',7854,9504);
INSERT INTO "django_geo_db_zipcode" VALUES(10819,25868,-5,'Lookout, West Virginia 25868',7855,9505);
INSERT INTO "django_geo_db_zipcode" VALUES(10820,25870,-5,'Maben, West Virginia 25870',7856,9506);
INSERT INTO "django_geo_db_zipcode" VALUES(10821,25871,-5,'Mabscott, West Virginia 25871',7857,9507);
INSERT INTO "django_geo_db_zipcode" VALUES(10822,25873,-5,'Mac Arthur, West Virginia 25873',7858,9508);
INSERT INTO "django_geo_db_zipcode" VALUES(10823,25875,-5,'McGraws, West Virginia 25875',7859,9509);
INSERT INTO "django_geo_db_zipcode" VALUES(10824,25876,-5,'Saulsville, West Virginia 25876',7860,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10825,25878,-5,'Midway, West Virginia 25878',7861,9510);
INSERT INTO "django_geo_db_zipcode" VALUES(10826,25879,-5,'Minden, West Virginia 25879',7862,9511);
INSERT INTO "django_geo_db_zipcode" VALUES(10827,25880,-5,'Mount Hope, West Virginia 25880',7863,9512);
INSERT INTO "django_geo_db_zipcode" VALUES(10828,25882,-5,'Mullens, West Virginia 25882',7864,9513);
INSERT INTO "django_geo_db_zipcode" VALUES(10829,25898,-5,'Shady Spring, West Virginia 25898',7865,9514);
INSERT INTO "django_geo_db_zipcode" VALUES(10830,25901,-5,'Oak Hill, West Virginia 25901',7866,9515);
INSERT INTO "django_geo_db_zipcode" VALUES(10831,25902,-5,'Odd, West Virginia 25902',7867,9516);
INSERT INTO "django_geo_db_zipcode" VALUES(10832,25904,-5,'Pax, West Virginia 25904',7868,9517);
INSERT INTO "django_geo_db_zipcode" VALUES(10833,25906,-5,'Piney View, West Virginia 25906',7869,9518);
INSERT INTO "django_geo_db_zipcode" VALUES(10834,25907,-5,'Prince, West Virginia 25907',7870,9519);
INSERT INTO "django_geo_db_zipcode" VALUES(10835,25908,-5,'Princewick, West Virginia 25908',7871,9520);
INSERT INTO "django_geo_db_zipcode" VALUES(10836,25909,-5,'Prosperity, West Virginia 25909',7872,9521);
INSERT INTO "django_geo_db_zipcode" VALUES(10837,25911,-5,'Raleigh, West Virginia 25911',7873,9522);
INSERT INTO "django_geo_db_zipcode" VALUES(10838,25912,-5,'Ramsey, West Virginia 25912',7874,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10839,25913,-5,'Ravencliff, West Virginia 25913',7875,9523);
INSERT INTO "django_geo_db_zipcode" VALUES(10840,25914,-5,'Redstar, West Virginia 25914',7876,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10841,25915,-5,'Rhodell, West Virginia 25915',7877,9524);
INSERT INTO "django_geo_db_zipcode" VALUES(10842,25916,-5,'Sabine, West Virginia 25916',7878,9525);
INSERT INTO "django_geo_db_zipcode" VALUES(10843,25917,-5,'Scarbro, West Virginia 25917',7879,9526);
INSERT INTO "django_geo_db_zipcode" VALUES(10844,25918,-5,'Shady Spring, West Virginia 25918',7865,9527);
INSERT INTO "django_geo_db_zipcode" VALUES(10845,25919,-5,'Skelton, West Virginia 25919',7880,9528);
INSERT INTO "django_geo_db_zipcode" VALUES(10846,25920,-5,'Slab Fork, West Virginia 25920',7881,9529);
INSERT INTO "django_geo_db_zipcode" VALUES(10847,25921,-5,'Sophia, West Virginia 25921',7882,9530);
INSERT INTO "django_geo_db_zipcode" VALUES(10848,25922,-5,'Spanishburg, West Virginia 25922',7883,9531);
INSERT INTO "django_geo_db_zipcode" VALUES(10849,25926,-5,'Sprague, West Virginia 25926',7884,9532);
INSERT INTO "django_geo_db_zipcode" VALUES(10850,25927,-5,'Stanaford, West Virginia 25927',7885,9470);
INSERT INTO "django_geo_db_zipcode" VALUES(10851,25928,-5,'Stephenson, West Virginia 25928',7886,9533);
INSERT INTO "django_geo_db_zipcode" VALUES(10852,25931,-5,'Summerlee, West Virginia 25931',7887,9280);
INSERT INTO "django_geo_db_zipcode" VALUES(10853,25932,-5,'Surveyor, West Virginia 25932',7888,9534);
INSERT INTO "django_geo_db_zipcode" VALUES(10854,25934,-5,'Terry, West Virginia 25934',7889,9535);
INSERT INTO "django_geo_db_zipcode" VALUES(10855,25936,-5,'Thurmond, West Virginia 25936',7890,9536);
INSERT INTO "django_geo_db_zipcode" VALUES(10856,25938,-5,'Victor, West Virginia 25938',7891,9537);
INSERT INTO "django_geo_db_zipcode" VALUES(10857,25942,-5,'Winona, West Virginia 25942',7892,9538);
INSERT INTO "django_geo_db_zipcode" VALUES(10858,25943,-5,'Wyco, West Virginia 25943',7893,9091);
INSERT INTO "django_geo_db_zipcode" VALUES(10859,25951,-5,'Hinton, West Virginia 25951',7894,9539);
INSERT INTO "django_geo_db_zipcode" VALUES(10860,25958,-5,'Charmco, West Virginia 25958',7895,9540);
INSERT INTO "django_geo_db_zipcode" VALUES(10861,25961,-5,'Crichton, West Virginia 25961',7896,9139);
INSERT INTO "django_geo_db_zipcode" VALUES(10862,25962,-5,'Rainelle, West Virginia 25962',7897,9541);
INSERT INTO "django_geo_db_zipcode" VALUES(10863,25965,-5,'Elton, West Virginia 25965',7898,9542);
INSERT INTO "django_geo_db_zipcode" VALUES(10864,25966,-5,'Green Sulphur Springs, West Virginia 25966',7899,9543);
INSERT INTO "django_geo_db_zipcode" VALUES(10865,25967,-5,'Hines, West Virginia 25967',7900,9139);
INSERT INTO "django_geo_db_zipcode" VALUES(10866,25969,-5,'Jumping Branch, West Virginia 25969',7901,9544);
INSERT INTO "django_geo_db_zipcode" VALUES(10867,25971,-5,'Lerona, West Virginia 25971',7902,9545);
INSERT INTO "django_geo_db_zipcode" VALUES(10868,25972,-5,'Leslie, West Virginia 25972',7903,9546);
INSERT INTO "django_geo_db_zipcode" VALUES(10869,25976,-5,'Meadow Bridge, West Virginia 25976',7904,9547);
INSERT INTO "django_geo_db_zipcode" VALUES(10870,25977,-5,'Meadow Creek, West Virginia 25977',7905,9548);
INSERT INTO "django_geo_db_zipcode" VALUES(10871,25978,-5,'Nimitz, West Virginia 25978',7906,9549);
INSERT INTO "django_geo_db_zipcode" VALUES(10872,25979,-5,'Pipestem, West Virginia 25979',7907,9550);
INSERT INTO "django_geo_db_zipcode" VALUES(10873,25981,-5,'Quinwood, West Virginia 25981',7908,9551);
INSERT INTO "django_geo_db_zipcode" VALUES(10874,25984,-5,'Rupert, West Virginia 25984',7909,9552);
INSERT INTO "django_geo_db_zipcode" VALUES(10875,25985,-5,'Sandstone, West Virginia 25985',7910,9553);
INSERT INTO "django_geo_db_zipcode" VALUES(10876,25986,-5,'Spring Dale, West Virginia 25986',7911,9554);
INSERT INTO "django_geo_db_zipcode" VALUES(10877,25988,-5,'True, West Virginia 25988',7912,9542);
INSERT INTO "django_geo_db_zipcode" VALUES(10878,25989,-5,'White Oak, West Virginia 25989',7913,9555);
INSERT INTO "django_geo_db_zipcode" VALUES(10879,26003,-5,'Wheeling, West Virginia 26003',7914,9556);
INSERT INTO "django_geo_db_zipcode" VALUES(10880,26030,-5,'Beech Bottom, West Virginia 26030',7915,9557);
INSERT INTO "django_geo_db_zipcode" VALUES(10881,26031,-5,'Benwood, West Virginia 26031',7916,9558);
INSERT INTO "django_geo_db_zipcode" VALUES(10882,26032,-5,'Bethany, West Virginia 26032',7917,9559);
INSERT INTO "django_geo_db_zipcode" VALUES(10883,26033,-5,'Cameron, West Virginia 26033',7918,9560);
INSERT INTO "django_geo_db_zipcode" VALUES(10884,26034,-5,'Chester, West Virginia 26034',7919,9561);
INSERT INTO "django_geo_db_zipcode" VALUES(10885,26035,-5,'Colliers, West Virginia 26035',7920,9562);
INSERT INTO "django_geo_db_zipcode" VALUES(10886,26036,-5,'Dallas, West Virginia 26036',7921,9563);
INSERT INTO "django_geo_db_zipcode" VALUES(10887,26037,-5,'Follansbee, West Virginia 26037',7922,9564);
INSERT INTO "django_geo_db_zipcode" VALUES(10888,26038,-5,'Glen Dale, West Virginia 26038',7923,9565);
INSERT INTO "django_geo_db_zipcode" VALUES(10889,26039,-5,'Glen Easton, West Virginia 26039',7924,9566);
INSERT INTO "django_geo_db_zipcode" VALUES(10890,26040,-5,'McMechen, West Virginia 26040',7925,9567);
INSERT INTO "django_geo_db_zipcode" VALUES(10891,26041,-5,'Moundsville, West Virginia 26041',7926,9568);
INSERT INTO "django_geo_db_zipcode" VALUES(10892,26047,-5,'New Cumberland, West Virginia 26047',7927,9569);
INSERT INTO "django_geo_db_zipcode" VALUES(10893,26050,-5,'Newell, West Virginia 26050',7928,9570);
INSERT INTO "django_geo_db_zipcode" VALUES(10894,26055,-5,'Proctor, West Virginia 26055',7929,9571);
INSERT INTO "django_geo_db_zipcode" VALUES(10895,26056,-5,'New Manchester, West Virginia 26056',7930,9572);
INSERT INTO "django_geo_db_zipcode" VALUES(10896,26058,-5,'Short Creek, West Virginia 26058',7931,9573);
INSERT INTO "django_geo_db_zipcode" VALUES(10897,26059,-5,'Triadelphia, West Virginia 26059',7932,9574);
INSERT INTO "django_geo_db_zipcode" VALUES(10898,26060,-5,'Valley Grove, West Virginia 26060',7933,9575);
INSERT INTO "django_geo_db_zipcode" VALUES(10899,26062,-5,'Weirton, West Virginia 26062',7934,9576);
INSERT INTO "django_geo_db_zipcode" VALUES(10900,26070,-5,'Wellsburg, West Virginia 26070',7935,9577);
INSERT INTO "django_geo_db_zipcode" VALUES(10901,26074,-5,'West Liberty, West Virginia 26074',7936,9578);
INSERT INTO "django_geo_db_zipcode" VALUES(10902,26075,-5,'Windsor Heights, West Virginia 26075',7937,9579);
INSERT INTO "django_geo_db_zipcode" VALUES(10903,26101,-5,'Parkersburg, West Virginia 26101',7938,9580);
INSERT INTO "django_geo_db_zipcode" VALUES(10904,26102,-5,'Parkersburg, West Virginia 26102',7938,9581);
INSERT INTO "django_geo_db_zipcode" VALUES(10905,26103,-5,'Parkersburg, West Virginia 26103',7938,9582);
INSERT INTO "django_geo_db_zipcode" VALUES(10906,26104,-5,'Parkersburg, West Virginia 26104',7938,9583);
INSERT INTO "django_geo_db_zipcode" VALUES(10907,26105,-5,'Vienna, West Virginia 26105',7939,9584);
INSERT INTO "django_geo_db_zipcode" VALUES(10908,26106,-5,'Parkersburg, West Virginia 26106',7938,9581);
INSERT INTO "django_geo_db_zipcode" VALUES(10909,26120,-5,'Mineral Wells, West Virginia 26120',7940,9581);
INSERT INTO "django_geo_db_zipcode" VALUES(10910,26121,-5,'Mineral Wells, West Virginia 26121',7940,9581);
INSERT INTO "django_geo_db_zipcode" VALUES(10911,26133,-5,'Belleville, West Virginia 26133',7941,9585);
INSERT INTO "django_geo_db_zipcode" VALUES(10912,26134,-5,'Belmont, West Virginia 26134',7942,9586);
INSERT INTO "django_geo_db_zipcode" VALUES(10913,26135,-5,'Bens Run, West Virginia 26135',7943,9587);
INSERT INTO "django_geo_db_zipcode" VALUES(10914,26136,-5,'Big Bend, West Virginia 26136',7944,9588);
INSERT INTO "django_geo_db_zipcode" VALUES(10915,26137,-5,'Big Springs, West Virginia 26137',7945,9589);
INSERT INTO "django_geo_db_zipcode" VALUES(10916,26138,-5,'Brohard, West Virginia 26138',7946,9590);
INSERT INTO "django_geo_db_zipcode" VALUES(10917,26141,-5,'Creston, West Virginia 26141',7947,9591);
INSERT INTO "django_geo_db_zipcode" VALUES(10918,26142,-5,'Davisville, West Virginia 26142',7948,9592);
INSERT INTO "django_geo_db_zipcode" VALUES(10919,26143,-5,'Elizabeth, West Virginia 26143',7949,9593);
INSERT INTO "django_geo_db_zipcode" VALUES(10920,26145,-5,'Pennsboro, West Virginia 26145',7950,9594);
INSERT INTO "django_geo_db_zipcode" VALUES(10921,26146,-5,'Friendly, West Virginia 26146',7951,9595);
INSERT INTO "django_geo_db_zipcode" VALUES(10922,26147,-5,'Grantsville, West Virginia 26147',7952,9596);
INSERT INTO "django_geo_db_zipcode" VALUES(10923,26148,-5,'Macfarlan, West Virginia 26148',7953,9597);
INSERT INTO "django_geo_db_zipcode" VALUES(10924,26149,-5,'Middlebourne, West Virginia 26149',7954,9598);
INSERT INTO "django_geo_db_zipcode" VALUES(10925,26150,-5,'Mineral Wells, West Virginia 26150',7940,9599);
INSERT INTO "django_geo_db_zipcode" VALUES(10926,26151,-5,'Mount Zion, West Virginia 26151',7955,9600);
INSERT INTO "django_geo_db_zipcode" VALUES(10927,26152,-5,'Munday, West Virginia 26152',7956,9601);
INSERT INTO "django_geo_db_zipcode" VALUES(10928,26155,-5,'New Martinsville, West Virginia 26155',7957,9602);
INSERT INTO "django_geo_db_zipcode" VALUES(10929,26159,-5,'Paden City, West Virginia 26159',7958,9603);
INSERT INTO "django_geo_db_zipcode" VALUES(10930,26160,-5,'Palestine, West Virginia 26160',7959,9604);
INSERT INTO "django_geo_db_zipcode" VALUES(10931,26161,-5,'Petroleum, West Virginia 26161',7960,9605);
INSERT INTO "django_geo_db_zipcode" VALUES(10932,26162,-5,'Porters Falls, West Virginia 26162',7961,9606);
INSERT INTO "django_geo_db_zipcode" VALUES(10933,26164,-5,'Ravenswood, West Virginia 26164',7962,9607);
INSERT INTO "django_geo_db_zipcode" VALUES(10934,26167,-5,'Reader, West Virginia 26167',7963,9608);
INSERT INTO "django_geo_db_zipcode" VALUES(10935,26169,-5,'Rockport, West Virginia 26169',7964,9609);
INSERT INTO "django_geo_db_zipcode" VALUES(10936,26170,-5,'Saint Marys, West Virginia 26170',7965,9610);
INSERT INTO "django_geo_db_zipcode" VALUES(10937,26173,-5,'Sherman, West Virginia 26173',7966,9611);
INSERT INTO "django_geo_db_zipcode" VALUES(10938,26175,-5,'Sistersville, West Virginia 26175',7967,9612);
INSERT INTO "django_geo_db_zipcode" VALUES(10939,26178,-5,'Smithville, West Virginia 26178',7968,9613);
INSERT INTO "django_geo_db_zipcode" VALUES(10940,26180,-5,'Walker, West Virginia 26180',7969,9614);
INSERT INTO "django_geo_db_zipcode" VALUES(10941,26181,-5,'Washington, West Virginia 26181',7970,9615);
INSERT INTO "django_geo_db_zipcode" VALUES(10942,26184,-5,'Waverly, West Virginia 26184',7971,9616);
INSERT INTO "django_geo_db_zipcode" VALUES(10943,26186,-5,'Wileyville, West Virginia 26186',7972,9617);
INSERT INTO "django_geo_db_zipcode" VALUES(10944,26187,-5,'Williamstown, West Virginia 26187',7973,9618);
INSERT INTO "django_geo_db_zipcode" VALUES(10945,26201,-5,'Buckhannon, West Virginia 26201',7974,9619);
INSERT INTO "django_geo_db_zipcode" VALUES(10946,26202,-5,'Fenwick, West Virginia 26202',7975,9620);
INSERT INTO "django_geo_db_zipcode" VALUES(10947,26203,-5,'Erbacon, West Virginia 26203',7976,9621);
INSERT INTO "django_geo_db_zipcode" VALUES(10948,26205,-5,'Craigsville, West Virginia 26205',7977,9622);
INSERT INTO "django_geo_db_zipcode" VALUES(10949,26206,-5,'Cowen, West Virginia 26206',7978,9623);
INSERT INTO "django_geo_db_zipcode" VALUES(10950,26208,-5,'Camden On Gauley, West Virginia 26208',7979,9624);
INSERT INTO "django_geo_db_zipcode" VALUES(10951,26209,-5,'Snowshoe, West Virginia 26209',7980,9625);
INSERT INTO "django_geo_db_zipcode" VALUES(10952,26210,-5,'Adrian, West Virginia 26210',7981,9626);
INSERT INTO "django_geo_db_zipcode" VALUES(10953,26215,-5,'Cleveland, West Virginia 26215',7982,9627);
INSERT INTO "django_geo_db_zipcode" VALUES(10954,26217,-5,'Diana, West Virginia 26217',7983,9628);
INSERT INTO "django_geo_db_zipcode" VALUES(10955,26218,-5,'French Creek, West Virginia 26218',7984,9629);
INSERT INTO "django_geo_db_zipcode" VALUES(10956,26219,-5,'Frenchton, West Virginia 26219',7985,9630);
INSERT INTO "django_geo_db_zipcode" VALUES(10957,26222,-5,'Hacker Valley, West Virginia 26222',7986,9631);
INSERT INTO "django_geo_db_zipcode" VALUES(10958,26224,-5,'Helvetia, West Virginia 26224',7987,9632);
INSERT INTO "django_geo_db_zipcode" VALUES(10959,26228,-5,'Kanawha Head, West Virginia 26228',7988,9633);
INSERT INTO "django_geo_db_zipcode" VALUES(10960,26229,-5,'Lorentz, West Virginia 26229',7989,9630);
INSERT INTO "django_geo_db_zipcode" VALUES(10961,26230,-5,'Pickens, West Virginia 26230',7990,9634);
INSERT INTO "django_geo_db_zipcode" VALUES(10962,26234,-5,'Rock Cave, West Virginia 26234',7991,9635);
INSERT INTO "django_geo_db_zipcode" VALUES(10963,26236,-5,'Selbyville, West Virginia 26236',7992,9636);
INSERT INTO "django_geo_db_zipcode" VALUES(10964,26237,-5,'Tallmansville, West Virginia 26237',7993,9637);
INSERT INTO "django_geo_db_zipcode" VALUES(10965,26238,-5,'Volga, West Virginia 26238',7994,9638);
INSERT INTO "django_geo_db_zipcode" VALUES(10966,26241,-5,'Elkins, West Virginia 26241',7995,9639);
INSERT INTO "django_geo_db_zipcode" VALUES(10967,26250,-5,'Belington, West Virginia 26250',7996,9640);
INSERT INTO "django_geo_db_zipcode" VALUES(10968,26253,-5,'Beverly, West Virginia 26253',7997,9641);
INSERT INTO "django_geo_db_zipcode" VALUES(10969,26254,-5,'Bowden, West Virginia 26254',7998,9642);
INSERT INTO "django_geo_db_zipcode" VALUES(10970,26257,-5,'Coalton, West Virginia 26257',7999,9643);
INSERT INTO "django_geo_db_zipcode" VALUES(10971,26259,-5,'Dailey, West Virginia 26259',8000,9644);
INSERT INTO "django_geo_db_zipcode" VALUES(10972,26260,-5,'Davis, West Virginia 26260',8001,9645);
INSERT INTO "django_geo_db_zipcode" VALUES(10973,26261,-5,'Richwood, West Virginia 26261',8002,9646);
INSERT INTO "django_geo_db_zipcode" VALUES(10974,26263,-5,'Dryfork, West Virginia 26263',8003,9647);
INSERT INTO "django_geo_db_zipcode" VALUES(10975,26264,-5,'Durbin, West Virginia 26264',8004,9648);
INSERT INTO "django_geo_db_zipcode" VALUES(10976,26266,-5,'Upperglade, West Virginia 26266',8005,9649);
INSERT INTO "django_geo_db_zipcode" VALUES(10977,26267,-5,'Ellamore, West Virginia 26267',8006,9650);
INSERT INTO "django_geo_db_zipcode" VALUES(10978,26268,-5,'Glady, West Virginia 26268',8007,9651);
INSERT INTO "django_geo_db_zipcode" VALUES(10979,26269,-5,'Hambleton, West Virginia 26269',8008,9652);
INSERT INTO "django_geo_db_zipcode" VALUES(10980,26270,-5,'Harman, West Virginia 26270',8009,9653);
INSERT INTO "django_geo_db_zipcode" VALUES(10981,26271,-5,'Hendricks, West Virginia 26271',8010,9654);
INSERT INTO "django_geo_db_zipcode" VALUES(10982,26273,-5,'Huttonsville, West Virginia 26273',8011,9655);
INSERT INTO "django_geo_db_zipcode" VALUES(10983,26275,-5,'Junior, West Virginia 26275',8012,9656);
INSERT INTO "django_geo_db_zipcode" VALUES(10984,26276,-5,'Kerens, West Virginia 26276',8013,9657);
INSERT INTO "django_geo_db_zipcode" VALUES(10985,26278,-5,'Mabie, West Virginia 26278',8014,9658);
INSERT INTO "django_geo_db_zipcode" VALUES(10986,26280,-5,'Mill Creek, West Virginia 26280',8015,9659);
INSERT INTO "django_geo_db_zipcode" VALUES(10987,26282,-5,'Monterville, West Virginia 26282',8016,9660);
INSERT INTO "django_geo_db_zipcode" VALUES(10988,26283,-5,'Montrose, West Virginia 26283',8017,9661);
INSERT INTO "django_geo_db_zipcode" VALUES(10989,26285,-5,'Norton, West Virginia 26285',8018,9662);
INSERT INTO "django_geo_db_zipcode" VALUES(10990,26287,-5,'Parsons, West Virginia 26287',8019,9663);
INSERT INTO "django_geo_db_zipcode" VALUES(10991,26288,-5,'Webster Springs, West Virginia 26288',8020,9664);
INSERT INTO "django_geo_db_zipcode" VALUES(10992,26289,-5,'Red Creek, West Virginia 26289',8021,9665);
INSERT INTO "django_geo_db_zipcode" VALUES(10993,26291,-5,'Slatyfork, West Virginia 26291',8022,9666);
INSERT INTO "django_geo_db_zipcode" VALUES(10994,26292,-5,'Thomas, West Virginia 26292',8023,9667);
INSERT INTO "django_geo_db_zipcode" VALUES(10995,26293,-5,'Valley Bend, West Virginia 26293',8024,9668);
INSERT INTO "django_geo_db_zipcode" VALUES(10996,26294,-5,'Valley Head, West Virginia 26294',8025,9669);
INSERT INTO "django_geo_db_zipcode" VALUES(10997,26296,-5,'Whitmer, West Virginia 26296',8026,9670);
INSERT INTO "django_geo_db_zipcode" VALUES(10998,26298,-5,'Bergoo, West Virginia 26298',8027,9671);
INSERT INTO "django_geo_db_zipcode" VALUES(10999,26301,-5,'Clarksburg, West Virginia 26301',8028,9672);
INSERT INTO "django_geo_db_zipcode" VALUES(11000,26302,-5,'Clarksburg, West Virginia 26302',8028,9673);
INSERT INTO "django_geo_db_zipcode" VALUES(11001,26306,-5,'Clarksburg, West Virginia 26306',8028,9674);
INSERT INTO "django_geo_db_zipcode" VALUES(11002,26320,-5,'Alma, West Virginia 26320',8029,9675);
INSERT INTO "django_geo_db_zipcode" VALUES(11003,26321,-5,'Alum Bridge, West Virginia 26321',8030,9676);
INSERT INTO "django_geo_db_zipcode" VALUES(11004,26323,-5,'Anmoore, West Virginia 26323',8031,9677);
INSERT INTO "django_geo_db_zipcode" VALUES(11005,26325,-5,'Auburn, West Virginia 26325',8032,9678);
INSERT INTO "django_geo_db_zipcode" VALUES(11006,26327,-5,'Berea, West Virginia 26327',8033,9679);
INSERT INTO "django_geo_db_zipcode" VALUES(11007,26328,-5,'Blandville, West Virginia 26328',8034,9680);
INSERT INTO "django_geo_db_zipcode" VALUES(11008,26330,-5,'Bridgeport, West Virginia 26330',8035,9681);
INSERT INTO "django_geo_db_zipcode" VALUES(11009,26332,-5,'Bristol, West Virginia 26332',8036,9682);
INSERT INTO "django_geo_db_zipcode" VALUES(11010,26333,-5,'Burnsville, West Virginia 26333',8037,9683);
INSERT INTO "django_geo_db_zipcode" VALUES(11011,26334,-5,'Brownton, West Virginia 26334',8038,9684);
INSERT INTO "django_geo_db_zipcode" VALUES(11012,26335,-5,'Burnsville, West Virginia 26335',8037,9685);
INSERT INTO "django_geo_db_zipcode" VALUES(11013,26337,-5,'Cairo, West Virginia 26337',8039,9686);
INSERT INTO "django_geo_db_zipcode" VALUES(11014,26338,-5,'Camden, West Virginia 26338',8040,9687);
INSERT INTO "django_geo_db_zipcode" VALUES(11015,26339,-5,'Center Point, West Virginia 26339',8041,9688);
INSERT INTO "django_geo_db_zipcode" VALUES(11016,26342,-5,'Coxs Mills, West Virginia 26342',8042,9689);
INSERT INTO "django_geo_db_zipcode" VALUES(11017,26343,-5,'Crawford, West Virginia 26343',8043,9690);
INSERT INTO "django_geo_db_zipcode" VALUES(11018,26346,-5,'Ellenboro, West Virginia 26346',8044,9691);
INSERT INTO "django_geo_db_zipcode" VALUES(11019,26347,-5,'Flemington, West Virginia 26347',8045,9692);
INSERT INTO "django_geo_db_zipcode" VALUES(11020,26348,-5,'Folsom, West Virginia 26348',8046,9693);
INSERT INTO "django_geo_db_zipcode" VALUES(11021,26349,-5,'Galloway, West Virginia 26349',8047,9694);
INSERT INTO "django_geo_db_zipcode" VALUES(11022,26350,-5,'Gilmer, West Virginia 26350',8048,9307);
INSERT INTO "django_geo_db_zipcode" VALUES(11023,26351,-5,'Glenville, West Virginia 26351',8049,9695);
INSERT INTO "django_geo_db_zipcode" VALUES(11024,26354,-5,'Grafton, West Virginia 26354',8050,9696);
INSERT INTO "django_geo_db_zipcode" VALUES(11025,26361,-5,'Gypsy, West Virginia 26361',8051,9697);
INSERT INTO "django_geo_db_zipcode" VALUES(11026,26362,-5,'Harrisville, West Virginia 26362',8052,9698);
INSERT INTO "django_geo_db_zipcode" VALUES(11027,26366,-5,'Haywood, West Virginia 26366',8053,9699);
INSERT INTO "django_geo_db_zipcode" VALUES(11028,26369,-5,'Hepzibah, West Virginia 26369',8054,9700);
INSERT INTO "django_geo_db_zipcode" VALUES(11029,26372,-5,'Horner, West Virginia 26372',8055,9701);
INSERT INTO "django_geo_db_zipcode" VALUES(11030,26374,-5,'Independence, West Virginia 26374',8056,9702);
INSERT INTO "django_geo_db_zipcode" VALUES(11031,26375,-5,'Industrial, West Virginia 26375',8057,9703);
INSERT INTO "django_geo_db_zipcode" VALUES(11032,26376,-5,'Ireland, West Virginia 26376',8058,9704);
INSERT INTO "django_geo_db_zipcode" VALUES(11033,26377,-5,'Jacksonburg, West Virginia 26377',8059,9705);
INSERT INTO "django_geo_db_zipcode" VALUES(11034,26378,-5,'Jane Lew, West Virginia 26378',8060,9706);
INSERT INTO "django_geo_db_zipcode" VALUES(11035,26384,-5,'Linn, West Virginia 26384',8061,9707);
INSERT INTO "django_geo_db_zipcode" VALUES(11036,26385,-5,'Lost Creek, West Virginia 26385',8062,9708);
INSERT INTO "django_geo_db_zipcode" VALUES(11037,26386,-5,'Lumberport, West Virginia 26386',8063,9709);
INSERT INTO "django_geo_db_zipcode" VALUES(11038,26404,-5,'Meadowbrook, West Virginia 26404',8064,9710);
INSERT INTO "django_geo_db_zipcode" VALUES(11039,26405,-5,'Moatsville, West Virginia 26405',8065,9711);
INSERT INTO "django_geo_db_zipcode" VALUES(11040,26407,-5,'Mountain, West Virginia 26407',8066,9712);
INSERT INTO "django_geo_db_zipcode" VALUES(11041,26408,-5,'Mount Clare, West Virginia 26408',8067,9713);
INSERT INTO "django_geo_db_zipcode" VALUES(11042,26410,-5,'Newburg, West Virginia 26410',8068,9714);
INSERT INTO "django_geo_db_zipcode" VALUES(11043,26411,-5,'New Milton, West Virginia 26411',8069,9715);
INSERT INTO "django_geo_db_zipcode" VALUES(11044,26412,-5,'Orlando, West Virginia 26412',8070,9716);
INSERT INTO "django_geo_db_zipcode" VALUES(11045,26415,-5,'Pennsboro, West Virginia 26415',7950,9717);
INSERT INTO "django_geo_db_zipcode" VALUES(11046,26416,-5,'Philippi, West Virginia 26416',8071,9718);
INSERT INTO "django_geo_db_zipcode" VALUES(11047,26419,-5,'Pine Grove, West Virginia 26419',8072,9719);
INSERT INTO "django_geo_db_zipcode" VALUES(11048,26421,-5,'Pullman, West Virginia 26421',8073,9720);
INSERT INTO "django_geo_db_zipcode" VALUES(11049,26422,-5,'Reynoldsville, West Virginia 26422',8074,9721);
INSERT INTO "django_geo_db_zipcode" VALUES(11050,26424,-5,'Rosemont, West Virginia 26424',8075,9722);
INSERT INTO "django_geo_db_zipcode" VALUES(11051,26425,-5,'Rowlesburg, West Virginia 26425',8076,9723);
INSERT INTO "django_geo_db_zipcode" VALUES(11052,26426,-5,'Salem, West Virginia 26426',8077,9724);
INSERT INTO "django_geo_db_zipcode" VALUES(11053,26430,-5,'Sand Fork, West Virginia 26430',8078,9725);
INSERT INTO "django_geo_db_zipcode" VALUES(11054,26431,-5,'Shinnston, West Virginia 26431',8079,9726);
INSERT INTO "django_geo_db_zipcode" VALUES(11055,26434,-5,'Shirley, West Virginia 26434',8080,9587);
INSERT INTO "django_geo_db_zipcode" VALUES(11056,26435,-5,'Simpson, West Virginia 26435',8081,9727);
INSERT INTO "django_geo_db_zipcode" VALUES(11057,26436,-5,'Smithburg, West Virginia 26436',8082,9728);
INSERT INTO "django_geo_db_zipcode" VALUES(11058,26437,-5,'Smithfield, West Virginia 26437',8083,9729);
INSERT INTO "django_geo_db_zipcode" VALUES(11059,26438,-5,'Spelter, West Virginia 26438',8084,9730);
INSERT INTO "django_geo_db_zipcode" VALUES(11060,26440,-5,'Thornton, West Virginia 26440',8085,9731);
INSERT INTO "django_geo_db_zipcode" VALUES(11061,26443,-5,'Troy, West Virginia 26443',8086,9732);
INSERT INTO "django_geo_db_zipcode" VALUES(11062,26444,-5,'Tunnelton, West Virginia 26444',8087,9733);
INSERT INTO "django_geo_db_zipcode" VALUES(11063,26447,-5,'Walkersville, West Virginia 26447',8088,9734);
INSERT INTO "django_geo_db_zipcode" VALUES(11064,26448,-5,'Wallace, West Virginia 26448',8089,9735);
INSERT INTO "django_geo_db_zipcode" VALUES(11065,26451,-5,'West Milford, West Virginia 26451',8090,9736);
INSERT INTO "django_geo_db_zipcode" VALUES(11066,26452,-5,'Weston, West Virginia 26452',8091,9737);
INSERT INTO "django_geo_db_zipcode" VALUES(11067,26456,-5,'West Union, West Virginia 26456',8092,9738);
INSERT INTO "django_geo_db_zipcode" VALUES(11068,26461,-5,'Wilsonburg, West Virginia 26461',8093,9674);
INSERT INTO "django_geo_db_zipcode" VALUES(11069,26462,-5,'Weston, West Virginia 26462',8091,9739);
INSERT INTO "django_geo_db_zipcode" VALUES(11070,26463,-5,'Wyatt, West Virginia 26463',8094,9740);
INSERT INTO "django_geo_db_zipcode" VALUES(11071,26501,-5,'Morgantown, West Virginia 26501',8095,9741);
INSERT INTO "django_geo_db_zipcode" VALUES(11072,26502,-5,'Morgantown, West Virginia 26502',8095,9742);
INSERT INTO "django_geo_db_zipcode" VALUES(11073,26503,-5,'Morgantown, West Virginia 26503',8095,9743);
INSERT INTO "django_geo_db_zipcode" VALUES(11074,26504,-5,'Morgantown, West Virginia 26504',8095,9744);
INSERT INTO "django_geo_db_zipcode" VALUES(11075,26505,-5,'Morgantown, West Virginia 26505',8095,9745);
INSERT INTO "django_geo_db_zipcode" VALUES(11076,26506,-5,'Morgantown, West Virginia 26506',8095,9746);
INSERT INTO "django_geo_db_zipcode" VALUES(11077,26507,-5,'Morgantown, West Virginia 26507',8095,9747);
INSERT INTO "django_geo_db_zipcode" VALUES(11078,26508,-5,'Morgantown, West Virginia 26508',8095,9748);
INSERT INTO "django_geo_db_zipcode" VALUES(11079,26519,-5,'Albright, West Virginia 26519',8096,9749);
INSERT INTO "django_geo_db_zipcode" VALUES(11080,26520,-5,'Arthurdale, West Virginia 26520',8097,9750);
INSERT INTO "django_geo_db_zipcode" VALUES(11081,26521,-5,'Blacksville, West Virginia 26521',8098,9751);
INSERT INTO "django_geo_db_zipcode" VALUES(11082,26522,-5,'Booth, West Virginia 26522',8099,9744);
INSERT INTO "django_geo_db_zipcode" VALUES(11083,26524,-5,'Bretz, West Virginia 26524',8100,9752);
INSERT INTO "django_geo_db_zipcode" VALUES(11084,26525,-5,'Bruceton Mills, West Virginia 26525',8101,9753);
INSERT INTO "django_geo_db_zipcode" VALUES(11085,26527,-5,'Cassville, West Virginia 26527',8102,9744);
INSERT INTO "django_geo_db_zipcode" VALUES(11086,26529,-5,'Core, West Virginia 26529',8103,9754);
INSERT INTO "django_geo_db_zipcode" VALUES(11087,26531,-5,'Dellslow, West Virginia 26531',8104,9755);
INSERT INTO "django_geo_db_zipcode" VALUES(11088,26533,-5,'Everettville, West Virginia 26533',8105,9744);
INSERT INTO "django_geo_db_zipcode" VALUES(11089,26534,-5,'Granville, West Virginia 26534',8106,9756);
INSERT INTO "django_geo_db_zipcode" VALUES(11090,26535,-5,'Hazelton, West Virginia 26535',8107,9752);
INSERT INTO "django_geo_db_zipcode" VALUES(11091,26537,-5,'Kingwood, West Virginia 26537',8108,9757);
INSERT INTO "django_geo_db_zipcode" VALUES(11092,26541,-5,'Maidsville, West Virginia 26541',8109,9758);
INSERT INTO "django_geo_db_zipcode" VALUES(11093,26542,-5,'Masontown, West Virginia 26542',8110,9759);
INSERT INTO "django_geo_db_zipcode" VALUES(11094,26543,-5,'Osage, West Virginia 26543',8111,9760);
INSERT INTO "django_geo_db_zipcode" VALUES(11095,26544,-5,'Pentress, West Virginia 26544',8112,9761);
INSERT INTO "django_geo_db_zipcode" VALUES(11096,26546,-5,'Pursglove, West Virginia 26546',8113,9762);
INSERT INTO "django_geo_db_zipcode" VALUES(11097,26547,-5,'Reedsville, West Virginia 26547',8114,9763);
INSERT INTO "django_geo_db_zipcode" VALUES(11098,26554,-5,'Fairmont, West Virginia 26554',8115,9764);
INSERT INTO "django_geo_db_zipcode" VALUES(11099,26555,-5,'Fairmont, West Virginia 26555',8115,9765);
INSERT INTO "django_geo_db_zipcode" VALUES(11100,26559,-5,'Barrackville, West Virginia 26559',8116,9766);
INSERT INTO "django_geo_db_zipcode" VALUES(11101,26560,-5,'Baxter, West Virginia 26560',8117,9765);
INSERT INTO "django_geo_db_zipcode" VALUES(11102,26561,-5,'Big Run, West Virginia 26561',8118,9767);
INSERT INTO "django_geo_db_zipcode" VALUES(11103,26562,-5,'Burton, West Virginia 26562',8119,9768);
INSERT INTO "django_geo_db_zipcode" VALUES(11104,26563,-5,'Carolina, West Virginia 26563',8120,9769);
INSERT INTO "django_geo_db_zipcode" VALUES(11105,26566,-5,'Colfax, West Virginia 26566',8121,9765);
INSERT INTO "django_geo_db_zipcode" VALUES(11106,26568,-5,'Enterprise, West Virginia 26568',8122,9770);
INSERT INTO "django_geo_db_zipcode" VALUES(11107,26570,-5,'Fairview, West Virginia 26570',8123,9771);
INSERT INTO "django_geo_db_zipcode" VALUES(11108,26571,-5,'Farmington, West Virginia 26571',8124,9772);
INSERT INTO "django_geo_db_zipcode" VALUES(11109,26572,-5,'Four States, West Virginia 26572',8125,9773);
INSERT INTO "django_geo_db_zipcode" VALUES(11110,26574,-5,'Grant Town, West Virginia 26574',8126,9774);
INSERT INTO "django_geo_db_zipcode" VALUES(11111,26575,-5,'Hundred, West Virginia 26575',8127,9775);
INSERT INTO "django_geo_db_zipcode" VALUES(11112,26576,-5,'Idamay, West Virginia 26576',8128,9776);
INSERT INTO "django_geo_db_zipcode" VALUES(11113,26578,-5,'Kingmont, West Virginia 26578',8129,9777);
INSERT INTO "django_geo_db_zipcode" VALUES(11114,26581,-5,'Littleton, West Virginia 26581',8130,9778);
INSERT INTO "django_geo_db_zipcode" VALUES(11115,26582,-5,'Mannington, West Virginia 26582',8131,9779);
INSERT INTO "django_geo_db_zipcode" VALUES(11116,26585,-5,'Metz, West Virginia 26585',8132,9780);
INSERT INTO "django_geo_db_zipcode" VALUES(11117,26586,-5,'Montana Mines, West Virginia 26586',8133,9781);
INSERT INTO "django_geo_db_zipcode" VALUES(11118,26587,-5,'Rachel, West Virginia 26587',8134,9782);
INSERT INTO "django_geo_db_zipcode" VALUES(11119,26588,-5,'Rivesville, West Virginia 26588',8135,9783);
INSERT INTO "django_geo_db_zipcode" VALUES(11120,26589,-5,'Wadestown, West Virginia 26589',8136,9784);
INSERT INTO "django_geo_db_zipcode" VALUES(11121,26590,-5,'Wana, West Virginia 26590',8137,9785);
INSERT INTO "django_geo_db_zipcode" VALUES(11122,26591,-5,'Worthington, West Virginia 26591',8138,9786);
INSERT INTO "django_geo_db_zipcode" VALUES(11123,26601,-5,'Sutton, West Virginia 26601',8139,9787);
INSERT INTO "django_geo_db_zipcode" VALUES(11124,26610,-5,'Birch River, West Virginia 26610',8140,9788);
INSERT INTO "django_geo_db_zipcode" VALUES(11125,26611,-5,'Cedarville, West Virginia 26611',8141,9789);
INSERT INTO "django_geo_db_zipcode" VALUES(11126,26612,-5,'Centralia, West Virginia 26612',8142,9790);
INSERT INTO "django_geo_db_zipcode" VALUES(11127,26615,-5,'Copen, West Virginia 26615',8143,9791);
INSERT INTO "django_geo_db_zipcode" VALUES(11128,26617,-5,'Dille, West Virginia 26617',8144,9792);
INSERT INTO "django_geo_db_zipcode" VALUES(11129,26618,-5,'Elmira, West Virginia 26618',8145,9793);
INSERT INTO "django_geo_db_zipcode" VALUES(11130,26619,-5,'Exchange, West Virginia 26619',8146,9794);
INSERT INTO "django_geo_db_zipcode" VALUES(11131,26621,-5,'Flatwoods, West Virginia 26621',8147,9795);
INSERT INTO "django_geo_db_zipcode" VALUES(11132,26623,-5,'Frametown, West Virginia 26623',8148,9796);
INSERT INTO "django_geo_db_zipcode" VALUES(11133,26624,-5,'Gassaway, West Virginia 26624',8149,9797);
INSERT INTO "django_geo_db_zipcode" VALUES(11134,26627,-5,'Heaters, West Virginia 26627',8150,9798);
INSERT INTO "django_geo_db_zipcode" VALUES(11135,26629,-5,'Little Birch, West Virginia 26629',8151,9799);
INSERT INTO "django_geo_db_zipcode" VALUES(11136,26630,-5,'Bridgeport, West Virginia 26630',8035,9800);
INSERT INTO "django_geo_db_zipcode" VALUES(11137,26631,-5,'Napier, West Virginia 26631',8152,9801);
INSERT INTO "django_geo_db_zipcode" VALUES(11138,26634,-5,'Perkins, West Virginia 26634',8153,9802);
INSERT INTO "django_geo_db_zipcode" VALUES(11139,26636,-5,'Rosedale, West Virginia 26636',8154,9803);
INSERT INTO "django_geo_db_zipcode" VALUES(11140,26638,-5,'Shock, West Virginia 26638',8155,9804);
INSERT INTO "django_geo_db_zipcode" VALUES(11141,26639,-5,'Strange Creek, West Virginia 26639',8156,9805);
INSERT INTO "django_geo_db_zipcode" VALUES(11142,26641,-5,'Wilsie, West Virginia 26641',8157,9806);
INSERT INTO "django_geo_db_zipcode" VALUES(11143,26651,-5,'Summersville, West Virginia 26651',8158,9807);
INSERT INTO "django_geo_db_zipcode" VALUES(11144,26656,-5,'Belva, West Virginia 26656',8159,9808);
INSERT INTO "django_geo_db_zipcode" VALUES(11145,26660,-5,'Calvin, West Virginia 26660',8160,9809);
INSERT INTO "django_geo_db_zipcode" VALUES(11146,26662,-5,'Canvas, West Virginia 26662',8161,9810);
INSERT INTO "django_geo_db_zipcode" VALUES(11147,26667,-5,'Drennen, West Virginia 26667',8162,9811);
INSERT INTO "django_geo_db_zipcode" VALUES(11148,26671,-5,'Gilboa, West Virginia 26671',8163,9812);
INSERT INTO "django_geo_db_zipcode" VALUES(11149,26674,-5,'Jodie, West Virginia 26674',8164,9813);
INSERT INTO "django_geo_db_zipcode" VALUES(11150,26675,-5,'Keslers Cross Lanes, West Virginia 26675',8165,9814);
INSERT INTO "django_geo_db_zipcode" VALUES(11151,26676,-5,'Leivasy, West Virginia 26676',8166,9815);
INSERT INTO "django_geo_db_zipcode" VALUES(11152,26678,-5,'Mount Lookout, West Virginia 26678',8167,9816);
INSERT INTO "django_geo_db_zipcode" VALUES(11153,26679,-5,'Mount Nebo, West Virginia 26679',8168,9817);
INSERT INTO "django_geo_db_zipcode" VALUES(11154,26680,-5,'Nallen, West Virginia 26680',8169,9818);
INSERT INTO "django_geo_db_zipcode" VALUES(11155,26681,-5,'Nettie, West Virginia 26681',8170,9819);
INSERT INTO "django_geo_db_zipcode" VALUES(11156,26684,-5,'Pool, West Virginia 26684',8171,9820);
INSERT INTO "django_geo_db_zipcode" VALUES(11157,26690,-5,'Swiss, West Virginia 26690',8172,9821);
INSERT INTO "django_geo_db_zipcode" VALUES(11158,26691,-5,'Tioga, West Virginia 26691',8173,9822);
INSERT INTO "django_geo_db_zipcode" VALUES(11159,26704,-5,'Augusta, West Virginia 26704',8174,9823);
INSERT INTO "django_geo_db_zipcode" VALUES(11160,26705,-5,'Aurora, West Virginia 26705',8175,9824);
INSERT INTO "django_geo_db_zipcode" VALUES(11161,26707,-5,'Bayard, West Virginia 26707',8176,9825);
INSERT INTO "django_geo_db_zipcode" VALUES(11162,26710,-5,'Burlington, West Virginia 26710',8177,9826);
INSERT INTO "django_geo_db_zipcode" VALUES(11163,26711,-5,'Capon Bridge, West Virginia 26711',8178,9827);
INSERT INTO "django_geo_db_zipcode" VALUES(11164,26714,-5,'Delray, West Virginia 26714',8179,9828);
INSERT INTO "django_geo_db_zipcode" VALUES(11165,26716,-5,'Eglon, West Virginia 26716',8180,9829);
INSERT INTO "django_geo_db_zipcode" VALUES(11166,26717,-5,'Elk Garden, West Virginia 26717',8181,9830);
INSERT INTO "django_geo_db_zipcode" VALUES(11167,26719,-5,'Fort Ashby, West Virginia 26719',8182,9831);
INSERT INTO "django_geo_db_zipcode" VALUES(11168,26720,-5,'Gormania, West Virginia 26720',8183,9832);
INSERT INTO "django_geo_db_zipcode" VALUES(11169,26722,-5,'Green Spring, West Virginia 26722',8184,9833);
INSERT INTO "django_geo_db_zipcode" VALUES(11170,26726,-5,'Keyser, West Virginia 26726',8185,9834);
INSERT INTO "django_geo_db_zipcode" VALUES(11171,26731,-5,'Lahmansville, West Virginia 26731',8186,9835);
INSERT INTO "django_geo_db_zipcode" VALUES(11172,26734,-5,'Medley, West Virginia 26734',8187,9836);
INSERT INTO "django_geo_db_zipcode" VALUES(11173,26739,-5,'Mount Storm, West Virginia 26739',8188,9837);
INSERT INTO "django_geo_db_zipcode" VALUES(11174,26743,-5,'New Creek, West Virginia 26743',8189,9838);
INSERT INTO "django_geo_db_zipcode" VALUES(11175,26750,-5,'Piedmont, West Virginia 26750',8190,9839);
INSERT INTO "django_geo_db_zipcode" VALUES(11176,26753,-5,'Ridgeley, West Virginia 26753',8191,9840);
INSERT INTO "django_geo_db_zipcode" VALUES(11177,26755,-5,'Rio, West Virginia 26755',8192,9841);
INSERT INTO "django_geo_db_zipcode" VALUES(11178,26757,-5,'Romney, West Virginia 26757',8193,9842);
INSERT INTO "django_geo_db_zipcode" VALUES(11179,26761,-5,'Shanks, West Virginia 26761',8194,9843);
INSERT INTO "django_geo_db_zipcode" VALUES(11180,26763,-5,'Springfield, West Virginia 26763',8195,9844);
INSERT INTO "django_geo_db_zipcode" VALUES(11181,26764,-5,'Terra Alta, West Virginia 26764',8196,9845);
INSERT INTO "django_geo_db_zipcode" VALUES(11182,26767,-5,'Wiley Ford, West Virginia 26767',8197,9846);
INSERT INTO "django_geo_db_zipcode" VALUES(11183,26801,-5,'Baker, West Virginia 26801',8198,9847);
INSERT INTO "django_geo_db_zipcode" VALUES(11184,26802,-5,'Brandywine, West Virginia 26802',8199,9848);
INSERT INTO "django_geo_db_zipcode" VALUES(11185,26804,-5,'Circleville, West Virginia 26804',8200,9849);
INSERT INTO "django_geo_db_zipcode" VALUES(11186,26807,-5,'Franklin, West Virginia 26807',8201,9850);
INSERT INTO "django_geo_db_zipcode" VALUES(11187,26808,-5,'High View, West Virginia 26808',8202,9851);
INSERT INTO "django_geo_db_zipcode" VALUES(11188,26810,-5,'Lost City, West Virginia 26810',8203,9852);
INSERT INTO "django_geo_db_zipcode" VALUES(11189,26812,-5,'Mathias, West Virginia 26812',8204,9853);
INSERT INTO "django_geo_db_zipcode" VALUES(11190,26814,-5,'Riverton, West Virginia 26814',8205,9854);
INSERT INTO "django_geo_db_zipcode" VALUES(11191,26815,-5,'Sugar Grove, West Virginia 26815',8206,9855);
INSERT INTO "django_geo_db_zipcode" VALUES(11192,26817,-5,'Bloomery, West Virginia 26817',8207,9856);
INSERT INTO "django_geo_db_zipcode" VALUES(11193,26818,-5,'Fisher, West Virginia 26818',8208,9857);
INSERT INTO "django_geo_db_zipcode" VALUES(11194,26823,-5,'Capon Springs, West Virginia 26823',8209,9858);
INSERT INTO "django_geo_db_zipcode" VALUES(11195,26824,-5,'Junction, West Virginia 26824',8210,9859);
INSERT INTO "django_geo_db_zipcode" VALUES(11196,26833,-5,'Maysville, West Virginia 26833',8211,9860);
INSERT INTO "django_geo_db_zipcode" VALUES(11197,26836,-5,'Moorefield, West Virginia 26836',8212,9861);
INSERT INTO "django_geo_db_zipcode" VALUES(11198,26838,-5,'Milam, West Virginia 26838',8213,9862);
INSERT INTO "django_geo_db_zipcode" VALUES(11199,26845,-5,'Old Fields, West Virginia 26845',8214,9863);
INSERT INTO "django_geo_db_zipcode" VALUES(11200,26847,-5,'Petersburg, West Virginia 26847',8215,9864);
INSERT INTO "django_geo_db_zipcode" VALUES(11201,26851,-5,'Wardensville, West Virginia 26851',8216,9865);
INSERT INTO "django_geo_db_zipcode" VALUES(11202,26852,-5,'Purgitsville, West Virginia 26852',8217,9866);
INSERT INTO "django_geo_db_zipcode" VALUES(11203,26855,-5,'Cabins, West Virginia 26855',8218,9867);
INSERT INTO "django_geo_db_zipcode" VALUES(11204,26865,-5,'Yellow Spring, West Virginia 26865',8219,9868);
INSERT INTO "django_geo_db_zipcode" VALUES(11205,26866,-5,'Upper Tract, West Virginia 26866',8220,9869);
INSERT INTO "django_geo_db_zipcode" VALUES(11206,26884,-5,'Seneca Rocks, West Virginia 26884',8221,9870);
INSERT INTO "django_geo_db_zipcode" VALUES(11207,26886,-5,'Onego, West Virginia 26886',8222,9871);
INSERT INTO "django_geo_db_zipcode" VALUES(11208,26905,-5,'Morgantown, West Virginia 26905',8095,9872);
INSERT INTO "django_geo_db_zipcode" VALUES(11209,27006,-5,'Advance, North Carolina 27006',8223,9873);
INSERT INTO "django_geo_db_zipcode" VALUES(11210,27007,-5,'Ararat, North Carolina 27007',8224,9874);
INSERT INTO "django_geo_db_zipcode" VALUES(11211,27009,-5,'Belews Creek, North Carolina 27009',8225,9875);
INSERT INTO "django_geo_db_zipcode" VALUES(11212,27010,-5,'Bethania, North Carolina 27010',8226,9876);
INSERT INTO "django_geo_db_zipcode" VALUES(11213,27011,-5,'Boonville, North Carolina 27011',8227,9877);
INSERT INTO "django_geo_db_zipcode" VALUES(11214,27012,-5,'Clemmons, North Carolina 27012',8228,9878);
INSERT INTO "django_geo_db_zipcode" VALUES(11215,27013,-5,'Cleveland, North Carolina 27013',8229,9879);
INSERT INTO "django_geo_db_zipcode" VALUES(11216,27014,-5,'Cooleemee, North Carolina 27014',8230,9880);
INSERT INTO "django_geo_db_zipcode" VALUES(11217,27016,-5,'Danbury, North Carolina 27016',8231,9881);
INSERT INTO "django_geo_db_zipcode" VALUES(11218,27017,-5,'Dobson, North Carolina 27017',8232,9882);
INSERT INTO "django_geo_db_zipcode" VALUES(11219,27018,-5,'East Bend, North Carolina 27018',8233,9883);
INSERT INTO "django_geo_db_zipcode" VALUES(11220,27019,-5,'Germanton, North Carolina 27019',8234,9884);
INSERT INTO "django_geo_db_zipcode" VALUES(11221,27020,-5,'Hamptonville, North Carolina 27020',8235,9885);
INSERT INTO "django_geo_db_zipcode" VALUES(11222,27021,-5,'King, North Carolina 27021',8236,9886);
INSERT INTO "django_geo_db_zipcode" VALUES(11223,27022,-5,'Lawsonville, North Carolina 27022',8237,9887);
INSERT INTO "django_geo_db_zipcode" VALUES(11224,27023,-5,'Lewisville, North Carolina 27023',8238,9888);
INSERT INTO "django_geo_db_zipcode" VALUES(11225,27024,-5,'Lowgap, North Carolina 27024',8239,9889);
INSERT INTO "django_geo_db_zipcode" VALUES(11226,27025,-5,'Madison, North Carolina 27025',8240,9890);
INSERT INTO "django_geo_db_zipcode" VALUES(11227,27027,-5,'Mayodan, North Carolina 27027',8241,9891);
INSERT INTO "django_geo_db_zipcode" VALUES(11228,27028,-5,'Mocksville, North Carolina 27028',8242,9892);
INSERT INTO "django_geo_db_zipcode" VALUES(11229,27030,-5,'Mount Airy, North Carolina 27030',8243,9893);
INSERT INTO "django_geo_db_zipcode" VALUES(11230,27031,-5,'White Plains, North Carolina 27031',8244,9894);
INSERT INTO "django_geo_db_zipcode" VALUES(11231,27040,-5,'Pfafftown, North Carolina 27040',8245,9895);
INSERT INTO "django_geo_db_zipcode" VALUES(11232,27041,-5,'Pilot Mountain, North Carolina 27041',8246,9896);
INSERT INTO "django_geo_db_zipcode" VALUES(11233,27042,-5,'Pine Hall, North Carolina 27042',8247,9897);
INSERT INTO "django_geo_db_zipcode" VALUES(11234,27043,-5,'Pinnacle, North Carolina 27043',8248,9898);
INSERT INTO "django_geo_db_zipcode" VALUES(11235,27045,-5,'Rural Hall, North Carolina 27045',8249,9899);
INSERT INTO "django_geo_db_zipcode" VALUES(11236,27046,-5,'Sandy Ridge, North Carolina 27046',8250,9900);
INSERT INTO "django_geo_db_zipcode" VALUES(11237,27047,-5,'Siloam, North Carolina 27047',8251,9901);
INSERT INTO "django_geo_db_zipcode" VALUES(11238,27048,-5,'Stoneville, North Carolina 27048',8252,9902);
INSERT INTO "django_geo_db_zipcode" VALUES(11239,27049,-5,'Toast, North Carolina 27049',8253,9903);
INSERT INTO "django_geo_db_zipcode" VALUES(11240,27050,-5,'Tobaccoville, North Carolina 27050',8254,9904);
INSERT INTO "django_geo_db_zipcode" VALUES(11241,27051,-5,'Walkertown, North Carolina 27051',8255,9905);
INSERT INTO "django_geo_db_zipcode" VALUES(11242,27052,-5,'Walnut Cove, North Carolina 27052',8256,9906);
INSERT INTO "django_geo_db_zipcode" VALUES(11243,27053,-5,'Westfield, North Carolina 27053',8257,9907);
INSERT INTO "django_geo_db_zipcode" VALUES(11244,27054,-5,'Woodleaf, North Carolina 27054',8258,9908);
INSERT INTO "django_geo_db_zipcode" VALUES(11245,27055,-5,'Yadkinville, North Carolina 27055',8259,9909);
INSERT INTO "django_geo_db_zipcode" VALUES(11246,27094,-5,'Rural Hall, North Carolina 27094',8249,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11247,27098,-5,'Rural Hall, North Carolina 27098',8249,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11248,27099,-5,'Rural Hall, North Carolina 27099',8249,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11249,27101,-5,'Winston Salem, North Carolina 27101',8260,9911);
INSERT INTO "django_geo_db_zipcode" VALUES(11250,27102,-5,'Winston Salem, North Carolina 27102',8260,9912);
INSERT INTO "django_geo_db_zipcode" VALUES(11251,27103,-5,'Winston Salem, North Carolina 27103',8260,9913);
INSERT INTO "django_geo_db_zipcode" VALUES(11252,27104,-5,'Winston Salem, North Carolina 27104',8260,9914);
INSERT INTO "django_geo_db_zipcode" VALUES(11253,27105,-5,'Winston Salem, North Carolina 27105',8260,9915);
INSERT INTO "django_geo_db_zipcode" VALUES(11254,27106,-5,'Winston Salem, North Carolina 27106',8260,9916);
INSERT INTO "django_geo_db_zipcode" VALUES(11255,27107,-5,'Winston Salem, North Carolina 27107',8260,9917);
INSERT INTO "django_geo_db_zipcode" VALUES(11256,27108,-5,'Winston Salem, North Carolina 27108',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11257,27109,-5,'Winston Salem, North Carolina 27109',8260,9918);
INSERT INTO "django_geo_db_zipcode" VALUES(11258,27110,-5,'Winston Salem, North Carolina 27110',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11259,27111,-5,'Winston Salem, North Carolina 27111',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11260,27113,-5,'Winston Salem, North Carolina 27113',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11261,27114,-5,'Winston Salem, North Carolina 27114',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11262,27115,-5,'Winston Salem, North Carolina 27115',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11263,27116,-5,'Winston Salem, North Carolina 27116',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11264,27117,-5,'Winston Salem, North Carolina 27117',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11265,27120,-5,'Winston Salem, North Carolina 27120',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11266,27127,-5,'Winston Salem, North Carolina 27127',8260,9919);
INSERT INTO "django_geo_db_zipcode" VALUES(11267,27130,-5,'Winston Salem, North Carolina 27130',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11268,27144,-5,'Salisbury, North Carolina 27144',8261,9920);
INSERT INTO "django_geo_db_zipcode" VALUES(11269,27150,-5,'Winston Salem, North Carolina 27150',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11270,27151,-5,'Winston Salem, North Carolina 27151',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11271,27152,-5,'Winston Salem, North Carolina 27152',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11272,27155,-5,'Winston Salem, North Carolina 27155',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11273,27156,-5,'Winston Salem, North Carolina 27156',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11274,27157,-5,'Winston Salem, North Carolina 27157',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11275,27198,-5,'Winston Salem, North Carolina 27198',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11276,27199,-5,'Winston Salem, North Carolina 27199',8260,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11277,27201,-5,'Alamance, North Carolina 27201',8262,9921);
INSERT INTO "django_geo_db_zipcode" VALUES(11278,27202,-5,'Altamahaw, North Carolina 27202',8263,9922);
INSERT INTO "django_geo_db_zipcode" VALUES(11279,27203,-5,'Asheboro, North Carolina 27203',8264,9923);
INSERT INTO "django_geo_db_zipcode" VALUES(11280,27204,-5,'Asheboro, North Carolina 27204',8264,9924);
INSERT INTO "django_geo_db_zipcode" VALUES(11281,27205,-5,'Asheboro, North Carolina 27205',8264,9925);
INSERT INTO "django_geo_db_zipcode" VALUES(11282,27207,-5,'Bear Creek, North Carolina 27207',8265,9926);
INSERT INTO "django_geo_db_zipcode" VALUES(11283,27208,-5,'Bennett, North Carolina 27208',8266,9927);
INSERT INTO "django_geo_db_zipcode" VALUES(11284,27209,-5,'Biscoe, North Carolina 27209',8267,9928);
INSERT INTO "django_geo_db_zipcode" VALUES(11285,27212,-5,'Blanch, North Carolina 27212',8268,9929);
INSERT INTO "django_geo_db_zipcode" VALUES(11286,27213,-5,'Bonlee, North Carolina 27213',8269,9930);
INSERT INTO "django_geo_db_zipcode" VALUES(11287,27214,-5,'Browns Summit, North Carolina 27214',8270,9931);
INSERT INTO "django_geo_db_zipcode" VALUES(11288,27215,-5,'Burlington, North Carolina 27215',8271,9932);
INSERT INTO "django_geo_db_zipcode" VALUES(11289,27216,-5,'Burlington, North Carolina 27216',8271,9933);
INSERT INTO "django_geo_db_zipcode" VALUES(11290,27217,-5,'Burlington, North Carolina 27217',8271,9934);
INSERT INTO "django_geo_db_zipcode" VALUES(11291,27220,-5,'Burlington, North Carolina 27220',8271,9935);
INSERT INTO "django_geo_db_zipcode" VALUES(11292,27228,-5,'Bynum, North Carolina 27228',8272,9936);
INSERT INTO "django_geo_db_zipcode" VALUES(11293,27229,-5,'Candor, North Carolina 27229',8273,9937);
INSERT INTO "django_geo_db_zipcode" VALUES(11294,27230,-5,'Cedar Falls, North Carolina 27230',8274,9938);
INSERT INTO "django_geo_db_zipcode" VALUES(11295,27231,-5,'Cedar Grove, North Carolina 27231',8275,9939);
INSERT INTO "django_geo_db_zipcode" VALUES(11296,27233,-5,'Climax, North Carolina 27233',8276,9940);
INSERT INTO "django_geo_db_zipcode" VALUES(11297,27235,-5,'Colfax, North Carolina 27235',8277,9941);
INSERT INTO "django_geo_db_zipcode" VALUES(11298,27237,-5,'Cumnock, North Carolina 27237',8278,9942);
INSERT INTO "django_geo_db_zipcode" VALUES(11299,27239,-5,'Denton, North Carolina 27239',8279,9943);
INSERT INTO "django_geo_db_zipcode" VALUES(11300,27242,-5,'Eagle Springs, North Carolina 27242',8280,9944);
INSERT INTO "django_geo_db_zipcode" VALUES(11301,27243,-5,'Efland, North Carolina 27243',8281,9945);
INSERT INTO "django_geo_db_zipcode" VALUES(11302,27244,-5,'Elon College, North Carolina 27244',8282,9946);
INSERT INTO "django_geo_db_zipcode" VALUES(11303,27247,-5,'Ether, North Carolina 27247',8283,9947);
INSERT INTO "django_geo_db_zipcode" VALUES(11304,27248,-5,'Franklinville, North Carolina 27248',8284,9948);
INSERT INTO "django_geo_db_zipcode" VALUES(11305,27249,-5,'Gibsonville, North Carolina 27249',8285,9949);
INSERT INTO "django_geo_db_zipcode" VALUES(11306,27252,-5,'Goldston, North Carolina 27252',8286,9950);
INSERT INTO "django_geo_db_zipcode" VALUES(11307,27253,-5,'Graham, North Carolina 27253',8287,9951);
INSERT INTO "django_geo_db_zipcode" VALUES(11308,27256,-5,'Gulf, North Carolina 27256',8288,9952);
INSERT INTO "django_geo_db_zipcode" VALUES(11309,27258,-5,'Haw River, North Carolina 27258',8289,9953);
INSERT INTO "django_geo_db_zipcode" VALUES(11310,27259,-5,'Highfalls, North Carolina 27259',8290,9954);
INSERT INTO "django_geo_db_zipcode" VALUES(11311,27260,-5,'High Point, North Carolina 27260',8291,9955);
INSERT INTO "django_geo_db_zipcode" VALUES(11312,27261,-5,'High Point, North Carolina 27261',8291,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11313,27262,-5,'High Point, North Carolina 27262',8291,9957);
INSERT INTO "django_geo_db_zipcode" VALUES(11314,27263,-5,'High Point, North Carolina 27263',8291,9958);
INSERT INTO "django_geo_db_zipcode" VALUES(11315,27264,-5,'High Point, North Carolina 27264',8291,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11316,27265,-5,'High Point, North Carolina 27265',8291,9959);
INSERT INTO "django_geo_db_zipcode" VALUES(11317,27278,-5,'Hillsborough, North Carolina 27278',8292,9960);
INSERT INTO "django_geo_db_zipcode" VALUES(11318,27281,-5,'Jackson Springs, North Carolina 27281',8293,9961);
INSERT INTO "django_geo_db_zipcode" VALUES(11319,27282,-5,'Jamestown, North Carolina 27282',8294,9962);
INSERT INTO "django_geo_db_zipcode" VALUES(11320,27283,-5,'Julian, North Carolina 27283',8295,9963);
INSERT INTO "django_geo_db_zipcode" VALUES(11321,27284,-5,'Kernersville, North Carolina 27284',8296,9964);
INSERT INTO "django_geo_db_zipcode" VALUES(11322,27285,-5,'Kernersville, North Carolina 27285',8296,9910);
INSERT INTO "django_geo_db_zipcode" VALUES(11323,27288,-5,'Eden, North Carolina 27288',8297,9965);
INSERT INTO "django_geo_db_zipcode" VALUES(11324,27289,-5,'Eden, North Carolina 27289',8297,9966);
INSERT INTO "django_geo_db_zipcode" VALUES(11325,27291,-5,'Leasburg, North Carolina 27291',8298,9967);
INSERT INTO "django_geo_db_zipcode" VALUES(11326,27292,-5,'Lexington, North Carolina 27292',8299,9968);
INSERT INTO "django_geo_db_zipcode" VALUES(11327,27293,-5,'Lexington, North Carolina 27293',8299,9969);
INSERT INTO "django_geo_db_zipcode" VALUES(11328,27294,-5,'Lexington, North Carolina 27294',8299,9969);
INSERT INTO "django_geo_db_zipcode" VALUES(11329,27295,-5,'Lexington, North Carolina 27295',8299,9970);
INSERT INTO "django_geo_db_zipcode" VALUES(11330,27298,-5,'Liberty, North Carolina 27298',8300,9971);
INSERT INTO "django_geo_db_zipcode" VALUES(11331,27299,-5,'Linwood, North Carolina 27299',8301,9972);
INSERT INTO "django_geo_db_zipcode" VALUES(11332,27301,-5,'McLeansville, North Carolina 27301',8302,9973);
INSERT INTO "django_geo_db_zipcode" VALUES(11333,27302,-5,'Mebane, North Carolina 27302',8303,9974);
INSERT INTO "django_geo_db_zipcode" VALUES(11334,27305,-5,'Milton, North Carolina 27305',8304,9975);
INSERT INTO "django_geo_db_zipcode" VALUES(11335,27306,-5,'Mount Gilead, North Carolina 27306',8305,9976);
INSERT INTO "django_geo_db_zipcode" VALUES(11336,27310,-5,'Oak Ridge, North Carolina 27310',8306,9977);
INSERT INTO "django_geo_db_zipcode" VALUES(11337,27311,-5,'Pelham, North Carolina 27311',8307,9978);
INSERT INTO "django_geo_db_zipcode" VALUES(11338,27312,-5,'Pittsboro, North Carolina 27312',8308,9979);
INSERT INTO "django_geo_db_zipcode" VALUES(11339,27313,-5,'Pleasant Garden, North Carolina 27313',8309,9980);
INSERT INTO "django_geo_db_zipcode" VALUES(11340,27314,-5,'Prospect Hill, North Carolina 27314',8310,9981);
INSERT INTO "django_geo_db_zipcode" VALUES(11341,27315,-5,'Providence, North Carolina 27315',8311,9982);
INSERT INTO "django_geo_db_zipcode" VALUES(11342,27316,-5,'Ramseur, North Carolina 27316',8312,9983);
INSERT INTO "django_geo_db_zipcode" VALUES(11343,27317,-5,'Randleman, North Carolina 27317',8313,9984);
INSERT INTO "django_geo_db_zipcode" VALUES(11344,27320,-5,'Reidsville, North Carolina 27320',8314,9985);
INSERT INTO "django_geo_db_zipcode" VALUES(11345,27321,-5,'Reidsville, North Carolina 27321',8314,9986);
INSERT INTO "django_geo_db_zipcode" VALUES(11346,27322,-5,'Reidsville, North Carolina 27322',8314,9966);
INSERT INTO "django_geo_db_zipcode" VALUES(11347,27323,-5,'Reidsville, North Carolina 27323',8314,9966);
INSERT INTO "django_geo_db_zipcode" VALUES(11348,27325,-5,'Robbins, North Carolina 27325',8315,9987);
INSERT INTO "django_geo_db_zipcode" VALUES(11349,27326,-5,'Ruffin, North Carolina 27326',8316,9988);
INSERT INTO "django_geo_db_zipcode" VALUES(11350,27330,-5,'Sanford, North Carolina 27330',8317,9989);
INSERT INTO "django_geo_db_zipcode" VALUES(11351,27331,-5,'Sanford, North Carolina 27331',8317,9990);
INSERT INTO "django_geo_db_zipcode" VALUES(11352,27332,-5,'Sanford, North Carolina 27332',8317,9991);
INSERT INTO "django_geo_db_zipcode" VALUES(11353,27340,-5,'Saxapahaw, North Carolina 27340',8318,9992);
INSERT INTO "django_geo_db_zipcode" VALUES(11354,27341,-5,'Seagrove, North Carolina 27341',8319,9993);
INSERT INTO "django_geo_db_zipcode" VALUES(11355,27342,-5,'Sedalia, North Carolina 27342',8320,9994);
INSERT INTO "django_geo_db_zipcode" VALUES(11356,27343,-5,'Semora, North Carolina 27343',8321,9995);
INSERT INTO "django_geo_db_zipcode" VALUES(11357,27344,-5,'Siler City, North Carolina 27344',8322,9996);
INSERT INTO "django_geo_db_zipcode" VALUES(11358,27349,-5,'Snow Camp, North Carolina 27349',8323,9997);
INSERT INTO "django_geo_db_zipcode" VALUES(11359,27350,-5,'Sophia, North Carolina 27350',8324,9998);
INSERT INTO "django_geo_db_zipcode" VALUES(11360,27351,-5,'Southmont, North Carolina 27351',8325,9999);
INSERT INTO "django_geo_db_zipcode" VALUES(11361,27355,-5,'Staley, North Carolina 27355',8326,10000);
INSERT INTO "django_geo_db_zipcode" VALUES(11362,27356,-5,'Star, North Carolina 27356',8327,10001);
INSERT INTO "django_geo_db_zipcode" VALUES(11363,27357,-5,'Stokesdale, North Carolina 27357',8328,10002);
INSERT INTO "django_geo_db_zipcode" VALUES(11364,27358,-5,'Summerfield, North Carolina 27358',8329,10003);
INSERT INTO "django_geo_db_zipcode" VALUES(11365,27359,-5,'Swepsonville, North Carolina 27359',8330,10004);
INSERT INTO "django_geo_db_zipcode" VALUES(11366,27360,-5,'Thomasville, North Carolina 27360',8331,10005);
INSERT INTO "django_geo_db_zipcode" VALUES(11367,27361,-5,'Thomasville, North Carolina 27361',8331,9969);
INSERT INTO "django_geo_db_zipcode" VALUES(11368,27370,-5,'Trinity, North Carolina 27370',8332,10006);
INSERT INTO "django_geo_db_zipcode" VALUES(11369,27371,-5,'Troy, North Carolina 27371',8333,10007);
INSERT INTO "django_geo_db_zipcode" VALUES(11370,27373,-5,'Wallburg, North Carolina 27373',8334,9969);
INSERT INTO "django_geo_db_zipcode" VALUES(11371,27374,-5,'Welcome, North Carolina 27374',8335,10008);
INSERT INTO "django_geo_db_zipcode" VALUES(11372,27375,-5,'Wentworth, North Carolina 27375',8336,9966);
INSERT INTO "django_geo_db_zipcode" VALUES(11373,27376,-5,'West End, North Carolina 27376',8337,10009);
INSERT INTO "django_geo_db_zipcode" VALUES(11374,27377,-5,'Whitsett, North Carolina 27377',8338,10010);
INSERT INTO "django_geo_db_zipcode" VALUES(11375,27379,-5,'Yanceyville, North Carolina 27379',8339,10011);
INSERT INTO "django_geo_db_zipcode" VALUES(11376,27391,-5,'Troy, North Carolina 27391',8333,10012);
INSERT INTO "django_geo_db_zipcode" VALUES(11377,27397,-5,'Yanceyville, North Carolina 27397',8339,10013);
INSERT INTO "django_geo_db_zipcode" VALUES(11378,27401,-5,'Greensboro, North Carolina 27401',8340,10014);
INSERT INTO "django_geo_db_zipcode" VALUES(11379,27402,-5,'Greensboro, North Carolina 27402',8340,10015);
INSERT INTO "django_geo_db_zipcode" VALUES(11380,27403,-5,'Greensboro, North Carolina 27403',8340,10016);
INSERT INTO "django_geo_db_zipcode" VALUES(11381,27404,-5,'Greensboro, North Carolina 27404',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11382,27405,-5,'Greensboro, North Carolina 27405',8340,10017);
INSERT INTO "django_geo_db_zipcode" VALUES(11383,27406,-5,'Greensboro, North Carolina 27406',8340,10018);
INSERT INTO "django_geo_db_zipcode" VALUES(11384,27407,-5,'Greensboro, North Carolina 27407',8340,10019);
INSERT INTO "django_geo_db_zipcode" VALUES(11385,27408,-5,'Greensboro, North Carolina 27408',8340,10020);
INSERT INTO "django_geo_db_zipcode" VALUES(11386,27409,-5,'Greensboro, North Carolina 27409',8340,10021);
INSERT INTO "django_geo_db_zipcode" VALUES(11387,27410,-5,'Greensboro, North Carolina 27410',8340,10022);
INSERT INTO "django_geo_db_zipcode" VALUES(11388,27411,-5,'Greensboro, North Carolina 27411',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11389,27412,-5,'Greensboro, North Carolina 27412',8340,10023);
INSERT INTO "django_geo_db_zipcode" VALUES(11390,27413,-5,'Greensboro, North Carolina 27413',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11391,27415,-5,'Greensboro, North Carolina 27415',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11392,27416,-5,'Greensboro, North Carolina 27416',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11393,27417,-5,'Greensboro, North Carolina 27417',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11394,27419,-5,'Greensboro, North Carolina 27419',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11395,27420,-5,'Greensboro, North Carolina 27420',8340,10024);
INSERT INTO "django_geo_db_zipcode" VALUES(11396,27425,-5,'Greensboro, North Carolina 27425',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11397,27427,-5,'Greensboro, North Carolina 27427',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11398,27429,-5,'Greensboro, North Carolina 27429',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11399,27435,-5,'Greensboro, North Carolina 27435',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11400,27438,-5,'Greensboro, North Carolina 27438',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11401,27455,-5,'Greensboro, North Carolina 27455',8340,10025);
INSERT INTO "django_geo_db_zipcode" VALUES(11402,27480,-5,'Greensboro, North Carolina 27480',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11403,27495,-5,'Greensboro, North Carolina 27495',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11404,27498,-5,'Greensboro, North Carolina 27498',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11405,27499,-5,'Greensboro, North Carolina 27499',8340,9956);
INSERT INTO "django_geo_db_zipcode" VALUES(11406,27501,-5,'Angier, North Carolina 27501',8341,10026);
INSERT INTO "django_geo_db_zipcode" VALUES(11407,27502,-5,'Apex, North Carolina 27502',8342,10027);
INSERT INTO "django_geo_db_zipcode" VALUES(11408,27503,-5,'Bahama, North Carolina 27503',8343,10028);
INSERT INTO "django_geo_db_zipcode" VALUES(11409,27504,-5,'Benson, North Carolina 27504',8344,10029);
INSERT INTO "django_geo_db_zipcode" VALUES(11410,27505,-5,'Broadway, North Carolina 27505',8345,10030);
INSERT INTO "django_geo_db_zipcode" VALUES(11411,27506,-5,'Buies Creek, North Carolina 27506',8346,10031);
INSERT INTO "django_geo_db_zipcode" VALUES(11412,27507,-5,'Bullock, North Carolina 27507',8347,10032);
INSERT INTO "django_geo_db_zipcode" VALUES(11413,27508,-5,'Bunn, North Carolina 27508',8348,10033);
INSERT INTO "django_geo_db_zipcode" VALUES(11414,27509,-5,'Butner, North Carolina 27509',8349,10034);
INSERT INTO "django_geo_db_zipcode" VALUES(11415,27510,-5,'Carrboro, North Carolina 27510',8350,10035);
INSERT INTO "django_geo_db_zipcode" VALUES(11416,27511,-5,'Cary, North Carolina 27511',8351,10036);
INSERT INTO "django_geo_db_zipcode" VALUES(11417,27512,-5,'Cary, North Carolina 27512',8351,10037);
INSERT INTO "django_geo_db_zipcode" VALUES(11418,27513,-5,'Cary, North Carolina 27513',8351,10038);
INSERT INTO "django_geo_db_zipcode" VALUES(11419,27514,-5,'Chapel Hill, North Carolina 27514',8352,10039);
INSERT INTO "django_geo_db_zipcode" VALUES(11420,27515,-5,'Chapel Hill, North Carolina 27515',8352,10040);
INSERT INTO "django_geo_db_zipcode" VALUES(11421,27516,-5,'Chapel Hill, North Carolina 27516',8352,10041);
INSERT INTO "django_geo_db_zipcode" VALUES(11422,27517,-5,'Chapel Hill, North Carolina 27517',8352,10042);
INSERT INTO "django_geo_db_zipcode" VALUES(11423,27518,-5,'Cary, North Carolina 27518',8351,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11424,27519,-5,'Cary, North Carolina 27519',8351,10044);
INSERT INTO "django_geo_db_zipcode" VALUES(11425,27520,-5,'Clayton, North Carolina 27520',8353,10045);
INSERT INTO "django_geo_db_zipcode" VALUES(11426,27521,-5,'Coats, North Carolina 27521',8354,10046);
INSERT INTO "django_geo_db_zipcode" VALUES(11427,27522,-5,'Creedmoor, North Carolina 27522',8355,10047);
INSERT INTO "django_geo_db_zipcode" VALUES(11428,27523,-5,'Eagle Rock, North Carolina 27523',8356,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11429,27524,-5,'Four Oaks, North Carolina 27524',8357,10048);
INSERT INTO "django_geo_db_zipcode" VALUES(11430,27525,-5,'Franklinton, North Carolina 27525',8358,10049);
INSERT INTO "django_geo_db_zipcode" VALUES(11431,27526,-5,'Fuquay Varina, North Carolina 27526',8359,10050);
INSERT INTO "django_geo_db_zipcode" VALUES(11432,27529,-5,'Garner, North Carolina 27529',8360,10051);
INSERT INTO "django_geo_db_zipcode" VALUES(11433,27530,-5,'Goldsboro, North Carolina 27530',8361,10052);
INSERT INTO "django_geo_db_zipcode" VALUES(11434,27531,-5,'Goldsboro, North Carolina 27531',8361,10053);
INSERT INTO "django_geo_db_zipcode" VALUES(11435,27532,-5,'Goldsboro, North Carolina 27532',8361,10054);
INSERT INTO "django_geo_db_zipcode" VALUES(11436,27533,-5,'Goldsboro, North Carolina 27533',8361,10054);
INSERT INTO "django_geo_db_zipcode" VALUES(11437,27534,-5,'Goldsboro, North Carolina 27534',8361,10055);
INSERT INTO "django_geo_db_zipcode" VALUES(11438,27536,-5,'Henderson, North Carolina 27536',8362,10056);
INSERT INTO "django_geo_db_zipcode" VALUES(11439,27537,-5,'Henderson, North Carolina 27537',8362,10057);
INSERT INTO "django_geo_db_zipcode" VALUES(11440,27539,-5,'Apex, North Carolina 27539',8342,10058);
INSERT INTO "django_geo_db_zipcode" VALUES(11441,27540,-5,'Holly Springs, North Carolina 27540',8363,10059);
INSERT INTO "django_geo_db_zipcode" VALUES(11442,27541,-5,'Hurdle Mills, North Carolina 27541',8364,10060);
INSERT INTO "django_geo_db_zipcode" VALUES(11443,27542,-5,'Kenly, North Carolina 27542',8365,10061);
INSERT INTO "django_geo_db_zipcode" VALUES(11444,27543,-5,'Kipling, North Carolina 27543',8366,10062);
INSERT INTO "django_geo_db_zipcode" VALUES(11445,27544,-5,'Kittrell, North Carolina 27544',8367,10063);
INSERT INTO "django_geo_db_zipcode" VALUES(11446,27545,-5,'Knightdale, North Carolina 27545',8368,10064);
INSERT INTO "django_geo_db_zipcode" VALUES(11447,27546,-5,'Lillington, North Carolina 27546',8369,10065);
INSERT INTO "django_geo_db_zipcode" VALUES(11448,27549,-5,'Louisburg, North Carolina 27549',8370,10066);
INSERT INTO "django_geo_db_zipcode" VALUES(11449,27551,-5,'Macon, North Carolina 27551',8371,10067);
INSERT INTO "django_geo_db_zipcode" VALUES(11450,27552,-5,'Mamers, North Carolina 27552',8372,10068);
INSERT INTO "django_geo_db_zipcode" VALUES(11451,27553,-5,'Manson, North Carolina 27553',8373,10069);
INSERT INTO "django_geo_db_zipcode" VALUES(11452,27555,-5,'Micro, North Carolina 27555',8374,10070);
INSERT INTO "django_geo_db_zipcode" VALUES(11453,27556,-5,'Middleburg, North Carolina 27556',8375,10071);
INSERT INTO "django_geo_db_zipcode" VALUES(11454,27557,-5,'Middlesex, North Carolina 27557',8376,10072);
INSERT INTO "django_geo_db_zipcode" VALUES(11455,27559,-5,'Moncure, North Carolina 27559',8377,10073);
INSERT INTO "django_geo_db_zipcode" VALUES(11456,27560,-5,'Morrisville, North Carolina 27560',8378,10074);
INSERT INTO "django_geo_db_zipcode" VALUES(11457,27561,-5,'Raleigh, North Carolina 27561',8379,10075);
INSERT INTO "django_geo_db_zipcode" VALUES(11458,27562,-5,'New Hill, North Carolina 27562',8380,10076);
INSERT INTO "django_geo_db_zipcode" VALUES(11459,27563,-5,'Norlina, North Carolina 27563',8381,10077);
INSERT INTO "django_geo_db_zipcode" VALUES(11460,27564,-5,'Creedmoor, North Carolina 27564',8355,10078);
INSERT INTO "django_geo_db_zipcode" VALUES(11461,27565,-5,'Oxford, North Carolina 27565',8382,10079);
INSERT INTO "django_geo_db_zipcode" VALUES(11462,27568,-5,'Pine Level, North Carolina 27568',8383,10080);
INSERT INTO "django_geo_db_zipcode" VALUES(11463,27569,-5,'Princeton, North Carolina 27569',8384,10081);
INSERT INTO "django_geo_db_zipcode" VALUES(11464,27570,-5,'Ridgeway, North Carolina 27570',8385,10082);
INSERT INTO "django_geo_db_zipcode" VALUES(11465,27571,-5,'Rolesville, North Carolina 27571',8386,10083);
INSERT INTO "django_geo_db_zipcode" VALUES(11466,27572,-5,'Rougemont, North Carolina 27572',8387,10084);
INSERT INTO "django_geo_db_zipcode" VALUES(11467,27573,-5,'Roxboro, North Carolina 27573',8388,10085);
INSERT INTO "django_geo_db_zipcode" VALUES(11468,27574,-5,'Roxboro, North Carolina 27574',8388,10086);
INSERT INTO "django_geo_db_zipcode" VALUES(11469,27576,-5,'Selma, North Carolina 27576',8389,10087);
INSERT INTO "django_geo_db_zipcode" VALUES(11470,27577,-5,'Smithfield, North Carolina 27577',8390,10088);
INSERT INTO "django_geo_db_zipcode" VALUES(11471,27581,-5,'Stem, North Carolina 27581',8391,10089);
INSERT INTO "django_geo_db_zipcode" VALUES(11472,27582,-5,'Stovall, North Carolina 27582',8392,10090);
INSERT INTO "django_geo_db_zipcode" VALUES(11473,27583,-5,'Timberlake, North Carolina 27583',8393,10091);
INSERT INTO "django_geo_db_zipcode" VALUES(11474,27584,-5,'Townsville, North Carolina 27584',8394,10092);
INSERT INTO "django_geo_db_zipcode" VALUES(11475,27586,-5,'Vaughan, North Carolina 27586',8395,10093);
INSERT INTO "django_geo_db_zipcode" VALUES(11476,27587,-5,'Wake Forest, North Carolina 27587',8396,10094);
INSERT INTO "django_geo_db_zipcode" VALUES(11477,27588,-5,'Wake Forest, North Carolina 27588',8396,10095);
INSERT INTO "django_geo_db_zipcode" VALUES(11478,27589,-5,'Warrenton, North Carolina 27589',8397,10096);
INSERT INTO "django_geo_db_zipcode" VALUES(11479,27591,-5,'Wendell, North Carolina 27591',8398,10097);
INSERT INTO "django_geo_db_zipcode" VALUES(11480,27592,-5,'Willow Spring, North Carolina 27592',8399,10098);
INSERT INTO "django_geo_db_zipcode" VALUES(11481,27593,-5,'Wilsons Mills, North Carolina 27593',8400,10099);
INSERT INTO "django_geo_db_zipcode" VALUES(11482,27594,-5,'Wise, North Carolina 27594',8401,10093);
INSERT INTO "django_geo_db_zipcode" VALUES(11483,27596,-5,'Youngsville, North Carolina 27596',8402,10100);
INSERT INTO "django_geo_db_zipcode" VALUES(11484,27597,-5,'Zebulon, North Carolina 27597',8403,10101);
INSERT INTO "django_geo_db_zipcode" VALUES(11485,27599,-5,'Chapel Hill, North Carolina 27599',8352,10040);
INSERT INTO "django_geo_db_zipcode" VALUES(11486,27601,-5,'Raleigh, North Carolina 27601',8379,10102);
INSERT INTO "django_geo_db_zipcode" VALUES(11487,27602,-5,'Raleigh, North Carolina 27602',8379,10103);
INSERT INTO "django_geo_db_zipcode" VALUES(11488,27603,-5,'Raleigh, North Carolina 27603',8379,10104);
INSERT INTO "django_geo_db_zipcode" VALUES(11489,27604,-5,'Raleigh, North Carolina 27604',8379,10105);
INSERT INTO "django_geo_db_zipcode" VALUES(11490,27605,-5,'Raleigh, North Carolina 27605',8379,10106);
INSERT INTO "django_geo_db_zipcode" VALUES(11491,27606,-5,'Raleigh, North Carolina 27606',8379,10107);
INSERT INTO "django_geo_db_zipcode" VALUES(11492,27607,-5,'Raleigh, North Carolina 27607',8379,10108);
INSERT INTO "django_geo_db_zipcode" VALUES(11493,27608,-5,'Raleigh, North Carolina 27608',8379,10109);
INSERT INTO "django_geo_db_zipcode" VALUES(11494,27609,-5,'Raleigh, North Carolina 27609',8379,10110);
INSERT INTO "django_geo_db_zipcode" VALUES(11495,27610,-5,'Raleigh, North Carolina 27610',8379,10111);
INSERT INTO "django_geo_db_zipcode" VALUES(11496,27611,-5,'Raleigh, North Carolina 27611',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11497,27612,-5,'Raleigh, North Carolina 27612',8379,10112);
INSERT INTO "django_geo_db_zipcode" VALUES(11498,27613,-5,'Raleigh, North Carolina 27613',8379,10113);
INSERT INTO "django_geo_db_zipcode" VALUES(11499,27614,-5,'Raleigh, North Carolina 27614',8379,10114);
INSERT INTO "django_geo_db_zipcode" VALUES(11500,27615,-5,'Raleigh, North Carolina 27615',8379,10115);
INSERT INTO "django_geo_db_zipcode" VALUES(11501,27616,-5,'Raleigh, North Carolina 27616',8379,10116);
INSERT INTO "django_geo_db_zipcode" VALUES(11502,27617,-5,'Raleigh, North Carolina 27617',8379,10117);
INSERT INTO "django_geo_db_zipcode" VALUES(11503,27619,-5,'Raleigh, North Carolina 27619',8379,10118);
INSERT INTO "django_geo_db_zipcode" VALUES(11504,27620,-5,'Raleigh, North Carolina 27620',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11505,27621,-5,'Raleigh, North Carolina 27621',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11506,27622,-5,'Raleigh, North Carolina 27622',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11507,27623,-5,'Raleigh, North Carolina 27623',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11508,27624,-5,'Raleigh, North Carolina 27624',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11509,27625,-5,'Raleigh, North Carolina 27625',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11510,27626,-5,'Raleigh, North Carolina 27626',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11511,27627,-5,'Raleigh, North Carolina 27627',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11512,27628,-5,'Raleigh, North Carolina 27628',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11513,27629,-5,'Raleigh, North Carolina 27629',8379,10119);
INSERT INTO "django_geo_db_zipcode" VALUES(11514,27630,-5,'Thomasville, North Carolina 27630',8331,10120);
INSERT INTO "django_geo_db_zipcode" VALUES(11515,27634,-5,'Raleigh, North Carolina 27634',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11516,27635,-5,'Raleigh, North Carolina 27635',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11517,27636,-5,'Raleigh, North Carolina 27636',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11518,27640,-5,'Raleigh, North Carolina 27640',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11519,27650,-5,'Raleigh, North Carolina 27650',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11520,27656,-5,'Raleigh, North Carolina 27656',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11521,27658,-5,'Raleigh, North Carolina 27658',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11522,27661,-5,'Raleigh, North Carolina 27661',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11523,27668,-5,'Raleigh, North Carolina 27668',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11524,27675,-5,'Raleigh, North Carolina 27675',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11525,27676,-5,'Raleigh, North Carolina 27676',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11526,27690,-5,'Raleigh, North Carolina 27690',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11527,27695,-5,'Raleigh, North Carolina 27695',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11528,27697,-5,'Raleigh, North Carolina 27697',8379,10121);
INSERT INTO "django_geo_db_zipcode" VALUES(11529,27698,-5,'Raleigh, North Carolina 27698',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11530,27699,-5,'Raleigh, North Carolina 27699',8379,10043);
INSERT INTO "django_geo_db_zipcode" VALUES(11531,27701,-5,'Durham, North Carolina 27701',8404,10122);
INSERT INTO "django_geo_db_zipcode" VALUES(11532,27702,-5,'Durham, North Carolina 27702',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11533,27703,-5,'Durham, North Carolina 27703',8404,10124);
INSERT INTO "django_geo_db_zipcode" VALUES(11534,27704,-5,'Durham, North Carolina 27704',8404,10125);
INSERT INTO "django_geo_db_zipcode" VALUES(11535,27705,-5,'Durham, North Carolina 27705',8404,10126);
INSERT INTO "django_geo_db_zipcode" VALUES(11536,27706,-5,'Durham, North Carolina 27706',8404,10127);
INSERT INTO "django_geo_db_zipcode" VALUES(11537,27707,-5,'Durham, North Carolina 27707',8404,10128);
INSERT INTO "django_geo_db_zipcode" VALUES(11538,27708,-5,'Durham, North Carolina 27708',8404,10129);
INSERT INTO "django_geo_db_zipcode" VALUES(11539,27709,-5,'Durham, North Carolina 27709',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11540,27710,-5,'Durham, North Carolina 27710',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11541,27711,-5,'Durham, North Carolina 27711',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11542,27712,-5,'Durham, North Carolina 27712',8404,10130);
INSERT INTO "django_geo_db_zipcode" VALUES(11543,27713,-5,'Durham, North Carolina 27713',8404,10131);
INSERT INTO "django_geo_db_zipcode" VALUES(11544,27715,-5,'Durham, North Carolina 27715',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11545,27717,-5,'Durham, North Carolina 27717',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11546,27722,-5,'Durham, North Carolina 27722',8404,10123);
INSERT INTO "django_geo_db_zipcode" VALUES(11547,27801,-5,'Rocky Mount, North Carolina 27801',8405,10132);
INSERT INTO "django_geo_db_zipcode" VALUES(11548,27802,-5,'Rocky Mount, North Carolina 27802',8405,10133);
INSERT INTO "django_geo_db_zipcode" VALUES(11549,27803,-5,'Rocky Mount, North Carolina 27803',8405,10134);
INSERT INTO "django_geo_db_zipcode" VALUES(11550,27804,-5,'Rocky Mount, North Carolina 27804',8405,10135);
INSERT INTO "django_geo_db_zipcode" VALUES(11551,27805,-5,'Aulander, North Carolina 27805',8406,10136);
INSERT INTO "django_geo_db_zipcode" VALUES(11552,27806,-5,'Aurora, North Carolina 27806',8407,10137);
INSERT INTO "django_geo_db_zipcode" VALUES(11553,27807,-5,'Bailey, North Carolina 27807',8408,10138);
INSERT INTO "django_geo_db_zipcode" VALUES(11554,27808,-5,'Bath, North Carolina 27808',8409,10139);
INSERT INTO "django_geo_db_zipcode" VALUES(11555,27809,-5,'Battleboro, North Carolina 27809',8410,10140);
INSERT INTO "django_geo_db_zipcode" VALUES(11556,27810,-5,'Belhaven, North Carolina 27810',8411,10141);
INSERT INTO "django_geo_db_zipcode" VALUES(11557,27811,-5,'Bellarthur, North Carolina 27811',8412,10142);
INSERT INTO "django_geo_db_zipcode" VALUES(11558,27812,-5,'Bethel, North Carolina 27812',8413,10143);
INSERT INTO "django_geo_db_zipcode" VALUES(11559,27813,-5,'Black Creek, North Carolina 27813',8414,10144);
INSERT INTO "django_geo_db_zipcode" VALUES(11560,27814,-5,'Blounts Creek, North Carolina 27814',8415,10145);
INSERT INTO "django_geo_db_zipcode" VALUES(11561,27816,-5,'Castalia, North Carolina 27816',8416,10146);
INSERT INTO "django_geo_db_zipcode" VALUES(11562,27817,-5,'Chocowinity, North Carolina 27817',8417,10147);
INSERT INTO "django_geo_db_zipcode" VALUES(11563,27818,-5,'Como, North Carolina 27818',8418,10148);
INSERT INTO "django_geo_db_zipcode" VALUES(11564,27819,-5,'Conetoe, North Carolina 27819',8419,10149);
INSERT INTO "django_geo_db_zipcode" VALUES(11565,27820,-5,'Conway, North Carolina 27820',8420,10150);
INSERT INTO "django_geo_db_zipcode" VALUES(11566,27821,-5,'Edward, North Carolina 27821',8421,10151);
INSERT INTO "django_geo_db_zipcode" VALUES(11567,27822,-5,'Elm City, North Carolina 27822',8422,10152);
INSERT INTO "django_geo_db_zipcode" VALUES(11568,27823,-5,'Enfield, North Carolina 27823',8423,10153);
INSERT INTO "django_geo_db_zipcode" VALUES(11569,27824,-5,'Engelhard, North Carolina 27824',8424,10154);
INSERT INTO "django_geo_db_zipcode" VALUES(11570,27825,-5,'Everetts, North Carolina 27825',8425,10155);
INSERT INTO "django_geo_db_zipcode" VALUES(11571,27826,-5,'Fairfield, North Carolina 27826',8426,10156);
INSERT INTO "django_geo_db_zipcode" VALUES(11572,27827,-5,'Falkland, North Carolina 27827',8427,10157);
INSERT INTO "django_geo_db_zipcode" VALUES(11573,27828,-5,'Farmville, North Carolina 27828',8428,10158);
INSERT INTO "django_geo_db_zipcode" VALUES(11574,27829,-5,'Fountain, North Carolina 27829',8429,10159);
INSERT INTO "django_geo_db_zipcode" VALUES(11575,27830,-5,'Fremont, North Carolina 27830',8430,10160);
INSERT INTO "django_geo_db_zipcode" VALUES(11576,27831,-5,'Garysburg, North Carolina 27831',8431,10161);
INSERT INTO "django_geo_db_zipcode" VALUES(11577,27832,-5,'Gaston, North Carolina 27832',8432,10162);
INSERT INTO "django_geo_db_zipcode" VALUES(11578,27833,-5,'Greenville, North Carolina 27833',8433,10163);
INSERT INTO "django_geo_db_zipcode" VALUES(11579,27834,-5,'Greenville, North Carolina 27834',8433,10164);
INSERT INTO "django_geo_db_zipcode" VALUES(11580,27835,-5,'Greenville, North Carolina 27835',8433,10165);
INSERT INTO "django_geo_db_zipcode" VALUES(11581,27836,-5,'Greenville, North Carolina 27836',8433,10163);
INSERT INTO "django_geo_db_zipcode" VALUES(11582,27837,-5,'Grimesland, North Carolina 27837',8434,10166);
INSERT INTO "django_geo_db_zipcode" VALUES(11583,27838,-5,'Gumberry, North Carolina 27838',8435,10167);
INSERT INTO "django_geo_db_zipcode" VALUES(11584,27839,-5,'Halifax, North Carolina 27839',8436,10168);
INSERT INTO "django_geo_db_zipcode" VALUES(11585,27840,-5,'Hamilton, North Carolina 27840',8437,10169);
INSERT INTO "django_geo_db_zipcode" VALUES(11586,27841,-5,'Hassell, North Carolina 27841',8438,10170);
INSERT INTO "django_geo_db_zipcode" VALUES(11587,27842,-5,'Henrico, North Carolina 27842',8439,10171);
INSERT INTO "django_geo_db_zipcode" VALUES(11588,27843,-5,'Hobgood, North Carolina 27843',8440,10172);
INSERT INTO "django_geo_db_zipcode" VALUES(11589,27844,-5,'Hollister, North Carolina 27844',8441,10173);
INSERT INTO "django_geo_db_zipcode" VALUES(11590,27845,-5,'Jackson, North Carolina 27845',8442,10174);
INSERT INTO "django_geo_db_zipcode" VALUES(11591,27846,-5,'Jamesville, North Carolina 27846',8443,10175);
INSERT INTO "django_geo_db_zipcode" VALUES(11592,27847,-5,'Kelford, North Carolina 27847',8444,10176);
INSERT INTO "django_geo_db_zipcode" VALUES(11593,27849,-5,'Lewiston Woodville, North Carolina 27849',8445,10177);
INSERT INTO "django_geo_db_zipcode" VALUES(11594,27850,-5,'Littleton, North Carolina 27850',8446,10178);
INSERT INTO "django_geo_db_zipcode" VALUES(11595,27851,-5,'Lucama, North Carolina 27851',8447,10179);
INSERT INTO "django_geo_db_zipcode" VALUES(11596,27852,-5,'Macclesfield, North Carolina 27852',8448,10180);
INSERT INTO "django_geo_db_zipcode" VALUES(11597,27853,-5,'Margarettsville, North Carolina 27853',8449,10181);
INSERT INTO "django_geo_db_zipcode" VALUES(11598,27854,-5,'Milwaukee, North Carolina 27854',8450,10182);
INSERT INTO "django_geo_db_zipcode" VALUES(11599,27855,-5,'Murfreesboro, North Carolina 27855',8451,10183);
INSERT INTO "django_geo_db_zipcode" VALUES(11600,27856,-5,'Nashville, North Carolina 27856',8452,10184);
INSERT INTO "django_geo_db_zipcode" VALUES(11601,27857,-5,'Oak City, North Carolina 27857',8453,10185);
INSERT INTO "django_geo_db_zipcode" VALUES(11602,27858,-5,'Greenville, North Carolina 27858',8433,10186);
INSERT INTO "django_geo_db_zipcode" VALUES(11603,27859,-5,'Palmyra, North Carolina 27859',8454,10187);
INSERT INTO "django_geo_db_zipcode" VALUES(11604,27860,-5,'Pantego, North Carolina 27860',8455,10188);
INSERT INTO "django_geo_db_zipcode" VALUES(11605,27861,-5,'Parmele, North Carolina 27861',8456,10189);
INSERT INTO "django_geo_db_zipcode" VALUES(11606,27862,-5,'Pendleton, North Carolina 27862',8457,10190);
INSERT INTO "django_geo_db_zipcode" VALUES(11607,27863,-5,'Pikeville, North Carolina 27863',8458,10191);
INSERT INTO "django_geo_db_zipcode" VALUES(11608,27864,-5,'Pinetops, North Carolina 27864',8459,10192);
INSERT INTO "django_geo_db_zipcode" VALUES(11609,27865,-5,'Pinetown, North Carolina 27865',8460,10193);
INSERT INTO "django_geo_db_zipcode" VALUES(11610,27866,-5,'Pleasant Hill, North Carolina 27866',8461,10194);
INSERT INTO "django_geo_db_zipcode" VALUES(11611,27867,-5,'Potecasi, North Carolina 27867',8462,10167);
INSERT INTO "django_geo_db_zipcode" VALUES(11612,27868,-5,'Red Oak, North Carolina 27868',8463,10195);
INSERT INTO "django_geo_db_zipcode" VALUES(11613,27869,-5,'Rich Square, North Carolina 27869',8464,10196);
INSERT INTO "django_geo_db_zipcode" VALUES(11614,27870,-5,'Roanoke Rapids, North Carolina 27870',8465,10197);
INSERT INTO "django_geo_db_zipcode" VALUES(11615,27871,-5,'Robersonville, North Carolina 27871',8466,10198);
INSERT INTO "django_geo_db_zipcode" VALUES(11616,27872,-5,'Roxobel, North Carolina 27872',8467,10199);
INSERT INTO "django_geo_db_zipcode" VALUES(11617,27873,-5,'Saratoga, North Carolina 27873',8468,10200);
INSERT INTO "django_geo_db_zipcode" VALUES(11618,27874,-5,'Scotland Neck, North Carolina 27874',8469,10201);
INSERT INTO "django_geo_db_zipcode" VALUES(11619,27875,-5,'Scranton, North Carolina 27875',8470,10202);
INSERT INTO "django_geo_db_zipcode" VALUES(11620,27876,-5,'Seaboard, North Carolina 27876',8471,10203);
INSERT INTO "django_geo_db_zipcode" VALUES(11621,27877,-5,'Severn, North Carolina 27877',8472,10204);
INSERT INTO "django_geo_db_zipcode" VALUES(11622,27878,-5,'Sharpsburg, North Carolina 27878',8473,10205);
INSERT INTO "django_geo_db_zipcode" VALUES(11623,27879,-5,'Simpson, North Carolina 27879',8474,10206);
INSERT INTO "django_geo_db_zipcode" VALUES(11624,27880,-5,'Sims, North Carolina 27880',8475,10207);
INSERT INTO "django_geo_db_zipcode" VALUES(11625,27881,-5,'Speed, North Carolina 27881',8476,10208);
INSERT INTO "django_geo_db_zipcode" VALUES(11626,27882,-5,'Spring Hope, North Carolina 27882',8477,10209);
INSERT INTO "django_geo_db_zipcode" VALUES(11627,27883,-5,'Stantonsburg, North Carolina 27883',8478,10210);
INSERT INTO "django_geo_db_zipcode" VALUES(11628,27884,-5,'Stokes, North Carolina 27884',8479,10211);
INSERT INTO "django_geo_db_zipcode" VALUES(11629,27885,-5,'Swanquarter, North Carolina 27885',8480,10212);
INSERT INTO "django_geo_db_zipcode" VALUES(11630,27886,-5,'Tarboro, North Carolina 27886',8481,10213);
INSERT INTO "django_geo_db_zipcode" VALUES(11631,27887,-5,'Tillery, North Carolina 27887',8482,10214);
INSERT INTO "django_geo_db_zipcode" VALUES(11632,27888,-5,'Walstonburg, North Carolina 27888',8483,10215);
INSERT INTO "django_geo_db_zipcode" VALUES(11633,27889,-5,'Washington, North Carolina 27889',8484,10216);
INSERT INTO "django_geo_db_zipcode" VALUES(11634,27890,-5,'Weldon, North Carolina 27890',8485,10217);
INSERT INTO "django_geo_db_zipcode" VALUES(11635,27891,-5,'Whitakers, North Carolina 27891',8486,10218);
INSERT INTO "django_geo_db_zipcode" VALUES(11636,27892,-5,'Williamston, North Carolina 27892',8487,10219);
INSERT INTO "django_geo_db_zipcode" VALUES(11637,27893,-5,'Wilson, North Carolina 27893',8488,10220);
INSERT INTO "django_geo_db_zipcode" VALUES(11638,27894,-5,'Wilson, North Carolina 27894',8488,10221);
INSERT INTO "django_geo_db_zipcode" VALUES(11639,27895,-5,'Wilson, North Carolina 27895',8488,10222);
INSERT INTO "django_geo_db_zipcode" VALUES(11640,27896,-5,'Wilson, North Carolina 27896',8488,10223);
INSERT INTO "django_geo_db_zipcode" VALUES(11641,27897,-5,'Woodland, North Carolina 27897',8489,10224);
INSERT INTO "django_geo_db_zipcode" VALUES(11642,27906,-5,'Elizabeth City, North Carolina 27906',8490,10225);
INSERT INTO "django_geo_db_zipcode" VALUES(11643,27907,-5,'Elizabeth City, North Carolina 27907',8490,10226);
INSERT INTO "django_geo_db_zipcode" VALUES(11644,27909,-5,'Elizabeth City, North Carolina 27909',8490,10227);
INSERT INTO "django_geo_db_zipcode" VALUES(11645,27910,-5,'Ahoskie, North Carolina 27910',8491,10228);
INSERT INTO "django_geo_db_zipcode" VALUES(11646,27915,-5,'Avon, North Carolina 27915',8492,10229);
INSERT INTO "django_geo_db_zipcode" VALUES(11647,27916,-5,'Aydlett, North Carolina 27916',8493,10230);
INSERT INTO "django_geo_db_zipcode" VALUES(11648,27917,-5,'Barco, North Carolina 27917',8494,10231);
INSERT INTO "django_geo_db_zipcode" VALUES(11649,27919,-5,'Belvidere, North Carolina 27919',8495,10232);
INSERT INTO "django_geo_db_zipcode" VALUES(11650,27920,-5,'Buxton, North Carolina 27920',8496,10233);
INSERT INTO "django_geo_db_zipcode" VALUES(11651,27921,-5,'Camden, North Carolina 27921',8497,10234);
INSERT INTO "django_geo_db_zipcode" VALUES(11652,27922,-5,'Cofield, North Carolina 27922',8498,10235);
INSERT INTO "django_geo_db_zipcode" VALUES(11653,27923,-5,'Coinjock, North Carolina 27923',8499,10236);
INSERT INTO "django_geo_db_zipcode" VALUES(11654,27924,-5,'Colerain, North Carolina 27924',8500,10237);
INSERT INTO "django_geo_db_zipcode" VALUES(11655,27925,-5,'Columbia, North Carolina 27925',8501,10238);
INSERT INTO "django_geo_db_zipcode" VALUES(11656,27926,-5,'Corapeake, North Carolina 27926',8502,10239);
INSERT INTO "django_geo_db_zipcode" VALUES(11657,27927,-5,'Corolla, North Carolina 27927',8503,10240);
INSERT INTO "django_geo_db_zipcode" VALUES(11658,27928,-5,'Creswell, North Carolina 27928',8504,10241);
INSERT INTO "django_geo_db_zipcode" VALUES(11659,27929,-5,'Currituck, North Carolina 27929',8505,10242);
INSERT INTO "django_geo_db_zipcode" VALUES(11660,27930,-5,'Durants Neck, North Carolina 27930',8506,10243);
INSERT INTO "django_geo_db_zipcode" VALUES(11661,27932,-5,'Edenton, North Carolina 27932',8507,10244);
INSERT INTO "django_geo_db_zipcode" VALUES(11662,27935,-5,'Eure, North Carolina 27935',8508,10245);
INSERT INTO "django_geo_db_zipcode" VALUES(11663,27936,-5,'Frisco, North Carolina 27936',8509,10246);
INSERT INTO "django_geo_db_zipcode" VALUES(11664,27937,-5,'Gates, North Carolina 27937',8510,10247);
INSERT INTO "django_geo_db_zipcode" VALUES(11665,27938,-5,'Gatesville, North Carolina 27938',8511,10248);
INSERT INTO "django_geo_db_zipcode" VALUES(11666,27939,-5,'Grandy, North Carolina 27939',8512,10249);
INSERT INTO "django_geo_db_zipcode" VALUES(11667,27941,-5,'Harbinger, North Carolina 27941',8513,10250);
INSERT INTO "django_geo_db_zipcode" VALUES(11668,27942,-5,'Harrellsville, North Carolina 27942',8514,10251);
INSERT INTO "django_geo_db_zipcode" VALUES(11669,27943,-5,'Hatteras, North Carolina 27943',8515,10252);
INSERT INTO "django_geo_db_zipcode" VALUES(11670,27944,-5,'Hertford, North Carolina 27944',8516,10253);
INSERT INTO "django_geo_db_zipcode" VALUES(11671,27946,-5,'Hobbsville, North Carolina 27946',8517,10254);
INSERT INTO "django_geo_db_zipcode" VALUES(11672,27947,-5,'Jarvisburg, North Carolina 27947',8518,10255);
INSERT INTO "django_geo_db_zipcode" VALUES(11673,27948,-5,'Kill Devil Hills, North Carolina 27948',8519,10256);
INSERT INTO "django_geo_db_zipcode" VALUES(11674,27949,-5,'Kitty Hawk, North Carolina 27949',8520,10257);
INSERT INTO "django_geo_db_zipcode" VALUES(11675,27950,-5,'Knotts Island, North Carolina 27950',8521,10258);
INSERT INTO "django_geo_db_zipcode" VALUES(11676,27953,-5,'Manns Harbor, North Carolina 27953',8522,10259);
INSERT INTO "django_geo_db_zipcode" VALUES(11677,27954,-5,'Manteo, North Carolina 27954',8523,10260);
INSERT INTO "django_geo_db_zipcode" VALUES(11678,27956,-5,'Maple, North Carolina 27956',8524,10261);
INSERT INTO "django_geo_db_zipcode" VALUES(11679,27957,-5,'Merry Hill, North Carolina 27957',8525,10262);
INSERT INTO "django_geo_db_zipcode" VALUES(11680,27958,-5,'Moyock, North Carolina 27958',8526,10263);
INSERT INTO "django_geo_db_zipcode" VALUES(11681,27959,-5,'Nags Head, North Carolina 27959',8527,10264);
INSERT INTO "django_geo_db_zipcode" VALUES(11682,27960,-5,'Ocracoke, North Carolina 27960',8528,10265);
INSERT INTO "django_geo_db_zipcode" VALUES(11683,27962,-5,'Plymouth, North Carolina 27962',8529,10266);
INSERT INTO "django_geo_db_zipcode" VALUES(11684,27964,-5,'Point Harbor, North Carolina 27964',8530,10267);
INSERT INTO "django_geo_db_zipcode" VALUES(11685,27965,-5,'Poplar Branch, North Carolina 27965',8531,10268);
INSERT INTO "django_geo_db_zipcode" VALUES(11686,27966,-5,'Powells Point, North Carolina 27966',8532,10269);
INSERT INTO "django_geo_db_zipcode" VALUES(11687,27967,-5,'Powellsville, North Carolina 27967',8533,10270);
INSERT INTO "django_geo_db_zipcode" VALUES(11688,27968,-5,'Rodanthe, North Carolina 27968',8534,10271);
INSERT INTO "django_geo_db_zipcode" VALUES(11689,27969,-5,'Roduco, North Carolina 27969',8535,10272);
INSERT INTO "django_geo_db_zipcode" VALUES(11690,27970,-5,'Roper, North Carolina 27970',8536,10273);
INSERT INTO "django_geo_db_zipcode" VALUES(11691,27972,-5,'Salvo, North Carolina 27972',8537,10274);
INSERT INTO "django_geo_db_zipcode" VALUES(11692,27973,-5,'Shawboro, North Carolina 27973',8538,10275);
INSERT INTO "django_geo_db_zipcode" VALUES(11693,27974,-5,'Shiloh, North Carolina 27974',8539,10276);
INSERT INTO "django_geo_db_zipcode" VALUES(11694,27976,-5,'South Mills, North Carolina 27976',8540,10277);
INSERT INTO "django_geo_db_zipcode" VALUES(11695,27978,-5,'Stumpy Point, North Carolina 27978',8541,10278);
INSERT INTO "django_geo_db_zipcode" VALUES(11696,27979,-5,'Sunbury, North Carolina 27979',8542,10279);
INSERT INTO "django_geo_db_zipcode" VALUES(11697,27980,-5,'Tyner, North Carolina 27980',8543,10280);
INSERT INTO "django_geo_db_zipcode" VALUES(11698,27981,-5,'Wanchese, North Carolina 27981',8544,10281);
INSERT INTO "django_geo_db_zipcode" VALUES(11699,27982,-5,'Waves, North Carolina 27982',8545,10282);
INSERT INTO "django_geo_db_zipcode" VALUES(11700,27983,-5,'Windsor, North Carolina 27983',8546,10283);
INSERT INTO "django_geo_db_zipcode" VALUES(11701,27985,-5,'Winfall, North Carolina 27985',8547,10284);
INSERT INTO "django_geo_db_zipcode" VALUES(11702,27986,-5,'Winton, North Carolina 27986',8548,10285);
INSERT INTO "django_geo_db_zipcode" VALUES(11703,28001,-5,'Albemarle, North Carolina 28001',8549,10286);
INSERT INTO "django_geo_db_zipcode" VALUES(11704,28002,-5,'Albemarle, North Carolina 28002',8549,10287);
INSERT INTO "django_geo_db_zipcode" VALUES(11705,28003,-5,'Marshville, North Carolina 28003',8550,10288);
INSERT INTO "django_geo_db_zipcode" VALUES(11706,28006,-5,'Alexis, North Carolina 28006',8551,10289);
INSERT INTO "django_geo_db_zipcode" VALUES(11707,28007,-5,'Ansonville, North Carolina 28007',8552,10290);
INSERT INTO "django_geo_db_zipcode" VALUES(11708,28009,-5,'Badin, North Carolina 28009',8553,10291);
INSERT INTO "django_geo_db_zipcode" VALUES(11709,28010,-5,'Barium Springs, North Carolina 28010',8554,10292);
INSERT INTO "django_geo_db_zipcode" VALUES(11710,28012,-5,'Belmont, North Carolina 28012',8555,10293);
INSERT INTO "django_geo_db_zipcode" VALUES(11711,28016,-5,'Bessemer City, North Carolina 28016',8556,10294);
INSERT INTO "django_geo_db_zipcode" VALUES(11712,28017,-5,'Boiling Springs, North Carolina 28017',8557,10295);
INSERT INTO "django_geo_db_zipcode" VALUES(11713,28018,-5,'Bostic, North Carolina 28018',8558,10296);
INSERT INTO "django_geo_db_zipcode" VALUES(11714,28019,-5,'Caroleen, North Carolina 28019',8559,10297);
INSERT INTO "django_geo_db_zipcode" VALUES(11715,28020,-5,'Casar, North Carolina 28020',8560,10298);
INSERT INTO "django_geo_db_zipcode" VALUES(11716,28021,-5,'Cherryville, North Carolina 28021',8561,10299);
INSERT INTO "django_geo_db_zipcode" VALUES(11717,28023,-5,'China Grove, North Carolina 28023',8562,10300);
INSERT INTO "django_geo_db_zipcode" VALUES(11718,28024,-5,'Cliffside, North Carolina 28024',8563,10301);
INSERT INTO "django_geo_db_zipcode" VALUES(11719,28025,-5,'Concord, North Carolina 28025',8564,10302);
INSERT INTO "django_geo_db_zipcode" VALUES(11720,28026,-5,'Concord, North Carolina 28026',8564,10303);
INSERT INTO "django_geo_db_zipcode" VALUES(11721,28027,-5,'Concord, North Carolina 28027',8564,10304);
INSERT INTO "django_geo_db_zipcode" VALUES(11722,28031,-5,'Cornelius, North Carolina 28031',8565,10305);
INSERT INTO "django_geo_db_zipcode" VALUES(11723,28032,-5,'Cramerton, North Carolina 28032',8566,10306);
INSERT INTO "django_geo_db_zipcode" VALUES(11724,28033,-5,'Crouse, North Carolina 28033',8567,10307);
INSERT INTO "django_geo_db_zipcode" VALUES(11725,28034,-5,'Dallas, North Carolina 28034',8568,10308);
INSERT INTO "django_geo_db_zipcode" VALUES(11726,28036,-5,'Davidson, North Carolina 28036',8569,10309);
INSERT INTO "django_geo_db_zipcode" VALUES(11727,28037,-5,'Denver, North Carolina 28037',8570,10310);
INSERT INTO "django_geo_db_zipcode" VALUES(11728,28038,-5,'Earl, North Carolina 28038',8571,10311);
INSERT INTO "django_geo_db_zipcode" VALUES(11729,28039,-5,'East Spencer, North Carolina 28039',8572,10312);
INSERT INTO "django_geo_db_zipcode" VALUES(11730,28040,-5,'Ellenboro, North Carolina 28040',8573,10313);
INSERT INTO "django_geo_db_zipcode" VALUES(11731,28041,-5,'Faith, North Carolina 28041',8574,10314);
INSERT INTO "django_geo_db_zipcode" VALUES(11732,28042,-5,'Fallston, North Carolina 28042',8575,10315);
INSERT INTO "django_geo_db_zipcode" VALUES(11733,28043,-5,'Forest City, North Carolina 28043',8576,10316);
INSERT INTO "django_geo_db_zipcode" VALUES(11734,28051,-5,'Gastonia, North Carolina 28051',8577,10317);
INSERT INTO "django_geo_db_zipcode" VALUES(11735,28052,-5,'Gastonia, North Carolina 28052',8577,10318);
INSERT INTO "django_geo_db_zipcode" VALUES(11736,28053,-5,'Gastonia, North Carolina 28053',8577,10319);
INSERT INTO "django_geo_db_zipcode" VALUES(11737,28054,-5,'Gastonia, North Carolina 28054',8577,10320);
INSERT INTO "django_geo_db_zipcode" VALUES(11738,28055,-5,'Gastonia, North Carolina 28055',8577,10317);
INSERT INTO "django_geo_db_zipcode" VALUES(11739,28056,-5,'Gastonia, North Carolina 28056',8577,10321);
INSERT INTO "django_geo_db_zipcode" VALUES(11740,28070,-5,'Huntersville, North Carolina 28070',8578,10322);
INSERT INTO "django_geo_db_zipcode" VALUES(11741,28071,-5,'Gold Hill, North Carolina 28071',8579,10323);
INSERT INTO "django_geo_db_zipcode" VALUES(11742,28072,-5,'Granite Quarry, North Carolina 28072',8580,10324);
INSERT INTO "django_geo_db_zipcode" VALUES(11743,28073,-5,'Grover, North Carolina 28073',8581,10325);
INSERT INTO "django_geo_db_zipcode" VALUES(11744,28074,-5,'Harris, North Carolina 28074',8582,10326);
INSERT INTO "django_geo_db_zipcode" VALUES(11745,28075,-5,'Harrisburg, North Carolina 28075',8583,10327);
INSERT INTO "django_geo_db_zipcode" VALUES(11746,28076,-5,'Henrietta, North Carolina 28076',8584,10328);
INSERT INTO "django_geo_db_zipcode" VALUES(11747,28077,-5,'High Shoals, North Carolina 28077',8585,10329);
INSERT INTO "django_geo_db_zipcode" VALUES(11748,28078,-5,'Huntersville, North Carolina 28078',8578,10330);
INSERT INTO "django_geo_db_zipcode" VALUES(11749,28079,-5,'Indian Trail, North Carolina 28079',8586,10331);
INSERT INTO "django_geo_db_zipcode" VALUES(11750,28080,-5,'Iron Station, North Carolina 28080',8587,10332);
INSERT INTO "django_geo_db_zipcode" VALUES(11751,28081,-5,'Kannapolis, North Carolina 28081',8588,10333);
INSERT INTO "django_geo_db_zipcode" VALUES(11752,28082,-5,'Kannapolis, North Carolina 28082',8588,10303);
INSERT INTO "django_geo_db_zipcode" VALUES(11753,28083,-5,'Kannapolis, North Carolina 28083',8588,10334);
INSERT INTO "django_geo_db_zipcode" VALUES(11754,28086,-5,'Kings Mountain, North Carolina 28086',8589,10335);
INSERT INTO "django_geo_db_zipcode" VALUES(11755,28088,-5,'Landis, North Carolina 28088',8590,10336);
INSERT INTO "django_geo_db_zipcode" VALUES(11756,28089,-5,'Lattimore, North Carolina 28089',8591,10337);
INSERT INTO "django_geo_db_zipcode" VALUES(11757,28090,-5,'Lawndale, North Carolina 28090',8592,10338);
INSERT INTO "django_geo_db_zipcode" VALUES(11758,28091,-5,'Lilesville, North Carolina 28091',8593,10339);
INSERT INTO "django_geo_db_zipcode" VALUES(11759,28092,-5,'Lincolnton, North Carolina 28092',8594,10340);
INSERT INTO "django_geo_db_zipcode" VALUES(11760,28093,-5,'Lincolnton, North Carolina 28093',8594,10341);
INSERT INTO "django_geo_db_zipcode" VALUES(11761,28097,-5,'Locust, North Carolina 28097',8595,10342);
INSERT INTO "django_geo_db_zipcode" VALUES(11762,28098,-5,'Lowell, North Carolina 28098',8596,10343);
INSERT INTO "django_geo_db_zipcode" VALUES(11763,28101,-5,'McAdenville, North Carolina 28101',8597,10344);
INSERT INTO "django_geo_db_zipcode" VALUES(11764,28102,-5,'McFarlan, North Carolina 28102',8598,10345);
INSERT INTO "django_geo_db_zipcode" VALUES(11765,28103,-5,'Marshville, North Carolina 28103',8550,10346);
INSERT INTO "django_geo_db_zipcode" VALUES(11766,28104,-5,'Matthews, North Carolina 28104',8599,10347);
INSERT INTO "django_geo_db_zipcode" VALUES(11767,28105,-5,'Matthews, North Carolina 28105',8599,10348);
INSERT INTO "django_geo_db_zipcode" VALUES(11768,28106,-5,'Matthews, North Carolina 28106',8599,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11769,28107,-5,'Midland, North Carolina 28107',8600,10350);
INSERT INTO "django_geo_db_zipcode" VALUES(11770,28108,-5,'Mineral Springs, North Carolina 28108',8601,10351);
INSERT INTO "django_geo_db_zipcode" VALUES(11771,28109,-5,'Misenheimer, North Carolina 28109',8602,10352);
INSERT INTO "django_geo_db_zipcode" VALUES(11772,28110,-5,'Monroe, North Carolina 28110',8603,10353);
INSERT INTO "django_geo_db_zipcode" VALUES(11773,28111,-5,'Monroe, North Carolina 28111',8603,10354);
INSERT INTO "django_geo_db_zipcode" VALUES(11774,28112,-5,'Monroe, North Carolina 28112',8603,10355);
INSERT INTO "django_geo_db_zipcode" VALUES(11775,28114,-5,'Mooresboro, North Carolina 28114',8604,10356);
INSERT INTO "django_geo_db_zipcode" VALUES(11776,28115,-5,'Mooresville, North Carolina 28115',8605,10357);
INSERT INTO "django_geo_db_zipcode" VALUES(11777,28117,-5,'Mooresville, North Carolina 28117',8605,10358);
INSERT INTO "django_geo_db_zipcode" VALUES(11778,28119,-5,'Morven, North Carolina 28119',8606,10359);
INSERT INTO "django_geo_db_zipcode" VALUES(11779,28120,-5,'Mount Holly, North Carolina 28120',8607,10360);
INSERT INTO "django_geo_db_zipcode" VALUES(11780,28123,-5,'Mount Mourne, North Carolina 28123',8608,10361);
INSERT INTO "django_geo_db_zipcode" VALUES(11781,28124,-5,'Mount Pleasant, North Carolina 28124',8609,10362);
INSERT INTO "django_geo_db_zipcode" VALUES(11782,28125,-5,'Mount Ulla, North Carolina 28125',8610,10363);
INSERT INTO "django_geo_db_zipcode" VALUES(11783,28126,-5,'Newell, North Carolina 28126',8611,10364);
INSERT INTO "django_geo_db_zipcode" VALUES(11784,28127,-5,'New London, North Carolina 28127',8612,10365);
INSERT INTO "django_geo_db_zipcode" VALUES(11785,28128,-5,'Norwood, North Carolina 28128',8613,10366);
INSERT INTO "django_geo_db_zipcode" VALUES(11786,28129,-5,'Oakboro, North Carolina 28129',8614,10367);
INSERT INTO "django_geo_db_zipcode" VALUES(11787,28130,-5,'Paw Creek, North Carolina 28130',8615,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11788,28133,-5,'Peachland, North Carolina 28133',8616,10368);
INSERT INTO "django_geo_db_zipcode" VALUES(11789,28134,-5,'Pineville, North Carolina 28134',8617,10369);
INSERT INTO "django_geo_db_zipcode" VALUES(11790,28135,-5,'Polkton, North Carolina 28135',8618,10370);
INSERT INTO "django_geo_db_zipcode" VALUES(11791,28136,-5,'Polkville, North Carolina 28136',8619,10371);
INSERT INTO "django_geo_db_zipcode" VALUES(11792,28137,-5,'Richfield, North Carolina 28137',8620,10372);
INSERT INTO "django_geo_db_zipcode" VALUES(11793,28138,-5,'Rockwell, North Carolina 28138',8621,10373);
INSERT INTO "django_geo_db_zipcode" VALUES(11794,28139,-5,'Rutherfordton, North Carolina 28139',8622,10374);
INSERT INTO "django_geo_db_zipcode" VALUES(11795,28144,-5,'Salisbury, North Carolina 28144',8261,10375);
INSERT INTO "django_geo_db_zipcode" VALUES(11796,28145,-5,'Salisbury, North Carolina 28145',8261,10376);
INSERT INTO "django_geo_db_zipcode" VALUES(11797,28146,-5,'Salisbury, North Carolina 28146',8261,10377);
INSERT INTO "django_geo_db_zipcode" VALUES(11798,28147,-5,'Salisbury, North Carolina 28147',8261,10378);
INSERT INTO "django_geo_db_zipcode" VALUES(11799,28150,-5,'Shelby, North Carolina 28150',8623,10379);
INSERT INTO "django_geo_db_zipcode" VALUES(11800,28151,-5,'Shelby, North Carolina 28151',8623,10380);
INSERT INTO "django_geo_db_zipcode" VALUES(11801,28152,-5,'Shelby, North Carolina 28152',8623,10381);
INSERT INTO "django_geo_db_zipcode" VALUES(11802,28159,-5,'Spencer, North Carolina 28159',8624,10382);
INSERT INTO "django_geo_db_zipcode" VALUES(11803,28160,-5,'Spindale, North Carolina 28160',8625,10383);
INSERT INTO "django_geo_db_zipcode" VALUES(11804,28163,-5,'Stanfield, North Carolina 28163',8626,10384);
INSERT INTO "django_geo_db_zipcode" VALUES(11805,28164,-5,'Stanley, North Carolina 28164',8627,10385);
INSERT INTO "django_geo_db_zipcode" VALUES(11806,28166,-5,'Troutman, North Carolina 28166',8628,10386);
INSERT INTO "django_geo_db_zipcode" VALUES(11807,28167,-5,'Union Mills, North Carolina 28167',8629,10387);
INSERT INTO "django_geo_db_zipcode" VALUES(11808,28168,-5,'Vale, North Carolina 28168',8630,10388);
INSERT INTO "django_geo_db_zipcode" VALUES(11809,28169,-5,'Waco, North Carolina 28169',8631,10389);
INSERT INTO "django_geo_db_zipcode" VALUES(11810,28170,-5,'Wadesboro, North Carolina 28170',8632,10390);
INSERT INTO "django_geo_db_zipcode" VALUES(11811,28173,-5,'Waxhaw, North Carolina 28173',8633,10391);
INSERT INTO "django_geo_db_zipcode" VALUES(11812,28174,-5,'Wingate, North Carolina 28174',8634,10392);
INSERT INTO "django_geo_db_zipcode" VALUES(11813,28201,-5,'Charlotte, North Carolina 28201',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11814,28202,-5,'Charlotte, North Carolina 28202',8635,10393);
INSERT INTO "django_geo_db_zipcode" VALUES(11815,28203,-5,'Charlotte, North Carolina 28203',8635,10394);
INSERT INTO "django_geo_db_zipcode" VALUES(11816,28204,-5,'Charlotte, North Carolina 28204',8635,10395);
INSERT INTO "django_geo_db_zipcode" VALUES(11817,28205,-5,'Charlotte, North Carolina 28205',8635,10396);
INSERT INTO "django_geo_db_zipcode" VALUES(11818,28206,-5,'Charlotte, North Carolina 28206',8635,10397);
INSERT INTO "django_geo_db_zipcode" VALUES(11819,28207,-5,'Charlotte, North Carolina 28207',8635,10398);
INSERT INTO "django_geo_db_zipcode" VALUES(11820,28208,-5,'Charlotte, North Carolina 28208',8635,10399);
INSERT INTO "django_geo_db_zipcode" VALUES(11821,28209,-5,'Charlotte, North Carolina 28209',8635,10400);
INSERT INTO "django_geo_db_zipcode" VALUES(11822,28210,-5,'Charlotte, North Carolina 28210',8635,10401);
INSERT INTO "django_geo_db_zipcode" VALUES(11823,28211,-5,'Charlotte, North Carolina 28211',8635,10402);
INSERT INTO "django_geo_db_zipcode" VALUES(11824,28212,-5,'Charlotte, North Carolina 28212',8635,10403);
INSERT INTO "django_geo_db_zipcode" VALUES(11825,28213,-5,'Charlotte, North Carolina 28213',8635,10404);
INSERT INTO "django_geo_db_zipcode" VALUES(11826,28214,-5,'Charlotte, North Carolina 28214',8635,10405);
INSERT INTO "django_geo_db_zipcode" VALUES(11827,28215,-5,'Charlotte, North Carolina 28215',8635,10406);
INSERT INTO "django_geo_db_zipcode" VALUES(11828,28216,-5,'Charlotte, North Carolina 28216',8635,10407);
INSERT INTO "django_geo_db_zipcode" VALUES(11829,28217,-5,'Charlotte, North Carolina 28217',8635,10408);
INSERT INTO "django_geo_db_zipcode" VALUES(11830,28218,-5,'Charlotte, North Carolina 28218',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11831,28219,-5,'Charlotte, North Carolina 28219',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11832,28220,-5,'Charlotte, North Carolina 28220',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11833,28221,-5,'Charlotte, North Carolina 28221',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11834,28222,-5,'Charlotte, North Carolina 28222',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11835,28223,-5,'Charlotte, North Carolina 28223',8635,10409);
INSERT INTO "django_geo_db_zipcode" VALUES(11836,28224,-5,'Charlotte, North Carolina 28224',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11837,28225,-5,'Charlotte, North Carolina 28225',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11838,28226,-5,'Charlotte, North Carolina 28226',8635,10410);
INSERT INTO "django_geo_db_zipcode" VALUES(11839,28227,-5,'Charlotte, North Carolina 28227',8635,10411);
INSERT INTO "django_geo_db_zipcode" VALUES(11840,28228,-5,'Charlotte, North Carolina 28228',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11841,28229,-5,'Charlotte, North Carolina 28229',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11842,28230,-5,'Charlotte, North Carolina 28230',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11843,28231,-5,'Charlotte, North Carolina 28231',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11844,28232,-5,'Charlotte, North Carolina 28232',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11845,28233,-5,'Charlotte, North Carolina 28233',8635,10412);
INSERT INTO "django_geo_db_zipcode" VALUES(11846,28234,-5,'Charlotte, North Carolina 28234',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11847,28235,-5,'Charlotte, North Carolina 28235',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11848,28236,-5,'Charlotte, North Carolina 28236',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11849,28237,-5,'Charlotte, North Carolina 28237',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11850,28240,-5,'Charlotte, North Carolina 28240',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11851,28241,-5,'Charlotte, North Carolina 28241',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11852,28242,-5,'Charlotte, North Carolina 28242',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11853,28243,-5,'Charlotte, North Carolina 28243',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11854,28244,-5,'Charlotte, North Carolina 28244',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11855,28246,-5,'Charlotte, North Carolina 28246',8635,10413);
INSERT INTO "django_geo_db_zipcode" VALUES(11856,28247,-5,'Charlotte, North Carolina 28247',8635,10414);
INSERT INTO "django_geo_db_zipcode" VALUES(11857,28250,-5,'Charlotte, North Carolina 28250',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11858,28253,-5,'Charlotte, North Carolina 28253',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11859,28254,-5,'Charlotte, North Carolina 28254',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11860,28255,-5,'Charlotte, North Carolina 28255',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11861,28256,-5,'Charlotte, North Carolina 28256',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11862,28258,-5,'Charlotte, North Carolina 28258',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11863,28260,-5,'Charlotte, North Carolina 28260',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11864,28261,-5,'Charlotte, North Carolina 28261',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11865,28262,-5,'Charlotte, North Carolina 28262',8635,10415);
INSERT INTO "django_geo_db_zipcode" VALUES(11866,28265,-5,'Charlotte, North Carolina 28265',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11867,28266,-5,'Charlotte, North Carolina 28266',8635,10416);
INSERT INTO "django_geo_db_zipcode" VALUES(11868,28269,-5,'Charlotte, North Carolina 28269',8635,10417);
INSERT INTO "django_geo_db_zipcode" VALUES(11869,28270,-5,'Charlotte, North Carolina 28270',8635,10418);
INSERT INTO "django_geo_db_zipcode" VALUES(11870,28272,-5,'Charlotte, North Carolina 28272',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11871,28273,-5,'Charlotte, North Carolina 28273',8635,10419);
INSERT INTO "django_geo_db_zipcode" VALUES(11872,28274,-5,'Charlotte, North Carolina 28274',8635,10420);
INSERT INTO "django_geo_db_zipcode" VALUES(11873,28275,-5,'Charlotte, North Carolina 28275',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11874,28277,-5,'Charlotte, North Carolina 28277',8635,10421);
INSERT INTO "django_geo_db_zipcode" VALUES(11875,28278,-5,'Charlotte, North Carolina 28278',8635,10422);
INSERT INTO "django_geo_db_zipcode" VALUES(11876,28280,-5,'Charlotte, North Carolina 28280',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11877,28281,-5,'Charlotte, North Carolina 28281',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11878,28282,-5,'Charlotte, North Carolina 28282',8635,10423);
INSERT INTO "django_geo_db_zipcode" VALUES(11879,28283,-5,'Charlotte, North Carolina 28283',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11880,28284,-5,'Charlotte, North Carolina 28284',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11881,28285,-5,'Charlotte, North Carolina 28285',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11882,28286,-5,'Charlotte, North Carolina 28286',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11883,28287,-5,'Charlotte, North Carolina 28287',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11884,28288,-5,'Charlotte, North Carolina 28288',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11885,28289,-5,'Charlotte, North Carolina 28289',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11886,28290,-5,'Charlotte, North Carolina 28290',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11887,28296,-5,'Charlotte, North Carolina 28296',8635,10424);
INSERT INTO "django_geo_db_zipcode" VALUES(11888,28297,-5,'Charlotte, North Carolina 28297',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11889,28299,-5,'Charlotte, North Carolina 28299',8635,10349);
INSERT INTO "django_geo_db_zipcode" VALUES(11890,28301,-5,'Fayetteville, North Carolina 28301',8636,10425);
INSERT INTO "django_geo_db_zipcode" VALUES(11891,28302,-5,'Fayetteville, North Carolina 28302',8636,10426);
INSERT INTO "django_geo_db_zipcode" VALUES(11892,28303,-5,'Fayetteville, North Carolina 28303',8636,10427);
INSERT INTO "django_geo_db_zipcode" VALUES(11893,28304,-5,'Fayetteville, North Carolina 28304',8636,10428);
INSERT INTO "django_geo_db_zipcode" VALUES(11894,28305,-5,'Fayetteville, North Carolina 28305',8636,10429);
INSERT INTO "django_geo_db_zipcode" VALUES(11895,28306,-5,'Fayetteville, North Carolina 28306',8636,10430);
INSERT INTO "django_geo_db_zipcode" VALUES(11896,28307,-5,'Fort Bragg, North Carolina 28307',8637,10431);
INSERT INTO "django_geo_db_zipcode" VALUES(11897,28308,-5,'Pope A F B, North Carolina 28308',8638,10432);
INSERT INTO "django_geo_db_zipcode" VALUES(11898,28309,-5,'Fayetteville, North Carolina 28309',8636,10433);
INSERT INTO "django_geo_db_zipcode" VALUES(11899,28310,-5,'Fort Bragg, North Carolina 28310',8637,10434);
INSERT INTO "django_geo_db_zipcode" VALUES(11900,28311,-5,'Fayetteville, North Carolina 28311',8636,10435);
INSERT INTO "django_geo_db_zipcode" VALUES(11901,28314,-5,'Fayetteville, North Carolina 28314',8636,10436);
INSERT INTO "django_geo_db_zipcode" VALUES(11902,28315,-5,'Aberdeen, North Carolina 28315',8639,10437);
INSERT INTO "django_geo_db_zipcode" VALUES(11903,28318,-5,'Autryville, North Carolina 28318',8640,10438);
INSERT INTO "django_geo_db_zipcode" VALUES(11904,28319,-5,'Barnesville, North Carolina 28319',8641,10439);
INSERT INTO "django_geo_db_zipcode" VALUES(11905,28320,-5,'Bladenboro, North Carolina 28320',8642,10440);
INSERT INTO "django_geo_db_zipcode" VALUES(11906,28323,-5,'Bunnlevel, North Carolina 28323',8643,10441);
INSERT INTO "django_geo_db_zipcode" VALUES(11907,28325,-5,'Calypso, North Carolina 28325',8644,10442);
INSERT INTO "django_geo_db_zipcode" VALUES(11908,28326,-5,'Cameron, North Carolina 28326',8645,10443);
INSERT INTO "django_geo_db_zipcode" VALUES(11909,28327,-5,'Carthage, North Carolina 28327',8646,10444);
INSERT INTO "django_geo_db_zipcode" VALUES(11910,28328,-5,'Clinton, North Carolina 28328',8647,10445);
INSERT INTO "django_geo_db_zipcode" VALUES(11911,28329,-5,'Clinton, North Carolina 28329',8647,10446);
INSERT INTO "django_geo_db_zipcode" VALUES(11912,28330,-5,'Cordova, North Carolina 28330',8648,10447);
INSERT INTO "django_geo_db_zipcode" VALUES(11913,28331,-5,'Cumberland, North Carolina 28331',8649,10448);
INSERT INTO "django_geo_db_zipcode" VALUES(11914,28332,-5,'Dublin, North Carolina 28332',8650,10449);
INSERT INTO "django_geo_db_zipcode" VALUES(11915,28333,-5,'Dudley, North Carolina 28333',8651,10450);
INSERT INTO "django_geo_db_zipcode" VALUES(11916,28334,-5,'Dunn, North Carolina 28334',8652,10451);
INSERT INTO "django_geo_db_zipcode" VALUES(11917,28335,-5,'Dunn, North Carolina 28335',8652,10452);
INSERT INTO "django_geo_db_zipcode" VALUES(11918,28337,-5,'Elizabethtown, North Carolina 28337',8653,10453);
INSERT INTO "django_geo_db_zipcode" VALUES(11919,28338,-5,'Ellerbe, North Carolina 28338',8654,10454);
INSERT INTO "django_geo_db_zipcode" VALUES(11920,28339,-5,'Erwin, North Carolina 28339',8655,10455);
INSERT INTO "django_geo_db_zipcode" VALUES(11921,28340,-5,'Fairmont, North Carolina 28340',8656,10456);
INSERT INTO "django_geo_db_zipcode" VALUES(11922,28341,-5,'Faison, North Carolina 28341',8657,10457);
INSERT INTO "django_geo_db_zipcode" VALUES(11923,28342,-5,'Falcon, North Carolina 28342',8658,10458);
INSERT INTO "django_geo_db_zipcode" VALUES(11924,28343,-5,'Gibson, North Carolina 28343',8659,10459);
INSERT INTO "django_geo_db_zipcode" VALUES(11925,28344,-5,'Godwin, North Carolina 28344',8660,10460);
INSERT INTO "django_geo_db_zipcode" VALUES(11926,28345,-5,'Hamlet, North Carolina 28345',8661,10461);
INSERT INTO "django_geo_db_zipcode" VALUES(11927,28347,-5,'Hoffman, North Carolina 28347',8662,10462);
INSERT INTO "django_geo_db_zipcode" VALUES(11928,28348,-5,'Hope Mills, North Carolina 28348',8663,10463);
INSERT INTO "django_geo_db_zipcode" VALUES(11929,28349,-5,'Kenansville, North Carolina 28349',8664,10464);
INSERT INTO "django_geo_db_zipcode" VALUES(11930,28350,-5,'Lakeview, North Carolina 28350',8665,10465);
INSERT INTO "django_geo_db_zipcode" VALUES(11931,28351,-5,'Laurel Hill, North Carolina 28351',8666,10466);
INSERT INTO "django_geo_db_zipcode" VALUES(11932,28352,-5,'Laurinburg, North Carolina 28352',8667,10467);
INSERT INTO "django_geo_db_zipcode" VALUES(11933,28353,-5,'Laurinburg, North Carolina 28353',8667,10468);
INSERT INTO "django_geo_db_zipcode" VALUES(11934,28355,-5,'Lemon Springs, North Carolina 28355',8668,9942);
INSERT INTO "django_geo_db_zipcode" VALUES(11935,28356,-5,'Linden, North Carolina 28356',8669,10469);
INSERT INTO "django_geo_db_zipcode" VALUES(11936,28357,-5,'Lumber Bridge, North Carolina 28357',8670,10470);
INSERT INTO "django_geo_db_zipcode" VALUES(11937,28358,-5,'Lumberton, North Carolina 28358',8671,10471);
INSERT INTO "django_geo_db_zipcode" VALUES(11938,28359,-5,'Lumberton, North Carolina 28359',8671,10472);
INSERT INTO "django_geo_db_zipcode" VALUES(11939,28360,-5,'Lumberton, North Carolina 28360',8671,10473);
INSERT INTO "django_geo_db_zipcode" VALUES(11940,28361,-5,'Mccain, North Carolina 28361',8672,10474);
INSERT INTO "django_geo_db_zipcode" VALUES(11941,28362,-5,'Marietta, North Carolina 28362',8673,10475);
INSERT INTO "django_geo_db_zipcode" VALUES(11942,28363,-5,'Marston, North Carolina 28363',8674,10476);
INSERT INTO "django_geo_db_zipcode" VALUES(11943,28364,-5,'Maxton, North Carolina 28364',8675,10477);
INSERT INTO "django_geo_db_zipcode" VALUES(11944,28365,-5,'Mount Olive, North Carolina 28365',8676,10478);
INSERT INTO "django_geo_db_zipcode" VALUES(11945,28366,-5,'Newton Grove, North Carolina 28366',8677,10479);
INSERT INTO "django_geo_db_zipcode" VALUES(11946,28367,-5,'Norman, North Carolina 28367',8678,10480);
INSERT INTO "django_geo_db_zipcode" VALUES(11947,28368,-5,'Olivia, North Carolina 28368',8679,10481);
INSERT INTO "django_geo_db_zipcode" VALUES(11948,28369,-5,'Orrum, North Carolina 28369',8680,10482);
INSERT INTO "django_geo_db_zipcode" VALUES(11949,28370,-5,'Pinehurst, North Carolina 28370',8681,10483);
INSERT INTO "django_geo_db_zipcode" VALUES(11950,28371,-5,'Parkton, North Carolina 28371',8682,10484);
INSERT INTO "django_geo_db_zipcode" VALUES(11951,28372,-5,'Pembroke, North Carolina 28372',8683,10485);
INSERT INTO "django_geo_db_zipcode" VALUES(11952,28373,-5,'Pinebluff, North Carolina 28373',8684,10486);
INSERT INTO "django_geo_db_zipcode" VALUES(11953,28374,-5,'Pinehurst, North Carolina 28374',8681,10487);
INSERT INTO "django_geo_db_zipcode" VALUES(11954,28375,-5,'Proctorville, North Carolina 28375',8685,10488);
INSERT INTO "django_geo_db_zipcode" VALUES(11955,28376,-5,'Raeford, North Carolina 28376',8686,10489);
INSERT INTO "django_geo_db_zipcode" VALUES(11956,28377,-5,'Red Springs, North Carolina 28377',8687,10490);
INSERT INTO "django_geo_db_zipcode" VALUES(11957,28378,-5,'Rex, North Carolina 28378',8688,10491);
INSERT INTO "django_geo_db_zipcode" VALUES(11958,28379,-5,'Rockingham, North Carolina 28379',8689,10492);
INSERT INTO "django_geo_db_zipcode" VALUES(11959,28380,-5,'Rockingham, North Carolina 28380',8689,10493);
INSERT INTO "django_geo_db_zipcode" VALUES(11960,28382,-5,'Roseboro, North Carolina 28382',8690,10494);
INSERT INTO "django_geo_db_zipcode" VALUES(11961,28383,-5,'Rowland, North Carolina 28383',8691,10495);
INSERT INTO "django_geo_db_zipcode" VALUES(11962,28384,-5,'Saint Pauls, North Carolina 28384',8692,10496);
INSERT INTO "django_geo_db_zipcode" VALUES(11963,28385,-5,'Salemburg, North Carolina 28385',8693,10497);
INSERT INTO "django_geo_db_zipcode" VALUES(11964,28386,-5,'Shannon, North Carolina 28386',8694,10498);
INSERT INTO "django_geo_db_zipcode" VALUES(11965,28387,-5,'Southern Pines, North Carolina 28387',8695,10499);
INSERT INTO "django_geo_db_zipcode" VALUES(11966,28388,-5,'Southern Pines, North Carolina 28388',8695,10500);
INSERT INTO "django_geo_db_zipcode" VALUES(11967,28390,-5,'Spring Lake, North Carolina 28390',8696,10501);
INSERT INTO "django_geo_db_zipcode" VALUES(11968,28391,-5,'Stedman, North Carolina 28391',8697,10502);
INSERT INTO "django_geo_db_zipcode" VALUES(11969,28392,-5,'Tar Heel, North Carolina 28392',8698,10503);
INSERT INTO "django_geo_db_zipcode" VALUES(11970,28393,-5,'Turkey, North Carolina 28393',8699,10504);
INSERT INTO "django_geo_db_zipcode" VALUES(11971,28394,-5,'Vass, North Carolina 28394',8700,10505);
INSERT INTO "django_geo_db_zipcode" VALUES(11972,28395,-5,'Wade, North Carolina 28395',8701,10506);
INSERT INTO "django_geo_db_zipcode" VALUES(11973,28396,-5,'Wagram, North Carolina 28396',8702,10507);
INSERT INTO "django_geo_db_zipcode" VALUES(11974,28397,-5,'Stedman, North Carolina 28397',8697,10508);
INSERT INTO "django_geo_db_zipcode" VALUES(11975,28398,-5,'Warsaw, North Carolina 28398',8703,10509);
INSERT INTO "django_geo_db_zipcode" VALUES(11976,28399,-5,'White Oak, North Carolina 28399',8704,10510);
INSERT INTO "django_geo_db_zipcode" VALUES(11977,28401,-5,'Wilmington, North Carolina 28401',8705,10511);
INSERT INTO "django_geo_db_zipcode" VALUES(11978,28402,-5,'Wilmington, North Carolina 28402',8705,10512);
INSERT INTO "django_geo_db_zipcode" VALUES(11979,28403,-5,'Wilmington, North Carolina 28403',8705,10513);
INSERT INTO "django_geo_db_zipcode" VALUES(11980,28404,-5,'Wilmington, North Carolina 28404',8705,10514);
INSERT INTO "django_geo_db_zipcode" VALUES(11981,28405,-5,'Wilmington, North Carolina 28405',8705,10515);
INSERT INTO "django_geo_db_zipcode" VALUES(11982,28406,-5,'Wilmington, North Carolina 28406',8705,10516);
INSERT INTO "django_geo_db_zipcode" VALUES(11983,28407,-5,'Wilmington, North Carolina 28407',8705,10516);
INSERT INTO "django_geo_db_zipcode" VALUES(11984,28408,-5,'Wilmington, North Carolina 28408',8705,10517);
INSERT INTO "django_geo_db_zipcode" VALUES(11985,28409,-5,'Wilmington, North Carolina 28409',8705,10518);
INSERT INTO "django_geo_db_zipcode" VALUES(11986,28410,-5,'Wilmington, North Carolina 28410',8705,10516);
INSERT INTO "django_geo_db_zipcode" VALUES(11987,28411,-5,'Wilmington, North Carolina 28411',8705,10519);
INSERT INTO "django_geo_db_zipcode" VALUES(11988,28412,-5,'Wilmington, North Carolina 28412',8705,10520);
INSERT INTO "django_geo_db_zipcode" VALUES(11989,28420,-5,'Ash, North Carolina 28420',8706,10521);
INSERT INTO "django_geo_db_zipcode" VALUES(11990,28421,-5,'Atkinson, North Carolina 28421',8707,10522);
INSERT INTO "django_geo_db_zipcode" VALUES(11991,28422,-5,'Bolivia, North Carolina 28422',8708,10523);
INSERT INTO "django_geo_db_zipcode" VALUES(11992,28423,-5,'Bolton, North Carolina 28423',8709,10524);
INSERT INTO "django_geo_db_zipcode" VALUES(11993,28424,-5,'Brunswick, North Carolina 28424',8710,10525);
INSERT INTO "django_geo_db_zipcode" VALUES(11994,28425,-5,'Burgaw, North Carolina 28425',8711,10526);
INSERT INTO "django_geo_db_zipcode" VALUES(11995,28428,-5,'Carolina Beach, North Carolina 28428',8712,10527);
INSERT INTO "django_geo_db_zipcode" VALUES(11996,28429,-5,'Castle Hayne, North Carolina 28429',8713,10528);
INSERT INTO "django_geo_db_zipcode" VALUES(11997,28430,-5,'Cerro Gordo, North Carolina 28430',8714,10529);
INSERT INTO "django_geo_db_zipcode" VALUES(11998,28431,-5,'Chadbourn, North Carolina 28431',8715,10530);
INSERT INTO "django_geo_db_zipcode" VALUES(11999,28432,-5,'Clarendon, North Carolina 28432',8716,10531);
INSERT INTO "django_geo_db_zipcode" VALUES(12000,28433,-5,'Clarkton, North Carolina 28433',8717,10532);
INSERT INTO "django_geo_db_zipcode" VALUES(12001,28434,-5,'Council, North Carolina 28434',8718,10533);
INSERT INTO "django_geo_db_zipcode" VALUES(12002,28435,-5,'Currie, North Carolina 28435',8719,10534);
INSERT INTO "django_geo_db_zipcode" VALUES(12003,28436,-5,'Delco, North Carolina 28436',8720,10535);
INSERT INTO "django_geo_db_zipcode" VALUES(12004,28438,-5,'Evergreen, North Carolina 28438',8721,10536);
INSERT INTO "django_geo_db_zipcode" VALUES(12005,28439,-5,'Fair Bluff, North Carolina 28439',8722,10537);
INSERT INTO "django_geo_db_zipcode" VALUES(12006,28441,-5,'Garland, North Carolina 28441',8723,10538);
INSERT INTO "django_geo_db_zipcode" VALUES(12007,28442,-5,'Hallsboro, North Carolina 28442',8724,10539);
INSERT INTO "django_geo_db_zipcode" VALUES(12008,28443,-5,'Hampstead, North Carolina 28443',8725,10540);
INSERT INTO "django_geo_db_zipcode" VALUES(12009,28444,-5,'Harrells, North Carolina 28444',8726,10541);
INSERT INTO "django_geo_db_zipcode" VALUES(12010,28445,-5,'Holly Ridge, North Carolina 28445',8727,10542);
INSERT INTO "django_geo_db_zipcode" VALUES(12011,28446,-5,'Ingold, North Carolina 28446',8728,10543);
INSERT INTO "django_geo_db_zipcode" VALUES(12012,28447,-5,'Ivanhoe, North Carolina 28447',8729,10544);
INSERT INTO "django_geo_db_zipcode" VALUES(12013,28448,-5,'Kelly, North Carolina 28448',8730,10545);
INSERT INTO "django_geo_db_zipcode" VALUES(12014,28449,-5,'Kure Beach, North Carolina 28449',8731,10546);
INSERT INTO "django_geo_db_zipcode" VALUES(12015,28450,-5,'Lake Waccamaw, North Carolina 28450',8732,10547);
INSERT INTO "django_geo_db_zipcode" VALUES(12016,28451,-5,'Leland, North Carolina 28451',8733,10548);
INSERT INTO "django_geo_db_zipcode" VALUES(12017,28452,-5,'Longwood, North Carolina 28452',8734,10549);
INSERT INTO "django_geo_db_zipcode" VALUES(12018,28453,-5,'Magnolia, North Carolina 28453',8735,10550);
INSERT INTO "django_geo_db_zipcode" VALUES(12019,28454,-5,'Maple Hill, North Carolina 28454',8736,10551);
INSERT INTO "django_geo_db_zipcode" VALUES(12020,28455,-5,'Nakina, North Carolina 28455',8737,10552);
INSERT INTO "django_geo_db_zipcode" VALUES(12021,28456,-5,'Riegelwood, North Carolina 28456',8738,10553);
INSERT INTO "django_geo_db_zipcode" VALUES(12022,28457,-5,'Rocky Point, North Carolina 28457',8739,10554);
INSERT INTO "django_geo_db_zipcode" VALUES(12023,28458,-5,'Rose Hill, North Carolina 28458',8740,10555);
INSERT INTO "django_geo_db_zipcode" VALUES(12024,28459,-5,'Shallotte, North Carolina 28459',8741,10556);
INSERT INTO "django_geo_db_zipcode" VALUES(12025,28460,-5,'Sneads Ferry, North Carolina 28460',8742,10557);
INSERT INTO "django_geo_db_zipcode" VALUES(12026,28461,-5,'Southport, North Carolina 28461',8743,10558);
INSERT INTO "django_geo_db_zipcode" VALUES(12027,28462,-5,'Supply, North Carolina 28462',8744,10559);
INSERT INTO "django_geo_db_zipcode" VALUES(12028,28463,-5,'Tabor City, North Carolina 28463',8745,10560);
INSERT INTO "django_geo_db_zipcode" VALUES(12029,28464,-5,'Teachey, North Carolina 28464',8746,10561);
INSERT INTO "django_geo_db_zipcode" VALUES(12030,28465,-5,'Oak Island, North Carolina 28465',8747,10562);
INSERT INTO "django_geo_db_zipcode" VALUES(12031,28466,-5,'Wallace, North Carolina 28466',8748,10563);
INSERT INTO "django_geo_db_zipcode" VALUES(12032,28467,-5,'Calabash, North Carolina 28467',8749,10564);
INSERT INTO "django_geo_db_zipcode" VALUES(12033,28468,-5,'Sunset Beach, North Carolina 28468',8750,10565);
INSERT INTO "django_geo_db_zipcode" VALUES(12034,28469,-5,'Ocean Isle Beach, North Carolina 28469',8751,10566);
INSERT INTO "django_geo_db_zipcode" VALUES(12035,28470,-5,'South Brunswick, North Carolina 28470',8752,10567);
INSERT INTO "django_geo_db_zipcode" VALUES(12036,28471,-5,'Watha, North Carolina 28471',8753,10568);
INSERT INTO "django_geo_db_zipcode" VALUES(12037,28472,-5,'Whiteville, North Carolina 28472',8754,10569);
INSERT INTO "django_geo_db_zipcode" VALUES(12038,28478,-5,'Willard, North Carolina 28478',8755,10570);
INSERT INTO "django_geo_db_zipcode" VALUES(12039,28479,-5,'Winnabow, North Carolina 28479',8756,10571);
INSERT INTO "django_geo_db_zipcode" VALUES(12040,28480,-5,'Wrightsville Beach, North Carolina 28480',8757,10572);
INSERT INTO "django_geo_db_zipcode" VALUES(12041,28501,-5,'Kinston, North Carolina 28501',8758,10573);
INSERT INTO "django_geo_db_zipcode" VALUES(12042,28502,-5,'Kinston, North Carolina 28502',8758,10574);
INSERT INTO "django_geo_db_zipcode" VALUES(12043,28503,-5,'Kinston, North Carolina 28503',8758,10575);
INSERT INTO "django_geo_db_zipcode" VALUES(12044,28504,-5,'Kinston, North Carolina 28504',8758,10576);
INSERT INTO "django_geo_db_zipcode" VALUES(12045,28508,-5,'Albertson, North Carolina 28508',8759,10577);
INSERT INTO "django_geo_db_zipcode" VALUES(12046,28509,-5,'Alliance, North Carolina 28509',8760,10578);
INSERT INTO "django_geo_db_zipcode" VALUES(12047,28510,-5,'Arapahoe, North Carolina 28510',8761,10579);
INSERT INTO "django_geo_db_zipcode" VALUES(12048,28511,-5,'Atlantic, North Carolina 28511',8762,10580);
INSERT INTO "django_geo_db_zipcode" VALUES(12049,28512,-5,'Atlantic Beach, North Carolina 28512',8763,10581);
INSERT INTO "django_geo_db_zipcode" VALUES(12050,28513,-5,'Ayden, North Carolina 28513',8764,10582);
INSERT INTO "django_geo_db_zipcode" VALUES(12051,28515,-5,'Bayboro, North Carolina 28515',8765,10583);
INSERT INTO "django_geo_db_zipcode" VALUES(12052,28516,-5,'Beaufort, North Carolina 28516',8766,10584);
INSERT INTO "django_geo_db_zipcode" VALUES(12053,28518,-5,'Beulaville, North Carolina 28518',8767,10585);
INSERT INTO "django_geo_db_zipcode" VALUES(12054,28519,-5,'Bridgeton, North Carolina 28519',8768,10586);
INSERT INTO "django_geo_db_zipcode" VALUES(12055,28520,-5,'Cedar Island, North Carolina 28520',8769,10587);
INSERT INTO "django_geo_db_zipcode" VALUES(12056,28521,-5,'Chinquapin, North Carolina 28521',8770,10588);
INSERT INTO "django_geo_db_zipcode" VALUES(12057,28522,-5,'Comfort, North Carolina 28522',8771,10589);
INSERT INTO "django_geo_db_zipcode" VALUES(12058,28523,-5,'Cove City, North Carolina 28523',8772,10590);
INSERT INTO "django_geo_db_zipcode" VALUES(12059,28524,-5,'Davis, North Carolina 28524',8773,10591);
INSERT INTO "django_geo_db_zipcode" VALUES(12060,28525,-5,'Deep Run, North Carolina 28525',8774,10592);
INSERT INTO "django_geo_db_zipcode" VALUES(12061,28526,-5,'Dover, North Carolina 28526',8775,10593);
INSERT INTO "django_geo_db_zipcode" VALUES(12062,28527,-5,'Ernul, North Carolina 28527',8776,10594);
INSERT INTO "django_geo_db_zipcode" VALUES(12063,28528,-5,'Gloucester, North Carolina 28528',8777,10595);
INSERT INTO "django_geo_db_zipcode" VALUES(12064,28529,-5,'Grantsboro, North Carolina 28529',8778,10596);
INSERT INTO "django_geo_db_zipcode" VALUES(12065,28530,-5,'Grifton, North Carolina 28530',8779,10597);
INSERT INTO "django_geo_db_zipcode" VALUES(12066,28531,-5,'Harkers Island, North Carolina 28531',8780,10598);
INSERT INTO "django_geo_db_zipcode" VALUES(12067,28532,-5,'Havelock, North Carolina 28532',8781,10599);
INSERT INTO "django_geo_db_zipcode" VALUES(12068,28533,-5,'Cherry Point, North Carolina 28533',8782,10600);
INSERT INTO "django_geo_db_zipcode" VALUES(12069,28537,-5,'Hobucken, North Carolina 28537',8783,10601);
INSERT INTO "django_geo_db_zipcode" VALUES(12070,28538,-5,'Hookerton, North Carolina 28538',8784,10602);
INSERT INTO "django_geo_db_zipcode" VALUES(12071,28539,-5,'Hubert, North Carolina 28539',8785,10603);
INSERT INTO "django_geo_db_zipcode" VALUES(12072,28540,-5,'Jacksonville, North Carolina 28540',8786,10604);
INSERT INTO "django_geo_db_zipcode" VALUES(12073,28541,-5,'Jacksonville, North Carolina 28541',8786,10605);
INSERT INTO "django_geo_db_zipcode" VALUES(12074,28542,-5,'Camp Lejeune, North Carolina 28542',8787,10606);
INSERT INTO "django_geo_db_zipcode" VALUES(12075,28543,-5,'Tarawa Terrace, North Carolina 28543',8788,10607);
INSERT INTO "django_geo_db_zipcode" VALUES(12076,28544,-5,'Midway Park, North Carolina 28544',8789,10608);
INSERT INTO "django_geo_db_zipcode" VALUES(12077,28545,-5,'Mccutcheon Field, North Carolina 28545',8790,10605);
INSERT INTO "django_geo_db_zipcode" VALUES(12078,28546,-5,'Jacksonville, North Carolina 28546',8786,10609);
INSERT INTO "django_geo_db_zipcode" VALUES(12079,28547,-5,'Camp Lejeune, North Carolina 28547',8787,10610);
INSERT INTO "django_geo_db_zipcode" VALUES(12080,28551,-5,'La Grange, North Carolina 28551',8791,10611);
INSERT INTO "django_geo_db_zipcode" VALUES(12081,28552,-5,'Lowland, North Carolina 28552',8792,10612);
INSERT INTO "django_geo_db_zipcode" VALUES(12082,28553,-5,'Marshallberg, North Carolina 28553',8793,10613);
INSERT INTO "django_geo_db_zipcode" VALUES(12083,28554,-5,'Maury, North Carolina 28554',8794,10614);
INSERT INTO "django_geo_db_zipcode" VALUES(12084,28555,-5,'Maysville, North Carolina 28555',8795,10615);
INSERT INTO "django_geo_db_zipcode" VALUES(12085,28556,-5,'Merritt, North Carolina 28556',8796,10616);
INSERT INTO "django_geo_db_zipcode" VALUES(12086,28557,-5,'Morehead City, North Carolina 28557',8797,10617);
INSERT INTO "django_geo_db_zipcode" VALUES(12087,28559,-5,'Fairplains, North Carolina 28559',8798,10618);
INSERT INTO "django_geo_db_zipcode" VALUES(12088,28560,-5,'New Bern, North Carolina 28560',8799,10619);
INSERT INTO "django_geo_db_zipcode" VALUES(12089,28561,-5,'New Bern, North Carolina 28561',8799,10620);
INSERT INTO "django_geo_db_zipcode" VALUES(12090,28562,-5,'New Bern, North Carolina 28562',8799,10621);
INSERT INTO "django_geo_db_zipcode" VALUES(12091,28563,-5,'New Bern, North Carolina 28563',8799,10622);
INSERT INTO "django_geo_db_zipcode" VALUES(12092,28564,-5,'New Bern, North Carolina 28564',8799,10622);
INSERT INTO "django_geo_db_zipcode" VALUES(12093,28570,-5,'Newport, North Carolina 28570',8800,10623);
INSERT INTO "django_geo_db_zipcode" VALUES(12094,28571,-5,'Oriental, North Carolina 28571',8801,10624);
INSERT INTO "django_geo_db_zipcode" VALUES(12095,28572,-5,'Pink Hill, North Carolina 28572',8802,10625);
INSERT INTO "django_geo_db_zipcode" VALUES(12096,28573,-5,'Pollocksville, North Carolina 28573',8803,10626);
INSERT INTO "django_geo_db_zipcode" VALUES(12097,28574,-5,'Richlands, North Carolina 28574',8804,10627);
INSERT INTO "django_geo_db_zipcode" VALUES(12098,28575,-5,'Salter Path, North Carolina 28575',8805,10628);
INSERT INTO "django_geo_db_zipcode" VALUES(12099,28577,-5,'Sealevel, North Carolina 28577',8806,10629);
INSERT INTO "django_geo_db_zipcode" VALUES(12100,28578,-5,'Seven Springs, North Carolina 28578',8807,10630);
INSERT INTO "django_geo_db_zipcode" VALUES(12101,28579,-5,'Smyrna, North Carolina 28579',8808,10631);
INSERT INTO "django_geo_db_zipcode" VALUES(12102,28580,-5,'Snow Hill, North Carolina 28580',8809,10632);
INSERT INTO "django_geo_db_zipcode" VALUES(12103,28581,-5,'Stacy, North Carolina 28581',8810,10633);
INSERT INTO "django_geo_db_zipcode" VALUES(12104,28582,-5,'Stella, North Carolina 28582',8811,10634);
INSERT INTO "django_geo_db_zipcode" VALUES(12105,28583,-5,'Stonewall, North Carolina 28583',8812,10578);
INSERT INTO "django_geo_db_zipcode" VALUES(12106,28584,-5,'Swansboro, North Carolina 28584',8813,10635);
INSERT INTO "django_geo_db_zipcode" VALUES(12107,28585,-5,'Trenton, North Carolina 28585',8814,10636);
INSERT INTO "django_geo_db_zipcode" VALUES(12108,28586,-5,'Vanceboro, North Carolina 28586',8815,10637);
INSERT INTO "django_geo_db_zipcode" VALUES(12109,28587,-5,'Vandemere, North Carolina 28587',8816,10638);
INSERT INTO "django_geo_db_zipcode" VALUES(12110,28589,-5,'Williston, North Carolina 28589',8817,10639);
INSERT INTO "django_geo_db_zipcode" VALUES(12111,28590,-5,'Winterville, North Carolina 28590',8818,10640);
INSERT INTO "django_geo_db_zipcode" VALUES(12112,28594,-5,'Emerald Isle, North Carolina 28594',8819,10641);
INSERT INTO "django_geo_db_zipcode" VALUES(12113,28599,-5,'Emerald Isle, North Carolina 28599',8819,10642);
INSERT INTO "django_geo_db_zipcode" VALUES(12114,28601,-5,'Hickory, North Carolina 28601',8820,10643);
INSERT INTO "django_geo_db_zipcode" VALUES(12115,28602,-5,'Hickory, North Carolina 28602',8820,10644);
INSERT INTO "django_geo_db_zipcode" VALUES(12116,28603,-5,'Hickory, North Carolina 28603',8820,10645);
INSERT INTO "django_geo_db_zipcode" VALUES(12117,28604,-5,'Banner Elk, North Carolina 28604',8821,10646);
INSERT INTO "django_geo_db_zipcode" VALUES(12118,28605,-5,'Blowing Rock, North Carolina 28605',8822,10647);
INSERT INTO "django_geo_db_zipcode" VALUES(12119,28606,-5,'Boomer, North Carolina 28606',8823,10648);
INSERT INTO "django_geo_db_zipcode" VALUES(12120,28607,-5,'Boone, North Carolina 28607',8824,10649);
INSERT INTO "django_geo_db_zipcode" VALUES(12121,28608,-5,'Boone, North Carolina 28608',8824,10650);
INSERT INTO "django_geo_db_zipcode" VALUES(12122,28609,-5,'Catawba, North Carolina 28609',8825,10651);
INSERT INTO "django_geo_db_zipcode" VALUES(12123,28610,-5,'Claremont, North Carolina 28610',8826,10652);
INSERT INTO "django_geo_db_zipcode" VALUES(12124,28611,-5,'Collettsville, North Carolina 28611',8827,10653);
INSERT INTO "django_geo_db_zipcode" VALUES(12125,28612,-5,'Connellys Springs, North Carolina 28612',8828,10654);
INSERT INTO "django_geo_db_zipcode" VALUES(12126,28613,-5,'Conover, North Carolina 28613',8829,10655);
INSERT INTO "django_geo_db_zipcode" VALUES(12127,28615,-5,'Creston, North Carolina 28615',8830,10656);
INSERT INTO "django_geo_db_zipcode" VALUES(12128,28616,-5,'Crossnore, North Carolina 28616',8831,10657);
INSERT INTO "django_geo_db_zipcode" VALUES(12129,28617,-5,'Crumpler, North Carolina 28617',8832,10658);
INSERT INTO "django_geo_db_zipcode" VALUES(12130,28618,-5,'Deep Gap, North Carolina 28618',8833,10659);
INSERT INTO "django_geo_db_zipcode" VALUES(12131,28619,-5,'Drexel, North Carolina 28619',8834,10660);
INSERT INTO "django_geo_db_zipcode" VALUES(12132,28620,-5,'Pleasant Hill, North Carolina 28620',8461,10661);
INSERT INTO "django_geo_db_zipcode" VALUES(12133,28621,-5,'Elkin, North Carolina 28621',8835,10662);
INSERT INTO "django_geo_db_zipcode" VALUES(12134,28622,-5,'Elk Park, North Carolina 28622',8836,10663);
INSERT INTO "django_geo_db_zipcode" VALUES(12135,28623,-5,'Ennice, North Carolina 28623',8837,10664);
INSERT INTO "django_geo_db_zipcode" VALUES(12136,28624,-5,'Ferguson, North Carolina 28624',8838,10665);
INSERT INTO "django_geo_db_zipcode" VALUES(12137,28625,-5,'Statesville, North Carolina 28625',8839,10666);
INSERT INTO "django_geo_db_zipcode" VALUES(12138,28626,-5,'Fleetwood, North Carolina 28626',8840,10667);
INSERT INTO "django_geo_db_zipcode" VALUES(12139,28627,-5,'Glade Valley, North Carolina 28627',8841,10668);
INSERT INTO "django_geo_db_zipcode" VALUES(12140,28628,-5,'Glen Alpine, North Carolina 28628',8842,10669);
INSERT INTO "django_geo_db_zipcode" VALUES(12141,28629,-5,'Glendale Springs, North Carolina 28629',8843,10670);
INSERT INTO "django_geo_db_zipcode" VALUES(12142,28630,-5,'Granite Falls, North Carolina 28630',8844,10671);
INSERT INTO "django_geo_db_zipcode" VALUES(12143,28631,-5,'Grassy Creek, North Carolina 28631',8845,10672);
INSERT INTO "django_geo_db_zipcode" VALUES(12144,28633,-5,'Lenoir, North Carolina 28633',8846,10673);
INSERT INTO "django_geo_db_zipcode" VALUES(12145,28634,-5,'Harmony, North Carolina 28634',8847,10674);
INSERT INTO "django_geo_db_zipcode" VALUES(12146,28635,-5,'Hays, North Carolina 28635',8848,10675);
INSERT INTO "django_geo_db_zipcode" VALUES(12147,28636,-5,'Hiddenite, North Carolina 28636',8849,10676);
INSERT INTO "django_geo_db_zipcode" VALUES(12148,28637,-5,'Hildebran, North Carolina 28637',8850,10677);
INSERT INTO "django_geo_db_zipcode" VALUES(12149,28638,-5,'Hudson, North Carolina 28638',8851,10678);
INSERT INTO "django_geo_db_zipcode" VALUES(12150,28640,-5,'Jefferson, North Carolina 28640',8852,10679);
INSERT INTO "django_geo_db_zipcode" VALUES(12151,28641,-5,'Jonas Ridge, North Carolina 28641',8853,10680);
INSERT INTO "django_geo_db_zipcode" VALUES(12152,28642,-5,'Jonesville, North Carolina 28642',8854,10681);
INSERT INTO "django_geo_db_zipcode" VALUES(12153,28643,-5,'Lansing, North Carolina 28643',8855,10682);
INSERT INTO "django_geo_db_zipcode" VALUES(12154,28644,-5,'Laurel Springs, North Carolina 28644',8856,10683);
INSERT INTO "django_geo_db_zipcode" VALUES(12155,28645,-5,'Lenoir, North Carolina 28645',8846,10684);
INSERT INTO "django_geo_db_zipcode" VALUES(12156,28646,-5,'Linville, North Carolina 28646',8857,10685);
INSERT INTO "django_geo_db_zipcode" VALUES(12157,28647,-5,'Linville Falls, North Carolina 28647',8858,10686);
INSERT INTO "django_geo_db_zipcode" VALUES(12158,28649,-5,'McGrady, North Carolina 28649',8859,10687);
INSERT INTO "django_geo_db_zipcode" VALUES(12159,28650,-5,'Maiden, North Carolina 28650',8860,10688);
INSERT INTO "django_geo_db_zipcode" VALUES(12160,28651,-5,'Millers Creek, North Carolina 28651',8861,10689);
INSERT INTO "django_geo_db_zipcode" VALUES(12161,28652,-5,'Minneapolis, North Carolina 28652',8862,10690);
INSERT INTO "django_geo_db_zipcode" VALUES(12162,28653,-5,'Montezuma, North Carolina 28653',8863,10691);
INSERT INTO "django_geo_db_zipcode" VALUES(12163,28654,-5,'Moravian Falls, North Carolina 28654',8864,10692);
INSERT INTO "django_geo_db_zipcode" VALUES(12164,28655,-5,'Morganton, North Carolina 28655',8865,10693);
INSERT INTO "django_geo_db_zipcode" VALUES(12165,28656,-5,'North Wilkesboro, North Carolina 28656',8866,10694);
INSERT INTO "django_geo_db_zipcode" VALUES(12166,28657,-5,'Newland, North Carolina 28657',8867,10695);
INSERT INTO "django_geo_db_zipcode" VALUES(12167,28658,-5,'Newton, North Carolina 28658',8868,10696);
INSERT INTO "django_geo_db_zipcode" VALUES(12168,28659,-5,'North Wilkesboro, North Carolina 28659',8866,10697);
INSERT INTO "django_geo_db_zipcode" VALUES(12169,28660,-5,'Olin, North Carolina 28660',8869,10698);
INSERT INTO "django_geo_db_zipcode" VALUES(12170,28661,-5,'Patterson, North Carolina 28661',8870,10699);
INSERT INTO "django_geo_db_zipcode" VALUES(12171,28662,-5,'Pineola, North Carolina 28662',8871,10700);
INSERT INTO "django_geo_db_zipcode" VALUES(12172,28663,-5,'Piney Creek, North Carolina 28663',8872,10701);
INSERT INTO "django_geo_db_zipcode" VALUES(12173,28664,-5,'Plumtree, North Carolina 28664',8873,10702);
INSERT INTO "django_geo_db_zipcode" VALUES(12174,28665,-5,'Purlear, North Carolina 28665',8874,10703);
INSERT INTO "django_geo_db_zipcode" VALUES(12175,28666,-5,'Icard, North Carolina 28666',8875,10704);
INSERT INTO "django_geo_db_zipcode" VALUES(12176,28667,-5,'Rhodhiss, North Carolina 28667',8876,10705);
INSERT INTO "django_geo_db_zipcode" VALUES(12177,28668,-5,'Roaring Gap, North Carolina 28668',8877,10706);
INSERT INTO "django_geo_db_zipcode" VALUES(12178,28669,-5,'Roaring River, North Carolina 28669',8878,10707);
INSERT INTO "django_geo_db_zipcode" VALUES(12179,28670,-5,'Ronda, North Carolina 28670',8879,10708);
INSERT INTO "django_geo_db_zipcode" VALUES(12180,28671,-5,'Rutherford College, North Carolina 28671',8880,10709);
INSERT INTO "django_geo_db_zipcode" VALUES(12181,28672,-5,'Scottville, North Carolina 28672',8881,10710);
INSERT INTO "django_geo_db_zipcode" VALUES(12182,28673,-5,'Sherrills Ford, North Carolina 28673',8882,10711);
INSERT INTO "django_geo_db_zipcode" VALUES(12183,28674,-5,'North Wilkesboro, North Carolina 28674',8866,10712);
INSERT INTO "django_geo_db_zipcode" VALUES(12184,28675,-5,'Sparta, North Carolina 28675',8883,10713);
INSERT INTO "django_geo_db_zipcode" VALUES(12185,28676,-5,'State Road, North Carolina 28676',8884,10714);
INSERT INTO "django_geo_db_zipcode" VALUES(12186,28677,-5,'Statesville, North Carolina 28677',8839,10715);
INSERT INTO "django_geo_db_zipcode" VALUES(12187,28678,-5,'Stony Point, North Carolina 28678',8885,10716);
INSERT INTO "django_geo_db_zipcode" VALUES(12188,28679,-5,'Sugar Grove, North Carolina 28679',8886,10717);
INSERT INTO "django_geo_db_zipcode" VALUES(12189,28680,-5,'Morganton, North Carolina 28680',8865,10718);
INSERT INTO "django_geo_db_zipcode" VALUES(12190,28681,-5,'Taylorsville, North Carolina 28681',8887,10719);
INSERT INTO "django_geo_db_zipcode" VALUES(12191,28682,-5,'Terrell, North Carolina 28682',8888,10720);
INSERT INTO "django_geo_db_zipcode" VALUES(12192,28683,-5,'Thurmond, North Carolina 28683',8889,10721);
INSERT INTO "django_geo_db_zipcode" VALUES(12193,28684,-5,'Todd, North Carolina 28684',8890,10722);
INSERT INTO "django_geo_db_zipcode" VALUES(12194,28685,-5,'Traphill, North Carolina 28685',8891,10723);
INSERT INTO "django_geo_db_zipcode" VALUES(12195,28687,-5,'Statesville, North Carolina 28687',8839,10361);
INSERT INTO "django_geo_db_zipcode" VALUES(12196,28688,-5,'Turnersburg, North Carolina 28688',8892,10361);
INSERT INTO "django_geo_db_zipcode" VALUES(12197,28689,-5,'Union Grove, North Carolina 28689',8893,10724);
INSERT INTO "django_geo_db_zipcode" VALUES(12198,28690,-5,'Valdese, North Carolina 28690',8894,10725);
INSERT INTO "django_geo_db_zipcode" VALUES(12199,28691,-5,'Valle Crucis, North Carolina 28691',8895,10726);
INSERT INTO "django_geo_db_zipcode" VALUES(12200,28692,-5,'Vilas, North Carolina 28692',8896,10727);
INSERT INTO "django_geo_db_zipcode" VALUES(12201,28693,-5,'Warrensville, North Carolina 28693',8897,10728);
INSERT INTO "django_geo_db_zipcode" VALUES(12202,28694,-5,'West Jefferson, North Carolina 28694',8898,10729);
INSERT INTO "django_geo_db_zipcode" VALUES(12203,28697,-5,'Wilkesboro, North Carolina 28697',8899,10730);
INSERT INTO "django_geo_db_zipcode" VALUES(12204,28698,-5,'Zionville, North Carolina 28698',8900,10731);
INSERT INTO "django_geo_db_zipcode" VALUES(12205,28699,-5,'Scotts, North Carolina 28699',8901,10732);
INSERT INTO "django_geo_db_zipcode" VALUES(12206,28701,-5,'Alexander, North Carolina 28701',8902,10733);
INSERT INTO "django_geo_db_zipcode" VALUES(12207,28702,-5,'Almond, North Carolina 28702',8903,10734);
INSERT INTO "django_geo_db_zipcode" VALUES(12208,28704,-5,'Arden, North Carolina 28704',8904,10735);
INSERT INTO "django_geo_db_zipcode" VALUES(12209,28705,-5,'Bakersville, North Carolina 28705',8905,10736);
INSERT INTO "django_geo_db_zipcode" VALUES(12210,28707,-5,'Balsam, North Carolina 28707',8906,10737);
INSERT INTO "django_geo_db_zipcode" VALUES(12211,28708,-5,'Balsam Grove, North Carolina 28708',8907,10738);
INSERT INTO "django_geo_db_zipcode" VALUES(12212,28709,-5,'Barnardsville, North Carolina 28709',8908,10739);
INSERT INTO "django_geo_db_zipcode" VALUES(12213,28710,-5,'Bat Cave, North Carolina 28710',8909,10740);
INSERT INTO "django_geo_db_zipcode" VALUES(12214,28711,-5,'Black Mountain, North Carolina 28711',8910,10741);
INSERT INTO "django_geo_db_zipcode" VALUES(12215,28712,-5,'Brevard, North Carolina 28712',8911,10742);
INSERT INTO "django_geo_db_zipcode" VALUES(12216,28713,-5,'Bryson City, North Carolina 28713',8912,10743);
INSERT INTO "django_geo_db_zipcode" VALUES(12217,28714,-5,'Burnsville, North Carolina 28714',8913,10744);
INSERT INTO "django_geo_db_zipcode" VALUES(12218,28715,-5,'Candler, North Carolina 28715',8914,10745);
INSERT INTO "django_geo_db_zipcode" VALUES(12219,28716,-5,'Canton, North Carolina 28716',8915,10746);
INSERT INTO "django_geo_db_zipcode" VALUES(12220,28717,-5,'Cashiers, North Carolina 28717',8916,10747);
INSERT INTO "django_geo_db_zipcode" VALUES(12221,28718,-5,'Cedar Mountain, North Carolina 28718',8917,10748);
INSERT INTO "django_geo_db_zipcode" VALUES(12222,28719,-5,'Cherokee, North Carolina 28719',8918,10749);
INSERT INTO "django_geo_db_zipcode" VALUES(12223,28720,-5,'Chimney Rock, North Carolina 28720',8919,10750);
INSERT INTO "django_geo_db_zipcode" VALUES(12224,28721,-5,'Clyde, North Carolina 28721',8920,10751);
INSERT INTO "django_geo_db_zipcode" VALUES(12225,28722,-5,'Columbus, North Carolina 28722',8921,10752);
INSERT INTO "django_geo_db_zipcode" VALUES(12226,28723,-5,'Cullowhee, North Carolina 28723',8922,10753);
INSERT INTO "django_geo_db_zipcode" VALUES(12227,28724,-5,'Dana, North Carolina 28724',8923,10754);
INSERT INTO "django_geo_db_zipcode" VALUES(12228,28725,-5,'Dillsboro, North Carolina 28725',8924,10755);
INSERT INTO "django_geo_db_zipcode" VALUES(12229,28726,-5,'East Flat Rock, North Carolina 28726',8925,10756);
INSERT INTO "django_geo_db_zipcode" VALUES(12230,28727,-5,'Edneyville, North Carolina 28727',8926,10757);
INSERT INTO "django_geo_db_zipcode" VALUES(12231,28728,-5,'Enka, North Carolina 28728',8927,10758);
INSERT INTO "django_geo_db_zipcode" VALUES(12232,28729,-5,'Etowah, North Carolina 28729',8928,10759);
INSERT INTO "django_geo_db_zipcode" VALUES(12233,28730,-5,'Fairview, North Carolina 28730',8929,10760);
INSERT INTO "django_geo_db_zipcode" VALUES(12234,28731,-5,'Flat Rock, North Carolina 28731',8930,10761);
INSERT INTO "django_geo_db_zipcode" VALUES(12235,28732,-5,'Fletcher, North Carolina 28732',8931,10762);
INSERT INTO "django_geo_db_zipcode" VALUES(12236,28733,-5,'Fontana Dam, North Carolina 28733',8932,10763);
INSERT INTO "django_geo_db_zipcode" VALUES(12237,28734,-5,'Franklin, North Carolina 28734',8933,10764);
INSERT INTO "django_geo_db_zipcode" VALUES(12238,28735,-5,'Gerton, North Carolina 28735',8934,10765);
INSERT INTO "django_geo_db_zipcode" VALUES(12239,28736,-5,'Glenville, North Carolina 28736',8935,10766);
INSERT INTO "django_geo_db_zipcode" VALUES(12240,28737,-5,'Glenwood, North Carolina 28737',8936,10767);
INSERT INTO "django_geo_db_zipcode" VALUES(12241,28738,-5,'Hazelwood, North Carolina 28738',8937,10768);
INSERT INTO "django_geo_db_zipcode" VALUES(12242,28739,-5,'Hendersonville, North Carolina 28739',8938,10769);
INSERT INTO "django_geo_db_zipcode" VALUES(12243,28740,-5,'Greenmountain, North Carolina 28740',8939,10770);
INSERT INTO "django_geo_db_zipcode" VALUES(12244,28741,-5,'Highlands, North Carolina 28741',8940,10771);
INSERT INTO "django_geo_db_zipcode" VALUES(12245,28742,-5,'Horse Shoe, North Carolina 28742',8941,10772);
INSERT INTO "django_geo_db_zipcode" VALUES(12246,28743,-5,'Hot Springs, North Carolina 28743',8942,10773);
INSERT INTO "django_geo_db_zipcode" VALUES(12247,28744,-5,'Franklin, North Carolina 28744',8933,10774);
INSERT INTO "django_geo_db_zipcode" VALUES(12248,28745,-5,'Lake Junaluska, North Carolina 28745',8943,10775);
INSERT INTO "django_geo_db_zipcode" VALUES(12249,28746,-5,'Lake Lure, North Carolina 28746',8944,10776);
INSERT INTO "django_geo_db_zipcode" VALUES(12250,28747,-5,'Lake Toxaway, North Carolina 28747',8945,10777);
INSERT INTO "django_geo_db_zipcode" VALUES(12251,28748,-5,'Leicester, North Carolina 28748',8946,10778);
INSERT INTO "django_geo_db_zipcode" VALUES(12252,28749,-5,'Little Switzerland, North Carolina 28749',8947,10779);
INSERT INTO "django_geo_db_zipcode" VALUES(12253,28750,-5,'Lynn, North Carolina 28750',8948,10780);
INSERT INTO "django_geo_db_zipcode" VALUES(12254,28751,-5,'Maggie Valley, North Carolina 28751',8949,10781);
INSERT INTO "django_geo_db_zipcode" VALUES(12255,28752,-5,'Marion, North Carolina 28752',8950,10782);
INSERT INTO "django_geo_db_zipcode" VALUES(12256,28753,-5,'Marshall, North Carolina 28753',8951,10783);
INSERT INTO "django_geo_db_zipcode" VALUES(12257,28754,-5,'Mars Hill, North Carolina 28754',8952,10784);
INSERT INTO "django_geo_db_zipcode" VALUES(12258,28755,-5,'Micaville, North Carolina 28755',8953,10785);
INSERT INTO "django_geo_db_zipcode" VALUES(12259,28756,-5,'Mill Spring, North Carolina 28756',8954,10786);
INSERT INTO "django_geo_db_zipcode" VALUES(12260,28757,-5,'Montreat, North Carolina 28757',8955,10787);
INSERT INTO "django_geo_db_zipcode" VALUES(12261,28758,-5,'Mountain Home, North Carolina 28758',8956,10788);
INSERT INTO "django_geo_db_zipcode" VALUES(12262,28760,-5,'Naples, North Carolina 28760',8957,10789);
INSERT INTO "django_geo_db_zipcode" VALUES(12263,28761,-5,'Nebo, North Carolina 28761',8958,10790);
INSERT INTO "django_geo_db_zipcode" VALUES(12264,28762,-5,'Old Fort, North Carolina 28762',8959,10791);
INSERT INTO "django_geo_db_zipcode" VALUES(12265,28763,-5,'Otto, North Carolina 28763',8960,10792);
INSERT INTO "django_geo_db_zipcode" VALUES(12266,28765,-5,'Penland, North Carolina 28765',8961,10793);
INSERT INTO "django_geo_db_zipcode" VALUES(12267,28766,-5,'Penrose, North Carolina 28766',8962,10794);
INSERT INTO "django_geo_db_zipcode" VALUES(12268,28767,-5,'Old Fort, North Carolina 28767',8959,10795);
INSERT INTO "django_geo_db_zipcode" VALUES(12269,28768,-5,'Pisgah Forest, North Carolina 28768',8963,10796);
INSERT INTO "django_geo_db_zipcode" VALUES(12270,28770,-5,'Ridgecrest, North Carolina 28770',8964,10797);
INSERT INTO "django_geo_db_zipcode" VALUES(12271,28771,-5,'Robbinsville, North Carolina 28771',8965,10798);
INSERT INTO "django_geo_db_zipcode" VALUES(12272,28772,-5,'Rosman, North Carolina 28772',8966,10799);
INSERT INTO "django_geo_db_zipcode" VALUES(12273,28773,-5,'Saluda, North Carolina 28773',8967,10800);
INSERT INTO "django_geo_db_zipcode" VALUES(12274,28774,-5,'Sapphire, North Carolina 28774',8968,10801);
INSERT INTO "django_geo_db_zipcode" VALUES(12275,28775,-5,'Scaly Mountain, North Carolina 28775',8969,10802);
INSERT INTO "django_geo_db_zipcode" VALUES(12276,28776,-5,'Skyland, North Carolina 28776',8970,10803);
INSERT INTO "django_geo_db_zipcode" VALUES(12277,28777,-5,'Spruce Pine, North Carolina 28777',8971,10804);
INSERT INTO "django_geo_db_zipcode" VALUES(12278,28778,-5,'Swannanoa, North Carolina 28778',8972,10805);
INSERT INTO "django_geo_db_zipcode" VALUES(12279,28779,-5,'Sylva, North Carolina 28779',8973,10806);
INSERT INTO "django_geo_db_zipcode" VALUES(12280,28781,-5,'Topton, North Carolina 28781',8974,10807);
INSERT INTO "django_geo_db_zipcode" VALUES(12281,28782,-5,'Tryon, North Carolina 28782',8975,10808);
INSERT INTO "django_geo_db_zipcode" VALUES(12282,28783,-5,'Tuckasegee, North Carolina 28783',8976,10809);
INSERT INTO "django_geo_db_zipcode" VALUES(12283,28784,-5,'Tuxedo, North Carolina 28784',8977,10810);
INSERT INTO "django_geo_db_zipcode" VALUES(12284,28785,-5,'Maggie Valley, North Carolina 28785',8949,10811);
INSERT INTO "django_geo_db_zipcode" VALUES(12285,28786,-5,'Waynesville, North Carolina 28786',8978,10812);
INSERT INTO "django_geo_db_zipcode" VALUES(12286,28787,-5,'Weaverville, North Carolina 28787',8979,10813);
INSERT INTO "django_geo_db_zipcode" VALUES(12287,28788,-5,'Webster, North Carolina 28788',8980,10814);
INSERT INTO "django_geo_db_zipcode" VALUES(12288,28789,-5,'Whittier, North Carolina 28789',8981,10815);
INSERT INTO "django_geo_db_zipcode" VALUES(12289,28790,-5,'Zirconia, North Carolina 28790',8982,10816);
INSERT INTO "django_geo_db_zipcode" VALUES(12290,28791,-5,'Hendersonville, North Carolina 28791',8938,10817);
INSERT INTO "django_geo_db_zipcode" VALUES(12291,28792,-5,'Hendersonville, North Carolina 28792',8938,10818);
INSERT INTO "django_geo_db_zipcode" VALUES(12292,28793,-5,'Hendersonville, North Carolina 28793',8938,10819);
INSERT INTO "django_geo_db_zipcode" VALUES(12293,28796,-5,'East Flat Rock, North Carolina 28796',8925,10820);
INSERT INTO "django_geo_db_zipcode" VALUES(12294,28800,-5,'Asheville, North Carolina 28800',8983,10821);
INSERT INTO "django_geo_db_zipcode" VALUES(12295,28801,-5,'Asheville, North Carolina 28801',8983,10822);
INSERT INTO "django_geo_db_zipcode" VALUES(12296,28802,-5,'Asheville, North Carolina 28802',8983,10823);
INSERT INTO "django_geo_db_zipcode" VALUES(12297,28803,-5,'Asheville, North Carolina 28803',8983,10824);
INSERT INTO "django_geo_db_zipcode" VALUES(12298,28804,-5,'Asheville, North Carolina 28804',8983,10825);
INSERT INTO "django_geo_db_zipcode" VALUES(12299,28805,-5,'Asheville, North Carolina 28805',8983,10826);
INSERT INTO "django_geo_db_zipcode" VALUES(12300,28806,-5,'Asheville, North Carolina 28806',8983,10827);
INSERT INTO "django_geo_db_zipcode" VALUES(12301,28808,-5,'Asheville, North Carolina 28808',8983,10828);
INSERT INTO "django_geo_db_zipcode" VALUES(12302,28810,-5,'Asheville, North Carolina 28810',8983,10829);
INSERT INTO "django_geo_db_zipcode" VALUES(12303,28813,-5,'Asheville, North Carolina 28813',8983,10830);
INSERT INTO "django_geo_db_zipcode" VALUES(12304,28814,-5,'Asheville, North Carolina 28814',8983,10831);
INSERT INTO "django_geo_db_zipcode" VALUES(12305,28815,-5,'Asheville, North Carolina 28815',8983,10829);
INSERT INTO "django_geo_db_zipcode" VALUES(12306,28816,-5,'Asheville, North Carolina 28816',8983,10829);
INSERT INTO "django_geo_db_zipcode" VALUES(12307,28818,-5,'Beulaville, North Carolina 28818',8767,10832);
INSERT INTO "django_geo_db_zipcode" VALUES(12308,28849,-5,'Wrightsboro, North Carolina 28849',8984,10833);
INSERT INTO "django_geo_db_zipcode" VALUES(12309,28894,-5,'Vass, North Carolina 28894',8700,10834);
INSERT INTO "django_geo_db_zipcode" VALUES(12310,28901,-5,'Andrews, North Carolina 28901',8985,10835);
INSERT INTO "django_geo_db_zipcode" VALUES(12311,28902,-5,'Brasstown, North Carolina 28902',8986,10836);
INSERT INTO "django_geo_db_zipcode" VALUES(12312,28903,-5,'Culberson, North Carolina 28903',8987,10837);
INSERT INTO "django_geo_db_zipcode" VALUES(12313,28904,-5,'Hayesville, North Carolina 28904',8988,10838);
INSERT INTO "django_geo_db_zipcode" VALUES(12314,28905,-5,'Marble, North Carolina 28905',8989,10839);
INSERT INTO "django_geo_db_zipcode" VALUES(12315,28906,-5,'Murphy, North Carolina 28906',8990,10840);
INSERT INTO "django_geo_db_zipcode" VALUES(12316,28909,-5,'Warne, North Carolina 28909',8991,10841);
INSERT INTO "django_geo_db_zipcode" VALUES(12317,28950,-5,'Winterville, North Carolina 28950',8818,10842);
INSERT INTO "django_geo_db_zipcode" VALUES(12318,28954,-5,'Emerald Isle, North Carolina 28954',8819,10843);
INSERT INTO "django_geo_db_zipcode" VALUES(12319,28971,-5,'Hendersonville, North Carolina 28971',8938,10844);
INSERT INTO "django_geo_db_zipcode" VALUES(12320,28972,-5,'Hendersonville, North Carolina 28972',8938,10845);
INSERT INTO "django_geo_db_zipcode" VALUES(12321,29001,-5,'Alcolu, South Carolina 29001',8992,10846);
INSERT INTO "django_geo_db_zipcode" VALUES(12322,29002,-5,'Ballentine, South Carolina 29002',8993,10847);
INSERT INTO "django_geo_db_zipcode" VALUES(12323,29003,-5,'Bamberg, South Carolina 29003',8994,10848);
INSERT INTO "django_geo_db_zipcode" VALUES(12324,29006,-5,'Batesburg, South Carolina 29006',8995,10849);
INSERT INTO "django_geo_db_zipcode" VALUES(12325,29009,-5,'Bethune, South Carolina 29009',8996,10850);
INSERT INTO "django_geo_db_zipcode" VALUES(12326,29010,-5,'Bishopville, South Carolina 29010',8997,10851);
INSERT INTO "django_geo_db_zipcode" VALUES(12327,29014,-5,'Blackstock, South Carolina 29014',8998,10852);
INSERT INTO "django_geo_db_zipcode" VALUES(12328,29015,-5,'Blair, South Carolina 29015',8999,10853);
INSERT INTO "django_geo_db_zipcode" VALUES(12329,29016,-5,'Blythewood, South Carolina 29016',9000,10854);
INSERT INTO "django_geo_db_zipcode" VALUES(12330,29018,-5,'Bowman, South Carolina 29018',9001,10855);
INSERT INTO "django_geo_db_zipcode" VALUES(12331,29020,-5,'Camden, South Carolina 29020',9002,10856);
INSERT INTO "django_geo_db_zipcode" VALUES(12332,29030,-5,'Cameron, South Carolina 29030',9003,10857);
INSERT INTO "django_geo_db_zipcode" VALUES(12333,29031,-5,'Carlisle, South Carolina 29031',9004,10858);
INSERT INTO "django_geo_db_zipcode" VALUES(12334,29032,-5,'Cassatt, South Carolina 29032',9005,10859);
INSERT INTO "django_geo_db_zipcode" VALUES(12335,29033,-5,'Cayce, South Carolina 29033',9006,10860);
INSERT INTO "django_geo_db_zipcode" VALUES(12336,29036,-5,'Chapin, South Carolina 29036',9007,10861);
INSERT INTO "django_geo_db_zipcode" VALUES(12337,29037,-5,'Chappells, South Carolina 29037',9008,10862);
INSERT INTO "django_geo_db_zipcode" VALUES(12338,29038,-5,'Cope, South Carolina 29038',9009,10863);
INSERT INTO "django_geo_db_zipcode" VALUES(12339,29039,-5,'Cordova, South Carolina 29039',9010,10864);
INSERT INTO "django_geo_db_zipcode" VALUES(12340,29040,-5,'Dalzell, South Carolina 29040',9011,10865);
INSERT INTO "django_geo_db_zipcode" VALUES(12341,29041,-5,'Davis Station, South Carolina 29041',9012,10866);
INSERT INTO "django_geo_db_zipcode" VALUES(12342,29042,-5,'Denmark, South Carolina 29042',9013,10867);
INSERT INTO "django_geo_db_zipcode" VALUES(12343,29044,-5,'Eastover, South Carolina 29044',9014,10868);
INSERT INTO "django_geo_db_zipcode" VALUES(12344,29045,-5,'Elgin, South Carolina 29045',9015,10869);
INSERT INTO "django_geo_db_zipcode" VALUES(12345,29046,-5,'Elliott, South Carolina 29046',9016,10870);
INSERT INTO "django_geo_db_zipcode" VALUES(12346,29047,-5,'Elloree, South Carolina 29047',9017,10871);
INSERT INTO "django_geo_db_zipcode" VALUES(12347,29048,-5,'Eutawville, South Carolina 29048',9018,10872);
INSERT INTO "django_geo_db_zipcode" VALUES(12348,29051,-5,'Gable, South Carolina 29051',9019,10873);
INSERT INTO "django_geo_db_zipcode" VALUES(12349,29052,-5,'Gadsden, South Carolina 29052',9020,10874);
INSERT INTO "django_geo_db_zipcode" VALUES(12350,29053,-5,'Gaston, South Carolina 29053',9021,10875);
INSERT INTO "django_geo_db_zipcode" VALUES(12351,29054,-5,'Gilbert, South Carolina 29054',9022,10876);
INSERT INTO "django_geo_db_zipcode" VALUES(12352,29055,-5,'Great Falls, South Carolina 29055',9023,10877);
INSERT INTO "django_geo_db_zipcode" VALUES(12353,29056,-5,'Greeleyville, South Carolina 29056',9024,10878);
INSERT INTO "django_geo_db_zipcode" VALUES(12354,29058,-5,'Heath Springs, South Carolina 29058',9025,10879);
INSERT INTO "django_geo_db_zipcode" VALUES(12355,29059,-5,'Holly Hill, South Carolina 29059',9026,10880);
INSERT INTO "django_geo_db_zipcode" VALUES(12356,29061,-5,'Hopkins, South Carolina 29061',9027,10881);
INSERT INTO "django_geo_db_zipcode" VALUES(12357,29062,-5,'Horatio, South Carolina 29062',9028,10882);
INSERT INTO "django_geo_db_zipcode" VALUES(12358,29063,-5,'Irmo, South Carolina 29063',9029,10883);
INSERT INTO "django_geo_db_zipcode" VALUES(12359,29065,-5,'Jenkinsville, South Carolina 29065',9030,10884);
INSERT INTO "django_geo_db_zipcode" VALUES(12360,29066,-5,'Batesburg-Leesville, South Carolina 29066',9031,10885);
INSERT INTO "django_geo_db_zipcode" VALUES(12361,29067,-5,'Kershaw, South Carolina 29067',9032,10886);
INSERT INTO "django_geo_db_zipcode" VALUES(12362,29069,-5,'Lamar, South Carolina 29069',9033,10887);
INSERT INTO "django_geo_db_zipcode" VALUES(12363,29070,-5,'Leesville, South Carolina 29070',9034,10888);
INSERT INTO "django_geo_db_zipcode" VALUES(12364,29071,-5,'Lexington, South Carolina 29071',9035,10889);
INSERT INTO "django_geo_db_zipcode" VALUES(12365,29072,-5,'Lexington, South Carolina 29072',9035,10890);
INSERT INTO "django_geo_db_zipcode" VALUES(12366,29073,-5,'Lexington, South Carolina 29073',9035,10891);
INSERT INTO "django_geo_db_zipcode" VALUES(12367,29074,-5,'Liberty Hill, South Carolina 29074',9036,10892);
INSERT INTO "django_geo_db_zipcode" VALUES(12368,29075,-5,'Little Mountain, South Carolina 29075',9037,10893);
INSERT INTO "django_geo_db_zipcode" VALUES(12369,29078,-5,'Lugoff, South Carolina 29078',9038,10894);
INSERT INTO "django_geo_db_zipcode" VALUES(12370,29079,-5,'Lydia, South Carolina 29079',9039,10895);
INSERT INTO "django_geo_db_zipcode" VALUES(12371,29080,-5,'Lynchburg, South Carolina 29080',9040,10896);
INSERT INTO "django_geo_db_zipcode" VALUES(12372,29081,-5,'Ehrhardt, South Carolina 29081',9041,10897);
INSERT INTO "django_geo_db_zipcode" VALUES(12373,29082,-5,'Lodge, South Carolina 29082',9042,10898);
INSERT INTO "django_geo_db_zipcode" VALUES(12374,29101,-5,'McBee, South Carolina 29101',9043,10899);
INSERT INTO "django_geo_db_zipcode" VALUES(12375,29102,-5,'Manning, South Carolina 29102',9044,10900);
INSERT INTO "django_geo_db_zipcode" VALUES(12376,29103,-5,'Mayesville, South Carolina 29103',9045,10901);
INSERT INTO "django_geo_db_zipcode" VALUES(12377,29104,-5,'Mayesville, South Carolina 29104',9045,10902);
INSERT INTO "django_geo_db_zipcode" VALUES(12378,29105,-5,'Monetta, South Carolina 29105',9046,10903);
INSERT INTO "django_geo_db_zipcode" VALUES(12379,29106,-5,'Monticello, South Carolina 29106',9047,10904);
INSERT INTO "django_geo_db_zipcode" VALUES(12380,29107,-5,'Neeses, South Carolina 29107',9048,10905);
INSERT INTO "django_geo_db_zipcode" VALUES(12381,29108,-5,'Newberry, South Carolina 29108',9049,10906);
INSERT INTO "django_geo_db_zipcode" VALUES(12382,29111,-5,'New Zion, South Carolina 29111',9050,10907);
INSERT INTO "django_geo_db_zipcode" VALUES(12383,29112,-5,'North, South Carolina 29112',9051,10908);
INSERT INTO "django_geo_db_zipcode" VALUES(12384,29113,-5,'Norway, South Carolina 29113',9052,10909);
INSERT INTO "django_geo_db_zipcode" VALUES(12385,29114,-5,'Olanta, South Carolina 29114',9053,10910);
INSERT INTO "django_geo_db_zipcode" VALUES(12386,29115,-5,'Orangeburg, South Carolina 29115',9054,10911);
INSERT INTO "django_geo_db_zipcode" VALUES(12387,29116,-5,'Orangeburg, South Carolina 29116',9054,10912);
INSERT INTO "django_geo_db_zipcode" VALUES(12388,29117,-5,'Orangeburg, South Carolina 29117',9054,10913);
INSERT INTO "django_geo_db_zipcode" VALUES(12389,29118,-5,'Orangeburg, South Carolina 29118',9054,10914);
INSERT INTO "django_geo_db_zipcode" VALUES(12390,29122,-5,'Peak, South Carolina 29122',9055,10915);
INSERT INTO "django_geo_db_zipcode" VALUES(12391,29123,-5,'Pelion, South Carolina 29123',9056,10916);
INSERT INTO "django_geo_db_zipcode" VALUES(12392,29124,-5,'Perry, South Carolina 29124',9057,10917);
INSERT INTO "django_geo_db_zipcode" VALUES(12393,29125,-5,'Pinewood, South Carolina 29125',9058,10918);
INSERT INTO "django_geo_db_zipcode" VALUES(12394,29126,-5,'Pomaria, South Carolina 29126',9059,10919);
INSERT INTO "django_geo_db_zipcode" VALUES(12395,29127,-5,'Prosperity, South Carolina 29127',9060,10920);
INSERT INTO "django_geo_db_zipcode" VALUES(12396,29128,-5,'Rembert, South Carolina 29128',9061,10921);
INSERT INTO "django_geo_db_zipcode" VALUES(12397,29129,-5,'Ridge Spring, South Carolina 29129',9062,10922);
INSERT INTO "django_geo_db_zipcode" VALUES(12398,29130,-5,'Ridgeway, South Carolina 29130',9063,10923);
INSERT INTO "django_geo_db_zipcode" VALUES(12399,29132,-5,'Rion, South Carolina 29132',9064,10924);
INSERT INTO "django_geo_db_zipcode" VALUES(12400,29133,-5,'Rowesville, South Carolina 29133',9065,10925);
INSERT INTO "django_geo_db_zipcode" VALUES(12401,29135,-5,'Saint Matthews, South Carolina 29135',9066,10926);
INSERT INTO "django_geo_db_zipcode" VALUES(12402,29137,-5,'Salley, South Carolina 29137',9067,10927);
INSERT INTO "django_geo_db_zipcode" VALUES(12403,29138,-5,'Saluda, South Carolina 29138',9068,10928);
INSERT INTO "django_geo_db_zipcode" VALUES(12404,29142,-5,'Santee, South Carolina 29142',9069,10929);
INSERT INTO "django_geo_db_zipcode" VALUES(12405,29143,-5,'Sardinia, South Carolina 29143',9070,10866);
INSERT INTO "django_geo_db_zipcode" VALUES(12406,29145,-5,'Silverstreet, South Carolina 29145',9071,10930);
INSERT INTO "django_geo_db_zipcode" VALUES(12407,29146,-5,'Springfield, South Carolina 29146',9072,10931);
INSERT INTO "django_geo_db_zipcode" VALUES(12408,29147,-5,'State Park, South Carolina 29147',9073,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12409,29148,-5,'Summerton, South Carolina 29148',9074,10933);
INSERT INTO "django_geo_db_zipcode" VALUES(12410,29150,-5,'Sumter, South Carolina 29150',9075,10934);
INSERT INTO "django_geo_db_zipcode" VALUES(12411,29151,-5,'Sumter, South Carolina 29151',9075,10935);
INSERT INTO "django_geo_db_zipcode" VALUES(12412,29152,-5,'Shaw A F B, South Carolina 29152',9076,10936);
INSERT INTO "django_geo_db_zipcode" VALUES(12413,29153,-5,'Sumter, South Carolina 29153',9075,10937);
INSERT INTO "django_geo_db_zipcode" VALUES(12414,29154,-5,'Sumter, South Carolina 29154',9075,10938);
INSERT INTO "django_geo_db_zipcode" VALUES(12415,29160,-5,'Swansea, South Carolina 29160',9077,10939);
INSERT INTO "django_geo_db_zipcode" VALUES(12416,29161,-5,'Timmonsville, South Carolina 29161',9078,10940);
INSERT INTO "django_geo_db_zipcode" VALUES(12417,29162,-5,'Turbeville, South Carolina 29162',9079,10941);
INSERT INTO "django_geo_db_zipcode" VALUES(12418,29163,-5,'Vance, South Carolina 29163',9080,10942);
INSERT INTO "django_geo_db_zipcode" VALUES(12419,29164,-5,'Wagener, South Carolina 29164',9081,10943);
INSERT INTO "django_geo_db_zipcode" VALUES(12420,29166,-5,'Ward, South Carolina 29166',9082,10944);
INSERT INTO "django_geo_db_zipcode" VALUES(12421,29168,-5,'Wedgefield, South Carolina 29168',9083,10945);
INSERT INTO "django_geo_db_zipcode" VALUES(12422,29169,-5,'West Columbia, South Carolina 29169',9084,10946);
INSERT INTO "django_geo_db_zipcode" VALUES(12423,29170,-5,'West Columbia, South Carolina 29170',9084,10947);
INSERT INTO "django_geo_db_zipcode" VALUES(12424,29171,-5,'West Columbia, South Carolina 29171',9084,10889);
INSERT INTO "django_geo_db_zipcode" VALUES(12425,29172,-5,'West Columbia, South Carolina 29172',9084,10948);
INSERT INTO "django_geo_db_zipcode" VALUES(12426,29175,-5,'Westville, South Carolina 29175',9085,10949);
INSERT INTO "django_geo_db_zipcode" VALUES(12427,29176,-5,'White Oak, South Carolina 29176',9086,10904);
INSERT INTO "django_geo_db_zipcode" VALUES(12428,29177,-5,'White Rock, South Carolina 29177',9087,10950);
INSERT INTO "django_geo_db_zipcode" VALUES(12429,29178,-5,'Whitmire, South Carolina 29178',9088,10951);
INSERT INTO "django_geo_db_zipcode" VALUES(12430,29180,-5,'Winnsboro, South Carolina 29180',9089,10952);
INSERT INTO "django_geo_db_zipcode" VALUES(12431,29201,-5,'Columbia, South Carolina 29201',9090,10953);
INSERT INTO "django_geo_db_zipcode" VALUES(12432,29202,-5,'Columbia, South Carolina 29202',9090,10954);
INSERT INTO "django_geo_db_zipcode" VALUES(12433,29203,-5,'Columbia, South Carolina 29203',9090,10955);
INSERT INTO "django_geo_db_zipcode" VALUES(12434,29204,-5,'Columbia, South Carolina 29204',9090,10956);
INSERT INTO "django_geo_db_zipcode" VALUES(12435,29205,-5,'Columbia, South Carolina 29205',9090,10957);
INSERT INTO "django_geo_db_zipcode" VALUES(12436,29206,-5,'Columbia, South Carolina 29206',9090,10958);
INSERT INTO "django_geo_db_zipcode" VALUES(12437,29207,-5,'Columbia, South Carolina 29207',9090,10959);
INSERT INTO "django_geo_db_zipcode" VALUES(12438,29208,-5,'Columbia, South Carolina 29208',9090,10960);
INSERT INTO "django_geo_db_zipcode" VALUES(12439,29209,-5,'Columbia, South Carolina 29209',9090,10961);
INSERT INTO "django_geo_db_zipcode" VALUES(12440,29210,-5,'Columbia, South Carolina 29210',9090,10962);
INSERT INTO "django_geo_db_zipcode" VALUES(12441,29211,-5,'Columbia, South Carolina 29211',9090,10963);
INSERT INTO "django_geo_db_zipcode" VALUES(12442,29212,-5,'Columbia, South Carolina 29212',9090,10964);
INSERT INTO "django_geo_db_zipcode" VALUES(12443,29214,-5,'Columbia, South Carolina 29214',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12444,29215,-5,'Columbia, South Carolina 29215',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12445,29216,-5,'Columbia, South Carolina 29216',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12446,29217,-5,'Columbia, South Carolina 29217',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12447,29218,-5,'Columbia, South Carolina 29218',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12448,29219,-5,'Columbia, South Carolina 29219',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12449,29220,-5,'Columbia, South Carolina 29220',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12450,29221,-5,'Columbia, South Carolina 29221',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12451,29222,-5,'Columbia, South Carolina 29222',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12452,29223,-5,'Columbia, South Carolina 29223',9090,10965);
INSERT INTO "django_geo_db_zipcode" VALUES(12453,29224,-5,'Columbia, South Carolina 29224',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12454,29225,-5,'Columbia, South Carolina 29225',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12455,29226,-5,'Columbia, South Carolina 29226',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12456,29227,-5,'Columbia, South Carolina 29227',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12457,29228,-5,'Columbia, South Carolina 29228',9090,10889);
INSERT INTO "django_geo_db_zipcode" VALUES(12458,29229,-5,'Columbia, South Carolina 29229',9090,10966);
INSERT INTO "django_geo_db_zipcode" VALUES(12459,29230,-5,'Columbia, South Carolina 29230',9090,10967);
INSERT INTO "django_geo_db_zipcode" VALUES(12460,29233,-5,'Columbia, South Carolina 29233',9090,10968);
INSERT INTO "django_geo_db_zipcode" VALUES(12461,29235,-5,'Clinton, South Carolina 29235',9091,10969);
INSERT INTO "django_geo_db_zipcode" VALUES(12462,29240,-5,'Columbia, South Carolina 29240',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12463,29250,-5,'Columbia, South Carolina 29250',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12464,29260,-5,'Columbia, South Carolina 29260',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12465,29290,-5,'Columbia, South Carolina 29290',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12466,29292,-5,'Columbia, South Carolina 29292',9090,10932);
INSERT INTO "django_geo_db_zipcode" VALUES(12467,29301,-5,'Spartanburg, South Carolina 29301',9092,10970);
INSERT INTO "django_geo_db_zipcode" VALUES(12468,29302,-5,'Spartanburg, South Carolina 29302',9092,10971);
INSERT INTO "django_geo_db_zipcode" VALUES(12469,29303,-5,'Spartanburg, South Carolina 29303',9092,10972);
INSERT INTO "django_geo_db_zipcode" VALUES(12470,29304,-5,'Spartanburg, South Carolina 29304',9092,10973);
INSERT INTO "django_geo_db_zipcode" VALUES(12471,29305,-5,'Spartanburg, South Carolina 29305',9092,10974);
INSERT INTO "django_geo_db_zipcode" VALUES(12472,29306,-5,'Spartanburg, South Carolina 29306',9092,10975);
INSERT INTO "django_geo_db_zipcode" VALUES(12473,29307,-5,'Spartanburg, South Carolina 29307',9092,10976);
INSERT INTO "django_geo_db_zipcode" VALUES(12474,29316,-5,'Spartanburg, South Carolina 29316',9092,10977);
INSERT INTO "django_geo_db_zipcode" VALUES(12475,29318,-5,'Spartanburg, South Carolina 29318',9092,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12476,29319,-5,'Spartanburg, South Carolina 29319',9092,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12477,29320,-5,'Arcadia, South Carolina 29320',9093,10979);
INSERT INTO "django_geo_db_zipcode" VALUES(12478,29321,-5,'Buffalo, South Carolina 29321',9094,10980);
INSERT INTO "django_geo_db_zipcode" VALUES(12479,29322,-5,'Campobello, South Carolina 29322',9095,10981);
INSERT INTO "django_geo_db_zipcode" VALUES(12480,29323,-5,'Chesnee, South Carolina 29323',9096,10982);
INSERT INTO "django_geo_db_zipcode" VALUES(12481,29324,-5,'Clifton, South Carolina 29324',9097,10983);
INSERT INTO "django_geo_db_zipcode" VALUES(12482,29325,-5,'Clinton, South Carolina 29325',9091,10984);
INSERT INTO "django_geo_db_zipcode" VALUES(12483,29329,-5,'Converse, South Carolina 29329',9098,10985);
INSERT INTO "django_geo_db_zipcode" VALUES(12484,29330,-5,'Cowpens, South Carolina 29330',9099,10986);
INSERT INTO "django_geo_db_zipcode" VALUES(12485,29331,-5,'Cross Anchor, South Carolina 29331',9100,10987);
INSERT INTO "django_geo_db_zipcode" VALUES(12486,29332,-5,'Cross Hill, South Carolina 29332',9101,10988);
INSERT INTO "django_geo_db_zipcode" VALUES(12487,29333,-5,'Drayton, South Carolina 29333',9102,10989);
INSERT INTO "django_geo_db_zipcode" VALUES(12488,29334,-5,'Duncan, South Carolina 29334',9103,10990);
INSERT INTO "django_geo_db_zipcode" VALUES(12489,29335,-5,'Enoree, South Carolina 29335',9104,10991);
INSERT INTO "django_geo_db_zipcode" VALUES(12490,29336,-5,'Fairforest, South Carolina 29336',9105,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12491,29338,-5,'Fingerville, South Carolina 29338',9106,10992);
INSERT INTO "django_geo_db_zipcode" VALUES(12492,29340,-5,'Gaffney, South Carolina 29340',9107,10993);
INSERT INTO "django_geo_db_zipcode" VALUES(12493,29341,-5,'Gaffney, South Carolina 29341',9107,10994);
INSERT INTO "django_geo_db_zipcode" VALUES(12494,29342,-5,'Gaffney, South Carolina 29342',9107,10995);
INSERT INTO "django_geo_db_zipcode" VALUES(12495,29346,-5,'Glendale, South Carolina 29346',9108,10996);
INSERT INTO "django_geo_db_zipcode" VALUES(12496,29348,-5,'Gramling, South Carolina 29348',9109,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12497,29349,-5,'Inman, South Carolina 29349',9110,10997);
INSERT INTO "django_geo_db_zipcode" VALUES(12498,29351,-5,'Joanna, South Carolina 29351',9111,10998);
INSERT INTO "django_geo_db_zipcode" VALUES(12499,29353,-5,'Jonesville, South Carolina 29353',9112,10999);
INSERT INTO "django_geo_db_zipcode" VALUES(12500,29355,-5,'Kinards, South Carolina 29355',9113,11000);
INSERT INTO "django_geo_db_zipcode" VALUES(12501,29356,-5,'Landrum, South Carolina 29356',9114,11001);
INSERT INTO "django_geo_db_zipcode" VALUES(12502,29360,-5,'Laurens, South Carolina 29360',9115,11002);
INSERT INTO "django_geo_db_zipcode" VALUES(12503,29363,-5,'Lake View, South Carolina 29363',9116,11003);
INSERT INTO "django_geo_db_zipcode" VALUES(12504,29364,-5,'Lockhart, South Carolina 29364',9117,11004);
INSERT INTO "django_geo_db_zipcode" VALUES(12505,29365,-5,'Lyman, South Carolina 29365',9118,11005);
INSERT INTO "django_geo_db_zipcode" VALUES(12506,29368,-5,'Mayo, South Carolina 29368',9119,11006);
INSERT INTO "django_geo_db_zipcode" VALUES(12507,29369,-5,'Moore, South Carolina 29369',9120,11007);
INSERT INTO "django_geo_db_zipcode" VALUES(12508,29370,-5,'Mountville, South Carolina 29370',9121,11008);
INSERT INTO "django_geo_db_zipcode" VALUES(12509,29372,-5,'Pacolet, South Carolina 29372',9122,11009);
INSERT INTO "django_geo_db_zipcode" VALUES(12510,29373,-5,'Pacolet Mills, South Carolina 29373',9123,11010);
INSERT INTO "django_geo_db_zipcode" VALUES(12511,29374,-5,'Pauline, South Carolina 29374',9124,11011);
INSERT INTO "django_geo_db_zipcode" VALUES(12512,29375,-5,'Reidville, South Carolina 29375',9125,11012);
INSERT INTO "django_geo_db_zipcode" VALUES(12513,29376,-5,'Roebuck, South Carolina 29376',9126,11013);
INSERT INTO "django_geo_db_zipcode" VALUES(12514,29377,-5,'Startex, South Carolina 29377',9127,11014);
INSERT INTO "django_geo_db_zipcode" VALUES(12515,29378,-5,'Una, South Carolina 29378',9128,11015);
INSERT INTO "django_geo_db_zipcode" VALUES(12516,29379,-5,'Union, South Carolina 29379',9129,11016);
INSERT INTO "django_geo_db_zipcode" VALUES(12517,29384,-5,'Waterloo, South Carolina 29384',9130,11017);
INSERT INTO "django_geo_db_zipcode" VALUES(12518,29385,-5,'Wellford, South Carolina 29385',9131,11018);
INSERT INTO "django_geo_db_zipcode" VALUES(12519,29386,-5,'White Stone, South Carolina 29386',9132,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12520,29388,-5,'Woodruff, South Carolina 29388',9133,11019);
INSERT INTO "django_geo_db_zipcode" VALUES(12521,29390,-5,'Duncan, South Carolina 29390',9103,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12522,29391,-5,'Duncan, South Carolina 29391',9103,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12523,29401,-5,'Charleston, South Carolina 29401',9134,11020);
INSERT INTO "django_geo_db_zipcode" VALUES(12524,29402,-5,'Charleston, South Carolina 29402',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12525,29403,-5,'Charleston, South Carolina 29403',9134,11022);
INSERT INTO "django_geo_db_zipcode" VALUES(12526,29404,-5,'Charleston AFB, South Carolina 29404',9135,11023);
INSERT INTO "django_geo_db_zipcode" VALUES(12527,29405,-5,'North Charleston, South Carolina 29405',9136,11024);
INSERT INTO "django_geo_db_zipcode" VALUES(12528,29406,-5,'Charleston, South Carolina 29406',9134,11025);
INSERT INTO "django_geo_db_zipcode" VALUES(12529,29407,-5,'Charleston, South Carolina 29407',9134,11026);
INSERT INTO "django_geo_db_zipcode" VALUES(12530,29409,-5,'Charleston, South Carolina 29409',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12531,29410,-5,'Charleston, South Carolina 29410',9134,11027);
INSERT INTO "django_geo_db_zipcode" VALUES(12532,29412,-5,'Charleston, South Carolina 29412',9134,11028);
INSERT INTO "django_geo_db_zipcode" VALUES(12533,29413,-5,'Charleston, South Carolina 29413',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12534,29414,-5,'Charleston, South Carolina 29414',9134,11029);
INSERT INTO "django_geo_db_zipcode" VALUES(12535,29415,-5,'Charleston, South Carolina 29415',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12536,29416,-5,'Charleston, South Carolina 29416',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12537,29417,-5,'Charleston, South Carolina 29417',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12538,29418,-5,'North Charleston, South Carolina 29418',9136,11030);
INSERT INTO "django_geo_db_zipcode" VALUES(12539,29419,-5,'Charleston, South Carolina 29419',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12540,29420,-5,'North Charleston, South Carolina 29420',9136,11031);
INSERT INTO "django_geo_db_zipcode" VALUES(12541,29422,-5,'Charleston, South Carolina 29422',9134,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12542,29423,-5,'Charleston, South Carolina 29423',9134,11032);
INSERT INTO "django_geo_db_zipcode" VALUES(12543,29424,-5,'Charleston, South Carolina 29424',9134,11033);
INSERT INTO "django_geo_db_zipcode" VALUES(12544,29425,-5,'Charleston, South Carolina 29425',9134,11034);
INSERT INTO "django_geo_db_zipcode" VALUES(12545,29426,-5,'Adams Run, South Carolina 29426',9137,11035);
INSERT INTO "django_geo_db_zipcode" VALUES(12546,29429,-5,'Awendaw, South Carolina 29429',9138,11036);
INSERT INTO "django_geo_db_zipcode" VALUES(12547,29430,-5,'Bethera, South Carolina 29430',9139,11037);
INSERT INTO "django_geo_db_zipcode" VALUES(12548,29431,-5,'Bonneau, South Carolina 29431',9140,11038);
INSERT INTO "django_geo_db_zipcode" VALUES(12549,29432,-5,'Branchville, South Carolina 29432',9141,11039);
INSERT INTO "django_geo_db_zipcode" VALUES(12550,29433,-5,'Canadys, South Carolina 29433',9142,11040);
INSERT INTO "django_geo_db_zipcode" VALUES(12551,29434,-5,'Cordesville, South Carolina 29434',9143,11041);
INSERT INTO "django_geo_db_zipcode" VALUES(12552,29435,-5,'Cottageville, South Carolina 29435',9144,11042);
INSERT INTO "django_geo_db_zipcode" VALUES(12553,29436,-5,'Cross, South Carolina 29436',9145,11043);
INSERT INTO "django_geo_db_zipcode" VALUES(12554,29437,-5,'Dorchester, South Carolina 29437',9146,11044);
INSERT INTO "django_geo_db_zipcode" VALUES(12555,29438,-5,'Edisto Island, South Carolina 29438',9147,11045);
INSERT INTO "django_geo_db_zipcode" VALUES(12556,29439,-5,'Folly Beach, South Carolina 29439',9148,11046);
INSERT INTO "django_geo_db_zipcode" VALUES(12557,29440,-5,'Georgetown, South Carolina 29440',9149,11047);
INSERT INTO "django_geo_db_zipcode" VALUES(12558,29442,-5,'Georgetown, South Carolina 29442',9149,11048);
INSERT INTO "django_geo_db_zipcode" VALUES(12559,29445,-5,'Goose Creek, South Carolina 29445',9150,11049);
INSERT INTO "django_geo_db_zipcode" VALUES(12560,29446,-5,'Green Pond, South Carolina 29446',9151,11050);
INSERT INTO "django_geo_db_zipcode" VALUES(12561,29447,-5,'Grover, South Carolina 29447',9152,11051);
INSERT INTO "django_geo_db_zipcode" VALUES(12562,29448,-5,'Harleyville, South Carolina 29448',9153,11052);
INSERT INTO "django_geo_db_zipcode" VALUES(12563,29449,-5,'Hollywood, South Carolina 29449',9154,11053);
INSERT INTO "django_geo_db_zipcode" VALUES(12564,29450,-5,'Huger, South Carolina 29450',9155,11054);
INSERT INTO "django_geo_db_zipcode" VALUES(12565,29451,-5,'Isle Of Palms, South Carolina 29451',9156,11055);
INSERT INTO "django_geo_db_zipcode" VALUES(12566,29452,-5,'Jacksonboro, South Carolina 29452',9157,11056);
INSERT INTO "django_geo_db_zipcode" VALUES(12567,29453,-5,'Jamestown, South Carolina 29453',9158,11057);
INSERT INTO "django_geo_db_zipcode" VALUES(12568,29455,-5,'Johns Island, South Carolina 29455',9159,11058);
INSERT INTO "django_geo_db_zipcode" VALUES(12569,29456,-5,'Ladson, South Carolina 29456',9160,11059);
INSERT INTO "django_geo_db_zipcode" VALUES(12570,29457,-5,'Johns Island, South Carolina 29457',9159,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12571,29458,-5,'McClellanville, South Carolina 29458',9161,11060);
INSERT INTO "django_geo_db_zipcode" VALUES(12572,29461,-5,'Moncks Corner, South Carolina 29461',9162,11061);
INSERT INTO "django_geo_db_zipcode" VALUES(12573,29464,-5,'Mount Pleasant, South Carolina 29464',9163,11062);
INSERT INTO "django_geo_db_zipcode" VALUES(12574,29465,-5,'Mount Pleasant, South Carolina 29465',9163,11021);
INSERT INTO "django_geo_db_zipcode" VALUES(12575,29466,-5,'Mount Pleasant, South Carolina 29466',9163,11063);
INSERT INTO "django_geo_db_zipcode" VALUES(12576,29468,-5,'Pineville, South Carolina 29468',9164,11064);
INSERT INTO "django_geo_db_zipcode" VALUES(12577,29469,-5,'Pinopolis, South Carolina 29469',9165,11065);
INSERT INTO "django_geo_db_zipcode" VALUES(12578,29470,-5,'Ravenel, South Carolina 29470',9166,11066);
INSERT INTO "django_geo_db_zipcode" VALUES(12579,29471,-5,'Reevesville, South Carolina 29471',9167,11067);
INSERT INTO "django_geo_db_zipcode" VALUES(12580,29472,-5,'Ridgeville, South Carolina 29472',9168,11068);
INSERT INTO "django_geo_db_zipcode" VALUES(12581,29474,-5,'Round O, South Carolina 29474',9169,11069);
INSERT INTO "django_geo_db_zipcode" VALUES(12582,29475,-5,'Ruffin, South Carolina 29475',9170,11070);
INSERT INTO "django_geo_db_zipcode" VALUES(12583,29476,-5,'Russellville, South Carolina 29476',9171,11071);
INSERT INTO "django_geo_db_zipcode" VALUES(12584,29477,-5,'Saint George, South Carolina 29477',9172,11072);
INSERT INTO "django_geo_db_zipcode" VALUES(12585,29479,-5,'Saint Stephen, South Carolina 29479',9173,11073);
INSERT INTO "django_geo_db_zipcode" VALUES(12586,29481,-5,'Smoaks, South Carolina 29481',9174,11074);
INSERT INTO "django_geo_db_zipcode" VALUES(12587,29482,-5,'Sullivans Island, South Carolina 29482',9175,11075);
INSERT INTO "django_geo_db_zipcode" VALUES(12588,29483,-5,'Summerville, South Carolina 29483',9176,11076);
INSERT INTO "django_geo_db_zipcode" VALUES(12589,29484,-5,'Summerville, South Carolina 29484',9176,11077);
INSERT INTO "django_geo_db_zipcode" VALUES(12590,29485,-5,'Summerville, South Carolina 29485',9176,11078);
INSERT INTO "django_geo_db_zipcode" VALUES(12591,29487,-5,'Wadmalaw Island, South Carolina 29487',9177,11079);
INSERT INTO "django_geo_db_zipcode" VALUES(12592,29488,-5,'Walterboro, South Carolina 29488',9178,11080);
INSERT INTO "django_geo_db_zipcode" VALUES(12593,29492,-5,'Charleston, South Carolina 29492',9134,11081);
INSERT INTO "django_geo_db_zipcode" VALUES(12594,29493,-5,'Williams, South Carolina 29493',9179,11082);
INSERT INTO "django_geo_db_zipcode" VALUES(12595,29494,-5,'Hollywood, South Carolina 29494',9154,11083);
INSERT INTO "django_geo_db_zipcode" VALUES(12596,29501,-5,'Florence, South Carolina 29501',9180,11084);
INSERT INTO "django_geo_db_zipcode" VALUES(12597,29502,-5,'Florence, South Carolina 29502',9180,11085);
INSERT INTO "django_geo_db_zipcode" VALUES(12598,29503,-5,'Florence, South Carolina 29503',9180,11086);
INSERT INTO "django_geo_db_zipcode" VALUES(12599,29504,-5,'Florence, South Carolina 29504',9180,11087);
INSERT INTO "django_geo_db_zipcode" VALUES(12600,29505,-5,'Florence, South Carolina 29505',9180,11088);
INSERT INTO "django_geo_db_zipcode" VALUES(12601,29506,-5,'Florence, South Carolina 29506',9180,11089);
INSERT INTO "django_geo_db_zipcode" VALUES(12602,29510,-5,'Andrews, South Carolina 29510',9181,11090);
INSERT INTO "django_geo_db_zipcode" VALUES(12603,29511,-5,'Aynor, South Carolina 29511',9182,11091);
INSERT INTO "django_geo_db_zipcode" VALUES(12604,29512,-5,'Bennettsville, South Carolina 29512',9183,11092);
INSERT INTO "django_geo_db_zipcode" VALUES(12605,29516,-5,'Blenheim, South Carolina 29516',9184,11093);
INSERT INTO "django_geo_db_zipcode" VALUES(12606,29518,-5,'Cades, South Carolina 29518',9185,11094);
INSERT INTO "django_geo_db_zipcode" VALUES(12607,29519,-5,'Centenary, South Carolina 29519',9186,11095);
INSERT INTO "django_geo_db_zipcode" VALUES(12608,29520,-5,'Cheraw, South Carolina 29520',9187,11096);
INSERT INTO "django_geo_db_zipcode" VALUES(12609,29525,-5,'Clio, South Carolina 29525',9188,11097);
INSERT INTO "django_geo_db_zipcode" VALUES(12610,29526,-5,'Conway, South Carolina 29526',9189,11098);
INSERT INTO "django_geo_db_zipcode" VALUES(12611,29527,-5,'Conway, South Carolina 29527',9189,11099);
INSERT INTO "django_geo_db_zipcode" VALUES(12612,29528,-5,'Conway, South Carolina 29528',9189,11100);
INSERT INTO "django_geo_db_zipcode" VALUES(12613,29530,-5,'Coward, South Carolina 29530',9190,11101);
INSERT INTO "django_geo_db_zipcode" VALUES(12614,29532,-5,'Darlington, South Carolina 29532',9191,11102);
INSERT INTO "django_geo_db_zipcode" VALUES(12615,29535,-5,'McCormick, South Carolina 29535',9192,11103);
INSERT INTO "django_geo_db_zipcode" VALUES(12616,29536,-5,'Dillon, South Carolina 29536',9193,11104);
INSERT INTO "django_geo_db_zipcode" VALUES(12617,29540,-5,'Darlington, South Carolina 29540',9191,11105);
INSERT INTO "django_geo_db_zipcode" VALUES(12618,29541,-5,'Effingham, South Carolina 29541',9194,11106);
INSERT INTO "django_geo_db_zipcode" VALUES(12619,29542,-5,'Floyd Dale, South Carolina 29542',9195,11107);
INSERT INTO "django_geo_db_zipcode" VALUES(12620,29543,-5,'Fork, South Carolina 29543',9196,11108);
INSERT INTO "django_geo_db_zipcode" VALUES(12621,29544,-5,'Galivants Ferry, South Carolina 29544',9197,11109);
INSERT INTO "django_geo_db_zipcode" VALUES(12622,29545,-5,'Green Sea, South Carolina 29545',9198,11110);
INSERT INTO "django_geo_db_zipcode" VALUES(12623,29546,-5,'Gresham, South Carolina 29546',9199,11111);
INSERT INTO "django_geo_db_zipcode" VALUES(12624,29547,-5,'Hamer, South Carolina 29547',9200,11112);
INSERT INTO "django_geo_db_zipcode" VALUES(12625,29549,-5,'Myrtle Beach, South Carolina 29549',9201,11113);
INSERT INTO "django_geo_db_zipcode" VALUES(12626,29550,-5,'Hartsville, South Carolina 29550',9202,11114);
INSERT INTO "django_geo_db_zipcode" VALUES(12627,29551,-5,'Hartsville, South Carolina 29551',9202,11115);
INSERT INTO "django_geo_db_zipcode" VALUES(12628,29554,-5,'Hemingway, South Carolina 29554',9203,11116);
INSERT INTO "django_geo_db_zipcode" VALUES(12629,29555,-5,'Johnsonville, South Carolina 29555',9204,11117);
INSERT INTO "django_geo_db_zipcode" VALUES(12630,29556,-5,'Kingstree, South Carolina 29556',9205,11118);
INSERT INTO "django_geo_db_zipcode" VALUES(12631,29560,-5,'Lake City, South Carolina 29560',9206,11119);
INSERT INTO "django_geo_db_zipcode" VALUES(12632,29561,-5,'Latta, South Carolina 29561',9207,11120);
INSERT INTO "django_geo_db_zipcode" VALUES(12633,29563,-5,'Lake View, South Carolina 29563',9116,11121);
INSERT INTO "django_geo_db_zipcode" VALUES(12634,29564,-5,'Lane, South Carolina 29564',9208,11122);
INSERT INTO "django_geo_db_zipcode" VALUES(12635,29565,-5,'Latta, South Carolina 29565',9207,11123);
INSERT INTO "django_geo_db_zipcode" VALUES(12636,29566,-5,'Little River, South Carolina 29566',9209,11124);
INSERT INTO "django_geo_db_zipcode" VALUES(12637,29567,-5,'Little Rock, South Carolina 29567',9210,11125);
INSERT INTO "django_geo_db_zipcode" VALUES(12638,29568,-5,'Longs, South Carolina 29568',9211,11126);
INSERT INTO "django_geo_db_zipcode" VALUES(12639,29569,-5,'Loris, South Carolina 29569',9212,11127);
INSERT INTO "django_geo_db_zipcode" VALUES(12640,29570,-5,'McColl, South Carolina 29570',9213,11128);
INSERT INTO "django_geo_db_zipcode" VALUES(12641,29571,-5,'Marion, South Carolina 29571',9214,11129);
INSERT INTO "django_geo_db_zipcode" VALUES(12642,29572,-5,'Myrtle Beach, South Carolina 29572',9201,11130);
INSERT INTO "django_geo_db_zipcode" VALUES(12643,29573,-5,'Minturn, South Carolina 29573',9215,11131);
INSERT INTO "django_geo_db_zipcode" VALUES(12644,29574,-5,'Mullins, South Carolina 29574',9216,11132);
INSERT INTO "django_geo_db_zipcode" VALUES(12645,29575,-5,'Myrtle Beach, South Carolina 29575',9201,11133);
INSERT INTO "django_geo_db_zipcode" VALUES(12646,29576,-5,'Murrells Inlet, South Carolina 29576',9217,11134);
INSERT INTO "django_geo_db_zipcode" VALUES(12647,29577,-5,'Myrtle Beach, South Carolina 29577',9201,11135);
INSERT INTO "django_geo_db_zipcode" VALUES(12648,29578,-5,'Myrtle Beach, South Carolina 29578',9201,11136);
INSERT INTO "django_geo_db_zipcode" VALUES(12649,29579,-5,'Myrtle Beach, South Carolina 29579',9201,11137);
INSERT INTO "django_geo_db_zipcode" VALUES(12650,29580,-5,'Nesmith, South Carolina 29580',9218,11138);
INSERT INTO "django_geo_db_zipcode" VALUES(12651,29581,-5,'Nichols, South Carolina 29581',9219,11139);
INSERT INTO "django_geo_db_zipcode" VALUES(12652,29582,-5,'North Myrtle Beach, South Carolina 29582',9220,11140);
INSERT INTO "django_geo_db_zipcode" VALUES(12653,29583,-5,'Pamplico, South Carolina 29583',9221,11141);
INSERT INTO "django_geo_db_zipcode" VALUES(12654,29584,-5,'Patrick, South Carolina 29584',9222,11142);
INSERT INTO "django_geo_db_zipcode" VALUES(12655,29585,-5,'Pawleys Island, South Carolina 29585',9223,11143);
INSERT INTO "django_geo_db_zipcode" VALUES(12656,29587,-5,'Myrtle Beach, South Carolina 29587',9201,11144);
INSERT INTO "django_geo_db_zipcode" VALUES(12657,29588,-5,'Myrtle Beach, South Carolina 29588',9201,11145);
INSERT INTO "django_geo_db_zipcode" VALUES(12658,29589,-5,'Rains, South Carolina 29589',9224,11146);
INSERT INTO "django_geo_db_zipcode" VALUES(12659,29590,-5,'Salters, South Carolina 29590',9225,11147);
INSERT INTO "django_geo_db_zipcode" VALUES(12660,29591,-5,'Scranton, South Carolina 29591',9226,11148);
INSERT INTO "django_geo_db_zipcode" VALUES(12661,29592,-5,'Sellers, South Carolina 29592',9227,11149);
INSERT INTO "django_geo_db_zipcode" VALUES(12662,29593,-5,'Society Hill, South Carolina 29593',9228,11150);
INSERT INTO "django_geo_db_zipcode" VALUES(12663,29594,-5,'Tatum, South Carolina 29594',9229,11151);
INSERT INTO "django_geo_db_zipcode" VALUES(12664,29596,-5,'Wallace, South Carolina 29596',9230,11152);
INSERT INTO "django_geo_db_zipcode" VALUES(12665,29597,-5,'North Myrtle Beach, South Carolina 29597',9220,11153);
INSERT INTO "django_geo_db_zipcode" VALUES(12666,29598,-5,'North Myrtle Beach, South Carolina 29598',9220,11100);
INSERT INTO "django_geo_db_zipcode" VALUES(12667,29599,-5,'Socastee, South Carolina 29599',9231,11154);
INSERT INTO "django_geo_db_zipcode" VALUES(12668,29601,-5,'Greenville, South Carolina 29601',9232,11155);
INSERT INTO "django_geo_db_zipcode" VALUES(12669,29602,-5,'Greenville, South Carolina 29602',9232,11156);
INSERT INTO "django_geo_db_zipcode" VALUES(12670,29603,-5,'Greenville, South Carolina 29603',9232,11157);
INSERT INTO "django_geo_db_zipcode" VALUES(12671,29604,-5,'Greenville, South Carolina 29604',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12672,29605,-5,'Greenville, South Carolina 29605',9232,11159);
INSERT INTO "django_geo_db_zipcode" VALUES(12673,29606,-5,'Greenville, South Carolina 29606',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12674,29607,-5,'Greenville, South Carolina 29607',9232,11160);
INSERT INTO "django_geo_db_zipcode" VALUES(12675,29608,-5,'Greenville, South Carolina 29608',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12676,29609,-5,'Greenville, South Carolina 29609',9232,11161);
INSERT INTO "django_geo_db_zipcode" VALUES(12677,29610,-5,'Greenville, South Carolina 29610',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12678,29611,-5,'Greenville, South Carolina 29611',9232,11162);
INSERT INTO "django_geo_db_zipcode" VALUES(12679,29612,-5,'Greenville, South Carolina 29612',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12680,29613,-5,'Greenville, South Carolina 29613',9232,11163);
INSERT INTO "django_geo_db_zipcode" VALUES(12681,29614,-5,'Greenville, South Carolina 29614',9232,11164);
INSERT INTO "django_geo_db_zipcode" VALUES(12682,29615,-5,'Greenville, South Carolina 29615',9232,11165);
INSERT INTO "django_geo_db_zipcode" VALUES(12683,29616,-5,'Greenville, South Carolina 29616',9232,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12684,29617,-5,'Greenville, South Carolina 29617',9232,11166);
INSERT INTO "django_geo_db_zipcode" VALUES(12685,29620,-5,'Abbeville, South Carolina 29620',9233,11167);
INSERT INTO "django_geo_db_zipcode" VALUES(12686,29621,-5,'Anderson, South Carolina 29621',9234,11168);
INSERT INTO "django_geo_db_zipcode" VALUES(12687,29622,-5,'Anderson, South Carolina 29622',9234,11169);
INSERT INTO "django_geo_db_zipcode" VALUES(12688,29623,-5,'Anderson, South Carolina 29623',9234,11170);
INSERT INTO "django_geo_db_zipcode" VALUES(12689,29624,-5,'Anderson, South Carolina 29624',9234,11171);
INSERT INTO "django_geo_db_zipcode" VALUES(12690,29625,-5,'Anderson, South Carolina 29625',9234,11172);
INSERT INTO "django_geo_db_zipcode" VALUES(12691,29626,-5,'Anderson, South Carolina 29626',9234,11173);
INSERT INTO "django_geo_db_zipcode" VALUES(12692,29627,-5,'Belton, South Carolina 29627',9235,11174);
INSERT INTO "django_geo_db_zipcode" VALUES(12693,29628,-5,'Calhoun Falls, South Carolina 29628',9236,11175);
INSERT INTO "django_geo_db_zipcode" VALUES(12694,29630,-5,'Central, South Carolina 29630',9237,11176);
INSERT INTO "django_geo_db_zipcode" VALUES(12695,29631,-5,'Clemson, South Carolina 29631',9238,11177);
INSERT INTO "django_geo_db_zipcode" VALUES(12696,29632,-5,'Clemson, South Carolina 29632',9238,11178);
INSERT INTO "django_geo_db_zipcode" VALUES(12697,29633,-5,'Clemson, South Carolina 29633',9238,11178);
INSERT INTO "django_geo_db_zipcode" VALUES(12698,29634,-5,'Clemson, South Carolina 29634',9238,11178);
INSERT INTO "django_geo_db_zipcode" VALUES(12699,29635,-5,'Cleveland, South Carolina 29635',9239,11179);
INSERT INTO "django_geo_db_zipcode" VALUES(12700,29636,-5,'Conestee, South Carolina 29636',9240,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12701,29638,-5,'Donalds, South Carolina 29638',9241,11180);
INSERT INTO "django_geo_db_zipcode" VALUES(12702,29639,-5,'Due West, South Carolina 29639',9242,11181);
INSERT INTO "django_geo_db_zipcode" VALUES(12703,29640,-5,'Easley, South Carolina 29640',9243,11182);
INSERT INTO "django_geo_db_zipcode" VALUES(12704,29641,-5,'Easley, South Carolina 29641',9243,11183);
INSERT INTO "django_geo_db_zipcode" VALUES(12705,29642,-5,'Easley, South Carolina 29642',9243,11184);
INSERT INTO "django_geo_db_zipcode" VALUES(12706,29643,-5,'Fair Play, South Carolina 29643',9244,11185);
INSERT INTO "django_geo_db_zipcode" VALUES(12707,29644,-5,'Fountain Inn, South Carolina 29644',9245,11186);
INSERT INTO "django_geo_db_zipcode" VALUES(12708,29645,-5,'Gray Court, South Carolina 29645',9246,11187);
INSERT INTO "django_geo_db_zipcode" VALUES(12709,29646,-5,'Greenwood, South Carolina 29646',9247,11188);
INSERT INTO "django_geo_db_zipcode" VALUES(12710,29647,-5,'Greenwood, South Carolina 29647',9247,11189);
INSERT INTO "django_geo_db_zipcode" VALUES(12711,29648,-5,'Greenwood, South Carolina 29648',9247,11190);
INSERT INTO "django_geo_db_zipcode" VALUES(12712,29649,-5,'Greenwood, South Carolina 29649',9247,11191);
INSERT INTO "django_geo_db_zipcode" VALUES(12713,29650,-5,'Greer, South Carolina 29650',9248,11192);
INSERT INTO "django_geo_db_zipcode" VALUES(12714,29651,-5,'Greer, South Carolina 29651',9248,11193);
INSERT INTO "django_geo_db_zipcode" VALUES(12715,29652,-5,'Greer, South Carolina 29652',9248,11158);
INSERT INTO "django_geo_db_zipcode" VALUES(12716,29653,-5,'Hodges, South Carolina 29653',9249,11194);
INSERT INTO "django_geo_db_zipcode" VALUES(12717,29654,-5,'Honea Path, South Carolina 29654',9250,11195);
INSERT INTO "django_geo_db_zipcode" VALUES(12718,29655,-5,'Iva, South Carolina 29655',9251,11196);
INSERT INTO "django_geo_db_zipcode" VALUES(12719,29656,-5,'La France, South Carolina 29656',9252,11197);
INSERT INTO "django_geo_db_zipcode" VALUES(12720,29657,-5,'Liberty, South Carolina 29657',9253,11198);
INSERT INTO "django_geo_db_zipcode" VALUES(12721,29658,-5,'Long Creek, South Carolina 29658',9254,11199);
INSERT INTO "django_geo_db_zipcode" VALUES(12722,29659,-5,'Lowndesville, South Carolina 29659',9255,11200);
INSERT INTO "django_geo_db_zipcode" VALUES(12723,29661,-5,'Marietta, South Carolina 29661',9256,11201);
INSERT INTO "django_geo_db_zipcode" VALUES(12724,29662,-5,'Mauldin, South Carolina 29662',9257,11202);
INSERT INTO "django_geo_db_zipcode" VALUES(12725,29664,-5,'Mountain Rest, South Carolina 29664',9258,11203);
INSERT INTO "django_geo_db_zipcode" VALUES(12726,29665,-5,'Newry, South Carolina 29665',9259,11204);
INSERT INTO "django_geo_db_zipcode" VALUES(12727,29666,-5,'Ninety Six, South Carolina 29666',9260,11205);
INSERT INTO "django_geo_db_zipcode" VALUES(12728,29667,-5,'Norris, South Carolina 29667',9261,11206);
INSERT INTO "django_geo_db_zipcode" VALUES(12729,29669,-5,'Pelzer, South Carolina 29669',9262,11207);
INSERT INTO "django_geo_db_zipcode" VALUES(12730,29670,-5,'Pendleton, South Carolina 29670',9263,11208);
INSERT INTO "django_geo_db_zipcode" VALUES(12731,29671,-5,'Pickens, South Carolina 29671',9264,11209);
INSERT INTO "django_geo_db_zipcode" VALUES(12732,29672,-5,'Seneca, South Carolina 29672',9265,11210);
INSERT INTO "django_geo_db_zipcode" VALUES(12733,29673,-5,'Piedmont, South Carolina 29673',9266,11211);
INSERT INTO "django_geo_db_zipcode" VALUES(12734,29675,-5,'Richland, South Carolina 29675',9267,11212);
INSERT INTO "django_geo_db_zipcode" VALUES(12735,29676,-5,'Salem, South Carolina 29676',9268,11213);
INSERT INTO "django_geo_db_zipcode" VALUES(12736,29677,-5,'Sandy Springs, South Carolina 29677',9269,11214);
INSERT INTO "django_geo_db_zipcode" VALUES(12737,29678,-5,'Seneca, South Carolina 29678',9265,11215);
INSERT INTO "django_geo_db_zipcode" VALUES(12738,29679,-5,'Seneca, South Carolina 29679',9265,11216);
INSERT INTO "django_geo_db_zipcode" VALUES(12739,29680,-5,'Simpsonville, South Carolina 29680',9270,11217);
INSERT INTO "django_geo_db_zipcode" VALUES(12740,29681,-5,'Simpsonville, South Carolina 29681',9270,11218);
INSERT INTO "django_geo_db_zipcode" VALUES(12741,29682,-5,'Six Mile, South Carolina 29682',9271,11219);
INSERT INTO "django_geo_db_zipcode" VALUES(12742,29683,-5,'Slater, South Carolina 29683',9272,11220);
INSERT INTO "django_geo_db_zipcode" VALUES(12743,29684,-5,'Starr, South Carolina 29684',9273,11221);
INSERT INTO "django_geo_db_zipcode" VALUES(12744,29685,-5,'Sunset, South Carolina 29685',9274,11222);
INSERT INTO "django_geo_db_zipcode" VALUES(12745,29686,-5,'Tamassee, South Carolina 29686',9275,11223);
INSERT INTO "django_geo_db_zipcode" VALUES(12746,29687,-5,'Taylors, South Carolina 29687',9276,11224);
INSERT INTO "django_geo_db_zipcode" VALUES(12747,29688,-5,'Tigerville, South Carolina 29688',9277,11225);
INSERT INTO "django_geo_db_zipcode" VALUES(12748,29689,-5,'Townville, South Carolina 29689',9278,11226);
INSERT INTO "django_geo_db_zipcode" VALUES(12749,29690,-5,'Travelers Rest, South Carolina 29690',9279,11227);
INSERT INTO "django_geo_db_zipcode" VALUES(12750,29691,-5,'Walhalla, South Carolina 29691',9280,11228);
INSERT INTO "django_geo_db_zipcode" VALUES(12751,29692,-5,'Ware Shoals, South Carolina 29692',9281,11229);
INSERT INTO "django_geo_db_zipcode" VALUES(12752,29693,-5,'Westminster, South Carolina 29693',9282,11230);
INSERT INTO "django_geo_db_zipcode" VALUES(12753,29695,-5,'Hodges, South Carolina 29695',9249,11231);
INSERT INTO "django_geo_db_zipcode" VALUES(12754,29696,-5,'West Union, South Carolina 29696',9283,11232);
INSERT INTO "django_geo_db_zipcode" VALUES(12755,29697,-5,'Williamston, South Carolina 29697',9284,11233);
INSERT INTO "django_geo_db_zipcode" VALUES(12756,29698,-5,'Greenville, South Carolina 29698',9232,10978);
INSERT INTO "django_geo_db_zipcode" VALUES(12757,29702,-5,'Blacksburg, South Carolina 29702',9285,11234);
INSERT INTO "django_geo_db_zipcode" VALUES(12758,29703,-5,'Bowling Green, South Carolina 29703',9286,11235);
INSERT INTO "django_geo_db_zipcode" VALUES(12759,29704,-5,'Catawba, South Carolina 29704',9287,11236);
INSERT INTO "django_geo_db_zipcode" VALUES(12760,29706,-5,'Chester, South Carolina 29706',9288,11237);
INSERT INTO "django_geo_db_zipcode" VALUES(12761,29708,-5,'Fort Mill, South Carolina 29708',9289,11238);
INSERT INTO "django_geo_db_zipcode" VALUES(12762,29709,-5,'Chesterfield, South Carolina 29709',9290,11239);
INSERT INTO "django_geo_db_zipcode" VALUES(12763,29710,-5,'Clover, South Carolina 29710',9291,11240);
INSERT INTO "django_geo_db_zipcode" VALUES(12764,29712,-5,'Edgemoor, South Carolina 29712',9292,11241);
INSERT INTO "django_geo_db_zipcode" VALUES(12765,29714,-5,'Fort Lawn, South Carolina 29714',9293,11242);
INSERT INTO "django_geo_db_zipcode" VALUES(12766,29715,-5,'Fort Mill, South Carolina 29715',9289,11243);
INSERT INTO "django_geo_db_zipcode" VALUES(12767,29716,-5,'Fort Mill, South Carolina 29716',9289,11244);
INSERT INTO "django_geo_db_zipcode" VALUES(12768,29717,-5,'Hickory Grove, South Carolina 29717',9294,11245);
INSERT INTO "django_geo_db_zipcode" VALUES(12769,29718,-5,'Jefferson, South Carolina 29718',9295,11246);
INSERT INTO "django_geo_db_zipcode" VALUES(12770,29720,-5,'Lancaster, South Carolina 29720',9296,11247);
INSERT INTO "django_geo_db_zipcode" VALUES(12771,29721,-5,'Lancaster, South Carolina 29721',9296,11248);
INSERT INTO "django_geo_db_zipcode" VALUES(12772,29722,-5,'Lancaster, South Carolina 29722',9296,11249);
INSERT INTO "django_geo_db_zipcode" VALUES(12773,29724,-5,'Lando, South Carolina 29724',9297,11250);
INSERT INTO "django_geo_db_zipcode" VALUES(12774,29726,-5,'McConnells, South Carolina 29726',9298,11251);
INSERT INTO "django_geo_db_zipcode" VALUES(12775,29727,-5,'Mount Croghan, South Carolina 29727',9299,11252);
INSERT INTO "django_geo_db_zipcode" VALUES(12776,29728,-5,'Pageland, South Carolina 29728',9300,11253);
INSERT INTO "django_geo_db_zipcode" VALUES(12777,29729,-5,'Richburg, South Carolina 29729',9301,11254);
INSERT INTO "django_geo_db_zipcode" VALUES(12778,29730,-5,'Rock Hill, South Carolina 29730',9302,11255);
INSERT INTO "django_geo_db_zipcode" VALUES(12779,29731,-5,'Rock Hill, South Carolina 29731',9302,11235);
INSERT INTO "django_geo_db_zipcode" VALUES(12780,29732,-5,'Rock Hill, South Carolina 29732',9302,11256);
INSERT INTO "django_geo_db_zipcode" VALUES(12781,29733,-5,'Rock Hill, South Carolina 29733',9302,11235);
INSERT INTO "django_geo_db_zipcode" VALUES(12782,29734,-5,'Rock Hill, South Carolina 29734',9302,11235);
INSERT INTO "django_geo_db_zipcode" VALUES(12783,29741,-5,'Ruby, South Carolina 29741',9303,11257);
INSERT INTO "django_geo_db_zipcode" VALUES(12784,29742,-5,'Sharon, South Carolina 29742',9304,11258);
INSERT INTO "django_geo_db_zipcode" VALUES(12785,29743,-5,'Smyrna, South Carolina 29743',9305,11259);
INSERT INTO "django_geo_db_zipcode" VALUES(12786,29744,-5,'Van Wyck, South Carolina 29744',9306,11260);
INSERT INTO "django_geo_db_zipcode" VALUES(12787,29745,-5,'York, South Carolina 29745',9307,11261);
INSERT INTO "django_geo_db_zipcode" VALUES(12788,29756,-5,'Garden City, South Carolina 29756',9308,11262);
INSERT INTO "django_geo_db_zipcode" VALUES(12789,29801,-5,'Aiken, South Carolina 29801',9309,11263);
INSERT INTO "django_geo_db_zipcode" VALUES(12790,29802,-5,'Aiken, South Carolina 29802',9309,11264);
INSERT INTO "django_geo_db_zipcode" VALUES(12791,29803,-5,'Aiken, South Carolina 29803',9309,11265);
INSERT INTO "django_geo_db_zipcode" VALUES(12792,29804,-5,'Aiken, South Carolina 29804',9309,11266);
INSERT INTO "django_geo_db_zipcode" VALUES(12793,29805,-5,'Aiken, South Carolina 29805',9309,11267);
INSERT INTO "django_geo_db_zipcode" VALUES(12794,29808,-5,'Aiken, South Carolina 29808',9309,11266);
INSERT INTO "django_geo_db_zipcode" VALUES(12795,29809,-5,'New Ellenton, South Carolina 29809',9310,11268);
INSERT INTO "django_geo_db_zipcode" VALUES(12796,29810,-5,'Allendale, South Carolina 29810',9311,11269);
INSERT INTO "django_geo_db_zipcode" VALUES(12797,29812,-5,'Barnwell, South Carolina 29812',9312,11270);
INSERT INTO "django_geo_db_zipcode" VALUES(12798,29813,-5,'Hilda, South Carolina 29813',9313,11271);
INSERT INTO "django_geo_db_zipcode" VALUES(12799,29816,-5,'Bath, South Carolina 29816',9314,11272);
INSERT INTO "django_geo_db_zipcode" VALUES(12800,29817,-5,'Blackville, South Carolina 29817',9315,11273);
INSERT INTO "django_geo_db_zipcode" VALUES(12801,29819,-5,'Bradley, South Carolina 29819',9316,11274);
INSERT INTO "django_geo_db_zipcode" VALUES(12802,29821,-5,'Clarks Hill, South Carolina 29821',9317,11275);
INSERT INTO "django_geo_db_zipcode" VALUES(12803,29822,-5,'Clearwater, South Carolina 29822',9318,11276);
INSERT INTO "django_geo_db_zipcode" VALUES(12804,29824,-5,'Edgefield, South Carolina 29824',9319,11277);
INSERT INTO "django_geo_db_zipcode" VALUES(12805,29826,-5,'Elko, South Carolina 29826',9320,11278);
INSERT INTO "django_geo_db_zipcode" VALUES(12806,29827,-5,'Fairfax, South Carolina 29827',9321,11279);
INSERT INTO "django_geo_db_zipcode" VALUES(12807,29828,-5,'Gloverville, South Carolina 29828',9322,11280);
INSERT INTO "django_geo_db_zipcode" VALUES(12808,29829,-5,'Graniteville, South Carolina 29829',9323,11281);
INSERT INTO "django_geo_db_zipcode" VALUES(12809,29831,-5,'Jackson, South Carolina 29831',9324,11282);
INSERT INTO "django_geo_db_zipcode" VALUES(12810,29832,-5,'Johnston, South Carolina 29832',9325,11283);
INSERT INTO "django_geo_db_zipcode" VALUES(12811,29834,-5,'Langley, South Carolina 29834',9326,11284);
INSERT INTO "django_geo_db_zipcode" VALUES(12812,29835,-5,'McCormick, South Carolina 29835',9192,11285);
INSERT INTO "django_geo_db_zipcode" VALUES(12813,29836,-5,'Martin, South Carolina 29836',9327,11286);
INSERT INTO "django_geo_db_zipcode" VALUES(12814,29838,-5,'Modoc, South Carolina 29838',9328,11287);
INSERT INTO "django_geo_db_zipcode" VALUES(12815,29839,-5,'Montmorenci, South Carolina 29839',9329,11288);
INSERT INTO "django_geo_db_zipcode" VALUES(12816,29840,-5,'Mount Carmel, South Carolina 29840',9330,11289);
INSERT INTO "django_geo_db_zipcode" VALUES(12817,29841,-5,'North Augusta, South Carolina 29841',9331,11290);
INSERT INTO "django_geo_db_zipcode" VALUES(12818,29842,-5,'Beech Island, South Carolina 29842',9332,11291);
INSERT INTO "django_geo_db_zipcode" VALUES(12819,29843,-5,'Olar, South Carolina 29843',9333,11292);
INSERT INTO "django_geo_db_zipcode" VALUES(12820,29844,-5,'Parksville, South Carolina 29844',9334,11293);
INSERT INTO "django_geo_db_zipcode" VALUES(12821,29845,-5,'Plum Branch, South Carolina 29845',9335,11294);
INSERT INTO "django_geo_db_zipcode" VALUES(12822,29846,-5,'Sycamore, South Carolina 29846',9336,11295);
INSERT INTO "django_geo_db_zipcode" VALUES(12823,29847,-5,'Trenton, South Carolina 29847',9337,11296);
INSERT INTO "django_geo_db_zipcode" VALUES(12824,29848,-5,'Troy, South Carolina 29848',9338,11297);
INSERT INTO "django_geo_db_zipcode" VALUES(12825,29849,-5,'Ulmer, South Carolina 29849',9339,11298);
INSERT INTO "django_geo_db_zipcode" VALUES(12826,29850,-5,'Vaucluse, South Carolina 29850',9340,11299);
INSERT INTO "django_geo_db_zipcode" VALUES(12827,29851,-5,'Warrenville, South Carolina 29851',9341,11300);
INSERT INTO "django_geo_db_zipcode" VALUES(12828,29853,-5,'Williston, South Carolina 29853',9342,11301);
INSERT INTO "django_geo_db_zipcode" VALUES(12829,29856,-5,'Windsor, South Carolina 29856',9343,11302);
INSERT INTO "django_geo_db_zipcode" VALUES(12830,29860,-5,'North Augusta, South Carolina 29860',9331,11303);
INSERT INTO "django_geo_db_zipcode" VALUES(12831,29861,-5,'North Augusta, South Carolina 29861',9331,11266);
INSERT INTO "django_geo_db_zipcode" VALUES(12832,29875,-5,'Murrells Inlet, South Carolina 29875',9217,11304);
INSERT INTO "django_geo_db_zipcode" VALUES(12833,29899,-5,'McCormick, South Carolina 29899',9192,11305);
INSERT INTO "django_geo_db_zipcode" VALUES(12834,29901,-5,'Beaufort, South Carolina 29901',9344,11306);
INSERT INTO "django_geo_db_zipcode" VALUES(12835,29902,-5,'Beaufort, South Carolina 29902',9344,11307);
INSERT INTO "django_geo_db_zipcode" VALUES(12836,29903,-5,'Beaufort, South Carolina 29903',9344,11308);
INSERT INTO "django_geo_db_zipcode" VALUES(12837,29904,-5,'Beaufort, South Carolina 29904',9344,11309);
INSERT INTO "django_geo_db_zipcode" VALUES(12838,29905,-5,'Beaufort, South Carolina 29905',9344,11310);
INSERT INTO "django_geo_db_zipcode" VALUES(12839,29906,-5,'Beaufort, South Carolina 29906',9344,11311);
INSERT INTO "django_geo_db_zipcode" VALUES(12840,29907,-5,'Beaufort, South Carolina 29907',9344,11312);
INSERT INTO "django_geo_db_zipcode" VALUES(12841,29909,-5,'Hilton Head Island, South Carolina 29909',9345,11313);
INSERT INTO "django_geo_db_zipcode" VALUES(12842,29910,-5,'Bluffton, South Carolina 29910',9346,11314);
INSERT INTO "django_geo_db_zipcode" VALUES(12843,29911,-5,'Brunson, South Carolina 29911',9347,11315);
INSERT INTO "django_geo_db_zipcode" VALUES(12844,29912,-5,'Coosawatchie, South Carolina 29912',9348,11316);
INSERT INTO "django_geo_db_zipcode" VALUES(12845,29913,-5,'Crocketville, South Carolina 29913',9349,11317);
INSERT INTO "django_geo_db_zipcode" VALUES(12846,29914,-5,'Dale, South Carolina 29914',9350,11318);
INSERT INTO "django_geo_db_zipcode" VALUES(12847,29915,-5,'Daufuskie Island, South Carolina 29915',9351,11319);
INSERT INTO "django_geo_db_zipcode" VALUES(12848,29916,-5,'Early Branch, South Carolina 29916',9352,11320);
INSERT INTO "django_geo_db_zipcode" VALUES(12849,29918,-5,'Estill, South Carolina 29918',9353,11321);
INSERT INTO "django_geo_db_zipcode" VALUES(12850,29920,-5,'Saint Helena Island, South Carolina 29920',9354,11322);
INSERT INTO "django_geo_db_zipcode" VALUES(12851,29921,-5,'Furman, South Carolina 29921',9355,11323);
INSERT INTO "django_geo_db_zipcode" VALUES(12852,29922,-5,'Garnett, South Carolina 29922',9356,11324);
INSERT INTO "django_geo_db_zipcode" VALUES(12853,29923,-5,'Gifford, South Carolina 29923',9357,11325);
INSERT INTO "django_geo_db_zipcode" VALUES(12854,29924,-5,'Hampton, South Carolina 29924',9358,11326);
INSERT INTO "django_geo_db_zipcode" VALUES(12855,29925,-5,'Hilton Head Island, South Carolina 29925',9345,11327);
INSERT INTO "django_geo_db_zipcode" VALUES(12856,29926,-5,'Hilton Head Island, South Carolina 29926',9345,11328);
INSERT INTO "django_geo_db_zipcode" VALUES(12857,29927,-5,'Hardeeville, South Carolina 29927',9359,11329);
INSERT INTO "django_geo_db_zipcode" VALUES(12858,29928,-5,'Hilton Head Island, South Carolina 29928',9345,11330);
INSERT INTO "django_geo_db_zipcode" VALUES(12859,29929,-5,'Islandton, South Carolina 29929',9360,11331);
INSERT INTO "django_geo_db_zipcode" VALUES(12860,29931,-5,'Lobeco, South Carolina 29931',9361,11332);
INSERT INTO "django_geo_db_zipcode" VALUES(12861,29932,-5,'Luray, South Carolina 29932',9362,11333);
INSERT INTO "django_geo_db_zipcode" VALUES(12862,29933,-5,'Miley, South Carolina 29933',9363,11334);
INSERT INTO "django_geo_db_zipcode" VALUES(12863,29934,-5,'Pineland, South Carolina 29934',9364,11335);
INSERT INTO "django_geo_db_zipcode" VALUES(12864,29935,-5,'Port Royal, South Carolina 29935',9365,11336);
INSERT INTO "django_geo_db_zipcode" VALUES(12865,29936,-5,'Ridgeland, South Carolina 29936',9366,11337);
INSERT INTO "django_geo_db_zipcode" VALUES(12866,29938,-5,'Hilton Head Island, South Carolina 29938',9345,11309);
INSERT INTO "django_geo_db_zipcode" VALUES(12867,29939,-5,'Scotia, South Carolina 29939',9367,11338);
INSERT INTO "django_geo_db_zipcode" VALUES(12868,29940,-5,'Seabrook, South Carolina 29940',9368,11339);
INSERT INTO "django_geo_db_zipcode" VALUES(12869,29941,-5,'Sheldon, South Carolina 29941',9369,11340);
INSERT INTO "django_geo_db_zipcode" VALUES(12870,29942,-5,'Hampton, South Carolina 29942',9358,11341);
INSERT INTO "django_geo_db_zipcode" VALUES(12871,29943,-5,'Tillman, South Carolina 29943',9370,11342);
INSERT INTO "django_geo_db_zipcode" VALUES(12872,29944,-5,'Varnville, South Carolina 29944',9371,11343);
INSERT INTO "django_geo_db_zipcode" VALUES(12873,29945,-5,'Yemassee, South Carolina 29945',9372,11344);
INSERT INTO "django_geo_db_zipcode" VALUES(12874,29982,-5,'Hilton Head Island, South Carolina 29982',9345,11345);
INSERT INTO "django_geo_db_zipcode" VALUES(12875,30002,-5,'Avondale Estates, Georgia 30002',9373,11346);
INSERT INTO "django_geo_db_zipcode" VALUES(12876,30003,-5,'Norcross, Georgia 30003',9374,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12877,30004,-5,'Alpharetta, Georgia 30004',9375,11348);
INSERT INTO "django_geo_db_zipcode" VALUES(12878,30005,-5,'Alpharetta, Georgia 30005',9375,11349);
INSERT INTO "django_geo_db_zipcode" VALUES(12879,30006,-5,'Marietta, Georgia 30006',9376,11350);
INSERT INTO "django_geo_db_zipcode" VALUES(12880,30007,-5,'Marietta, Georgia 30007',9376,11350);
INSERT INTO "django_geo_db_zipcode" VALUES(12881,30008,-5,'Marietta, Georgia 30008',9376,11351);
INSERT INTO "django_geo_db_zipcode" VALUES(12882,30009,-5,'Alpharetta, Georgia 30009',9375,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(12883,30010,-5,'Norcross, Georgia 30010',9374,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12884,30011,-5,'Auburn, Georgia 30011',9377,11353);
INSERT INTO "django_geo_db_zipcode" VALUES(12885,30012,-5,'Conyers, Georgia 30012',9378,11354);
INSERT INTO "django_geo_db_zipcode" VALUES(12886,30013,-5,'Conyers, Georgia 30013',9378,11355);
INSERT INTO "django_geo_db_zipcode" VALUES(12887,30014,-5,'Covington, Georgia 30014',9379,11356);
INSERT INTO "django_geo_db_zipcode" VALUES(12888,30015,-5,'Covington, Georgia 30015',9379,11357);
INSERT INTO "django_geo_db_zipcode" VALUES(12889,30016,-5,'Covington, Georgia 30016',9379,11358);
INSERT INTO "django_geo_db_zipcode" VALUES(12890,30017,-5,'Grayson, Georgia 30017',9380,11359);
INSERT INTO "django_geo_db_zipcode" VALUES(12891,30018,-5,'Jersey, Georgia 30018',9381,11360);
INSERT INTO "django_geo_db_zipcode" VALUES(12892,30019,-5,'Dacula, Georgia 30019',9382,11361);
INSERT INTO "django_geo_db_zipcode" VALUES(12893,30021,-5,'Clarkston, Georgia 30021',9383,11362);
INSERT INTO "django_geo_db_zipcode" VALUES(12894,30022,-5,'Alpharetta, Georgia 30022',9375,11363);
INSERT INTO "django_geo_db_zipcode" VALUES(12895,30023,-5,'Alpharetta, Georgia 30023',9375,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(12896,30024,-5,'Suwanee, Georgia 30024',9384,11364);
INSERT INTO "django_geo_db_zipcode" VALUES(12897,30025,-5,'Social Circle, Georgia 30025',9385,11365);
INSERT INTO "django_geo_db_zipcode" VALUES(12898,30026,-5,'Duluth, Georgia 30026',9386,11366);
INSERT INTO "django_geo_db_zipcode" VALUES(12899,30028,-5,'Cumming, Georgia 30028',9387,11367);
INSERT INTO "django_geo_db_zipcode" VALUES(12900,30029,-5,'Duluth, Georgia 30029',9386,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12901,30030,-5,'Decatur, Georgia 30030',9388,11368);
INSERT INTO "django_geo_db_zipcode" VALUES(12902,30031,-5,'Decatur, Georgia 30031',9388,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12903,30032,-5,'Decatur, Georgia 30032',9388,11370);
INSERT INTO "django_geo_db_zipcode" VALUES(12904,30033,-5,'Decatur, Georgia 30033',9388,11371);
INSERT INTO "django_geo_db_zipcode" VALUES(12905,30034,-5,'Decatur, Georgia 30034',9388,11372);
INSERT INTO "django_geo_db_zipcode" VALUES(12906,30035,-5,'Decatur, Georgia 30035',9388,11373);
INSERT INTO "django_geo_db_zipcode" VALUES(12907,30036,-5,'Decatur, Georgia 30036',9388,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12908,30037,-5,'Decatur, Georgia 30037',9388,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12909,30038,-5,'Lithonia, Georgia 30038',9389,11374);
INSERT INTO "django_geo_db_zipcode" VALUES(12910,30039,-5,'Snellville, Georgia 30039',9390,11375);
INSERT INTO "django_geo_db_zipcode" VALUES(12911,30040,-5,'Cumming, Georgia 30040',9387,11376);
INSERT INTO "django_geo_db_zipcode" VALUES(12912,30041,-5,'Cumming, Georgia 30041',9387,11377);
INSERT INTO "django_geo_db_zipcode" VALUES(12913,30042,-5,'Lawrenceville, Georgia 30042',9391,11378);
INSERT INTO "django_geo_db_zipcode" VALUES(12914,30043,-5,'Lawrenceville, Georgia 30043',9391,11379);
INSERT INTO "django_geo_db_zipcode" VALUES(12915,30044,-5,'Lawrenceville, Georgia 30044',9391,11380);
INSERT INTO "django_geo_db_zipcode" VALUES(12916,30045,-5,'Lawrenceville, Georgia 30045',9391,11381);
INSERT INTO "django_geo_db_zipcode" VALUES(12917,30046,-5,'Lawrenceville, Georgia 30046',9391,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12918,30047,-5,'Lilburn, Georgia 30047',9392,11382);
INSERT INTO "django_geo_db_zipcode" VALUES(12919,30048,-5,'Lilburn, Georgia 30048',9392,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12920,30052,-5,'Loganville, Georgia 30052',9393,11383);
INSERT INTO "django_geo_db_zipcode" VALUES(12921,30054,-5,'Oxford, Georgia 30054',9394,11384);
INSERT INTO "django_geo_db_zipcode" VALUES(12922,30055,-5,'Mansfield, Georgia 30055',9395,11385);
INSERT INTO "django_geo_db_zipcode" VALUES(12923,30056,-5,'Newborn, Georgia 30056',9396,11386);
INSERT INTO "django_geo_db_zipcode" VALUES(12924,30058,-5,'Lithonia, Georgia 30058',9389,11387);
INSERT INTO "django_geo_db_zipcode" VALUES(12925,30060,-5,'Marietta, Georgia 30060',9376,11388);
INSERT INTO "django_geo_db_zipcode" VALUES(12926,30061,-5,'Marietta, Georgia 30061',9376,11389);
INSERT INTO "django_geo_db_zipcode" VALUES(12927,30062,-5,'Marietta, Georgia 30062',9376,11390);
INSERT INTO "django_geo_db_zipcode" VALUES(12928,30063,-5,'Marietta, Georgia 30063',9376,11391);
INSERT INTO "django_geo_db_zipcode" VALUES(12929,30064,-5,'Marietta, Georgia 30064',9376,11392);
INSERT INTO "django_geo_db_zipcode" VALUES(12930,30065,-5,'Marietta, Georgia 30065',9376,11350);
INSERT INTO "django_geo_db_zipcode" VALUES(12931,30066,-5,'Marietta, Georgia 30066',9376,11393);
INSERT INTO "django_geo_db_zipcode" VALUES(12932,30067,-5,'Marietta, Georgia 30067',9376,11394);
INSERT INTO "django_geo_db_zipcode" VALUES(12933,30068,-5,'Marietta, Georgia 30068',9376,11395);
INSERT INTO "django_geo_db_zipcode" VALUES(12934,30069,-5,'Marietta, Georgia 30069',9376,11350);
INSERT INTO "django_geo_db_zipcode" VALUES(12935,30070,-5,'Porterdale, Georgia 30070',9397,11396);
INSERT INTO "django_geo_db_zipcode" VALUES(12936,30071,-5,'Norcross, Georgia 30071',9374,11397);
INSERT INTO "django_geo_db_zipcode" VALUES(12937,30072,-5,'Pine Lake, Georgia 30072',9398,11398);
INSERT INTO "django_geo_db_zipcode" VALUES(12938,30074,-5,'Redan, Georgia 30074',9399,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12939,30075,-5,'Roswell, Georgia 30075',9400,11399);
INSERT INTO "django_geo_db_zipcode" VALUES(12940,30076,-5,'Roswell, Georgia 30076',9400,11400);
INSERT INTO "django_geo_db_zipcode" VALUES(12941,30077,-5,'Roswell, Georgia 30077',9400,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(12942,30078,-5,'Snellville, Georgia 30078',9390,11401);
INSERT INTO "django_geo_db_zipcode" VALUES(12943,30079,-5,'Scottdale, Georgia 30079',9401,11402);
INSERT INTO "django_geo_db_zipcode" VALUES(12944,30080,-5,'Smyrna, Georgia 30080',9402,11403);
INSERT INTO "django_geo_db_zipcode" VALUES(12945,30081,-5,'Smyrna, Georgia 30081',9402,11404);
INSERT INTO "django_geo_db_zipcode" VALUES(12946,30082,-5,'Smyrna, Georgia 30082',9402,11405);
INSERT INTO "django_geo_db_zipcode" VALUES(12947,30083,-5,'Stone Mountain, Georgia 30083',9403,11406);
INSERT INTO "django_geo_db_zipcode" VALUES(12948,30084,-5,'Tucker, Georgia 30084',9404,11407);
INSERT INTO "django_geo_db_zipcode" VALUES(12949,30085,-5,'Tucker, Georgia 30085',9404,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12950,30086,-5,'Stone Mountain, Georgia 30086',9403,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(12951,30087,-5,'Stone Mountain, Georgia 30087',9403,11408);
INSERT INTO "django_geo_db_zipcode" VALUES(12952,30088,-5,'Stone Mountain, Georgia 30088',9403,11409);
INSERT INTO "django_geo_db_zipcode" VALUES(12953,30090,-5,'Marietta, Georgia 30090',9376,11410);
INSERT INTO "django_geo_db_zipcode" VALUES(12954,30091,-5,'Norcross, Georgia 30091',9374,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12955,30092,-5,'Norcross, Georgia 30092',9374,11411);
INSERT INTO "django_geo_db_zipcode" VALUES(12956,30093,-5,'Norcross, Georgia 30093',9374,11412);
INSERT INTO "django_geo_db_zipcode" VALUES(12957,30094,-5,'Conyers, Georgia 30094',9378,11413);
INSERT INTO "django_geo_db_zipcode" VALUES(12958,30095,-5,'Duluth, Georgia 30095',9386,11414);
INSERT INTO "django_geo_db_zipcode" VALUES(12959,30096,-5,'Duluth, Georgia 30096',9386,11415);
INSERT INTO "django_geo_db_zipcode" VALUES(12960,30097,-5,'Duluth, Georgia 30097',9386,11416);
INSERT INTO "django_geo_db_zipcode" VALUES(12961,30098,-5,'Duluth, Georgia 30098',9386,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(12962,30099,-5,'Duluth, Georgia 30099',9386,11417);
INSERT INTO "django_geo_db_zipcode" VALUES(12963,30101,-5,'Acworth, Georgia 30101',9405,11418);
INSERT INTO "django_geo_db_zipcode" VALUES(12964,30102,-5,'Acworth, Georgia 30102',9405,11419);
INSERT INTO "django_geo_db_zipcode" VALUES(12965,30103,-5,'Adairsville, Georgia 30103',9406,11420);
INSERT INTO "django_geo_db_zipcode" VALUES(12966,30104,-5,'Aragon, Georgia 30104',9407,11421);
INSERT INTO "django_geo_db_zipcode" VALUES(12967,30105,-5,'Armuchee, Georgia 30105',9408,11422);
INSERT INTO "django_geo_db_zipcode" VALUES(12968,30106,-5,'Austell, Georgia 30106',9409,11423);
INSERT INTO "django_geo_db_zipcode" VALUES(12969,30107,-5,'Ball Ground, Georgia 30107',9410,11424);
INSERT INTO "django_geo_db_zipcode" VALUES(12970,30108,-5,'Bowdon, Georgia 30108',9411,11425);
INSERT INTO "django_geo_db_zipcode" VALUES(12971,30109,-5,'Bowdon Junction, Georgia 30109',9412,11426);
INSERT INTO "django_geo_db_zipcode" VALUES(12972,30110,-5,'Bremen, Georgia 30110',9413,11427);
INSERT INTO "django_geo_db_zipcode" VALUES(12973,30111,-5,'Clarkdale, Georgia 30111',9414,11350);
INSERT INTO "django_geo_db_zipcode" VALUES(12974,30113,-5,'Buchanan, Georgia 30113',9415,11428);
INSERT INTO "django_geo_db_zipcode" VALUES(12975,30114,-5,'Canton, Georgia 30114',9416,11429);
INSERT INTO "django_geo_db_zipcode" VALUES(12976,30115,-5,'Canton, Georgia 30115',9416,11430);
INSERT INTO "django_geo_db_zipcode" VALUES(12977,30116,-5,'Carrollton, Georgia 30116',9417,11431);
INSERT INTO "django_geo_db_zipcode" VALUES(12978,30117,-5,'Carrollton, Georgia 30117',9417,11432);
INSERT INTO "django_geo_db_zipcode" VALUES(12979,30118,-5,'Carrollton, Georgia 30118',9417,11433);
INSERT INTO "django_geo_db_zipcode" VALUES(12980,30119,-5,'Carrollton, Georgia 30119',9417,11434);
INSERT INTO "django_geo_db_zipcode" VALUES(12981,30120,-5,'Cartersville, Georgia 30120',9418,11435);
INSERT INTO "django_geo_db_zipcode" VALUES(12982,30121,-5,'Cartersville, Georgia 30121',9418,11436);
INSERT INTO "django_geo_db_zipcode" VALUES(12983,30122,-5,'Lithia Springs, Georgia 30122',9419,11437);
INSERT INTO "django_geo_db_zipcode" VALUES(12984,30123,-5,'Cassville, Georgia 30123',9420,11438);
INSERT INTO "django_geo_db_zipcode" VALUES(12985,30124,-5,'Cave Spring, Georgia 30124',9421,11439);
INSERT INTO "django_geo_db_zipcode" VALUES(12986,30125,-5,'Cedartown, Georgia 30125',9422,11440);
INSERT INTO "django_geo_db_zipcode" VALUES(12987,30126,-5,'Mableton, Georgia 30126',9423,11441);
INSERT INTO "django_geo_db_zipcode" VALUES(12988,30127,-5,'Powder Springs, Georgia 30127',9424,11442);
INSERT INTO "django_geo_db_zipcode" VALUES(12989,30129,-5,'Coosa, Georgia 30129',9425,11443);
INSERT INTO "django_geo_db_zipcode" VALUES(12990,30132,-5,'Dallas, Georgia 30132',9426,11444);
INSERT INTO "django_geo_db_zipcode" VALUES(12991,30133,-5,'Douglasville, Georgia 30133',9427,11445);
INSERT INTO "django_geo_db_zipcode" VALUES(12992,30134,-5,'Douglasville, Georgia 30134',9427,11446);
INSERT INTO "django_geo_db_zipcode" VALUES(12993,30135,-5,'Douglasville, Georgia 30135',9427,11447);
INSERT INTO "django_geo_db_zipcode" VALUES(12994,30137,-5,'Emerson, Georgia 30137',9428,11448);
INSERT INTO "django_geo_db_zipcode" VALUES(12995,30138,-5,'Esom Hill, Georgia 30138',9429,11449);
INSERT INTO "django_geo_db_zipcode" VALUES(12996,30139,-5,'Fairmount, Georgia 30139',9430,11450);
INSERT INTO "django_geo_db_zipcode" VALUES(12997,30140,-5,'Felton, Georgia 30140',9431,11451);
INSERT INTO "django_geo_db_zipcode" VALUES(12998,30141,-5,'Hiram, Georgia 30141',9432,11452);
INSERT INTO "django_geo_db_zipcode" VALUES(12999,30142,-5,'Holly Springs, Georgia 30142',9433,11453);
INSERT INTO "django_geo_db_zipcode" VALUES(13000,30143,-5,'Jasper, Georgia 30143',9434,11454);
INSERT INTO "django_geo_db_zipcode" VALUES(13001,30144,-5,'Kennesaw, Georgia 30144',9435,11455);
INSERT INTO "django_geo_db_zipcode" VALUES(13002,30145,-5,'Kingston, Georgia 30145',9436,11456);
INSERT INTO "django_geo_db_zipcode" VALUES(13003,30146,-5,'Lebanon, Georgia 30146',9437,11453);
INSERT INTO "django_geo_db_zipcode" VALUES(13004,30147,-5,'Lindale, Georgia 30147',9438,11457);
INSERT INTO "django_geo_db_zipcode" VALUES(13005,30148,-5,'Marble Hill, Georgia 30148',9439,11458);
INSERT INTO "django_geo_db_zipcode" VALUES(13006,30149,-5,'Mount Berry, Georgia 30149',9440,11459);
INSERT INTO "django_geo_db_zipcode" VALUES(13007,30150,-5,'Mount Zion, Georgia 30150',9441,11460);
INSERT INTO "django_geo_db_zipcode" VALUES(13008,30151,-5,'Nelson, Georgia 30151',9442,11453);
INSERT INTO "django_geo_db_zipcode" VALUES(13009,30152,-5,'Kennesaw, Georgia 30152',9435,11461);
INSERT INTO "django_geo_db_zipcode" VALUES(13010,30153,-5,'Rockmart, Georgia 30153',9443,11462);
INSERT INTO "django_geo_db_zipcode" VALUES(13011,30154,-5,'Douglasville, Georgia 30154',9427,11445);
INSERT INTO "django_geo_db_zipcode" VALUES(13012,30157,-5,'Dallas, Georgia 30157',9426,11463);
INSERT INTO "django_geo_db_zipcode" VALUES(13013,30161,-5,'Rome, Georgia 30161',9444,11464);
INSERT INTO "django_geo_db_zipcode" VALUES(13014,30162,-5,'Rome, Georgia 30162',9444,11465);
INSERT INTO "django_geo_db_zipcode" VALUES(13015,30163,-5,'Rome, Georgia 30163',9444,11443);
INSERT INTO "django_geo_db_zipcode" VALUES(13016,30164,-5,'Rome, Georgia 30164',9444,11443);
INSERT INTO "django_geo_db_zipcode" VALUES(13017,30165,-5,'Rome, Georgia 30165',9444,11466);
INSERT INTO "django_geo_db_zipcode" VALUES(13018,30166,-5,'Carrollton, Georgia 30166',9417,11467);
INSERT INTO "django_geo_db_zipcode" VALUES(13019,30168,-5,'Austell, Georgia 30168',9409,11468);
INSERT INTO "django_geo_db_zipcode" VALUES(13020,30170,-5,'Roopville, Georgia 30170',9445,11469);
INSERT INTO "django_geo_db_zipcode" VALUES(13021,30171,-5,'Rydal, Georgia 30171',9446,11470);
INSERT INTO "django_geo_db_zipcode" VALUES(13022,30172,-5,'Shannon, Georgia 30172',9447,11443);
INSERT INTO "django_geo_db_zipcode" VALUES(13023,30173,-5,'Silver Creek, Georgia 30173',9448,11471);
INSERT INTO "django_geo_db_zipcode" VALUES(13024,30175,-5,'Talking Rock, Georgia 30175',9449,11472);
INSERT INTO "django_geo_db_zipcode" VALUES(13025,30176,-5,'Tallapoosa, Georgia 30176',9450,11473);
INSERT INTO "django_geo_db_zipcode" VALUES(13026,30177,-5,'Tate, Georgia 30177',9451,11474);
INSERT INTO "django_geo_db_zipcode" VALUES(13027,30178,-5,'Taylorsville, Georgia 30178',9452,11475);
INSERT INTO "django_geo_db_zipcode" VALUES(13028,30179,-5,'Temple, Georgia 30179',9453,11476);
INSERT INTO "django_geo_db_zipcode" VALUES(13029,30180,-5,'Villa Rica, Georgia 30180',9454,11477);
INSERT INTO "django_geo_db_zipcode" VALUES(13030,30182,-5,'Waco, Georgia 30182',9455,11478);
INSERT INTO "django_geo_db_zipcode" VALUES(13031,30183,-5,'Waleska, Georgia 30183',9456,11479);
INSERT INTO "django_geo_db_zipcode" VALUES(13032,30184,-5,'White, Georgia 30184',9457,11480);
INSERT INTO "django_geo_db_zipcode" VALUES(13033,30185,-5,'Whitesburg, Georgia 30185',9458,11481);
INSERT INTO "django_geo_db_zipcode" VALUES(13034,30187,-5,'Winston, Georgia 30187',9459,11482);
INSERT INTO "django_geo_db_zipcode" VALUES(13035,30188,-5,'Woodstock, Georgia 30188',9460,11483);
INSERT INTO "django_geo_db_zipcode" VALUES(13036,30189,-5,'Woodstock, Georgia 30189',9460,11484);
INSERT INTO "django_geo_db_zipcode" VALUES(13037,30202,-5,'Alpharetta, Georgia 30202',9375,11485);
INSERT INTO "django_geo_db_zipcode" VALUES(13038,30203,-5,'Brooks, Georgia 30203',9461,11486);
INSERT INTO "django_geo_db_zipcode" VALUES(13039,30204,-5,'Barnesville, Georgia 30204',9462,11487);
INSERT INTO "django_geo_db_zipcode" VALUES(13040,30205,-5,'Brooks, Georgia 30205',9461,11488);
INSERT INTO "django_geo_db_zipcode" VALUES(13041,30206,-5,'Concord, Georgia 30206',9463,11489);
INSERT INTO "django_geo_db_zipcode" VALUES(13042,30212,-5,'Experiment, Georgia 30212',9464,11490);
INSERT INTO "django_geo_db_zipcode" VALUES(13043,30213,-5,'Fairburn, Georgia 30213',9465,11491);
INSERT INTO "django_geo_db_zipcode" VALUES(13044,30214,-5,'Fayetteville, Georgia 30214',9466,11492);
INSERT INTO "django_geo_db_zipcode" VALUES(13045,30215,-5,'Fayetteville, Georgia 30215',9466,11493);
INSERT INTO "django_geo_db_zipcode" VALUES(13046,30216,-5,'Flovilla, Georgia 30216',9467,11494);
INSERT INTO "django_geo_db_zipcode" VALUES(13047,30217,-5,'Franklin, Georgia 30217',9468,11495);
INSERT INTO "django_geo_db_zipcode" VALUES(13048,30218,-5,'Gay, Georgia 30218',9469,11496);
INSERT INTO "django_geo_db_zipcode" VALUES(13049,30219,-5,'Glenn, Georgia 30219',9470,11497);
INSERT INTO "django_geo_db_zipcode" VALUES(13050,30220,-5,'Grantville, Georgia 30220',9471,11498);
INSERT INTO "django_geo_db_zipcode" VALUES(13051,30222,-5,'Greenville, Georgia 30222',9472,11499);
INSERT INTO "django_geo_db_zipcode" VALUES(13052,30223,-5,'Griffin, Georgia 30223',9473,11500);
INSERT INTO "django_geo_db_zipcode" VALUES(13053,30224,-5,'Griffin, Georgia 30224',9473,11501);
INSERT INTO "django_geo_db_zipcode" VALUES(13054,30228,-5,'Hampton, Georgia 30228',9474,11502);
INSERT INTO "django_geo_db_zipcode" VALUES(13055,30229,-5,'Haralson, Georgia 30229',9475,11503);
INSERT INTO "django_geo_db_zipcode" VALUES(13056,30230,-5,'Hogansville, Georgia 30230',9476,11504);
INSERT INTO "django_geo_db_zipcode" VALUES(13057,30232,-5,'Inman, Georgia 30232',9477,11505);
INSERT INTO "django_geo_db_zipcode" VALUES(13058,30233,-5,'Jackson, Georgia 30233',9478,11506);
INSERT INTO "django_geo_db_zipcode" VALUES(13059,30234,-5,'Jenkinsburg, Georgia 30234',9479,11507);
INSERT INTO "django_geo_db_zipcode" VALUES(13060,30236,-5,'Jonesboro, Georgia 30236',9480,11508);
INSERT INTO "django_geo_db_zipcode" VALUES(13061,30237,-5,'Jonesboro, Georgia 30237',9480,11509);
INSERT INTO "django_geo_db_zipcode" VALUES(13062,30238,-5,'Jonesboro, Georgia 30238',9480,11510);
INSERT INTO "django_geo_db_zipcode" VALUES(13063,30240,-5,'Lagrange, Georgia 30240',9481,11511);
INSERT INTO "django_geo_db_zipcode" VALUES(13064,30241,-5,'Lagrange, Georgia 30241',9481,11512);
INSERT INTO "django_geo_db_zipcode" VALUES(13065,30248,-5,'Locust Grove, Georgia 30248',9482,11513);
INSERT INTO "django_geo_db_zipcode" VALUES(13066,30250,-5,'Lovejoy, Georgia 30250',9483,11514);
INSERT INTO "django_geo_db_zipcode" VALUES(13067,30251,-5,'Luthersville, Georgia 30251',9484,11515);
INSERT INTO "django_geo_db_zipcode" VALUES(13068,30252,-5,'Mcdonough, Georgia 30252',9485,11516);
INSERT INTO "django_geo_db_zipcode" VALUES(13069,30253,-5,'Mcdonough, Georgia 30253',9485,11517);
INSERT INTO "django_geo_db_zipcode" VALUES(13070,30256,-5,'Meansville, Georgia 30256',9486,11518);
INSERT INTO "django_geo_db_zipcode" VALUES(13071,30257,-5,'Milner, Georgia 30257',9487,11519);
INSERT INTO "django_geo_db_zipcode" VALUES(13072,30258,-5,'Molena, Georgia 30258',9488,11520);
INSERT INTO "django_geo_db_zipcode" VALUES(13073,30259,-5,'Moreland, Georgia 30259',9489,11521);
INSERT INTO "django_geo_db_zipcode" VALUES(13074,30260,-5,'Morrow, Georgia 30260',9490,11522);
INSERT INTO "django_geo_db_zipcode" VALUES(13075,30261,-5,'Lagrange, Georgia 30261',9481,11523);
INSERT INTO "django_geo_db_zipcode" VALUES(13076,30263,-5,'Newnan, Georgia 30263',9491,11524);
INSERT INTO "django_geo_db_zipcode" VALUES(13077,30264,-5,'Newnan, Georgia 30264',9491,11525);
INSERT INTO "django_geo_db_zipcode" VALUES(13078,30265,-5,'Newnan, Georgia 30265',9491,11526);
INSERT INTO "django_geo_db_zipcode" VALUES(13079,30266,-5,'Orchard Hill, Georgia 30266',9492,11527);
INSERT INTO "django_geo_db_zipcode" VALUES(13080,30268,-5,'Palmetto, Georgia 30268',9493,11528);
INSERT INTO "django_geo_db_zipcode" VALUES(13081,30269,-5,'Peachtree City, Georgia 30269',9494,11529);
INSERT INTO "django_geo_db_zipcode" VALUES(13082,30271,-5,'Newnan, Georgia 30271',9491,11530);
INSERT INTO "django_geo_db_zipcode" VALUES(13083,30272,-5,'Red Oak, Georgia 30272',9495,11531);
INSERT INTO "django_geo_db_zipcode" VALUES(13084,30273,-5,'Rex, Georgia 30273',9496,11532);
INSERT INTO "django_geo_db_zipcode" VALUES(13085,30274,-5,'Riverdale, Georgia 30274',9497,11533);
INSERT INTO "django_geo_db_zipcode" VALUES(13086,30275,-5,'Sargent, Georgia 30275',9498,11534);
INSERT INTO "django_geo_db_zipcode" VALUES(13087,30276,-5,'Senoia, Georgia 30276',9499,11535);
INSERT INTO "django_geo_db_zipcode" VALUES(13088,30277,-5,'Sharpsburg, Georgia 30277',9500,11536);
INSERT INTO "django_geo_db_zipcode" VALUES(13089,30281,-5,'Stockbridge, Georgia 30281',9501,11537);
INSERT INTO "django_geo_db_zipcode" VALUES(13090,30283,-5,'Jackson, Georgia 30283',9478,11538);
INSERT INTO "django_geo_db_zipcode" VALUES(13091,30284,-5,'Sunny Side, Georgia 30284',9502,11539);
INSERT INTO "django_geo_db_zipcode" VALUES(13092,30285,-5,'The Rock, Georgia 30285',9503,11540);
INSERT INTO "django_geo_db_zipcode" VALUES(13093,30286,-5,'Thomaston, Georgia 30286',9504,11541);
INSERT INTO "django_geo_db_zipcode" VALUES(13094,30287,-5,'Morrow, Georgia 30287',9490,11509);
INSERT INTO "django_geo_db_zipcode" VALUES(13095,30288,-5,'Conley, Georgia 30288',9505,11542);
INSERT INTO "django_geo_db_zipcode" VALUES(13096,30289,-5,'Turin, Georgia 30289',9506,11543);
INSERT INTO "django_geo_db_zipcode" VALUES(13097,30290,-5,'Tyrone, Georgia 30290',9507,11544);
INSERT INTO "django_geo_db_zipcode" VALUES(13098,30291,-5,'Union City, Georgia 30291',9508,11545);
INSERT INTO "django_geo_db_zipcode" VALUES(13099,30292,-5,'Williamson, Georgia 30292',9509,11546);
INSERT INTO "django_geo_db_zipcode" VALUES(13100,30293,-5,'Woodbury, Georgia 30293',9510,11547);
INSERT INTO "django_geo_db_zipcode" VALUES(13101,30294,-5,'Ellenwood, Georgia 30294',9511,11548);
INSERT INTO "django_geo_db_zipcode" VALUES(13102,30295,-5,'Zebulon, Georgia 30295',9512,11549);
INSERT INTO "django_geo_db_zipcode" VALUES(13103,30296,-5,'Riverdale, Georgia 30296',9497,11550);
INSERT INTO "django_geo_db_zipcode" VALUES(13104,30297,-5,'Forest Park, Georgia 30297',9513,11551);
INSERT INTO "django_geo_db_zipcode" VALUES(13105,30298,-5,'Forest Park, Georgia 30298',9513,11509);
INSERT INTO "django_geo_db_zipcode" VALUES(13106,30301,-5,'Atlanta, Georgia 30301',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13107,30302,-5,'Atlanta, Georgia 30302',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13108,30303,-5,'Atlanta, Georgia 30303',9514,11552);
INSERT INTO "django_geo_db_zipcode" VALUES(13109,30304,-5,'Atlanta, Georgia 30304',9514,11553);
INSERT INTO "django_geo_db_zipcode" VALUES(13110,30305,-5,'Atlanta, Georgia 30305',9514,11554);
INSERT INTO "django_geo_db_zipcode" VALUES(13111,30306,-5,'Atlanta, Georgia 30306',9514,11555);
INSERT INTO "django_geo_db_zipcode" VALUES(13112,30307,-5,'Atlanta, Georgia 30307',9514,11556);
INSERT INTO "django_geo_db_zipcode" VALUES(13113,30308,-5,'Atlanta, Georgia 30308',9514,11557);
INSERT INTO "django_geo_db_zipcode" VALUES(13114,30309,-5,'Atlanta, Georgia 30309',9514,11558);
INSERT INTO "django_geo_db_zipcode" VALUES(13115,30310,-5,'Atlanta, Georgia 30310',9514,11559);
INSERT INTO "django_geo_db_zipcode" VALUES(13116,30311,-5,'Atlanta, Georgia 30311',9514,11560);
INSERT INTO "django_geo_db_zipcode" VALUES(13117,30312,-5,'Atlanta, Georgia 30312',9514,11561);
INSERT INTO "django_geo_db_zipcode" VALUES(13118,30313,-5,'Atlanta, Georgia 30313',9514,11562);
INSERT INTO "django_geo_db_zipcode" VALUES(13119,30314,-5,'Atlanta, Georgia 30314',9514,11563);
INSERT INTO "django_geo_db_zipcode" VALUES(13120,30315,-5,'Atlanta, Georgia 30315',9514,11564);
INSERT INTO "django_geo_db_zipcode" VALUES(13121,30316,-5,'Atlanta, Georgia 30316',9514,11565);
INSERT INTO "django_geo_db_zipcode" VALUES(13122,30317,-5,'Atlanta, Georgia 30317',9514,11566);
INSERT INTO "django_geo_db_zipcode" VALUES(13123,30318,-5,'Atlanta, Georgia 30318',9514,11567);
INSERT INTO "django_geo_db_zipcode" VALUES(13124,30319,-5,'Atlanta, Georgia 30319',9514,11568);
INSERT INTO "django_geo_db_zipcode" VALUES(13125,30320,-5,'Atlanta, Georgia 30320',9514,11569);
INSERT INTO "django_geo_db_zipcode" VALUES(13126,30321,-5,'Atlanta, Georgia 30321',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13127,30322,-5,'Atlanta, Georgia 30322',9514,11570);
INSERT INTO "django_geo_db_zipcode" VALUES(13128,30323,-5,'Atlanta, Georgia 30323',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13129,30324,-5,'Atlanta, Georgia 30324',9514,11571);
INSERT INTO "django_geo_db_zipcode" VALUES(13130,30325,-5,'Atlanta, Georgia 30325',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13131,30326,-5,'Atlanta, Georgia 30326',9514,11572);
INSERT INTO "django_geo_db_zipcode" VALUES(13132,30327,-5,'Atlanta, Georgia 30327',9514,11573);
INSERT INTO "django_geo_db_zipcode" VALUES(13133,30328,-5,'Atlanta, Georgia 30328',9514,11574);
INSERT INTO "django_geo_db_zipcode" VALUES(13134,30329,-5,'Atlanta, Georgia 30329',9514,11575);
INSERT INTO "django_geo_db_zipcode" VALUES(13135,30330,-5,'Atlanta, Georgia 30330',9514,11576);
INSERT INTO "django_geo_db_zipcode" VALUES(13136,30331,-5,'Atlanta, Georgia 30331',9514,11577);
INSERT INTO "django_geo_db_zipcode" VALUES(13137,30332,-5,'Atlanta, Georgia 30332',9514,11578);
INSERT INTO "django_geo_db_zipcode" VALUES(13138,30333,-5,'Atlanta, Georgia 30333',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13139,30334,-5,'Atlanta, Georgia 30334',9514,11579);
INSERT INTO "django_geo_db_zipcode" VALUES(13140,30335,-5,'Atlanta, Georgia 30335',9514,11580);
INSERT INTO "django_geo_db_zipcode" VALUES(13141,30336,-5,'Atlanta, Georgia 30336',9514,11581);
INSERT INTO "django_geo_db_zipcode" VALUES(13142,30337,-5,'Atlanta, Georgia 30337',9514,11582);
INSERT INTO "django_geo_db_zipcode" VALUES(13143,30338,-5,'Atlanta, Georgia 30338',9514,11583);
INSERT INTO "django_geo_db_zipcode" VALUES(13144,30339,-5,'Atlanta, Georgia 30339',9514,11584);
INSERT INTO "django_geo_db_zipcode" VALUES(13145,30340,-5,'Atlanta, Georgia 30340',9514,11585);
INSERT INTO "django_geo_db_zipcode" VALUES(13146,30341,-5,'Atlanta, Georgia 30341',9514,11586);
INSERT INTO "django_geo_db_zipcode" VALUES(13147,30342,-5,'Atlanta, Georgia 30342',9514,11587);
INSERT INTO "django_geo_db_zipcode" VALUES(13148,30343,-5,'Atlanta, Georgia 30343',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13149,30344,-5,'Atlanta, Georgia 30344',9514,11588);
INSERT INTO "django_geo_db_zipcode" VALUES(13150,30345,-5,'Atlanta, Georgia 30345',9514,11589);
INSERT INTO "django_geo_db_zipcode" VALUES(13151,30346,-5,'Atlanta, Georgia 30346',9514,11590);
INSERT INTO "django_geo_db_zipcode" VALUES(13152,30347,-5,'Atlanta, Georgia 30347',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13153,30348,-5,'Atlanta, Georgia 30348',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13154,30349,-5,'Atlanta, Georgia 30349',9514,11591);
INSERT INTO "django_geo_db_zipcode" VALUES(13155,30350,-5,'Atlanta, Georgia 30350',9514,11592);
INSERT INTO "django_geo_db_zipcode" VALUES(13156,30351,-5,'Atlanta, Georgia 30351',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13157,30353,-5,'Atlanta, Georgia 30353',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13158,30354,-5,'Atlanta, Georgia 30354',9514,11593);
INSERT INTO "django_geo_db_zipcode" VALUES(13159,30355,-5,'Atlanta, Georgia 30355',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13160,30356,-5,'Atlanta, Georgia 30356',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13161,30357,-5,'Atlanta, Georgia 30357',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13162,30358,-5,'Atlanta, Georgia 30358',9514,11594);
INSERT INTO "django_geo_db_zipcode" VALUES(13163,30359,-5,'Atlanta, Georgia 30359',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13164,30360,-5,'Atlanta, Georgia 30360',9514,11595);
INSERT INTO "django_geo_db_zipcode" VALUES(13165,30361,-5,'Atlanta, Georgia 30361',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13166,30362,-5,'Atlanta, Georgia 30362',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13167,30363,-5,'Atlanta, Georgia 30363',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13168,30364,-5,'Atlanta, Georgia 30364',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13169,30365,-5,'Atlanta, Georgia 30365',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13170,30366,-5,'Atlanta, Georgia 30366',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13171,30367,-5,'Atlanta, Georgia 30367',9514,11596);
INSERT INTO "django_geo_db_zipcode" VALUES(13172,30368,-5,'Atlanta, Georgia 30368',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13173,30369,-5,'Atlanta, Georgia 30369',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13174,30370,-5,'Atlanta, Georgia 30370',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13175,30371,-5,'Atlanta, Georgia 30371',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13176,30374,-5,'Atlanta, Georgia 30374',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13177,30375,-5,'Atlanta, Georgia 30375',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13178,30376,-5,'Atlanta, Georgia 30376',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13179,30377,-5,'Atlanta, Georgia 30377',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13180,30378,-5,'Atlanta, Georgia 30378',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13181,30379,-5,'Atlanta, Georgia 30379',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13182,30380,-5,'Atlanta, Georgia 30380',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13183,30381,-5,'Atlanta, Georgia 30381',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13184,30384,-5,'Atlanta, Georgia 30384',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13185,30385,-5,'Atlanta, Georgia 30385',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13186,30386,-5,'Atlanta, Georgia 30386',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13187,30387,-5,'Atlanta, Georgia 30387',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13188,30388,-5,'Atlanta, Georgia 30388',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13189,30389,-5,'Atlanta, Georgia 30389',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13190,30390,-5,'Atlanta, Georgia 30390',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13191,30392,-5,'Atlanta, Georgia 30392',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13192,30394,-5,'Atlanta, Georgia 30394',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13193,30396,-5,'Atlanta, Georgia 30396',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13194,30398,-5,'Atlanta, Georgia 30398',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13195,30399,-5,'Atlanta, Georgia 30399',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13196,30401,-5,'Swainsboro, Georgia 30401',9515,11597);
INSERT INTO "django_geo_db_zipcode" VALUES(13197,30410,-5,'Ailey, Georgia 30410',9516,11598);
INSERT INTO "django_geo_db_zipcode" VALUES(13198,30411,-5,'Alamo, Georgia 30411',9517,11599);
INSERT INTO "django_geo_db_zipcode" VALUES(13199,30412,-5,'Alston, Georgia 30412',9518,11600);
INSERT INTO "django_geo_db_zipcode" VALUES(13200,30413,-5,'Bartow, Georgia 30413',9519,11601);
INSERT INTO "django_geo_db_zipcode" VALUES(13201,30414,-5,'Bellville, Georgia 30414',9520,11602);
INSERT INTO "django_geo_db_zipcode" VALUES(13202,30415,-5,'Brooklet, Georgia 30415',9521,11603);
INSERT INTO "django_geo_db_zipcode" VALUES(13203,30417,-5,'Claxton, Georgia 30417',9522,11604);
INSERT INTO "django_geo_db_zipcode" VALUES(13204,30420,-5,'Cobbtown, Georgia 30420',9523,11605);
INSERT INTO "django_geo_db_zipcode" VALUES(13205,30421,-5,'Collins, Georgia 30421',9524,11606);
INSERT INTO "django_geo_db_zipcode" VALUES(13206,30423,-5,'Daisy, Georgia 30423',9525,11607);
INSERT INTO "django_geo_db_zipcode" VALUES(13207,30424,-5,'Dover, Georgia 30424',9526,11608);
INSERT INTO "django_geo_db_zipcode" VALUES(13208,30425,-5,'Garfield, Georgia 30425',9527,11609);
INSERT INTO "django_geo_db_zipcode" VALUES(13209,30426,-5,'Girard, Georgia 30426',9528,11610);
INSERT INTO "django_geo_db_zipcode" VALUES(13210,30427,-5,'Glennville, Georgia 30427',9529,11611);
INSERT INTO "django_geo_db_zipcode" VALUES(13211,30428,-5,'Glenwood, Georgia 30428',9530,11612);
INSERT INTO "django_geo_db_zipcode" VALUES(13212,30429,-5,'Hagan, Georgia 30429',9531,11613);
INSERT INTO "django_geo_db_zipcode" VALUES(13213,30434,-5,'Louisville, Georgia 30434',9532,11614);
INSERT INTO "django_geo_db_zipcode" VALUES(13214,30436,-5,'Lyons, Georgia 30436',9533,11615);
INSERT INTO "django_geo_db_zipcode" VALUES(13215,30438,-5,'Manassas, Georgia 30438',9534,11616);
INSERT INTO "django_geo_db_zipcode" VALUES(13216,30439,-5,'Metter, Georgia 30439',9535,11617);
INSERT INTO "django_geo_db_zipcode" VALUES(13217,30441,-5,'Midville, Georgia 30441',9536,11618);
INSERT INTO "django_geo_db_zipcode" VALUES(13218,30442,-5,'Millen, Georgia 30442',9537,11619);
INSERT INTO "django_geo_db_zipcode" VALUES(13219,30444,-5,'East Point, Georgia 30444',9538,11620);
INSERT INTO "django_geo_db_zipcode" VALUES(13220,30445,-5,'Mount Vernon, Georgia 30445',9539,11621);
INSERT INTO "django_geo_db_zipcode" VALUES(13221,30446,-5,'Newington, Georgia 30446',9540,11622);
INSERT INTO "django_geo_db_zipcode" VALUES(13222,30447,-5,'Norristown, Georgia 30447',9541,11623);
INSERT INTO "django_geo_db_zipcode" VALUES(13223,30448,-5,'Nunez, Georgia 30448',9542,11624);
INSERT INTO "django_geo_db_zipcode" VALUES(13224,30449,-5,'Oliver, Georgia 30449',9543,11625);
INSERT INTO "django_geo_db_zipcode" VALUES(13225,30450,-5,'Portal, Georgia 30450',9544,11626);
INSERT INTO "django_geo_db_zipcode" VALUES(13226,30451,-5,'Pulaski, Georgia 30451',9545,11627);
INSERT INTO "django_geo_db_zipcode" VALUES(13227,30452,-5,'Register, Georgia 30452',9546,11628);
INSERT INTO "django_geo_db_zipcode" VALUES(13228,30453,-5,'Reidsville, Georgia 30453',9547,11629);
INSERT INTO "django_geo_db_zipcode" VALUES(13229,30454,-5,'Rockledge, Georgia 30454',9548,11630);
INSERT INTO "django_geo_db_zipcode" VALUES(13230,30455,-5,'Rocky Ford, Georgia 30455',9549,11631);
INSERT INTO "django_geo_db_zipcode" VALUES(13231,30456,-5,'Sardis, Georgia 30456',9550,11632);
INSERT INTO "django_geo_db_zipcode" VALUES(13232,30457,-5,'Soperton, Georgia 30457',9551,11633);
INSERT INTO "django_geo_db_zipcode" VALUES(13233,30458,-5,'Statesboro, Georgia 30458',9552,11634);
INSERT INTO "django_geo_db_zipcode" VALUES(13234,30459,-5,'Statesboro, Georgia 30459',9552,11635);
INSERT INTO "django_geo_db_zipcode" VALUES(13235,30460,-5,'Statesboro, Georgia 30460',9552,11636);
INSERT INTO "django_geo_db_zipcode" VALUES(13236,30461,-5,'Statesboro, Georgia 30461',9552,11637);
INSERT INTO "django_geo_db_zipcode" VALUES(13237,30464,-5,'Stillmore, Georgia 30464',9553,11638);
INSERT INTO "django_geo_db_zipcode" VALUES(13238,30466,-5,'Summertown, Georgia 30466',9554,11639);
INSERT INTO "django_geo_db_zipcode" VALUES(13239,30467,-5,'Sylvania, Georgia 30467',9555,11640);
INSERT INTO "django_geo_db_zipcode" VALUES(13240,30470,-5,'Tarrytown, Georgia 30470',9556,11641);
INSERT INTO "django_geo_db_zipcode" VALUES(13241,30471,-5,'Twin City, Georgia 30471',9557,11642);
INSERT INTO "django_geo_db_zipcode" VALUES(13242,30473,-5,'Uvalda, Georgia 30473',9558,11643);
INSERT INTO "django_geo_db_zipcode" VALUES(13243,30474,-5,'Vidalia, Georgia 30474',9559,11644);
INSERT INTO "django_geo_db_zipcode" VALUES(13244,30475,-5,'Vidalia, Georgia 30475',9559,11645);
INSERT INTO "django_geo_db_zipcode" VALUES(13245,30477,-5,'Wadley, Georgia 30477',9560,11646);
INSERT INTO "django_geo_db_zipcode" VALUES(13246,30499,-5,'Reidsville, Georgia 30499',9547,11647);
INSERT INTO "django_geo_db_zipcode" VALUES(13247,30501,-5,'Gainesville, Georgia 30501',9561,11648);
INSERT INTO "django_geo_db_zipcode" VALUES(13248,30502,-5,'Chestnut Mountain, Georgia 30502',9562,11649);
INSERT INTO "django_geo_db_zipcode" VALUES(13249,30503,-5,'Gainesville, Georgia 30503',9561,11650);
INSERT INTO "django_geo_db_zipcode" VALUES(13250,30504,-5,'Gainesville, Georgia 30504',9561,11651);
INSERT INTO "django_geo_db_zipcode" VALUES(13251,30505,-5,'Gainesville, Georgia 30505',9561,11652);
INSERT INTO "django_geo_db_zipcode" VALUES(13252,30506,-5,'Gainesville, Georgia 30506',9561,11653);
INSERT INTO "django_geo_db_zipcode" VALUES(13253,30507,-5,'Gainesville, Georgia 30507',9561,11654);
INSERT INTO "django_geo_db_zipcode" VALUES(13254,30510,-5,'Alto, Georgia 30510',9563,11655);
INSERT INTO "django_geo_db_zipcode" VALUES(13255,30511,-5,'Baldwin, Georgia 30511',9564,11656);
INSERT INTO "django_geo_db_zipcode" VALUES(13256,30512,-5,'Blairsville, Georgia 30512',9565,11657);
INSERT INTO "django_geo_db_zipcode" VALUES(13257,30513,-5,'Blue Ridge, Georgia 30513',9566,11658);
INSERT INTO "django_geo_db_zipcode" VALUES(13258,30514,-5,'Blairsville, Georgia 30514',9565,11659);
INSERT INTO "django_geo_db_zipcode" VALUES(13259,30515,-5,'Buford, Georgia 30515',9567,11347);
INSERT INTO "django_geo_db_zipcode" VALUES(13260,30516,-5,'Bowersville, Georgia 30516',9568,11660);
INSERT INTO "django_geo_db_zipcode" VALUES(13261,30517,-5,'Braselton, Georgia 30517',9569,11661);
INSERT INTO "django_geo_db_zipcode" VALUES(13262,30518,-5,'Buford, Georgia 30518',9567,11662);
INSERT INTO "django_geo_db_zipcode" VALUES(13263,30519,-5,'Buford, Georgia 30519',9567,11663);
INSERT INTO "django_geo_db_zipcode" VALUES(13264,30520,-5,'Canon, Georgia 30520',9570,11664);
INSERT INTO "django_geo_db_zipcode" VALUES(13265,30521,-5,'Carnesville, Georgia 30521',9571,11665);
INSERT INTO "django_geo_db_zipcode" VALUES(13266,30522,-5,'Cherrylog, Georgia 30522',9572,11666);
INSERT INTO "django_geo_db_zipcode" VALUES(13267,30523,-5,'Clarkesville, Georgia 30523',9573,11667);
INSERT INTO "django_geo_db_zipcode" VALUES(13268,30525,-5,'Clayton, Georgia 30525',9574,11668);
INSERT INTO "django_geo_db_zipcode" VALUES(13269,30527,-5,'Clermont, Georgia 30527',9575,11669);
INSERT INTO "django_geo_db_zipcode" VALUES(13270,30528,-5,'Cleveland, Georgia 30528',9576,11670);
INSERT INTO "django_geo_db_zipcode" VALUES(13271,30529,-5,'Commerce, Georgia 30529',9577,11671);
INSERT INTO "django_geo_db_zipcode" VALUES(13272,30530,-5,'Commerce, Georgia 30530',9577,11672);
INSERT INTO "django_geo_db_zipcode" VALUES(13273,30531,-5,'Cornelia, Georgia 30531',9578,11673);
INSERT INTO "django_geo_db_zipcode" VALUES(13274,30533,-5,'Dahlonega, Georgia 30533',9579,11674);
INSERT INTO "django_geo_db_zipcode" VALUES(13275,30534,-5,'Dawsonville, Georgia 30534',9580,11675);
INSERT INTO "django_geo_db_zipcode" VALUES(13276,30535,-5,'Demorest, Georgia 30535',9581,11676);
INSERT INTO "django_geo_db_zipcode" VALUES(13277,30537,-5,'Dillard, Georgia 30537',9582,11677);
INSERT INTO "django_geo_db_zipcode" VALUES(13278,30538,-5,'Eastanollee, Georgia 30538',9583,11678);
INSERT INTO "django_geo_db_zipcode" VALUES(13279,30539,-5,'East Ellijay, Georgia 30539',9584,11679);
INSERT INTO "django_geo_db_zipcode" VALUES(13280,30540,-5,'Ellijay, Georgia 30540',9585,11680);
INSERT INTO "django_geo_db_zipcode" VALUES(13281,30541,-5,'Epworth, Georgia 30541',9586,11681);
INSERT INTO "django_geo_db_zipcode" VALUES(13282,30542,-5,'Flowery Branch, Georgia 30542',9587,11682);
INSERT INTO "django_geo_db_zipcode" VALUES(13283,30543,-5,'Gillsville, Georgia 30543',9588,11683);
INSERT INTO "django_geo_db_zipcode" VALUES(13284,30544,-5,'Demorest, Georgia 30544',9581,11684);
INSERT INTO "django_geo_db_zipcode" VALUES(13285,30545,-5,'Helen, Georgia 30545',9589,11685);
INSERT INTO "django_geo_db_zipcode" VALUES(13286,30546,-5,'Hiawassee, Georgia 30546',9590,11686);
INSERT INTO "django_geo_db_zipcode" VALUES(13287,30547,-5,'Homer, Georgia 30547',9591,11687);
INSERT INTO "django_geo_db_zipcode" VALUES(13288,30548,-5,'Hoschton, Georgia 30548',9592,11688);
INSERT INTO "django_geo_db_zipcode" VALUES(13289,30549,-5,'Jefferson, Georgia 30549',9593,11689);
INSERT INTO "django_geo_db_zipcode" VALUES(13290,30552,-5,'Lakemont, Georgia 30552',9594,11690);
INSERT INTO "django_geo_db_zipcode" VALUES(13291,30553,-5,'Lavonia, Georgia 30553',9595,11691);
INSERT INTO "django_geo_db_zipcode" VALUES(13292,30554,-5,'Lula, Georgia 30554',9596,11692);
INSERT INTO "django_geo_db_zipcode" VALUES(13293,30555,-5,'McCaysville, Georgia 30555',9597,11693);
INSERT INTO "django_geo_db_zipcode" VALUES(13294,30557,-5,'Martin, Georgia 30557',9598,11694);
INSERT INTO "django_geo_db_zipcode" VALUES(13295,30558,-5,'Maysville, Georgia 30558',9599,11695);
INSERT INTO "django_geo_db_zipcode" VALUES(13296,30559,-5,'Mineral Bluff, Georgia 30559',9600,11696);
INSERT INTO "django_geo_db_zipcode" VALUES(13297,30560,-5,'Morganton, Georgia 30560',9601,11697);
INSERT INTO "django_geo_db_zipcode" VALUES(13298,30562,-5,'Mountain City, Georgia 30562',9602,11698);
INSERT INTO "django_geo_db_zipcode" VALUES(13299,30563,-5,'Mount Airy, Georgia 30563',9603,11699);
INSERT INTO "django_geo_db_zipcode" VALUES(13300,30564,-5,'Murrayville, Georgia 30564',9604,11700);
INSERT INTO "django_geo_db_zipcode" VALUES(13301,30565,-5,'Nicholson, Georgia 30565',9605,11701);
INSERT INTO "django_geo_db_zipcode" VALUES(13302,30566,-5,'Oakwood, Georgia 30566',9606,11702);
INSERT INTO "django_geo_db_zipcode" VALUES(13303,30567,-5,'Pendergrass, Georgia 30567',9607,11703);
INSERT INTO "django_geo_db_zipcode" VALUES(13304,30568,-5,'Rabun Gap, Georgia 30568',9608,11704);
INSERT INTO "django_geo_db_zipcode" VALUES(13305,30571,-5,'Sautee Nacoochee, Georgia 30571',9609,11705);
INSERT INTO "django_geo_db_zipcode" VALUES(13306,30572,-5,'Suches, Georgia 30572',9610,11706);
INSERT INTO "django_geo_db_zipcode" VALUES(13307,30573,-5,'Tallulah Falls, Georgia 30573',9611,11707);
INSERT INTO "django_geo_db_zipcode" VALUES(13308,30575,-5,'Talmo, Georgia 30575',9612,11708);
INSERT INTO "django_geo_db_zipcode" VALUES(13309,30576,-5,'Tiger, Georgia 30576',9613,11709);
INSERT INTO "django_geo_db_zipcode" VALUES(13310,30577,-5,'Toccoa, Georgia 30577',9614,11710);
INSERT INTO "django_geo_db_zipcode" VALUES(13311,30580,-5,'Turnerville, Georgia 30580',9615,11711);
INSERT INTO "django_geo_db_zipcode" VALUES(13312,30581,-5,'Wiley, Georgia 30581',9616,11712);
INSERT INTO "django_geo_db_zipcode" VALUES(13313,30582,-5,'Young Harris, Georgia 30582',9617,11713);
INSERT INTO "django_geo_db_zipcode" VALUES(13314,30596,-5,'Alto, Georgia 30596',9563,11714);
INSERT INTO "django_geo_db_zipcode" VALUES(13315,30597,-5,'Dahlonega, Georgia 30597',9579,11715);
INSERT INTO "django_geo_db_zipcode" VALUES(13316,30598,-5,'Toccoa, Georgia 30598',9614,11716);
INSERT INTO "django_geo_db_zipcode" VALUES(13317,30599,-5,'Commerce, Georgia 30599',9577,11717);
INSERT INTO "django_geo_db_zipcode" VALUES(13318,30601,-5,'Athens, Georgia 30601',9618,11718);
INSERT INTO "django_geo_db_zipcode" VALUES(13319,30602,-5,'Athens, Georgia 30602',9618,11719);
INSERT INTO "django_geo_db_zipcode" VALUES(13320,30603,-5,'Athens, Georgia 30603',9618,11720);
INSERT INTO "django_geo_db_zipcode" VALUES(13321,30604,-5,'Athens, Georgia 30604',9618,11721);
INSERT INTO "django_geo_db_zipcode" VALUES(13322,30605,-5,'Athens, Georgia 30605',9618,11722);
INSERT INTO "django_geo_db_zipcode" VALUES(13323,30606,-5,'Athens, Georgia 30606',9618,11723);
INSERT INTO "django_geo_db_zipcode" VALUES(13324,30607,-5,'Athens, Georgia 30607',9618,11724);
INSERT INTO "django_geo_db_zipcode" VALUES(13325,30608,-5,'Athens, Georgia 30608',9618,11721);
INSERT INTO "django_geo_db_zipcode" VALUES(13326,30609,-5,'Athens, Georgia 30609',9618,11725);
INSERT INTO "django_geo_db_zipcode" VALUES(13327,30610,-5,'Athens, Georgia 30610',9618,11721);
INSERT INTO "django_geo_db_zipcode" VALUES(13328,30612,-5,'Athens, Georgia 30612',9618,11721);
INSERT INTO "django_geo_db_zipcode" VALUES(13329,30613,-5,'Athens, Georgia 30613',9618,11726);
INSERT INTO "django_geo_db_zipcode" VALUES(13330,30619,-5,'Arnoldsville, Georgia 30619',9619,11727);
INSERT INTO "django_geo_db_zipcode" VALUES(13331,30620,-5,'Bethlehem, Georgia 30620',9620,11728);
INSERT INTO "django_geo_db_zipcode" VALUES(13332,30621,-5,'Bishop, Georgia 30621',9621,11729);
INSERT INTO "django_geo_db_zipcode" VALUES(13333,30622,-5,'Bogart, Georgia 30622',9622,11730);
INSERT INTO "django_geo_db_zipcode" VALUES(13334,30623,-5,'Bostwick, Georgia 30623',9623,11731);
INSERT INTO "django_geo_db_zipcode" VALUES(13335,30624,-5,'Bowman, Georgia 30624',9624,11732);
INSERT INTO "django_geo_db_zipcode" VALUES(13336,30625,-5,'Buckhead, Georgia 30625',9625,11733);
INSERT INTO "django_geo_db_zipcode" VALUES(13337,30627,-5,'Carlton, Georgia 30627',9626,11734);
INSERT INTO "django_geo_db_zipcode" VALUES(13338,30628,-5,'Colbert, Georgia 30628',9627,11735);
INSERT INTO "django_geo_db_zipcode" VALUES(13339,30629,-5,'Comer, Georgia 30629',9628,11736);
INSERT INTO "django_geo_db_zipcode" VALUES(13340,30630,-5,'Crawford, Georgia 30630',9629,11737);
INSERT INTO "django_geo_db_zipcode" VALUES(13341,30631,-5,'Crawfordville, Georgia 30631',9630,11738);
INSERT INTO "django_geo_db_zipcode" VALUES(13342,30633,-5,'Danielsville, Georgia 30633',9631,11739);
INSERT INTO "django_geo_db_zipcode" VALUES(13343,30634,-5,'Dewy Rose, Georgia 30634',9632,11740);
INSERT INTO "django_geo_db_zipcode" VALUES(13344,30635,-5,'Elberton, Georgia 30635',9633,11741);
INSERT INTO "django_geo_db_zipcode" VALUES(13345,30638,-5,'Farmington, Georgia 30638',9634,11742);
INSERT INTO "django_geo_db_zipcode" VALUES(13346,30639,-5,'Franklin Springs, Georgia 30639',9635,11743);
INSERT INTO "django_geo_db_zipcode" VALUES(13347,30641,-5,'Good Hope, Georgia 30641',9636,11744);
INSERT INTO "django_geo_db_zipcode" VALUES(13348,30642,-5,'Greensboro, Georgia 30642',9637,11745);
INSERT INTO "django_geo_db_zipcode" VALUES(13349,30643,-5,'Hartwell, Georgia 30643',9638,11746);
INSERT INTO "django_geo_db_zipcode" VALUES(13350,30645,-5,'High Shoals, Georgia 30645',9639,11747);
INSERT INTO "django_geo_db_zipcode" VALUES(13351,30646,-5,'Hull, Georgia 30646',9640,11748);
INSERT INTO "django_geo_db_zipcode" VALUES(13352,30647,-5,'Ila, Georgia 30647',9641,11749);
INSERT INTO "django_geo_db_zipcode" VALUES(13353,30648,-5,'Lexington, Georgia 30648',9642,11750);
INSERT INTO "django_geo_db_zipcode" VALUES(13354,30650,-5,'Madison, Georgia 30650',9643,11751);
INSERT INTO "django_geo_db_zipcode" VALUES(13355,30652,-5,'Greensboro, Georgia 30652',9637,11752);
INSERT INTO "django_geo_db_zipcode" VALUES(13356,30655,-5,'Monroe, Georgia 30655',9644,11753);
INSERT INTO "django_geo_db_zipcode" VALUES(13357,30656,-5,'Monroe, Georgia 30656',9644,11754);
INSERT INTO "django_geo_db_zipcode" VALUES(13358,30660,-5,'Rayle, Georgia 30660',9645,11755);
INSERT INTO "django_geo_db_zipcode" VALUES(13359,30662,-5,'Royston, Georgia 30662',9646,11756);
INSERT INTO "django_geo_db_zipcode" VALUES(13360,30663,-5,'Rutledge, Georgia 30663',9647,11757);
INSERT INTO "django_geo_db_zipcode" VALUES(13361,30664,-5,'Sharon, Georgia 30664',9648,11758);
INSERT INTO "django_geo_db_zipcode" VALUES(13362,30665,-5,'Siloam, Georgia 30665',9649,11759);
INSERT INTO "django_geo_db_zipcode" VALUES(13363,30666,-5,'Statham, Georgia 30666',9650,11760);
INSERT INTO "django_geo_db_zipcode" VALUES(13364,30667,-5,'Stephens, Georgia 30667',9651,11761);
INSERT INTO "django_geo_db_zipcode" VALUES(13365,30668,-5,'Tignall, Georgia 30668',9652,11762);
INSERT INTO "django_geo_db_zipcode" VALUES(13366,30669,-5,'Union Point, Georgia 30669',9653,11763);
INSERT INTO "django_geo_db_zipcode" VALUES(13367,30671,-5,'Maxeys, Georgia 30671',9654,11764);
INSERT INTO "django_geo_db_zipcode" VALUES(13368,30673,-5,'Washington, Georgia 30673',9655,11765);
INSERT INTO "django_geo_db_zipcode" VALUES(13369,30677,-5,'Watkinsville, Georgia 30677',9656,11766);
INSERT INTO "django_geo_db_zipcode" VALUES(13370,30678,-5,'White Plains, Georgia 30678',9657,11767);
INSERT INTO "django_geo_db_zipcode" VALUES(13371,30680,-5,'Winder, Georgia 30680',9658,11768);
INSERT INTO "django_geo_db_zipcode" VALUES(13372,30683,-5,'Winterville, Georgia 30683',9659,11769);
INSERT INTO "django_geo_db_zipcode" VALUES(13373,30701,-5,'Calhoun, Georgia 30701',9660,11770);
INSERT INTO "django_geo_db_zipcode" VALUES(13374,30703,-5,'Calhoun, Georgia 30703',9660,11771);
INSERT INTO "django_geo_db_zipcode" VALUES(13375,30705,-5,'Chatsworth, Georgia 30705',9661,11772);
INSERT INTO "django_geo_db_zipcode" VALUES(13376,30707,-5,'Chickamauga, Georgia 30707',9662,11773);
INSERT INTO "django_geo_db_zipcode" VALUES(13377,30708,-5,'Cisco, Georgia 30708',9663,11774);
INSERT INTO "django_geo_db_zipcode" VALUES(13378,30710,-5,'Cohutta, Georgia 30710',9664,11775);
INSERT INTO "django_geo_db_zipcode" VALUES(13379,30711,-5,'Crandall, Georgia 30711',9665,11776);
INSERT INTO "django_geo_db_zipcode" VALUES(13380,30716,-5,'Tallapoosa, Georgia 30716',9450,11777);
INSERT INTO "django_geo_db_zipcode" VALUES(13381,30719,-5,'Dalton, Georgia 30719',9666,11778);
INSERT INTO "django_geo_db_zipcode" VALUES(13382,30720,-5,'Dalton, Georgia 30720',9666,11779);
INSERT INTO "django_geo_db_zipcode" VALUES(13383,30721,-5,'Dalton, Georgia 30721',9666,11780);
INSERT INTO "django_geo_db_zipcode" VALUES(13384,30722,-5,'Dalton, Georgia 30722',9666,11781);
INSERT INTO "django_geo_db_zipcode" VALUES(13385,30724,-5,'Eton, Georgia 30724',9667,11782);
INSERT INTO "django_geo_db_zipcode" VALUES(13386,30725,-5,'Flintstone, Georgia 30725',9668,11783);
INSERT INTO "django_geo_db_zipcode" VALUES(13387,30726,-5,'Graysville, Georgia 30726',9669,11784);
INSERT INTO "django_geo_db_zipcode" VALUES(13388,30728,-5,'La Fayette, Georgia 30728',9670,11785);
INSERT INTO "django_geo_db_zipcode" VALUES(13389,30730,-5,'Lyerly, Georgia 30730',9671,11786);
INSERT INTO "django_geo_db_zipcode" VALUES(13390,30731,-5,'Menlo, Georgia 30731',9672,11787);
INSERT INTO "django_geo_db_zipcode" VALUES(13391,30732,-5,'Oakman, Georgia 30732',9673,11788);
INSERT INTO "django_geo_db_zipcode" VALUES(13392,30733,-5,'Plainville, Georgia 30733',9674,11789);
INSERT INTO "django_geo_db_zipcode" VALUES(13393,30734,-5,'Ranger, Georgia 30734',9675,11790);
INSERT INTO "django_geo_db_zipcode" VALUES(13394,30735,-5,'Resaca, Georgia 30735',9676,11791);
INSERT INTO "django_geo_db_zipcode" VALUES(13395,30736,-5,'Ringgold, Georgia 30736',9677,11792);
INSERT INTO "django_geo_db_zipcode" VALUES(13396,30738,-5,'Rising Fawn, Georgia 30738',9678,11793);
INSERT INTO "django_geo_db_zipcode" VALUES(13397,30739,-5,'Rock Spring, Georgia 30739',9679,11794);
INSERT INTO "django_geo_db_zipcode" VALUES(13398,30740,-5,'Rocky Face, Georgia 30740',9680,11795);
INSERT INTO "django_geo_db_zipcode" VALUES(13399,30741,-5,'Rossville, Georgia 30741',9681,11796);
INSERT INTO "django_geo_db_zipcode" VALUES(13400,30742,-5,'Fort Oglethorpe, Georgia 30742',9682,11797);
INSERT INTO "django_geo_db_zipcode" VALUES(13401,30746,-5,'Sugar Valley, Georgia 30746',9683,11798);
INSERT INTO "django_geo_db_zipcode" VALUES(13402,30747,-5,'Summerville, Georgia 30747',9684,11799);
INSERT INTO "django_geo_db_zipcode" VALUES(13403,30750,-5,'Lookout Mountain, Georgia 30750',9685,11800);
INSERT INTO "django_geo_db_zipcode" VALUES(13404,30751,-5,'Tennga, Georgia 30751',9686,11801);
INSERT INTO "django_geo_db_zipcode" VALUES(13405,30752,-5,'Trenton, Georgia 30752',9687,11802);
INSERT INTO "django_geo_db_zipcode" VALUES(13406,30753,-5,'Trion, Georgia 30753',9688,11803);
INSERT INTO "django_geo_db_zipcode" VALUES(13407,30754,-5,'Summerville, Georgia 30754',9684,11804);
INSERT INTO "django_geo_db_zipcode" VALUES(13408,30755,-5,'Tunnel Hill, Georgia 30755',9689,11805);
INSERT INTO "django_geo_db_zipcode" VALUES(13409,30756,-5,'Varnell, Georgia 30756',9690,11806);
INSERT INTO "django_geo_db_zipcode" VALUES(13410,30757,-5,'Wildwood, Georgia 30757',9691,11807);
INSERT INTO "django_geo_db_zipcode" VALUES(13411,30802,-5,'Appling, Georgia 30802',9692,11808);
INSERT INTO "django_geo_db_zipcode" VALUES(13412,30803,-5,'Avera, Georgia 30803',9693,11809);
INSERT INTO "django_geo_db_zipcode" VALUES(13413,30805,-5,'Blythe, Georgia 30805',9694,11810);
INSERT INTO "django_geo_db_zipcode" VALUES(13414,30806,-5,'Boneville, Georgia 30806',9695,11811);
INSERT INTO "django_geo_db_zipcode" VALUES(13415,30807,-5,'Camak, Georgia 30807',9696,11812);
INSERT INTO "django_geo_db_zipcode" VALUES(13416,30808,-5,'Dearing, Georgia 30808',9697,11813);
INSERT INTO "django_geo_db_zipcode" VALUES(13417,30809,-5,'Evans, Georgia 30809',9698,11814);
INSERT INTO "django_geo_db_zipcode" VALUES(13418,30810,-5,'Gibson, Georgia 30810',9699,11815);
INSERT INTO "django_geo_db_zipcode" VALUES(13419,30811,-5,'Gough, Georgia 30811',9700,11816);
INSERT INTO "django_geo_db_zipcode" VALUES(13420,30812,-5,'Gracewood, Georgia 30812',9701,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13421,30813,-5,'Grovetown, Georgia 30813',9702,11818);
INSERT INTO "django_geo_db_zipcode" VALUES(13422,30814,-5,'Harlem, Georgia 30814',9703,11819);
INSERT INTO "django_geo_db_zipcode" VALUES(13423,30815,-5,'Hephzibah, Georgia 30815',9704,11820);
INSERT INTO "django_geo_db_zipcode" VALUES(13424,30816,-5,'Keysville, Georgia 30816',9705,11821);
INSERT INTO "django_geo_db_zipcode" VALUES(13425,30817,-5,'Lincolnton, Georgia 30817',9706,11822);
INSERT INTO "django_geo_db_zipcode" VALUES(13426,30818,-5,'Matthews, Georgia 30818',9707,11823);
INSERT INTO "django_geo_db_zipcode" VALUES(13427,30819,-5,'Mesena, Georgia 30819',9708,11824);
INSERT INTO "django_geo_db_zipcode" VALUES(13428,30820,-5,'Mitchell, Georgia 30820',9709,11825);
INSERT INTO "django_geo_db_zipcode" VALUES(13429,30821,-5,'Norwood, Georgia 30821',9710,11826);
INSERT INTO "django_geo_db_zipcode" VALUES(13430,30822,-5,'Perkins, Georgia 30822',9711,11827);
INSERT INTO "django_geo_db_zipcode" VALUES(13431,30823,-5,'Stapleton, Georgia 30823',9712,11828);
INSERT INTO "django_geo_db_zipcode" VALUES(13432,30824,-5,'Thomson, Georgia 30824',9713,11829);
INSERT INTO "django_geo_db_zipcode" VALUES(13433,30828,-5,'Warrenton, Georgia 30828',9714,11830);
INSERT INTO "django_geo_db_zipcode" VALUES(13434,30830,-5,'Waynesboro, Georgia 30830',9715,11831);
INSERT INTO "django_geo_db_zipcode" VALUES(13435,30833,-5,'Wrens, Georgia 30833',9716,11832);
INSERT INTO "django_geo_db_zipcode" VALUES(13436,30881,-5,'Atlanta, Georgia 30881',9514,11833);
INSERT INTO "django_geo_db_zipcode" VALUES(13437,30901,-5,'Augusta, Georgia 30901',9717,11834);
INSERT INTO "django_geo_db_zipcode" VALUES(13438,30903,-5,'Augusta, Georgia 30903',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13439,30904,-5,'Augusta, Georgia 30904',9717,11835);
INSERT INTO "django_geo_db_zipcode" VALUES(13440,30905,-5,'Augusta, Georgia 30905',9717,11836);
INSERT INTO "django_geo_db_zipcode" VALUES(13441,30906,-5,'Augusta, Georgia 30906',9717,11837);
INSERT INTO "django_geo_db_zipcode" VALUES(13442,30907,-5,'Augusta, Georgia 30907',9717,11838);
INSERT INTO "django_geo_db_zipcode" VALUES(13443,30909,-5,'Augusta, Georgia 30909',9717,11839);
INSERT INTO "django_geo_db_zipcode" VALUES(13444,30910,-5,'Augusta, Georgia 30910',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13445,30911,-5,'Augusta, Georgia 30911',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13446,30912,-5,'Augusta, Georgia 30912',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13447,30913,-5,'Augusta, Georgia 30913',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13448,30914,-5,'Augusta, Georgia 30914',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13449,30916,-5,'Augusta, Georgia 30916',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13450,30917,-5,'Augusta, Georgia 30917',9717,11840);
INSERT INTO "django_geo_db_zipcode" VALUES(13451,30919,-5,'Augusta, Georgia 30919',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13452,30999,-5,'Augusta, Georgia 30999',9717,11817);
INSERT INTO "django_geo_db_zipcode" VALUES(13453,31001,-5,'Abbeville, Georgia 31001',9718,11841);
INSERT INTO "django_geo_db_zipcode" VALUES(13454,31002,-5,'Adrian, Georgia 31002',9719,11842);
INSERT INTO "django_geo_db_zipcode" VALUES(13455,31003,-5,'Allentown, Georgia 31003',9720,11843);
INSERT INTO "django_geo_db_zipcode" VALUES(13456,31004,-5,'Bolingbroke, Georgia 31004',9721,11844);
INSERT INTO "django_geo_db_zipcode" VALUES(13457,31005,-5,'Bonaire, Georgia 31005',9722,11845);
INSERT INTO "django_geo_db_zipcode" VALUES(13458,31006,-5,'Butler, Georgia 31006',9723,11846);
INSERT INTO "django_geo_db_zipcode" VALUES(13459,31007,-5,'Byromville, Georgia 31007',9724,11847);
INSERT INTO "django_geo_db_zipcode" VALUES(13460,31008,-5,'Byron, Georgia 31008',9725,11848);
INSERT INTO "django_geo_db_zipcode" VALUES(13461,31009,-5,'Cadwell, Georgia 31009',9726,11849);
INSERT INTO "django_geo_db_zipcode" VALUES(13462,31010,-5,'Cordele, Georgia 31010',9727,11850);
INSERT INTO "django_geo_db_zipcode" VALUES(13463,31011,-5,'Chauncey, Georgia 31011',9728,11851);
INSERT INTO "django_geo_db_zipcode" VALUES(13464,31012,-5,'Chester, Georgia 31012',9729,11852);
INSERT INTO "django_geo_db_zipcode" VALUES(13465,31013,-5,'Clinchfield, Georgia 31013',9730,11853);
INSERT INTO "django_geo_db_zipcode" VALUES(13466,31014,-5,'Cochran, Georgia 31014',9731,11854);
INSERT INTO "django_geo_db_zipcode" VALUES(13467,31015,-5,'Cordele, Georgia 31015',9727,11855);
INSERT INTO "django_geo_db_zipcode" VALUES(13468,31016,-5,'Culloden, Georgia 31016',9732,11856);
INSERT INTO "django_geo_db_zipcode" VALUES(13469,31017,-5,'Danville, Georgia 31017',9733,11857);
INSERT INTO "django_geo_db_zipcode" VALUES(13470,31018,-5,'Davisboro, Georgia 31018',9734,11858);
INSERT INTO "django_geo_db_zipcode" VALUES(13471,31019,-5,'Dexter, Georgia 31019',9735,11859);
INSERT INTO "django_geo_db_zipcode" VALUES(13472,31020,-5,'Dry Branch, Georgia 31020',9736,11860);
INSERT INTO "django_geo_db_zipcode" VALUES(13473,31021,-5,'Dublin, Georgia 31021',9737,11861);
INSERT INTO "django_geo_db_zipcode" VALUES(13474,31022,-5,'Dudley, Georgia 31022',9738,11862);
INSERT INTO "django_geo_db_zipcode" VALUES(13475,31023,-5,'Eastman, Georgia 31023',9739,11863);
INSERT INTO "django_geo_db_zipcode" VALUES(13476,31024,-5,'Eatonton, Georgia 31024',9740,11864);
INSERT INTO "django_geo_db_zipcode" VALUES(13477,31025,-5,'Elko, Georgia 31025',9741,11865);
INSERT INTO "django_geo_db_zipcode" VALUES(13478,31027,-5,'Dublin, Georgia 31027',9737,11866);
INSERT INTO "django_geo_db_zipcode" VALUES(13479,31028,-5,'Centerville, Georgia 31028',9742,11867);
INSERT INTO "django_geo_db_zipcode" VALUES(13480,31029,-5,'Forsyth, Georgia 31029',9743,11868);
INSERT INTO "django_geo_db_zipcode" VALUES(13481,31030,-5,'Fort Valley, Georgia 31030',9744,11869);
INSERT INTO "django_geo_db_zipcode" VALUES(13482,31031,-5,'Gordon, Georgia 31031',9745,11870);
INSERT INTO "django_geo_db_zipcode" VALUES(13483,31032,-5,'Gray, Georgia 31032',9746,11871);
INSERT INTO "django_geo_db_zipcode" VALUES(13484,31033,-5,'Haddock, Georgia 31033',9747,11872);
INSERT INTO "django_geo_db_zipcode" VALUES(13485,31034,-5,'Hardwick, Georgia 31034',9748,11873);
INSERT INTO "django_geo_db_zipcode" VALUES(13486,31035,-5,'Harrison, Georgia 31035',9749,11874);
INSERT INTO "django_geo_db_zipcode" VALUES(13487,31036,-5,'Hawkinsville, Georgia 31036',9750,11875);
INSERT INTO "django_geo_db_zipcode" VALUES(13488,31037,-5,'Helena, Georgia 31037',9751,11876);
INSERT INTO "django_geo_db_zipcode" VALUES(13489,31038,-5,'Hillsboro, Georgia 31038',9752,11877);
INSERT INTO "django_geo_db_zipcode" VALUES(13490,31039,-5,'Howard, Georgia 31039',9753,11878);
INSERT INTO "django_geo_db_zipcode" VALUES(13491,31040,-5,'Dublin, Georgia 31040',9737,11879);
INSERT INTO "django_geo_db_zipcode" VALUES(13492,31041,-5,'Ideal, Georgia 31041',9754,11880);
INSERT INTO "django_geo_db_zipcode" VALUES(13493,31042,-5,'Irwinton, Georgia 31042',9755,11881);
INSERT INTO "django_geo_db_zipcode" VALUES(13494,31044,-5,'Jeffersonville, Georgia 31044',9756,11882);
INSERT INTO "django_geo_db_zipcode" VALUES(13495,31045,-5,'Jewell, Georgia 31045',9757,11883);
INSERT INTO "django_geo_db_zipcode" VALUES(13496,31046,-5,'Juliette, Georgia 31046',9758,11884);
INSERT INTO "django_geo_db_zipcode" VALUES(13497,31047,-5,'Kathleen, Georgia 31047',9759,11885);
INSERT INTO "django_geo_db_zipcode" VALUES(13498,31049,-5,'Kite, Georgia 31049',9760,11886);
INSERT INTO "django_geo_db_zipcode" VALUES(13499,31050,-5,'Knoxville, Georgia 31050',9761,11887);
INSERT INTO "django_geo_db_zipcode" VALUES(13500,31051,-5,'Lilly, Georgia 31051',9762,11888);
INSERT INTO "django_geo_db_zipcode" VALUES(13501,31052,-5,'Lizella, Georgia 31052',9763,11889);
INSERT INTO "django_geo_db_zipcode" VALUES(13502,31054,-5,'McIntyre, Georgia 31054',9764,11890);
INSERT INTO "django_geo_db_zipcode" VALUES(13503,31055,-5,'McRae, Georgia 31055',9765,11891);
INSERT INTO "django_geo_db_zipcode" VALUES(13504,31057,-5,'Marshallville, Georgia 31057',9766,11892);
INSERT INTO "django_geo_db_zipcode" VALUES(13505,31058,-5,'Mauk, Georgia 31058',9767,11893);
INSERT INTO "django_geo_db_zipcode" VALUES(13506,31060,-5,'Milan, Georgia 31060',9768,11894);
INSERT INTO "django_geo_db_zipcode" VALUES(13507,31061,-5,'Milledgeville, Georgia 31061',9769,11895);
INSERT INTO "django_geo_db_zipcode" VALUES(13508,31062,-5,'Milledgeville, Georgia 31062',9769,11896);
INSERT INTO "django_geo_db_zipcode" VALUES(13509,31063,-5,'Montezuma, Georgia 31063',9770,11897);
INSERT INTO "django_geo_db_zipcode" VALUES(13510,31064,-5,'Monticello, Georgia 31064',9771,11898);
INSERT INTO "django_geo_db_zipcode" VALUES(13511,31065,-5,'Montrose, Georgia 31065',9772,11899);
INSERT INTO "django_geo_db_zipcode" VALUES(13512,31066,-5,'Musella, Georgia 31066',9773,11900);
INSERT INTO "django_geo_db_zipcode" VALUES(13513,31067,-5,'Oconee, Georgia 31067',9774,11901);
INSERT INTO "django_geo_db_zipcode" VALUES(13514,31068,-5,'Oglethorpe, Georgia 31068',9775,11902);
INSERT INTO "django_geo_db_zipcode" VALUES(13515,31069,-5,'Perry, Georgia 31069',9776,11903);
INSERT INTO "django_geo_db_zipcode" VALUES(13516,31070,-5,'Pinehurst, Georgia 31070',9777,11904);
INSERT INTO "django_geo_db_zipcode" VALUES(13517,31071,-5,'Pineview, Georgia 31071',9778,11905);
INSERT INTO "django_geo_db_zipcode" VALUES(13518,31072,-5,'Pitts, Georgia 31072',9779,11906);
INSERT INTO "django_geo_db_zipcode" VALUES(13519,31073,-5,'Plainfield, Georgia 31073',9780,11907);
INSERT INTO "django_geo_db_zipcode" VALUES(13520,31075,-5,'Rentz, Georgia 31075',9781,11908);
INSERT INTO "django_geo_db_zipcode" VALUES(13521,31076,-5,'Reynolds, Georgia 31076',9782,11909);
INSERT INTO "django_geo_db_zipcode" VALUES(13522,31077,-5,'Rhine, Georgia 31077',9783,11910);
INSERT INTO "django_geo_db_zipcode" VALUES(13523,31078,-5,'Roberta, Georgia 31078',9784,11911);
INSERT INTO "django_geo_db_zipcode" VALUES(13524,31079,-5,'Rochelle, Georgia 31079',9785,11912);
INSERT INTO "django_geo_db_zipcode" VALUES(13525,31081,-5,'Rupert, Georgia 31081',9786,11913);
INSERT INTO "django_geo_db_zipcode" VALUES(13526,31082,-5,'Sandersville, Georgia 31082',9787,11914);
INSERT INTO "django_geo_db_zipcode" VALUES(13527,31083,-5,'Scotland, Georgia 31083',9788,11915);
INSERT INTO "django_geo_db_zipcode" VALUES(13528,31084,-5,'Seville, Georgia 31084',9789,11916);
INSERT INTO "django_geo_db_zipcode" VALUES(13529,31085,-5,'Shady Dale, Georgia 31085',9790,11917);
INSERT INTO "django_geo_db_zipcode" VALUES(13530,31086,-5,'Smarr, Georgia 31086',9791,11918);
INSERT INTO "django_geo_db_zipcode" VALUES(13531,31087,-5,'Sparta, Georgia 31087',9792,11919);
INSERT INTO "django_geo_db_zipcode" VALUES(13532,31088,-5,'Warner Robins, Georgia 31088',9793,11920);
INSERT INTO "django_geo_db_zipcode" VALUES(13533,31089,-5,'Tennille, Georgia 31089',9794,11921);
INSERT INTO "django_geo_db_zipcode" VALUES(13534,31090,-5,'Toomsboro, Georgia 31090',9795,11922);
INSERT INTO "django_geo_db_zipcode" VALUES(13535,31091,-5,'Unadilla, Georgia 31091',9796,11923);
INSERT INTO "django_geo_db_zipcode" VALUES(13536,31092,-5,'Vienna, Georgia 31092',9797,11924);
INSERT INTO "django_geo_db_zipcode" VALUES(13537,31093,-5,'Warner Robins, Georgia 31093',9793,11925);
INSERT INTO "django_geo_db_zipcode" VALUES(13538,31094,-5,'Warthen, Georgia 31094',9798,11926);
INSERT INTO "django_geo_db_zipcode" VALUES(13539,31095,-5,'Warner Robins, Georgia 31095',9793,11927);
INSERT INTO "django_geo_db_zipcode" VALUES(13540,31096,-5,'Wrightsville, Georgia 31096',9799,11928);
INSERT INTO "django_geo_db_zipcode" VALUES(13541,31097,-5,'Yatesville, Georgia 31097',9800,11929);
INSERT INTO "django_geo_db_zipcode" VALUES(13542,31098,-5,'Warner Robins, Georgia 31098',9793,11930);
INSERT INTO "django_geo_db_zipcode" VALUES(13543,31099,-5,'Warner Robins, Georgia 31099',9793,11931);
INSERT INTO "django_geo_db_zipcode" VALUES(13544,31106,-5,'Atlanta, Georgia 31106',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13545,31107,-5,'Atlanta, Georgia 31107',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13546,31119,-5,'Atlanta, Georgia 31119',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13547,31126,-5,'Atlanta, Georgia 31126',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13548,31131,-5,'Atlanta, Georgia 31131',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13549,31139,-5,'Atlanta, Georgia 31139',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13550,31141,-5,'Atlanta, Georgia 31141',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13551,31145,-5,'Atlanta, Georgia 31145',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13552,31146,-5,'Atlanta, Georgia 31146',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(13553,31150,-5,'Atlanta, Georgia 31150',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13554,31156,-5,'Atlanta, Georgia 31156',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13555,31191,-5,'Atlanta, Georgia 31191',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13556,31192,-5,'Atlanta, Georgia 31192',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13557,31193,-5,'Atlanta, Georgia 31193',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13558,31195,-5,'Atlanta, Georgia 31195',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13559,31196,-5,'Atlanta, Georgia 31196',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13560,31197,-5,'Atlanta, Georgia 31197',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13561,31198,-5,'Atlanta, Georgia 31198',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13562,31199,-5,'Atlanta, Georgia 31199',9514,11352);
INSERT INTO "django_geo_db_zipcode" VALUES(13563,31201,-5,'Macon, Georgia 31201',9801,11932);
INSERT INTO "django_geo_db_zipcode" VALUES(13564,31202,-5,'Macon, Georgia 31202',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13565,31203,-5,'Macon, Georgia 31203',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13566,31204,-5,'Macon, Georgia 31204',9801,11934);
INSERT INTO "django_geo_db_zipcode" VALUES(13567,31205,-5,'Macon, Georgia 31205',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13568,31206,-5,'Macon, Georgia 31206',9801,11935);
INSERT INTO "django_geo_db_zipcode" VALUES(13569,31207,-5,'Macon, Georgia 31207',9801,11936);
INSERT INTO "django_geo_db_zipcode" VALUES(13570,31208,-5,'Macon, Georgia 31208',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13571,31209,-5,'Macon, Georgia 31209',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13572,31210,-5,'Macon, Georgia 31210',9801,11937);
INSERT INTO "django_geo_db_zipcode" VALUES(13573,31211,-5,'Macon, Georgia 31211',9801,11938);
INSERT INTO "django_geo_db_zipcode" VALUES(13574,31212,-5,'Macon, Georgia 31212',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13575,31213,-5,'Macon, Georgia 31213',9801,11939);
INSERT INTO "django_geo_db_zipcode" VALUES(13576,31216,-5,'Macon, Georgia 31216',9801,11940);
INSERT INTO "django_geo_db_zipcode" VALUES(13577,31217,-5,'Macon, Georgia 31217',9801,11941);
INSERT INTO "django_geo_db_zipcode" VALUES(13578,31220,-5,'Macon, Georgia 31220',9801,11942);
INSERT INTO "django_geo_db_zipcode" VALUES(13579,31221,-5,'Macon, Georgia 31221',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13580,31267,-5,'Cecil, Georgia 31267',9802,11943);
INSERT INTO "django_geo_db_zipcode" VALUES(13581,31294,-5,'Macon, Georgia 31294',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13582,31295,-5,'Macon, Georgia 31295',9801,11944);
INSERT INTO "django_geo_db_zipcode" VALUES(13583,31296,-5,'Macon, Georgia 31296',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13584,31297,-5,'Macon, Georgia 31297',9801,11945);
INSERT INTO "django_geo_db_zipcode" VALUES(13585,31298,-5,'Macon, Georgia 31298',9801,11946);
INSERT INTO "django_geo_db_zipcode" VALUES(13586,31299,-5,'Macon, Georgia 31299',9801,11933);
INSERT INTO "django_geo_db_zipcode" VALUES(13587,31301,-5,'Allenhurst, Georgia 31301',9803,11947);
INSERT INTO "django_geo_db_zipcode" VALUES(13588,31302,-5,'Bloomingdale, Georgia 31302',9804,11948);
INSERT INTO "django_geo_db_zipcode" VALUES(13589,31303,-5,'Clyo, Georgia 31303',9805,11949);
INSERT INTO "django_geo_db_zipcode" VALUES(13590,31304,-5,'Crescent, Georgia 31304',9806,11950);
INSERT INTO "django_geo_db_zipcode" VALUES(13591,31305,-5,'Darien, Georgia 31305',9807,11951);
INSERT INTO "django_geo_db_zipcode" VALUES(13592,31307,-5,'Eden, Georgia 31307',9808,11952);
INSERT INTO "django_geo_db_zipcode" VALUES(13593,31308,-5,'Ellabell, Georgia 31308',9809,11953);
INSERT INTO "django_geo_db_zipcode" VALUES(13594,31309,-5,'Fleming, Georgia 31309',9810,11954);
INSERT INTO "django_geo_db_zipcode" VALUES(13595,31310,-5,'Hinesville, Georgia 31310',9811,11955);
INSERT INTO "django_geo_db_zipcode" VALUES(13596,31312,-5,'Guyton, Georgia 31312',9812,11956);
INSERT INTO "django_geo_db_zipcode" VALUES(13597,31313,-5,'Hinesville, Georgia 31313',9811,11957);
INSERT INTO "django_geo_db_zipcode" VALUES(13598,31314,-5,'Fort Stewart, Georgia 31314',9813,11958);
INSERT INTO "django_geo_db_zipcode" VALUES(13599,31315,-5,'Fort Stewart, Georgia 31315',9813,11959);
INSERT INTO "django_geo_db_zipcode" VALUES(13600,31316,-5,'Ludowici, Georgia 31316',9814,11960);
INSERT INTO "django_geo_db_zipcode" VALUES(13601,31318,-5,'Meldrim, Georgia 31318',9815,11961);
INSERT INTO "django_geo_db_zipcode" VALUES(13602,31319,-5,'Meridian, Georgia 31319',9816,11962);
INSERT INTO "django_geo_db_zipcode" VALUES(13603,31320,-5,'Midway, Georgia 31320',9817,11963);
INSERT INTO "django_geo_db_zipcode" VALUES(13604,31321,-5,'Pembroke, Georgia 31321',9818,11964);
INSERT INTO "django_geo_db_zipcode" VALUES(13605,31322,-5,'Pooler, Georgia 31322',9819,11965);
INSERT INTO "django_geo_db_zipcode" VALUES(13606,31323,-5,'Riceboro, Georgia 31323',9820,11966);
INSERT INTO "django_geo_db_zipcode" VALUES(13607,31324,-5,'Richmond Hill, Georgia 31324',9821,11967);
INSERT INTO "django_geo_db_zipcode" VALUES(13608,31326,-5,'Rincon, Georgia 31326',9822,11968);
INSERT INTO "django_geo_db_zipcode" VALUES(13609,31327,-5,'Sapelo Island, Georgia 31327',9823,11969);
INSERT INTO "django_geo_db_zipcode" VALUES(13610,31328,-5,'Tybee Island, Georgia 31328',9824,11970);
INSERT INTO "django_geo_db_zipcode" VALUES(13611,31329,-5,'Springfield, Georgia 31329',9825,11971);
INSERT INTO "django_geo_db_zipcode" VALUES(13612,31331,-5,'Townsend, Georgia 31331',9826,11972);
INSERT INTO "django_geo_db_zipcode" VALUES(13613,31332,-5,'Valona, Georgia 31332',9827,11950);
INSERT INTO "django_geo_db_zipcode" VALUES(13614,31333,-5,'Walthourville, Georgia 31333',9828,11973);
INSERT INTO "django_geo_db_zipcode" VALUES(13615,31337,-5,'Lenox, Georgia 31337',9829,11974);
INSERT INTO "django_geo_db_zipcode" VALUES(13616,31401,-5,'Savannah, Georgia 31401',9830,11975);
INSERT INTO "django_geo_db_zipcode" VALUES(13617,31402,-5,'Savannah, Georgia 31402',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13618,31403,-5,'Savannah, Georgia 31403',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13619,31404,-5,'Savannah, Georgia 31404',9830,11977);
INSERT INTO "django_geo_db_zipcode" VALUES(13620,31405,-5,'Savannah, Georgia 31405',9830,11978);
INSERT INTO "django_geo_db_zipcode" VALUES(13621,31406,-5,'Savannah, Georgia 31406',9830,11979);
INSERT INTO "django_geo_db_zipcode" VALUES(13622,31407,-5,'Savannah, Georgia 31407',9830,11980);
INSERT INTO "django_geo_db_zipcode" VALUES(13623,31408,-5,'Savannah, Georgia 31408',9830,11981);
INSERT INTO "django_geo_db_zipcode" VALUES(13624,31409,-5,'Savannah, Georgia 31409',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13625,31410,-5,'Savannah, Georgia 31410',9830,11982);
INSERT INTO "django_geo_db_zipcode" VALUES(13626,31411,-5,'Savannah, Georgia 31411',9830,11983);
INSERT INTO "django_geo_db_zipcode" VALUES(13627,31412,-5,'Savannah, Georgia 31412',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13628,31414,-5,'Savannah, Georgia 31414',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13629,31415,-5,'Savannah, Georgia 31415',9830,11984);
INSERT INTO "django_geo_db_zipcode" VALUES(13630,31416,-5,'Savannah, Georgia 31416',9830,11985);
INSERT INTO "django_geo_db_zipcode" VALUES(13631,31418,-5,'Savannah, Georgia 31418',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13632,31419,-5,'Savannah, Georgia 31419',9830,11986);
INSERT INTO "django_geo_db_zipcode" VALUES(13633,31420,-5,'Savannah, Georgia 31420',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13634,31421,-5,'Savannah, Georgia 31421',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13635,31422,-5,'Savannah, Georgia 31422',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13636,31424,-5,'Richmond Hill, Georgia 31424',9821,11987);
INSERT INTO "django_geo_db_zipcode" VALUES(13637,31441,-5,'Savannah, Georgia 31441',9830,11988);
INSERT INTO "django_geo_db_zipcode" VALUES(13638,31498,-5,'Savannah, Georgia 31498',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13639,31499,-5,'Savannah, Georgia 31499',9830,11976);
INSERT INTO "django_geo_db_zipcode" VALUES(13640,31501,-5,'Waycross, Georgia 31501',9831,11989);
INSERT INTO "django_geo_db_zipcode" VALUES(13641,31502,-5,'Waycross, Georgia 31502',9831,11990);
INSERT INTO "django_geo_db_zipcode" VALUES(13642,31503,-5,'Waycross, Georgia 31503',9831,11991);
INSERT INTO "django_geo_db_zipcode" VALUES(13643,31507,-5,'Marshallville, Georgia 31507',9766,11992);
INSERT INTO "django_geo_db_zipcode" VALUES(13644,31510,-5,'Alma, Georgia 31510',9832,11993);
INSERT INTO "django_geo_db_zipcode" VALUES(13645,31512,-5,'Ambrose, Georgia 31512',9833,11994);
INSERT INTO "django_geo_db_zipcode" VALUES(13646,31513,-5,'Baxley, Georgia 31513',9834,11995);
INSERT INTO "django_geo_db_zipcode" VALUES(13647,31515,-5,'Baxley, Georgia 31515',9834,11996);
INSERT INTO "django_geo_db_zipcode" VALUES(13648,31516,-5,'Blackshear, Georgia 31516',9835,11997);
INSERT INTO "django_geo_db_zipcode" VALUES(13649,31518,-5,'Bristol, Georgia 31518',9836,11998);
INSERT INTO "django_geo_db_zipcode" VALUES(13650,31519,-5,'Broxton, Georgia 31519',9837,11999);
INSERT INTO "django_geo_db_zipcode" VALUES(13651,31520,-5,'Brunswick, Georgia 31520',9838,12000);
INSERT INTO "django_geo_db_zipcode" VALUES(13652,31521,-5,'Brunswick, Georgia 31521',9838,12001);
INSERT INTO "django_geo_db_zipcode" VALUES(13653,31522,-5,'Saint Simons Island, Georgia 31522',9839,12002);
INSERT INTO "django_geo_db_zipcode" VALUES(13654,31523,-5,'Brunswick, Georgia 31523',9838,12003);
INSERT INTO "django_geo_db_zipcode" VALUES(13655,31524,-5,'Brunswick, Georgia 31524',9838,12004);
INSERT INTO "django_geo_db_zipcode" VALUES(13656,31525,-5,'Brunswick, Georgia 31525',9838,12005);
INSERT INTO "django_geo_db_zipcode" VALUES(13657,31527,-5,'Jekyll Island, Georgia 31527',9840,12006);
INSERT INTO "django_geo_db_zipcode" VALUES(13658,31532,-5,'Denton, Georgia 31532',9841,12007);
INSERT INTO "django_geo_db_zipcode" VALUES(13659,31533,-5,'Douglas, Georgia 31533',9842,12008);
INSERT INTO "django_geo_db_zipcode" VALUES(13660,31534,-5,'Douglas, Georgia 31534',9842,12009);
INSERT INTO "django_geo_db_zipcode" VALUES(13661,31535,-5,'Douglas, Georgia 31535',9842,12010);
INSERT INTO "django_geo_db_zipcode" VALUES(13662,31537,-5,'Folkston, Georgia 31537',9843,12011);
INSERT INTO "django_geo_db_zipcode" VALUES(13663,31539,-5,'Hazlehurst, Georgia 31539',9844,12012);
INSERT INTO "django_geo_db_zipcode" VALUES(13664,31542,-5,'Hoboken, Georgia 31542',9845,12013);
INSERT INTO "django_geo_db_zipcode" VALUES(13665,31543,-5,'Hortense, Georgia 31543',9846,12014);
INSERT INTO "django_geo_db_zipcode" VALUES(13666,31544,-5,'Jacksonville, Georgia 31544',9847,12015);
INSERT INTO "django_geo_db_zipcode" VALUES(13667,31545,-5,'Jesup, Georgia 31545',9848,12016);
INSERT INTO "django_geo_db_zipcode" VALUES(13668,31546,-5,'Jesup, Georgia 31546',9848,12017);
INSERT INTO "django_geo_db_zipcode" VALUES(13669,31547,-5,'Kings Bay, Georgia 31547',9849,12018);
INSERT INTO "django_geo_db_zipcode" VALUES(13670,31548,-5,'Kingsland, Georgia 31548',9850,12019);
INSERT INTO "django_geo_db_zipcode" VALUES(13671,31549,-5,'Lumber City, Georgia 31549',9851,12020);
INSERT INTO "django_geo_db_zipcode" VALUES(13672,31550,-5,'Manor, Georgia 31550',9852,12021);
INSERT INTO "django_geo_db_zipcode" VALUES(13673,31551,-5,'Mershon, Georgia 31551',9853,12022);
INSERT INTO "django_geo_db_zipcode" VALUES(13674,31552,-5,'Millwood, Georgia 31552',9854,12023);
INSERT INTO "django_geo_db_zipcode" VALUES(13675,31553,-5,'Nahunta, Georgia 31553',9855,12024);
INSERT INTO "django_geo_db_zipcode" VALUES(13676,31554,-5,'Nicholls, Georgia 31554',9856,12025);
INSERT INTO "django_geo_db_zipcode" VALUES(13677,31555,-5,'Odum, Georgia 31555',9857,12026);
INSERT INTO "django_geo_db_zipcode" VALUES(13678,31556,-5,'Offerman, Georgia 31556',9858,12027);
INSERT INTO "django_geo_db_zipcode" VALUES(13679,31557,-5,'Patterson, Georgia 31557',9859,12028);
INSERT INTO "django_geo_db_zipcode" VALUES(13680,31558,-5,'Saint Marys, Georgia 31558',9860,12029);
INSERT INTO "django_geo_db_zipcode" VALUES(13681,31560,-5,'Screven, Georgia 31560',9861,12030);
INSERT INTO "django_geo_db_zipcode" VALUES(13682,31561,-5,'Sea Island, Georgia 31561',9862,12031);
INSERT INTO "django_geo_db_zipcode" VALUES(13683,31563,-5,'Surrency, Georgia 31563',9863,12032);
INSERT INTO "django_geo_db_zipcode" VALUES(13684,31564,-5,'Waresboro, Georgia 31564',9864,11990);
INSERT INTO "django_geo_db_zipcode" VALUES(13685,31565,-5,'Waverly, Georgia 31565',9865,12033);
INSERT INTO "django_geo_db_zipcode" VALUES(13686,31566,-5,'Waynesville, Georgia 31566',9866,12034);
INSERT INTO "django_geo_db_zipcode" VALUES(13687,31567,-5,'West Green, Georgia 31567',9867,12035);
INSERT INTO "django_geo_db_zipcode" VALUES(13688,31568,-5,'White Oak, Georgia 31568',9868,12036);
INSERT INTO "django_geo_db_zipcode" VALUES(13689,31569,-5,'Woodbine, Georgia 31569',9869,12037);
INSERT INTO "django_geo_db_zipcode" VALUES(13690,31598,-5,'Jesup, Georgia 31598',9848,12038);
INSERT INTO "django_geo_db_zipcode" VALUES(13691,31599,-5,'Jesup, Georgia 31599',9848,12038);
INSERT INTO "django_geo_db_zipcode" VALUES(13692,31601,-5,'Valdosta, Georgia 31601',9870,12039);
INSERT INTO "django_geo_db_zipcode" VALUES(13693,31602,-5,'Valdosta, Georgia 31602',9870,12040);
INSERT INTO "django_geo_db_zipcode" VALUES(13694,31603,-5,'Valdosta, Georgia 31603',9870,12041);
INSERT INTO "django_geo_db_zipcode" VALUES(13695,31604,-5,'Valdosta, Georgia 31604',9870,12041);
INSERT INTO "django_geo_db_zipcode" VALUES(13696,31605,-5,'Valdosta, Georgia 31605',9870,12042);
INSERT INTO "django_geo_db_zipcode" VALUES(13697,31606,-5,'Valdosta, Georgia 31606',9870,12043);
INSERT INTO "django_geo_db_zipcode" VALUES(13698,31607,-5,'Valdosta, Georgia 31607',9870,12044);
INSERT INTO "django_geo_db_zipcode" VALUES(13699,31610,-5,'Sparks, Georgia 31610',9871,12045);
INSERT INTO "django_geo_db_zipcode" VALUES(13700,31620,-5,'Adel, Georgia 31620',9872,12046);
INSERT INTO "django_geo_db_zipcode" VALUES(13701,31622,-5,'Alapaha, Georgia 31622',9873,12047);
INSERT INTO "django_geo_db_zipcode" VALUES(13702,31623,-5,'Argyle, Georgia 31623',9874,12048);
INSERT INTO "django_geo_db_zipcode" VALUES(13703,31624,-5,'Axson, Georgia 31624',9875,12049);
INSERT INTO "django_geo_db_zipcode" VALUES(13704,31625,-5,'Barney, Georgia 31625',9876,12050);
INSERT INTO "django_geo_db_zipcode" VALUES(13705,31626,-5,'Boston, Georgia 31626',9877,12051);
INSERT INTO "django_geo_db_zipcode" VALUES(13706,31627,-5,'Cecil, Georgia 31627',9802,12052);
INSERT INTO "django_geo_db_zipcode" VALUES(13707,31629,-5,'Dixie, Georgia 31629',9878,12053);
INSERT INTO "django_geo_db_zipcode" VALUES(13708,31630,-5,'Du Pont, Georgia 31630',9879,12054);
INSERT INTO "django_geo_db_zipcode" VALUES(13709,31631,-5,'Fargo, Georgia 31631',9880,12055);
INSERT INTO "django_geo_db_zipcode" VALUES(13710,31632,-5,'Hahira, Georgia 31632',9881,12056);
INSERT INTO "django_geo_db_zipcode" VALUES(13711,31634,-5,'Homerville, Georgia 31634',9882,12057);
INSERT INTO "django_geo_db_zipcode" VALUES(13712,31635,-5,'Lakeland, Georgia 31635',9883,12058);
INSERT INTO "django_geo_db_zipcode" VALUES(13713,31636,-5,'Lake Park, Georgia 31636',9884,12059);
INSERT INTO "django_geo_db_zipcode" VALUES(13714,31637,-5,'Lenox, Georgia 31637',9829,12060);
INSERT INTO "django_geo_db_zipcode" VALUES(13715,31638,-5,'Morven, Georgia 31638',9885,12061);
INSERT INTO "django_geo_db_zipcode" VALUES(13716,31639,-5,'Nashville, Georgia 31639',9886,12062);
INSERT INTO "django_geo_db_zipcode" VALUES(13717,31641,-5,'Naylor, Georgia 31641',9887,12063);
INSERT INTO "django_geo_db_zipcode" VALUES(13718,31642,-5,'Pearson, Georgia 31642',9888,12064);
INSERT INTO "django_geo_db_zipcode" VALUES(13719,31643,-5,'Quitman, Georgia 31643',9889,12065);
INSERT INTO "django_geo_db_zipcode" VALUES(13720,31645,-5,'Ray City, Georgia 31645',9890,12066);
INSERT INTO "django_geo_db_zipcode" VALUES(13721,31646,-5,'Saint George, Georgia 31646',9891,12067);
INSERT INTO "django_geo_db_zipcode" VALUES(13722,31647,-5,'Sparks, Georgia 31647',9871,12068);
INSERT INTO "django_geo_db_zipcode" VALUES(13723,31648,-5,'Statenville, Georgia 31648',9892,12069);
INSERT INTO "django_geo_db_zipcode" VALUES(13724,31649,-5,'Stockton, Georgia 31649',9893,12070);
INSERT INTO "django_geo_db_zipcode" VALUES(13725,31650,-5,'Willacoochee, Georgia 31650',9894,12071);
INSERT INTO "django_geo_db_zipcode" VALUES(13726,31659,-5,'Nashville, Georgia 31659',9886,12072);
INSERT INTO "django_geo_db_zipcode" VALUES(13727,31698,-5,'Valdosta, Georgia 31698',9870,12073);
INSERT INTO "django_geo_db_zipcode" VALUES(13728,31699,-5,'Valdosta, Georgia 31699',9870,12074);
INSERT INTO "django_geo_db_zipcode" VALUES(13729,31700,-5,'Albany, Georgia 31700',9895,12075);
INSERT INTO "django_geo_db_zipcode" VALUES(13730,31701,-5,'Albany, Georgia 31701',9895,12076);
INSERT INTO "django_geo_db_zipcode" VALUES(13731,31702,-5,'Albany, Georgia 31702',9895,12077);
INSERT INTO "django_geo_db_zipcode" VALUES(13732,31703,-5,'Albany, Georgia 31703',9895,12078);
INSERT INTO "django_geo_db_zipcode" VALUES(13733,31704,-5,'Albany, Georgia 31704',9895,12079);
INSERT INTO "django_geo_db_zipcode" VALUES(13734,31705,-5,'Albany, Georgia 31705',9895,12080);
INSERT INTO "django_geo_db_zipcode" VALUES(13735,31706,-5,'Albany, Georgia 31706',9895,12081);
INSERT INTO "django_geo_db_zipcode" VALUES(13736,31707,-5,'Albany, Georgia 31707',9895,12082);
INSERT INTO "django_geo_db_zipcode" VALUES(13737,31708,-5,'Albany, Georgia 31708',9895,12083);
INSERT INTO "django_geo_db_zipcode" VALUES(13738,31709,-5,'Americus, Georgia 31709',9896,12084);
INSERT INTO "django_geo_db_zipcode" VALUES(13739,31710,-5,'Americus, Georgia 31710',9896,12085);
INSERT INTO "django_geo_db_zipcode" VALUES(13740,31711,-5,'Andersonville, Georgia 31711',9897,12086);
INSERT INTO "django_geo_db_zipcode" VALUES(13741,31712,-5,'Arabi, Georgia 31712',9898,12087);
INSERT INTO "django_geo_db_zipcode" VALUES(13742,31713,-5,'Arlington, Georgia 31713',9899,12088);
INSERT INTO "django_geo_db_zipcode" VALUES(13743,31714,-5,'Ashburn, Georgia 31714',9900,12089);
INSERT INTO "django_geo_db_zipcode" VALUES(13744,31715,-5,'Attapulgus, Georgia 31715',9901,12090);
INSERT INTO "django_geo_db_zipcode" VALUES(13745,31716,-5,'Baconton, Georgia 31716',9902,12091);
INSERT INTO "django_geo_db_zipcode" VALUES(13746,31717,-5,'Bainbridge, Georgia 31717',9903,12092);
INSERT INTO "django_geo_db_zipcode" VALUES(13747,31718,-5,'Bainbridge, Georgia 31718',9903,12093);
INSERT INTO "django_geo_db_zipcode" VALUES(13748,31719,-5,'Americus, Georgia 31719',9896,12094);
INSERT INTO "django_geo_db_zipcode" VALUES(13749,31720,-5,'Barwick, Georgia 31720',9904,12095);
INSERT INTO "django_geo_db_zipcode" VALUES(13750,31721,-5,'Albany, Georgia 31721',9895,12096);
INSERT INTO "django_geo_db_zipcode" VALUES(13751,31722,-5,'Berlin, Georgia 31722',9905,12097);
INSERT INTO "django_geo_db_zipcode" VALUES(13752,31723,-5,'Blakely, Georgia 31723',9906,12098);
INSERT INTO "django_geo_db_zipcode" VALUES(13753,31724,-5,'Bluffton, Georgia 31724',9907,12099);
INSERT INTO "django_geo_db_zipcode" VALUES(13754,31725,-5,'Brinson, Georgia 31725',9908,12100);
INSERT INTO "django_geo_db_zipcode" VALUES(13755,31726,-5,'Bronwood, Georgia 31726',9909,12101);
INSERT INTO "django_geo_db_zipcode" VALUES(13756,31727,-5,'Brookfield, Georgia 31727',9910,12102);
INSERT INTO "django_geo_db_zipcode" VALUES(13757,31728,-5,'Cairo, Georgia 31728',9911,12103);
INSERT INTO "django_geo_db_zipcode" VALUES(13758,31729,-5,'Calvary, Georgia 31729',9912,12104);
INSERT INTO "django_geo_db_zipcode" VALUES(13759,31730,-5,'Camilla, Georgia 31730',9913,12105);
INSERT INTO "django_geo_db_zipcode" VALUES(13760,31732,-5,'Cedar Springs, Georgia 31732',9914,12106);
INSERT INTO "django_geo_db_zipcode" VALUES(13761,31733,-5,'Chula, Georgia 31733',9915,12107);
INSERT INTO "django_geo_db_zipcode" VALUES(13762,31734,-5,'Climax, Georgia 31734',9916,12108);
INSERT INTO "django_geo_db_zipcode" VALUES(13763,31735,-5,'Cobb, Georgia 31735',9917,12109);
INSERT INTO "django_geo_db_zipcode" VALUES(13764,31736,-5,'Coleman, Georgia 31736',9918,12110);
INSERT INTO "django_geo_db_zipcode" VALUES(13765,31737,-5,'Colquitt, Georgia 31737',9919,12111);
INSERT INTO "django_geo_db_zipcode" VALUES(13766,31738,-5,'Coolidge, Georgia 31738',9920,12112);
INSERT INTO "django_geo_db_zipcode" VALUES(13767,31739,-5,'Cotton, Georgia 31739',9921,12113);
INSERT INTO "django_geo_db_zipcode" VALUES(13768,31740,-5,'Cuthbert, Georgia 31740',9922,12114);
INSERT INTO "django_geo_db_zipcode" VALUES(13769,31741,-5,'Damascus, Georgia 31741',9923,12115);
INSERT INTO "django_geo_db_zipcode" VALUES(13770,31742,-5,'Dawson, Georgia 31742',9924,12116);
INSERT INTO "django_geo_db_zipcode" VALUES(13771,31743,-5,'De Soto, Georgia 31743',9925,12117);
INSERT INTO "django_geo_db_zipcode" VALUES(13772,31744,-5,'Doerun, Georgia 31744',9926,12118);
INSERT INTO "django_geo_db_zipcode" VALUES(13773,31745,-5,'Donalsonville, Georgia 31745',9927,12119);
INSERT INTO "django_geo_db_zipcode" VALUES(13774,31746,-5,'Edison, Georgia 31746',9928,12120);
INSERT INTO "django_geo_db_zipcode" VALUES(13775,31747,-5,'Ellenton, Georgia 31747',9929,12121);
INSERT INTO "django_geo_db_zipcode" VALUES(13776,31749,-5,'Enigma, Georgia 31749',9930,12122);
INSERT INTO "django_geo_db_zipcode" VALUES(13777,31750,-5,'Fitzgerald, Georgia 31750',9931,12123);
INSERT INTO "django_geo_db_zipcode" VALUES(13778,31751,-5,'Fort Gaines, Georgia 31751',9932,12124);
INSERT INTO "django_geo_db_zipcode" VALUES(13779,31752,-5,'Fowlstown, Georgia 31752',9933,12125);
INSERT INTO "django_geo_db_zipcode" VALUES(13780,31753,-5,'Funston, Georgia 31753',9934,12126);
INSERT INTO "django_geo_db_zipcode" VALUES(13781,31754,-5,'Georgetown, Georgia 31754',9935,12127);
INSERT INTO "django_geo_db_zipcode" VALUES(13782,31756,-5,'Hartsfield, Georgia 31756',9936,12128);
INSERT INTO "django_geo_db_zipcode" VALUES(13783,31757,-5,'Thomasville, Georgia 31757',9937,12129);
INSERT INTO "django_geo_db_zipcode" VALUES(13784,31758,-5,'Thomasville, Georgia 31758',9937,12130);
INSERT INTO "django_geo_db_zipcode" VALUES(13785,31759,-5,'Iron City, Georgia 31759',9938,12131);
INSERT INTO "django_geo_db_zipcode" VALUES(13786,31760,-5,'Irwinville, Georgia 31760',9939,12132);
INSERT INTO "django_geo_db_zipcode" VALUES(13787,31761,-5,'Jakin, Georgia 31761',9940,12133);
INSERT INTO "django_geo_db_zipcode" VALUES(13788,31762,-5,'Leary, Georgia 31762',9941,12134);
INSERT INTO "django_geo_db_zipcode" VALUES(13789,31763,-5,'Leesburg, Georgia 31763',9942,12135);
INSERT INTO "django_geo_db_zipcode" VALUES(13790,31764,-5,'Leslie, Georgia 31764',9943,12136);
INSERT INTO "django_geo_db_zipcode" VALUES(13791,31765,-5,'Meigs, Georgia 31765',9944,12137);
INSERT INTO "django_geo_db_zipcode" VALUES(13792,31766,-5,'Morgan, Georgia 31766',9945,12138);
INSERT INTO "django_geo_db_zipcode" VALUES(13793,31767,-5,'Morris, Georgia 31767',9946,12139);
INSERT INTO "django_geo_db_zipcode" VALUES(13794,31768,-5,'Moultrie, Georgia 31768',9947,12140);
INSERT INTO "django_geo_db_zipcode" VALUES(13795,31769,-5,'Mystic, Georgia 31769',9948,12141);
INSERT INTO "django_geo_db_zipcode" VALUES(13796,31770,-5,'Newton, Georgia 31770',9949,12142);
INSERT INTO "django_geo_db_zipcode" VALUES(13797,31771,-5,'Norman Park, Georgia 31771',9950,12143);
INSERT INTO "django_geo_db_zipcode" VALUES(13798,31772,-5,'Oakfield, Georgia 31772',9951,12144);
INSERT INTO "django_geo_db_zipcode" VALUES(13799,31773,-5,'Ochlocknee, Georgia 31773',9952,12145);
INSERT INTO "django_geo_db_zipcode" VALUES(13800,31774,-5,'Ocilla, Georgia 31774',9953,12146);
INSERT INTO "django_geo_db_zipcode" VALUES(13801,31775,-5,'Omega, Georgia 31775',9954,12147);
INSERT INTO "django_geo_db_zipcode" VALUES(13802,31776,-5,'Moultrie, Georgia 31776',9947,12148);
INSERT INTO "django_geo_db_zipcode" VALUES(13803,31777,-5,'Parrott, Georgia 31777',9955,12149);
INSERT INTO "django_geo_db_zipcode" VALUES(13804,31778,-5,'Pavo, Georgia 31778',9956,12150);
INSERT INTO "django_geo_db_zipcode" VALUES(13805,31779,-5,'Pelham, Georgia 31779',9957,12151);
INSERT INTO "django_geo_db_zipcode" VALUES(13806,31780,-5,'Plains, Georgia 31780',9958,12152);
INSERT INTO "django_geo_db_zipcode" VALUES(13807,31781,-5,'Poulan, Georgia 31781',9959,12153);
INSERT INTO "django_geo_db_zipcode" VALUES(13808,31782,-5,'Putney, Georgia 31782',9960,12078);
INSERT INTO "django_geo_db_zipcode" VALUES(13809,31783,-5,'Rebecca, Georgia 31783',9961,12154);
INSERT INTO "django_geo_db_zipcode" VALUES(13810,31784,-5,'Sale City, Georgia 31784',9962,12155);
INSERT INTO "django_geo_db_zipcode" VALUES(13811,31785,-5,'Sasser, Georgia 31785',9963,12156);
INSERT INTO "django_geo_db_zipcode" VALUES(13812,31786,-5,'Shellman, Georgia 31786',9964,12157);
INSERT INTO "django_geo_db_zipcode" VALUES(13813,31787,-5,'Smithville, Georgia 31787',9965,12158);
INSERT INTO "django_geo_db_zipcode" VALUES(13814,31788,-5,'White House, Tennessee 31788',9966,12159);
INSERT INTO "django_geo_db_zipcode" VALUES(13815,31789,-5,'Sumner, Georgia 31789',9967,12160);
INSERT INTO "django_geo_db_zipcode" VALUES(13816,31790,-5,'Sycamore, Georgia 31790',9968,12161);
INSERT INTO "django_geo_db_zipcode" VALUES(13817,31791,-5,'Sylvester, Georgia 31791',9969,12162);
INSERT INTO "django_geo_db_zipcode" VALUES(13818,31792,-5,'Thomasville, Georgia 31792',9937,12163);
INSERT INTO "django_geo_db_zipcode" VALUES(13819,31793,-5,'Tifton, Georgia 31793',9970,12164);
INSERT INTO "django_geo_db_zipcode" VALUES(13820,31794,-5,'Tifton, Georgia 31794',9970,12165);
INSERT INTO "django_geo_db_zipcode" VALUES(13821,31795,-5,'Ty Ty, Georgia 31795',9971,12166);
INSERT INTO "django_geo_db_zipcode" VALUES(13822,31796,-5,'Warwick, Georgia 31796',9972,12167);
INSERT INTO "django_geo_db_zipcode" VALUES(13823,31797,-5,'Whigham, Georgia 31797',9973,12168);
INSERT INTO "django_geo_db_zipcode" VALUES(13824,31798,-5,'Wray, Georgia 31798',9974,12169);
INSERT INTO "django_geo_db_zipcode" VALUES(13825,31799,-5,'Thomasville, Georgia 31799',9937,12170);
INSERT INTO "django_geo_db_zipcode" VALUES(13826,31801,-5,'Box Springs, Georgia 31801',9975,12171);
INSERT INTO "django_geo_db_zipcode" VALUES(13827,31803,-5,'Buena Vista, Georgia 31803',9976,12172);
INSERT INTO "django_geo_db_zipcode" VALUES(13828,31804,-5,'Cataula, Georgia 31804',9977,12173);
INSERT INTO "django_geo_db_zipcode" VALUES(13829,31805,-5,'Cusseta, Georgia 31805',9978,12174);
INSERT INTO "django_geo_db_zipcode" VALUES(13830,31806,-5,'Ellaville, Georgia 31806',9979,12175);
INSERT INTO "django_geo_db_zipcode" VALUES(13831,31807,-5,'Ellerslie, Georgia 31807',9980,12176);
INSERT INTO "django_geo_db_zipcode" VALUES(13832,31808,-5,'Fortson, Georgia 31808',9981,12177);
INSERT INTO "django_geo_db_zipcode" VALUES(13833,31810,-5,'Geneva, Georgia 31810',9982,12178);
INSERT INTO "django_geo_db_zipcode" VALUES(13834,31811,-5,'Hamilton, Georgia 31811',9983,12179);
INSERT INTO "django_geo_db_zipcode" VALUES(13835,31812,-5,'Junction City, Georgia 31812',9984,12180);
INSERT INTO "django_geo_db_zipcode" VALUES(13836,31814,-5,'Louvale, Georgia 31814',9985,12181);
INSERT INTO "django_geo_db_zipcode" VALUES(13837,31815,-5,'Lumpkin, Georgia 31815',9986,12182);
INSERT INTO "django_geo_db_zipcode" VALUES(13838,31816,-5,'Manchester, Georgia 31816',9987,12183);
INSERT INTO "django_geo_db_zipcode" VALUES(13839,31820,-5,'Midland, Georgia 31820',9988,12184);
INSERT INTO "django_geo_db_zipcode" VALUES(13840,31821,-5,'Omaha, Georgia 31821',9989,12185);
INSERT INTO "django_geo_db_zipcode" VALUES(13841,31822,-5,'Pine Mountain, Georgia 31822',9990,12186);
INSERT INTO "django_geo_db_zipcode" VALUES(13842,31823,-5,'Pine Mountain Valley, Georgia 31823',9991,12187);
INSERT INTO "django_geo_db_zipcode" VALUES(13843,31824,-5,'Preston, Georgia 31824',9992,12188);
INSERT INTO "django_geo_db_zipcode" VALUES(13844,31825,-5,'Richland, Georgia 31825',9993,12189);
INSERT INTO "django_geo_db_zipcode" VALUES(13845,31826,-5,'Shiloh, Georgia 31826',9994,12190);
INSERT INTO "django_geo_db_zipcode" VALUES(13846,31827,-5,'Talbotton, Georgia 31827',9995,12191);
INSERT INTO "django_geo_db_zipcode" VALUES(13847,31829,-5,'Upatoi, Georgia 31829',9996,12192);
INSERT INTO "django_geo_db_zipcode" VALUES(13848,31830,-5,'Warm Springs, Georgia 31830',9997,12193);
INSERT INTO "django_geo_db_zipcode" VALUES(13849,31831,-5,'Waverly Hall, Georgia 31831',9998,12194);
INSERT INTO "django_geo_db_zipcode" VALUES(13850,31832,-5,'Weston, Georgia 31832',9999,12195);
INSERT INTO "django_geo_db_zipcode" VALUES(13851,31833,-5,'West Point, Georgia 31833',10000,12196);
INSERT INTO "django_geo_db_zipcode" VALUES(13852,31836,-5,'Woodland, Georgia 31836',10001,12197);
INSERT INTO "django_geo_db_zipcode" VALUES(13853,31901,-5,'Columbus, Georgia 31901',10002,12198);
INSERT INTO "django_geo_db_zipcode" VALUES(13854,31902,-5,'Columbus, Georgia 31902',10002,12199);
INSERT INTO "django_geo_db_zipcode" VALUES(13855,31903,-5,'Columbus, Georgia 31903',10002,12200);
INSERT INTO "django_geo_db_zipcode" VALUES(13856,31904,-5,'Columbus, Georgia 31904',10002,12201);
INSERT INTO "django_geo_db_zipcode" VALUES(13857,31905,-5,'Fort Benning, Georgia 31905',10003,12202);
INSERT INTO "django_geo_db_zipcode" VALUES(13858,31906,-5,'Columbus, Georgia 31906',10002,12203);
INSERT INTO "django_geo_db_zipcode" VALUES(13859,31907,-5,'Columbus, Georgia 31907',10002,12204);
INSERT INTO "django_geo_db_zipcode" VALUES(13860,31908,-5,'Columbus, Georgia 31908',10002,12205);
INSERT INTO "django_geo_db_zipcode" VALUES(13861,31909,-5,'Columbus, Georgia 31909',10002,12206);
INSERT INTO "django_geo_db_zipcode" VALUES(13862,31914,-5,'Columbus, Georgia 31914',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13863,31917,-5,'Columbus, Georgia 31917',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13864,31993,-5,'Columbus, Georgia 31993',10002,12208);
INSERT INTO "django_geo_db_zipcode" VALUES(13865,31994,-5,'Columbus, Georgia 31994',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13866,31995,-5,'Fort Benning, Georgia 31995',10003,12209);
INSERT INTO "django_geo_db_zipcode" VALUES(13867,31997,-5,'Columbus, Georgia 31997',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13868,31998,-5,'Columbus, Georgia 31998',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13869,31999,-5,'Columbus, Georgia 31999',10002,12207);
INSERT INTO "django_geo_db_zipcode" VALUES(13870,32004,-5,'Ponte Vedra Beach, Florida 32004',10004,12210);
INSERT INTO "django_geo_db_zipcode" VALUES(13871,32007,-5,'Bostwick, Florida 32007',10005,12211);
INSERT INTO "django_geo_db_zipcode" VALUES(13872,32008,-5,'Branford, Florida 32008',10006,12212);
INSERT INTO "django_geo_db_zipcode" VALUES(13873,32009,-5,'Bryceville, Florida 32009',10007,12213);
INSERT INTO "django_geo_db_zipcode" VALUES(13874,32011,-5,'Callahan, Florida 32011',10008,12214);
INSERT INTO "django_geo_db_zipcode" VALUES(13875,32013,-5,'Day, Florida 32013',10009,12215);
INSERT INTO "django_geo_db_zipcode" VALUES(13876,32024,-5,'Lake City, Florida 32024',10010,12216);
INSERT INTO "django_geo_db_zipcode" VALUES(13877,32025,-5,'Lake City, Florida 32025',10010,12217);
INSERT INTO "django_geo_db_zipcode" VALUES(13878,32030,-5,'Doctors Inlet, Florida 32030',10011,12218);
INSERT INTO "django_geo_db_zipcode" VALUES(13879,32033,-5,'Elkton, Florida 32033',10012,12219);
INSERT INTO "django_geo_db_zipcode" VALUES(13880,32034,-5,'Fernandina Beach, Florida 32034',10013,12220);
INSERT INTO "django_geo_db_zipcode" VALUES(13881,32035,-5,'Fernandina Beach, Florida 32035',10013,12221);
INSERT INTO "django_geo_db_zipcode" VALUES(13882,32038,-5,'Fort White, Florida 32038',10014,12222);
INSERT INTO "django_geo_db_zipcode" VALUES(13883,32040,-5,'Glen Saint Mary, Florida 32040',10015,12223);
INSERT INTO "django_geo_db_zipcode" VALUES(13884,32041,-5,'Yulee, Florida 32041',10016,12224);
INSERT INTO "django_geo_db_zipcode" VALUES(13885,32042,-5,'Graham, Florida 32042',10017,12225);
INSERT INTO "django_geo_db_zipcode" VALUES(13886,32043,-5,'Green Cove Springs, Florida 32043',10018,12226);
INSERT INTO "django_geo_db_zipcode" VALUES(13887,32044,-5,'Hampton, Florida 32044',10019,12227);
INSERT INTO "django_geo_db_zipcode" VALUES(13888,32046,-5,'Hilliard, Florida 32046',10020,12228);
INSERT INTO "django_geo_db_zipcode" VALUES(13889,32047,-5,'Yulee, Florida 32047',10016,12229);
INSERT INTO "django_geo_db_zipcode" VALUES(13890,32050,-5,'Middleburg, Florida 32050',10021,12230);
INSERT INTO "django_geo_db_zipcode" VALUES(13891,32052,-5,'Jasper, Florida 32052',10022,12231);
INSERT INTO "django_geo_db_zipcode" VALUES(13892,32053,-5,'Jennings, Florida 32053',10023,12232);
INSERT INTO "django_geo_db_zipcode" VALUES(13893,32054,-5,'Lake Butler, Florida 32054',10024,12233);
INSERT INTO "django_geo_db_zipcode" VALUES(13894,32055,-5,'Lake City, Florida 32055',10010,12234);
INSERT INTO "django_geo_db_zipcode" VALUES(13895,32056,-5,'Lake City, Florida 32056',10010,12235);
INSERT INTO "django_geo_db_zipcode" VALUES(13896,32058,-5,'Lawtey, Florida 32058',10025,12236);
INSERT INTO "django_geo_db_zipcode" VALUES(13897,32059,-5,'Lee, Florida 32059',10026,12237);
INSERT INTO "django_geo_db_zipcode" VALUES(13898,32060,-5,'Live Oak, Florida 32060',10027,12238);
INSERT INTO "django_geo_db_zipcode" VALUES(13899,32061,-5,'Lulu, Florida 32061',10028,12239);
INSERT INTO "django_geo_db_zipcode" VALUES(13900,32062,-5,'McAlpin, Florida 32062',10029,12240);
INSERT INTO "django_geo_db_zipcode" VALUES(13901,32063,-5,'Macclenny, Florida 32063',10030,12241);
INSERT INTO "django_geo_db_zipcode" VALUES(13902,32064,-5,'Live Oak, Florida 32064',10027,12242);
INSERT INTO "django_geo_db_zipcode" VALUES(13903,32065,-5,'Orange Park, Florida 32065',10031,12243);
INSERT INTO "django_geo_db_zipcode" VALUES(13904,32066,-5,'Mayo, Florida 32066',10032,12244);
INSERT INTO "django_geo_db_zipcode" VALUES(13905,32067,-5,'Orange Park, Florida 32067',10031,12245);
INSERT INTO "django_geo_db_zipcode" VALUES(13906,32068,-5,'Middleburg, Florida 32068',10021,12246);
INSERT INTO "django_geo_db_zipcode" VALUES(13907,32071,-5,'O Brien, Florida 32071',10033,12247);
INSERT INTO "django_geo_db_zipcode" VALUES(13908,32072,-5,'Olustee, Florida 32072',10034,12248);
INSERT INTO "django_geo_db_zipcode" VALUES(13909,32073,-5,'Orange Park, Florida 32073',10031,12249);
INSERT INTO "django_geo_db_zipcode" VALUES(13910,32079,-5,'Penney Farms, Florida 32079',10035,12250);
INSERT INTO "django_geo_db_zipcode" VALUES(13911,32080,-5,'St. Augustine, Florida 32080',10036,12251);
INSERT INTO "django_geo_db_zipcode" VALUES(13912,32081,-5,'Pomona Park, Florida 32081',10037,12252);
INSERT INTO "django_geo_db_zipcode" VALUES(13913,32082,-5,'Ponte Vedra Beach, Florida 32082',10004,12253);
INSERT INTO "django_geo_db_zipcode" VALUES(13914,32083,-5,'Raiford, Florida 32083',10038,12254);
INSERT INTO "django_geo_db_zipcode" VALUES(13915,32084,-5,'Saint Augustine, Florida 32084',10039,12255);
INSERT INTO "django_geo_db_zipcode" VALUES(13916,32085,-5,'Saint Augustine, Florida 32085',10039,12210);
INSERT INTO "django_geo_db_zipcode" VALUES(13917,32086,-5,'Saint Augustine, Florida 32086',10039,12256);
INSERT INTO "django_geo_db_zipcode" VALUES(13918,32087,-5,'Sanderson, Florida 32087',10040,12257);
INSERT INTO "django_geo_db_zipcode" VALUES(13919,32091,-5,'Starke, Florida 32091',10041,12258);
INSERT INTO "django_geo_db_zipcode" VALUES(13920,32092,-5,'Saint Augustine, Florida 32092',10039,12259);
INSERT INTO "django_geo_db_zipcode" VALUES(13921,32094,-5,'Wellborn, Florida 32094',10042,12260);
INSERT INTO "django_geo_db_zipcode" VALUES(13922,32095,-5,'Saint Augustine, Florida 32095',10039,12261);
INSERT INTO "django_geo_db_zipcode" VALUES(13923,32096,-5,'White Springs, Florida 32096',10043,12262);
INSERT INTO "django_geo_db_zipcode" VALUES(13924,32097,-5,'Yulee, Florida 32097',10016,12263);
INSERT INTO "django_geo_db_zipcode" VALUES(13925,32098,-5,'Palm Valley, Florida 32098',10044,12264);
INSERT INTO "django_geo_db_zipcode" VALUES(13926,32099,-5,'Jacksonville, Florida 32099',10045,12265);
INSERT INTO "django_geo_db_zipcode" VALUES(13927,32102,-5,'Astor, Florida 32102',10046,12266);
INSERT INTO "django_geo_db_zipcode" VALUES(13928,32105,-5,'Barberville, Florida 32105',10047,12267);
INSERT INTO "django_geo_db_zipcode" VALUES(13929,32110,-5,'Bunnell, Florida 32110',10048,12268);
INSERT INTO "django_geo_db_zipcode" VALUES(13930,32111,-5,'Candler, Florida 32111',10049,12269);
INSERT INTO "django_geo_db_zipcode" VALUES(13931,32112,-5,'Crescent City, Florida 32112',10050,12270);
INSERT INTO "django_geo_db_zipcode" VALUES(13932,32113,-5,'Citra, Florida 32113',10051,12271);
INSERT INTO "django_geo_db_zipcode" VALUES(13933,32114,-5,'Daytona Beach, Florida 32114',10052,12272);
INSERT INTO "django_geo_db_zipcode" VALUES(13934,32115,-5,'Daytona Beach, Florida 32115',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13935,32116,-5,'Daytona Beach, Florida 32116',10052,12274);
INSERT INTO "django_geo_db_zipcode" VALUES(13936,32117,-5,'Daytona Beach, Florida 32117',10052,12275);
INSERT INTO "django_geo_db_zipcode" VALUES(13937,32118,-5,'Daytona Beach, Florida 32118',10052,12276);
INSERT INTO "django_geo_db_zipcode" VALUES(13938,32119,-5,'Daytona Beach, Florida 32119',10052,12277);
INSERT INTO "django_geo_db_zipcode" VALUES(13939,32120,-5,'Daytona Beach, Florida 32120',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13940,32121,-5,'Daytona Beach, Florida 32121',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13941,32122,-5,'Daytona Beach, Florida 32122',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13942,32123,-5,'Daytona Beach, Florida 32123',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13943,32124,-5,'Daytona Beach, Florida 32124',10052,12278);
INSERT INTO "django_geo_db_zipcode" VALUES(13944,32125,-5,'Daytona Beach, Florida 32125',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13945,32126,-5,'Daytona Beach, Florida 32126',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13946,32127,-5,'Daytona Beach, Florida 32127',10052,12279);
INSERT INTO "django_geo_db_zipcode" VALUES(13947,32128,-5,'Port Orange, Florida 32128',10053,12280);
INSERT INTO "django_geo_db_zipcode" VALUES(13948,32129,-5,'Port Orange, Florida 32129',10053,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13949,32130,-5,'De Leon Springs, Florida 32130',10054,12281);
INSERT INTO "django_geo_db_zipcode" VALUES(13950,32131,-5,'East Palatka, Florida 32131',10055,12282);
INSERT INTO "django_geo_db_zipcode" VALUES(13951,32132,-5,'Edgewater, Florida 32132',10056,12283);
INSERT INTO "django_geo_db_zipcode" VALUES(13952,32133,-5,'Eastlake Weir, Florida 32133',10057,12284);
INSERT INTO "django_geo_db_zipcode" VALUES(13953,32134,-5,'Fort McCoy, Florida 32134',10058,12285);
INSERT INTO "django_geo_db_zipcode" VALUES(13954,32135,-5,'Palm Coast, Florida 32135',10059,12286);
INSERT INTO "django_geo_db_zipcode" VALUES(13955,32136,-5,'Flagler Beach, Florida 32136',10060,12287);
INSERT INTO "django_geo_db_zipcode" VALUES(13956,32137,-5,'Palm Coast, Florida 32137',10059,12288);
INSERT INTO "django_geo_db_zipcode" VALUES(13957,32138,-5,'Grandin, Florida 32138',10061,12289);
INSERT INTO "django_geo_db_zipcode" VALUES(13958,32139,-5,'Georgetown, Florida 32139',10062,12290);
INSERT INTO "django_geo_db_zipcode" VALUES(13959,32140,-5,'Florahome, Florida 32140',10063,12291);
INSERT INTO "django_geo_db_zipcode" VALUES(13960,32141,-5,'Edgewater, Florida 32141',10056,12292);
INSERT INTO "django_geo_db_zipcode" VALUES(13961,32142,-5,'Palm Coast, Florida 32142',10059,12286);
INSERT INTO "django_geo_db_zipcode" VALUES(13962,32145,-5,'Hastings, Florida 32145',10064,12293);
INSERT INTO "django_geo_db_zipcode" VALUES(13963,32147,-5,'Hollister, Florida 32147',10065,12294);
INSERT INTO "django_geo_db_zipcode" VALUES(13964,32148,-5,'Interlachen, Florida 32148',10066,12295);
INSERT INTO "django_geo_db_zipcode" VALUES(13965,32149,-5,'Interlachen, Florida 32149',10066,12296);
INSERT INTO "django_geo_db_zipcode" VALUES(13966,32151,-5,'Flagler Beach, Florida 32151',10060,12286);
INSERT INTO "django_geo_db_zipcode" VALUES(13967,32157,-5,'Lake Como, Florida 32157',10067,12297);
INSERT INTO "django_geo_db_zipcode" VALUES(13968,32158,-5,'Lady Lake, Florida 32158',10068,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(13969,32159,-5,'Lady Lake, Florida 32159',10068,12299);
INSERT INTO "django_geo_db_zipcode" VALUES(13970,32160,-5,'Lake Geneva, Florida 32160',10069,12300);
INSERT INTO "django_geo_db_zipcode" VALUES(13971,32162,-5,'The Villages, Florida 32162',10070,12301);
INSERT INTO "django_geo_db_zipcode" VALUES(13972,32164,-5,'Palm Coast, Florida 32164',10059,12302);
INSERT INTO "django_geo_db_zipcode" VALUES(13973,32168,-5,'New Smyrna Beach, Florida 32168',10071,12303);
INSERT INTO "django_geo_db_zipcode" VALUES(13974,32169,-5,'New Smyrna Beach, Florida 32169',10071,12304);
INSERT INTO "django_geo_db_zipcode" VALUES(13975,32170,-5,'New Smyrna Beach, Florida 32170',10071,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13976,32173,-5,'Ormond Beach, Florida 32173',10072,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13977,32174,-5,'Ormond Beach, Florida 32174',10072,12305);
INSERT INTO "django_geo_db_zipcode" VALUES(13978,32175,-5,'Ormond Beach, Florida 32175',10072,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13979,32176,-5,'Ormond Beach, Florida 32176',10072,12306);
INSERT INTO "django_geo_db_zipcode" VALUES(13980,32177,-5,'Palatka, Florida 32177',10073,12307);
INSERT INTO "django_geo_db_zipcode" VALUES(13981,32178,-5,'Palatka, Florida 32178',10073,12308);
INSERT INTO "django_geo_db_zipcode" VALUES(13982,32179,-5,'Ocklawaha, Florida 32179',10074,12309);
INSERT INTO "django_geo_db_zipcode" VALUES(13983,32180,-5,'Pierson, Florida 32180',10075,12310);
INSERT INTO "django_geo_db_zipcode" VALUES(13984,32181,-5,'Pomona Park, Florida 32181',10037,12311);
INSERT INTO "django_geo_db_zipcode" VALUES(13985,32182,-5,'Orange Springs, Florida 32182',10076,12312);
INSERT INTO "django_geo_db_zipcode" VALUES(13986,32183,-5,'Ocklawaha, Florida 32183',10074,12313);
INSERT INTO "django_geo_db_zipcode" VALUES(13987,32185,-5,'Putnam Hall, Florida 32185',10077,12314);
INSERT INTO "django_geo_db_zipcode" VALUES(13988,32187,-5,'San Mateo, Florida 32187',10078,12315);
INSERT INTO "django_geo_db_zipcode" VALUES(13989,32189,-5,'Satsuma, Florida 32189',10079,12316);
INSERT INTO "django_geo_db_zipcode" VALUES(13990,32190,-5,'Seville, Florida 32190',10080,12317);
INSERT INTO "django_geo_db_zipcode" VALUES(13991,32192,-5,'Sparr, Florida 32192',10081,12318);
INSERT INTO "django_geo_db_zipcode" VALUES(13992,32193,-5,'Welaka, Florida 32193',10082,12319);
INSERT INTO "django_geo_db_zipcode" VALUES(13993,32195,-5,'Weirsdale, Florida 32195',10083,12320);
INSERT INTO "django_geo_db_zipcode" VALUES(13994,32198,-5,'Daytona Beach, Florida 32198',10052,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(13995,32201,-5,'Jacksonville, Florida 32201',10045,12321);
INSERT INTO "django_geo_db_zipcode" VALUES(13996,32202,-5,'Jacksonville, Florida 32202',10045,12322);
INSERT INTO "django_geo_db_zipcode" VALUES(13997,32203,-5,'Jacksonville, Florida 32203',10045,12323);
INSERT INTO "django_geo_db_zipcode" VALUES(13998,32204,-5,'Jacksonville, Florida 32204',10045,12324);
INSERT INTO "django_geo_db_zipcode" VALUES(13999,32205,-5,'Jacksonville, Florida 32205',10045,12325);
INSERT INTO "django_geo_db_zipcode" VALUES(14000,32206,-5,'Jacksonville, Florida 32206',10045,12326);
INSERT INTO "django_geo_db_zipcode" VALUES(14001,32207,-5,'Jacksonville, Florida 32207',10045,12327);
INSERT INTO "django_geo_db_zipcode" VALUES(14002,32208,-5,'Jacksonville, Florida 32208',10045,12328);
INSERT INTO "django_geo_db_zipcode" VALUES(14003,32209,-5,'Jacksonville, Florida 32209',10045,12329);
INSERT INTO "django_geo_db_zipcode" VALUES(14004,32210,-5,'Jacksonville, Florida 32210',10045,12330);
INSERT INTO "django_geo_db_zipcode" VALUES(14005,32211,-5,'Jacksonville, Florida 32211',10045,12331);
INSERT INTO "django_geo_db_zipcode" VALUES(14006,32212,-5,'Jacksonville, Florida 32212',10045,12332);
INSERT INTO "django_geo_db_zipcode" VALUES(14007,32214,-5,'Jacksonville, Florida 32214',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14008,32215,-5,'Jacksonville, Florida 32215',10045,12334);
INSERT INTO "django_geo_db_zipcode" VALUES(14009,32216,-5,'Jacksonville, Florida 32216',10045,12335);
INSERT INTO "django_geo_db_zipcode" VALUES(14010,32217,-5,'Jacksonville, Florida 32217',10045,12336);
INSERT INTO "django_geo_db_zipcode" VALUES(14011,32218,-5,'Jacksonville, Florida 32218',10045,12337);
INSERT INTO "django_geo_db_zipcode" VALUES(14012,32219,-5,'Jacksonville, Florida 32219',10045,12338);
INSERT INTO "django_geo_db_zipcode" VALUES(14013,32220,-5,'Jacksonville, Florida 32220',10045,12339);
INSERT INTO "django_geo_db_zipcode" VALUES(14014,32221,-5,'Jacksonville, Florida 32221',10045,12340);
INSERT INTO "django_geo_db_zipcode" VALUES(14015,32222,-5,'Jacksonville, Florida 32222',10045,12341);
INSERT INTO "django_geo_db_zipcode" VALUES(14016,32223,-5,'Jacksonville, Florida 32223',10045,12342);
INSERT INTO "django_geo_db_zipcode" VALUES(14017,32224,-5,'Jacksonville, Florida 32224',10045,12343);
INSERT INTO "django_geo_db_zipcode" VALUES(14018,32225,-5,'Jacksonville, Florida 32225',10045,12344);
INSERT INTO "django_geo_db_zipcode" VALUES(14019,32226,-5,'Jacksonville, Florida 32226',10045,12345);
INSERT INTO "django_geo_db_zipcode" VALUES(14020,32227,-5,'Jacksonville, Florida 32227',10045,12346);
INSERT INTO "django_geo_db_zipcode" VALUES(14021,32228,-5,'Jacksonville, Florida 32228',10045,12347);
INSERT INTO "django_geo_db_zipcode" VALUES(14022,32229,-5,'Jacksonville, Florida 32229',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14023,32230,-5,'Jacksonville, Florida 32230',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14024,32231,-5,'Jacksonville, Florida 32231',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14025,32232,-5,'Jacksonville, Florida 32232',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14026,32233,-5,'Atlantic Beach, Florida 32233',10084,12348);
INSERT INTO "django_geo_db_zipcode" VALUES(14027,32234,-5,'Jacksonville, Florida 32234',10045,12349);
INSERT INTO "django_geo_db_zipcode" VALUES(14028,32235,-5,'Jacksonville, Florida 32235',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14029,32236,-5,'Jacksonville, Florida 32236',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14030,32237,-5,'Jacksonville, Florida 32237',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14031,32238,-5,'Jacksonville, Florida 32238',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14032,32239,-5,'Jacksonville, Florida 32239',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14033,32240,-5,'Jacksonville Beach, Florida 32240',10085,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14034,32241,-5,'Jacksonville, Florida 32241',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14035,32244,-5,'Jacksonville, Florida 32244',10045,12350);
INSERT INTO "django_geo_db_zipcode" VALUES(14036,32245,-5,'Jacksonville, Florida 32245',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14037,32246,-5,'Jacksonville, Florida 32246',10045,12351);
INSERT INTO "django_geo_db_zipcode" VALUES(14038,32247,-5,'Jacksonville, Florida 32247',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14039,32250,-5,'Jacksonville Beach, Florida 32250',10085,12352);
INSERT INTO "django_geo_db_zipcode" VALUES(14040,32254,-5,'Jacksonville, Florida 32254',10045,12353);
INSERT INTO "django_geo_db_zipcode" VALUES(14041,32255,-5,'Jacksonville, Florida 32255',10045,12354);
INSERT INTO "django_geo_db_zipcode" VALUES(14042,32256,-5,'Jacksonville, Florida 32256',10045,12355);
INSERT INTO "django_geo_db_zipcode" VALUES(14043,32257,-5,'Jacksonville, Florida 32257',10045,12356);
INSERT INTO "django_geo_db_zipcode" VALUES(14044,32258,-5,'Jacksonville, Florida 32258',10045,12357);
INSERT INTO "django_geo_db_zipcode" VALUES(14045,32259,-5,'Jacksonville, Florida 32259',10045,12358);
INSERT INTO "django_geo_db_zipcode" VALUES(14046,32260,-5,'Jacksonville, Florida 32260',10045,12210);
INSERT INTO "django_geo_db_zipcode" VALUES(14047,32266,-5,'Neptune Beach, Florida 32266',10086,12359);
INSERT INTO "django_geo_db_zipcode" VALUES(14048,32267,-5,'Jacksonville, Florida 32267',10045,12333);
INSERT INTO "django_geo_db_zipcode" VALUES(14049,32276,-5,'Jacksonville, Florida 32276',10045,12360);
INSERT INTO "django_geo_db_zipcode" VALUES(14050,32277,-5,'Jacksonville, Florida 32277',10045,12361);
INSERT INTO "django_geo_db_zipcode" VALUES(14051,32301,-5,'Tallahassee, Florida 32301',10087,12362);
INSERT INTO "django_geo_db_zipcode" VALUES(14052,32302,-5,'Tallahassee, Florida 32302',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14053,32303,-5,'Tallahassee, Florida 32303',10087,12364);
INSERT INTO "django_geo_db_zipcode" VALUES(14054,32304,-5,'Tallahassee, Florida 32304',10087,12365);
INSERT INTO "django_geo_db_zipcode" VALUES(14055,32305,-5,'Wakulla Springs, Florida 32305',10088,12366);
INSERT INTO "django_geo_db_zipcode" VALUES(14056,32306,-5,'Tallahassee, Florida 32306',10087,12367);
INSERT INTO "django_geo_db_zipcode" VALUES(14057,32307,-5,'Tallahassee, Florida 32307',10087,12368);
INSERT INTO "django_geo_db_zipcode" VALUES(14058,32308,-5,'Tallahassee, Florida 32308',10087,12369);
INSERT INTO "django_geo_db_zipcode" VALUES(14059,32309,-5,'Miccosukee Cpo, Florida 32309',10089,12370);
INSERT INTO "django_geo_db_zipcode" VALUES(14060,32310,-5,'Tallahassee, Florida 32310',10087,12371);
INSERT INTO "django_geo_db_zipcode" VALUES(14061,32311,-5,'Tallahassee, Florida 32311',10087,12372);
INSERT INTO "django_geo_db_zipcode" VALUES(14062,32312,-5,'Tallahassee, Florida 32312',10087,12373);
INSERT INTO "django_geo_db_zipcode" VALUES(14063,32313,-5,'Tallahassee, Florida 32313',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14064,32314,-5,'Tallahassee, Florida 32314',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14065,32315,-5,'Tallahassee, Florida 32315',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14066,32316,-5,'Tallahassee, Florida 32316',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14067,32317,-5,'Tallahassee, Florida 32317',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14068,32320,-5,'Apalachicola, Florida 32320',10090,12374);
INSERT INTO "django_geo_db_zipcode" VALUES(14069,32321,-5,'Bristol, Florida 32321',10091,12375);
INSERT INTO "django_geo_db_zipcode" VALUES(14070,32322,-5,'Carrabelle, Florida 32322',10092,12376);
INSERT INTO "django_geo_db_zipcode" VALUES(14071,32323,-5,'Lanark Village, Florida 32323',10093,12377);
INSERT INTO "django_geo_db_zipcode" VALUES(14072,32324,-5,'Chattahoochee, Florida 32324',10094,12378);
INSERT INTO "django_geo_db_zipcode" VALUES(14073,32326,-5,'Crawfordville, Florida 32326',10095,12379);
INSERT INTO "django_geo_db_zipcode" VALUES(14074,32327,-5,'Crawfordville, Florida 32327',10095,12380);
INSERT INTO "django_geo_db_zipcode" VALUES(14075,32328,-5,'Eastpoint, Florida 32328',10096,12381);
INSERT INTO "django_geo_db_zipcode" VALUES(14076,32329,-5,'Apalachicola, Florida 32329',10090,12382);
INSERT INTO "django_geo_db_zipcode" VALUES(14077,32330,-5,'Greensboro, Florida 32330',10097,12383);
INSERT INTO "django_geo_db_zipcode" VALUES(14078,32331,-5,'Greenville, Florida 32331',10098,12384);
INSERT INTO "django_geo_db_zipcode" VALUES(14079,32332,-5,'Gretna, Florida 32332',10099,12385);
INSERT INTO "django_geo_db_zipcode" VALUES(14080,32333,-5,'Havana, Florida 32333',10100,12386);
INSERT INTO "django_geo_db_zipcode" VALUES(14081,32334,-5,'Hosford, Florida 32334',10101,12387);
INSERT INTO "django_geo_db_zipcode" VALUES(14082,32335,-5,'Sumatra, Florida 32335',10102,12388);
INSERT INTO "django_geo_db_zipcode" VALUES(14083,32336,-5,'Lamont, Florida 32336',10103,12389);
INSERT INTO "django_geo_db_zipcode" VALUES(14084,32337,-5,'Lloyd, Florida 32337',10104,12390);
INSERT INTO "django_geo_db_zipcode" VALUES(14085,32340,-5,'Madison, Florida 32340',10105,12391);
INSERT INTO "django_geo_db_zipcode" VALUES(14086,32341,-5,'Madison, Florida 32341',10105,12392);
INSERT INTO "django_geo_db_zipcode" VALUES(14087,32342,-5,'Midway, Florida 32342',10106,12393);
INSERT INTO "django_geo_db_zipcode" VALUES(14088,32343,-5,'Midway, Florida 32343',10106,12394);
INSERT INTO "django_geo_db_zipcode" VALUES(14089,32344,-5,'Monticello, Florida 32344',10107,12395);
INSERT INTO "django_geo_db_zipcode" VALUES(14090,32345,-5,'Monticello, Florida 32345',10107,12396);
INSERT INTO "django_geo_db_zipcode" VALUES(14091,32346,-5,'Panacea, Florida 32346',10108,12397);
INSERT INTO "django_geo_db_zipcode" VALUES(14092,32347,-5,'Perry, Florida 32347',10109,12398);
INSERT INTO "django_geo_db_zipcode" VALUES(14093,32348,-5,'Perry, Florida 32348',10109,12399);
INSERT INTO "django_geo_db_zipcode" VALUES(14094,32349,-5,'Perry, Florida 32349',10109,12400);
INSERT INTO "django_geo_db_zipcode" VALUES(14095,32350,-5,'Pinetta, Florida 32350',10110,12401);
INSERT INTO "django_geo_db_zipcode" VALUES(14096,32351,-5,'Quincy, Florida 32351',10111,12402);
INSERT INTO "django_geo_db_zipcode" VALUES(14097,32352,-5,'Mount Pleasant, Florida 32352',10112,12403);
INSERT INTO "django_geo_db_zipcode" VALUES(14098,32353,-5,'Quincy, Florida 32353',10111,12404);
INSERT INTO "django_geo_db_zipcode" VALUES(14099,32355,-5,'Saint Marks, Florida 32355',10113,12405);
INSERT INTO "django_geo_db_zipcode" VALUES(14100,32356,-5,'Salem, Florida 32356',10114,12406);
INSERT INTO "django_geo_db_zipcode" VALUES(14101,32357,-5,'Shady Grove, Florida 32357',10115,12407);
INSERT INTO "django_geo_db_zipcode" VALUES(14102,32358,-5,'Sopchoppy, Florida 32358',10116,12408);
INSERT INTO "django_geo_db_zipcode" VALUES(14103,32359,-5,'Steinhatchee, Florida 32359',10117,12409);
INSERT INTO "django_geo_db_zipcode" VALUES(14104,32360,-5,'Telogia, Florida 32360',10118,12410);
INSERT INTO "django_geo_db_zipcode" VALUES(14105,32361,-5,'Wacissa, Florida 32361',10119,12411);
INSERT INTO "django_geo_db_zipcode" VALUES(14106,32362,-5,'Woodville, Florida 32362',10120,12412);
INSERT INTO "django_geo_db_zipcode" VALUES(14107,32395,-5,'Tallahassee, Florida 32395',10087,12363);
INSERT INTO "django_geo_db_zipcode" VALUES(14108,32399,-5,'Tallahassee, Florida 32399',10087,12413);
INSERT INTO "django_geo_db_zipcode" VALUES(14109,32401,-6,'Panama City, Florida 32401',10121,12414);
INSERT INTO "django_geo_db_zipcode" VALUES(14110,32402,-5,'Panama City, Florida 32402',10121,12415);
INSERT INTO "django_geo_db_zipcode" VALUES(14111,32403,-6,'Panama City, Florida 32403',10121,12416);
INSERT INTO "django_geo_db_zipcode" VALUES(14112,32404,-6,'Panama City, Florida 32404',10121,12417);
INSERT INTO "django_geo_db_zipcode" VALUES(14113,32405,-6,'Panama City, Florida 32405',10121,12418);
INSERT INTO "django_geo_db_zipcode" VALUES(14114,32406,-5,'Panama City, Florida 32406',10121,12415);
INSERT INTO "django_geo_db_zipcode" VALUES(14115,32407,-6,'Panama City Beach, Florida 32407',10122,12419);
INSERT INTO "django_geo_db_zipcode" VALUES(14116,32408,-6,'Panama City, Florida 32408',10121,12420);
INSERT INTO "django_geo_db_zipcode" VALUES(14117,32409,-6,'Panama City, Florida 32409',10121,12421);
INSERT INTO "django_geo_db_zipcode" VALUES(14118,32410,-6,'Mexico Beach, Florida 32410',10123,12422);
INSERT INTO "django_geo_db_zipcode" VALUES(14119,32411,-5,'Panama City, Florida 32411',10121,12415);
INSERT INTO "django_geo_db_zipcode" VALUES(14120,32412,-5,'Panama City, Florida 32412',10121,12415);
INSERT INTO "django_geo_db_zipcode" VALUES(14121,32413,-6,'Panama City Beach, Florida 32413',10122,12423);
INSERT INTO "django_geo_db_zipcode" VALUES(14122,32417,-6,'Panama City, Florida 32417',10121,12424);
INSERT INTO "django_geo_db_zipcode" VALUES(14123,32420,-6,'Alford, Florida 32420',10124,12425);
INSERT INTO "django_geo_db_zipcode" VALUES(14124,32421,-6,'Altha, Florida 32421',10125,12426);
INSERT INTO "django_geo_db_zipcode" VALUES(14125,32422,-6,'Argyle, Florida 32422',10126,12427);
INSERT INTO "django_geo_db_zipcode" VALUES(14126,32423,-6,'Bascom, Florida 32423',10127,12428);
INSERT INTO "django_geo_db_zipcode" VALUES(14127,32424,-6,'Blountstown, Florida 32424',10128,12429);
INSERT INTO "django_geo_db_zipcode" VALUES(14128,32425,-6,'Bonifay, Florida 32425',10129,12430);
INSERT INTO "django_geo_db_zipcode" VALUES(14129,32426,-6,'Campbellton, Florida 32426',10130,12431);
INSERT INTO "django_geo_db_zipcode" VALUES(14130,32427,-6,'Caryville, Florida 32427',10131,12432);
INSERT INTO "django_geo_db_zipcode" VALUES(14131,32428,-6,'Chipley, Florida 32428',10132,12433);
INSERT INTO "django_geo_db_zipcode" VALUES(14132,32430,-6,'Clarksville, Florida 32430',10133,12434);
INSERT INTO "django_geo_db_zipcode" VALUES(14133,32431,-6,'Cottondale, Florida 32431',10134,12435);
INSERT INTO "django_geo_db_zipcode" VALUES(14134,32432,-6,'Cypress, Florida 32432',10135,12436);
INSERT INTO "django_geo_db_zipcode" VALUES(14135,32433,-6,'Defuniak Springs, Florida 32433',10136,12437);
INSERT INTO "django_geo_db_zipcode" VALUES(14136,32434,-6,'Mossy Head, Florida 32434',10137,12438);
INSERT INTO "django_geo_db_zipcode" VALUES(14137,32435,-6,'Defuniak Springs, Florida 32435',10136,12439);
INSERT INTO "django_geo_db_zipcode" VALUES(14138,32436,-6,'Wewahitchka, Florida 32436',10138,12440);
INSERT INTO "django_geo_db_zipcode" VALUES(14139,32437,-6,'Ebro, Florida 32437',10139,12441);
INSERT INTO "django_geo_db_zipcode" VALUES(14140,32438,-6,'Fountain, Florida 32438',10140,12442);
INSERT INTO "django_geo_db_zipcode" VALUES(14141,32439,-6,'Freeport, Florida 32439',10141,12443);
INSERT INTO "django_geo_db_zipcode" VALUES(14142,32440,-6,'Graceville, Florida 32440',10142,12444);
INSERT INTO "django_geo_db_zipcode" VALUES(14143,32442,-6,'Grand Ridge, Florida 32442',10143,12445);
INSERT INTO "django_geo_db_zipcode" VALUES(14144,32443,-6,'Greenwood, Florida 32443',10144,12446);
INSERT INTO "django_geo_db_zipcode" VALUES(14145,32444,-6,'Lynn Haven, Florida 32444',10145,12447);
INSERT INTO "django_geo_db_zipcode" VALUES(14146,32445,-6,'Malone, Florida 32445',10146,12448);
INSERT INTO "django_geo_db_zipcode" VALUES(14147,32446,-6,'Marianna, Florida 32446',10147,12449);
INSERT INTO "django_geo_db_zipcode" VALUES(14148,32447,-6,'Marianna, Florida 32447',10147,12450);
INSERT INTO "django_geo_db_zipcode" VALUES(14149,32448,-6,'Marianna, Florida 32448',10147,12451);
INSERT INTO "django_geo_db_zipcode" VALUES(14150,32449,-6,'Kinard, Florida 32449',10148,12452);
INSERT INTO "django_geo_db_zipcode" VALUES(14151,32452,-6,'Noma, Florida 32452',10149,12453);
INSERT INTO "django_geo_db_zipcode" VALUES(14152,32454,-6,'Point Washington, Florida 32454',10150,12439);
INSERT INTO "django_geo_db_zipcode" VALUES(14153,32455,-6,'Ponce De Leon, Florida 32455',10151,12454);
INSERT INTO "django_geo_db_zipcode" VALUES(14154,32456,-5,'Port Saint Joe, Florida 32456',10152,12455);
INSERT INTO "django_geo_db_zipcode" VALUES(14155,32457,-6,'Port Saint Joe, Florida 32457',10152,12456);
INSERT INTO "django_geo_db_zipcode" VALUES(14156,32459,-6,'Santa Rosa Beach, Florida 32459',10153,12457);
INSERT INTO "django_geo_db_zipcode" VALUES(14157,32460,-6,'Sneads, Florida 32460',10154,12458);
INSERT INTO "django_geo_db_zipcode" VALUES(14158,32461,-6,'Sunnyside, Florida 32461',10155,12459);
INSERT INTO "django_geo_db_zipcode" VALUES(14159,32462,-6,'Vernon, Florida 32462',10156,12460);
INSERT INTO "django_geo_db_zipcode" VALUES(14160,32463,-6,'Wausau, Florida 32463',10157,12461);
INSERT INTO "django_geo_db_zipcode" VALUES(14161,32464,-6,'Westville, Florida 32464',10158,12462);
INSERT INTO "django_geo_db_zipcode" VALUES(14162,32465,-6,'Wewahitchka, Florida 32465',10138,12463);
INSERT INTO "django_geo_db_zipcode" VALUES(14163,32466,-6,'Youngstown, Florida 32466',10159,12464);
INSERT INTO "django_geo_db_zipcode" VALUES(14164,32476,-5,'Lake Mary, Florida 32476',10160,12465);
INSERT INTO "django_geo_db_zipcode" VALUES(14165,32478,-6,'Chipley, Florida 32478',10132,12466);
INSERT INTO "django_geo_db_zipcode" VALUES(14166,32501,-6,'Pensacola, Florida 32501',10161,12467);
INSERT INTO "django_geo_db_zipcode" VALUES(14167,32502,-6,'Pensacola, Florida 32502',10161,12468);
INSERT INTO "django_geo_db_zipcode" VALUES(14168,32503,-6,'Pensacola, Florida 32503',10161,12469);
INSERT INTO "django_geo_db_zipcode" VALUES(14169,32504,-6,'Pensacola, Florida 32504',10161,12470);
INSERT INTO "django_geo_db_zipcode" VALUES(14170,32505,-6,'Pensacola, Florida 32505',10161,12471);
INSERT INTO "django_geo_db_zipcode" VALUES(14171,32506,-6,'Pensacola, Florida 32506',10161,12472);
INSERT INTO "django_geo_db_zipcode" VALUES(14172,32507,-6,'Pensacola, Florida 32507',10161,12473);
INSERT INTO "django_geo_db_zipcode" VALUES(14173,32508,-6,'Pensacola, Florida 32508',10161,12474);
INSERT INTO "django_geo_db_zipcode" VALUES(14174,32509,-6,'Pensacola, Florida 32509',10161,12475);
INSERT INTO "django_geo_db_zipcode" VALUES(14175,32511,-6,'Pensacola, Florida 32511',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14176,32512,-6,'Pensacola, Florida 32512',10161,12477);
INSERT INTO "django_geo_db_zipcode" VALUES(14177,32513,-6,'Pensacola, Florida 32513',10161,12478);
INSERT INTO "django_geo_db_zipcode" VALUES(14178,32514,-6,'Pensacola, Florida 32514',10161,12479);
INSERT INTO "django_geo_db_zipcode" VALUES(14179,32516,-6,'Pensacola, Florida 32516',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14180,32520,-6,'Pensacola, Florida 32520',10161,12480);
INSERT INTO "django_geo_db_zipcode" VALUES(14181,32521,-6,'Pensacola, Florida 32521',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14182,32522,-6,'Pensacola, Florida 32522',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14183,32523,-6,'Pensacola, Florida 32523',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14184,32524,-6,'Pensacola, Florida 32524',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14185,32526,-6,'Pensacola, Florida 32526',10161,12481);
INSERT INTO "django_geo_db_zipcode" VALUES(14186,32530,-6,'Bagdad, Florida 32530',10162,12482);
INSERT INTO "django_geo_db_zipcode" VALUES(14187,32531,-6,'Baker, Florida 32531',10163,12483);
INSERT INTO "django_geo_db_zipcode" VALUES(14188,32533,-6,'Cantonment, Florida 32533',10164,12484);
INSERT INTO "django_geo_db_zipcode" VALUES(14189,32534,-6,'Pensacola, Florida 32534',10161,12485);
INSERT INTO "django_geo_db_zipcode" VALUES(14190,32535,-6,'Century, Florida 32535',10165,12486);
INSERT INTO "django_geo_db_zipcode" VALUES(14191,32536,-6,'Crestview, Florida 32536',10166,12487);
INSERT INTO "django_geo_db_zipcode" VALUES(14192,32537,-6,'Milligan, Florida 32537',10167,12488);
INSERT INTO "django_geo_db_zipcode" VALUES(14193,32538,-6,'Paxton, Florida 32538',10168,12489);
INSERT INTO "django_geo_db_zipcode" VALUES(14194,32539,-6,'Crestview, Florida 32539',10166,12490);
INSERT INTO "django_geo_db_zipcode" VALUES(14195,32540,-6,'Destin, Florida 32540',10169,12491);
INSERT INTO "django_geo_db_zipcode" VALUES(14196,32541,-6,'Destin, Florida 32541',10169,12492);
INSERT INTO "django_geo_db_zipcode" VALUES(14197,32542,-6,'Eglin AFB, Florida 32542',10170,12493);
INSERT INTO "django_geo_db_zipcode" VALUES(14198,32544,-6,'Hurlburt Field, Florida 32544',10171,12494);
INSERT INTO "django_geo_db_zipcode" VALUES(14199,32546,-6,'Myrtle Grove, Florida 32546',10172,12495);
INSERT INTO "django_geo_db_zipcode" VALUES(14200,32547,-6,'Fort Walton Beach, Florida 32547',10173,12496);
INSERT INTO "django_geo_db_zipcode" VALUES(14201,32548,-6,'Fort Walton Beach, Florida 32548',10173,12497);
INSERT INTO "django_geo_db_zipcode" VALUES(14202,32549,-6,'Fort Walton Beach, Florida 32549',10173,12491);
INSERT INTO "django_geo_db_zipcode" VALUES(14203,32550,-6,'Miramar Beach, Florida 32550',10174,12498);
INSERT INTO "django_geo_db_zipcode" VALUES(14204,32559,-6,'Pensacola, Florida 32559',10161,12499);
INSERT INTO "django_geo_db_zipcode" VALUES(14205,32560,-6,'Gonzalez, Florida 32560',10175,12500);
INSERT INTO "django_geo_db_zipcode" VALUES(14206,32561,-6,'Gulf Breeze, Florida 32561',10176,12501);
INSERT INTO "django_geo_db_zipcode" VALUES(14207,32562,-6,'Gulf Breeze, Florida 32562',10176,12502);
INSERT INTO "django_geo_db_zipcode" VALUES(14208,32563,-6,'Harold, Florida 32563',10177,12502);
INSERT INTO "django_geo_db_zipcode" VALUES(14209,32564,-6,'Holt, Florida 32564',10178,12503);
INSERT INTO "django_geo_db_zipcode" VALUES(14210,32565,-6,'Jay, Florida 32565',10179,12504);
INSERT INTO "django_geo_db_zipcode" VALUES(14211,32566,-6,'Gulf Breeze, Florida 32566',10176,12505);
INSERT INTO "django_geo_db_zipcode" VALUES(14212,32567,-6,'Laurel Hill, Florida 32567',10180,12506);
INSERT INTO "django_geo_db_zipcode" VALUES(14213,32568,-6,'McDavid, Florida 32568',10181,12507);
INSERT INTO "django_geo_db_zipcode" VALUES(14214,32569,-5,'Mary Esther, Florida 32569',10182,12508);
INSERT INTO "django_geo_db_zipcode" VALUES(14215,32570,-6,'Milton, Florida 32570',10183,12509);
INSERT INTO "django_geo_db_zipcode" VALUES(14216,32571,-6,'Milton, Florida 32571',10183,12510);
INSERT INTO "django_geo_db_zipcode" VALUES(14217,32572,-6,'Milton, Florida 32572',10183,12502);
INSERT INTO "django_geo_db_zipcode" VALUES(14218,32573,-6,'Pensacola, Florida 32573',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14219,32574,-6,'Pensacola, Florida 32574',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14220,32575,-6,'Pensacola, Florida 32575',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14221,32576,-6,'Pensacola, Florida 32576',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14222,32577,-6,'Molino, Florida 32577',10184,12511);
INSERT INTO "django_geo_db_zipcode" VALUES(14223,32578,-5,'Niceville, Florida 32578',10185,12512);
INSERT INTO "django_geo_db_zipcode" VALUES(14224,32579,-6,'Shalimar, Florida 32579',10186,12513);
INSERT INTO "django_geo_db_zipcode" VALUES(14225,32580,-6,'Valparaiso, Florida 32580',10187,12514);
INSERT INTO "django_geo_db_zipcode" VALUES(14226,32581,-6,'Pensacola, Florida 32581',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14227,32582,-6,'Pensacola, Florida 32582',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14228,32583,-6,'Milton, Florida 32583',10183,12515);
INSERT INTO "django_geo_db_zipcode" VALUES(14229,32588,-6,'Niceville, Florida 32588',10185,12491);
INSERT INTO "django_geo_db_zipcode" VALUES(14230,32589,-6,'Pensacola, Florida 32589',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14231,32590,-6,'Pensacola, Florida 32590',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14232,32591,-6,'Pensacola, Florida 32591',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14233,32592,-6,'Pensacola, Florida 32592',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14234,32593,-6,'Pensacola, Florida 32593',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14235,32594,-6,'Pensacola, Florida 32594',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14236,32595,-6,'Pensacola, Florida 32595',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14237,32596,-6,'Pensacola, Florida 32596',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14238,32597,-6,'Pensacola, Florida 32597',10161,12516);
INSERT INTO "django_geo_db_zipcode" VALUES(14239,32598,-6,'Pensacola, Florida 32598',10161,12476);
INSERT INTO "django_geo_db_zipcode" VALUES(14240,32601,-5,'Gainesville, Florida 32601',10188,12517);
INSERT INTO "django_geo_db_zipcode" VALUES(14241,32602,-5,'Gainesville, Florida 32602',10188,12518);
INSERT INTO "django_geo_db_zipcode" VALUES(14242,32603,-5,'Gainesville, Florida 32603',10188,12519);
INSERT INTO "django_geo_db_zipcode" VALUES(14243,32604,-5,'Gainesville, Florida 32604',10188,12520);
INSERT INTO "django_geo_db_zipcode" VALUES(14244,32605,-5,'Gainesville, Florida 32605',10188,12521);
INSERT INTO "django_geo_db_zipcode" VALUES(14245,32606,-5,'Gainesville, Florida 32606',10188,12522);
INSERT INTO "django_geo_db_zipcode" VALUES(14246,32607,-5,'Gainesville, Florida 32607',10188,12523);
INSERT INTO "django_geo_db_zipcode" VALUES(14247,32608,-5,'Gainesville, Florida 32608',10188,12524);
INSERT INTO "django_geo_db_zipcode" VALUES(14248,32609,-5,'Gainesville, Florida 32609',10188,12525);
INSERT INTO "django_geo_db_zipcode" VALUES(14249,32610,-5,'Gainesville, Florida 32610',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14250,32611,-5,'Gainesville, Florida 32611',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14251,32612,-5,'Gainesville, Florida 32612',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14252,32613,-5,'Gainesville, Florida 32613',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14253,32614,-5,'Gainesville, Florida 32614',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14254,32615,-5,'Alachua, Florida 32615',10189,12527);
INSERT INTO "django_geo_db_zipcode" VALUES(14255,32616,-5,'Alachua, Florida 32616',10189,12528);
INSERT INTO "django_geo_db_zipcode" VALUES(14256,32617,-5,'Anthony, Florida 32617',10190,12529);
INSERT INTO "django_geo_db_zipcode" VALUES(14257,32618,-5,'Archer, Florida 32618',10191,12530);
INSERT INTO "django_geo_db_zipcode" VALUES(14258,32619,-5,'Bell, Florida 32619',10192,12531);
INSERT INTO "django_geo_db_zipcode" VALUES(14259,32621,-5,'Bronson, Florida 32621',10193,12532);
INSERT INTO "django_geo_db_zipcode" VALUES(14260,32622,-5,'Brooker, Florida 32622',10194,12533);
INSERT INTO "django_geo_db_zipcode" VALUES(14261,32625,-5,'Cedar Key, Florida 32625',10195,12534);
INSERT INTO "django_geo_db_zipcode" VALUES(14262,32626,-5,'Chiefland, Florida 32626',10196,12535);
INSERT INTO "django_geo_db_zipcode" VALUES(14263,32627,-5,'Gainesville, Florida 32627',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14264,32628,-5,'Cross City, Florida 32628',10197,12536);
INSERT INTO "django_geo_db_zipcode" VALUES(14265,32631,-5,'Earleton, Florida 32631',10198,12537);
INSERT INTO "django_geo_db_zipcode" VALUES(14266,32633,-5,'Evinston, Florida 32633',10199,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14267,32634,-5,'Fairfield, Florida 32634',10200,12538);
INSERT INTO "django_geo_db_zipcode" VALUES(14268,32635,-5,'Gainesville, Florida 32635',10188,12526);
INSERT INTO "django_geo_db_zipcode" VALUES(14269,32638,-5,'Trenton, Florida 32638',10201,12539);
INSERT INTO "django_geo_db_zipcode" VALUES(14270,32639,-5,'Gulf Hammock, Florida 32639',10202,12540);
INSERT INTO "django_geo_db_zipcode" VALUES(14271,32640,-5,'Hawthorne, Florida 32640',10203,12541);
INSERT INTO "django_geo_db_zipcode" VALUES(14272,32641,-5,'Gainesville, Florida 32641',10188,12542);
INSERT INTO "django_geo_db_zipcode" VALUES(14273,32643,-5,'High Springs, Florida 32643',10204,12543);
INSERT INTO "django_geo_db_zipcode" VALUES(14274,32644,-5,'Chiefland, Florida 32644',10196,12544);
INSERT INTO "django_geo_db_zipcode" VALUES(14275,32648,-5,'Horseshoe Beach, Florida 32648',10205,12545);
INSERT INTO "django_geo_db_zipcode" VALUES(14276,32653,-5,'Gainesville, Florida 32653',10188,12546);
INSERT INTO "django_geo_db_zipcode" VALUES(14277,32654,-5,'Island Grove, Florida 32654',10206,12547);
INSERT INTO "django_geo_db_zipcode" VALUES(14278,32655,-5,'High Springs, Florida 32655',10204,12548);
INSERT INTO "django_geo_db_zipcode" VALUES(14279,32656,-5,'Keystone Heights, Florida 32656',10207,12549);
INSERT INTO "django_geo_db_zipcode" VALUES(14280,32658,-5,'La Crosse, Florida 32658',10208,12550);
INSERT INTO "django_geo_db_zipcode" VALUES(14281,32662,-5,'Lochloosa, Florida 32662',10209,12551);
INSERT INTO "django_geo_db_zipcode" VALUES(14282,32663,-5,'Lowell, Florida 32663',10210,12552);
INSERT INTO "django_geo_db_zipcode" VALUES(14283,32664,-5,'McIntosh, Florida 32664',10211,12553);
INSERT INTO "django_geo_db_zipcode" VALUES(14284,32666,-5,'Melrose, Florida 32666',10212,12554);
INSERT INTO "django_geo_db_zipcode" VALUES(14285,32667,-5,'Micanopy, Florida 32667',10213,12555);
INSERT INTO "django_geo_db_zipcode" VALUES(14286,32668,-5,'Morriston, Florida 32668',10214,12556);
INSERT INTO "django_geo_db_zipcode" VALUES(14287,32669,-5,'Newberry, Florida 32669',10215,12557);
INSERT INTO "django_geo_db_zipcode" VALUES(14288,32680,-5,'Old Town, Florida 32680',10216,12558);
INSERT INTO "django_geo_db_zipcode" VALUES(14289,32681,-5,'Orange Lake, Florida 32681',10217,12559);
INSERT INTO "django_geo_db_zipcode" VALUES(14290,32683,-5,'Otter Creek, Florida 32683',10218,12560);
INSERT INTO "django_geo_db_zipcode" VALUES(14291,32686,-5,'Reddick, Florida 32686',10219,12561);
INSERT INTO "django_geo_db_zipcode" VALUES(14292,32692,-5,'Suwannee, Florida 32692',10220,12562);
INSERT INTO "django_geo_db_zipcode" VALUES(14293,32693,-5,'Trenton, Florida 32693',10201,12563);
INSERT INTO "django_geo_db_zipcode" VALUES(14294,32694,-5,'Waldo, Florida 32694',10221,12564);
INSERT INTO "django_geo_db_zipcode" VALUES(14295,32696,-5,'Williston, Florida 32696',10222,12565);
INSERT INTO "django_geo_db_zipcode" VALUES(14296,32697,-5,'Worthington Springs, Florida 32697',10223,12566);
INSERT INTO "django_geo_db_zipcode" VALUES(14297,32699,-5,'Newberry, Florida 32699',10215,12567);
INSERT INTO "django_geo_db_zipcode" VALUES(14298,32701,-5,'Altamonte Springs, Florida 32701',10224,12568);
INSERT INTO "django_geo_db_zipcode" VALUES(14299,32702,-5,'Altoona, Florida 32702',10225,12569);
INSERT INTO "django_geo_db_zipcode" VALUES(14300,32703,-5,'Apopka, Florida 32703',10226,12570);
INSERT INTO "django_geo_db_zipcode" VALUES(14301,32704,-5,'Apopka, Florida 32704',10226,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14302,32706,-5,'Cassadaga, Florida 32706',10227,12572);
INSERT INTO "django_geo_db_zipcode" VALUES(14303,32707,-5,'Casselberry, Florida 32707',10228,12573);
INSERT INTO "django_geo_db_zipcode" VALUES(14304,32708,-5,'Winter Springs, Florida 32708',10229,12574);
INSERT INTO "django_geo_db_zipcode" VALUES(14305,32709,-5,'Christmas, Florida 32709',10230,12575);
INSERT INTO "django_geo_db_zipcode" VALUES(14306,32710,-5,'Clarcona, Florida 32710',10231,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14307,32712,-5,'Apopka, Florida 32712',10226,12576);
INSERT INTO "django_geo_db_zipcode" VALUES(14308,32713,-5,'Debary, Florida 32713',10232,12577);
INSERT INTO "django_geo_db_zipcode" VALUES(14309,32714,-5,'Altamonte Springs, Florida 32714',10224,12578);
INSERT INTO "django_geo_db_zipcode" VALUES(14310,32715,-5,'Altamonte Springs, Florida 32715',10224,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14311,32716,-5,'Altamonte Springs, Florida 32716',10224,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14312,32718,-5,'Casselberry, Florida 32718',10228,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14313,32719,-5,'Winter Springs, Florida 32719',10229,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14314,32720,-5,'Deland, Florida 32720',10233,12580);
INSERT INTO "django_geo_db_zipcode" VALUES(14315,32721,-5,'Deland, Florida 32721',10233,12581);
INSERT INTO "django_geo_db_zipcode" VALUES(14316,32722,-5,'Glenwood, Florida 32722',10234,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(14317,32724,-5,'Deland, Florida 32724',10233,12582);
INSERT INTO "django_geo_db_zipcode" VALUES(14318,32725,-5,'Deltona, Florida 32725',10235,12583);
INSERT INTO "django_geo_db_zipcode" VALUES(14319,32726,-5,'Eustis, Florida 32726',10236,12584);
INSERT INTO "django_geo_db_zipcode" VALUES(14320,32727,-5,'Eustis, Florida 32727',10236,12585);
INSERT INTO "django_geo_db_zipcode" VALUES(14321,32728,-5,'Deltona, Florida 32728',10235,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(14322,32730,-5,'Casselberry, Florida 32730',10228,12586);
INSERT INTO "django_geo_db_zipcode" VALUES(14323,32732,-5,'Geneva, Florida 32732',10237,12587);
INSERT INTO "django_geo_db_zipcode" VALUES(14324,32733,-5,'Goldenrod, Florida 32733',10238,12588);
INSERT INTO "django_geo_db_zipcode" VALUES(14325,32735,-5,'Grand Island, Florida 32735',10239,12589);
INSERT INTO "django_geo_db_zipcode" VALUES(14326,32736,-5,'Eustis, Florida 32736',10236,12590);
INSERT INTO "django_geo_db_zipcode" VALUES(14327,32738,-5,'Deltona, Florida 32738',10235,12591);
INSERT INTO "django_geo_db_zipcode" VALUES(14328,32739,-5,'Deltona, Florida 32739',10235,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(14329,32744,-5,'Lake Helen, Florida 32744',10240,12592);
INSERT INTO "django_geo_db_zipcode" VALUES(14330,32745,-5,'Heathrow, Florida 32745',10241,12593);
INSERT INTO "django_geo_db_zipcode" VALUES(14331,32746,-5,'Lake Mary, Florida 32746',10160,12594);
INSERT INTO "django_geo_db_zipcode" VALUES(14332,32747,-5,'Lake Monroe, Florida 32747',10242,12595);
INSERT INTO "django_geo_db_zipcode" VALUES(14333,32750,-5,'Longwood, Florida 32750',10243,12596);
INSERT INTO "django_geo_db_zipcode" VALUES(14334,32751,-5,'Maitland, Florida 32751',10244,12597);
INSERT INTO "django_geo_db_zipcode" VALUES(14335,32752,-5,'Longwood, Florida 32752',10243,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14336,32754,-5,'Mims, Florida 32754',10245,12598);
INSERT INTO "django_geo_db_zipcode" VALUES(14337,32756,-5,'Mount Dora, Florida 32756',10246,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(14338,32757,-5,'Mount Dora, Florida 32757',10246,12599);
INSERT INTO "django_geo_db_zipcode" VALUES(14339,32759,-5,'Oak Hill, Florida 32759',10247,12600);
INSERT INTO "django_geo_db_zipcode" VALUES(14340,32762,-5,'Oviedo, Florida 32762',10248,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14341,32763,-5,'Orange City, Florida 32763',10249,12601);
INSERT INTO "django_geo_db_zipcode" VALUES(14342,32764,-5,'Osteen, Florida 32764',10250,12602);
INSERT INTO "django_geo_db_zipcode" VALUES(14343,32765,-5,'Oviedo, Florida 32765',10248,12603);
INSERT INTO "django_geo_db_zipcode" VALUES(14344,32766,-5,'Oviedo, Florida 32766',10248,12604);
INSERT INTO "django_geo_db_zipcode" VALUES(14345,32767,-5,'Paisley, Florida 32767',10251,12605);
INSERT INTO "django_geo_db_zipcode" VALUES(14346,32768,-5,'Plymouth, Florida 32768',10252,12606);
INSERT INTO "django_geo_db_zipcode" VALUES(14347,32769,-5,'Oak Hill, Florida 32769',10247,12607);
INSERT INTO "django_geo_db_zipcode" VALUES(14348,32771,-5,'Sanford, Florida 32771',10253,12608);
INSERT INTO "django_geo_db_zipcode" VALUES(14349,32772,-5,'Sanford, Florida 32772',10253,12609);
INSERT INTO "django_geo_db_zipcode" VALUES(14350,32773,-5,'Sanford, Florida 32773',10253,12610);
INSERT INTO "django_geo_db_zipcode" VALUES(14351,32774,-5,'Orange City, Florida 32774',10249,12273);
INSERT INTO "django_geo_db_zipcode" VALUES(14352,32775,-5,'Scottsmoor, Florida 32775',10254,12611);
INSERT INTO "django_geo_db_zipcode" VALUES(14353,32776,-5,'Sorrento, Florida 32776',10255,12612);
INSERT INTO "django_geo_db_zipcode" VALUES(14354,32777,-5,'Tangerine, Florida 32777',10256,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14355,32778,-5,'Tavares, Florida 32778',10257,12613);
INSERT INTO "django_geo_db_zipcode" VALUES(14356,32779,-5,'Longwood, Florida 32779',10243,12614);
INSERT INTO "django_geo_db_zipcode" VALUES(14357,32780,-5,'Titusville, Florida 32780',10258,12615);
INSERT INTO "django_geo_db_zipcode" VALUES(14358,32781,-5,'Titusville, Florida 32781',10258,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14359,32782,-5,'Titusville, Florida 32782',10258,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14360,32783,-5,'Titusville, Florida 32783',10258,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14361,32784,-5,'Umatilla, Florida 32784',10259,12617);
INSERT INTO "django_geo_db_zipcode" VALUES(14362,32789,-5,'Winter Park, Florida 32789',10260,12618);
INSERT INTO "django_geo_db_zipcode" VALUES(14363,32790,-5,'Winter Park, Florida 32790',10260,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14364,32791,-5,'Longwood, Florida 32791',10243,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14365,32792,-5,'Winter Park, Florida 32792',10260,12619);
INSERT INTO "django_geo_db_zipcode" VALUES(14366,32793,-5,'Winter Park, Florida 32793',10260,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14367,32794,-5,'Maitland, Florida 32794',10244,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14368,32795,-5,'Lake Mary, Florida 32795',10160,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14369,32796,-5,'Titusville, Florida 32796',10258,12620);
INSERT INTO "django_geo_db_zipcode" VALUES(14370,32798,-5,'Zellwood, Florida 32798',10261,12621);
INSERT INTO "django_geo_db_zipcode" VALUES(14371,32799,-5,'Mid Florida, Florida 32799',10262,12579);
INSERT INTO "django_geo_db_zipcode" VALUES(14372,32801,-5,'Orlando, Florida 32801',10263,12622);
INSERT INTO "django_geo_db_zipcode" VALUES(14373,32802,-5,'Orlando, Florida 32802',10263,12623);
INSERT INTO "django_geo_db_zipcode" VALUES(14374,32803,-5,'Orlando, Florida 32803',10263,12624);
INSERT INTO "django_geo_db_zipcode" VALUES(14375,32804,-5,'Orlando, Florida 32804',10263,12625);
INSERT INTO "django_geo_db_zipcode" VALUES(14376,32805,-5,'Orlando, Florida 32805',10263,12626);
INSERT INTO "django_geo_db_zipcode" VALUES(14377,32806,-5,'Orlando, Florida 32806',10263,12627);
INSERT INTO "django_geo_db_zipcode" VALUES(14378,32807,-5,'Orlando, Florida 32807',10263,12628);
INSERT INTO "django_geo_db_zipcode" VALUES(14379,32808,-5,'Orlando, Florida 32808',10263,12629);
INSERT INTO "django_geo_db_zipcode" VALUES(14380,32809,-5,'Orlando, Florida 32809',10263,12630);
INSERT INTO "django_geo_db_zipcode" VALUES(14381,32810,-5,'Orlando, Florida 32810',10263,12631);
INSERT INTO "django_geo_db_zipcode" VALUES(14382,32811,-5,'Orlando, Florida 32811',10263,12632);
INSERT INTO "django_geo_db_zipcode" VALUES(14383,32812,-5,'Orlando, Florida 32812',10263,12633);
INSERT INTO "django_geo_db_zipcode" VALUES(14384,32813,-5,'Orlando, Florida 32813',10263,12634);
INSERT INTO "django_geo_db_zipcode" VALUES(14385,32814,-5,'Orlando, Florida 32814',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14386,32815,-5,'Orlando, Florida 32815',10263,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14387,32816,-5,'Orlando, Florida 32816',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14388,32817,-5,'Orlando, Florida 32817',10263,12635);
INSERT INTO "django_geo_db_zipcode" VALUES(14389,32818,-5,'Orlando, Florida 32818',10263,12636);
INSERT INTO "django_geo_db_zipcode" VALUES(14390,32819,-5,'Orlando, Florida 32819',10263,12637);
INSERT INTO "django_geo_db_zipcode" VALUES(14391,32820,-5,'Orlando, Florida 32820',10263,12638);
INSERT INTO "django_geo_db_zipcode" VALUES(14392,32821,-5,'Orlando, Florida 32821',10263,12639);
INSERT INTO "django_geo_db_zipcode" VALUES(14393,32822,-5,'Orlando, Florida 32822',10263,12640);
INSERT INTO "django_geo_db_zipcode" VALUES(14394,32824,-5,'Orlando, Florida 32824',10263,12641);
INSERT INTO "django_geo_db_zipcode" VALUES(14395,32825,-5,'Orlando, Florida 32825',10263,12642);
INSERT INTO "django_geo_db_zipcode" VALUES(14396,32826,-5,'Orlando, Florida 32826',10263,12643);
INSERT INTO "django_geo_db_zipcode" VALUES(14397,32827,-5,'Orlando, Florida 32827',10263,12644);
INSERT INTO "django_geo_db_zipcode" VALUES(14398,32828,-5,'Orlando, Florida 32828',10263,12645);
INSERT INTO "django_geo_db_zipcode" VALUES(14399,32829,-5,'Orlando, Florida 32829',10263,12646);
INSERT INTO "django_geo_db_zipcode" VALUES(14400,32830,-5,'Orlando, Florida 32830',10263,12647);
INSERT INTO "django_geo_db_zipcode" VALUES(14401,32831,-5,'Orlando, Florida 32831',10263,12648);
INSERT INTO "django_geo_db_zipcode" VALUES(14402,32832,-5,'Orlando, Florida 32832',10263,12649);
INSERT INTO "django_geo_db_zipcode" VALUES(14403,32833,-5,'Orlando, Florida 32833',10263,12650);
INSERT INTO "django_geo_db_zipcode" VALUES(14404,32834,-5,'Orlando, Florida 32834',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14405,32835,-5,'Orlando, Florida 32835',10263,12651);
INSERT INTO "django_geo_db_zipcode" VALUES(14406,32836,-5,'Orlando, Florida 32836',10263,12652);
INSERT INTO "django_geo_db_zipcode" VALUES(14407,32837,-5,'Orlando, Florida 32837',10263,12653);
INSERT INTO "django_geo_db_zipcode" VALUES(14408,32839,-5,'Orlando, Florida 32839',10263,12654);
INSERT INTO "django_geo_db_zipcode" VALUES(14409,32853,-5,'Orlando, Florida 32853',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14410,32854,-5,'Orlando, Florida 32854',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14411,32855,-5,'Orlando, Florida 32855',10263,12655);
INSERT INTO "django_geo_db_zipcode" VALUES(14412,32856,-5,'Orlando, Florida 32856',10263,12656);
INSERT INTO "django_geo_db_zipcode" VALUES(14413,32857,-5,'Orlando, Florida 32857',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14414,32858,-5,'Orlando, Florida 32858',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14415,32859,-5,'Orlando, Florida 32859',10263,12657);
INSERT INTO "django_geo_db_zipcode" VALUES(14416,32860,-5,'Orlando, Florida 32860',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14417,32861,-5,'Orlando, Florida 32861',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14418,32862,-5,'Orlando, Florida 32862',10263,12658);
INSERT INTO "django_geo_db_zipcode" VALUES(14419,32867,-5,'Orlando, Florida 32867',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14420,32868,-5,'Orlando, Florida 32868',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14421,32869,-5,'Orlando, Florida 32869',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14422,32872,-5,'Orlando, Florida 32872',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14423,32877,-5,'Orlando, Florida 32877',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14424,32878,-5,'Orlando, Florida 32878',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14425,32886,-5,'Orlando, Florida 32886',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14426,32887,-5,'Orlando, Florida 32887',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14427,32889,-5,'Orlando, Florida 32889',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14428,32890,-5,'Orlando, Florida 32890',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14429,32891,-5,'Orlando, Florida 32891',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14430,32893,-5,'Orlando, Florida 32893',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14431,32897,-5,'Orlando, Florida 32897',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14432,32898,-5,'Orlando, Florida 32898',10263,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(14433,32899,-5,'Orlando, Florida 32899',10263,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14434,32901,-5,'Melbourne, Florida 32901',10264,12659);
INSERT INTO "django_geo_db_zipcode" VALUES(14435,32902,-5,'Melbourne, Florida 32902',10264,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14436,32903,-5,'Indialantic, Florida 32903',10265,12660);
INSERT INTO "django_geo_db_zipcode" VALUES(14437,32904,-5,'Melbourne, Florida 32904',10264,12661);
INSERT INTO "django_geo_db_zipcode" VALUES(14438,32905,-5,'Palm Bay, Florida 32905',10266,12662);
INSERT INTO "django_geo_db_zipcode" VALUES(14439,32906,-5,'Palm Bay, Florida 32906',10266,12663);
INSERT INTO "django_geo_db_zipcode" VALUES(14440,32907,-5,'Palm Bay, Florida 32907',10266,12664);
INSERT INTO "django_geo_db_zipcode" VALUES(14441,32908,-5,'Palm Bay, Florida 32908',10266,12665);
INSERT INTO "django_geo_db_zipcode" VALUES(14442,32909,-5,'Palm Bay, Florida 32909',10266,12666);
INSERT INTO "django_geo_db_zipcode" VALUES(14443,32910,-5,'Palm Bay, Florida 32910',10266,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14444,32911,-5,'Palm Bay, Florida 32911',10266,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14445,32912,-5,'Melbourne, Florida 32912',10264,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14446,32919,-5,'Melbourne, Florida 32919',10264,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14447,32920,-5,'Cape Canaveral, Florida 32920',10267,12667);
INSERT INTO "django_geo_db_zipcode" VALUES(14448,32922,-5,'Cocoa, Florida 32922',10268,12668);
INSERT INTO "django_geo_db_zipcode" VALUES(14449,32923,-5,'Cocoa, Florida 32923',10268,12669);
INSERT INTO "django_geo_db_zipcode" VALUES(14450,32924,-5,'Cocoa, Florida 32924',10268,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14451,32925,-5,'Patrick AFB, Florida 32925',10269,12670);
INSERT INTO "django_geo_db_zipcode" VALUES(14452,32926,-5,'Cocoa, Florida 32926',10268,12671);
INSERT INTO "django_geo_db_zipcode" VALUES(14453,32927,-5,'Cocoa, Florida 32927',10268,12672);
INSERT INTO "django_geo_db_zipcode" VALUES(14454,32931,-5,'Cocoa Beach, Florida 32931',10270,12673);
INSERT INTO "django_geo_db_zipcode" VALUES(14455,32932,-5,'Cocoa Beach, Florida 32932',10270,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14456,32934,-5,'Melbourne, Florida 32934',10264,12674);
INSERT INTO "django_geo_db_zipcode" VALUES(14457,32935,-5,'Melbourne, Florida 32935',10264,12675);
INSERT INTO "django_geo_db_zipcode" VALUES(14458,32936,-5,'Melbourne, Florida 32936',10264,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14459,32937,-5,'Satellite Beach, Florida 32937',10271,12676);
INSERT INTO "django_geo_db_zipcode" VALUES(14460,32940,-5,'Melbourne, Florida 32940',10264,12677);
INSERT INTO "django_geo_db_zipcode" VALUES(14461,32941,-5,'Melbourne, Florida 32941',10264,12678);
INSERT INTO "django_geo_db_zipcode" VALUES(14462,32948,-5,'Fellsmere, Florida 32948',10272,12679);
INSERT INTO "django_geo_db_zipcode" VALUES(14463,32949,-5,'Grant, Florida 32949',10273,12680);
INSERT INTO "django_geo_db_zipcode" VALUES(14464,32950,-5,'Malabar, Florida 32950',10274,12681);
INSERT INTO "django_geo_db_zipcode" VALUES(14465,32951,-5,'Melbourne Beach, Florida 32951',10275,12682);
INSERT INTO "django_geo_db_zipcode" VALUES(14466,32952,-5,'Merritt Island, Florida 32952',10276,12683);
INSERT INTO "django_geo_db_zipcode" VALUES(14467,32953,-5,'Merritt Island, Florida 32953',10276,12684);
INSERT INTO "django_geo_db_zipcode" VALUES(14468,32954,-5,'Merritt Island, Florida 32954',10276,12685);
INSERT INTO "django_geo_db_zipcode" VALUES(14469,32955,-5,'Rockledge, Florida 32955',10277,12686);
INSERT INTO "django_geo_db_zipcode" VALUES(14470,32956,-5,'Rockledge, Florida 32956',10277,12687);
INSERT INTO "django_geo_db_zipcode" VALUES(14471,32957,-5,'Roseland, Florida 32957',10278,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14472,32958,-5,'Sebastian, Florida 32958',10279,12689);
INSERT INTO "django_geo_db_zipcode" VALUES(14473,32959,-5,'Sharpes, Florida 32959',10280,12616);
INSERT INTO "django_geo_db_zipcode" VALUES(14474,32960,-5,'Vero Beach, Florida 32960',10281,12690);
INSERT INTO "django_geo_db_zipcode" VALUES(14475,32961,-5,'Vero Beach, Florida 32961',10281,12691);
INSERT INTO "django_geo_db_zipcode" VALUES(14476,32962,-5,'Vero Beach, Florida 32962',10281,12692);
INSERT INTO "django_geo_db_zipcode" VALUES(14477,32963,-5,'Vero Beach, Florida 32963',10281,12693);
INSERT INTO "django_geo_db_zipcode" VALUES(14478,32964,-5,'Vero Beach, Florida 32964',10281,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14479,32965,-5,'Vero Beach, Florida 32965',10281,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14480,32966,-5,'Vero Beach, Florida 32966',10281,12694);
INSERT INTO "django_geo_db_zipcode" VALUES(14481,32967,-5,'Vero Beach, Florida 32967',10281,12695);
INSERT INTO "django_geo_db_zipcode" VALUES(14482,32968,-5,'Vero Beach, Florida 32968',10281,12696);
INSERT INTO "django_geo_db_zipcode" VALUES(14483,32969,-5,'Vero Beach, Florida 32969',10281,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14484,32970,-5,'Wabasso, Florida 32970',10282,12697);
INSERT INTO "django_geo_db_zipcode" VALUES(14485,32971,-5,'Winter Beach, Florida 32971',10283,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14486,32976,-5,'Sebastian, Florida 32976',10279,12698);
INSERT INTO "django_geo_db_zipcode" VALUES(14487,32977,-5,'Winter Beach, Florida 32977',10283,12699);
INSERT INTO "django_geo_db_zipcode" VALUES(14488,32978,-5,'Sebastian, Florida 32978',10279,12688);
INSERT INTO "django_geo_db_zipcode" VALUES(14489,33001,-5,'Long Key, Florida 33001',10284,12700);
INSERT INTO "django_geo_db_zipcode" VALUES(14490,33002,-5,'Hialeah, Florida 33002',10285,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14491,33003,-5,'Florida City, Florida 33003',10286,12702);
INSERT INTO "django_geo_db_zipcode" VALUES(14492,33004,-5,'Dania, Florida 33004',10287,12703);
INSERT INTO "django_geo_db_zipcode" VALUES(14493,33008,-5,'Hallandale, Florida 33008',10288,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14494,33009,-5,'Hallandale, Florida 33009',10288,12705);
INSERT INTO "django_geo_db_zipcode" VALUES(14495,33010,-5,'Hialeah, Florida 33010',10285,12706);
INSERT INTO "django_geo_db_zipcode" VALUES(14496,33011,-5,'Hialeah, Florida 33011',10285,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14497,33012,-5,'Hialeah, Florida 33012',10285,12707);
INSERT INTO "django_geo_db_zipcode" VALUES(14498,33013,-5,'Hialeah, Florida 33013',10285,12708);
INSERT INTO "django_geo_db_zipcode" VALUES(14499,33014,-5,'Hialeah, Florida 33014',10285,12709);
INSERT INTO "django_geo_db_zipcode" VALUES(14500,33015,-5,'Hialeah, Florida 33015',10285,12710);
INSERT INTO "django_geo_db_zipcode" VALUES(14501,33016,-5,'Hialeah, Florida 33016',10285,12711);
INSERT INTO "django_geo_db_zipcode" VALUES(14502,33017,-5,'Hialeah, Florida 33017',10285,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14503,33018,-5,'Hialeah, Florida 33018',10285,12712);
INSERT INTO "django_geo_db_zipcode" VALUES(14504,33019,-5,'Hollywood, Florida 33019',10289,12713);
INSERT INTO "django_geo_db_zipcode" VALUES(14505,33020,-5,'Hollywood, Florida 33020',10289,12714);
INSERT INTO "django_geo_db_zipcode" VALUES(14506,33021,-5,'Hollywood, Florida 33021',10289,12715);
INSERT INTO "django_geo_db_zipcode" VALUES(14507,33022,-5,'Hollywood, Florida 33022',10289,12716);
INSERT INTO "django_geo_db_zipcode" VALUES(14508,33023,-5,'Hollywood, Florida 33023',10289,12717);
INSERT INTO "django_geo_db_zipcode" VALUES(14509,33024,-5,'Hollywood, Florida 33024',10289,12718);
INSERT INTO "django_geo_db_zipcode" VALUES(14510,33025,-5,'Hollywood, Florida 33025',10289,12719);
INSERT INTO "django_geo_db_zipcode" VALUES(14511,33026,-5,'Hollywood, Florida 33026',10289,12720);
INSERT INTO "django_geo_db_zipcode" VALUES(14512,33027,-5,'Hollywood, Florida 33027',10289,12721);
INSERT INTO "django_geo_db_zipcode" VALUES(14513,33028,-5,'Pembroke Pines, Florida 33028',10290,12722);
INSERT INTO "django_geo_db_zipcode" VALUES(14514,33029,-5,'Hollywood, Florida 33029',10289,12723);
INSERT INTO "django_geo_db_zipcode" VALUES(14515,33030,-5,'Homestead, Florida 33030',10291,12724);
INSERT INTO "django_geo_db_zipcode" VALUES(14516,33031,-5,'Homestead, Florida 33031',10291,12725);
INSERT INTO "django_geo_db_zipcode" VALUES(14517,33032,-5,'Homestead, Florida 33032',10291,12726);
INSERT INTO "django_geo_db_zipcode" VALUES(14518,33033,-5,'Homestead, Florida 33033',10291,12727);
INSERT INTO "django_geo_db_zipcode" VALUES(14519,33034,-5,'Homestead, Florida 33034',10291,12728);
INSERT INTO "django_geo_db_zipcode" VALUES(14520,33035,-5,'Homestead, Florida 33035',10291,12729);
INSERT INTO "django_geo_db_zipcode" VALUES(14521,33036,-5,'Islamorada, Florida 33036',10292,12730);
INSERT INTO "django_geo_db_zipcode" VALUES(14522,33037,-5,'Key Largo, Florida 33037',10293,12731);
INSERT INTO "django_geo_db_zipcode" VALUES(14523,33039,-5,'Homestead, Florida 33039',10291,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14524,33040,-5,'Key West, Florida 33040',10294,12732);
INSERT INTO "django_geo_db_zipcode" VALUES(14525,33041,-5,'Key West, Florida 33041',10294,12733);
INSERT INTO "django_geo_db_zipcode" VALUES(14526,33042,-5,'Summerland Key, Florida 33042',10295,12734);
INSERT INTO "django_geo_db_zipcode" VALUES(14527,33043,-5,'Big Pine Key, Florida 33043',10296,12735);
INSERT INTO "django_geo_db_zipcode" VALUES(14528,33044,-5,'Sugarloaf Shores, Florida 33044',10297,12736);
INSERT INTO "django_geo_db_zipcode" VALUES(14529,33045,-5,'Key West, Florida 33045',10294,12733);
INSERT INTO "django_geo_db_zipcode" VALUES(14530,33047,-5,'West Little River, Florida 33047',10298,12737);
INSERT INTO "django_geo_db_zipcode" VALUES(14531,33050,-5,'Marathon, Florida 33050',10299,12738);
INSERT INTO "django_geo_db_zipcode" VALUES(14532,33051,-5,'Key Colony Beach, Florida 33051',10300,12739);
INSERT INTO "django_geo_db_zipcode" VALUES(14533,33052,-5,'Marathon Shores, Florida 33052',10301,12740);
INSERT INTO "django_geo_db_zipcode" VALUES(14534,33054,-5,'Opa Locka, Florida 33054',10302,12741);
INSERT INTO "django_geo_db_zipcode" VALUES(14535,33055,-5,'Opa Locka, Florida 33055',10302,12742);
INSERT INTO "django_geo_db_zipcode" VALUES(14536,33056,-5,'Opa Locka, Florida 33056',10302,12743);
INSERT INTO "django_geo_db_zipcode" VALUES(14537,33058,-5,'Lake Lucerne, Florida 33058',10303,12744);
INSERT INTO "django_geo_db_zipcode" VALUES(14538,33060,-5,'Pompano Beach, Florida 33060',10304,12745);
INSERT INTO "django_geo_db_zipcode" VALUES(14539,33061,-5,'Pompano Beach, Florida 33061',10304,12746);
INSERT INTO "django_geo_db_zipcode" VALUES(14540,33062,-5,'Pompano Beach, Florida 33062',10304,12747);
INSERT INTO "django_geo_db_zipcode" VALUES(14541,33063,-5,'Pompano Beach, Florida 33063',10304,12748);
INSERT INTO "django_geo_db_zipcode" VALUES(14542,33064,-5,'Pompano Beach, Florida 33064',10304,12749);
INSERT INTO "django_geo_db_zipcode" VALUES(14543,33065,-5,'Pompano Beach, Florida 33065',10304,12750);
INSERT INTO "django_geo_db_zipcode" VALUES(14544,33066,-5,'Pompano Beach, Florida 33066',10304,12751);
INSERT INTO "django_geo_db_zipcode" VALUES(14545,33067,-5,'Pompano Beach, Florida 33067',10304,12752);
INSERT INTO "django_geo_db_zipcode" VALUES(14546,33068,-5,'Pompano Beach, Florida 33068',10304,12753);
INSERT INTO "django_geo_db_zipcode" VALUES(14547,33069,-5,'Pompano Beach, Florida 33069',10304,12754);
INSERT INTO "django_geo_db_zipcode" VALUES(14548,33070,-5,'Tavernier, Florida 33070',10305,12755);
INSERT INTO "django_geo_db_zipcode" VALUES(14549,33071,-5,'Pompano Beach, Florida 33071',10304,12756);
INSERT INTO "django_geo_db_zipcode" VALUES(14550,33072,-5,'Pompano Beach, Florida 33072',10304,12757);
INSERT INTO "django_geo_db_zipcode" VALUES(14551,33073,-5,'Pompano Beach, Florida 33073',10304,12758);
INSERT INTO "django_geo_db_zipcode" VALUES(14552,33074,-5,'Pompano Beach, Florida 33074',10304,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14553,33075,-5,'Pompano Beach, Florida 33075',10304,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14554,33076,-5,'Pompano Beach, Florida 33076',10304,12759);
INSERT INTO "django_geo_db_zipcode" VALUES(14555,33077,-5,'Pompano Beach, Florida 33077',10304,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14556,33081,-5,'Hollywood, Florida 33081',10289,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14557,33082,-5,'Pembroke Pines, Florida 33082',10290,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14558,33083,-5,'Hollywood, Florida 33083',10289,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14559,33084,-5,'Pembroke Pines, Florida 33084',10290,12760);
INSERT INTO "django_geo_db_zipcode" VALUES(14560,33090,-5,'Homestead, Florida 33090',10291,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14561,33092,-5,'Homestead, Florida 33092',10291,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14562,33093,-5,'Pompano Beach, Florida 33093',10304,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14563,33097,-5,'Pompano Beach, Florida 33097',10304,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14564,33101,-5,'Miami, Florida 33101',10306,12761);
INSERT INTO "django_geo_db_zipcode" VALUES(14565,33102,-5,'Miami, Florida 33102',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14566,33107,-5,'Miami, Florida 33107',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14567,33109,-5,'Miami Beach, Florida 33109',10307,12762);
INSERT INTO "django_geo_db_zipcode" VALUES(14568,33110,-5,'Miami, Florida 33110',10306,12763);
INSERT INTO "django_geo_db_zipcode" VALUES(14569,33111,-5,'Miami, Florida 33111',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14570,33114,-5,'Miami, Florida 33114',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14571,33116,-5,'Miami, Florida 33116',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14572,33119,-5,'Miami Beach, Florida 33119',10307,12764);
INSERT INTO "django_geo_db_zipcode" VALUES(14573,33121,-5,'Miami, Florida 33121',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14574,33122,-5,'Miami, Florida 33122',10306,12765);
INSERT INTO "django_geo_db_zipcode" VALUES(14575,33124,-5,'Miami, Florida 33124',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14576,33125,-5,'Miami, Florida 33125',10306,12766);
INSERT INTO "django_geo_db_zipcode" VALUES(14577,33126,-5,'Miami, Florida 33126',10306,12767);
INSERT INTO "django_geo_db_zipcode" VALUES(14578,33127,-5,'Miami, Florida 33127',10306,12768);
INSERT INTO "django_geo_db_zipcode" VALUES(14579,33128,-5,'Miami, Florida 33128',10306,12769);
INSERT INTO "django_geo_db_zipcode" VALUES(14580,33129,-5,'Miami, Florida 33129',10306,12770);
INSERT INTO "django_geo_db_zipcode" VALUES(14581,33130,-5,'Miami, Florida 33130',10306,12771);
INSERT INTO "django_geo_db_zipcode" VALUES(14582,33131,-5,'Miami, Florida 33131',10306,12772);
INSERT INTO "django_geo_db_zipcode" VALUES(14583,33132,-5,'Miami, Florida 33132',10306,12773);
INSERT INTO "django_geo_db_zipcode" VALUES(14584,33133,-5,'Miami, Florida 33133',10306,12774);
INSERT INTO "django_geo_db_zipcode" VALUES(14585,33134,-5,'Miami, Florida 33134',10306,12775);
INSERT INTO "django_geo_db_zipcode" VALUES(14586,33135,-5,'Miami, Florida 33135',10306,12776);
INSERT INTO "django_geo_db_zipcode" VALUES(14587,33136,-5,'Miami, Florida 33136',10306,12777);
INSERT INTO "django_geo_db_zipcode" VALUES(14588,33137,-5,'Miami, Florida 33137',10306,12778);
INSERT INTO "django_geo_db_zipcode" VALUES(14589,33138,-5,'Miami, Florida 33138',10306,12779);
INSERT INTO "django_geo_db_zipcode" VALUES(14590,33139,-5,'Miami Beach, Florida 33139',10307,12780);
INSERT INTO "django_geo_db_zipcode" VALUES(14591,33140,-5,'Miami Beach, Florida 33140',10307,12781);
INSERT INTO "django_geo_db_zipcode" VALUES(14592,33141,-5,'Miami Beach, Florida 33141',10307,12782);
INSERT INTO "django_geo_db_zipcode" VALUES(14593,33142,-5,'Miami, Florida 33142',10306,12783);
INSERT INTO "django_geo_db_zipcode" VALUES(14594,33143,-5,'Miami, Florida 33143',10306,12784);
INSERT INTO "django_geo_db_zipcode" VALUES(14595,33144,-5,'Miami, Florida 33144',10306,12785);
INSERT INTO "django_geo_db_zipcode" VALUES(14596,33145,-5,'Miami, Florida 33145',10306,12786);
INSERT INTO "django_geo_db_zipcode" VALUES(14597,33146,-5,'Miami, Florida 33146',10306,12787);
INSERT INTO "django_geo_db_zipcode" VALUES(14598,33147,-5,'Miami, Florida 33147',10306,12788);
INSERT INTO "django_geo_db_zipcode" VALUES(14599,33148,-5,'Miami, Florida 33148',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14600,33149,-5,'Key Biscayne, Florida 33149',10308,12789);
INSERT INTO "django_geo_db_zipcode" VALUES(14601,33150,-5,'Miami, Florida 33150',10306,12790);
INSERT INTO "django_geo_db_zipcode" VALUES(14602,33151,-5,'Miami, Florida 33151',10306,12791);
INSERT INTO "django_geo_db_zipcode" VALUES(14603,33152,-5,'Miami, Florida 33152',10306,12792);
INSERT INTO "django_geo_db_zipcode" VALUES(14604,33153,-5,'Miami, Florida 33153',10306,12793);
INSERT INTO "django_geo_db_zipcode" VALUES(14605,33154,-5,'Miami, Florida 33154',10306,12794);
INSERT INTO "django_geo_db_zipcode" VALUES(14606,33155,-5,'Miami, Florida 33155',10306,12795);
INSERT INTO "django_geo_db_zipcode" VALUES(14607,33156,-5,'Miami, Florida 33156',10306,12796);
INSERT INTO "django_geo_db_zipcode" VALUES(14608,33157,-5,'Miami, Florida 33157',10306,12797);
INSERT INTO "django_geo_db_zipcode" VALUES(14609,33158,-5,'Miami, Florida 33158',10306,12798);
INSERT INTO "django_geo_db_zipcode" VALUES(14610,33159,-5,'Miami, Florida 33159',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14611,33160,-5,'North Miami Beach, Florida 33160',10309,12799);
INSERT INTO "django_geo_db_zipcode" VALUES(14612,33161,-5,'Miami, Florida 33161',10306,12800);
INSERT INTO "django_geo_db_zipcode" VALUES(14613,33162,-5,'Miami, Florida 33162',10306,12801);
INSERT INTO "django_geo_db_zipcode" VALUES(14614,33163,-5,'Miami, Florida 33163',10306,12802);
INSERT INTO "django_geo_db_zipcode" VALUES(14615,33164,-5,'Miami, Florida 33164',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14616,33165,-5,'Miami, Florida 33165',10306,12803);
INSERT INTO "django_geo_db_zipcode" VALUES(14617,33166,-5,'Miami, Florida 33166',10306,12804);
INSERT INTO "django_geo_db_zipcode" VALUES(14618,33167,-5,'Miami, Florida 33167',10306,12805);
INSERT INTO "django_geo_db_zipcode" VALUES(14619,33168,-5,'Miami, Florida 33168',10306,12806);
INSERT INTO "django_geo_db_zipcode" VALUES(14620,33169,-5,'Miami, Florida 33169',10306,12807);
INSERT INTO "django_geo_db_zipcode" VALUES(14621,33170,-5,'Miami, Florida 33170',10306,12808);
INSERT INTO "django_geo_db_zipcode" VALUES(14622,33172,-5,'Miami, Florida 33172',10306,12809);
INSERT INTO "django_geo_db_zipcode" VALUES(14623,33173,-5,'Miami, Florida 33173',10306,12810);
INSERT INTO "django_geo_db_zipcode" VALUES(14624,33174,-5,'Miami, Florida 33174',10306,12811);
INSERT INTO "django_geo_db_zipcode" VALUES(14625,33175,-5,'Miami, Florida 33175',10306,12812);
INSERT INTO "django_geo_db_zipcode" VALUES(14626,33176,-5,'Miami, Florida 33176',10306,12813);
INSERT INTO "django_geo_db_zipcode" VALUES(14627,33177,-5,'Miami, Florida 33177',10306,12814);
INSERT INTO "django_geo_db_zipcode" VALUES(14628,33178,-5,'Miami, Florida 33178',10306,12815);
INSERT INTO "django_geo_db_zipcode" VALUES(14629,33179,-5,'Miami, Florida 33179',10306,12816);
INSERT INTO "django_geo_db_zipcode" VALUES(14630,33180,-5,'Miami, Florida 33180',10306,12817);
INSERT INTO "django_geo_db_zipcode" VALUES(14631,33181,-5,'Miami, Florida 33181',10306,12818);
INSERT INTO "django_geo_db_zipcode" VALUES(14632,33182,-5,'Miami, Florida 33182',10306,12819);
INSERT INTO "django_geo_db_zipcode" VALUES(14633,33183,-5,'Miami, Florida 33183',10306,12820);
INSERT INTO "django_geo_db_zipcode" VALUES(14634,33184,-5,'Miami, Florida 33184',10306,12821);
INSERT INTO "django_geo_db_zipcode" VALUES(14635,33185,-5,'Miami, Florida 33185',10306,12822);
INSERT INTO "django_geo_db_zipcode" VALUES(14636,33186,-5,'Miami, Florida 33186',10306,12823);
INSERT INTO "django_geo_db_zipcode" VALUES(14637,33187,-5,'Miami, Florida 33187',10306,12824);
INSERT INTO "django_geo_db_zipcode" VALUES(14638,33188,-5,'Miami, Florida 33188',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14639,33189,-5,'Miami, Florida 33189',10306,12825);
INSERT INTO "django_geo_db_zipcode" VALUES(14640,33190,-5,'Miami, Florida 33190',10306,12826);
INSERT INTO "django_geo_db_zipcode" VALUES(14641,33192,-5,'Miami, Florida 33192',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14642,33193,-5,'Miami, Florida 33193',10306,12827);
INSERT INTO "django_geo_db_zipcode" VALUES(14643,33194,-5,'Miami, Florida 33194',10306,12828);
INSERT INTO "django_geo_db_zipcode" VALUES(14644,33195,-5,'Miami, Florida 33195',10306,12829);
INSERT INTO "django_geo_db_zipcode" VALUES(14645,33196,-5,'Miami, Florida 33196',10306,12830);
INSERT INTO "django_geo_db_zipcode" VALUES(14646,33197,-5,'Miami, Florida 33197',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14647,33199,-5,'Miami, Florida 33199',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14648,33201,-5,'Hollywood, Florida 33201',10289,12831);
INSERT INTO "django_geo_db_zipcode" VALUES(14649,33231,-5,'Miami, Florida 33231',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14650,33233,-5,'Miami, Florida 33233',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14651,33234,-5,'Miami, Florida 33234',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14652,33238,-5,'Miami, Florida 33238',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14653,33239,-5,'Miami Beach, Florida 33239',10307,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14654,33242,-5,'Miami, Florida 33242',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14655,33243,-5,'Miami, Florida 33243',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14656,33245,-5,'Miami, Florida 33245',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14657,33247,-5,'Miami, Florida 33247',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14658,33255,-5,'Miami, Florida 33255',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14659,33256,-5,'Miami, Florida 33256',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14660,33257,-5,'Miami, Florida 33257',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14661,33261,-5,'Miami, Florida 33261',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14662,33265,-5,'Miami, Florida 33265',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14663,33266,-5,'Miami, Florida 33266',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14664,33269,-5,'Miami, Florida 33269',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14665,33280,-5,'Miami, Florida 33280',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14666,33283,-5,'Miami, Florida 33283',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14667,33296,-5,'Miami, Florida 33296',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14668,33299,-5,'Miami, Florida 33299',10306,12701);
INSERT INTO "django_geo_db_zipcode" VALUES(14669,33301,-5,'Fort Lauderdale, Florida 33301',10310,12832);
INSERT INTO "django_geo_db_zipcode" VALUES(14670,33302,-5,'Fort Lauderdale, Florida 33302',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14671,33303,-5,'Fort Lauderdale, Florida 33303',10310,12833);
INSERT INTO "django_geo_db_zipcode" VALUES(14672,33304,-5,'Fort Lauderdale, Florida 33304',10310,12834);
INSERT INTO "django_geo_db_zipcode" VALUES(14673,33305,-5,'Fort Lauderdale, Florida 33305',10310,12835);
INSERT INTO "django_geo_db_zipcode" VALUES(14674,33306,-5,'Fort Lauderdale, Florida 33306',10310,12836);
INSERT INTO "django_geo_db_zipcode" VALUES(14675,33307,-5,'Fort Lauderdale, Florida 33307',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14676,33308,-5,'Fort Lauderdale, Florida 33308',10310,12837);
INSERT INTO "django_geo_db_zipcode" VALUES(14677,33309,-5,'Fort Lauderdale, Florida 33309',10310,12838);
INSERT INTO "django_geo_db_zipcode" VALUES(14678,33310,-5,'Fort Lauderdale, Florida 33310',10310,12839);
INSERT INTO "django_geo_db_zipcode" VALUES(14679,33311,-5,'Fort Lauderdale, Florida 33311',10310,12840);
INSERT INTO "django_geo_db_zipcode" VALUES(14680,33312,-5,'Fort Lauderdale, Florida 33312',10310,12841);
INSERT INTO "django_geo_db_zipcode" VALUES(14681,33313,-5,'Fort Lauderdale, Florida 33313',10310,12842);
INSERT INTO "django_geo_db_zipcode" VALUES(14682,33314,-5,'Fort Lauderdale, Florida 33314',10310,12843);
INSERT INTO "django_geo_db_zipcode" VALUES(14683,33315,-5,'Fort Lauderdale, Florida 33315',10310,12844);
INSERT INTO "django_geo_db_zipcode" VALUES(14684,33316,-5,'Fort Lauderdale, Florida 33316',10310,12845);
INSERT INTO "django_geo_db_zipcode" VALUES(14685,33317,-5,'Fort Lauderdale, Florida 33317',10310,12846);
INSERT INTO "django_geo_db_zipcode" VALUES(14686,33318,-5,'Fort Lauderdale, Florida 33318',10310,12847);
INSERT INTO "django_geo_db_zipcode" VALUES(14687,33319,-5,'Fort Lauderdale, Florida 33319',10310,12848);
INSERT INTO "django_geo_db_zipcode" VALUES(14688,33320,-5,'Fort Lauderdale, Florida 33320',10310,12849);
INSERT INTO "django_geo_db_zipcode" VALUES(14689,33321,-5,'Fort Lauderdale, Florida 33321',10310,12850);
INSERT INTO "django_geo_db_zipcode" VALUES(14690,33322,-5,'Fort Lauderdale, Florida 33322',10310,12851);
INSERT INTO "django_geo_db_zipcode" VALUES(14691,33323,-5,'Fort Lauderdale, Florida 33323',10310,12852);
INSERT INTO "django_geo_db_zipcode" VALUES(14692,33324,-5,'Fort Lauderdale, Florida 33324',10310,12853);
INSERT INTO "django_geo_db_zipcode" VALUES(14693,33325,-5,'Fort Lauderdale, Florida 33325',10310,12854);
INSERT INTO "django_geo_db_zipcode" VALUES(14694,33326,-5,'Weston, Florida 33326',10311,12855);
INSERT INTO "django_geo_db_zipcode" VALUES(14695,33327,-5,'Weston, Florida 33327',10311,12856);
INSERT INTO "django_geo_db_zipcode" VALUES(14696,33328,-5,'Fort Lauderdale, Florida 33328',10310,12857);
INSERT INTO "django_geo_db_zipcode" VALUES(14697,33329,-5,'Fort Lauderdale, Florida 33329',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14698,33330,-5,'Fort Lauderdale, Florida 33330',10310,12858);
INSERT INTO "django_geo_db_zipcode" VALUES(14699,33331,-5,'Fort Lauderdale, Florida 33331',10310,12859);
INSERT INTO "django_geo_db_zipcode" VALUES(14700,33332,-5,'Fort Lauderdale, Florida 33332',10310,12860);
INSERT INTO "django_geo_db_zipcode" VALUES(14701,33334,-5,'Fort Lauderdale, Florida 33334',10310,12861);
INSERT INTO "django_geo_db_zipcode" VALUES(14702,33335,-5,'Fort Lauderdale, Florida 33335',10310,12862);
INSERT INTO "django_geo_db_zipcode" VALUES(14703,33337,-5,'Fort Lauderdale, Florida 33337',10310,12863);
INSERT INTO "django_geo_db_zipcode" VALUES(14704,33338,-5,'Fort Lauderdale, Florida 33338',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14705,33339,-5,'Fort Lauderdale, Florida 33339',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14706,33340,-5,'Fort Lauderdale, Florida 33340',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14707,33345,-5,'Fort Lauderdale, Florida 33345',10310,12864);
INSERT INTO "django_geo_db_zipcode" VALUES(14708,33346,-5,'Fort Lauderdale, Florida 33346',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14709,33348,-5,'Fort Lauderdale, Florida 33348',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14710,33349,-5,'Fort Lauderdale, Florida 33349',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14711,33351,-5,'Fort Lauderdale, Florida 33351',10310,12865);
INSERT INTO "django_geo_db_zipcode" VALUES(14712,33352,-5,'Pine Island Ridge, Florida 33352',10312,12866);
INSERT INTO "django_geo_db_zipcode" VALUES(14713,33355,-5,'Fort Lauderdale, Florida 33355',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14714,33359,-5,'Fort Lauderdale, Florida 33359',10310,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14715,33380,-5,'Winter Haven, Florida 33380',10313,12867);
INSERT INTO "django_geo_db_zipcode" VALUES(14716,33388,-5,'Fort Lauderdale, Florida 33388',10310,12868);
INSERT INTO "django_geo_db_zipcode" VALUES(14717,33394,-5,'Fort Lauderdale, Florida 33394',10310,12869);
INSERT INTO "django_geo_db_zipcode" VALUES(14718,33401,-5,'West Palm Beach, Florida 33401',10314,12870);
INSERT INTO "django_geo_db_zipcode" VALUES(14719,33402,-5,'West Palm Beach, Florida 33402',10314,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14720,33403,-5,'West Palm Beach, Florida 33403',10314,12872);
INSERT INTO "django_geo_db_zipcode" VALUES(14721,33404,-5,'West Palm Beach, Florida 33404',10314,12873);
INSERT INTO "django_geo_db_zipcode" VALUES(14722,33405,-5,'West Palm Beach, Florida 33405',10314,12874);
INSERT INTO "django_geo_db_zipcode" VALUES(14723,33406,-5,'West Palm Beach, Florida 33406',10314,12875);
INSERT INTO "django_geo_db_zipcode" VALUES(14724,33407,-5,'West Palm Beach, Florida 33407',10314,12876);
INSERT INTO "django_geo_db_zipcode" VALUES(14725,33408,-5,'North Palm Beach, Florida 33408',10315,12877);
INSERT INTO "django_geo_db_zipcode" VALUES(14726,33409,-5,'West Palm Beach, Florida 33409',10314,12878);
INSERT INTO "django_geo_db_zipcode" VALUES(14727,33410,-5,'West Palm Beach, Florida 33410',10314,12879);
INSERT INTO "django_geo_db_zipcode" VALUES(14728,33411,-5,'West Palm Beach, Florida 33411',10314,12880);
INSERT INTO "django_geo_db_zipcode" VALUES(14729,33412,-5,'West Palm Beach, Florida 33412',10314,12881);
INSERT INTO "django_geo_db_zipcode" VALUES(14730,33413,-5,'West Palm Beach, Florida 33413',10314,12882);
INSERT INTO "django_geo_db_zipcode" VALUES(14731,33414,-5,'West Palm Beach, Florida 33414',10314,12883);
INSERT INTO "django_geo_db_zipcode" VALUES(14732,33415,-5,'West Palm Beach, Florida 33415',10314,12884);
INSERT INTO "django_geo_db_zipcode" VALUES(14733,33416,-5,'West Palm Beach, Florida 33416',10314,12885);
INSERT INTO "django_geo_db_zipcode" VALUES(14734,33417,-5,'West Palm Beach, Florida 33417',10314,12886);
INSERT INTO "django_geo_db_zipcode" VALUES(14735,33418,-5,'West Palm Beach, Florida 33418',10314,12887);
INSERT INTO "django_geo_db_zipcode" VALUES(14736,33419,-5,'West Palm Beach, Florida 33419',10314,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14737,33420,-5,'West Palm Beach, Florida 33420',10314,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14738,33421,-5,'West Palm Beach, Florida 33421',10314,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14739,33422,-5,'West Palm Beach, Florida 33422',10314,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14740,33424,-5,'Boynton Beach, Florida 33424',10316,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14741,33425,-5,'Boynton Beach, Florida 33425',10316,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14742,33426,-5,'Boynton Beach, Florida 33426',10316,12888);
INSERT INTO "django_geo_db_zipcode" VALUES(14743,33427,-5,'Boca Raton, Florida 33427',10317,12889);
INSERT INTO "django_geo_db_zipcode" VALUES(14744,33428,-5,'Boca Raton, Florida 33428',10317,12890);
INSERT INTO "django_geo_db_zipcode" VALUES(14745,33429,-5,'Boca Raton, Florida 33429',10317,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14746,33430,-5,'Belle Glade, Florida 33430',10318,12891);
INSERT INTO "django_geo_db_zipcode" VALUES(14747,33431,-5,'Boca Raton, Florida 33431',10317,12892);
INSERT INTO "django_geo_db_zipcode" VALUES(14748,33432,-5,'Boca Raton, Florida 33432',10317,12893);
INSERT INTO "django_geo_db_zipcode" VALUES(14749,33433,-5,'Boca Raton, Florida 33433',10317,12894);
INSERT INTO "django_geo_db_zipcode" VALUES(14750,33434,-5,'Boca Raton, Florida 33434',10317,12895);
INSERT INTO "django_geo_db_zipcode" VALUES(14751,33435,-5,'Boynton Beach, Florida 33435',10316,12896);
INSERT INTO "django_geo_db_zipcode" VALUES(14752,33436,-5,'Boynton Beach, Florida 33436',10316,12897);
INSERT INTO "django_geo_db_zipcode" VALUES(14753,33437,-5,'Boynton Beach, Florida 33437',10316,12898);
INSERT INTO "django_geo_db_zipcode" VALUES(14754,33438,-5,'Canal Point, Florida 33438',10319,12899);
INSERT INTO "django_geo_db_zipcode" VALUES(14755,33439,-5,'Bryant, Florida 33439',10320,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14756,33440,-5,'Clewiston, Florida 33440',10321,12900);
INSERT INTO "django_geo_db_zipcode" VALUES(14757,33441,-5,'Deerfield Beach, Florida 33441',10322,12901);
INSERT INTO "django_geo_db_zipcode" VALUES(14758,33442,-5,'Deerfield Beach, Florida 33442',10322,12902);
INSERT INTO "django_geo_db_zipcode" VALUES(14759,33443,-5,'Deerfield Beach, Florida 33443',10322,12704);
INSERT INTO "django_geo_db_zipcode" VALUES(14760,33444,-5,'Delray Beach, Florida 33444',10323,12903);
INSERT INTO "django_geo_db_zipcode" VALUES(14761,33445,-5,'Delray Beach, Florida 33445',10323,12904);
INSERT INTO "django_geo_db_zipcode" VALUES(14762,33446,-5,'Delray Beach, Florida 33446',10323,12905);
INSERT INTO "django_geo_db_zipcode" VALUES(14763,33447,-5,'Delray Beach, Florida 33447',10323,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14764,33448,-5,'Delray Beach, Florida 33448',10323,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14765,33452,-5,'Lantana, Florida 33452',10324,12906);
INSERT INTO "django_geo_db_zipcode" VALUES(14766,33454,-5,'Lake Worth, Florida 33454',10325,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14767,33455,-5,'Hobe Sound, Florida 33455',10326,12907);
INSERT INTO "django_geo_db_zipcode" VALUES(14768,33458,-5,'Jupiter, Florida 33458',10327,12908);
INSERT INTO "django_geo_db_zipcode" VALUES(14769,33459,-5,'Lake Harbor, Florida 33459',10328,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14770,33460,-5,'Lake Worth, Florida 33460',10325,12909);
INSERT INTO "django_geo_db_zipcode" VALUES(14771,33461,-5,'Lake Worth, Florida 33461',10325,12910);
INSERT INTO "django_geo_db_zipcode" VALUES(14772,33462,-5,'Lake Worth, Florida 33462',10325,12911);
INSERT INTO "django_geo_db_zipcode" VALUES(14773,33463,-5,'Lake Worth, Florida 33463',10325,12912);
INSERT INTO "django_geo_db_zipcode" VALUES(14774,33464,-5,'Lake Worth, Florida 33464',10325,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14775,33465,-5,'Lake Worth, Florida 33465',10325,12913);
INSERT INTO "django_geo_db_zipcode" VALUES(14776,33466,-5,'Lake Worth, Florida 33466',10325,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14777,33467,-5,'Lake Worth, Florida 33467',10325,12914);
INSERT INTO "django_geo_db_zipcode" VALUES(14778,33468,-5,'Jupiter, Florida 33468',10327,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14779,33469,-5,'Jupiter, Florida 33469',10327,12915);
INSERT INTO "django_geo_db_zipcode" VALUES(14780,33470,-5,'Loxahatchee, Florida 33470',10329,12916);
INSERT INTO "django_geo_db_zipcode" VALUES(14781,33471,-5,'Moore Haven, Florida 33471',10330,12917);
INSERT INTO "django_geo_db_zipcode" VALUES(14782,33474,-5,'Boynton Beach, Florida 33474',10316,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14783,33475,-5,'Hobe Sound, Florida 33475',10326,12918);
INSERT INTO "django_geo_db_zipcode" VALUES(14784,33476,-5,'Pahokee, Florida 33476',10331,12919);
INSERT INTO "django_geo_db_zipcode" VALUES(14785,33477,-5,'Jupiter, Florida 33477',10327,12920);
INSERT INTO "django_geo_db_zipcode" VALUES(14786,33478,-5,'Jupiter, Florida 33478',10327,12921);
INSERT INTO "django_geo_db_zipcode" VALUES(14787,33480,-5,'Palm Beach, Florida 33480',10332,12922);
INSERT INTO "django_geo_db_zipcode" VALUES(14788,33481,-5,'Boca Raton, Florida 33481',10317,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14789,33482,-5,'Delray Beach, Florida 33482',10323,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14790,33483,-5,'Delray Beach, Florida 33483',10323,12923);
INSERT INTO "django_geo_db_zipcode" VALUES(14791,33484,-5,'Delray Beach, Florida 33484',10323,12924);
INSERT INTO "django_geo_db_zipcode" VALUES(14792,33486,-5,'Boca Raton, Florida 33486',10317,12925);
INSERT INTO "django_geo_db_zipcode" VALUES(14793,33487,-5,'Boca Raton, Florida 33487',10317,12926);
INSERT INTO "django_geo_db_zipcode" VALUES(14794,33488,-5,'Boca Raton, Florida 33488',10317,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14795,33493,-5,'South Bay, Florida 33493',10333,12927);
INSERT INTO "django_geo_db_zipcode" VALUES(14796,33496,-5,'Boca Raton, Florida 33496',10317,12928);
INSERT INTO "django_geo_db_zipcode" VALUES(14797,33497,-5,'Boca Raton, Florida 33497',10317,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14798,33498,-5,'Boca Raton, Florida 33498',10317,12929);
INSERT INTO "django_geo_db_zipcode" VALUES(14799,33499,-5,'Boca Raton, Florida 33499',10317,12871);
INSERT INTO "django_geo_db_zipcode" VALUES(14800,33501,-5,'Brandon, Florida 33501',10334,12930);
INSERT INTO "django_geo_db_zipcode" VALUES(14801,33503,-5,'Balm, Florida 33503',10335,12931);
INSERT INTO "django_geo_db_zipcode" VALUES(14802,33509,-5,'Brandon, Florida 33509',10334,12932);
INSERT INTO "django_geo_db_zipcode" VALUES(14803,33510,-5,'Brandon, Florida 33510',10334,12933);
INSERT INTO "django_geo_db_zipcode" VALUES(14804,33511,-5,'Brandon, Florida 33511',10334,12934);
INSERT INTO "django_geo_db_zipcode" VALUES(14805,33513,-5,'Bushnell, Florida 33513',10336,12935);
INSERT INTO "django_geo_db_zipcode" VALUES(14806,33514,-5,'Center Hill, Florida 33514',10337,12936);
INSERT INTO "django_geo_db_zipcode" VALUES(14807,33515,-5,'Fort Lauderdale, Florida 33515',10310,12937);
INSERT INTO "django_geo_db_zipcode" VALUES(14808,33521,-5,'Coleman, Florida 33521',10338,12938);
INSERT INTO "django_geo_db_zipcode" VALUES(14809,33523,-5,'Dade City, Florida 33523',10339,12939);
INSERT INTO "django_geo_db_zipcode" VALUES(14810,33524,-5,'Crystal Springs, Florida 33524',10340,12940);
INSERT INTO "django_geo_db_zipcode" VALUES(14811,33525,-5,'Dade City, Florida 33525',10339,12941);
INSERT INTO "django_geo_db_zipcode" VALUES(14812,33526,-5,'Dade City, Florida 33526',10339,12942);
INSERT INTO "django_geo_db_zipcode" VALUES(14813,33527,-5,'Dover, Florida 33527',10341,12943);
INSERT INTO "django_geo_db_zipcode" VALUES(14814,33528,-5,'Lake Panasoffkee, Florida 33528',10342,12944);
INSERT INTO "django_geo_db_zipcode" VALUES(14815,33530,-5,'Durant, Florida 33530',10343,12945);
INSERT INTO "django_geo_db_zipcode" VALUES(14816,33534,-5,'Gibsonton, Florida 33534',10344,12946);
INSERT INTO "django_geo_db_zipcode" VALUES(14817,33537,-5,'Lacoochee, Florida 33537',10345,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(14818,33538,-5,'Lake Panasoffkee, Florida 33538',10342,12948);
INSERT INTO "django_geo_db_zipcode" VALUES(14819,33539,-5,'Zephyrhills, Florida 33539',10346,12949);
INSERT INTO "django_geo_db_zipcode" VALUES(14820,33540,-5,'Zephyrhills, Florida 33540',10346,12950);
INSERT INTO "django_geo_db_zipcode" VALUES(14821,33541,-5,'Zephyrhills, Florida 33541',10346,12951);
INSERT INTO "django_geo_db_zipcode" VALUES(14822,33542,-5,'Zephyrhills, Florida 33542',10346,12952);
INSERT INTO "django_geo_db_zipcode" VALUES(14823,33543,-5,'Zephyrhills, Florida 33543',10346,12953);
INSERT INTO "django_geo_db_zipcode" VALUES(14824,33544,-5,'Zephyrhills, Florida 33544',10346,12954);
INSERT INTO "django_geo_db_zipcode" VALUES(14825,33547,-5,'Lithia, Florida 33547',10347,12955);
INSERT INTO "django_geo_db_zipcode" VALUES(14826,33548,-5,'Lutz, Florida 33548',10348,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14827,33549,-5,'Lutz, Florida 33549',10348,12957);
INSERT INTO "django_geo_db_zipcode" VALUES(14828,33550,-5,'Mango, Florida 33550',10349,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14829,33556,-5,'Odessa, Florida 33556',10350,12958);
INSERT INTO "django_geo_db_zipcode" VALUES(14830,33558,-5,'Land O'' Lakes, Florida 33558',10351,12959);
INSERT INTO "django_geo_db_zipcode" VALUES(14831,33559,-5,'Land O'' Lakes, Florida 33559',10351,12960);
INSERT INTO "django_geo_db_zipcode" VALUES(14832,33563,-5,'Plant City, Florida 33563',10352,12961);
INSERT INTO "django_geo_db_zipcode" VALUES(14833,33564,-5,'Plant City, Florida 33564',10352,12962);
INSERT INTO "django_geo_db_zipcode" VALUES(14834,33565,-5,'Plant City, Florida 33565',10352,12963);
INSERT INTO "django_geo_db_zipcode" VALUES(14835,33566,-5,'Plant City, Florida 33566',10352,12964);
INSERT INTO "django_geo_db_zipcode" VALUES(14836,33567,-5,'Plant City, Florida 33567',10352,12965);
INSERT INTO "django_geo_db_zipcode" VALUES(14837,33568,-5,'Riverview, Florida 33568',10353,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14838,33569,-5,'Riverview, Florida 33569',10353,12966);
INSERT INTO "django_geo_db_zipcode" VALUES(14839,33570,-5,'Ruskin, Florida 33570',10354,12967);
INSERT INTO "django_geo_db_zipcode" VALUES(14840,33571,-5,'Sun City Center, Florida 33571',10355,12968);
INSERT INTO "django_geo_db_zipcode" VALUES(14841,33572,-5,'Apollo Beach, Florida 33572',10356,12969);
INSERT INTO "django_geo_db_zipcode" VALUES(14842,33573,-5,'Sun City Center, Florida 33573',10355,12970);
INSERT INTO "django_geo_db_zipcode" VALUES(14843,33574,-5,'Saint Leo, Florida 33574',10357,12971);
INSERT INTO "django_geo_db_zipcode" VALUES(14844,33576,-5,'San Antonio, Florida 33576',10358,12972);
INSERT INTO "django_geo_db_zipcode" VALUES(14845,33578,-5,'St. Leo, Florida 33578',10359,12973);
INSERT INTO "django_geo_db_zipcode" VALUES(14846,33583,-5,'Seffner, Florida 33583',10360,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14847,33584,-5,'Seffner, Florida 33584',10360,12974);
INSERT INTO "django_geo_db_zipcode" VALUES(14848,33585,-5,'Sumterville, Florida 33585',10361,12975);
INSERT INTO "django_geo_db_zipcode" VALUES(14849,33586,-5,'Sun City, Florida 33586',10362,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14850,33587,-5,'Sydney, Florida 33587',10363,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14851,33592,-5,'Thonotosassa, Florida 33592',10364,12976);
INSERT INTO "django_geo_db_zipcode" VALUES(14852,33593,-5,'Trilby, Florida 33593',10365,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(14853,33594,-5,'Valrico, Florida 33594',10366,12977);
INSERT INTO "django_geo_db_zipcode" VALUES(14854,33595,-5,'Valrico, Florida 33595',10366,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14855,33597,-5,'Webster, Florida 33597',10367,12978);
INSERT INTO "django_geo_db_zipcode" VALUES(14856,33598,-5,'Wimauma, Florida 33598',10368,12979);
INSERT INTO "django_geo_db_zipcode" VALUES(14857,33599,-5,'Punta Gorda, Florida 33599',10369,12980);
INSERT INTO "django_geo_db_zipcode" VALUES(14858,33601,-5,'Tampa, Florida 33601',10370,12981);
INSERT INTO "django_geo_db_zipcode" VALUES(14859,33602,-5,'Tampa, Florida 33602',10370,12982);
INSERT INTO "django_geo_db_zipcode" VALUES(14860,33603,-5,'Tampa, Florida 33603',10370,12983);
INSERT INTO "django_geo_db_zipcode" VALUES(14861,33604,-5,'Tampa, Florida 33604',10370,12984);
INSERT INTO "django_geo_db_zipcode" VALUES(14862,33605,-5,'Tampa, Florida 33605',10370,12985);
INSERT INTO "django_geo_db_zipcode" VALUES(14863,33606,-5,'Tampa, Florida 33606',10370,12986);
INSERT INTO "django_geo_db_zipcode" VALUES(14864,33607,-5,'Tampa, Florida 33607',10370,12987);
INSERT INTO "django_geo_db_zipcode" VALUES(14865,33608,-5,'Tampa, Florida 33608',10370,12988);
INSERT INTO "django_geo_db_zipcode" VALUES(14866,33609,-5,'Tampa, Florida 33609',10370,12989);
INSERT INTO "django_geo_db_zipcode" VALUES(14867,33610,-5,'Tampa, Florida 33610',10370,12990);
INSERT INTO "django_geo_db_zipcode" VALUES(14868,33611,-5,'Tampa, Florida 33611',10370,12991);
INSERT INTO "django_geo_db_zipcode" VALUES(14869,33612,-5,'Tampa, Florida 33612',10370,12992);
INSERT INTO "django_geo_db_zipcode" VALUES(14870,33613,-5,'Tampa, Florida 33613',10370,12993);
INSERT INTO "django_geo_db_zipcode" VALUES(14871,33614,-5,'Tampa, Florida 33614',10370,12994);
INSERT INTO "django_geo_db_zipcode" VALUES(14872,33615,-5,'Tampa, Florida 33615',10370,12995);
INSERT INTO "django_geo_db_zipcode" VALUES(14873,33616,-5,'Tampa, Florida 33616',10370,12996);
INSERT INTO "django_geo_db_zipcode" VALUES(14874,33617,-5,'Tampa, Florida 33617',10370,12997);
INSERT INTO "django_geo_db_zipcode" VALUES(14875,33618,-5,'Tampa, Florida 33618',10370,12998);
INSERT INTO "django_geo_db_zipcode" VALUES(14876,33619,-5,'Tampa, Florida 33619',10370,12999);
INSERT INTO "django_geo_db_zipcode" VALUES(14877,33620,-5,'Tampa, Florida 33620',10370,13000);
INSERT INTO "django_geo_db_zipcode" VALUES(14878,33621,-5,'Tampa, Florida 33621',10370,13001);
INSERT INTO "django_geo_db_zipcode" VALUES(14879,33622,-5,'Tampa, Florida 33622',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14880,33623,-5,'Tampa, Florida 33623',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14881,33624,-5,'Tampa, Florida 33624',10370,13002);
INSERT INTO "django_geo_db_zipcode" VALUES(14882,33625,-5,'Tampa, Florida 33625',10370,13003);
INSERT INTO "django_geo_db_zipcode" VALUES(14883,33626,-5,'Tampa, Florida 33626',10370,13004);
INSERT INTO "django_geo_db_zipcode" VALUES(14884,33629,-5,'Tampa, Florida 33629',10370,13005);
INSERT INTO "django_geo_db_zipcode" VALUES(14885,33630,-5,'Tampa, Florida 33630',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14886,33631,-5,'Tampa, Florida 33631',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14887,33633,-5,'Tampa, Florida 33633',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14888,33634,-5,'Tampa, Florida 33634',10370,13006);
INSERT INTO "django_geo_db_zipcode" VALUES(14889,33635,-5,'Tampa, Florida 33635',10370,13007);
INSERT INTO "django_geo_db_zipcode" VALUES(14890,33637,-5,'Tampa, Florida 33637',10370,13008);
INSERT INTO "django_geo_db_zipcode" VALUES(14891,33643,-5,'Tampa, Florida 33643',10370,13009);
INSERT INTO "django_geo_db_zipcode" VALUES(14892,33647,-5,'Tampa, Florida 33647',10370,13010);
INSERT INTO "django_geo_db_zipcode" VALUES(14893,33650,-5,'Tampa, Florida 33650',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14894,33651,-5,'Tampa, Florida 33651',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14895,33655,-5,'Tampa, Florida 33655',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14896,33659,-5,'Palm River-Clair Mel, Florida 33659',10371,13011);
INSERT INTO "django_geo_db_zipcode" VALUES(14897,33660,-5,'Tampa, Florida 33660',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14898,33661,-5,'Tampa, Florida 33661',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14899,33662,-5,'Tampa, Florida 33662',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14900,33663,-5,'Tampa, Florida 33663',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14901,33664,-5,'Tampa, Florida 33664',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14902,33672,-5,'Tampa, Florida 33672',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14903,33673,-5,'Tampa, Florida 33673',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14904,33674,-5,'Tampa, Florida 33674',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14905,33675,-5,'Tampa, Florida 33675',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14906,33677,-5,'Tampa, Florida 33677',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14907,33679,-5,'Tampa, Florida 33679',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14908,33680,-5,'Tampa, Florida 33680',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14909,33681,-5,'Tampa, Florida 33681',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14910,33682,-5,'Tampa, Florida 33682',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14911,33684,-5,'Tampa, Florida 33684',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14912,33685,-5,'Tampa, Florida 33685',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14913,33686,-5,'Tampa, Florida 33686',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14914,33687,-5,'Tampa, Florida 33687',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14915,33688,-5,'Tampa, Florida 33688',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14916,33689,-5,'Tampa, Florida 33689',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14917,33690,-5,'Tampa, Florida 33690',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14918,33694,-5,'Tampa, Florida 33694',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14919,33697,-5,'Tampa, Florida 33697',10370,12956);
INSERT INTO "django_geo_db_zipcode" VALUES(14920,33701,-5,'Saint Petersburg, Florida 33701',10372,13012);
INSERT INTO "django_geo_db_zipcode" VALUES(14921,33702,-5,'Saint Petersburg, Florida 33702',10372,13013);
INSERT INTO "django_geo_db_zipcode" VALUES(14922,33703,-5,'Saint Petersburg, Florida 33703',10372,13014);
INSERT INTO "django_geo_db_zipcode" VALUES(14923,33704,-5,'Saint Petersburg, Florida 33704',10372,13015);
INSERT INTO "django_geo_db_zipcode" VALUES(14924,33705,-5,'Saint Petersburg, Florida 33705',10372,13016);
INSERT INTO "django_geo_db_zipcode" VALUES(14925,33706,-5,'Saint Petersburg, Florida 33706',10372,13017);
INSERT INTO "django_geo_db_zipcode" VALUES(14926,33707,-5,'Saint Petersburg, Florida 33707',10372,13018);
INSERT INTO "django_geo_db_zipcode" VALUES(14927,33708,-5,'Saint Petersburg, Florida 33708',10372,13019);
INSERT INTO "django_geo_db_zipcode" VALUES(14928,33709,-5,'Saint Petersburg, Florida 33709',10372,13020);
INSERT INTO "django_geo_db_zipcode" VALUES(14929,33710,-5,'Saint Petersburg, Florida 33710',10372,13021);
INSERT INTO "django_geo_db_zipcode" VALUES(14930,33711,-5,'Saint Petersburg, Florida 33711',10372,13022);
INSERT INTO "django_geo_db_zipcode" VALUES(14931,33712,-5,'Saint Petersburg, Florida 33712',10372,13023);
INSERT INTO "django_geo_db_zipcode" VALUES(14932,33713,-5,'Saint Petersburg, Florida 33713',10372,13024);
INSERT INTO "django_geo_db_zipcode" VALUES(14933,33714,-5,'Saint Petersburg, Florida 33714',10372,13025);
INSERT INTO "django_geo_db_zipcode" VALUES(14934,33715,-5,'Saint Petersburg, Florida 33715',10372,13026);
INSERT INTO "django_geo_db_zipcode" VALUES(14935,33716,-5,'Saint Petersburg, Florida 33716',10372,13027);
INSERT INTO "django_geo_db_zipcode" VALUES(14936,33728,-5,'Saint Petersburg, Florida 33728',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14937,33729,-5,'Saint Petersburg, Florida 33729',10372,13029);
INSERT INTO "django_geo_db_zipcode" VALUES(14938,33730,-5,'Saint Petersburg, Florida 33730',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14939,33731,-5,'Saint Petersburg, Florida 33731',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14940,33732,-5,'Saint Petersburg, Florida 33732',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14941,33733,-5,'Saint Petersburg, Florida 33733',10372,13030);
INSERT INTO "django_geo_db_zipcode" VALUES(14942,33734,-5,'Saint Petersburg, Florida 33734',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14943,33736,-5,'Saint Petersburg, Florida 33736',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14944,33737,-5,'Saint Petersburg, Florida 33737',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14945,33738,-5,'Saint Petersburg, Florida 33738',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14946,33740,-5,'Saint Petersburg, Florida 33740',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14947,33741,-5,'Saint Petersburg, Florida 33741',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14948,33742,-5,'Saint Petersburg, Florida 33742',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14949,33743,-5,'Saint Petersburg, Florida 33743',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14950,33744,-5,'Bay Pines, Florida 33744',10373,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14951,33747,-5,'Saint Petersburg, Florida 33747',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14952,33755,-5,'Clearwater, Florida 33755',10374,13031);
INSERT INTO "django_geo_db_zipcode" VALUES(14953,33756,-5,'Clearwater, Florida 33756',10374,13032);
INSERT INTO "django_geo_db_zipcode" VALUES(14954,33757,-5,'Clearwater, Florida 33757',10374,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14955,33758,-5,'Clearwater, Florida 33758',10374,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14956,33759,-5,'Clearwater, Florida 33759',10374,13033);
INSERT INTO "django_geo_db_zipcode" VALUES(14957,33760,-5,'Clearwater, Florida 33760',10374,13034);
INSERT INTO "django_geo_db_zipcode" VALUES(14958,33761,-5,'Clearwater, Florida 33761',10374,13035);
INSERT INTO "django_geo_db_zipcode" VALUES(14959,33762,-5,'Clearwater, Florida 33762',10374,13036);
INSERT INTO "django_geo_db_zipcode" VALUES(14960,33763,-5,'Clearwater, Florida 33763',10374,13037);
INSERT INTO "django_geo_db_zipcode" VALUES(14961,33764,-5,'Clearwater, Florida 33764',10374,13038);
INSERT INTO "django_geo_db_zipcode" VALUES(14962,33765,-5,'Clearwater, Florida 33765',10374,13039);
INSERT INTO "django_geo_db_zipcode" VALUES(14963,33766,-5,'Clearwater, Florida 33766',10374,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14964,33767,-5,'Clearwater Beach, Florida 33767',10375,13040);
INSERT INTO "django_geo_db_zipcode" VALUES(14965,33769,-5,'Clearwater, Florida 33769',10374,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14966,33770,-5,'Largo, Florida 33770',10376,13041);
INSERT INTO "django_geo_db_zipcode" VALUES(14967,33771,-5,'Largo, Florida 33771',10376,13042);
INSERT INTO "django_geo_db_zipcode" VALUES(14968,33772,-5,'Seminole, Florida 33772',10377,13043);
INSERT INTO "django_geo_db_zipcode" VALUES(14969,33773,-5,'Largo, Florida 33773',10376,13044);
INSERT INTO "django_geo_db_zipcode" VALUES(14970,33774,-5,'Largo, Florida 33774',10376,13045);
INSERT INTO "django_geo_db_zipcode" VALUES(14971,33775,-5,'Seminole, Florida 33775',10377,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14972,33776,-5,'Seminole, Florida 33776',10377,13046);
INSERT INTO "django_geo_db_zipcode" VALUES(14973,33777,-5,'Largo, Florida 33777',10376,13047);
INSERT INTO "django_geo_db_zipcode" VALUES(14974,33778,-5,'Largo, Florida 33778',10376,13048);
INSERT INTO "django_geo_db_zipcode" VALUES(14975,33779,-5,'Largo, Florida 33779',10376,13049);
INSERT INTO "django_geo_db_zipcode" VALUES(14976,33780,-5,'Pinellas Park, Florida 33780',10378,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14977,33781,-5,'Pinellas Park, Florida 33781',10378,13050);
INSERT INTO "django_geo_db_zipcode" VALUES(14978,33782,-5,'Pinellas Park, Florida 33782',10378,13051);
INSERT INTO "django_geo_db_zipcode" VALUES(14979,33784,-5,'Saint Petersburg, Florida 33784',10372,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(14980,33785,-5,'Indian Rocks Beach, Florida 33785',10379,13052);
INSERT INTO "django_geo_db_zipcode" VALUES(14981,33786,-5,'Belleair Beach, Florida 33786',10380,13053);
INSERT INTO "django_geo_db_zipcode" VALUES(14982,33801,-5,'Lakeland, Florida 33801',10381,13054);
INSERT INTO "django_geo_db_zipcode" VALUES(14983,33802,-5,'Lakeland, Florida 33802',10381,13055);
INSERT INTO "django_geo_db_zipcode" VALUES(14984,33803,-5,'Lakeland, Florida 33803',10381,13056);
INSERT INTO "django_geo_db_zipcode" VALUES(14985,33804,-5,'Lakeland, Florida 33804',10381,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(14986,33805,-5,'Lakeland, Florida 33805',10381,13058);
INSERT INTO "django_geo_db_zipcode" VALUES(14987,33806,-5,'Lakeland, Florida 33806',10381,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(14988,33807,-5,'Lakeland, Florida 33807',10381,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(14989,33809,-5,'Lakeland, Florida 33809',10381,13059);
INSERT INTO "django_geo_db_zipcode" VALUES(14990,33810,-5,'Lakeland, Florida 33810',10381,13060);
INSERT INTO "django_geo_db_zipcode" VALUES(14991,33811,-5,'Lakeland, Florida 33811',10381,13061);
INSERT INTO "django_geo_db_zipcode" VALUES(14992,33813,-5,'Lakeland, Florida 33813',10381,13062);
INSERT INTO "django_geo_db_zipcode" VALUES(14993,33815,-5,'Lakeland, Florida 33815',10381,13063);
INSERT INTO "django_geo_db_zipcode" VALUES(14994,33820,-5,'Alturas, Florida 33820',10382,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(14995,33823,-5,'Auburndale, Florida 33823',10383,13064);
INSERT INTO "django_geo_db_zipcode" VALUES(14996,33825,-5,'Avon Park, Florida 33825',10384,13065);
INSERT INTO "django_geo_db_zipcode" VALUES(14997,33826,-5,'Avon Park, Florida 33826',10384,13066);
INSERT INTO "django_geo_db_zipcode" VALUES(14998,33827,-5,'Babson Park, Florida 33827',10385,13067);
INSERT INTO "django_geo_db_zipcode" VALUES(14999,33830,-5,'Bartow, Florida 33830',10386,13068);
INSERT INTO "django_geo_db_zipcode" VALUES(15000,33831,-5,'Bartow, Florida 33831',10386,13069);
INSERT INTO "django_geo_db_zipcode" VALUES(15001,33834,-5,'Bowling Green, Florida 33834',10387,13070);
INSERT INTO "django_geo_db_zipcode" VALUES(15002,33835,-5,'Bradley, Florida 33835',10388,13071);
INSERT INTO "django_geo_db_zipcode" VALUES(15003,33836,-5,'Davenport, Florida 33836',10389,13072);
INSERT INTO "django_geo_db_zipcode" VALUES(15004,33837,-5,'Davenport, Florida 33837',10389,13073);
INSERT INTO "django_geo_db_zipcode" VALUES(15005,33838,-5,'Dundee, Florida 33838',10390,13074);
INSERT INTO "django_geo_db_zipcode" VALUES(15006,33839,-5,'Eagle Lake, Florida 33839',10391,13075);
INSERT INTO "django_geo_db_zipcode" VALUES(15007,33840,-5,'Eaton Park, Florida 33840',10392,13076);
INSERT INTO "django_geo_db_zipcode" VALUES(15008,33841,-5,'Fort Meade, Florida 33841',10393,13077);
INSERT INTO "django_geo_db_zipcode" VALUES(15009,33843,-5,'Frostproof, Florida 33843',10394,13078);
INSERT INTO "django_geo_db_zipcode" VALUES(15010,33844,-5,'Haines City, Florida 33844',10395,13079);
INSERT INTO "django_geo_db_zipcode" VALUES(15011,33845,-5,'Haines City, Florida 33845',10395,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(15012,33846,-5,'Highland City, Florida 33846',10396,13080);
INSERT INTO "django_geo_db_zipcode" VALUES(15013,33847,-5,'Homeland, Florida 33847',10397,13081);
INSERT INTO "django_geo_db_zipcode" VALUES(15014,33848,-5,'Intercession City, Florida 33848',10398,13082);
INSERT INTO "django_geo_db_zipcode" VALUES(15015,33849,-5,'Kathleen, Florida 33849',10399,13083);
INSERT INTO "django_geo_db_zipcode" VALUES(15016,33850,-5,'Lake Alfred, Florida 33850',10400,13084);
INSERT INTO "django_geo_db_zipcode" VALUES(15017,33851,-5,'Lake Hamilton, Florida 33851',10401,13085);
INSERT INTO "django_geo_db_zipcode" VALUES(15018,33852,-5,'Lake Placid, Florida 33852',10402,13086);
INSERT INTO "django_geo_db_zipcode" VALUES(15019,33853,-5,'Lake Wales, Florida 33853',10403,13087);
INSERT INTO "django_geo_db_zipcode" VALUES(15020,33854,-5,'Fedhaven, Florida 33854',10404,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(15021,33855,-5,'Indian Lake Estates, Florida 33855',10405,13088);
INSERT INTO "django_geo_db_zipcode" VALUES(15022,33856,-5,'Nalcrest, Florida 33856',10406,13089);
INSERT INTO "django_geo_db_zipcode" VALUES(15023,33857,-5,'Lorida, Florida 33857',10407,13090);
INSERT INTO "django_geo_db_zipcode" VALUES(15024,33858,-5,'Loughman, Florida 33858',10408,13091);
INSERT INTO "django_geo_db_zipcode" VALUES(15025,33859,-5,'Lake Wales, Florida 33859',10403,13092);
INSERT INTO "django_geo_db_zipcode" VALUES(15026,33860,-5,'Mulberry, Florida 33860',10409,13093);
INSERT INTO "django_geo_db_zipcode" VALUES(15027,33862,-5,'Lake Placid, Florida 33862',10402,13094);
INSERT INTO "django_geo_db_zipcode" VALUES(15028,33863,-5,'Nichols, Florida 33863',10410,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(15029,33865,-5,'Ona, Florida 33865',10411,13095);
INSERT INTO "django_geo_db_zipcode" VALUES(15030,33867,-5,'River Ranch, Florida 33867',10412,13096);
INSERT INTO "django_geo_db_zipcode" VALUES(15031,33868,-5,'Polk City, Florida 33868',10413,13097);
INSERT INTO "django_geo_db_zipcode" VALUES(15032,33870,-5,'Sebring, Florida 33870',10414,13098);
INSERT INTO "django_geo_db_zipcode" VALUES(15033,33871,-5,'Sebring, Florida 33871',10414,13099);
INSERT INTO "django_geo_db_zipcode" VALUES(15034,33872,-5,'Sebring, Florida 33872',10414,13100);
INSERT INTO "django_geo_db_zipcode" VALUES(15035,33873,-5,'Wauchula, Florida 33873',10415,13101);
INSERT INTO "django_geo_db_zipcode" VALUES(15036,33875,-5,'Sebring, Florida 33875',10414,13102);
INSERT INTO "django_geo_db_zipcode" VALUES(15037,33876,-5,'Sebring, Florida 33876',10414,13103);
INSERT INTO "django_geo_db_zipcode" VALUES(15038,33877,-5,'Waverly, Florida 33877',10416,13104);
INSERT INTO "django_geo_db_zipcode" VALUES(15039,33880,-5,'Winter Haven, Florida 33880',10313,13105);
INSERT INTO "django_geo_db_zipcode" VALUES(15040,33881,-5,'Winter Haven, Florida 33881',10313,13106);
INSERT INTO "django_geo_db_zipcode" VALUES(15041,33882,-5,'Winter Haven, Florida 33882',10313,13107);
INSERT INTO "django_geo_db_zipcode" VALUES(15042,33883,-5,'Winter Haven, Florida 33883',10313,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(15043,33884,-5,'Winter Haven, Florida 33884',10313,13108);
INSERT INTO "django_geo_db_zipcode" VALUES(15044,33885,-5,'Winter Haven, Florida 33885',10313,13057);
INSERT INTO "django_geo_db_zipcode" VALUES(15045,33888,-5,'Winter Haven, Florida 33888',10313,13109);
INSERT INTO "django_geo_db_zipcode" VALUES(15046,33890,-5,'Zolfo Springs, Florida 33890',10417,13110);
INSERT INTO "django_geo_db_zipcode" VALUES(15047,33896,-5,'Loughman, Florida 33896',10408,13111);
INSERT INTO "django_geo_db_zipcode" VALUES(15048,33897,-5,'Citrus Ridge, Florida 33897',10418,13112);
INSERT INTO "django_geo_db_zipcode" VALUES(15049,33898,-5,'Highland Park, Florida 33898',10419,13113);
INSERT INTO "django_geo_db_zipcode" VALUES(15050,33901,-5,'Fort Myers, Florida 33901',10420,13114);
INSERT INTO "django_geo_db_zipcode" VALUES(15051,33902,-5,'Fort Myers, Florida 33902',10420,13115);
INSERT INTO "django_geo_db_zipcode" VALUES(15052,33903,-5,'North Fort Myers, Florida 33903',10421,13116);
INSERT INTO "django_geo_db_zipcode" VALUES(15053,33904,-5,'Cape Coral, Florida 33904',10422,13117);
INSERT INTO "django_geo_db_zipcode" VALUES(15054,33905,-5,'Fort Myers, Florida 33905',10420,13118);
INSERT INTO "django_geo_db_zipcode" VALUES(15055,33906,-5,'Fort Myers, Florida 33906',10420,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15056,33907,-5,'Fort Myers, Florida 33907',10420,13120);
INSERT INTO "django_geo_db_zipcode" VALUES(15057,33908,-5,'Fort Myers, Florida 33908',10420,13121);
INSERT INTO "django_geo_db_zipcode" VALUES(15058,33909,-5,'Cape Coral, Florida 33909',10422,13122);
INSERT INTO "django_geo_db_zipcode" VALUES(15059,33910,-5,'Cape Coral, Florida 33910',10422,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15060,33911,-5,'Fort Myers, Florida 33911',10420,13123);
INSERT INTO "django_geo_db_zipcode" VALUES(15061,33912,-5,'Fort Myers, Florida 33912',10420,13124);
INSERT INTO "django_geo_db_zipcode" VALUES(15062,33913,-5,'Fort Myers, Florida 33913',10420,13125);
INSERT INTO "django_geo_db_zipcode" VALUES(15063,33914,-5,'Cape Coral, Florida 33914',10422,13126);
INSERT INTO "django_geo_db_zipcode" VALUES(15064,33915,-5,'Cape Coral, Florida 33915',10422,13127);
INSERT INTO "django_geo_db_zipcode" VALUES(15065,33916,-5,'Fort Myers, Florida 33916',10420,13128);
INSERT INTO "django_geo_db_zipcode" VALUES(15066,33917,-5,'North Fort Myers, Florida 33917',10421,13129);
INSERT INTO "django_geo_db_zipcode" VALUES(15067,33918,-5,'North Fort Myers, Florida 33918',10421,13130);
INSERT INTO "django_geo_db_zipcode" VALUES(15068,33919,-5,'Fort Myers, Florida 33919',10420,13131);
INSERT INTO "django_geo_db_zipcode" VALUES(15069,33920,-5,'Alva, Florida 33920',10423,13132);
INSERT INTO "django_geo_db_zipcode" VALUES(15070,33921,-5,'Boca Grande, Florida 33921',10424,13133);
INSERT INTO "django_geo_db_zipcode" VALUES(15071,33922,-5,'Bokeelia, Florida 33922',10425,13134);
INSERT INTO "django_geo_db_zipcode" VALUES(15072,33924,-5,'Captiva, Florida 33924',10426,13135);
INSERT INTO "django_geo_db_zipcode" VALUES(15073,33927,-5,'Punta Gorda, Florida 33927',10369,13136);
INSERT INTO "django_geo_db_zipcode" VALUES(15074,33928,-5,'Estero, Florida 33928',10427,13137);
INSERT INTO "django_geo_db_zipcode" VALUES(15075,33930,-5,'Felda, Florida 33930',10428,13138);
INSERT INTO "django_geo_db_zipcode" VALUES(15076,33931,-5,'Fort Myers Beach, Florida 33931',10429,13139);
INSERT INTO "django_geo_db_zipcode" VALUES(15077,33932,-5,'Fort Myers Beach, Florida 33932',10429,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15078,33935,-5,'Labelle, Florida 33935',10430,13140);
INSERT INTO "django_geo_db_zipcode" VALUES(15079,33936,-5,'Lehigh Acres, Florida 33936',10431,13141);
INSERT INTO "django_geo_db_zipcode" VALUES(15080,33938,-5,'Murdock, Florida 33938',10432,13136);
INSERT INTO "django_geo_db_zipcode" VALUES(15081,33944,-5,'Palmdale, Florida 33944',10433,13142);
INSERT INTO "django_geo_db_zipcode" VALUES(15082,33945,-5,'Pineland, Florida 33945',10434,13143);
INSERT INTO "django_geo_db_zipcode" VALUES(15083,33946,-5,'Placida, Florida 33946',10435,13144);
INSERT INTO "django_geo_db_zipcode" VALUES(15084,33947,-5,'Rotonda West, Florida 33947',10436,13145);
INSERT INTO "django_geo_db_zipcode" VALUES(15085,33948,-5,'Port Charlotte, Florida 33948',10437,13146);
INSERT INTO "django_geo_db_zipcode" VALUES(15086,33949,-5,'Port Charlotte, Florida 33949',10437,13147);
INSERT INTO "django_geo_db_zipcode" VALUES(15087,33950,-5,'Punta Gorda, Florida 33950',10369,13148);
INSERT INTO "django_geo_db_zipcode" VALUES(15088,33951,-5,'Punta Gorda, Florida 33951',10369,13149);
INSERT INTO "django_geo_db_zipcode" VALUES(15089,33952,-5,'Port Charlotte, Florida 33952',10437,13150);
INSERT INTO "django_geo_db_zipcode" VALUES(15090,33953,-5,'Port Charlotte, Florida 33953',10437,13151);
INSERT INTO "django_geo_db_zipcode" VALUES(15091,33954,-5,'Port Charlotte, Florida 33954',10437,13152);
INSERT INTO "django_geo_db_zipcode" VALUES(15092,33955,-5,'Punta Gorda, Florida 33955',10369,13153);
INSERT INTO "django_geo_db_zipcode" VALUES(15093,33956,-5,'Saint James City, Florida 33956',10438,13154);
INSERT INTO "django_geo_db_zipcode" VALUES(15094,33957,-5,'Sanibel, Florida 33957',10439,13155);
INSERT INTO "django_geo_db_zipcode" VALUES(15095,33960,-5,'Venus, Florida 33960',10440,13156);
INSERT INTO "django_geo_db_zipcode" VALUES(15096,33961,-5,'Fort Myers, Florida 33961',10420,13157);
INSERT INTO "django_geo_db_zipcode" VALUES(15097,33965,-5,'Fort Myers, Florida 33965',10420,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15098,33970,-5,'Lehigh Acres, Florida 33970',10431,13158);
INSERT INTO "django_geo_db_zipcode" VALUES(15099,33971,-5,'Lehigh Acres, Florida 33971',10431,13159);
INSERT INTO "django_geo_db_zipcode" VALUES(15100,33972,-5,'Lehigh Acres, Florida 33972',10431,13160);
INSERT INTO "django_geo_db_zipcode" VALUES(15101,33975,-5,'Labelle, Florida 33975',10430,13161);
INSERT INTO "django_geo_db_zipcode" VALUES(15102,33980,-5,'Port Charlotte, Florida 33980',10437,13162);
INSERT INTO "django_geo_db_zipcode" VALUES(15103,33981,-5,'Port Charlotte, Florida 33981',10437,13163);
INSERT INTO "django_geo_db_zipcode" VALUES(15104,33982,-5,'Punta Gorda, Florida 33982',10369,13164);
INSERT INTO "django_geo_db_zipcode" VALUES(15105,33983,-5,'Punta Gorda, Florida 33983',10369,13165);
INSERT INTO "django_geo_db_zipcode" VALUES(15106,33990,-5,'Cape Coral, Florida 33990',10422,13166);
INSERT INTO "django_geo_db_zipcode" VALUES(15107,33991,-5,'Cape Coral, Florida 33991',10422,13167);
INSERT INTO "django_geo_db_zipcode" VALUES(15108,33993,-5,'Cape Coral, Florida 33993',10422,13168);
INSERT INTO "django_geo_db_zipcode" VALUES(15109,33994,-5,'Fort Myers, Florida 33994',10420,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15110,34101,-5,'Naples, Florida 34101',10441,13169);
INSERT INTO "django_geo_db_zipcode" VALUES(15111,34102,-5,'Naples, Florida 34102',10441,13170);
INSERT INTO "django_geo_db_zipcode" VALUES(15112,34103,-5,'Naples, Florida 34103',10441,13171);
INSERT INTO "django_geo_db_zipcode" VALUES(15113,34104,-5,'Naples, Florida 34104',10441,13172);
INSERT INTO "django_geo_db_zipcode" VALUES(15114,34105,-5,'Naples, Florida 34105',10441,13173);
INSERT INTO "django_geo_db_zipcode" VALUES(15115,34106,-5,'Naples, Florida 34106',10441,13174);
INSERT INTO "django_geo_db_zipcode" VALUES(15116,34107,-5,'Vanderbilt Beach, Florida 34107',10442,13174);
INSERT INTO "django_geo_db_zipcode" VALUES(15117,34108,-5,'Naples, Florida 34108',10441,13175);
INSERT INTO "django_geo_db_zipcode" VALUES(15118,34109,-5,'Naples, Florida 34109',10441,13176);
INSERT INTO "django_geo_db_zipcode" VALUES(15119,34110,-5,'Naples, Florida 34110',10441,13177);
INSERT INTO "django_geo_db_zipcode" VALUES(15120,34112,-5,'Naples, Florida 34112',10441,13178);
INSERT INTO "django_geo_db_zipcode" VALUES(15121,34113,-5,'Naples, Florida 34113',10441,13179);
INSERT INTO "django_geo_db_zipcode" VALUES(15122,34114,-5,'Naples, Florida 34114',10441,13180);
INSERT INTO "django_geo_db_zipcode" VALUES(15123,34116,-5,'Naples, Florida 34116',10441,13181);
INSERT INTO "django_geo_db_zipcode" VALUES(15124,34117,-5,'Naples, Florida 34117',10441,13182);
INSERT INTO "django_geo_db_zipcode" VALUES(15125,34119,-5,'Naples, Florida 34119',10441,13183);
INSERT INTO "django_geo_db_zipcode" VALUES(15126,34120,-5,'Naples, Florida 34120',10441,13184);
INSERT INTO "django_geo_db_zipcode" VALUES(15127,34133,-5,'Bonita Springs, Florida 34133',10443,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15128,34134,-5,'Bonita Springs, Florida 34134',10443,13185);
INSERT INTO "django_geo_db_zipcode" VALUES(15129,34135,-5,'Bonita Springs, Florida 34135',10443,13186);
INSERT INTO "django_geo_db_zipcode" VALUES(15130,34136,-5,'Bonita Springs, Florida 34136',10443,13119);
INSERT INTO "django_geo_db_zipcode" VALUES(15131,34137,-5,'Copeland, Florida 34137',10444,13187);
INSERT INTO "django_geo_db_zipcode" VALUES(15132,34138,-5,'Chokoloskee, Florida 34138',10445,13188);
INSERT INTO "django_geo_db_zipcode" VALUES(15133,34139,-5,'Everglades City, Florida 34139',10446,13189);
INSERT INTO "django_geo_db_zipcode" VALUES(15134,34140,-5,'Goodland, Florida 34140',10447,13174);
INSERT INTO "django_geo_db_zipcode" VALUES(15135,34141,-5,'Ochopee, Florida 34141',10448,13190);
INSERT INTO "django_geo_db_zipcode" VALUES(15136,34142,-5,'Immokalee, Florida 34142',10449,13191);
INSERT INTO "django_geo_db_zipcode" VALUES(15137,34143,-5,'Immokalee, Florida 34143',10449,13192);
INSERT INTO "django_geo_db_zipcode" VALUES(15138,34145,-5,'Marco Island, Florida 34145',10450,13193);
INSERT INTO "django_geo_db_zipcode" VALUES(15139,34146,-5,'Marco Island, Florida 34146',10450,13174);
INSERT INTO "django_geo_db_zipcode" VALUES(15140,34154,-5,'Goodland, Florida 34154',10447,13194);
INSERT INTO "django_geo_db_zipcode" VALUES(15141,34168,-5,'Chokoloskee, Florida 34168',10445,13195);
INSERT INTO "django_geo_db_zipcode" VALUES(15142,34201,-5,'Bradenton, Florida 34201',10451,13196);
INSERT INTO "django_geo_db_zipcode" VALUES(15143,34202,-5,'Bradenton, Florida 34202',10451,13197);
INSERT INTO "django_geo_db_zipcode" VALUES(15144,34203,-5,'Bradenton, Florida 34203',10451,13198);
INSERT INTO "django_geo_db_zipcode" VALUES(15145,34204,-5,'Bradenton, Florida 34204',10451,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15146,34205,-5,'Bradenton, Florida 34205',10451,13200);
INSERT INTO "django_geo_db_zipcode" VALUES(15147,34206,-5,'Bradenton, Florida 34206',10451,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15148,34207,-5,'Bradenton, Florida 34207',10451,13201);
INSERT INTO "django_geo_db_zipcode" VALUES(15149,34208,-5,'Bradenton, Florida 34208',10451,13202);
INSERT INTO "django_geo_db_zipcode" VALUES(15150,34209,-5,'Bradenton, Florida 34209',10451,13203);
INSERT INTO "django_geo_db_zipcode" VALUES(15151,34210,-5,'Bradenton, Florida 34210',10451,13204);
INSERT INTO "django_geo_db_zipcode" VALUES(15152,34211,-5,'Memphis, Florida 34211',10452,13205);
INSERT INTO "django_geo_db_zipcode" VALUES(15153,34215,-5,'Cortez, Florida 34215',10453,13206);
INSERT INTO "django_geo_db_zipcode" VALUES(15154,34216,-5,'Anna Maria, Florida 34216',10454,13207);
INSERT INTO "django_geo_db_zipcode" VALUES(15155,34217,-5,'Bradenton Beach, Florida 34217',10455,13208);
INSERT INTO "django_geo_db_zipcode" VALUES(15156,34218,-5,'Holmes Beach, Florida 34218',10456,13209);
INSERT INTO "django_geo_db_zipcode" VALUES(15157,34219,-5,'Parrish, Florida 34219',10457,13210);
INSERT INTO "django_geo_db_zipcode" VALUES(15158,34220,-5,'Palmetto, Florida 34220',10458,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15159,34221,-5,'Palmetto, Florida 34221',10458,13211);
INSERT INTO "django_geo_db_zipcode" VALUES(15160,34222,-5,'Ellenton, Florida 34222',10459,13212);
INSERT INTO "django_geo_db_zipcode" VALUES(15161,34223,-5,'Englewood, Florida 34223',10460,13213);
INSERT INTO "django_geo_db_zipcode" VALUES(15162,34224,-5,'Englewood, Florida 34224',10460,13214);
INSERT INTO "django_geo_db_zipcode" VALUES(15163,34228,-5,'Longboat Key, Florida 34228',10461,13215);
INSERT INTO "django_geo_db_zipcode" VALUES(15164,34229,-5,'Osprey, Florida 34229',10462,13216);
INSERT INTO "django_geo_db_zipcode" VALUES(15165,34230,-5,'Sarasota, Florida 34230',10463,13217);
INSERT INTO "django_geo_db_zipcode" VALUES(15166,34231,-5,'Sarasota, Florida 34231',10463,13218);
INSERT INTO "django_geo_db_zipcode" VALUES(15167,34232,-5,'Sarasota, Florida 34232',10463,13219);
INSERT INTO "django_geo_db_zipcode" VALUES(15168,34233,-5,'Sarasota, Florida 34233',10463,13220);
INSERT INTO "django_geo_db_zipcode" VALUES(15169,34234,-5,'Sarasota, Florida 34234',10463,13221);
INSERT INTO "django_geo_db_zipcode" VALUES(15170,34235,-5,'Sarasota, Florida 34235',10463,13222);
INSERT INTO "django_geo_db_zipcode" VALUES(15171,34236,-5,'Sarasota, Florida 34236',10463,13223);
INSERT INTO "django_geo_db_zipcode" VALUES(15172,34237,-5,'Sarasota, Florida 34237',10463,13224);
INSERT INTO "django_geo_db_zipcode" VALUES(15173,34238,-5,'Sarasota, Florida 34238',10463,13225);
INSERT INTO "django_geo_db_zipcode" VALUES(15174,34239,-5,'Sarasota, Florida 34239',10463,13226);
INSERT INTO "django_geo_db_zipcode" VALUES(15175,34240,-5,'Sarasota, Florida 34240',10463,13227);
INSERT INTO "django_geo_db_zipcode" VALUES(15176,34241,-5,'Sarasota, Florida 34241',10463,13228);
INSERT INTO "django_geo_db_zipcode" VALUES(15177,34242,-5,'Sarasota, Florida 34242',10463,13229);
INSERT INTO "django_geo_db_zipcode" VALUES(15178,34243,-5,'Sarasota, Florida 34243',10463,13230);
INSERT INTO "django_geo_db_zipcode" VALUES(15179,34250,-5,'Terra Ceia, Florida 34250',10464,13231);
INSERT INTO "django_geo_db_zipcode" VALUES(15180,34251,-5,'Myakka City, Florida 34251',10465,13232);
INSERT INTO "django_geo_db_zipcode" VALUES(15181,34260,-5,'Manasota, Florida 34260',10466,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15182,34264,-5,'Oneco, Florida 34264',10467,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15183,34265,-5,'Arcadia, Florida 34265',10468,13233);
INSERT INTO "django_geo_db_zipcode" VALUES(15184,34266,-5,'Arcadia, Florida 34266',10468,13234);
INSERT INTO "django_geo_db_zipcode" VALUES(15185,34267,-5,'Fort Ogden, Florida 34267',10469,13233);
INSERT INTO "django_geo_db_zipcode" VALUES(15186,34268,-5,'Nocatee, Florida 34268',10470,13235);
INSERT INTO "django_geo_db_zipcode" VALUES(15187,34270,-5,'Tallevast, Florida 34270',10471,13236);
INSERT INTO "django_geo_db_zipcode" VALUES(15188,34272,-5,'Laurel, Florida 34272',10472,13237);
INSERT INTO "django_geo_db_zipcode" VALUES(15189,34274,-5,'Nokomis, Florida 34274',10473,13238);
INSERT INTO "django_geo_db_zipcode" VALUES(15190,34275,-5,'Nokomis, Florida 34275',10473,13239);
INSERT INTO "django_geo_db_zipcode" VALUES(15191,34276,-5,'Sarasota, Florida 34276',10463,13240);
INSERT INTO "django_geo_db_zipcode" VALUES(15192,34277,-5,'Sarasota, Florida 34277',10463,13240);
INSERT INTO "django_geo_db_zipcode" VALUES(15193,34278,-5,'Sarasota, Florida 34278',10463,13241);
INSERT INTO "django_geo_db_zipcode" VALUES(15194,34280,-5,'Bradenton, Florida 34280',10451,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15195,34281,-5,'Bradenton, Florida 34281',10451,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15196,34282,-5,'Bradenton, Florida 34282',10451,13199);
INSERT INTO "django_geo_db_zipcode" VALUES(15197,34284,-5,'Venice, Florida 34284',10474,13240);
INSERT INTO "django_geo_db_zipcode" VALUES(15198,34285,-5,'Venice, Florida 34285',10474,13242);
INSERT INTO "django_geo_db_zipcode" VALUES(15199,34286,-5,'North Port, Florida 34286',10475,13243);
INSERT INTO "django_geo_db_zipcode" VALUES(15200,34287,-5,'North Port, Florida 34287',10475,13244);
INSERT INTO "django_geo_db_zipcode" VALUES(15201,34288,-5,'North Port, Florida 34288',10475,13245);
INSERT INTO "django_geo_db_zipcode" VALUES(15202,34289,-5,'North Port, Florida 34289',10475,13246);
INSERT INTO "django_geo_db_zipcode" VALUES(15203,34292,-5,'Venice, Florida 34292',10474,13247);
INSERT INTO "django_geo_db_zipcode" VALUES(15204,34293,-5,'Venice, Florida 34293',10474,13248);
INSERT INTO "django_geo_db_zipcode" VALUES(15205,34295,-5,'Englewood, Florida 34295',10460,13249);
INSERT INTO "django_geo_db_zipcode" VALUES(15206,34334,-5,'Grove City, Florida 34334',10476,13250);
INSERT INTO "django_geo_db_zipcode" VALUES(15207,34420,-5,'Belleview, Florida 34420',10477,13251);
INSERT INTO "django_geo_db_zipcode" VALUES(15208,34421,-5,'Belleview, Florida 34421',10477,13252);
INSERT INTO "django_geo_db_zipcode" VALUES(15209,34423,-5,'Crystal River, Florida 34423',10478,13253);
INSERT INTO "django_geo_db_zipcode" VALUES(15210,34424,-5,'Crystal River, Florida 34424',10478,13254);
INSERT INTO "django_geo_db_zipcode" VALUES(15211,34426,-5,'Pine Ridge, Florida 34426',10479,13255);
INSERT INTO "django_geo_db_zipcode" VALUES(15212,34428,-5,'Crystal River, Florida 34428',10478,13256);
INSERT INTO "django_geo_db_zipcode" VALUES(15213,34429,-5,'Crystal River, Florida 34429',10478,13257);
INSERT INTO "django_geo_db_zipcode" VALUES(15214,34430,-5,'Dunnellon, Florida 34430',10480,13252);
INSERT INTO "django_geo_db_zipcode" VALUES(15215,34431,-5,'Dunnellon, Florida 34431',10480,13258);
INSERT INTO "django_geo_db_zipcode" VALUES(15216,34432,-5,'Dunnellon, Florida 34432',10480,13259);
INSERT INTO "django_geo_db_zipcode" VALUES(15217,34433,-5,'Dunnellon, Florida 34433',10480,13260);
INSERT INTO "django_geo_db_zipcode" VALUES(15218,34434,-5,'Dunnellon, Florida 34434',10480,13261);
INSERT INTO "django_geo_db_zipcode" VALUES(15219,34436,-5,'Floral City, Florida 34436',10481,13262);
INSERT INTO "django_geo_db_zipcode" VALUES(15220,34442,-5,'Hernando, Florida 34442',10482,13263);
INSERT INTO "django_geo_db_zipcode" VALUES(15221,34445,-5,'Holder, Florida 34445',10483,13264);
INSERT INTO "django_geo_db_zipcode" VALUES(15222,34446,-5,'Homosassa, Florida 34446',10484,13265);
INSERT INTO "django_geo_db_zipcode" VALUES(15223,34447,-5,'Homosassa Springs, Florida 34447',10485,13266);
INSERT INTO "django_geo_db_zipcode" VALUES(15224,34448,-5,'Homosassa, Florida 34448',10484,13267);
INSERT INTO "django_geo_db_zipcode" VALUES(15225,34449,-5,'Inglis, Florida 34449',10486,13268);
INSERT INTO "django_geo_db_zipcode" VALUES(15226,34450,-5,'Inverness, Florida 34450',10487,13269);
INSERT INTO "django_geo_db_zipcode" VALUES(15227,34451,-5,'Inverness, Florida 34451',10487,13270);
INSERT INTO "django_geo_db_zipcode" VALUES(15228,34452,-5,'Inverness, Florida 34452',10487,13271);
INSERT INTO "django_geo_db_zipcode" VALUES(15229,34453,-5,'Inverness, Florida 34453',10487,13272);
INSERT INTO "django_geo_db_zipcode" VALUES(15230,34460,-5,'Lecanto, Florida 34460',10488,13273);
INSERT INTO "django_geo_db_zipcode" VALUES(15231,34461,-5,'Lecanto, Florida 34461',10488,13274);
INSERT INTO "django_geo_db_zipcode" VALUES(15232,34464,-5,'Beverly Hills, Florida 34464',10489,13273);
INSERT INTO "django_geo_db_zipcode" VALUES(15233,34465,-5,'Beverly Hills, Florida 34465',10489,13275);
INSERT INTO "django_geo_db_zipcode" VALUES(15234,34470,-5,'Ocala, Florida 34470',10490,13276);
INSERT INTO "django_geo_db_zipcode" VALUES(15235,34471,-5,'Ocala, Florida 34471',10490,13277);
INSERT INTO "django_geo_db_zipcode" VALUES(15236,34472,-5,'Ocala, Florida 34472',10490,13278);
INSERT INTO "django_geo_db_zipcode" VALUES(15237,34473,-5,'Ocala, Florida 34473',10490,13279);
INSERT INTO "django_geo_db_zipcode" VALUES(15238,34474,-5,'Ocala, Florida 34474',10490,13280);
INSERT INTO "django_geo_db_zipcode" VALUES(15239,34475,-5,'Ocala, Florida 34475',10490,13281);
INSERT INTO "django_geo_db_zipcode" VALUES(15240,34476,-5,'Ocala, Florida 34476',10490,13282);
INSERT INTO "django_geo_db_zipcode" VALUES(15241,34477,-5,'Ocala, Florida 34477',10490,13252);
INSERT INTO "django_geo_db_zipcode" VALUES(15242,34478,-5,'Ocala, Florida 34478',10490,13283);
INSERT INTO "django_geo_db_zipcode" VALUES(15243,34479,-5,'Ocala, Florida 34479',10490,13284);
INSERT INTO "django_geo_db_zipcode" VALUES(15244,34480,-5,'Ocala, Florida 34480',10490,13285);
INSERT INTO "django_geo_db_zipcode" VALUES(15245,34481,-5,'Ocala, Florida 34481',10490,13286);
INSERT INTO "django_geo_db_zipcode" VALUES(15246,34482,-5,'Ocala, Florida 34482',10490,13287);
INSERT INTO "django_geo_db_zipcode" VALUES(15247,34483,-5,'Ocala, Florida 34483',10490,13252);
INSERT INTO "django_geo_db_zipcode" VALUES(15248,34484,-5,'Oxford, Florida 34484',10491,13288);
INSERT INTO "django_geo_db_zipcode" VALUES(15249,34487,-5,'Homosassa, Florida 34487',10484,13273);
INSERT INTO "django_geo_db_zipcode" VALUES(15250,34488,-5,'Silver Springs, Florida 34488',10492,13289);
INSERT INTO "django_geo_db_zipcode" VALUES(15251,34489,-5,'Silver Springs, Florida 34489',10492,13290);
INSERT INTO "django_geo_db_zipcode" VALUES(15252,34491,-5,'Summerfield, Florida 34491',10493,13291);
INSERT INTO "django_geo_db_zipcode" VALUES(15253,34492,-5,'Summerfield, Florida 34492',10493,13292);
INSERT INTO "django_geo_db_zipcode" VALUES(15254,34498,-5,'Yankeetown, Florida 34498',10494,13293);
INSERT INTO "django_geo_db_zipcode" VALUES(15255,34592,-5,'Port St. Lucie, Florida 34592',10495,13294);
INSERT INTO "django_geo_db_zipcode" VALUES(15256,34601,-5,'Brooksville, Florida 34601',10496,13295);
INSERT INTO "django_geo_db_zipcode" VALUES(15257,34602,-5,'Brooksville, Florida 34602',10496,13296);
INSERT INTO "django_geo_db_zipcode" VALUES(15258,34603,-5,'Brooksville, Florida 34603',10496,13297);
INSERT INTO "django_geo_db_zipcode" VALUES(15259,34604,-5,'Spring Hill, Florida 34604',10497,13298);
INSERT INTO "django_geo_db_zipcode" VALUES(15260,34605,-5,'Brooksville, Florida 34605',10496,13299);
INSERT INTO "django_geo_db_zipcode" VALUES(15261,34606,-5,'Spring Hill, Florida 34606',10497,13300);
INSERT INTO "django_geo_db_zipcode" VALUES(15262,34607,-5,'Spring Hill, Florida 34607',10497,13301);
INSERT INTO "django_geo_db_zipcode" VALUES(15263,34608,-5,'Spring Hill, Florida 34608',10497,13302);
INSERT INTO "django_geo_db_zipcode" VALUES(15264,34609,-5,'Brooksville, Florida 34609',10496,13303);
INSERT INTO "django_geo_db_zipcode" VALUES(15265,34610,-5,'Brooksville, Florida 34610',10496,13304);
INSERT INTO "django_geo_db_zipcode" VALUES(15266,34611,-5,'Spring Hill, Florida 34611',10497,13297);
INSERT INTO "django_geo_db_zipcode" VALUES(15267,34613,-5,'Brooksville, Florida 34613',10496,13305);
INSERT INTO "django_geo_db_zipcode" VALUES(15268,34614,-5,'Brooksville, Florida 34614',10496,13306);
INSERT INTO "django_geo_db_zipcode" VALUES(15269,34636,-5,'Istachatta, Florida 34636',10498,13307);
INSERT INTO "django_geo_db_zipcode" VALUES(15270,34639,-5,'Land O Lakes, Florida 34639',10499,13308);
INSERT INTO "django_geo_db_zipcode" VALUES(15271,34652,-5,'New Port Richey, Florida 34652',10500,13309);
INSERT INTO "django_geo_db_zipcode" VALUES(15272,34653,-5,'New Port Richey, Florida 34653',10500,13310);
INSERT INTO "django_geo_db_zipcode" VALUES(15273,34654,-5,'New Port Richey, Florida 34654',10500,13311);
INSERT INTO "django_geo_db_zipcode" VALUES(15274,34655,-5,'New Port Richey, Florida 34655',10500,13312);
INSERT INTO "django_geo_db_zipcode" VALUES(15275,34656,-5,'New Port Richey, Florida 34656',10500,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(15276,34660,-5,'Ozona, Florida 34660',10501,13313);
INSERT INTO "django_geo_db_zipcode" VALUES(15277,34661,-5,'Nobleton, Florida 34661',10502,13314);
INSERT INTO "django_geo_db_zipcode" VALUES(15278,34667,-5,'Hudson, Florida 34667',10503,13315);
INSERT INTO "django_geo_db_zipcode" VALUES(15279,34668,-5,'Port Richey, Florida 34668',10504,13316);
INSERT INTO "django_geo_db_zipcode" VALUES(15280,34669,-5,'Hudson, Florida 34669',10503,13317);
INSERT INTO "django_geo_db_zipcode" VALUES(15281,34673,-5,'Port Richey, Florida 34673',10504,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(15282,34674,-5,'Hudson, Florida 34674',10503,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(15283,34677,-5,'Oldsmar, Florida 34677',10505,13318);
INSERT INTO "django_geo_db_zipcode" VALUES(15284,34678,-5,'Palm Harbor, Florida 34678',10506,13319);
INSERT INTO "django_geo_db_zipcode" VALUES(15285,34679,-5,'Aripeka, Florida 34679',10507,13320);
INSERT INTO "django_geo_db_zipcode" VALUES(15286,34680,-5,'Elfers, Florida 34680',10508,12947);
INSERT INTO "django_geo_db_zipcode" VALUES(15287,34681,-5,'Crystal Beach, Florida 34681',10509,13321);
INSERT INTO "django_geo_db_zipcode" VALUES(15288,34682,-5,'Palm Harbor, Florida 34682',10506,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(15289,34683,-5,'Palm Harbor, Florida 34683',10506,13322);
INSERT INTO "django_geo_db_zipcode" VALUES(15290,34684,-5,'Palm Harbor, Florida 34684',10506,13323);
INSERT INTO "django_geo_db_zipcode" VALUES(15291,34685,-5,'Palm Harbor, Florida 34685',10506,13324);
INSERT INTO "django_geo_db_zipcode" VALUES(15292,34688,-5,'Tarpon Springs, Florida 34688',10510,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(15293,34689,-5,'Tarpon Springs, Florida 34689',10510,13325);
INSERT INTO "django_geo_db_zipcode" VALUES(15294,34690,-5,'Holiday, Florida 34690',10511,13326);
INSERT INTO "django_geo_db_zipcode" VALUES(15295,34691,-5,'Holiday, Florida 34691',10511,13327);
INSERT INTO "django_geo_db_zipcode" VALUES(15296,34695,-5,'Safety Harbor, Florida 34695',10512,13328);
INSERT INTO "django_geo_db_zipcode" VALUES(15297,34697,-5,'Dunedin, Florida 34697',10513,13028);
INSERT INTO "django_geo_db_zipcode" VALUES(15298,34698,-5,'Dunedin, Florida 34698',10513,13329);
INSERT INTO "django_geo_db_zipcode" VALUES(15299,34703,-5,'Astatula, Florida 34703',10514,13330);
INSERT INTO "django_geo_db_zipcode" VALUES(15300,34705,-5,'Astatula, Florida 34705',10514,13331);
INSERT INTO "django_geo_db_zipcode" VALUES(15301,34711,-5,'Clermont, Florida 34711',10515,13332);
INSERT INTO "django_geo_db_zipcode" VALUES(15302,34712,-5,'Clermont, Florida 34712',10515,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(15303,34713,-5,'Clermont, Florida 34713',10515,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(15304,34729,-5,'Ferndale, Florida 34729',10516,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(15305,34731,-5,'Fruitland Park, Florida 34731',10517,13333);
INSERT INTO "django_geo_db_zipcode" VALUES(15306,34734,-5,'Gotha, Florida 34734',10518,13334);
INSERT INTO "django_geo_db_zipcode" VALUES(15307,34736,-5,'Groveland, Florida 34736',10519,13335);
INSERT INTO "django_geo_db_zipcode" VALUES(15308,34737,-5,'Howey In The Hills, Florida 34737',10520,13336);
INSERT INTO "django_geo_db_zipcode" VALUES(15309,34739,-5,'Kenansville, Florida 34739',10521,13337);
INSERT INTO "django_geo_db_zipcode" VALUES(15310,34740,-5,'Killarney, Florida 34740',10522,13338);
INSERT INTO "django_geo_db_zipcode" VALUES(15311,34741,-5,'Kissimmee, Florida 34741',10523,13339);
INSERT INTO "django_geo_db_zipcode" VALUES(15312,34742,-5,'Kissimmee, Florida 34742',10523,13340);
INSERT INTO "django_geo_db_zipcode" VALUES(15313,34743,-5,'Kissimmee, Florida 34743',10523,13341);
INSERT INTO "django_geo_db_zipcode" VALUES(15314,34744,-5,'Kissimmee, Florida 34744',10523,13342);
INSERT INTO "django_geo_db_zipcode" VALUES(15315,34745,-5,'Kissimmee, Florida 34745',10523,13340);
INSERT INTO "django_geo_db_zipcode" VALUES(15316,34746,-5,'Kissimmee, Florida 34746',10523,13343);
INSERT INTO "django_geo_db_zipcode" VALUES(15317,34747,-5,'Kissimmee, Florida 34747',10523,13344);
INSERT INTO "django_geo_db_zipcode" VALUES(15318,34748,-5,'Leesburg, Florida 34748',10524,13345);
INSERT INTO "django_geo_db_zipcode" VALUES(15319,34749,-5,'Leesburg, Florida 34749',10524,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(15320,34753,-5,'Mascotte, Florida 34753',10525,13346);
INSERT INTO "django_geo_db_zipcode" VALUES(15321,34755,-5,'Minneola, Florida 34755',10526,13347);
INSERT INTO "django_geo_db_zipcode" VALUES(15322,34756,-5,'Montverde, Florida 34756',10527,13348);
INSERT INTO "django_geo_db_zipcode" VALUES(15323,34758,-5,'Kissimmee, Florida 34758',10523,13349);
INSERT INTO "django_geo_db_zipcode" VALUES(15324,34759,-5,'Kissimmee, Florida 34759',10523,13350);
INSERT INTO "django_geo_db_zipcode" VALUES(15325,34760,-5,'Oakland, Florida 34760',10528,13351);
INSERT INTO "django_geo_db_zipcode" VALUES(15326,34761,-5,'Ocoee, Florida 34761',10529,13352);
INSERT INTO "django_geo_db_zipcode" VALUES(15327,34762,-5,'Okahumpka, Florida 34762',10530,13353);
INSERT INTO "django_geo_db_zipcode" VALUES(15328,34769,-5,'Saint Cloud, Florida 34769',10531,13354);
INSERT INTO "django_geo_db_zipcode" VALUES(15329,34770,-5,'Saint Cloud, Florida 34770',10531,13340);
INSERT INTO "django_geo_db_zipcode" VALUES(15330,34771,-5,'Saint Cloud, Florida 34771',10531,13355);
INSERT INTO "django_geo_db_zipcode" VALUES(15331,34772,-5,'Saint Cloud, Florida 34772',10531,13356);
INSERT INTO "django_geo_db_zipcode" VALUES(15332,34773,-5,'Saint Cloud, Florida 34773',10531,13357);
INSERT INTO "django_geo_db_zipcode" VALUES(15333,34777,-5,'Winter Garden, Florida 34777',10532,13358);
INSERT INTO "django_geo_db_zipcode" VALUES(15334,34778,-5,'Winter Garden, Florida 34778',10532,12571);
INSERT INTO "django_geo_db_zipcode" VALUES(15335,34785,-5,'Wildwood, Florida 34785',10533,13359);
INSERT INTO "django_geo_db_zipcode" VALUES(15336,34786,-5,'Windermere, Florida 34786',10534,13360);
INSERT INTO "django_geo_db_zipcode" VALUES(15337,34787,-5,'Winter Garden, Florida 34787',10532,13361);
INSERT INTO "django_geo_db_zipcode" VALUES(15338,34788,-5,'Leesburg, Florida 34788',10524,13362);
INSERT INTO "django_geo_db_zipcode" VALUES(15339,34789,-5,'Leesburg, Florida 34789',10524,12298);
INSERT INTO "django_geo_db_zipcode" VALUES(15340,34797,-5,'Yalaha, Florida 34797',10535,13363);
INSERT INTO "django_geo_db_zipcode" VALUES(15341,34801,-5,'Brooksville, Florida 34801',10496,13364);
INSERT INTO "django_geo_db_zipcode" VALUES(15342,34837,-5,'Hunters Creek, Florida 34837',10536,13365);
INSERT INTO "django_geo_db_zipcode" VALUES(15343,34869,-5,'Tarpon Springs, Florida 34869',10510,13366);
INSERT INTO "django_geo_db_zipcode" VALUES(15344,34876,-5,'Lake Butter, Florida 34876',10537,13367);
INSERT INTO "django_geo_db_zipcode" VALUES(15345,34924,-5,'Okeechobee, Florida 34924',10538,13368);
INSERT INTO "django_geo_db_zipcode" VALUES(15346,34945,-5,'Fort Pierce, Florida 34945',10539,13369);
INSERT INTO "django_geo_db_zipcode" VALUES(15347,34946,-5,'Fort Pierce, Florida 34946',10539,13370);
INSERT INTO "django_geo_db_zipcode" VALUES(15348,34947,-5,'Fort Pierce, Florida 34947',10539,13371);
INSERT INTO "django_geo_db_zipcode" VALUES(15349,34948,-5,'Fort Pierce, Florida 34948',10539,13372);
INSERT INTO "django_geo_db_zipcode" VALUES(15350,34949,-5,'Fort Pierce, Florida 34949',10539,13373);
INSERT INTO "django_geo_db_zipcode" VALUES(15351,34950,-5,'Fort Pierce, Florida 34950',10539,13374);
INSERT INTO "django_geo_db_zipcode" VALUES(15352,34951,-5,'Fort Pierce, Florida 34951',10539,13375);
INSERT INTO "django_geo_db_zipcode" VALUES(15353,34952,-5,'Port Saint Lucie, Florida 34952',10540,13376);
INSERT INTO "django_geo_db_zipcode" VALUES(15354,34953,-5,'Port Saint Lucie, Florida 34953',10540,13377);
INSERT INTO "django_geo_db_zipcode" VALUES(15355,34954,-5,'Fort Pierce, Florida 34954',10539,13372);
INSERT INTO "django_geo_db_zipcode" VALUES(15356,34956,-5,'Indiantown, Florida 34956',10541,13378);
INSERT INTO "django_geo_db_zipcode" VALUES(15357,34957,-5,'Jensen Beach, Florida 34957',10542,13379);
INSERT INTO "django_geo_db_zipcode" VALUES(15358,34958,-5,'Jensen Beach, Florida 34958',10542,13380);
INSERT INTO "django_geo_db_zipcode" VALUES(15359,34972,-5,'Okeechobee, Florida 34972',10538,13381);
INSERT INTO "django_geo_db_zipcode" VALUES(15360,34973,-5,'Okeechobee, Florida 34973',10538,13382);
INSERT INTO "django_geo_db_zipcode" VALUES(15361,34974,-5,'Okeechobee, Florida 34974',10538,13383);
INSERT INTO "django_geo_db_zipcode" VALUES(15362,34979,-5,'Fort Pierce, Florida 34979',10539,13372);
INSERT INTO "django_geo_db_zipcode" VALUES(15363,34981,-5,'Fort Pierce, Florida 34981',10539,13384);
INSERT INTO "django_geo_db_zipcode" VALUES(15364,34982,-5,'Fort Pierce, Florida 34982',10539,13385);
INSERT INTO "django_geo_db_zipcode" VALUES(15365,34983,-5,'Port Saint Lucie, Florida 34983',10540,13386);
INSERT INTO "django_geo_db_zipcode" VALUES(15366,34984,-5,'Port Saint Lucie, Florida 34984',10540,13387);
INSERT INTO "django_geo_db_zipcode" VALUES(15367,34985,-5,'Port Saint Lucie, Florida 34985',10540,13372);
INSERT INTO "django_geo_db_zipcode" VALUES(15368,34986,-5,'Port Saint Lucie, Florida 34986',10540,13388);
INSERT INTO "django_geo_db_zipcode" VALUES(15369,34987,-5,'Port Saint Lucie, Florida 34987',10540,13389);
INSERT INTO "django_geo_db_zipcode" VALUES(15370,34988,-5,'Port Saint Lucie, Florida 34988',10540,13390);
INSERT INTO "django_geo_db_zipcode" VALUES(15371,34990,-5,'Palm City, Florida 34990',10543,13391);
INSERT INTO "django_geo_db_zipcode" VALUES(15372,34991,-5,'Palm City, Florida 34991',10543,12918);
INSERT INTO "django_geo_db_zipcode" VALUES(15373,34992,-5,'Port Salerno, Florida 34992',10544,12918);
INSERT INTO "django_geo_db_zipcode" VALUES(15374,34994,-5,'Stuart, Florida 34994',10545,13392);
INSERT INTO "django_geo_db_zipcode" VALUES(15375,34995,-5,'Stuart, Florida 34995',10545,13393);
INSERT INTO "django_geo_db_zipcode" VALUES(15376,34996,-5,'Stuart, Florida 34996',10545,13394);
INSERT INTO "django_geo_db_zipcode" VALUES(15377,34997,-5,'Stuart, Florida 34997',10545,13395);
INSERT INTO "django_geo_db_zipcode" VALUES(15378,35004,-6,'Moody, Alabama 35004',10546,13396);
INSERT INTO "django_geo_db_zipcode" VALUES(15379,35005,-6,'Adamsville, Alabama 35005',10547,13397);
INSERT INTO "django_geo_db_zipcode" VALUES(15380,35006,-6,'Adger, Alabama 35006',10548,13398);
INSERT INTO "django_geo_db_zipcode" VALUES(15381,35007,-6,'Alabaster, Alabama 35007',10549,13399);
INSERT INTO "django_geo_db_zipcode" VALUES(15382,35010,-6,'Alexander City, Alabama 35010',10550,13400);
INSERT INTO "django_geo_db_zipcode" VALUES(15383,35011,-6,'Alexander City, Alabama 35011',10550,13401);
INSERT INTO "django_geo_db_zipcode" VALUES(15384,35013,-6,'Allgood, Alabama 35013',10551,13402);
INSERT INTO "django_geo_db_zipcode" VALUES(15385,35014,-6,'Alpine, Alabama 35014',10552,13403);
INSERT INTO "django_geo_db_zipcode" VALUES(15386,35015,-6,'Alton, Alabama 35015',10553,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15387,35016,-6,'Arab, Alabama 35016',10554,13405);
INSERT INTO "django_geo_db_zipcode" VALUES(15388,35019,-6,'Baileyton, Alabama 35019',10555,13406);
INSERT INTO "django_geo_db_zipcode" VALUES(15389,35020,-6,'Bessemer, Alabama 35020',10556,13407);
INSERT INTO "django_geo_db_zipcode" VALUES(15390,35021,-6,'Bessemer, Alabama 35021',10556,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15391,35022,-6,'Bessemer, Alabama 35022',10556,13408);
INSERT INTO "django_geo_db_zipcode" VALUES(15392,35023,-6,'Bessemer, Alabama 35023',10556,13409);
INSERT INTO "django_geo_db_zipcode" VALUES(15393,35026,-6,'Clanton, Alabama 35026',10557,13410);
INSERT INTO "django_geo_db_zipcode" VALUES(15394,35031,-6,'Blountsville, Alabama 35031',10558,13411);
INSERT INTO "django_geo_db_zipcode" VALUES(15395,35032,-6,'Bon Air, Alabama 35032',10559,13412);
INSERT INTO "django_geo_db_zipcode" VALUES(15396,35033,-6,'Bremen, Alabama 35033',10560,13413);
INSERT INTO "django_geo_db_zipcode" VALUES(15397,35034,-6,'Brent, Alabama 35034',10561,13414);
INSERT INTO "django_geo_db_zipcode" VALUES(15398,35035,-6,'Brierfield, Alabama 35035',10562,13415);
INSERT INTO "django_geo_db_zipcode" VALUES(15399,35036,-6,'Brookside, Alabama 35036',10563,13416);
INSERT INTO "django_geo_db_zipcode" VALUES(15400,35038,-6,'Burnwell, Alabama 35038',10564,13417);
INSERT INTO "django_geo_db_zipcode" VALUES(15401,35039,-6,'Brookside, Alabama 35039',10563,13418);
INSERT INTO "django_geo_db_zipcode" VALUES(15402,35040,-6,'Calera, Alabama 35040',10565,13419);
INSERT INTO "django_geo_db_zipcode" VALUES(15403,35041,-6,'Cardiff, Alabama 35041',10566,13420);
INSERT INTO "django_geo_db_zipcode" VALUES(15404,35042,-6,'Centreville, Alabama 35042',10567,13421);
INSERT INTO "django_geo_db_zipcode" VALUES(15405,35043,-6,'Chelsea, Alabama 35043',10568,13422);
INSERT INTO "django_geo_db_zipcode" VALUES(15406,35044,-6,'Childersburg, Alabama 35044',10569,13423);
INSERT INTO "django_geo_db_zipcode" VALUES(15407,35045,-6,'Clanton, Alabama 35045',10557,13424);
INSERT INTO "django_geo_db_zipcode" VALUES(15408,35046,-6,'Clanton, Alabama 35046',10557,13425);
INSERT INTO "django_geo_db_zipcode" VALUES(15409,35048,-6,'Clay, Alabama 35048',10570,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15410,35049,-6,'Cleveland, Alabama 35049',10571,13426);
INSERT INTO "django_geo_db_zipcode" VALUES(15411,35050,-6,'Columbiana, Alabama 35050',10572,13427);
INSERT INTO "django_geo_db_zipcode" VALUES(15412,35051,-6,'Columbiana, Alabama 35051',10572,13428);
INSERT INTO "django_geo_db_zipcode" VALUES(15413,35052,-6,'Cook Springs, Alabama 35052',10573,13429);
INSERT INTO "django_geo_db_zipcode" VALUES(15414,35053,-6,'Crane Hill, Alabama 35053',10574,13430);
INSERT INTO "django_geo_db_zipcode" VALUES(15415,35054,-6,'Cropwell, Alabama 35054',10575,13431);
INSERT INTO "django_geo_db_zipcode" VALUES(15416,35055,-6,'Cullman, Alabama 35055',10576,13432);
INSERT INTO "django_geo_db_zipcode" VALUES(15417,35056,-6,'Cullman, Alabama 35056',10576,13433);
INSERT INTO "django_geo_db_zipcode" VALUES(15418,35057,-6,'Cullman, Alabama 35057',10576,13434);
INSERT INTO "django_geo_db_zipcode" VALUES(15419,35058,-6,'Cullman, Alabama 35058',10576,13435);
INSERT INTO "django_geo_db_zipcode" VALUES(15420,35060,-6,'Docena, Alabama 35060',10577,13436);
INSERT INTO "django_geo_db_zipcode" VALUES(15421,35061,-6,'Dolomite, Alabama 35061',10578,13437);
INSERT INTO "django_geo_db_zipcode" VALUES(15422,35062,-6,'Dora, Alabama 35062',10579,13438);
INSERT INTO "django_geo_db_zipcode" VALUES(15423,35063,-6,'Empire, Alabama 35063',10580,13439);
INSERT INTO "django_geo_db_zipcode" VALUES(15424,35064,-6,'Fairfield, Alabama 35064',10581,13440);
INSERT INTO "django_geo_db_zipcode" VALUES(15425,35068,-6,'Fultondale, Alabama 35068',10582,13441);
INSERT INTO "django_geo_db_zipcode" VALUES(15426,35070,-6,'Garden City, Alabama 35070',10583,13442);
INSERT INTO "django_geo_db_zipcode" VALUES(15427,35071,-6,'Gardendale, Alabama 35071',10584,13443);
INSERT INTO "django_geo_db_zipcode" VALUES(15428,35072,-6,'Goodwater, Alabama 35072',10585,13444);
INSERT INTO "django_geo_db_zipcode" VALUES(15429,35073,-6,'Graysville, Alabama 35073',10586,13445);
INSERT INTO "django_geo_db_zipcode" VALUES(15430,35074,-6,'Green Pond, Alabama 35074',10587,13446);
INSERT INTO "django_geo_db_zipcode" VALUES(15431,35077,-6,'Hanceville, Alabama 35077',10588,13447);
INSERT INTO "django_geo_db_zipcode" VALUES(15432,35078,-6,'Harpersville, Alabama 35078',10589,13448);
INSERT INTO "django_geo_db_zipcode" VALUES(15433,35079,-6,'Hayden, Alabama 35079',10590,13449);
INSERT INTO "django_geo_db_zipcode" VALUES(15434,35080,-6,'Helena, Alabama 35080',10591,13450);
INSERT INTO "django_geo_db_zipcode" VALUES(15435,35082,-6,'Hollins, Alabama 35082',10592,13451);
INSERT INTO "django_geo_db_zipcode" VALUES(15436,35083,-6,'Holly Pond, Alabama 35083',10593,13452);
INSERT INTO "django_geo_db_zipcode" VALUES(15437,35085,-6,'Jemison, Alabama 35085',10594,13453);
INSERT INTO "django_geo_db_zipcode" VALUES(15438,35087,-6,'Joppa, Alabama 35087',10595,13454);
INSERT INTO "django_geo_db_zipcode" VALUES(15439,35089,-6,'Kellyton, Alabama 35089',10596,13455);
INSERT INTO "django_geo_db_zipcode" VALUES(15440,35091,-6,'Kimberly, Alabama 35091',10597,13456);
INSERT INTO "django_geo_db_zipcode" VALUES(15441,35094,-6,'Leeds, Alabama 35094',10598,13457);
INSERT INTO "django_geo_db_zipcode" VALUES(15442,35096,-6,'Lincoln, Alabama 35096',10599,13458);
INSERT INTO "django_geo_db_zipcode" VALUES(15443,35097,-6,'Locust Fork, Alabama 35097',10600,13459);
INSERT INTO "django_geo_db_zipcode" VALUES(15444,35098,-6,'Logan, Alabama 35098',10601,13460);
INSERT INTO "django_geo_db_zipcode" VALUES(15445,35111,-6,'McCalla, Alabama 35111',10602,13461);
INSERT INTO "django_geo_db_zipcode" VALUES(15446,35112,-6,'Margaret, Alabama 35112',10603,13462);
INSERT INTO "django_geo_db_zipcode" VALUES(15447,35114,-6,'Maylene, Alabama 35114',10604,13463);
INSERT INTO "django_geo_db_zipcode" VALUES(15448,35115,-6,'Montevallo, Alabama 35115',10605,13464);
INSERT INTO "django_geo_db_zipcode" VALUES(15449,35116,-6,'Morris, Alabama 35116',10606,13465);
INSERT INTO "django_geo_db_zipcode" VALUES(15450,35117,-6,'Mount Olive, Alabama 35117',10607,13466);
INSERT INTO "django_geo_db_zipcode" VALUES(15451,35118,-6,'Mulga, Alabama 35118',10608,13467);
INSERT INTO "django_geo_db_zipcode" VALUES(15452,35119,-6,'New Castle, Alabama 35119',10609,13468);
INSERT INTO "django_geo_db_zipcode" VALUES(15453,35120,-6,'Odenville, Alabama 35120',10610,13469);
INSERT INTO "django_geo_db_zipcode" VALUES(15454,35121,-6,'Oneonta, Alabama 35121',10611,13470);
INSERT INTO "django_geo_db_zipcode" VALUES(15455,35123,-6,'Palmerdale, Alabama 35123',10612,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15456,35124,-6,'Pelham, Alabama 35124',10613,13471);
INSERT INTO "django_geo_db_zipcode" VALUES(15457,35125,-6,'Pell City, Alabama 35125',10614,13472);
INSERT INTO "django_geo_db_zipcode" VALUES(15458,35126,-6,'Pinson, Alabama 35126',10615,13473);
INSERT INTO "django_geo_db_zipcode" VALUES(15459,35127,-6,'Pleasant Grove, Alabama 35127',10616,13474);
INSERT INTO "django_geo_db_zipcode" VALUES(15460,35128,-6,'Pell City, Alabama 35128',10614,13475);
INSERT INTO "django_geo_db_zipcode" VALUES(15461,35130,-6,'Quinton, Alabama 35130',10617,13476);
INSERT INTO "django_geo_db_zipcode" VALUES(15462,35131,-6,'Ragland, Alabama 35131',10618,13477);
INSERT INTO "django_geo_db_zipcode" VALUES(15463,35133,-6,'Remlap, Alabama 35133',10619,13478);
INSERT INTO "django_geo_db_zipcode" VALUES(15464,35135,-6,'Riverside, Alabama 35135',10620,13479);
INSERT INTO "django_geo_db_zipcode" VALUES(15465,35136,-6,'Rockford, Alabama 35136',10621,13480);
INSERT INTO "django_geo_db_zipcode" VALUES(15466,35137,-6,'Saginaw, Alabama 35137',10622,13481);
INSERT INTO "django_geo_db_zipcode" VALUES(15467,35139,-6,'Sayre, Alabama 35139',10623,13482);
INSERT INTO "django_geo_db_zipcode" VALUES(15468,35142,-6,'Shannon, Alabama 35142',10624,13483);
INSERT INTO "django_geo_db_zipcode" VALUES(15469,35143,-6,'Shelby, Alabama 35143',10625,13484);
INSERT INTO "django_geo_db_zipcode" VALUES(15470,35144,-6,'Siluria, Alabama 35144',10626,13485);
INSERT INTO "django_geo_db_zipcode" VALUES(15471,35146,-6,'Springville, Alabama 35146',10627,13486);
INSERT INTO "django_geo_db_zipcode" VALUES(15472,35147,-6,'Sterrett, Alabama 35147',10628,13487);
INSERT INTO "django_geo_db_zipcode" VALUES(15473,35148,-6,'Sumiton, Alabama 35148',10629,13488);
INSERT INTO "django_geo_db_zipcode" VALUES(15474,35149,-6,'Sycamore, Alabama 35149',10630,13489);
INSERT INTO "django_geo_db_zipcode" VALUES(15475,35150,-6,'Sylacauga, Alabama 35150',10631,13490);
INSERT INTO "django_geo_db_zipcode" VALUES(15476,35151,-6,'Sylacauga, Alabama 35151',10631,13491);
INSERT INTO "django_geo_db_zipcode" VALUES(15477,35160,-6,'Talladega, Alabama 35160',10632,13492);
INSERT INTO "django_geo_db_zipcode" VALUES(15478,35161,-6,'Talladega, Alabama 35161',10632,13493);
INSERT INTO "django_geo_db_zipcode" VALUES(15479,35171,-6,'Thorsby, Alabama 35171',10633,13494);
INSERT INTO "django_geo_db_zipcode" VALUES(15480,35172,-6,'Trafford, Alabama 35172',10634,13495);
INSERT INTO "django_geo_db_zipcode" VALUES(15481,35173,-6,'Trussville, Alabama 35173',10635,13496);
INSERT INTO "django_geo_db_zipcode" VALUES(15482,35175,-6,'Union Grove, Alabama 35175',10636,13497);
INSERT INTO "django_geo_db_zipcode" VALUES(15483,35176,-6,'Vandiver, Alabama 35176',10637,13498);
INSERT INTO "django_geo_db_zipcode" VALUES(15484,35178,-6,'Vincent, Alabama 35178',10638,13499);
INSERT INTO "django_geo_db_zipcode" VALUES(15485,35179,-6,'Vinemont, Alabama 35179',10639,13500);
INSERT INTO "django_geo_db_zipcode" VALUES(15486,35180,-6,'Warrior, Alabama 35180',10640,13501);
INSERT INTO "django_geo_db_zipcode" VALUES(15487,35181,-6,'Watson, Alabama 35181',10641,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15488,35182,-6,'Wattsville, Alabama 35182',10642,13502);
INSERT INTO "django_geo_db_zipcode" VALUES(15489,35183,-6,'Weogufka, Alabama 35183',10643,13503);
INSERT INTO "django_geo_db_zipcode" VALUES(15490,35184,-6,'West Blocton, Alabama 35184',10644,13504);
INSERT INTO "django_geo_db_zipcode" VALUES(15491,35185,-6,'Westover, Alabama 35185',10645,13505);
INSERT INTO "django_geo_db_zipcode" VALUES(15492,35186,-6,'Wilsonville, Alabama 35186',10646,13506);
INSERT INTO "django_geo_db_zipcode" VALUES(15493,35187,-6,'Wilton, Alabama 35187',10647,13507);
INSERT INTO "django_geo_db_zipcode" VALUES(15494,35188,-6,'Woodstock, Alabama 35188',10648,13508);
INSERT INTO "django_geo_db_zipcode" VALUES(15495,35201,-6,'Birmingham, Alabama 35201',10649,13509);
INSERT INTO "django_geo_db_zipcode" VALUES(15496,35202,-6,'Birmingham, Alabama 35202',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15497,35203,-6,'Birmingham, Alabama 35203',10649,13510);
INSERT INTO "django_geo_db_zipcode" VALUES(15498,35204,-6,'Birmingham, Alabama 35204',10649,13511);
INSERT INTO "django_geo_db_zipcode" VALUES(15499,35205,-6,'Birmingham, Alabama 35205',10649,13512);
INSERT INTO "django_geo_db_zipcode" VALUES(15500,35206,-6,'Birmingham, Alabama 35206',10649,13513);
INSERT INTO "django_geo_db_zipcode" VALUES(15501,35207,-6,'Birmingham, Alabama 35207',10649,13514);
INSERT INTO "django_geo_db_zipcode" VALUES(15502,35208,-6,'Birmingham, Alabama 35208',10649,13515);
INSERT INTO "django_geo_db_zipcode" VALUES(15503,35209,-6,'Birmingham, Alabama 35209',10649,13516);
INSERT INTO "django_geo_db_zipcode" VALUES(15504,35210,-6,'Birmingham, Alabama 35210',10649,13517);
INSERT INTO "django_geo_db_zipcode" VALUES(15505,35211,-6,'Birmingham, Alabama 35211',10649,13518);
INSERT INTO "django_geo_db_zipcode" VALUES(15506,35212,-6,'Birmingham, Alabama 35212',10649,13519);
INSERT INTO "django_geo_db_zipcode" VALUES(15507,35213,-6,'Birmingham, Alabama 35213',10649,13520);
INSERT INTO "django_geo_db_zipcode" VALUES(15508,35214,-6,'Birmingham, Alabama 35214',10649,13521);
INSERT INTO "django_geo_db_zipcode" VALUES(15509,35215,-6,'Birmingham, Alabama 35215',10649,13522);
INSERT INTO "django_geo_db_zipcode" VALUES(15510,35216,-6,'Birmingham, Alabama 35216',10649,13523);
INSERT INTO "django_geo_db_zipcode" VALUES(15511,35217,-6,'Birmingham, Alabama 35217',10649,13524);
INSERT INTO "django_geo_db_zipcode" VALUES(15512,35218,-6,'Birmingham, Alabama 35218',10649,13525);
INSERT INTO "django_geo_db_zipcode" VALUES(15513,35219,-6,'Birmingham, Alabama 35219',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15514,35220,-6,'Birmingham, Alabama 35220',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15515,35221,-6,'Birmingham, Alabama 35221',10649,13526);
INSERT INTO "django_geo_db_zipcode" VALUES(15516,35222,-6,'Birmingham, Alabama 35222',10649,13527);
INSERT INTO "django_geo_db_zipcode" VALUES(15517,35223,-6,'Birmingham, Alabama 35223',10649,13528);
INSERT INTO "django_geo_db_zipcode" VALUES(15518,35224,-6,'Birmingham, Alabama 35224',10649,13529);
INSERT INTO "django_geo_db_zipcode" VALUES(15519,35225,-6,'Birmingham, Alabama 35225',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15520,35226,-6,'Birmingham, Alabama 35226',10649,13530);
INSERT INTO "django_geo_db_zipcode" VALUES(15521,35228,-6,'Birmingham, Alabama 35228',10649,13531);
INSERT INTO "django_geo_db_zipcode" VALUES(15522,35229,-6,'Birmingham, Alabama 35229',10649,13532);
INSERT INTO "django_geo_db_zipcode" VALUES(15523,35230,-6,'Birmingham, Alabama 35230',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15524,35231,-6,'Birmingham, Alabama 35231',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15525,35232,-6,'Birmingham, Alabama 35232',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15526,35233,-6,'Birmingham, Alabama 35233',10649,13533);
INSERT INTO "django_geo_db_zipcode" VALUES(15527,35234,-6,'Birmingham, Alabama 35234',10649,13534);
INSERT INTO "django_geo_db_zipcode" VALUES(15528,35235,-6,'Birmingham, Alabama 35235',10649,13535);
INSERT INTO "django_geo_db_zipcode" VALUES(15529,35236,-6,'Birmingham, Alabama 35236',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15530,35237,-6,'Birmingham, Alabama 35237',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15531,35238,-6,'Birmingham, Alabama 35238',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15532,35240,-6,'Birmingham, Alabama 35240',10649,13536);
INSERT INTO "django_geo_db_zipcode" VALUES(15533,35242,-6,'Birmingham, Alabama 35242',10649,13537);
INSERT INTO "django_geo_db_zipcode" VALUES(15534,35243,-6,'Birmingham, Alabama 35243',10649,13538);
INSERT INTO "django_geo_db_zipcode" VALUES(15535,35244,-6,'Birmingham, Alabama 35244',10649,13539);
INSERT INTO "django_geo_db_zipcode" VALUES(15536,35245,-6,'Birmingham, Alabama 35245',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15537,35246,-6,'Birmingham, Alabama 35246',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15538,35249,-6,'Birmingham, Alabama 35249',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15539,35253,-6,'Birmingham, Alabama 35253',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15540,35254,-6,'Birmingham, Alabama 35254',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15541,35255,-6,'Birmingham, Alabama 35255',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15542,35259,-6,'Birmingham, Alabama 35259',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15543,35260,-6,'Birmingham, Alabama 35260',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15544,35261,-6,'Birmingham, Alabama 35261',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15545,35263,-6,'Birmingham, Alabama 35263',10649,13540);
INSERT INTO "django_geo_db_zipcode" VALUES(15546,35266,-6,'Birmingham, Alabama 35266',10649,13541);
INSERT INTO "django_geo_db_zipcode" VALUES(15547,35277,-6,'Birmingham, Alabama 35277',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15548,35278,-6,'Birmingham, Alabama 35278',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15549,35279,-6,'Birmingham, Alabama 35279',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15550,35280,-6,'Birmingham, Alabama 35280',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15551,35281,-6,'Birmingham, Alabama 35281',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15552,35282,-6,'Birmingham, Alabama 35282',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15553,35283,-6,'Birmingham, Alabama 35283',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15554,35285,-6,'Birmingham, Alabama 35285',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15555,35286,-6,'Birmingham, Alabama 35286',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15556,35287,-6,'Birmingham, Alabama 35287',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15557,35288,-6,'Birmingham, Alabama 35288',10649,13542);
INSERT INTO "django_geo_db_zipcode" VALUES(15558,35289,-6,'Birmingham, Alabama 35289',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15559,35290,-6,'Birmingham, Alabama 35290',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15560,35291,-6,'Birmingham, Alabama 35291',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15561,35292,-6,'Birmingham, Alabama 35292',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15562,35293,-6,'Birmingham, Alabama 35293',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15563,35294,-6,'Birmingham, Alabama 35294',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15564,35295,-6,'Birmingham, Alabama 35295',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15565,35296,-6,'Birmingham, Alabama 35296',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15566,35297,-6,'Birmingham, Alabama 35297',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15567,35298,-6,'Birmingham, Alabama 35298',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15568,35299,-6,'Birmingham, Alabama 35299',10649,13404);
INSERT INTO "django_geo_db_zipcode" VALUES(15569,35308,-6,'Dora, Alabama 35308',10579,13543);
INSERT INTO "django_geo_db_zipcode" VALUES(15570,35401,-6,'Tuscaloosa, Alabama 35401',10650,13544);
INSERT INTO "django_geo_db_zipcode" VALUES(15571,35402,-6,'Tuscaloosa, Alabama 35402',10650,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15572,35403,-6,'Tuscaloosa, Alabama 35403',10650,13546);
INSERT INTO "django_geo_db_zipcode" VALUES(15573,35404,-6,'Tuscaloosa, Alabama 35404',10650,13547);
INSERT INTO "django_geo_db_zipcode" VALUES(15574,35405,-6,'Tuscaloosa, Alabama 35405',10650,13548);
INSERT INTO "django_geo_db_zipcode" VALUES(15575,35406,-6,'Tuscaloosa, Alabama 35406',10650,13549);
INSERT INTO "django_geo_db_zipcode" VALUES(15576,35407,-6,'Tuscaloosa, Alabama 35407',10650,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15577,35440,-6,'Abernant, Alabama 35440',10651,13550);
INSERT INTO "django_geo_db_zipcode" VALUES(15578,35441,-6,'Akron, Alabama 35441',10652,13551);
INSERT INTO "django_geo_db_zipcode" VALUES(15579,35442,-6,'Aliceville, Alabama 35442',10653,13552);
INSERT INTO "django_geo_db_zipcode" VALUES(15580,35443,-6,'Boligee, Alabama 35443',10654,13553);
INSERT INTO "django_geo_db_zipcode" VALUES(15581,35444,-6,'Brookwood, Alabama 35444',10655,13554);
INSERT INTO "django_geo_db_zipcode" VALUES(15582,35446,-6,'Buhl, Alabama 35446',10656,13555);
INSERT INTO "django_geo_db_zipcode" VALUES(15583,35447,-6,'Carrollton, Alabama 35447',10657,13556);
INSERT INTO "django_geo_db_zipcode" VALUES(15584,35448,-6,'Clinton, Alabama 35448',10658,13557);
INSERT INTO "django_geo_db_zipcode" VALUES(15585,35449,-6,'Coaling, Alabama 35449',10659,13558);
INSERT INTO "django_geo_db_zipcode" VALUES(15586,35452,-6,'Coker, Alabama 35452',10660,13559);
INSERT INTO "django_geo_db_zipcode" VALUES(15587,35453,-6,'Cottondale, Alabama 35453',10661,13560);
INSERT INTO "django_geo_db_zipcode" VALUES(15588,35456,-6,'Duncanville, Alabama 35456',10662,13561);
INSERT INTO "django_geo_db_zipcode" VALUES(15589,35457,-6,'Echola, Alabama 35457',10663,13562);
INSERT INTO "django_geo_db_zipcode" VALUES(15590,35458,-6,'Elrod, Alabama 35458',10664,13563);
INSERT INTO "django_geo_db_zipcode" VALUES(15591,35459,-6,'Emelle, Alabama 35459',10665,13564);
INSERT INTO "django_geo_db_zipcode" VALUES(15592,35460,-6,'Epes, Alabama 35460',10666,13565);
INSERT INTO "django_geo_db_zipcode" VALUES(15593,35461,-6,'Ethelsville, Alabama 35461',10667,13566);
INSERT INTO "django_geo_db_zipcode" VALUES(15594,35462,-6,'Eutaw, Alabama 35462',10668,13567);
INSERT INTO "django_geo_db_zipcode" VALUES(15595,35463,-6,'Fosters, Alabama 35463',10669,13568);
INSERT INTO "django_geo_db_zipcode" VALUES(15596,35464,-6,'Gainesville, Alabama 35464',10670,13569);
INSERT INTO "django_geo_db_zipcode" VALUES(15597,35466,-6,'Gordo, Alabama 35466',10671,13570);
INSERT INTO "django_geo_db_zipcode" VALUES(15598,35468,-6,'Kellerman, Alabama 35468',10672,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15599,35469,-6,'Knoxville, Alabama 35469',10673,13571);
INSERT INTO "django_geo_db_zipcode" VALUES(15600,35470,-6,'Livingston, Alabama 35470',10674,13572);
INSERT INTO "django_geo_db_zipcode" VALUES(15601,35471,-6,'McShan, Alabama 35471',10675,13573);
INSERT INTO "django_geo_db_zipcode" VALUES(15602,35473,-6,'Northport, Alabama 35473',10676,13574);
INSERT INTO "django_geo_db_zipcode" VALUES(15603,35474,-6,'Moundville, Alabama 35474',10677,13575);
INSERT INTO "django_geo_db_zipcode" VALUES(15604,35475,-6,'Northport, Alabama 35475',10676,13576);
INSERT INTO "django_geo_db_zipcode" VALUES(15605,35476,-6,'Northport, Alabama 35476',10676,13577);
INSERT INTO "django_geo_db_zipcode" VALUES(15606,35477,-6,'Panola, Alabama 35477',10678,13578);
INSERT INTO "django_geo_db_zipcode" VALUES(15607,35478,-6,'Peterson, Alabama 35478',10679,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15608,35480,-6,'Ralph, Alabama 35480',10680,13579);
INSERT INTO "django_geo_db_zipcode" VALUES(15609,35481,-6,'Reform, Alabama 35481',10681,13580);
INSERT INTO "django_geo_db_zipcode" VALUES(15610,35482,-6,'Samantha, Alabama 35482',10682,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15611,35485,-6,'Tuscaloosa, Alabama 35485',10650,13545);
INSERT INTO "django_geo_db_zipcode" VALUES(15612,35486,-6,'Tuscaloosa, Alabama 35486',10650,13581);
INSERT INTO "django_geo_db_zipcode" VALUES(15613,35487,-6,'Tuscaloosa, Alabama 35487',10650,13582);
INSERT INTO "django_geo_db_zipcode" VALUES(15614,35490,-6,'Vance, Alabama 35490',10683,13583);
INSERT INTO "django_geo_db_zipcode" VALUES(15615,35491,-6,'West Greene, Alabama 35491',10684,13557);
INSERT INTO "django_geo_db_zipcode" VALUES(15616,35501,-6,'Jasper, Alabama 35501',10685,13584);
INSERT INTO "django_geo_db_zipcode" VALUES(15617,35502,-6,'Jasper, Alabama 35502',10685,13585);
INSERT INTO "django_geo_db_zipcode" VALUES(15618,35503,-6,'Jasper, Alabama 35503',10685,13586);
INSERT INTO "django_geo_db_zipcode" VALUES(15619,35504,-6,'Jasper, Alabama 35504',10685,13587);
INSERT INTO "django_geo_db_zipcode" VALUES(15620,35540,-6,'Addison, Alabama 35540',10686,13588);
INSERT INTO "django_geo_db_zipcode" VALUES(15621,35541,-6,'Arley, Alabama 35541',10687,13589);
INSERT INTO "django_geo_db_zipcode" VALUES(15622,35542,-6,'Bankston, Alabama 35542',10688,13590);
INSERT INTO "django_geo_db_zipcode" VALUES(15623,35543,-6,'Bear Creek, Alabama 35543',10689,13591);
INSERT INTO "django_geo_db_zipcode" VALUES(15624,35544,-6,'Beaverton, Alabama 35544',10690,13592);
INSERT INTO "django_geo_db_zipcode" VALUES(15625,35545,-6,'Belk, Alabama 35545',10691,13593);
INSERT INTO "django_geo_db_zipcode" VALUES(15626,35546,-6,'Berry, Alabama 35546',10692,13594);
INSERT INTO "django_geo_db_zipcode" VALUES(15627,35548,-6,'Brilliant, Alabama 35548',10693,13595);
INSERT INTO "django_geo_db_zipcode" VALUES(15628,35549,-6,'Carbon Hill, Alabama 35549',10694,13596);
INSERT INTO "django_geo_db_zipcode" VALUES(15629,35550,-6,'Cordova, Alabama 35550',10695,13597);
INSERT INTO "django_geo_db_zipcode" VALUES(15630,35551,-6,'Delmar, Alabama 35551',10696,13598);
INSERT INTO "django_geo_db_zipcode" VALUES(15631,35552,-6,'Detroit, Alabama 35552',10697,13599);
INSERT INTO "django_geo_db_zipcode" VALUES(15632,35553,-6,'Double Springs, Alabama 35553',10698,13600);
INSERT INTO "django_geo_db_zipcode" VALUES(15633,35554,-6,'Eldridge, Alabama 35554',10699,13601);
INSERT INTO "django_geo_db_zipcode" VALUES(15634,35555,-6,'Fayette, Alabama 35555',10700,13602);
INSERT INTO "django_geo_db_zipcode" VALUES(15635,35559,-6,'Glen Allen, Alabama 35559',10701,13603);
INSERT INTO "django_geo_db_zipcode" VALUES(15636,35560,-6,'Goodsprings, Alabama 35560',10702,13604);
INSERT INTO "django_geo_db_zipcode" VALUES(15637,35563,-6,'Guin, Alabama 35563',10703,13605);
INSERT INTO "django_geo_db_zipcode" VALUES(15638,35564,-6,'Hackleburg, Alabama 35564',10704,13606);
INSERT INTO "django_geo_db_zipcode" VALUES(15639,35565,-6,'Haleyville, Alabama 35565',10705,13607);
INSERT INTO "django_geo_db_zipcode" VALUES(15640,35570,-6,'Hamilton, Alabama 35570',10706,13608);
INSERT INTO "django_geo_db_zipcode" VALUES(15641,35571,-6,'Hodges, Alabama 35571',10707,13609);
INSERT INTO "django_geo_db_zipcode" VALUES(15642,35572,-6,'Houston, Alabama 35572',10708,13610);
INSERT INTO "django_geo_db_zipcode" VALUES(15643,35573,-6,'Kansas, Alabama 35573',10709,13611);
INSERT INTO "django_geo_db_zipcode" VALUES(15644,35574,-6,'Kennedy, Alabama 35574',10710,13612);
INSERT INTO "django_geo_db_zipcode" VALUES(15645,35575,-6,'Lynn, Alabama 35575',10711,13613);
INSERT INTO "django_geo_db_zipcode" VALUES(15646,35576,-6,'Millport, Alabama 35576',10712,13614);
INSERT INTO "django_geo_db_zipcode" VALUES(15647,35577,-6,'Natural Bridge, Alabama 35577',10713,13615);
INSERT INTO "django_geo_db_zipcode" VALUES(15648,35578,-6,'Nauvoo, Alabama 35578',10714,13616);
INSERT INTO "django_geo_db_zipcode" VALUES(15649,35579,-6,'Oakman, Alabama 35579',10715,13617);
INSERT INTO "django_geo_db_zipcode" VALUES(15650,35580,-6,'Parrish, Alabama 35580',10716,13618);
INSERT INTO "django_geo_db_zipcode" VALUES(15651,35581,-6,'Phil Campbell, Alabama 35581',10717,13619);
INSERT INTO "django_geo_db_zipcode" VALUES(15652,35582,-6,'Red Bay, Alabama 35582',10718,13620);
INSERT INTO "django_geo_db_zipcode" VALUES(15653,35584,-6,'Sipsey, Alabama 35584',10719,13621);
INSERT INTO "django_geo_db_zipcode" VALUES(15654,35585,-6,'Spruce Pine, Alabama 35585',10720,13622);
INSERT INTO "django_geo_db_zipcode" VALUES(15655,35586,-6,'Sulligent, Alabama 35586',10721,13623);
INSERT INTO "django_geo_db_zipcode" VALUES(15656,35587,-6,'Townley, Alabama 35587',10722,13624);
INSERT INTO "django_geo_db_zipcode" VALUES(15657,35592,-6,'Vernon, Alabama 35592',10723,13625);
INSERT INTO "django_geo_db_zipcode" VALUES(15658,35593,-6,'Vina, Alabama 35593',10724,13626);
INSERT INTO "django_geo_db_zipcode" VALUES(15659,35594,-6,'Winfield, Alabama 35594',10725,13627);
INSERT INTO "django_geo_db_zipcode" VALUES(15660,35601,-6,'Decatur, Alabama 35601',10726,13628);
INSERT INTO "django_geo_db_zipcode" VALUES(15661,35602,-6,'Decatur, Alabama 35602',10726,13629);
INSERT INTO "django_geo_db_zipcode" VALUES(15662,35603,-6,'Decatur, Alabama 35603',10726,13630);
INSERT INTO "django_geo_db_zipcode" VALUES(15663,35609,-6,'Decatur, Alabama 35609',10726,13631);
INSERT INTO "django_geo_db_zipcode" VALUES(15664,35610,-6,'Anderson, Alabama 35610',10727,13632);
INSERT INTO "django_geo_db_zipcode" VALUES(15665,35611,-6,'Athens, Alabama 35611',10728,13633);
INSERT INTO "django_geo_db_zipcode" VALUES(15666,35612,-6,'Athens, Alabama 35612',10728,13634);
INSERT INTO "django_geo_db_zipcode" VALUES(15667,35613,-6,'Athens, Alabama 35613',10728,13635);
INSERT INTO "django_geo_db_zipcode" VALUES(15668,35614,-6,'Athens, Alabama 35614',10728,13636);
INSERT INTO "django_geo_db_zipcode" VALUES(15669,35615,-6,'Belle Mina, Alabama 35615',10729,13634);
INSERT INTO "django_geo_db_zipcode" VALUES(15670,35616,-6,'Cherokee, Alabama 35616',10730,13637);
INSERT INTO "django_geo_db_zipcode" VALUES(15671,35617,-6,'Cloverdale, Alabama 35617',10731,13638);
INSERT INTO "django_geo_db_zipcode" VALUES(15672,35618,-6,'Courtland, Alabama 35618',10732,13639);
INSERT INTO "django_geo_db_zipcode" VALUES(15673,35619,-6,'Danville, Alabama 35619',10733,13640);
INSERT INTO "django_geo_db_zipcode" VALUES(15674,35620,-6,'Elkmont, Alabama 35620',10734,13641);
INSERT INTO "django_geo_db_zipcode" VALUES(15675,35621,-6,'Eva, Alabama 35621',10735,13642);
INSERT INTO "django_geo_db_zipcode" VALUES(15676,35622,-6,'Falkville, Alabama 35622',10736,13643);
INSERT INTO "django_geo_db_zipcode" VALUES(15677,35630,-6,'Florence, Alabama 35630',10737,13644);
INSERT INTO "django_geo_db_zipcode" VALUES(15678,35631,-6,'Florence, Alabama 35631',10737,13638);
INSERT INTO "django_geo_db_zipcode" VALUES(15679,35632,-6,'Florence, Alabama 35632',10737,13638);
INSERT INTO "django_geo_db_zipcode" VALUES(15680,35633,-6,'Florence, Alabama 35633',10737,13645);
INSERT INTO "django_geo_db_zipcode" VALUES(15681,35634,-6,'Florence, Alabama 35634',10737,13646);
INSERT INTO "django_geo_db_zipcode" VALUES(15682,35640,-6,'Hartselle, Alabama 35640',10738,13647);
INSERT INTO "django_geo_db_zipcode" VALUES(15683,35643,-6,'Hillsboro, Alabama 35643',10739,13648);
INSERT INTO "django_geo_db_zipcode" VALUES(15684,35645,-6,'Killen, Alabama 35645',10740,13649);
INSERT INTO "django_geo_db_zipcode" VALUES(15685,35646,-6,'Leighton, Alabama 35646',10741,13650);
INSERT INTO "django_geo_db_zipcode" VALUES(15686,35647,-6,'Lester, Alabama 35647',10742,13651);
INSERT INTO "django_geo_db_zipcode" VALUES(15687,35648,-6,'Lexington, Alabama 35648',10743,13652);
INSERT INTO "django_geo_db_zipcode" VALUES(15688,35649,-6,'Mooresville, Alabama 35649',10744,13653);
INSERT INTO "django_geo_db_zipcode" VALUES(15689,35650,-6,'Moulton, Alabama 35650',10745,13654);
INSERT INTO "django_geo_db_zipcode" VALUES(15690,35651,-6,'Mount Hope, Alabama 35651',10746,13655);
INSERT INTO "django_geo_db_zipcode" VALUES(15691,35652,-6,'Rogersville, Alabama 35652',10747,13656);
INSERT INTO "django_geo_db_zipcode" VALUES(15692,35653,-6,'Russellville, Alabama 35653',10748,13657);
INSERT INTO "django_geo_db_zipcode" VALUES(15693,35654,-6,'Russellville, Alabama 35654',10748,13658);
INSERT INTO "django_geo_db_zipcode" VALUES(15694,35659,-6,'Russellville, Alabama 35659',10748,13659);
INSERT INTO "django_geo_db_zipcode" VALUES(15695,35660,-6,'Sheffield, Alabama 35660',10749,13660);
INSERT INTO "django_geo_db_zipcode" VALUES(15696,35661,-6,'Muscle Shoals, Alabama 35661',10750,13661);
INSERT INTO "django_geo_db_zipcode" VALUES(15697,35662,-6,'Muscle Shoals, Alabama 35662',10750,13662);
INSERT INTO "django_geo_db_zipcode" VALUES(15698,35670,-6,'Somerville, Alabama 35670',10751,13663);
INSERT INTO "django_geo_db_zipcode" VALUES(15699,35671,-6,'Tanner, Alabama 35671',10752,13664);
INSERT INTO "django_geo_db_zipcode" VALUES(15700,35672,-6,'Town Creek, Alabama 35672',10753,13665);
INSERT INTO "django_geo_db_zipcode" VALUES(15701,35673,-6,'Trinity, Alabama 35673',10754,13666);
INSERT INTO "django_geo_db_zipcode" VALUES(15702,35674,-6,'Tuscumbia, Alabama 35674',10755,13667);
INSERT INTO "django_geo_db_zipcode" VALUES(15703,35677,-6,'Waterloo, Alabama 35677',10756,13668);
INSERT INTO "django_geo_db_zipcode" VALUES(15704,35699,-6,'Decatur, Alabama 35699',10726,13631);
INSERT INTO "django_geo_db_zipcode" VALUES(15705,35703,-6,'Cardiff, Alabama 35703',10566,13420);
INSERT INTO "django_geo_db_zipcode" VALUES(15706,35715,-6,'Montevallo, Alabama 35715',10605,13669);
INSERT INTO "django_geo_db_zipcode" VALUES(15707,35739,-6,'Ardmore, Alabama 35739',10757,13670);
INSERT INTO "django_geo_db_zipcode" VALUES(15708,35740,-6,'Bridgeport, Alabama 35740',10758,13671);
INSERT INTO "django_geo_db_zipcode" VALUES(15709,35741,-6,'Brownsboro, Alabama 35741',10759,13672);
INSERT INTO "django_geo_db_zipcode" VALUES(15710,35742,-6,'Capshaw, Alabama 35742',10760,13673);
INSERT INTO "django_geo_db_zipcode" VALUES(15711,35744,-6,'Dutton, Alabama 35744',10761,13674);
INSERT INTO "django_geo_db_zipcode" VALUES(15712,35745,-6,'Estillfork, Alabama 35745',10762,13675);
INSERT INTO "django_geo_db_zipcode" VALUES(15713,35746,-6,'Fackler, Alabama 35746',10763,13676);
INSERT INTO "django_geo_db_zipcode" VALUES(15714,35747,-6,'Grant, Alabama 35747',10764,13677);
INSERT INTO "django_geo_db_zipcode" VALUES(15715,35748,-6,'Gurley, Alabama 35748',10765,13678);
INSERT INTO "django_geo_db_zipcode" VALUES(15716,35749,-6,'Harvest, Alabama 35749',10766,13679);
INSERT INTO "django_geo_db_zipcode" VALUES(15717,35750,-6,'Hazel Green, Alabama 35750',10767,13680);
INSERT INTO "django_geo_db_zipcode" VALUES(15718,35751,-6,'Hollytree, Alabama 35751',10768,13681);
INSERT INTO "django_geo_db_zipcode" VALUES(15719,35752,-6,'Hollywood, Alabama 35752',10769,13682);
INSERT INTO "django_geo_db_zipcode" VALUES(15720,35754,-6,'Laceys Spring, Alabama 35754',10770,13683);
INSERT INTO "django_geo_db_zipcode" VALUES(15721,35755,-6,'Langston, Alabama 35755',10771,13684);
INSERT INTO "django_geo_db_zipcode" VALUES(15722,35756,-6,'Madison, Alabama 35756',10772,13685);
INSERT INTO "django_geo_db_zipcode" VALUES(15723,35757,-6,'Madison, Alabama 35757',10772,13686);
INSERT INTO "django_geo_db_zipcode" VALUES(15724,35758,-6,'Madison, Alabama 35758',10772,13687);
INSERT INTO "django_geo_db_zipcode" VALUES(15725,35759,-6,'Meridianville, Alabama 35759',10773,13688);
INSERT INTO "django_geo_db_zipcode" VALUES(15726,35760,-6,'New Hope, Alabama 35760',10774,13689);
INSERT INTO "django_geo_db_zipcode" VALUES(15727,35761,-6,'New Market, Alabama 35761',10775,13690);
INSERT INTO "django_geo_db_zipcode" VALUES(15728,35762,-6,'Normal, Alabama 35762',10776,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15729,35763,-6,'Owens Cross Roads, Alabama 35763',10777,13692);
INSERT INTO "django_geo_db_zipcode" VALUES(15730,35764,-6,'Paint Rock, Alabama 35764',10778,13693);
INSERT INTO "django_geo_db_zipcode" VALUES(15731,35765,-6,'Pisgah, Alabama 35765',10779,13694);
INSERT INTO "django_geo_db_zipcode" VALUES(15732,35766,-6,'Princeton, Alabama 35766',10780,13695);
INSERT INTO "django_geo_db_zipcode" VALUES(15733,35767,-6,'Ryland, Alabama 35767',10781,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15734,35768,-6,'Scottsboro, Alabama 35768',10782,13696);
INSERT INTO "django_geo_db_zipcode" VALUES(15735,35769,-6,'Scottsboro, Alabama 35769',10782,13697);
INSERT INTO "django_geo_db_zipcode" VALUES(15736,35771,-6,'Section, Alabama 35771',10783,13698);
INSERT INTO "django_geo_db_zipcode" VALUES(15737,35772,-6,'Stevenson, Alabama 35772',10784,13699);
INSERT INTO "django_geo_db_zipcode" VALUES(15738,35773,-6,'Toney, Alabama 35773',10785,13700);
INSERT INTO "django_geo_db_zipcode" VALUES(15739,35774,-6,'Trenton, Alabama 35774',10786,13701);
INSERT INTO "django_geo_db_zipcode" VALUES(15740,35775,-6,'Valhermoso Springs, Alabama 35775',10787,13702);
INSERT INTO "django_geo_db_zipcode" VALUES(15741,35776,-6,'Woodville, Alabama 35776',10788,13703);
INSERT INTO "django_geo_db_zipcode" VALUES(15742,35801,-6,'Huntsville, Alabama 35801',10789,13704);
INSERT INTO "django_geo_db_zipcode" VALUES(15743,35802,-6,'Huntsville, Alabama 35802',10789,13705);
INSERT INTO "django_geo_db_zipcode" VALUES(15744,35803,-6,'Huntsville, Alabama 35803',10789,13706);
INSERT INTO "django_geo_db_zipcode" VALUES(15745,35804,-6,'Huntsville, Alabama 35804',10789,13707);
INSERT INTO "django_geo_db_zipcode" VALUES(15746,35805,-6,'Huntsville, Alabama 35805',10789,13708);
INSERT INTO "django_geo_db_zipcode" VALUES(15747,35806,-6,'Huntsville, Alabama 35806',10789,13709);
INSERT INTO "django_geo_db_zipcode" VALUES(15748,35807,-6,'Huntsville, Alabama 35807',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15749,35808,-6,'Huntsville, Alabama 35808',10789,13710);
INSERT INTO "django_geo_db_zipcode" VALUES(15750,35809,-6,'Huntsville, Alabama 35809',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15751,35810,-6,'Huntsville, Alabama 35810',10789,13711);
INSERT INTO "django_geo_db_zipcode" VALUES(15752,35811,-6,'Huntsville, Alabama 35811',10789,13712);
INSERT INTO "django_geo_db_zipcode" VALUES(15753,35812,-6,'Huntsville, Alabama 35812',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15754,35813,-6,'Huntsville, Alabama 35813',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15755,35814,-6,'Huntsville, Alabama 35814',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15756,35815,-6,'Huntsville, Alabama 35815',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15757,35816,-6,'Huntsville, Alabama 35816',10789,13713);
INSERT INTO "django_geo_db_zipcode" VALUES(15758,35824,-6,'Huntsville, Alabama 35824',10789,13714);
INSERT INTO "django_geo_db_zipcode" VALUES(15759,35893,-6,'Huntsville, Alabama 35893',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15760,35894,-6,'Huntsville, Alabama 35894',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15761,35895,-6,'Huntsville, Alabama 35895',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15762,35896,-6,'Huntsville, Alabama 35896',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15763,35897,-6,'Huntsville, Alabama 35897',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15764,35898,-6,'Huntsville, Alabama 35898',10789,13691);
INSERT INTO "django_geo_db_zipcode" VALUES(15765,35899,-6,'Huntsville, Alabama 35899',10789,13715);
INSERT INTO "django_geo_db_zipcode" VALUES(15766,35901,-6,'Gadsden, Alabama 35901',10790,13716);
INSERT INTO "django_geo_db_zipcode" VALUES(15767,35902,-6,'Gadsden, Alabama 35902',10790,13717);
INSERT INTO "django_geo_db_zipcode" VALUES(15768,35903,-6,'Gadsden, Alabama 35903',10790,13718);
INSERT INTO "django_geo_db_zipcode" VALUES(15769,35904,-6,'Gadsden, Alabama 35904',10790,13719);
INSERT INTO "django_geo_db_zipcode" VALUES(15770,35905,-6,'Gadsden, Alabama 35905',10790,13720);
INSERT INTO "django_geo_db_zipcode" VALUES(15771,35906,-6,'Rainbow City, Alabama 35906',10791,13721);
INSERT INTO "django_geo_db_zipcode" VALUES(15772,35907,-6,'Gadsden, Alabama 35907',10790,13722);
INSERT INTO "django_geo_db_zipcode" VALUES(15773,35950,-6,'Albertville, Alabama 35950',10792,13723);
INSERT INTO "django_geo_db_zipcode" VALUES(15774,35951,-6,'Albertville, Alabama 35951',10792,13724);
INSERT INTO "django_geo_db_zipcode" VALUES(15775,35952,-6,'Altoona, Alabama 35952',10793,13725);
INSERT INTO "django_geo_db_zipcode" VALUES(15776,35953,-6,'Ashville, Alabama 35953',10794,13726);
INSERT INTO "django_geo_db_zipcode" VALUES(15777,35954,-6,'Attalla, Alabama 35954',10795,13727);
INSERT INTO "django_geo_db_zipcode" VALUES(15778,35956,-6,'Boaz, Alabama 35956',10796,13728);
INSERT INTO "django_geo_db_zipcode" VALUES(15779,35957,-6,'Boaz, Alabama 35957',10796,13729);
INSERT INTO "django_geo_db_zipcode" VALUES(15780,35958,-6,'Bryant, Alabama 35958',10797,13730);
INSERT INTO "django_geo_db_zipcode" VALUES(15781,35959,-6,'Cedar Bluff, Alabama 35959',10798,13731);
INSERT INTO "django_geo_db_zipcode" VALUES(15782,35960,-6,'Centre, Alabama 35960',10799,13732);
INSERT INTO "django_geo_db_zipcode" VALUES(15783,35961,-6,'Collinsville, Alabama 35961',10800,13733);
INSERT INTO "django_geo_db_zipcode" VALUES(15784,35962,-6,'Crossville, Alabama 35962',10801,13734);
INSERT INTO "django_geo_db_zipcode" VALUES(15785,35963,-6,'Dawson, Alabama 35963',10802,13735);
INSERT INTO "django_geo_db_zipcode" VALUES(15786,35964,-6,'Douglas, Alabama 35964',10803,13736);
INSERT INTO "django_geo_db_zipcode" VALUES(15787,35966,-6,'Flat Rock, Alabama 35966',10804,13737);
INSERT INTO "django_geo_db_zipcode" VALUES(15788,35967,-6,'Fort Payne, Alabama 35967',10805,13738);
INSERT INTO "django_geo_db_zipcode" VALUES(15789,35968,-6,'Fort Payne, Alabama 35968',10805,13739);
INSERT INTO "django_geo_db_zipcode" VALUES(15790,35969,-6,'Fort Payne, Alabama 35969',10805,13740);
INSERT INTO "django_geo_db_zipcode" VALUES(15791,35971,-6,'Fyffe, Alabama 35971',10806,13741);
INSERT INTO "django_geo_db_zipcode" VALUES(15792,35972,-6,'Gallant, Alabama 35972',10807,13742);
INSERT INTO "django_geo_db_zipcode" VALUES(15793,35973,-6,'Gaylesville, Alabama 35973',10808,13743);
INSERT INTO "django_geo_db_zipcode" VALUES(15794,35974,-6,'Geraldine, Alabama 35974',10809,13744);
INSERT INTO "django_geo_db_zipcode" VALUES(15795,35975,-6,'Groveoak, Alabama 35975',10810,13745);
INSERT INTO "django_geo_db_zipcode" VALUES(15796,35976,-6,'Guntersville, Alabama 35976',10811,13746);
INSERT INTO "django_geo_db_zipcode" VALUES(15797,35978,-6,'Henagar, Alabama 35978',10812,13747);
INSERT INTO "django_geo_db_zipcode" VALUES(15798,35979,-6,'Higdon, Alabama 35979',10813,13748);
INSERT INTO "django_geo_db_zipcode" VALUES(15799,35980,-6,'Horton, Alabama 35980',10814,13749);
INSERT INTO "django_geo_db_zipcode" VALUES(15800,35981,-6,'Ider, Alabama 35981',10815,13750);
INSERT INTO "django_geo_db_zipcode" VALUES(15801,35983,-6,'Leesburg, Alabama 35983',10816,13751);
INSERT INTO "django_geo_db_zipcode" VALUES(15802,35984,-6,'Mentone, Alabama 35984',10817,13752);
INSERT INTO "django_geo_db_zipcode" VALUES(15803,35986,-6,'Rainsville, Alabama 35986',10818,13753);
INSERT INTO "django_geo_db_zipcode" VALUES(15804,35987,-6,'Steele, Alabama 35987',10819,13754);
INSERT INTO "django_geo_db_zipcode" VALUES(15805,35988,-6,'Sylvania, Alabama 35988',10820,13755);
INSERT INTO "django_geo_db_zipcode" VALUES(15806,35989,-6,'Valley Head, Alabama 35989',10821,13756);
INSERT INTO "django_geo_db_zipcode" VALUES(15807,35990,-6,'Walnut Grove, Alabama 35990',10822,13757);
INSERT INTO "django_geo_db_zipcode" VALUES(15808,36003,-6,'Autaugaville, Alabama 36003',10823,13758);
INSERT INTO "django_geo_db_zipcode" VALUES(15809,36005,-6,'Banks, Alabama 36005',10824,13759);
INSERT INTO "django_geo_db_zipcode" VALUES(15810,36006,-6,'Billingsley, Alabama 36006',10825,13760);
INSERT INTO "django_geo_db_zipcode" VALUES(15811,36008,-6,'Booth, Alabama 36008',10826,13761);
INSERT INTO "django_geo_db_zipcode" VALUES(15812,36009,-6,'Brantley, Alabama 36009',10827,13762);
INSERT INTO "django_geo_db_zipcode" VALUES(15813,36010,-6,'Brundidge, Alabama 36010',10828,13763);
INSERT INTO "django_geo_db_zipcode" VALUES(15814,36013,-6,'Cecil, Alabama 36013',10829,13764);
INSERT INTO "django_geo_db_zipcode" VALUES(15815,36015,-6,'Chapman, Alabama 36015',10830,13765);
INSERT INTO "django_geo_db_zipcode" VALUES(15816,36016,-6,'Clayton, Alabama 36016',10831,13766);
INSERT INTO "django_geo_db_zipcode" VALUES(15817,36017,-6,'Clio, Alabama 36017',10832,13767);
INSERT INTO "django_geo_db_zipcode" VALUES(15818,36020,-6,'Coosada, Alabama 36020',10833,13768);
INSERT INTO "django_geo_db_zipcode" VALUES(15819,36022,-6,'Deatsville, Alabama 36022',10834,13769);
INSERT INTO "django_geo_db_zipcode" VALUES(15820,36023,-6,'East Tallassee, Alabama 36023',10835,13770);
INSERT INTO "django_geo_db_zipcode" VALUES(15821,36024,-6,'Eclectic, Alabama 36024',10836,13771);
INSERT INTO "django_geo_db_zipcode" VALUES(15822,36025,-6,'Elmore, Alabama 36025',10837,13772);
INSERT INTO "django_geo_db_zipcode" VALUES(15823,36026,-6,'Equality, Alabama 36026',10838,13773);
INSERT INTO "django_geo_db_zipcode" VALUES(15824,36027,-6,'Eufaula, Alabama 36027',10839,13774);
INSERT INTO "django_geo_db_zipcode" VALUES(15825,36028,-6,'Dozier, Alabama 36028',10840,13775);
INSERT INTO "django_geo_db_zipcode" VALUES(15826,36029,-6,'Fitzpatrick, Alabama 36029',10841,13776);
INSERT INTO "django_geo_db_zipcode" VALUES(15827,36030,-6,'Forest Home, Alabama 36030',10842,13777);
INSERT INTO "django_geo_db_zipcode" VALUES(15828,36031,-6,'Fort Davis, Alabama 36031',10843,13778);
INSERT INTO "django_geo_db_zipcode" VALUES(15829,36032,-6,'Fort Deposit, Alabama 36032',10844,13779);
INSERT INTO "django_geo_db_zipcode" VALUES(15830,36033,-6,'Georgiana, Alabama 36033',10845,13780);
INSERT INTO "django_geo_db_zipcode" VALUES(15831,36034,-6,'Glenwood, Alabama 36034',10846,13781);
INSERT INTO "django_geo_db_zipcode" VALUES(15832,36035,-6,'Goshen, Alabama 36035',10847,13782);
INSERT INTO "django_geo_db_zipcode" VALUES(15833,36036,-6,'Grady, Alabama 36036',10848,13783);
INSERT INTO "django_geo_db_zipcode" VALUES(15834,36037,-6,'Greenville, Alabama 36037',10849,13784);
INSERT INTO "django_geo_db_zipcode" VALUES(15835,36038,-6,'Gantt, Alabama 36038',10850,13785);
INSERT INTO "django_geo_db_zipcode" VALUES(15836,36039,-6,'Hardaway, Alabama 36039',10851,13786);
INSERT INTO "django_geo_db_zipcode" VALUES(15837,36040,-6,'Hayneville, Alabama 36040',10852,13787);
INSERT INTO "django_geo_db_zipcode" VALUES(15838,36041,-6,'Highland Home, Alabama 36041',10853,13788);
INSERT INTO "django_geo_db_zipcode" VALUES(15839,36042,-6,'Honoraville, Alabama 36042',10854,13789);
INSERT INTO "django_geo_db_zipcode" VALUES(15840,36043,-6,'Hope Hull, Alabama 36043',10855,13790);
INSERT INTO "django_geo_db_zipcode" VALUES(15841,36045,-6,'Kent, Alabama 36045',10856,13791);
INSERT INTO "django_geo_db_zipcode" VALUES(15842,36046,-6,'Lapine, Alabama 36046',10857,13792);
INSERT INTO "django_geo_db_zipcode" VALUES(15843,36047,-6,'Letohatchee, Alabama 36047',10858,13793);
INSERT INTO "django_geo_db_zipcode" VALUES(15844,36048,-6,'Louisville, Alabama 36048',10859,13794);
INSERT INTO "django_geo_db_zipcode" VALUES(15845,36049,-6,'Luverne, Alabama 36049',10860,13795);
INSERT INTO "django_geo_db_zipcode" VALUES(15846,36051,-6,'Marbury, Alabama 36051',10861,13796);
INSERT INTO "django_geo_db_zipcode" VALUES(15847,36052,-6,'Mathews, Alabama 36052',10862,13797);
INSERT INTO "django_geo_db_zipcode" VALUES(15848,36053,-6,'Midway, Alabama 36053',10863,13798);
INSERT INTO "django_geo_db_zipcode" VALUES(15849,36054,-6,'Millbrook, Alabama 36054',10864,13799);
INSERT INTO "django_geo_db_zipcode" VALUES(15850,36057,-6,'Mount Meigs, Alabama 36057',10865,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15851,36061,-6,'Perote, Alabama 36061',10866,13801);
INSERT INTO "django_geo_db_zipcode" VALUES(15852,36062,-6,'Petrey, Alabama 36062',10867,13802);
INSERT INTO "django_geo_db_zipcode" VALUES(15853,36064,-6,'Pike Road, Alabama 36064',10868,13803);
INSERT INTO "django_geo_db_zipcode" VALUES(15854,36065,-6,'Pine Level, Alabama 36065',10869,13804);
INSERT INTO "django_geo_db_zipcode" VALUES(15855,36066,-6,'Prattville, Alabama 36066',10870,13805);
INSERT INTO "django_geo_db_zipcode" VALUES(15856,36067,-6,'Prattville, Alabama 36067',10870,13806);
INSERT INTO "django_geo_db_zipcode" VALUES(15857,36068,-6,'Prattville, Alabama 36068',10870,13807);
INSERT INTO "django_geo_db_zipcode" VALUES(15858,36069,-6,'Ramer, Alabama 36069',10871,13808);
INSERT INTO "django_geo_db_zipcode" VALUES(15859,36071,-6,'Rutledge, Alabama 36071',10872,13809);
INSERT INTO "django_geo_db_zipcode" VALUES(15860,36072,-6,'Eufaula, Alabama 36072',10839,13810);
INSERT INTO "django_geo_db_zipcode" VALUES(15861,36075,-6,'Shorter, Alabama 36075',10873,13811);
INSERT INTO "django_geo_db_zipcode" VALUES(15862,36078,-6,'Tallassee, Alabama 36078',10874,13812);
INSERT INTO "django_geo_db_zipcode" VALUES(15863,36079,-6,'Troy, Alabama 36079',10875,13813);
INSERT INTO "django_geo_db_zipcode" VALUES(15864,36080,-6,'Titus, Alabama 36080',10876,13814);
INSERT INTO "django_geo_db_zipcode" VALUES(15865,36081,-6,'Troy, Alabama 36081',10875,13815);
INSERT INTO "django_geo_db_zipcode" VALUES(15866,36082,-6,'Troy, Alabama 36082',10875,13816);
INSERT INTO "django_geo_db_zipcode" VALUES(15867,36083,-6,'Tuskegee, Alabama 36083',10877,13817);
INSERT INTO "django_geo_db_zipcode" VALUES(15868,36087,-6,'Tuskegee Institute, Alabama 36087',10878,13818);
INSERT INTO "django_geo_db_zipcode" VALUES(15869,36088,-6,'Tuskegee Institute, Alabama 36088',10878,13819);
INSERT INTO "django_geo_db_zipcode" VALUES(15870,36089,-6,'Union Springs, Alabama 36089',10879,13820);
INSERT INTO "django_geo_db_zipcode" VALUES(15871,36091,-6,'Verbena, Alabama 36091',10880,13821);
INSERT INTO "django_geo_db_zipcode" VALUES(15872,36092,-6,'Wetumpka, Alabama 36092',10881,13822);
INSERT INTO "django_geo_db_zipcode" VALUES(15873,36093,-6,'Wetumpka, Alabama 36093',10881,13823);
INSERT INTO "django_geo_db_zipcode" VALUES(15874,36101,-6,'Montgomery, Alabama 36101',10882,13824);
INSERT INTO "django_geo_db_zipcode" VALUES(15875,36102,-6,'Montgomery, Alabama 36102',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15876,36103,-6,'Montgomery, Alabama 36103',10882,13825);
INSERT INTO "django_geo_db_zipcode" VALUES(15877,36104,-6,'Montgomery, Alabama 36104',10882,13826);
INSERT INTO "django_geo_db_zipcode" VALUES(15878,36105,-6,'Montgomery, Alabama 36105',10882,13827);
INSERT INTO "django_geo_db_zipcode" VALUES(15879,36106,-6,'Montgomery, Alabama 36106',10882,13828);
INSERT INTO "django_geo_db_zipcode" VALUES(15880,36107,-6,'Montgomery, Alabama 36107',10882,13829);
INSERT INTO "django_geo_db_zipcode" VALUES(15881,36108,-6,'Montgomery, Alabama 36108',10882,13830);
INSERT INTO "django_geo_db_zipcode" VALUES(15882,36109,-6,'Montgomery, Alabama 36109',10882,13831);
INSERT INTO "django_geo_db_zipcode" VALUES(15883,36110,-6,'Montgomery, Alabama 36110',10882,13832);
INSERT INTO "django_geo_db_zipcode" VALUES(15884,36111,-6,'Montgomery, Alabama 36111',10882,13833);
INSERT INTO "django_geo_db_zipcode" VALUES(15885,36112,-6,'Montgomery, Alabama 36112',10882,13834);
INSERT INTO "django_geo_db_zipcode" VALUES(15886,36113,-6,'Montgomery, Alabama 36113',10882,13835);
INSERT INTO "django_geo_db_zipcode" VALUES(15887,36114,-6,'Montgomery, Alabama 36114',10882,13836);
INSERT INTO "django_geo_db_zipcode" VALUES(15888,36115,-6,'Montgomery, Alabama 36115',10882,13837);
INSERT INTO "django_geo_db_zipcode" VALUES(15889,36116,-6,'Montgomery, Alabama 36116',10882,13838);
INSERT INTO "django_geo_db_zipcode" VALUES(15890,36117,-6,'Montgomery, Alabama 36117',10882,13839);
INSERT INTO "django_geo_db_zipcode" VALUES(15891,36118,-6,'Montgomery, Alabama 36118',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15892,36119,-6,'Montgomery, Alabama 36119',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15893,36120,-6,'Montgomery, Alabama 36120',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15894,36121,-6,'Montgomery, Alabama 36121',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15895,36123,-6,'Montgomery, Alabama 36123',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15896,36124,-6,'Montgomery, Alabama 36124',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15897,36125,-6,'Montgomery, Alabama 36125',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15898,36130,-6,'Montgomery, Alabama 36130',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15899,36131,-6,'Montgomery, Alabama 36131',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15900,36132,-6,'Montgomery, Alabama 36132',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15901,36133,-6,'Montgomery, Alabama 36133',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15902,36134,-6,'Montgomery, Alabama 36134',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15903,36135,-6,'Montgomery, Alabama 36135',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15904,36140,-6,'Montgomery, Alabama 36140',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15905,36141,-6,'Montgomery, Alabama 36141',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15906,36142,-6,'Montgomery, Alabama 36142',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15907,36177,-6,'Montgomery, Alabama 36177',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15908,36191,-6,'Montgomery, Alabama 36191',10882,13800);
INSERT INTO "django_geo_db_zipcode" VALUES(15909,36201,-6,'Anniston, Alabama 36201',10883,13840);
INSERT INTO "django_geo_db_zipcode" VALUES(15910,36202,-6,'Anniston, Alabama 36202',10883,13841);
INSERT INTO "django_geo_db_zipcode" VALUES(15911,36203,-6,'Anniston, Alabama 36203',10883,13842);
INSERT INTO "django_geo_db_zipcode" VALUES(15912,36204,-6,'Anniston, Alabama 36204',10883,13841);
INSERT INTO "django_geo_db_zipcode" VALUES(15913,36205,-6,'Anniston, Alabama 36205',10883,13843);
INSERT INTO "django_geo_db_zipcode" VALUES(15914,36206,-6,'Anniston, Alabama 36206',10883,13844);
INSERT INTO "django_geo_db_zipcode" VALUES(15915,36207,-6,'Anniston, Alabama 36207',10883,13845);
INSERT INTO "django_geo_db_zipcode" VALUES(15916,36250,-6,'Alexandria, Alabama 36250',10884,13846);
INSERT INTO "django_geo_db_zipcode" VALUES(15917,36251,-6,'Ashland, Alabama 36251',10885,13847);
INSERT INTO "django_geo_db_zipcode" VALUES(15918,36253,-6,'Bynum, Alabama 36253',10886,13841);
INSERT INTO "django_geo_db_zipcode" VALUES(15919,36254,-6,'Choccolocco, Alabama 36254',10887,13848);
INSERT INTO "django_geo_db_zipcode" VALUES(15920,36255,-6,'Cragford, Alabama 36255',10888,13849);
INSERT INTO "django_geo_db_zipcode" VALUES(15921,36256,-6,'Daviston, Alabama 36256',10889,13850);
INSERT INTO "django_geo_db_zipcode" VALUES(15922,36257,-6,'De Armanville, Alabama 36257',10890,13841);
INSERT INTO "django_geo_db_zipcode" VALUES(15923,36258,-6,'Delta, Alabama 36258',10891,13851);
INSERT INTO "django_geo_db_zipcode" VALUES(15924,36260,-6,'Eastaboga, Alabama 36260',10892,13852);
INSERT INTO "django_geo_db_zipcode" VALUES(15925,36261,-6,'Edwardsville, Alabama 36261',10893,13853);
INSERT INTO "django_geo_db_zipcode" VALUES(15926,36262,-6,'Fruithurst, Alabama 36262',10894,13854);
INSERT INTO "django_geo_db_zipcode" VALUES(15927,36263,-6,'Graham, Alabama 36263',10895,13855);
INSERT INTO "django_geo_db_zipcode" VALUES(15928,36264,-6,'Heflin, Alabama 36264',10896,13856);
INSERT INTO "django_geo_db_zipcode" VALUES(15929,36265,-6,'Jacksonville, Alabama 36265',10897,13857);
INSERT INTO "django_geo_db_zipcode" VALUES(15930,36266,-6,'Lineville, Alabama 36266',10898,13858);
INSERT INTO "django_geo_db_zipcode" VALUES(15931,36267,-6,'Millerville, Alabama 36267',10899,13859);
INSERT INTO "django_geo_db_zipcode" VALUES(15932,36268,-6,'Munford, Alabama 36268',10900,13860);
INSERT INTO "django_geo_db_zipcode" VALUES(15933,36269,-6,'Muscadine, Alabama 36269',10901,13861);
INSERT INTO "django_geo_db_zipcode" VALUES(15934,36270,-6,'Newell, Alabama 36270',10902,13862);
INSERT INTO "django_geo_db_zipcode" VALUES(15935,36271,-6,'Ohatchee, Alabama 36271',10903,13863);
INSERT INTO "django_geo_db_zipcode" VALUES(15936,36272,-6,'Piedmont, Alabama 36272',10904,13864);
INSERT INTO "django_geo_db_zipcode" VALUES(15937,36273,-6,'Ranburne, Alabama 36273',10905,13865);
INSERT INTO "django_geo_db_zipcode" VALUES(15938,36274,-6,'Roanoke, Alabama 36274',10906,13866);
INSERT INTO "django_geo_db_zipcode" VALUES(15939,36275,-6,'Spring Garden, Alabama 36275',10907,13867);
INSERT INTO "django_geo_db_zipcode" VALUES(15940,36276,-6,'Wadley, Alabama 36276',10908,13868);
INSERT INTO "django_geo_db_zipcode" VALUES(15941,36277,-6,'Weaver, Alabama 36277',10909,13869);
INSERT INTO "django_geo_db_zipcode" VALUES(15942,36278,-6,'Wedowee, Alabama 36278',10910,13870);
INSERT INTO "django_geo_db_zipcode" VALUES(15943,36279,-6,'Wellington, Alabama 36279',10911,13871);
INSERT INTO "django_geo_db_zipcode" VALUES(15944,36280,-6,'Woodland, Alabama 36280',10912,13872);
INSERT INTO "django_geo_db_zipcode" VALUES(15945,36301,-6,'Dothan, Alabama 36301',10913,13873);
INSERT INTO "django_geo_db_zipcode" VALUES(15946,36302,-6,'Dothan, Alabama 36302',10913,13874);
INSERT INTO "django_geo_db_zipcode" VALUES(15947,36303,-6,'Dothan, Alabama 36303',10913,13875);
INSERT INTO "django_geo_db_zipcode" VALUES(15948,36304,-6,'Dothan, Alabama 36304',10913,13874);
INSERT INTO "django_geo_db_zipcode" VALUES(15949,36305,-6,'Dothan, Alabama 36305',10913,13876);
INSERT INTO "django_geo_db_zipcode" VALUES(15950,36310,-6,'Abbeville, Alabama 36310',10914,13877);
INSERT INTO "django_geo_db_zipcode" VALUES(15951,36311,-6,'Ariton, Alabama 36311',10915,13878);
INSERT INTO "django_geo_db_zipcode" VALUES(15952,36312,-6,'Ashford, Alabama 36312',10916,13879);
INSERT INTO "django_geo_db_zipcode" VALUES(15953,36313,-6,'Bellwood, Alabama 36313',10917,13880);
INSERT INTO "django_geo_db_zipcode" VALUES(15954,36314,-6,'Black, Alabama 36314',10918,13881);
INSERT INTO "django_geo_db_zipcode" VALUES(15955,36316,-6,'Chancellor, Alabama 36316',10919,13882);
INSERT INTO "django_geo_db_zipcode" VALUES(15956,36317,-6,'Clopton, Alabama 36317',10920,13883);
INSERT INTO "django_geo_db_zipcode" VALUES(15957,36318,-6,'Coffee Springs, Alabama 36318',10921,13884);
INSERT INTO "django_geo_db_zipcode" VALUES(15958,36319,-6,'Columbia, Alabama 36319',10922,13885);
INSERT INTO "django_geo_db_zipcode" VALUES(15959,36320,-6,'Cottonwood, Alabama 36320',10923,13886);
INSERT INTO "django_geo_db_zipcode" VALUES(15960,36321,-6,'Cowarts, Alabama 36321',10924,13887);
INSERT INTO "django_geo_db_zipcode" VALUES(15961,36322,-6,'Daleville, Alabama 36322',10925,13888);
INSERT INTO "django_geo_db_zipcode" VALUES(15962,36323,-6,'Elba, Alabama 36323',10926,13889);
INSERT INTO "django_geo_db_zipcode" VALUES(15963,36330,-6,'Enterprise, Alabama 36330',10927,13890);
INSERT INTO "django_geo_db_zipcode" VALUES(15964,36331,-6,'Enterprise, Alabama 36331',10927,13891);
INSERT INTO "django_geo_db_zipcode" VALUES(15965,36340,-6,'Geneva, Alabama 36340',10928,13892);
INSERT INTO "django_geo_db_zipcode" VALUES(15966,36343,-6,'Gordon, Alabama 36343',10929,13893);
INSERT INTO "django_geo_db_zipcode" VALUES(15967,36344,-6,'Hartford, Alabama 36344',10930,13894);
INSERT INTO "django_geo_db_zipcode" VALUES(15968,36345,-6,'Headland, Alabama 36345',10931,13895);
INSERT INTO "django_geo_db_zipcode" VALUES(15969,36346,-6,'Jack, Alabama 36346',10932,13896);
INSERT INTO "django_geo_db_zipcode" VALUES(15970,36349,-6,'Malvern, Alabama 36349',10933,13897);
INSERT INTO "django_geo_db_zipcode" VALUES(15971,36350,-6,'Midland City, Alabama 36350',10934,13898);
INSERT INTO "django_geo_db_zipcode" VALUES(15972,36351,-6,'New Brockton, Alabama 36351',10935,13899);
INSERT INTO "django_geo_db_zipcode" VALUES(15973,36352,-6,'Newton, Alabama 36352',10936,13900);
INSERT INTO "django_geo_db_zipcode" VALUES(15974,36353,-6,'Newville, Alabama 36353',10937,13901);
INSERT INTO "django_geo_db_zipcode" VALUES(15975,36360,-6,'Ozark, Alabama 36360',10938,13902);
INSERT INTO "django_geo_db_zipcode" VALUES(15976,36361,-6,'Ozark, Alabama 36361',10938,13903);
INSERT INTO "django_geo_db_zipcode" VALUES(15977,36362,-6,'Fort Rucker, Alabama 36362',10939,13904);
INSERT INTO "django_geo_db_zipcode" VALUES(15978,36370,-6,'Pansey, Alabama 36370',10940,13905);
INSERT INTO "django_geo_db_zipcode" VALUES(15979,36371,-6,'Pinckard, Alabama 36371',10941,13906);
INSERT INTO "django_geo_db_zipcode" VALUES(15980,36373,-6,'Shorterville, Alabama 36373',10942,13907);
INSERT INTO "django_geo_db_zipcode" VALUES(15981,36374,-6,'Skipperville, Alabama 36374',10943,13908);
INSERT INTO "django_geo_db_zipcode" VALUES(15982,36375,-6,'Slocomb, Alabama 36375',10944,13909);
INSERT INTO "django_geo_db_zipcode" VALUES(15983,36376,-6,'Webb, Alabama 36376',10945,13910);
INSERT INTO "django_geo_db_zipcode" VALUES(15984,36383,-6,'Lanett, Alabama 36383',10946,13911);
INSERT INTO "django_geo_db_zipcode" VALUES(15985,36395,-6,'Malvern, Alabama 36395',10933,13912);
INSERT INTO "django_geo_db_zipcode" VALUES(15986,36401,-6,'Evergreen, Alabama 36401',10947,13913);
INSERT INTO "django_geo_db_zipcode" VALUES(15987,36420,-6,'Andalusia, Alabama 36420',10948,13914);
INSERT INTO "django_geo_db_zipcode" VALUES(15988,36422,-6,'Lockhart, Alabama 36422',10949,13915);
INSERT INTO "django_geo_db_zipcode" VALUES(15989,36425,-6,'Beatrice, Alabama 36425',10950,13916);
INSERT INTO "django_geo_db_zipcode" VALUES(15990,36426,-6,'Brewton, Alabama 36426',10951,13917);
INSERT INTO "django_geo_db_zipcode" VALUES(15991,36427,-6,'Brewton, Alabama 36427',10951,13918);
INSERT INTO "django_geo_db_zipcode" VALUES(15992,36429,-6,'Brooklyn, Alabama 36429',10952,13919);
INSERT INTO "django_geo_db_zipcode" VALUES(15993,36431,-6,'Burnt Corn, Alabama 36431',10953,13920);
INSERT INTO "django_geo_db_zipcode" VALUES(15994,36432,-6,'Castleberry, Alabama 36432',10954,13921);
INSERT INTO "django_geo_db_zipcode" VALUES(15995,36435,-6,'Coy, Alabama 36435',10955,13922);
INSERT INTO "django_geo_db_zipcode" VALUES(15996,36436,-6,'Dickinson, Alabama 36436',10956,13923);
INSERT INTO "django_geo_db_zipcode" VALUES(15997,36439,-6,'Excel, Alabama 36439',10957,13924);
INSERT INTO "django_geo_db_zipcode" VALUES(15998,36441,-6,'Flomaton, Alabama 36441',10958,13925);
INSERT INTO "django_geo_db_zipcode" VALUES(15999,36442,-6,'Florala, Alabama 36442',10959,13926);
INSERT INTO "django_geo_db_zipcode" VALUES(16000,36444,-6,'Franklin, Alabama 36444',10960,13927);
INSERT INTO "django_geo_db_zipcode" VALUES(16001,36445,-6,'Frisco City, Alabama 36445',10961,13928);
INSERT INTO "django_geo_db_zipcode" VALUES(16002,36446,-6,'Fulton, Alabama 36446',10962,13929);
INSERT INTO "django_geo_db_zipcode" VALUES(16003,36449,-6,'Goodway, Alabama 36449',10963,13920);
INSERT INTO "django_geo_db_zipcode" VALUES(16004,36451,-6,'Grove Hill, Alabama 36451',10964,13930);
INSERT INTO "django_geo_db_zipcode" VALUES(16005,36453,-6,'Kinston, Alabama 36453',10965,13931);
INSERT INTO "django_geo_db_zipcode" VALUES(16006,36454,-6,'Lenox, Alabama 36454',10966,13919);
INSERT INTO "django_geo_db_zipcode" VALUES(16007,36455,-6,'Lockhart, Alabama 36455',10949,13932);
INSERT INTO "django_geo_db_zipcode" VALUES(16008,36456,-6,'McKenzie, Alabama 36456',10967,13933);
INSERT INTO "django_geo_db_zipcode" VALUES(16009,36457,-6,'Megargel, Alabama 36457',10968,13934);
INSERT INTO "django_geo_db_zipcode" VALUES(16010,36458,-6,'Mexia, Alabama 36458',10969,13935);
INSERT INTO "django_geo_db_zipcode" VALUES(16011,36460,-6,'Monroeville, Alabama 36460',10970,13936);
INSERT INTO "django_geo_db_zipcode" VALUES(16012,36461,-6,'Monroeville, Alabama 36461',10970,13937);
INSERT INTO "django_geo_db_zipcode" VALUES(16013,36462,-6,'Monroeville, Alabama 36462',10970,13920);
INSERT INTO "django_geo_db_zipcode" VALUES(16014,36467,-6,'Opp, Alabama 36467',10971,13938);
INSERT INTO "django_geo_db_zipcode" VALUES(16015,36470,-6,'Perdue Hill, Alabama 36470',10972,13939);
INSERT INTO "django_geo_db_zipcode" VALUES(16016,36471,-6,'Peterman, Alabama 36471',10973,13940);
INSERT INTO "django_geo_db_zipcode" VALUES(16017,36473,-6,'Range, Alabama 36473',10974,13941);
INSERT INTO "django_geo_db_zipcode" VALUES(16018,36474,-6,'Red Level, Alabama 36474',10975,13942);
INSERT INTO "django_geo_db_zipcode" VALUES(16019,36475,-6,'Repton, Alabama 36475',10976,13943);
INSERT INTO "django_geo_db_zipcode" VALUES(16020,36476,-6,'River Falls, Alabama 36476',10977,13944);
INSERT INTO "django_geo_db_zipcode" VALUES(16021,36477,-6,'Samson, Alabama 36477',10978,13945);
INSERT INTO "django_geo_db_zipcode" VALUES(16022,36480,-6,'Uriah, Alabama 36480',10979,13946);
INSERT INTO "django_geo_db_zipcode" VALUES(16023,36481,-6,'Vredenburgh, Alabama 36481',10980,13947);
INSERT INTO "django_geo_db_zipcode" VALUES(16024,36482,-6,'Whatley, Alabama 36482',10981,13948);
INSERT INTO "django_geo_db_zipcode" VALUES(16025,36483,-6,'Wing, Alabama 36483',10982,13949);
INSERT INTO "django_geo_db_zipcode" VALUES(16026,36501,-6,'Alma, Alabama 36501',10983,13950);
INSERT INTO "django_geo_db_zipcode" VALUES(16027,36502,-6,'Atmore, Alabama 36502',10984,13951);
INSERT INTO "django_geo_db_zipcode" VALUES(16028,36503,-6,'Atmore, Alabama 36503',10984,13952);
INSERT INTO "django_geo_db_zipcode" VALUES(16029,36504,-6,'Atmore, Alabama 36504',10984,13953);
INSERT INTO "django_geo_db_zipcode" VALUES(16030,36505,-6,'Axis, Alabama 36505',10985,13954);
INSERT INTO "django_geo_db_zipcode" VALUES(16031,36507,-6,'Bay Minette, Alabama 36507',10986,13955);
INSERT INTO "django_geo_db_zipcode" VALUES(16032,36508,-6,'Dauphin Island, Alabama 36508',10987,13956);
INSERT INTO "django_geo_db_zipcode" VALUES(16033,36509,-6,'Bayou La Batre, Alabama 36509',10988,13957);
INSERT INTO "django_geo_db_zipcode" VALUES(16034,36511,-6,'Bon Secour, Alabama 36511',10989,13958);
INSERT INTO "django_geo_db_zipcode" VALUES(16035,36512,-6,'Bucks, Alabama 36512',10990,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16036,36513,-6,'Calvert, Alabama 36513',10991,13960);
INSERT INTO "django_geo_db_zipcode" VALUES(16037,36515,-6,'Carlton, Alabama 36515',10992,13961);
INSERT INTO "django_geo_db_zipcode" VALUES(16038,36518,-6,'Chatom, Alabama 36518',10993,13962);
INSERT INTO "django_geo_db_zipcode" VALUES(16039,36521,-6,'Chunchula, Alabama 36521',10994,13963);
INSERT INTO "django_geo_db_zipcode" VALUES(16040,36522,-6,'Citronelle, Alabama 36522',10995,13964);
INSERT INTO "django_geo_db_zipcode" VALUES(16041,36523,-6,'Coden, Alabama 36523',10996,13965);
INSERT INTO "django_geo_db_zipcode" VALUES(16042,36524,-6,'Coffeeville, Alabama 36524',10997,13966);
INSERT INTO "django_geo_db_zipcode" VALUES(16043,36525,-6,'Creola, Alabama 36525',10998,13967);
INSERT INTO "django_geo_db_zipcode" VALUES(16044,36526,-6,'Daphne, Alabama 36526',10999,13968);
INSERT INTO "django_geo_db_zipcode" VALUES(16045,36527,-6,'Spanish Fort, Alabama 36527',11000,13969);
INSERT INTO "django_geo_db_zipcode" VALUES(16046,36528,-6,'Dauphin Island, Alabama 36528',10987,13970);
INSERT INTO "django_geo_db_zipcode" VALUES(16047,36529,-6,'Deer Park, Alabama 36529',11001,13971);
INSERT INTO "django_geo_db_zipcode" VALUES(16048,36530,-6,'Elberta, Alabama 36530',11002,13972);
INSERT INTO "django_geo_db_zipcode" VALUES(16049,36531,-6,'Loxley, Alabama 36531',11003,13973);
INSERT INTO "django_geo_db_zipcode" VALUES(16050,36532,-6,'Fairhope, Alabama 36532',11004,13974);
INSERT INTO "django_geo_db_zipcode" VALUES(16051,36533,-6,'Fairhope, Alabama 36533',11004,13975);
INSERT INTO "django_geo_db_zipcode" VALUES(16052,36535,-6,'Foley, Alabama 36535',11005,13976);
INSERT INTO "django_geo_db_zipcode" VALUES(16053,36536,-6,'Foley, Alabama 36536',11005,13977);
INSERT INTO "django_geo_db_zipcode" VALUES(16054,36538,-6,'Frankville, Alabama 36538',11006,13978);
INSERT INTO "django_geo_db_zipcode" VALUES(16055,36539,-6,'Fruitdale, Alabama 36539',11007,13979);
INSERT INTO "django_geo_db_zipcode" VALUES(16056,36540,-6,'Gainestown, Alabama 36540',11008,13980);
INSERT INTO "django_geo_db_zipcode" VALUES(16057,36541,-6,'Grand Bay, Alabama 36541',11009,13981);
INSERT INTO "django_geo_db_zipcode" VALUES(16058,36542,-6,'Gulf Shores, Alabama 36542',11010,13982);
INSERT INTO "django_geo_db_zipcode" VALUES(16059,36543,-6,'Huxford, Alabama 36543',11011,13983);
INSERT INTO "django_geo_db_zipcode" VALUES(16060,36544,-6,'Irvington, Alabama 36544',11012,13984);
INSERT INTO "django_geo_db_zipcode" VALUES(16061,36545,-6,'Jackson, Alabama 36545',11013,13985);
INSERT INTO "django_geo_db_zipcode" VALUES(16062,36547,-6,'Gulf Shores, Alabama 36547',11010,13986);
INSERT INTO "django_geo_db_zipcode" VALUES(16063,36548,-6,'Leroy, Alabama 36548',11014,13987);
INSERT INTO "django_geo_db_zipcode" VALUES(16064,36549,-6,'Lillian, Alabama 36549',11015,13988);
INSERT INTO "django_geo_db_zipcode" VALUES(16065,36550,-6,'Little River, Alabama 36550',11016,13989);
INSERT INTO "django_geo_db_zipcode" VALUES(16066,36551,-6,'Loxley, Alabama 36551',11003,13990);
INSERT INTO "django_geo_db_zipcode" VALUES(16067,36553,-6,'McIntosh, Alabama 36553',11017,13991);
INSERT INTO "django_geo_db_zipcode" VALUES(16068,36555,-6,'Magnolia Springs, Alabama 36555',11018,13992);
INSERT INTO "django_geo_db_zipcode" VALUES(16069,36556,-6,'Malcolm, Alabama 36556',11019,13993);
INSERT INTO "django_geo_db_zipcode" VALUES(16070,36558,-6,'Millry, Alabama 36558',11020,13994);
INSERT INTO "django_geo_db_zipcode" VALUES(16071,36559,-6,'Montrose, Alabama 36559',11021,13995);
INSERT INTO "django_geo_db_zipcode" VALUES(16072,36560,-6,'Mount Vernon, Alabama 36560',11022,13996);
INSERT INTO "django_geo_db_zipcode" VALUES(16073,36561,-6,'Orange Beach, Alabama 36561',11023,13997);
INSERT INTO "django_geo_db_zipcode" VALUES(16074,36562,-6,'Perdido, Alabama 36562',11024,13998);
INSERT INTO "django_geo_db_zipcode" VALUES(16075,36564,-6,'Point Clear, Alabama 36564',11025,13999);
INSERT INTO "django_geo_db_zipcode" VALUES(16076,36567,-6,'Robertsdale, Alabama 36567',11026,14000);
INSERT INTO "django_geo_db_zipcode" VALUES(16077,36568,-6,'Saint Elmo, Alabama 36568',11027,14001);
INSERT INTO "django_geo_db_zipcode" VALUES(16078,36569,-6,'Saint Stephens, Alabama 36569',11028,14002);
INSERT INTO "django_geo_db_zipcode" VALUES(16079,36570,-6,'Salitpa, Alabama 36570',11029,14003);
INSERT INTO "django_geo_db_zipcode" VALUES(16080,36571,-6,'Saraland, Alabama 36571',11030,14004);
INSERT INTO "django_geo_db_zipcode" VALUES(16081,36572,-6,'Satsuma, Alabama 36572',11031,14005);
INSERT INTO "django_geo_db_zipcode" VALUES(16082,36574,-6,'Seminole, Alabama 36574',11032,14006);
INSERT INTO "django_geo_db_zipcode" VALUES(16083,36575,-6,'Semmes, Alabama 36575',11033,14007);
INSERT INTO "django_geo_db_zipcode" VALUES(16084,36576,-6,'Silverhill, Alabama 36576',11034,14008);
INSERT INTO "django_geo_db_zipcode" VALUES(16085,36577,-6,'Spanish Fort, Alabama 36577',11000,14009);
INSERT INTO "django_geo_db_zipcode" VALUES(16086,36578,-6,'Stapleton, Alabama 36578',11035,14010);
INSERT INTO "django_geo_db_zipcode" VALUES(16087,36579,-6,'Stockton, Alabama 36579',11036,14011);
INSERT INTO "django_geo_db_zipcode" VALUES(16088,36580,-6,'Summerdale, Alabama 36580',11037,14012);
INSERT INTO "django_geo_db_zipcode" VALUES(16089,36581,-6,'Sunflower, Alabama 36581',11038,14013);
INSERT INTO "django_geo_db_zipcode" VALUES(16090,36582,-6,'Theodore, Alabama 36582',11039,14014);
INSERT INTO "django_geo_db_zipcode" VALUES(16091,36583,-6,'Tibbie, Alabama 36583',11040,14015);
INSERT INTO "django_geo_db_zipcode" VALUES(16092,36584,-6,'Vinegar Bend, Alabama 36584',11041,14016);
INSERT INTO "django_geo_db_zipcode" VALUES(16093,36585,-6,'Wagarville, Alabama 36585',11042,14017);
INSERT INTO "django_geo_db_zipcode" VALUES(16094,36586,-6,'Walker Springs, Alabama 36586',11043,14018);
INSERT INTO "django_geo_db_zipcode" VALUES(16095,36587,-6,'Wilmer, Alabama 36587',11044,14019);
INSERT INTO "django_geo_db_zipcode" VALUES(16096,36590,-6,'Theodore, Alabama 36590',11039,14020);
INSERT INTO "django_geo_db_zipcode" VALUES(16097,36601,-6,'Mobile, Alabama 36601',11045,14021);
INSERT INTO "django_geo_db_zipcode" VALUES(16098,36602,-6,'Mobile, Alabama 36602',11045,14022);
INSERT INTO "django_geo_db_zipcode" VALUES(16099,36603,-6,'Mobile, Alabama 36603',11045,14023);
INSERT INTO "django_geo_db_zipcode" VALUES(16100,36604,-6,'Mobile, Alabama 36604',11045,14024);
INSERT INTO "django_geo_db_zipcode" VALUES(16101,36605,-6,'Mobile, Alabama 36605',11045,14025);
INSERT INTO "django_geo_db_zipcode" VALUES(16102,36606,-6,'Mobile, Alabama 36606',11045,14026);
INSERT INTO "django_geo_db_zipcode" VALUES(16103,36607,-6,'Mobile, Alabama 36607',11045,14027);
INSERT INTO "django_geo_db_zipcode" VALUES(16104,36608,-6,'Mobile, Alabama 36608',11045,14028);
INSERT INTO "django_geo_db_zipcode" VALUES(16105,36609,-6,'Mobile, Alabama 36609',11045,14029);
INSERT INTO "django_geo_db_zipcode" VALUES(16106,36610,-6,'Mobile, Alabama 36610',11045,14030);
INSERT INTO "django_geo_db_zipcode" VALUES(16107,36611,-6,'Mobile, Alabama 36611',11045,14031);
INSERT INTO "django_geo_db_zipcode" VALUES(16108,36612,-6,'Mobile, Alabama 36612',11045,14032);
INSERT INTO "django_geo_db_zipcode" VALUES(16109,36613,-6,'Eight Mile, Alabama 36613',11046,14033);
INSERT INTO "django_geo_db_zipcode" VALUES(16110,36614,-6,'Mobile, Alabama 36614',11045,14034);
INSERT INTO "django_geo_db_zipcode" VALUES(16111,36615,-6,'Mobile, Alabama 36615',11045,14035);
INSERT INTO "django_geo_db_zipcode" VALUES(16112,36616,-6,'Mobile, Alabama 36616',11045,14036);
INSERT INTO "django_geo_db_zipcode" VALUES(16113,36617,-6,'Mobile, Alabama 36617',11045,14037);
INSERT INTO "django_geo_db_zipcode" VALUES(16114,36618,-6,'Mobile, Alabama 36618',11045,14038);
INSERT INTO "django_geo_db_zipcode" VALUES(16115,36619,-6,'Mobile, Alabama 36619',11045,14039);
INSERT INTO "django_geo_db_zipcode" VALUES(16116,36621,-6,'Mobile, Alabama 36621',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16117,36622,-6,'Mobile, Alabama 36622',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16118,36623,-6,'Mobile, Alabama 36623',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16119,36625,-6,'Mobile, Alabama 36625',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16120,36626,-6,'Mobile, Alabama 36626',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16121,36628,-6,'Mobile, Alabama 36628',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16122,36630,-6,'Mobile, Alabama 36630',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16123,36631,-6,'Mobile, Alabama 36631',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16124,36633,-6,'Mobile, Alabama 36633',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16125,36640,-6,'Mobile, Alabama 36640',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16126,36641,-6,'Mobile, Alabama 36641',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16127,36644,-6,'Mobile, Alabama 36644',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16128,36652,-6,'Mobile, Alabama 36652',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16129,36660,-6,'Mobile, Alabama 36660',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16130,36663,-6,'Mobile, Alabama 36663',11045,14040);
INSERT INTO "django_geo_db_zipcode" VALUES(16131,36670,-6,'Mobile, Alabama 36670',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16132,36671,-6,'Mobile, Alabama 36671',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16133,36675,-6,'Mobile, Alabama 36675',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16134,36685,-6,'Mobile, Alabama 36685',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16135,36688,-6,'Mobile, Alabama 36688',11045,14041);
INSERT INTO "django_geo_db_zipcode" VALUES(16136,36689,-6,'Mobile, Alabama 36689',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16137,36690,-6,'Mobile, Alabama 36690',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16138,36691,-6,'Mobile, Alabama 36691',11045,13959);
INSERT INTO "django_geo_db_zipcode" VALUES(16139,36693,-6,'Mobile, Alabama 36693',11045,14042);
INSERT INTO "django_geo_db_zipcode" VALUES(16140,36695,-6,'Mobile, Alabama 36695',11045,14043);
INSERT INTO "django_geo_db_zipcode" VALUES(16141,36701,-6,'Selma, Alabama 36701',11047,14044);
INSERT INTO "django_geo_db_zipcode" VALUES(16142,36702,-6,'Selma, Alabama 36702',11047,14045);
INSERT INTO "django_geo_db_zipcode" VALUES(16143,36703,-6,'Selma, Alabama 36703',11047,14046);
INSERT INTO "django_geo_db_zipcode" VALUES(16144,36720,-6,'Alberta, Alabama 36720',11048,14047);
INSERT INTO "django_geo_db_zipcode" VALUES(16145,36721,-6,'Annemanie, Alabama 36721',11049,14048);
INSERT INTO "django_geo_db_zipcode" VALUES(16146,36722,-6,'Arlington, Alabama 36722',11050,14049);
INSERT INTO "django_geo_db_zipcode" VALUES(16147,36723,-6,'Boykin, Alabama 36723',11051,14050);
INSERT INTO "django_geo_db_zipcode" VALUES(16148,36726,-6,'Camden, Alabama 36726',11052,14051);
INSERT INTO "django_geo_db_zipcode" VALUES(16149,36727,-6,'Campbell, Alabama 36727',11053,14052);
INSERT INTO "django_geo_db_zipcode" VALUES(16150,36728,-6,'Catherine, Alabama 36728',11054,14053);
INSERT INTO "django_geo_db_zipcode" VALUES(16151,36732,-6,'Demopolis, Alabama 36732',11055,14054);
INSERT INTO "django_geo_db_zipcode" VALUES(16152,36736,-6,'Dixons Mills, Alabama 36736',11056,14055);
INSERT INTO "django_geo_db_zipcode" VALUES(16153,36738,-6,'Faunsdale, Alabama 36738',11057,14056);
INSERT INTO "django_geo_db_zipcode" VALUES(16154,36740,-6,'Forkland, Alabama 36740',11058,14057);
INSERT INTO "django_geo_db_zipcode" VALUES(16155,36741,-6,'Furman, Alabama 36741',11059,14058);
INSERT INTO "django_geo_db_zipcode" VALUES(16156,36742,-6,'Gallion, Alabama 36742',11060,14059);
INSERT INTO "django_geo_db_zipcode" VALUES(16157,36744,-6,'Greensboro, Alabama 36744',11061,14060);
INSERT INTO "django_geo_db_zipcode" VALUES(16158,36745,-6,'Jefferson, Alabama 36745',11062,14061);
INSERT INTO "django_geo_db_zipcode" VALUES(16159,36748,-6,'Linden, Alabama 36748',11063,14062);
INSERT INTO "django_geo_db_zipcode" VALUES(16160,36749,-6,'Jones, Alabama 36749',11064,14063);
INSERT INTO "django_geo_db_zipcode" VALUES(16161,36750,-6,'Maplesville, Alabama 36750',11065,14064);
INSERT INTO "django_geo_db_zipcode" VALUES(16162,36751,-6,'Lower Peach Tree, Alabama 36751',11066,14065);
INSERT INTO "django_geo_db_zipcode" VALUES(16163,36752,-6,'Lowndesboro, Alabama 36752',11067,14066);
INSERT INTO "django_geo_db_zipcode" VALUES(16164,36753,-6,'McWilliams, Alabama 36753',11068,14048);
INSERT INTO "django_geo_db_zipcode" VALUES(16165,36754,-6,'Magnolia, Alabama 36754',11069,14067);
INSERT INTO "django_geo_db_zipcode" VALUES(16166,36755,-6,'Greensboro, Alabama 36755',11061,14068);
INSERT INTO "django_geo_db_zipcode" VALUES(16167,36756,-6,'Marion, Alabama 36756',11070,14069);
INSERT INTO "django_geo_db_zipcode" VALUES(16168,36758,-6,'Plantersville, Alabama 36758',11071,14070);
INSERT INTO "django_geo_db_zipcode" VALUES(16169,36759,-6,'Marion Junction, Alabama 36759',11072,14071);
INSERT INTO "django_geo_db_zipcode" VALUES(16170,36761,-6,'Minter, Alabama 36761',11073,14072);
INSERT INTO "django_geo_db_zipcode" VALUES(16171,36762,-6,'Morvin, Alabama 36762',11074,14073);
INSERT INTO "django_geo_db_zipcode" VALUES(16172,36763,-6,'Myrtlewood, Alabama 36763',11075,14074);
INSERT INTO "django_geo_db_zipcode" VALUES(16173,36764,-6,'Nanafalia, Alabama 36764',11076,14075);
INSERT INTO "django_geo_db_zipcode" VALUES(16174,36765,-6,'Newbern, Alabama 36765',11077,14076);
INSERT INTO "django_geo_db_zipcode" VALUES(16175,36766,-6,'Oak Hill, Alabama 36766',11078,14077);
INSERT INTO "django_geo_db_zipcode" VALUES(16176,36767,-6,'Orrville, Alabama 36767',11079,14078);
INSERT INTO "django_geo_db_zipcode" VALUES(16177,36768,-6,'Pine Apple, Alabama 36768',11080,14079);
INSERT INTO "django_geo_db_zipcode" VALUES(16178,36769,-6,'Pine Hill, Alabama 36769',11081,14080);
INSERT INTO "django_geo_db_zipcode" VALUES(16179,36773,-6,'Safford, Alabama 36773',11082,14081);
INSERT INTO "django_geo_db_zipcode" VALUES(16180,36775,-6,'Sardis, Alabama 36775',11083,14082);
INSERT INTO "django_geo_db_zipcode" VALUES(16181,36776,-6,'Sawyerville, Alabama 36776',11084,14083);
INSERT INTO "django_geo_db_zipcode" VALUES(16182,36778,-6,'Snow Hill, Alabama 36778',11085,14084);
INSERT INTO "django_geo_db_zipcode" VALUES(16183,36779,-6,'Sprott, Alabama 36779',11086,14085);
INSERT INTO "django_geo_db_zipcode" VALUES(16184,36782,-6,'Sweet Water, Alabama 36782',11087,14086);
INSERT INTO "django_geo_db_zipcode" VALUES(16185,36783,-6,'Thomaston, Alabama 36783',11088,14087);
INSERT INTO "django_geo_db_zipcode" VALUES(16186,36784,-6,'Thomasville, Alabama 36784',11089,14088);
INSERT INTO "django_geo_db_zipcode" VALUES(16187,36785,-6,'Tyler, Alabama 36785',11090,14089);
INSERT INTO "django_geo_db_zipcode" VALUES(16188,36786,-6,'Uniontown, Alabama 36786',11091,14090);
INSERT INTO "django_geo_db_zipcode" VALUES(16189,36790,-6,'Stanton, Alabama 36790',11092,14091);
INSERT INTO "django_geo_db_zipcode" VALUES(16190,36792,-6,'Randolph, Alabama 36792',11093,14092);
INSERT INTO "django_geo_db_zipcode" VALUES(16191,36793,-6,'Lawley, Alabama 36793',11094,14093);
INSERT INTO "django_geo_db_zipcode" VALUES(16192,36801,-6,'Opelika, Alabama 36801',11095,14094);
INSERT INTO "django_geo_db_zipcode" VALUES(16193,36802,-6,'Opelika, Alabama 36802',11095,14095);
INSERT INTO "django_geo_db_zipcode" VALUES(16194,36803,-6,'Opelika, Alabama 36803',11095,14096);
INSERT INTO "django_geo_db_zipcode" VALUES(16195,36804,-6,'Opelika, Alabama 36804',11095,14097);
INSERT INTO "django_geo_db_zipcode" VALUES(16196,36830,-6,'Auburn, Alabama 36830',11096,14098);
INSERT INTO "django_geo_db_zipcode" VALUES(16197,36831,-6,'Auburn, Alabama 36831',11096,14095);
INSERT INTO "django_geo_db_zipcode" VALUES(16198,36832,-6,'Auburn, Alabama 36832',11096,14099);
INSERT INTO "django_geo_db_zipcode" VALUES(16199,36849,-6,'Auburn University, Alabama 36849',11097,14100);
INSERT INTO "django_geo_db_zipcode" VALUES(16200,36850,-6,'Camp Hill, Alabama 36850',11098,14101);
INSERT INTO "django_geo_db_zipcode" VALUES(16201,36851,-6,'Cottonton, Alabama 36851',11099,14102);
INSERT INTO "django_geo_db_zipcode" VALUES(16202,36852,-6,'Cusseta, Alabama 36852',11100,14103);
INSERT INTO "django_geo_db_zipcode" VALUES(16203,36853,-6,'Dadeville, Alabama 36853',11101,14104);
INSERT INTO "django_geo_db_zipcode" VALUES(16204,36854,-6,'Valley, Alabama 36854',11102,14105);
INSERT INTO "django_geo_db_zipcode" VALUES(16205,36855,-6,'Five Points, Alabama 36855',11103,14106);
INSERT INTO "django_geo_db_zipcode" VALUES(16206,36856,-6,'Fort Mitchell, Alabama 36856',11104,14107);
INSERT INTO "django_geo_db_zipcode" VALUES(16207,36858,-6,'Hatchechubbee, Alabama 36858',11105,14108);
INSERT INTO "django_geo_db_zipcode" VALUES(16208,36859,-6,'Holy Trinity, Alabama 36859',11106,14109);
INSERT INTO "django_geo_db_zipcode" VALUES(16209,36860,-6,'Hurtsboro, Alabama 36860',11107,14110);
INSERT INTO "django_geo_db_zipcode" VALUES(16210,36861,-6,'Jacksons Gap, Alabama 36861',11108,14111);
INSERT INTO "django_geo_db_zipcode" VALUES(16211,36862,-6,'Lafayette, Alabama 36862',11109,14112);
INSERT INTO "django_geo_db_zipcode" VALUES(16212,36863,-6,'Lanett, Alabama 36863',10946,14113);
INSERT INTO "django_geo_db_zipcode" VALUES(16213,36865,-6,'Loachapoka, Alabama 36865',11110,14095);
INSERT INTO "django_geo_db_zipcode" VALUES(16214,36866,-6,'Notasulga, Alabama 36866',11111,14114);
INSERT INTO "django_geo_db_zipcode" VALUES(16215,36867,-6,'Phenix City, Alabama 36867',11112,14115);
INSERT INTO "django_geo_db_zipcode" VALUES(16216,36868,-6,'Phenix City, Alabama 36868',11112,14116);
INSERT INTO "django_geo_db_zipcode" VALUES(16217,36869,-6,'Phenix City, Alabama 36869',11112,14117);
INSERT INTO "django_geo_db_zipcode" VALUES(16218,36870,-6,'Phenix City, Alabama 36870',11112,14118);
INSERT INTO "django_geo_db_zipcode" VALUES(16219,36871,-6,'Pittsview, Alabama 36871',11113,14119);
INSERT INTO "django_geo_db_zipcode" VALUES(16220,36872,-6,'Valley, Alabama 36872',11102,14095);
INSERT INTO "django_geo_db_zipcode" VALUES(16221,36874,-6,'Salem, Alabama 36874',11114,14120);
INSERT INTO "django_geo_db_zipcode" VALUES(16222,36875,-6,'Seale, Alabama 36875',11115,14121);
INSERT INTO "django_geo_db_zipcode" VALUES(16223,36876,-6,'Uniontown, Alabama 36876',11091,14122);
INSERT INTO "django_geo_db_zipcode" VALUES(16224,36877,-6,'Smiths, Alabama 36877',11116,14123);
INSERT INTO "django_geo_db_zipcode" VALUES(16225,36879,-6,'Waverly, Alabama 36879',11117,14124);
INSERT INTO "django_geo_db_zipcode" VALUES(16226,36901,-6,'Bellamy, Alabama 36901',11118,14125);
INSERT INTO "django_geo_db_zipcode" VALUES(16227,36904,-6,'Butler, Alabama 36904',11119,14126);
INSERT INTO "django_geo_db_zipcode" VALUES(16228,36906,-6,'Cromwell, Alabama 36906',11120,14127);
INSERT INTO "django_geo_db_zipcode" VALUES(16229,36907,-6,'Cuba, Alabama 36907',11121,14128);
INSERT INTO "django_geo_db_zipcode" VALUES(16230,36908,-6,'Gilbertown, Alabama 36908',11122,14129);
INSERT INTO "django_geo_db_zipcode" VALUES(16231,36910,-6,'Jachin, Alabama 36910',11123,14130);
INSERT INTO "django_geo_db_zipcode" VALUES(16232,36912,-6,'Lisman, Alabama 36912',11124,14131);
INSERT INTO "django_geo_db_zipcode" VALUES(16233,36913,-6,'Melvin, Alabama 36913',11125,14127);
INSERT INTO "django_geo_db_zipcode" VALUES(16234,36915,-6,'Needham, Alabama 36915',11126,14132);
INSERT INTO "django_geo_db_zipcode" VALUES(16235,36916,-6,'Pennington, Alabama 36916',11127,14133);
INSERT INTO "django_geo_db_zipcode" VALUES(16236,36919,-6,'Silas, Alabama 36919',11128,14134);
INSERT INTO "django_geo_db_zipcode" VALUES(16237,36921,-6,'Toxey, Alabama 36921',11129,14135);
INSERT INTO "django_geo_db_zipcode" VALUES(16238,36922,-6,'Ward, Alabama 36922',11130,14136);
INSERT INTO "django_geo_db_zipcode" VALUES(16239,36925,-6,'York, Alabama 36925',11131,14137);
INSERT INTO "django_geo_db_zipcode" VALUES(16240,37010,-6,'Adams, Tennessee 37010',11132,14138);
INSERT INTO "django_geo_db_zipcode" VALUES(16241,37011,-6,'Antioch, Tennessee 37011',11133,14139);
INSERT INTO "django_geo_db_zipcode" VALUES(16242,37012,-6,'Alexandria, Tennessee 37012',11134,14140);
INSERT INTO "django_geo_db_zipcode" VALUES(16243,37013,-6,'Antioch, Tennessee 37013',11133,14141);
INSERT INTO "django_geo_db_zipcode" VALUES(16244,37014,-6,'Arrington, Tennessee 37014',11135,14142);
INSERT INTO "django_geo_db_zipcode" VALUES(16245,37015,-6,'Ashland City, Tennessee 37015',11136,14143);
INSERT INTO "django_geo_db_zipcode" VALUES(16246,37016,-6,'Auburntown, Tennessee 37016',11137,14144);
INSERT INTO "django_geo_db_zipcode" VALUES(16247,37018,-6,'Beechgrove, Tennessee 37018',11138,14145);
INSERT INTO "django_geo_db_zipcode" VALUES(16248,37019,-6,'Belfast, Tennessee 37019',11139,14146);
INSERT INTO "django_geo_db_zipcode" VALUES(16249,37020,-6,'Bell Buckle, Tennessee 37020',11140,14147);
INSERT INTO "django_geo_db_zipcode" VALUES(16250,37022,-6,'Bethpage, Tennessee 37022',11141,14148);
INSERT INTO "django_geo_db_zipcode" VALUES(16251,37023,-6,'Big Rock, Tennessee 37023',11142,14149);
INSERT INTO "django_geo_db_zipcode" VALUES(16252,37024,-6,'Brentwood, Tennessee 37024',11143,14150);
INSERT INTO "django_geo_db_zipcode" VALUES(16253,37025,-6,'Bon Aqua, Tennessee 37025',11144,14151);
INSERT INTO "django_geo_db_zipcode" VALUES(16254,37026,-6,'Bradyville, Tennessee 37026',11145,14152);
INSERT INTO "django_geo_db_zipcode" VALUES(16255,37027,-6,'Brentwood, Tennessee 37027',11143,14153);
INSERT INTO "django_geo_db_zipcode" VALUES(16256,37028,-6,'Bumpus Mills, Tennessee 37028',11146,14154);
INSERT INTO "django_geo_db_zipcode" VALUES(16257,37029,-6,'Burns, Tennessee 37029',11147,14155);
INSERT INTO "django_geo_db_zipcode" VALUES(16258,37030,-6,'Carthage, Tennessee 37030',11148,14156);
INSERT INTO "django_geo_db_zipcode" VALUES(16259,37031,-6,'Castalian Springs, Tennessee 37031',11149,14157);
INSERT INTO "django_geo_db_zipcode" VALUES(16260,37032,-6,'Cedar Hill, Tennessee 37032',11150,14158);
INSERT INTO "django_geo_db_zipcode" VALUES(16261,37033,-6,'Centerville, Tennessee 37033',11151,14159);
INSERT INTO "django_geo_db_zipcode" VALUES(16262,37034,-6,'Chapel Hill, Tennessee 37034',11152,14160);
INSERT INTO "django_geo_db_zipcode" VALUES(16263,37035,-6,'Chapmansboro, Tennessee 37035',11153,14161);
INSERT INTO "django_geo_db_zipcode" VALUES(16264,37036,-6,'Charlotte, Tennessee 37036',11154,14162);
INSERT INTO "django_geo_db_zipcode" VALUES(16265,37037,-6,'Christiana, Tennessee 37037',11155,14163);
INSERT INTO "django_geo_db_zipcode" VALUES(16266,37040,-6,'Clarksville, Tennessee 37040',11156,14164);
INSERT INTO "django_geo_db_zipcode" VALUES(16267,37041,-6,'Clarksville, Tennessee 37041',11156,14165);
INSERT INTO "django_geo_db_zipcode" VALUES(16268,37042,-6,'Clarksville, Tennessee 37042',11156,14166);
INSERT INTO "django_geo_db_zipcode" VALUES(16269,37043,-6,'Clarksville, Tennessee 37043',11156,14167);
INSERT INTO "django_geo_db_zipcode" VALUES(16270,37044,-6,'Clarksville, Tennessee 37044',11156,14168);
INSERT INTO "django_geo_db_zipcode" VALUES(16271,37046,-6,'College Grove, Tennessee 37046',11157,14169);
INSERT INTO "django_geo_db_zipcode" VALUES(16272,37047,-6,'Cornersville, Tennessee 37047',11158,14170);
INSERT INTO "django_geo_db_zipcode" VALUES(16273,37048,-6,'Cottontown, Tennessee 37048',11159,14171);
INSERT INTO "django_geo_db_zipcode" VALUES(16274,37049,-6,'Cross Plains, Tennessee 37049',11160,14172);
INSERT INTO "django_geo_db_zipcode" VALUES(16275,37050,-6,'Cumberland City, Tennessee 37050',11161,14173);
INSERT INTO "django_geo_db_zipcode" VALUES(16276,37051,-6,'Cumberland Furnace, Tennessee 37051',11162,14174);
INSERT INTO "django_geo_db_zipcode" VALUES(16277,37052,-6,'Cunningham, Tennessee 37052',11163,14175);
INSERT INTO "django_geo_db_zipcode" VALUES(16278,37055,-6,'Dickson, Tennessee 37055',11164,14176);
INSERT INTO "django_geo_db_zipcode" VALUES(16279,37056,-6,'Dickson, Tennessee 37056',11164,14177);
INSERT INTO "django_geo_db_zipcode" VALUES(16280,37057,-6,'Dixon Springs, Tennessee 37057',11165,14178);
INSERT INTO "django_geo_db_zipcode" VALUES(16281,37058,-6,'Dover, Tennessee 37058',11166,14179);
INSERT INTO "django_geo_db_zipcode" VALUES(16282,37059,-6,'Dowelltown, Tennessee 37059',11167,14180);
INSERT INTO "django_geo_db_zipcode" VALUES(16283,37060,-6,'Eagleville, Tennessee 37060',11168,14181);
INSERT INTO "django_geo_db_zipcode" VALUES(16284,37061,-6,'Erin, Tennessee 37061',11169,14182);
INSERT INTO "django_geo_db_zipcode" VALUES(16285,37062,-6,'Fairview, Tennessee 37062',11170,14183);
INSERT INTO "django_geo_db_zipcode" VALUES(16286,37063,-6,'Fosterville, Tennessee 37063',11171,14184);
INSERT INTO "django_geo_db_zipcode" VALUES(16287,37064,-6,'Franklin, Tennessee 37064',11172,14185);
INSERT INTO "django_geo_db_zipcode" VALUES(16288,37065,-6,'Franklin, Tennessee 37065',11172,14186);
INSERT INTO "django_geo_db_zipcode" VALUES(16289,37066,-6,'Gallatin, Tennessee 37066',11173,14187);
INSERT INTO "django_geo_db_zipcode" VALUES(16290,37067,-6,'Franklin, Tennessee 37067',11172,14188);
INSERT INTO "django_geo_db_zipcode" VALUES(16291,37068,-6,'Franklin, Tennessee 37068',11172,14150);
INSERT INTO "django_geo_db_zipcode" VALUES(16292,37069,-6,'Franklin, Tennessee 37069',11172,14189);
INSERT INTO "django_geo_db_zipcode" VALUES(16293,37070,-6,'Goodlettsville, Tennessee 37070',11174,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16294,37071,-6,'Gladeville, Tennessee 37071',11175,14191);
INSERT INTO "django_geo_db_zipcode" VALUES(16295,37072,-6,'Goodlettsville, Tennessee 37072',11174,14192);
INSERT INTO "django_geo_db_zipcode" VALUES(16296,37073,-6,'Greenbrier, Tennessee 37073',11176,14193);
INSERT INTO "django_geo_db_zipcode" VALUES(16297,37074,-6,'Hartsville, Tennessee 37074',11177,14194);
INSERT INTO "django_geo_db_zipcode" VALUES(16298,37075,-6,'Hendersonville, Tennessee 37075',11178,14195);
INSERT INTO "django_geo_db_zipcode" VALUES(16299,37076,-6,'Hermitage, Tennessee 37076',11179,14196);
INSERT INTO "django_geo_db_zipcode" VALUES(16300,37077,-6,'Hendersonville, Tennessee 37077',11178,14197);
INSERT INTO "django_geo_db_zipcode" VALUES(16301,37078,-6,'Hurricane Mills, Tennessee 37078',11180,14198);
INSERT INTO "django_geo_db_zipcode" VALUES(16302,37079,-6,'Indian Mound, Tennessee 37079',11181,14199);
INSERT INTO "django_geo_db_zipcode" VALUES(16303,37080,-6,'Joelton, Tennessee 37080',11182,14200);
INSERT INTO "django_geo_db_zipcode" VALUES(16304,37082,-6,'Kingston Springs, Tennessee 37082',11183,14201);
INSERT INTO "django_geo_db_zipcode" VALUES(16305,37083,-6,'Lafayette, Tennessee 37083',11184,14202);
INSERT INTO "django_geo_db_zipcode" VALUES(16306,37085,-6,'Lascassas, Tennessee 37085',11185,14203);
INSERT INTO "django_geo_db_zipcode" VALUES(16307,37086,-6,'La Vergne, Tennessee 37086',11186,14204);
INSERT INTO "django_geo_db_zipcode" VALUES(16308,37087,-6,'Lebanon, Tennessee 37087',11187,14205);
INSERT INTO "django_geo_db_zipcode" VALUES(16309,37088,-6,'Lebanon, Tennessee 37088',11187,14191);
INSERT INTO "django_geo_db_zipcode" VALUES(16310,37089,-6,'La Vergne, Tennessee 37089',11186,14184);
INSERT INTO "django_geo_db_zipcode" VALUES(16311,37090,-6,'Lebanon, Tennessee 37090',11187,14206);
INSERT INTO "django_geo_db_zipcode" VALUES(16312,37091,-6,'Lewisburg, Tennessee 37091',11188,14207);
INSERT INTO "django_geo_db_zipcode" VALUES(16313,37095,-6,'Liberty, Tennessee 37095',11189,14208);
INSERT INTO "django_geo_db_zipcode" VALUES(16314,37096,-6,'Linden, Tennessee 37096',11190,14209);
INSERT INTO "django_geo_db_zipcode" VALUES(16315,37097,-6,'Lobelville, Tennessee 37097',11191,14210);
INSERT INTO "django_geo_db_zipcode" VALUES(16316,37098,-6,'Lyles, Tennessee 37098',11192,14211);
INSERT INTO "django_geo_db_zipcode" VALUES(16317,37101,-6,'McEwen, Tennessee 37101',11193,14212);
INSERT INTO "django_geo_db_zipcode" VALUES(16318,37110,-6,'McMinnville, Tennessee 37110',11194,14213);
INSERT INTO "django_geo_db_zipcode" VALUES(16319,37111,-6,'McMinnville, Tennessee 37111',11194,14214);
INSERT INTO "django_geo_db_zipcode" VALUES(16320,37115,-6,'Madison, Tennessee 37115',11195,14215);
INSERT INTO "django_geo_db_zipcode" VALUES(16321,37116,-6,'Madison, Tennessee 37116',11195,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16322,37118,-6,'Milton, Tennessee 37118',11196,14216);
INSERT INTO "django_geo_db_zipcode" VALUES(16323,37119,-6,'Mitchellville, Tennessee 37119',11197,14217);
INSERT INTO "django_geo_db_zipcode" VALUES(16324,37121,-6,'Mount Juliet, Tennessee 37121',11198,14191);
INSERT INTO "django_geo_db_zipcode" VALUES(16325,37122,-6,'Mount Juliet, Tennessee 37122',11198,14218);
INSERT INTO "django_geo_db_zipcode" VALUES(16326,37127,-6,'Murfreesboro, Tennessee 37127',11199,14219);
INSERT INTO "django_geo_db_zipcode" VALUES(16327,37128,-6,'Murfreesboro, Tennessee 37128',11199,14220);
INSERT INTO "django_geo_db_zipcode" VALUES(16328,37129,-6,'Murfreesboro, Tennessee 37129',11199,14221);
INSERT INTO "django_geo_db_zipcode" VALUES(16329,37130,-6,'Murfreesboro, Tennessee 37130',11199,14222);
INSERT INTO "django_geo_db_zipcode" VALUES(16330,37131,-6,'Murfreesboro, Tennessee 37131',11199,14184);
INSERT INTO "django_geo_db_zipcode" VALUES(16331,37132,-6,'Murfreesboro, Tennessee 37132',11199,14184);
INSERT INTO "django_geo_db_zipcode" VALUES(16332,37133,-6,'Murfreesboro, Tennessee 37133',11199,14184);
INSERT INTO "django_geo_db_zipcode" VALUES(16333,37134,-6,'New Johnsonville, Tennessee 37134',11200,14223);
INSERT INTO "django_geo_db_zipcode" VALUES(16334,37135,-6,'Nolensville, Tennessee 37135',11201,14224);
INSERT INTO "django_geo_db_zipcode" VALUES(16335,37136,-6,'Norene, Tennessee 37136',11202,14191);
INSERT INTO "django_geo_db_zipcode" VALUES(16336,37137,-6,'Nunnelly, Tennessee 37137',11203,14225);
INSERT INTO "django_geo_db_zipcode" VALUES(16337,37138,-6,'Old Hickory, Tennessee 37138',11204,14226);
INSERT INTO "django_geo_db_zipcode" VALUES(16338,37140,-6,'Only, Tennessee 37140',11205,14227);
INSERT INTO "django_geo_db_zipcode" VALUES(16339,37141,-6,'Orlinda, Tennessee 37141',11206,14228);
INSERT INTO "django_geo_db_zipcode" VALUES(16340,37142,-6,'Palmyra, Tennessee 37142',11207,14229);
INSERT INTO "django_geo_db_zipcode" VALUES(16341,37143,-6,'Pegram, Tennessee 37143',11208,14230);
INSERT INTO "django_geo_db_zipcode" VALUES(16342,37144,-6,'Petersburg, Tennessee 37144',11209,14231);
INSERT INTO "django_geo_db_zipcode" VALUES(16343,37145,-6,'Pleasant Shade, Tennessee 37145',11210,14232);
INSERT INTO "django_geo_db_zipcode" VALUES(16344,37146,-6,'Pleasant View, Tennessee 37146',11211,14233);
INSERT INTO "django_geo_db_zipcode" VALUES(16345,37147,-6,'Pleasantville, Tennessee 37147',11212,14234);
INSERT INTO "django_geo_db_zipcode" VALUES(16346,37148,-6,'Portland, Tennessee 37148',11213,14235);
INSERT INTO "django_geo_db_zipcode" VALUES(16347,37149,-6,'Readyville, Tennessee 37149',11214,14236);
INSERT INTO "django_geo_db_zipcode" VALUES(16348,37150,-6,'Red Boiling Springs, Tennessee 37150',11215,14237);
INSERT INTO "django_geo_db_zipcode" VALUES(16349,37151,-6,'Riddleton, Tennessee 37151',11216,14238);
INSERT INTO "django_geo_db_zipcode" VALUES(16350,37152,-6,'Ridgetop, Tennessee 37152',11217,14239);
INSERT INTO "django_geo_db_zipcode" VALUES(16351,37153,-6,'Rockvale, Tennessee 37153',11218,14240);
INSERT INTO "django_geo_db_zipcode" VALUES(16352,37155,-6,'Saint Bethlehem, Tennessee 37155',11219,14165);
INSERT INTO "django_geo_db_zipcode" VALUES(16353,37160,-6,'Shelbyville, Tennessee 37160',11220,14241);
INSERT INTO "django_geo_db_zipcode" VALUES(16354,37161,-6,'Shelbyville, Tennessee 37161',11220,14242);
INSERT INTO "django_geo_db_zipcode" VALUES(16355,37162,-6,'Shelbyville, Tennessee 37162',11220,14243);
INSERT INTO "django_geo_db_zipcode" VALUES(16356,37165,-6,'Slayden, Tennessee 37165',11221,14244);
INSERT INTO "django_geo_db_zipcode" VALUES(16357,37166,-6,'Smithville, Tennessee 37166',11222,14245);
INSERT INTO "django_geo_db_zipcode" VALUES(16358,37167,-6,'Smyrna, Tennessee 37167',11223,14246);
INSERT INTO "django_geo_db_zipcode" VALUES(16359,37171,-6,'Southside, Tennessee 37171',11224,14247);
INSERT INTO "django_geo_db_zipcode" VALUES(16360,37172,-6,'Springfield, Tennessee 37172',11225,14248);
INSERT INTO "django_geo_db_zipcode" VALUES(16361,37174,-6,'Spring Hill, Tennessee 37174',11226,14249);
INSERT INTO "django_geo_db_zipcode" VALUES(16362,37175,-6,'Stewart, Tennessee 37175',11227,14250);
INSERT INTO "django_geo_db_zipcode" VALUES(16363,37178,-6,'Tennessee Ridge, Tennessee 37178',11228,14251);
INSERT INTO "django_geo_db_zipcode" VALUES(16364,37179,-6,'Thompsons Station, Tennessee 37179',11229,14252);
INSERT INTO "django_geo_db_zipcode" VALUES(16365,37180,-6,'Unionville, Tennessee 37180',11230,14253);
INSERT INTO "django_geo_db_zipcode" VALUES(16366,37181,-6,'Vanleer, Tennessee 37181',11231,14254);
INSERT INTO "django_geo_db_zipcode" VALUES(16367,37183,-6,'Wartrace, Tennessee 37183',11232,14255);
INSERT INTO "django_geo_db_zipcode" VALUES(16368,37184,-6,'Watertown, Tennessee 37184',11233,14256);
INSERT INTO "django_geo_db_zipcode" VALUES(16369,37185,-6,'Waverly, Tennessee 37185',11234,14257);
INSERT INTO "django_geo_db_zipcode" VALUES(16370,37186,-6,'Westmoreland, Tennessee 37186',11235,14258);
INSERT INTO "django_geo_db_zipcode" VALUES(16371,37187,-6,'White Bluff, Tennessee 37187',11236,14259);
INSERT INTO "django_geo_db_zipcode" VALUES(16372,37188,-6,'White House, Tennessee 37188',9966,14260);
INSERT INTO "django_geo_db_zipcode" VALUES(16373,37189,-6,'Whites Creek, Tennessee 37189',11237,14261);
INSERT INTO "django_geo_db_zipcode" VALUES(16374,37190,-6,'Woodbury, Tennessee 37190',11238,14262);
INSERT INTO "django_geo_db_zipcode" VALUES(16375,37191,-6,'Woodlawn, Tennessee 37191',11239,14263);
INSERT INTO "django_geo_db_zipcode" VALUES(16376,37201,-6,'Nashville, Tennessee 37201',11240,14264);
INSERT INTO "django_geo_db_zipcode" VALUES(16377,37202,-6,'Nashville, Tennessee 37202',11240,14265);
INSERT INTO "django_geo_db_zipcode" VALUES(16378,37203,-6,'Nashville, Tennessee 37203',11240,14266);
INSERT INTO "django_geo_db_zipcode" VALUES(16379,37204,-6,'Nashville, Tennessee 37204',11240,14267);
INSERT INTO "django_geo_db_zipcode" VALUES(16380,37205,-6,'Nashville, Tennessee 37205',11240,14268);
INSERT INTO "django_geo_db_zipcode" VALUES(16381,37206,-6,'Nashville, Tennessee 37206',11240,14269);
INSERT INTO "django_geo_db_zipcode" VALUES(16382,37207,-6,'Nashville, Tennessee 37207',11240,14270);
INSERT INTO "django_geo_db_zipcode" VALUES(16383,37208,-6,'Nashville, Tennessee 37208',11240,14271);
INSERT INTO "django_geo_db_zipcode" VALUES(16384,37209,-6,'Nashville, Tennessee 37209',11240,14272);
INSERT INTO "django_geo_db_zipcode" VALUES(16385,37210,-6,'Nashville, Tennessee 37210',11240,14273);
INSERT INTO "django_geo_db_zipcode" VALUES(16386,37211,-6,'Nashville, Tennessee 37211',11240,14274);
INSERT INTO "django_geo_db_zipcode" VALUES(16387,37212,-6,'Nashville, Tennessee 37212',11240,14275);
INSERT INTO "django_geo_db_zipcode" VALUES(16388,37213,-6,'Nashville, Tennessee 37213',11240,14276);
INSERT INTO "django_geo_db_zipcode" VALUES(16389,37214,-6,'Nashville, Tennessee 37214',11240,14277);
INSERT INTO "django_geo_db_zipcode" VALUES(16390,37215,-6,'Nashville, Tennessee 37215',11240,14278);
INSERT INTO "django_geo_db_zipcode" VALUES(16391,37216,-6,'Nashville, Tennessee 37216',11240,14279);
INSERT INTO "django_geo_db_zipcode" VALUES(16392,37217,-6,'Nashville, Tennessee 37217',11240,14280);
INSERT INTO "django_geo_db_zipcode" VALUES(16393,37218,-6,'Nashville, Tennessee 37218',11240,14281);
INSERT INTO "django_geo_db_zipcode" VALUES(16394,37219,-6,'Nashville, Tennessee 37219',11240,14282);
INSERT INTO "django_geo_db_zipcode" VALUES(16395,37220,-6,'Nashville, Tennessee 37220',11240,14283);
INSERT INTO "django_geo_db_zipcode" VALUES(16396,37221,-6,'Nashville, Tennessee 37221',11240,14284);
INSERT INTO "django_geo_db_zipcode" VALUES(16397,37222,-6,'Nashville, Tennessee 37222',11240,14285);
INSERT INTO "django_geo_db_zipcode" VALUES(16398,37224,-6,'Nashville, Tennessee 37224',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16399,37227,-6,'Nashville, Tennessee 37227',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16400,37228,-6,'Nashville, Tennessee 37228',11240,14286);
INSERT INTO "django_geo_db_zipcode" VALUES(16401,37229,-6,'Nashville, Tennessee 37229',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16402,37230,-6,'Nashville, Tennessee 37230',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16403,37232,-6,'Nashville, Tennessee 37232',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16404,37234,-6,'Nashville, Tennessee 37234',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16405,37235,-6,'Nashville, Tennessee 37235',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16406,37236,-6,'Nashville, Tennessee 37236',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16407,37237,-6,'Nashville, Tennessee 37237',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16408,37238,-6,'Nashville, Tennessee 37238',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16409,37239,-6,'Nashville, Tennessee 37239',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16410,37240,-6,'Nashville, Tennessee 37240',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16411,37241,-6,'Nashville, Tennessee 37241',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16412,37242,-6,'Nashville, Tennessee 37242',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16413,37243,-6,'Nashville, Tennessee 37243',11240,14287);
INSERT INTO "django_geo_db_zipcode" VALUES(16414,37244,-6,'Nashville, Tennessee 37244',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16415,37245,-6,'Nashville, Tennessee 37245',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16416,37246,-6,'Nashville, Tennessee 37246',11240,14288);
INSERT INTO "django_geo_db_zipcode" VALUES(16417,37247,-6,'Nashville, Tennessee 37247',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16418,37248,-6,'Nashville, Tennessee 37248',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16419,37249,-6,'Nashville, Tennessee 37249',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16420,37250,-6,'Nashville, Tennessee 37250',11240,14190);
INSERT INTO "django_geo_db_zipcode" VALUES(16421,37301,-6,'Altamont, Tennessee 37301',11241,14289);
INSERT INTO "django_geo_db_zipcode" VALUES(16422,37302,-5,'Apison, Tennessee 37302',11242,14290);
INSERT INTO "django_geo_db_zipcode" VALUES(16423,37303,-5,'Athens, Tennessee 37303',11243,14291);
INSERT INTO "django_geo_db_zipcode" VALUES(16424,37304,-5,'Bakewell, Tennessee 37304',11244,14292);
INSERT INTO "django_geo_db_zipcode" VALUES(16425,37305,-6,'Beersheba Springs, Tennessee 37305',11245,14293);
INSERT INTO "django_geo_db_zipcode" VALUES(16426,37306,-6,'Belvidere, Tennessee 37306',11246,14294);
INSERT INTO "django_geo_db_zipcode" VALUES(16427,37307,-5,'Benton, Tennessee 37307',11247,14295);
INSERT INTO "django_geo_db_zipcode" VALUES(16428,37308,-5,'Birchwood, Tennessee 37308',11248,14296);
INSERT INTO "django_geo_db_zipcode" VALUES(16429,37309,-5,'Calhoun, Tennessee 37309',11249,14297);
INSERT INTO "django_geo_db_zipcode" VALUES(16430,37310,-5,'Charleston, Tennessee 37310',11250,14298);
INSERT INTO "django_geo_db_zipcode" VALUES(16431,37311,-5,'Cleveland, Tennessee 37311',11251,14299);
INSERT INTO "django_geo_db_zipcode" VALUES(16432,37312,-5,'Cleveland, Tennessee 37312',11251,14300);
INSERT INTO "django_geo_db_zipcode" VALUES(16433,37313,-6,'Coalmont, Tennessee 37313',11252,14301);
INSERT INTO "django_geo_db_zipcode" VALUES(16434,37314,-5,'Cokercreek, Tennessee 37314',11253,14302);
INSERT INTO "django_geo_db_zipcode" VALUES(16435,37315,-5,'Collegedale, Tennessee 37315',11254,14303);
INSERT INTO "django_geo_db_zipcode" VALUES(16436,37316,-5,'Conasauga, Tennessee 37316',11255,14304);
INSERT INTO "django_geo_db_zipcode" VALUES(16437,37317,-5,'Copperhill, Tennessee 37317',11256,14305);
INSERT INTO "django_geo_db_zipcode" VALUES(16438,37318,-6,'Cowan, Tennessee 37318',11257,14306);
INSERT INTO "django_geo_db_zipcode" VALUES(16439,37320,-5,'Cleveland, Tennessee 37320',11251,14307);
INSERT INTO "django_geo_db_zipcode" VALUES(16440,37321,-5,'Dayton, Tennessee 37321',11258,14308);
INSERT INTO "django_geo_db_zipcode" VALUES(16441,37322,-5,'Decatur, Tennessee 37322',11259,14309);
INSERT INTO "django_geo_db_zipcode" VALUES(16442,37323,-5,'Cleveland, Tennessee 37323',11251,14310);
INSERT INTO "django_geo_db_zipcode" VALUES(16443,37324,-6,'Decherd, Tennessee 37324',11260,14311);
INSERT INTO "django_geo_db_zipcode" VALUES(16444,37325,-5,'Delano, Tennessee 37325',11261,14312);
INSERT INTO "django_geo_db_zipcode" VALUES(16445,37326,-5,'Ducktown, Tennessee 37326',11262,14313);
INSERT INTO "django_geo_db_zipcode" VALUES(16446,37327,-6,'Dunlap, Tennessee 37327',11263,14314);
INSERT INTO "django_geo_db_zipcode" VALUES(16447,37328,-6,'Elora, Tennessee 37328',11264,14315);
INSERT INTO "django_geo_db_zipcode" VALUES(16448,37329,-5,'Englewood, Tennessee 37329',11265,14316);
INSERT INTO "django_geo_db_zipcode" VALUES(16449,37330,-6,'Estill Springs, Tennessee 37330',11266,14317);
INSERT INTO "django_geo_db_zipcode" VALUES(16450,37331,-5,'Etowah, Tennessee 37331',11267,14318);
INSERT INTO "django_geo_db_zipcode" VALUES(16451,37332,-5,'Evensville, Tennessee 37332',11268,14319);
INSERT INTO "django_geo_db_zipcode" VALUES(16452,37333,-5,'Farner, Tennessee 37333',11269,14320);
INSERT INTO "django_geo_db_zipcode" VALUES(16453,37334,-6,'Fayetteville, Tennessee 37334',11270,14321);
INSERT INTO "django_geo_db_zipcode" VALUES(16454,37335,-6,'Flintville, Tennessee 37335',11271,14322);
INSERT INTO "django_geo_db_zipcode" VALUES(16455,37336,-5,'Georgetown, Tennessee 37336',11272,14323);
INSERT INTO "django_geo_db_zipcode" VALUES(16456,37337,-6,'Grandview, Tennessee 37337',11273,14324);
INSERT INTO "django_geo_db_zipcode" VALUES(16457,37338,-6,'Graysville, Tennessee 37338',11274,14325);
INSERT INTO "django_geo_db_zipcode" VALUES(16458,37339,-6,'Gruetli Laager, Tennessee 37339',11275,14326);
INSERT INTO "django_geo_db_zipcode" VALUES(16459,37340,-6,'Guild, Tennessee 37340',11276,14327);
INSERT INTO "django_geo_db_zipcode" VALUES(16460,37341,-5,'Harrison, Tennessee 37341',11277,14328);
INSERT INTO "django_geo_db_zipcode" VALUES(16461,37342,-6,'Hillsboro, Tennessee 37342',11278,14329);
INSERT INTO "django_geo_db_zipcode" VALUES(16462,37343,-5,'Hixson, Tennessee 37343',11279,14330);
INSERT INTO "django_geo_db_zipcode" VALUES(16463,37345,-6,'Huntland, Tennessee 37345',11280,14331);
INSERT INTO "django_geo_db_zipcode" VALUES(16464,37347,-6,'Jasper, Tennessee 37347',11281,14332);
INSERT INTO "django_geo_db_zipcode" VALUES(16465,37348,-6,'Kelso, Tennessee 37348',11282,14333);
INSERT INTO "django_geo_db_zipcode" VALUES(16466,37349,-6,'Manchester, Tennessee 37349',11283,14334);
INSERT INTO "django_geo_db_zipcode" VALUES(16467,37350,-5,'Lookout Mountain, Tennessee 37350',11284,14335);
INSERT INTO "django_geo_db_zipcode" VALUES(16468,37351,-5,'Lupton City, Tennessee 37351',11285,14336);
INSERT INTO "django_geo_db_zipcode" VALUES(16469,37352,-6,'Lynchburg, Tennessee 37352',11286,14337);
INSERT INTO "django_geo_db_zipcode" VALUES(16470,37353,-5,'McDonald, Tennessee 37353',11287,14338);
INSERT INTO "django_geo_db_zipcode" VALUES(16471,37354,-5,'Madisonville, Tennessee 37354',11288,14339);
INSERT INTO "django_geo_db_zipcode" VALUES(16472,37355,-6,'Manchester, Tennessee 37355',11283,14340);
INSERT INTO "django_geo_db_zipcode" VALUES(16473,37356,-6,'Monteagle, Tennessee 37356',11289,14341);
INSERT INTO "django_geo_db_zipcode" VALUES(16474,37357,-6,'Morrison, Tennessee 37357',11290,14342);
INSERT INTO "django_geo_db_zipcode" VALUES(16475,37359,-6,'Mulberry, Tennessee 37359',11291,14343);
INSERT INTO "django_geo_db_zipcode" VALUES(16476,37360,-6,'Normandy, Tennessee 37360',11292,14344);
INSERT INTO "django_geo_db_zipcode" VALUES(16477,37361,-5,'Ocoee, Tennessee 37361',11293,14345);
INSERT INTO "django_geo_db_zipcode" VALUES(16478,37362,-5,'Oldfort, Tennessee 37362',11294,14346);
INSERT INTO "django_geo_db_zipcode" VALUES(16479,37363,-5,'Ooltewah, Tennessee 37363',11295,14347);
INSERT INTO "django_geo_db_zipcode" VALUES(16480,37364,-5,'Cleveland, Tennessee 37364',11251,14307);
INSERT INTO "django_geo_db_zipcode" VALUES(16481,37365,-6,'Palmer, Tennessee 37365',11296,14348);
INSERT INTO "django_geo_db_zipcode" VALUES(16482,37366,-6,'Pelham, Tennessee 37366',11297,14349);
INSERT INTO "django_geo_db_zipcode" VALUES(16483,37367,-6,'Pikeville, Tennessee 37367',11298,14350);
INSERT INTO "django_geo_db_zipcode" VALUES(16484,37369,-5,'Reliance, Tennessee 37369',11299,14351);
INSERT INTO "django_geo_db_zipcode" VALUES(16485,37370,-5,'Riceville, Tennessee 37370',11300,14352);
INSERT INTO "django_geo_db_zipcode" VALUES(16486,37371,-5,'Athens, Tennessee 37371',11243,14353);
INSERT INTO "django_geo_db_zipcode" VALUES(16487,37372,-6,'Saint Andrews, Tennessee 37372',11301,14354);
INSERT INTO "django_geo_db_zipcode" VALUES(16488,37373,-5,'Sale Creek, Tennessee 37373',11302,14355);
INSERT INTO "django_geo_db_zipcode" VALUES(16489,37374,-6,'Sequatchie, Tennessee 37374',11303,14356);
INSERT INTO "django_geo_db_zipcode" VALUES(16490,37375,-6,'Sewanee, Tennessee 37375',11304,14357);
INSERT INTO "django_geo_db_zipcode" VALUES(16491,37376,-6,'Sherwood, Tennessee 37376',11305,14358);
INSERT INTO "django_geo_db_zipcode" VALUES(16492,37377,-5,'Signal Mountain, Tennessee 37377',11306,14359);
INSERT INTO "django_geo_db_zipcode" VALUES(16493,37378,-6,'Smartt, Tennessee 37378',11307,14214);
INSERT INTO "django_geo_db_zipcode" VALUES(16494,37379,-5,'Soddy Daisy, Tennessee 37379',11308,14360);
INSERT INTO "django_geo_db_zipcode" VALUES(16495,37380,-6,'South Pittsburg, Tennessee 37380',11309,14361);
INSERT INTO "django_geo_db_zipcode" VALUES(16496,37381,-5,'Spring City, Tennessee 37381',11310,14362);
INSERT INTO "django_geo_db_zipcode" VALUES(16497,37382,-6,'Summitville, Tennessee 37382',11311,14334);
INSERT INTO "django_geo_db_zipcode" VALUES(16498,37383,-6,'Sewanee, Tennessee 37383',11304,14363);
INSERT INTO "django_geo_db_zipcode" VALUES(16499,37384,-5,'Soddy Daisy, Tennessee 37384',11308,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16500,37385,-5,'Tellico Plains, Tennessee 37385',11312,14365);
INSERT INTO "django_geo_db_zipcode" VALUES(16501,37387,-6,'Tracy City, Tennessee 37387',11313,14366);
INSERT INTO "django_geo_db_zipcode" VALUES(16502,37388,-6,'Tullahoma, Tennessee 37388',11314,14367);
INSERT INTO "django_geo_db_zipcode" VALUES(16503,37389,-6,'Arnold AFB, Tennessee 37389',11315,14334);
INSERT INTO "django_geo_db_zipcode" VALUES(16504,37391,-5,'Turtletown, Tennessee 37391',11316,14368);
INSERT INTO "django_geo_db_zipcode" VALUES(16505,37394,-6,'Viola, Tennessee 37394',11317,14369);
INSERT INTO "django_geo_db_zipcode" VALUES(16506,37395,-5,'Watts Bar Dam, Tennessee 37395',11318,14370);
INSERT INTO "django_geo_db_zipcode" VALUES(16507,37396,-6,'Whiteside, Tennessee 37396',11319,14371);
INSERT INTO "django_geo_db_zipcode" VALUES(16508,37397,-6,'Whitwell, Tennessee 37397',11320,14372);
INSERT INTO "django_geo_db_zipcode" VALUES(16509,37398,-6,'Winchester, Tennessee 37398',11321,14373);
INSERT INTO "django_geo_db_zipcode" VALUES(16510,37401,-5,'Chattanooga, Tennessee 37401',11322,14374);
INSERT INTO "django_geo_db_zipcode" VALUES(16511,37402,-5,'Chattanooga, Tennessee 37402',11322,14375);
INSERT INTO "django_geo_db_zipcode" VALUES(16512,37403,-5,'Chattanooga, Tennessee 37403',11322,14376);
INSERT INTO "django_geo_db_zipcode" VALUES(16513,37404,-5,'Chattanooga, Tennessee 37404',11322,14377);
INSERT INTO "django_geo_db_zipcode" VALUES(16514,37405,-5,'Chattanooga, Tennessee 37405',11322,14378);
INSERT INTO "django_geo_db_zipcode" VALUES(16515,37406,-5,'Chattanooga, Tennessee 37406',11322,14379);
INSERT INTO "django_geo_db_zipcode" VALUES(16516,37407,-5,'Chattanooga, Tennessee 37407',11322,14380);
INSERT INTO "django_geo_db_zipcode" VALUES(16517,37408,-5,'Chattanooga, Tennessee 37408',11322,14381);
INSERT INTO "django_geo_db_zipcode" VALUES(16518,37409,-5,'Chattanooga, Tennessee 37409',11322,14382);
INSERT INTO "django_geo_db_zipcode" VALUES(16519,37410,-5,'Chattanooga, Tennessee 37410',11322,14383);
INSERT INTO "django_geo_db_zipcode" VALUES(16520,37411,-5,'Chattanooga, Tennessee 37411',11322,14384);
INSERT INTO "django_geo_db_zipcode" VALUES(16521,37412,-5,'Chattanooga, Tennessee 37412',11322,14385);
INSERT INTO "django_geo_db_zipcode" VALUES(16522,37414,-5,'Chattanooga, Tennessee 37414',11322,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16523,37415,-5,'Chattanooga, Tennessee 37415',11322,14386);
INSERT INTO "django_geo_db_zipcode" VALUES(16524,37416,-5,'Chattanooga, Tennessee 37416',11322,14387);
INSERT INTO "django_geo_db_zipcode" VALUES(16525,37419,-5,'Chattanooga, Tennessee 37419',11322,14388);
INSERT INTO "django_geo_db_zipcode" VALUES(16526,37421,-5,'Chattanooga, Tennessee 37421',11322,14389);
INSERT INTO "django_geo_db_zipcode" VALUES(16527,37422,-5,'Chattanooga, Tennessee 37422',11322,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16528,37424,-5,'Chattanooga, Tennessee 37424',11322,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16529,37450,-5,'Chattanooga, Tennessee 37450',11322,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16530,37499,-5,'Chattanooga, Tennessee 37499',11322,14364);
INSERT INTO "django_geo_db_zipcode" VALUES(16531,37501,-6,'Memphis, Tennessee 37501',11323,14390);
INSERT INTO "django_geo_db_zipcode" VALUES(16532,37601,-5,'Johnson City, Tennessee 37601',11324,14391);
INSERT INTO "django_geo_db_zipcode" VALUES(16533,37602,-5,'Johnson City, Tennessee 37602',11324,14392);
INSERT INTO "django_geo_db_zipcode" VALUES(16534,37604,-5,'Johnson City, Tennessee 37604',11324,14393);
INSERT INTO "django_geo_db_zipcode" VALUES(16535,37605,-5,'Johnson City, Tennessee 37605',11324,14394);
INSERT INTO "django_geo_db_zipcode" VALUES(16536,37614,-5,'Johnson City, Tennessee 37614',11324,14395);
INSERT INTO "django_geo_db_zipcode" VALUES(16537,37615,-5,'Johnson City, Tennessee 37615',11324,14396);
INSERT INTO "django_geo_db_zipcode" VALUES(16538,37616,-5,'Afton, Tennessee 37616',11325,14397);
INSERT INTO "django_geo_db_zipcode" VALUES(16539,37617,-5,'Blountville, Tennessee 37617',11326,14398);
INSERT INTO "django_geo_db_zipcode" VALUES(16540,37618,-5,'Bluff City, Tennessee 37618',11327,14399);
INSERT INTO "django_geo_db_zipcode" VALUES(16541,37620,-5,'Bristol, Tennessee 37620',11328,14400);
INSERT INTO "django_geo_db_zipcode" VALUES(16542,37621,-5,'Bristol, Tennessee 37621',11328,14401);
INSERT INTO "django_geo_db_zipcode" VALUES(16543,37625,-5,'Bristol, Tennessee 37625',11328,14401);
INSERT INTO "django_geo_db_zipcode" VALUES(16544,37640,-5,'Butler, Tennessee 37640',11329,14402);
INSERT INTO "django_geo_db_zipcode" VALUES(16545,37641,-5,'Chuckey, Tennessee 37641',11330,14403);
INSERT INTO "django_geo_db_zipcode" VALUES(16546,37642,-5,'Church Hill, Tennessee 37642',11331,14404);
INSERT INTO "django_geo_db_zipcode" VALUES(16547,37643,-5,'Elizabethton, Tennessee 37643',11332,14405);
INSERT INTO "django_geo_db_zipcode" VALUES(16548,37644,-5,'Elizabethton, Tennessee 37644',11332,14406);
INSERT INTO "django_geo_db_zipcode" VALUES(16549,37645,-5,'Mount Carmel, Tennessee 37645',11333,14407);
INSERT INTO "django_geo_db_zipcode" VALUES(16550,37650,-5,'Erwin, Tennessee 37650',11334,14408);
INSERT INTO "django_geo_db_zipcode" VALUES(16551,37656,-5,'Fall Branch, Tennessee 37656',11335,14409);
INSERT INTO "django_geo_db_zipcode" VALUES(16552,37657,-5,'Flag Pond, Tennessee 37657',11336,14410);
INSERT INTO "django_geo_db_zipcode" VALUES(16553,37658,-5,'Hampton, Tennessee 37658',11337,14411);
INSERT INTO "django_geo_db_zipcode" VALUES(16554,37659,-5,'Jonesborough, Tennessee 37659',11338,14412);
INSERT INTO "django_geo_db_zipcode" VALUES(16555,37660,-5,'Kingsport, Tennessee 37660',11339,14413);
INSERT INTO "django_geo_db_zipcode" VALUES(16556,37662,-5,'Kingsport, Tennessee 37662',11339,14414);
INSERT INTO "django_geo_db_zipcode" VALUES(16557,37663,-5,'Kingsport, Tennessee 37663',11339,14415);
INSERT INTO "django_geo_db_zipcode" VALUES(16558,37664,-5,'Kingsport, Tennessee 37664',11339,14416);
INSERT INTO "django_geo_db_zipcode" VALUES(16559,37665,-5,'Kingsport, Tennessee 37665',11339,14417);
INSERT INTO "django_geo_db_zipcode" VALUES(16560,37669,-5,'Kingsport, Tennessee 37669',11339,14401);
INSERT INTO "django_geo_db_zipcode" VALUES(16561,37680,-5,'Laurel Bloomery, Tennessee 37680',11340,14418);
INSERT INTO "django_geo_db_zipcode" VALUES(16562,37681,-5,'Limestone, Tennessee 37681',11341,14419);
INSERT INTO "django_geo_db_zipcode" VALUES(16563,37682,-5,'Milligan College, Tennessee 37682',11342,14420);
INSERT INTO "django_geo_db_zipcode" VALUES(16564,37683,-5,'Mountain City, Tennessee 37683',11343,14421);
INSERT INTO "django_geo_db_zipcode" VALUES(16565,37684,-5,'Mountain Home, Tennessee 37684',11344,14422);
INSERT INTO "django_geo_db_zipcode" VALUES(16566,37686,-5,'Piney Flats, Tennessee 37686',11345,14423);
INSERT INTO "django_geo_db_zipcode" VALUES(16567,37687,-5,'Roan Mountain, Tennessee 37687',11346,14424);
INSERT INTO "django_geo_db_zipcode" VALUES(16568,37688,-5,'Shady Valley, Tennessee 37688',11347,14425);
INSERT INTO "django_geo_db_zipcode" VALUES(16569,37690,-5,'Telford, Tennessee 37690',11348,14426);
INSERT INTO "django_geo_db_zipcode" VALUES(16570,37691,-5,'Trade, Tennessee 37691',11349,14427);
INSERT INTO "django_geo_db_zipcode" VALUES(16571,37692,-5,'Unicoi, Tennessee 37692',11350,14428);
INSERT INTO "django_geo_db_zipcode" VALUES(16572,37694,-5,'Watauga, Tennessee 37694',11351,14429);
INSERT INTO "django_geo_db_zipcode" VALUES(16573,37699,-5,'Piney Flats, Tennessee 37699',11345,14401);
INSERT INTO "django_geo_db_zipcode" VALUES(16574,37701,-5,'Alcoa, Tennessee 37701',11352,14430);
INSERT INTO "django_geo_db_zipcode" VALUES(16575,37705,-5,'Andersonville, Tennessee 37705',11353,14431);
INSERT INTO "django_geo_db_zipcode" VALUES(16576,37707,-5,'Arthur, Tennessee 37707',11354,14432);
INSERT INTO "django_geo_db_zipcode" VALUES(16577,37708,-5,'Bean Station, Tennessee 37708',11355,14433);
INSERT INTO "django_geo_db_zipcode" VALUES(16578,37709,-5,'Blaine, Tennessee 37709',11356,14434);
INSERT INTO "django_geo_db_zipcode" VALUES(16579,37710,-5,'Briceville, Tennessee 37710',11357,14435);
INSERT INTO "django_geo_db_zipcode" VALUES(16580,37711,-5,'Bulls Gap, Tennessee 37711',11358,14436);
INSERT INTO "django_geo_db_zipcode" VALUES(16581,37713,-5,'Bybee, Tennessee 37713',11359,14437);
INSERT INTO "django_geo_db_zipcode" VALUES(16582,37714,-5,'Caryville, Tennessee 37714',11360,14438);
INSERT INTO "django_geo_db_zipcode" VALUES(16583,37715,-5,'Clairfield, Tennessee 37715',11361,14439);
INSERT INTO "django_geo_db_zipcode" VALUES(16584,37716,-5,'Clinton, Tennessee 37716',11362,14440);
INSERT INTO "django_geo_db_zipcode" VALUES(16585,37717,-5,'Clinton, Tennessee 37717',11362,14441);
INSERT INTO "django_geo_db_zipcode" VALUES(16586,37719,-5,'Coalfield, Tennessee 37719',11363,14442);
INSERT INTO "django_geo_db_zipcode" VALUES(16587,37721,-5,'Corryton, Tennessee 37721',11364,14443);
INSERT INTO "django_geo_db_zipcode" VALUES(16588,37722,-5,'Cosby, Tennessee 37722',11365,14444);
INSERT INTO "django_geo_db_zipcode" VALUES(16589,37723,-6,'Crab Orchard, Tennessee 37723',11366,14445);
INSERT INTO "django_geo_db_zipcode" VALUES(16590,37724,-5,'Cumberland Gap, Tennessee 37724',11367,14446);
INSERT INTO "django_geo_db_zipcode" VALUES(16591,37725,-5,'Dandridge, Tennessee 37725',11368,14447);
INSERT INTO "django_geo_db_zipcode" VALUES(16592,37726,-5,'Deer Lodge, Tennessee 37726',11369,14448);
INSERT INTO "django_geo_db_zipcode" VALUES(16593,37727,-5,'Del Rio, Tennessee 37727',11370,14449);
INSERT INTO "django_geo_db_zipcode" VALUES(16594,37729,-5,'Duff, Tennessee 37729',11371,14450);
INSERT INTO "django_geo_db_zipcode" VALUES(16595,37730,-5,'Eagan, Tennessee 37730',11372,14451);
INSERT INTO "django_geo_db_zipcode" VALUES(16596,37731,-5,'Eidson, Tennessee 37731',11373,14452);
INSERT INTO "django_geo_db_zipcode" VALUES(16597,37732,-5,'Elgin, Tennessee 37732',11374,14453);
INSERT INTO "django_geo_db_zipcode" VALUES(16598,37733,-5,'Rugby, Tennessee 37733',11375,14454);
INSERT INTO "django_geo_db_zipcode" VALUES(16599,37737,-5,'Friendsville, Tennessee 37737',11376,14455);
INSERT INTO "django_geo_db_zipcode" VALUES(16600,37738,-5,'Gatlinburg, Tennessee 37738',11377,14456);
INSERT INTO "django_geo_db_zipcode" VALUES(16601,37742,-5,'Greenback, Tennessee 37742',11378,14457);
INSERT INTO "django_geo_db_zipcode" VALUES(16602,37743,-5,'Greeneville, Tennessee 37743',11379,14458);
INSERT INTO "django_geo_db_zipcode" VALUES(16603,37744,-5,'Greeneville, Tennessee 37744',11379,14459);
INSERT INTO "django_geo_db_zipcode" VALUES(16604,37745,-5,'Greeneville, Tennessee 37745',11379,14460);
INSERT INTO "django_geo_db_zipcode" VALUES(16605,37748,-5,'Harriman, Tennessee 37748',11380,14461);
INSERT INTO "django_geo_db_zipcode" VALUES(16606,37752,-5,'Harrogate, Tennessee 37752',11381,14462);
INSERT INTO "django_geo_db_zipcode" VALUES(16607,37753,-5,'Hartford, Tennessee 37753',11382,14463);
INSERT INTO "django_geo_db_zipcode" VALUES(16608,37754,-5,'Heiskell, Tennessee 37754',11383,14464);
INSERT INTO "django_geo_db_zipcode" VALUES(16609,37755,-5,'Helenwood, Tennessee 37755',11384,14465);
INSERT INTO "django_geo_db_zipcode" VALUES(16610,37756,-5,'Huntsville, Tennessee 37756',11385,14466);
INSERT INTO "django_geo_db_zipcode" VALUES(16611,37757,-5,'Jacksboro, Tennessee 37757',11386,14467);
INSERT INTO "django_geo_db_zipcode" VALUES(16612,37760,-5,'Jefferson City, Tennessee 37760',11387,14468);
INSERT INTO "django_geo_db_zipcode" VALUES(16613,37762,-5,'Jellico, Tennessee 37762',11388,14469);
INSERT INTO "django_geo_db_zipcode" VALUES(16614,37763,-5,'Kingston, Tennessee 37763',11389,14470);
INSERT INTO "django_geo_db_zipcode" VALUES(16615,37764,-5,'Kodak, Tennessee 37764',11390,14471);
INSERT INTO "django_geo_db_zipcode" VALUES(16616,37765,-5,'Kyles Ford, Tennessee 37765',11391,14472);
INSERT INTO "django_geo_db_zipcode" VALUES(16617,37766,-5,'La Follette, Tennessee 37766',11392,14473);
INSERT INTO "django_geo_db_zipcode" VALUES(16618,37769,-5,'Lake City, Tennessee 37769',11393,14474);
INSERT INTO "django_geo_db_zipcode" VALUES(16619,37770,-5,'Lancing, Tennessee 37770',11394,14475);
INSERT INTO "django_geo_db_zipcode" VALUES(16620,37771,-5,'Lenoir City, Tennessee 37771',11395,14476);
INSERT INTO "django_geo_db_zipcode" VALUES(16621,37772,-5,'Lenoir City, Tennessee 37772',11395,14477);
INSERT INTO "django_geo_db_zipcode" VALUES(16622,37773,-5,'Lone Mountain, Tennessee 37773',11396,14478);
INSERT INTO "django_geo_db_zipcode" VALUES(16623,37774,-5,'Loudon, Tennessee 37774',11397,14479);
INSERT INTO "django_geo_db_zipcode" VALUES(16624,37777,-5,'Louisville, Tennessee 37777',11398,14480);
INSERT INTO "django_geo_db_zipcode" VALUES(16625,37778,-5,'Lowland, Tennessee 37778',11399,14481);
INSERT INTO "django_geo_db_zipcode" VALUES(16626,37779,-5,'Luttrell, Tennessee 37779',11400,14482);
INSERT INTO "django_geo_db_zipcode" VALUES(16627,37801,-5,'Maryville, Tennessee 37801',11401,14483);
INSERT INTO "django_geo_db_zipcode" VALUES(16628,37802,-5,'Maryville, Tennessee 37802',11401,14484);
INSERT INTO "django_geo_db_zipcode" VALUES(16629,37803,-5,'Maryville, Tennessee 37803',11401,14485);
INSERT INTO "django_geo_db_zipcode" VALUES(16630,37804,-5,'Maryville, Tennessee 37804',11401,14486);
INSERT INTO "django_geo_db_zipcode" VALUES(16631,37806,-5,'Mascot, Tennessee 37806',11402,14487);
INSERT INTO "django_geo_db_zipcode" VALUES(16632,37807,-5,'Maynardville, Tennessee 37807',11403,14488);
INSERT INTO "django_geo_db_zipcode" VALUES(16633,37809,-5,'Midway, Tennessee 37809',11404,14489);
INSERT INTO "django_geo_db_zipcode" VALUES(16634,37810,-5,'Mohawk, Tennessee 37810',11405,14490);
INSERT INTO "django_geo_db_zipcode" VALUES(16635,37811,-5,'Mooresburg, Tennessee 37811',11406,14491);
INSERT INTO "django_geo_db_zipcode" VALUES(16636,37813,-5,'Morristown, Tennessee 37813',11407,14492);
INSERT INTO "django_geo_db_zipcode" VALUES(16637,37814,-5,'Morristown, Tennessee 37814',11407,14493);
INSERT INTO "django_geo_db_zipcode" VALUES(16638,37815,-5,'Morristown, Tennessee 37815',11407,14481);
INSERT INTO "django_geo_db_zipcode" VALUES(16639,37816,-5,'Morristown, Tennessee 37816',11407,14481);
INSERT INTO "django_geo_db_zipcode" VALUES(16640,37818,-5,'Mosheim, Tennessee 37818',11408,14494);
INSERT INTO "django_geo_db_zipcode" VALUES(16641,37819,-5,'Newcomb, Tennessee 37819',11409,14495);
INSERT INTO "django_geo_db_zipcode" VALUES(16642,37820,-5,'New Market, Tennessee 37820',11410,14496);
INSERT INTO "django_geo_db_zipcode" VALUES(16643,37821,-5,'Newport, Tennessee 37821',11411,14497);
INSERT INTO "django_geo_db_zipcode" VALUES(16644,37822,-5,'Newport, Tennessee 37822',11411,14498);
INSERT INTO "django_geo_db_zipcode" VALUES(16645,37824,-5,'New Tazewell, Tennessee 37824',11412,14499);
INSERT INTO "django_geo_db_zipcode" VALUES(16646,37825,-5,'New Tazewell, Tennessee 37825',11412,14500);
INSERT INTO "django_geo_db_zipcode" VALUES(16647,37826,-5,'Niota, Tennessee 37826',11413,14501);
INSERT INTO "django_geo_db_zipcode" VALUES(16648,37828,-5,'Norris, Tennessee 37828',11414,14502);
INSERT INTO "django_geo_db_zipcode" VALUES(16649,37829,-5,'Oakdale, Tennessee 37829',11415,14503);
INSERT INTO "django_geo_db_zipcode" VALUES(16650,37830,-5,'Oak Ridge, Tennessee 37830',11416,14504);
INSERT INTO "django_geo_db_zipcode" VALUES(16651,37831,-5,'Oak Ridge, Tennessee 37831',11416,14505);
INSERT INTO "django_geo_db_zipcode" VALUES(16652,37838,-6,'Sewanee, Tennessee 37838',11304,14506);
INSERT INTO "django_geo_db_zipcode" VALUES(16653,37840,-5,'Oliver Springs, Tennessee 37840',11417,14507);
INSERT INTO "django_geo_db_zipcode" VALUES(16654,37841,-5,'Oneida, Tennessee 37841',11418,14508);
INSERT INTO "django_geo_db_zipcode" VALUES(16655,37842,-6,'Ozone, Tennessee 37842',11419,14509);
INSERT INTO "django_geo_db_zipcode" VALUES(16656,37843,-5,'Parrottsville, Tennessee 37843',11420,14510);
INSERT INTO "django_geo_db_zipcode" VALUES(16657,37845,-5,'Petros, Tennessee 37845',11421,14511);
INSERT INTO "django_geo_db_zipcode" VALUES(16658,37846,-5,'Philadelphia, Tennessee 37846',11422,14512);
INSERT INTO "django_geo_db_zipcode" VALUES(16659,37847,-5,'Pioneer, Tennessee 37847',11423,14513);
INSERT INTO "django_geo_db_zipcode" VALUES(16660,37848,-5,'Powder Springs, Tennessee 37848',11424,14514);
INSERT INTO "django_geo_db_zipcode" VALUES(16661,37849,-5,'Powell, Tennessee 37849',11425,14515);
INSERT INTO "django_geo_db_zipcode" VALUES(16662,37851,-5,'Pruden, Tennessee 37851',11426,14516);
INSERT INTO "django_geo_db_zipcode" VALUES(16663,37852,-5,'Robbins, Tennessee 37852',11427,14517);
INSERT INTO "django_geo_db_zipcode" VALUES(16664,37853,-5,'Rockford, Tennessee 37853',11428,14518);
INSERT INTO "django_geo_db_zipcode" VALUES(16665,37854,-5,'Rockwood, Tennessee 37854',11429,14519);
INSERT INTO "django_geo_db_zipcode" VALUES(16666,37857,-5,'Rogersville, Tennessee 37857',11430,14520);
INSERT INTO "django_geo_db_zipcode" VALUES(16667,37860,-5,'Russellville, Tennessee 37860',11431,14521);
INSERT INTO "django_geo_db_zipcode" VALUES(16668,37861,-5,'Rutledge, Tennessee 37861',11432,14522);
INSERT INTO "django_geo_db_zipcode" VALUES(16669,37862,-5,'Sevierville, Tennessee 37862',11433,14523);
INSERT INTO "django_geo_db_zipcode" VALUES(16670,37863,-5,'Pigeon Forge, Tennessee 37863',11434,14524);
INSERT INTO "django_geo_db_zipcode" VALUES(16671,37864,-5,'Sevierville, Tennessee 37864',11433,14525);
INSERT INTO "django_geo_db_zipcode" VALUES(16672,37865,-5,'Seymour, Tennessee 37865',11435,14526);
INSERT INTO "django_geo_db_zipcode" VALUES(16673,37866,-5,'Sharps Chapel, Tennessee 37866',11436,14527);
INSERT INTO "django_geo_db_zipcode" VALUES(16674,37867,-5,'Shawanee, Tennessee 37867',11437,14528);
INSERT INTO "django_geo_db_zipcode" VALUES(16675,37868,-5,'Pigeon Forge, Tennessee 37868',11434,14529);
INSERT INTO "django_geo_db_zipcode" VALUES(16676,37869,-5,'Sneedville, Tennessee 37869',11438,14530);
INSERT INTO "django_geo_db_zipcode" VALUES(16677,37870,-5,'Speedwell, Tennessee 37870',11439,14531);
INSERT INTO "django_geo_db_zipcode" VALUES(16678,37871,-5,'Strawberry Plains, Tennessee 37871',11440,14532);
INSERT INTO "django_geo_db_zipcode" VALUES(16679,37872,-5,'Sunbright, Tennessee 37872',11441,14533);
INSERT INTO "django_geo_db_zipcode" VALUES(16680,37873,-5,'Surgoinsville, Tennessee 37873',11442,14534);
INSERT INTO "django_geo_db_zipcode" VALUES(16681,37874,-5,'Sweetwater, Tennessee 37874',11443,14535);
INSERT INTO "django_geo_db_zipcode" VALUES(16682,37876,-5,'Sevierville, Tennessee 37876',11433,14536);
INSERT INTO "django_geo_db_zipcode" VALUES(16683,37877,-5,'Talbott, Tennessee 37877',11444,14537);
INSERT INTO "django_geo_db_zipcode" VALUES(16684,37878,-5,'Tallassee, Tennessee 37878',11445,14538);
INSERT INTO "django_geo_db_zipcode" VALUES(16685,37879,-5,'Tazewell, Tennessee 37879',11446,14539);
INSERT INTO "django_geo_db_zipcode" VALUES(16686,37880,-5,'Ten Mile, Tennessee 37880',11447,14540);
INSERT INTO "django_geo_db_zipcode" VALUES(16687,37881,-5,'Thorn Hill, Tennessee 37881',11448,14541);
INSERT INTO "django_geo_db_zipcode" VALUES(16688,37882,-5,'Townsend, Tennessee 37882',11449,14542);
INSERT INTO "django_geo_db_zipcode" VALUES(16689,37885,-5,'Vonore, Tennessee 37885',11450,14543);
INSERT INTO "django_geo_db_zipcode" VALUES(16690,37886,-5,'Walland, Tennessee 37886',11451,14544);
INSERT INTO "django_geo_db_zipcode" VALUES(16691,37887,-5,'Wartburg, Tennessee 37887',11452,14545);
INSERT INTO "django_geo_db_zipcode" VALUES(16692,37888,-5,'Washburn, Tennessee 37888',11453,14546);
INSERT INTO "django_geo_db_zipcode" VALUES(16693,37890,-5,'White Pine, Tennessee 37890',11454,14547);
INSERT INTO "django_geo_db_zipcode" VALUES(16694,37891,-5,'Whitesburg, Tennessee 37891',11455,14548);
INSERT INTO "django_geo_db_zipcode" VALUES(16695,37892,-5,'Winfield, Tennessee 37892',11456,14549);
INSERT INTO "django_geo_db_zipcode" VALUES(16696,37893,-5,'Winona, Tennessee 37893',11457,14550);
INSERT INTO "django_geo_db_zipcode" VALUES(16697,37901,-5,'Knoxville, Tennessee 37901',11458,14551);
INSERT INTO "django_geo_db_zipcode" VALUES(16698,37902,-5,'Knoxville, Tennessee 37902',11458,14552);
INSERT INTO "django_geo_db_zipcode" VALUES(16699,37909,-5,'Knoxville, Tennessee 37909',11458,14553);
INSERT INTO "django_geo_db_zipcode" VALUES(16700,37912,-5,'Knoxville, Tennessee 37912',11458,14554);
INSERT INTO "django_geo_db_zipcode" VALUES(16701,37913,-5,'Knoxville, Tennessee 37913',11458,14555);
INSERT INTO "django_geo_db_zipcode" VALUES(16702,37914,-5,'Knoxville, Tennessee 37914',11458,14556);
INSERT INTO "django_geo_db_zipcode" VALUES(16703,37915,-5,'Knoxville, Tennessee 37915',11458,14557);
INSERT INTO "django_geo_db_zipcode" VALUES(16704,37916,-5,'Knoxville, Tennessee 37916',11458,14558);
INSERT INTO "django_geo_db_zipcode" VALUES(16705,37917,-5,'Knoxville, Tennessee 37917',11458,14559);
INSERT INTO "django_geo_db_zipcode" VALUES(16706,37918,-5,'Knoxville, Tennessee 37918',11458,14560);
INSERT INTO "django_geo_db_zipcode" VALUES(16707,37919,-5,'Knoxville, Tennessee 37919',11458,14561);
INSERT INTO "django_geo_db_zipcode" VALUES(16708,37920,-5,'Knoxville, Tennessee 37920',11458,14562);
INSERT INTO "django_geo_db_zipcode" VALUES(16709,37921,-5,'Knoxville, Tennessee 37921',11458,14563);
INSERT INTO "django_geo_db_zipcode" VALUES(16710,37922,-5,'Knoxville, Tennessee 37922',11458,14564);
INSERT INTO "django_geo_db_zipcode" VALUES(16711,37923,-5,'Knoxville, Tennessee 37923',11458,14565);
INSERT INTO "django_geo_db_zipcode" VALUES(16712,37924,-5,'Knoxville, Tennessee 37924',11458,14566);
INSERT INTO "django_geo_db_zipcode" VALUES(16713,37927,-5,'Knoxville, Tennessee 37927',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16714,37928,-5,'Knoxville, Tennessee 37928',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16715,37929,-5,'Knoxville, Tennessee 37929',11458,14568);
INSERT INTO "django_geo_db_zipcode" VALUES(16716,37930,-5,'Knoxville, Tennessee 37930',11458,14569);
INSERT INTO "django_geo_db_zipcode" VALUES(16717,37931,-5,'Knoxville, Tennessee 37931',11458,14570);
INSERT INTO "django_geo_db_zipcode" VALUES(16718,37932,-5,'Knoxville, Tennessee 37932',11458,14571);
INSERT INTO "django_geo_db_zipcode" VALUES(16719,37933,-5,'Knoxville, Tennessee 37933',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16720,37937,-6,'Powells Crossroads, Tennessee 37937',11459,14572);
INSERT INTO "django_geo_db_zipcode" VALUES(16721,37938,-5,'Knoxville, Tennessee 37938',11458,14573);
INSERT INTO "django_geo_db_zipcode" VALUES(16722,37939,-5,'Knoxville, Tennessee 37939',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16723,37940,-5,'Knoxville, Tennessee 37940',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16724,37950,-5,'Knoxville, Tennessee 37950',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16725,37951,-5,'Knoxville, Tennessee 37951',11458,14574);
INSERT INTO "django_geo_db_zipcode" VALUES(16726,37990,-5,'Knoxville, Tennessee 37990',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16727,37995,-5,'Knoxville, Tennessee 37995',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16728,37996,-5,'Knoxville, Tennessee 37996',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16729,37997,-5,'Knoxville, Tennessee 37997',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16730,37998,-5,'Knoxville, Tennessee 37998',11458,14575);
INSERT INTO "django_geo_db_zipcode" VALUES(16731,37999,-5,'Knoxville, Tennessee 37999',11458,14567);
INSERT INTO "django_geo_db_zipcode" VALUES(16732,38001,-6,'Alamo, Tennessee 38001',11460,14576);
INSERT INTO "django_geo_db_zipcode" VALUES(16733,38002,-6,'Arlington, Tennessee 38002',11461,14577);
INSERT INTO "django_geo_db_zipcode" VALUES(16734,38004,-6,'Atoka, Tennessee 38004',11462,14578);
INSERT INTO "django_geo_db_zipcode" VALUES(16735,38006,-6,'Bells, Tennessee 38006',11463,14579);
INSERT INTO "django_geo_db_zipcode" VALUES(16736,38007,-6,'Bogota, Tennessee 38007',11464,14580);
INSERT INTO "django_geo_db_zipcode" VALUES(16737,38008,-6,'Bolivar, Tennessee 38008',11465,14581);
INSERT INTO "django_geo_db_zipcode" VALUES(16738,38010,-6,'Braden, Tennessee 38010',11466,14582);
INSERT INTO "django_geo_db_zipcode" VALUES(16739,38011,-6,'Brighton, Tennessee 38011',11467,14583);
INSERT INTO "django_geo_db_zipcode" VALUES(16740,38012,-6,'Brownsville, Tennessee 38012',11468,14584);
INSERT INTO "django_geo_db_zipcode" VALUES(16741,38014,-6,'Brunswick, Tennessee 38014',11469,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16742,38015,-6,'Burlison, Tennessee 38015',11470,14586);
INSERT INTO "django_geo_db_zipcode" VALUES(16743,38016,-6,'Memphis, Tennessee 38016',11323,14587);
INSERT INTO "django_geo_db_zipcode" VALUES(16744,38017,-6,'Collierville, Tennessee 38017',11471,14588);
INSERT INTO "django_geo_db_zipcode" VALUES(16745,38018,-6,'Cordova, Tennessee 38018',11472,14589);
INSERT INTO "django_geo_db_zipcode" VALUES(16746,38019,-6,'Covington, Tennessee 38019',11473,14590);
INSERT INTO "django_geo_db_zipcode" VALUES(16747,38021,-6,'Crockett Mills, Tennessee 38021',11474,14591);
INSERT INTO "django_geo_db_zipcode" VALUES(16748,38023,-6,'Drummonds, Tennessee 38023',11475,14592);
INSERT INTO "django_geo_db_zipcode" VALUES(16749,38024,-6,'Dyersburg, Tennessee 38024',11476,14593);
INSERT INTO "django_geo_db_zipcode" VALUES(16750,38025,-6,'Dyersburg, Tennessee 38025',11476,14594);
INSERT INTO "django_geo_db_zipcode" VALUES(16751,38026,-6,'Memphis, Tennessee 38026',11323,14595);
INSERT INTO "django_geo_db_zipcode" VALUES(16752,38027,-6,'Collierville, Tennessee 38027',11471,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16753,38028,-6,'Eads, Tennessee 38028',11477,14596);
INSERT INTO "django_geo_db_zipcode" VALUES(16754,38029,-6,'Ellendale, Tennessee 38029',11478,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16755,38030,-6,'Finley, Tennessee 38030',11479,14597);
INSERT INTO "django_geo_db_zipcode" VALUES(16756,38034,-6,'Friendship, Tennessee 38034',11480,14598);
INSERT INTO "django_geo_db_zipcode" VALUES(16757,38036,-6,'Gallaway, Tennessee 38036',11481,14599);
INSERT INTO "django_geo_db_zipcode" VALUES(16758,38037,-6,'Gates, Tennessee 38037',11482,14600);
INSERT INTO "django_geo_db_zipcode" VALUES(16759,38039,-6,'Grand Junction, Tennessee 38039',11483,14601);
INSERT INTO "django_geo_db_zipcode" VALUES(16760,38040,-6,'Halls, Tennessee 38040',11484,14602);
INSERT INTO "django_geo_db_zipcode" VALUES(16761,38041,-6,'Henning, Arkansas 38041',11485,14603);
INSERT INTO "django_geo_db_zipcode" VALUES(16762,38042,-6,'Hickory Valley, Tennessee 38042',11486,14604);
INSERT INTO "django_geo_db_zipcode" VALUES(16763,38043,-6,'Hickory Withe, Tennessee 38043',11487,14605);
INSERT INTO "django_geo_db_zipcode" VALUES(16764,38044,-6,'Hornsby, Tennessee 38044',11488,14606);
INSERT INTO "django_geo_db_zipcode" VALUES(16765,38045,-6,'Laconia, Tennessee 38045',11489,14607);
INSERT INTO "django_geo_db_zipcode" VALUES(16766,38046,-6,'La Grange, Tennessee 38046',11490,14608);
INSERT INTO "django_geo_db_zipcode" VALUES(16767,38047,-6,'Lenox, Tennessee 38047',11491,14609);
INSERT INTO "django_geo_db_zipcode" VALUES(16768,38048,-6,'Macon, Tennessee 38048',11492,14610);
INSERT INTO "django_geo_db_zipcode" VALUES(16769,38049,-6,'Mason, Tennessee 38049',11493,14611);
INSERT INTO "django_geo_db_zipcode" VALUES(16770,38050,-6,'Maury City, Tennessee 38050',11494,14612);
INSERT INTO "django_geo_db_zipcode" VALUES(16771,38052,-6,'Middleton, Tennessee 38052',11495,14613);
INSERT INTO "django_geo_db_zipcode" VALUES(16772,38053,-6,'Millington, Tennessee 38053',11496,14614);
INSERT INTO "django_geo_db_zipcode" VALUES(16773,38054,-6,'Millington, Tennessee 38054',11496,14615);
INSERT INTO "django_geo_db_zipcode" VALUES(16774,38055,-6,'Millington, Tennessee 38055',11496,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16775,38056,-6,'Miston, Tennessee 38056',11497,14594);
INSERT INTO "django_geo_db_zipcode" VALUES(16776,38057,-6,'Moscow, Tennessee 38057',11498,14616);
INSERT INTO "django_geo_db_zipcode" VALUES(16777,38058,-6,'Munford, Tennessee 38058',11499,14617);
INSERT INTO "django_geo_db_zipcode" VALUES(16778,38059,-6,'Newbern, Tennessee 38059',11500,14618);
INSERT INTO "django_geo_db_zipcode" VALUES(16779,38060,-6,'Oakland, Tennessee 38060',11501,14619);
INSERT INTO "django_geo_db_zipcode" VALUES(16780,38061,-6,'Pocahontas, Tennessee 38061',11502,14620);
INSERT INTO "django_geo_db_zipcode" VALUES(16781,38063,-6,'Ripley, Arkansas 38063',11503,14621);
INSERT INTO "django_geo_db_zipcode" VALUES(16782,38066,-6,'Rossville, Tennessee 38066',11504,14622);
INSERT INTO "django_geo_db_zipcode" VALUES(16783,38067,-6,'Saulsbury, Tennessee 38067',11505,14623);
INSERT INTO "django_geo_db_zipcode" VALUES(16784,38068,-6,'Somerville, Tennessee 38068',11506,14624);
INSERT INTO "django_geo_db_zipcode" VALUES(16785,38069,-6,'Stanton, Tennessee 38069',11507,14625);
INSERT INTO "django_geo_db_zipcode" VALUES(16786,38070,-6,'Tigrett, Tennessee 38070',11508,14626);
INSERT INTO "django_geo_db_zipcode" VALUES(16787,38071,-6,'Tipton, Tennessee 38071',11509,14627);
INSERT INTO "django_geo_db_zipcode" VALUES(16788,38073,-6,'Gates, Tennessee 38073',11482,14628);
INSERT INTO "django_geo_db_zipcode" VALUES(16789,38074,-6,'Bolivar, Tennessee 38074',11465,14629);
INSERT INTO "django_geo_db_zipcode" VALUES(16790,38075,-6,'Whiteville, Tennessee 38075',11510,14630);
INSERT INTO "django_geo_db_zipcode" VALUES(16791,38076,-6,'Williston, Tennessee 38076',11511,14631);
INSERT INTO "django_geo_db_zipcode" VALUES(16792,38077,-6,'Wynnburg, Tennessee 38077',11512,14632);
INSERT INTO "django_geo_db_zipcode" VALUES(16793,38079,-6,'Tiptonville, Kentucky 38079',11513,14633);
INSERT INTO "django_geo_db_zipcode" VALUES(16794,38080,-6,'Ridgely, Tennessee 38080',11514,14634);
INSERT INTO "django_geo_db_zipcode" VALUES(16795,38083,-6,'Millington, Tennessee 38083',11496,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16796,38088,-6,'Cordova, Tennessee 38088',11472,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16797,38101,-6,'Memphis, Tennessee 38101',11323,14635);
INSERT INTO "django_geo_db_zipcode" VALUES(16798,38103,-6,'Memphis, Tennessee 38103',11323,14636);
INSERT INTO "django_geo_db_zipcode" VALUES(16799,38104,-6,'Memphis, Tennessee 38104',11323,14637);
INSERT INTO "django_geo_db_zipcode" VALUES(16800,38105,-6,'Memphis, Tennessee 38105',11323,14638);
INSERT INTO "django_geo_db_zipcode" VALUES(16801,38106,-6,'Memphis, Tennessee 38106',11323,14639);
INSERT INTO "django_geo_db_zipcode" VALUES(16802,38107,-6,'Memphis, Tennessee 38107',11323,14640);
INSERT INTO "django_geo_db_zipcode" VALUES(16803,38108,-6,'Memphis, Tennessee 38108',11323,14641);
INSERT INTO "django_geo_db_zipcode" VALUES(16804,38109,-6,'Memphis, Tennessee 38109',11323,14642);
INSERT INTO "django_geo_db_zipcode" VALUES(16805,38110,-6,'Memphis, Tennessee 38110',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16806,38111,-6,'Memphis, Tennessee 38111',11323,14643);
INSERT INTO "django_geo_db_zipcode" VALUES(16807,38112,-6,'Memphis, Tennessee 38112',11323,14644);
INSERT INTO "django_geo_db_zipcode" VALUES(16808,38113,-6,'Memphis, Tennessee 38113',11323,14645);
INSERT INTO "django_geo_db_zipcode" VALUES(16809,38114,-6,'Memphis, Tennessee 38114',11323,14646);
INSERT INTO "django_geo_db_zipcode" VALUES(16810,38115,-6,'Memphis, Tennessee 38115',11323,14647);
INSERT INTO "django_geo_db_zipcode" VALUES(16811,38116,-6,'Memphis, Tennessee 38116',11323,14648);
INSERT INTO "django_geo_db_zipcode" VALUES(16812,38117,-6,'Memphis, Tennessee 38117',11323,14649);
INSERT INTO "django_geo_db_zipcode" VALUES(16813,38118,-6,'Memphis, Tennessee 38118',11323,14650);
INSERT INTO "django_geo_db_zipcode" VALUES(16814,38119,-6,'Memphis, Tennessee 38119',11323,14651);
INSERT INTO "django_geo_db_zipcode" VALUES(16815,38120,-6,'Memphis, Tennessee 38120',11323,14652);
INSERT INTO "django_geo_db_zipcode" VALUES(16816,38122,-6,'Memphis, Tennessee 38122',11323,14653);
INSERT INTO "django_geo_db_zipcode" VALUES(16817,38124,-6,'Memphis, Tennessee 38124',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16818,38125,-6,'Memphis, Tennessee 38125',11323,14654);
INSERT INTO "django_geo_db_zipcode" VALUES(16819,38126,-6,'Memphis, Tennessee 38126',11323,14655);
INSERT INTO "django_geo_db_zipcode" VALUES(16820,38127,-6,'Memphis, Tennessee 38127',11323,14656);
INSERT INTO "django_geo_db_zipcode" VALUES(16821,38128,-6,'Memphis, Tennessee 38128',11323,14657);
INSERT INTO "django_geo_db_zipcode" VALUES(16822,38130,-6,'Memphis, Tennessee 38130',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16823,38131,-6,'Memphis, Tennessee 38131',11323,14658);
INSERT INTO "django_geo_db_zipcode" VALUES(16824,38132,-6,'Memphis, Tennessee 38132',11323,14659);
INSERT INTO "django_geo_db_zipcode" VALUES(16825,38133,-6,'Memphis, Tennessee 38133',11323,14660);
INSERT INTO "django_geo_db_zipcode" VALUES(16826,38134,-6,'Memphis, Tennessee 38134',11323,14661);
INSERT INTO "django_geo_db_zipcode" VALUES(16827,38135,-6,'Memphis, Tennessee 38135',11323,14662);
INSERT INTO "django_geo_db_zipcode" VALUES(16828,38136,-6,'Memphis, Tennessee 38136',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16829,38137,-6,'Memphis, Tennessee 38137',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16830,38138,-6,'Germantown, Tennessee 38138',11515,14663);
INSERT INTO "django_geo_db_zipcode" VALUES(16831,38139,-6,'Germantown, Tennessee 38139',11515,14664);
INSERT INTO "django_geo_db_zipcode" VALUES(16832,38140,-6,'Memphis, Tennessee 38140',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16833,38141,-6,'Memphis, Tennessee 38141',11323,14665);
INSERT INTO "django_geo_db_zipcode" VALUES(16834,38142,-6,'Memphis, Tennessee 38142',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16835,38143,-6,'Memphis, Tennessee 38143',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16836,38145,-6,'Memphis, Tennessee 38145',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16837,38146,-6,'Memphis, Tennessee 38146',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16838,38147,-6,'Memphis, Tennessee 38147',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16839,38148,-6,'Memphis, Tennessee 38148',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16840,38150,-6,'Memphis, Tennessee 38150',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16841,38151,-6,'Memphis, Tennessee 38151',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16842,38152,-6,'Memphis, Tennessee 38152',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16843,38157,-6,'Memphis, Tennessee 38157',11323,14666);
INSERT INTO "django_geo_db_zipcode" VALUES(16844,38159,-6,'Memphis, Tennessee 38159',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16845,38160,-6,'Metcalfe, Mississippi 38160',11516,14667);
INSERT INTO "django_geo_db_zipcode" VALUES(16846,38161,-6,'Memphis, Tennessee 38161',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16847,38163,-6,'Memphis, Tennessee 38163',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16848,38165,-6,'Memphis, Tennessee 38165',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16849,38166,-6,'Memphis, Tennessee 38166',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16850,38167,-6,'Memphis, Tennessee 38167',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16851,38168,-6,'Memphis, Tennessee 38168',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16852,38173,-6,'Memphis, Tennessee 38173',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16853,38174,-6,'Memphis, Tennessee 38174',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16854,38175,-6,'Memphis, Tennessee 38175',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16855,38177,-6,'Memphis, Tennessee 38177',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16856,38181,-6,'Memphis, Tennessee 38181',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16857,38182,-6,'Memphis, Tennessee 38182',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16858,38183,-6,'Germantown, Tennessee 38183',11515,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16859,38184,-6,'Memphis, Tennessee 38184',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16860,38186,-6,'Memphis, Tennessee 38186',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16861,38187,-6,'Memphis, Tennessee 38187',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16862,38188,-6,'Memphis, Tennessee 38188',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16863,38190,-6,'Memphis, Tennessee 38190',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16864,38193,-6,'Memphis, Tennessee 38193',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16865,38194,-6,'Memphis, Tennessee 38194',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16866,38195,-6,'Memphis, Tennessee 38195',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16867,38197,-6,'Memphis, Tennessee 38197',11323,14585);
INSERT INTO "django_geo_db_zipcode" VALUES(16868,38201,-6,'McKenzie, Tennessee 38201',11517,14668);
INSERT INTO "django_geo_db_zipcode" VALUES(16869,38220,-6,'Atwood, Tennessee 38220',11518,14669);
INSERT INTO "django_geo_db_zipcode" VALUES(16870,38221,-6,'Big Sandy, Tennessee 38221',11519,14670);
INSERT INTO "django_geo_db_zipcode" VALUES(16871,38222,-6,'Buchanan, Tennessee 38222',11520,14671);
INSERT INTO "django_geo_db_zipcode" VALUES(16872,38223,-6,'Como, Tennessee 38223',11521,14672);
INSERT INTO "django_geo_db_zipcode" VALUES(16873,38224,-6,'Cottage Grove, Tennessee 38224',11522,14673);
INSERT INTO "django_geo_db_zipcode" VALUES(16874,38225,-6,'Dresden, Tennessee 38225',11523,14674);
INSERT INTO "django_geo_db_zipcode" VALUES(16875,38226,-6,'Dukedom, Tennessee 38226',11524,14675);
INSERT INTO "django_geo_db_zipcode" VALUES(16876,38229,-6,'Gleason, Tennessee 38229',11525,14676);
INSERT INTO "django_geo_db_zipcode" VALUES(16877,38230,-6,'Greenfield, Tennessee 38230',11526,14677);
INSERT INTO "django_geo_db_zipcode" VALUES(16878,38231,-6,'Henry, Tennessee 38231',11527,14678);
INSERT INTO "django_geo_db_zipcode" VALUES(16879,38232,-6,'Hornbeak, Tennessee 38232',11528,14679);
INSERT INTO "django_geo_db_zipcode" VALUES(16880,38233,-6,'Kenton, Tennessee 38233',11529,14680);
INSERT INTO "django_geo_db_zipcode" VALUES(16881,38235,-6,'McLemoresville, Tennessee 38235',11530,14681);
INSERT INTO "django_geo_db_zipcode" VALUES(16882,38236,-6,'Mansfield, Tennessee 38236',11531,14682);
INSERT INTO "django_geo_db_zipcode" VALUES(16883,38237,-6,'Martin, Tennessee 38237',11532,14683);
INSERT INTO "django_geo_db_zipcode" VALUES(16884,38238,-6,'Martin, Tennessee 38238',11532,14684);
INSERT INTO "django_geo_db_zipcode" VALUES(16885,38240,-6,'Obion, Tennessee 38240',11533,14685);
INSERT INTO "django_geo_db_zipcode" VALUES(16886,38241,-6,'Palmersville, Tennessee 38241',11534,14686);
INSERT INTO "django_geo_db_zipcode" VALUES(16887,38242,-6,'Paris, Tennessee 38242',11535,14687);
INSERT INTO "django_geo_db_zipcode" VALUES(16888,38251,-6,'Puryear, Tennessee 38251',11536,14688);
INSERT INTO "django_geo_db_zipcode" VALUES(16889,38253,-6,'Rives, Tennessee 38253',11537,14689);
INSERT INTO "django_geo_db_zipcode" VALUES(16890,38254,-6,'Samburg, Tennessee 38254',11538,14690);
INSERT INTO "django_geo_db_zipcode" VALUES(16891,38255,-6,'Sharon, Tennessee 38255',11539,14691);
INSERT INTO "django_geo_db_zipcode" VALUES(16892,38256,-6,'Springville, Tennessee 38256',11540,14692);
INSERT INTO "django_geo_db_zipcode" VALUES(16893,38257,-6,'South Fulton, Tennessee 38257',11541,14693);
INSERT INTO "django_geo_db_zipcode" VALUES(16894,38258,-6,'Trezevant, Tennessee 38258',11542,14694);
INSERT INTO "django_geo_db_zipcode" VALUES(16895,38259,-6,'Trimble, Tennessee 38259',11543,14695);
INSERT INTO "django_geo_db_zipcode" VALUES(16896,38260,-6,'Troy, Tennessee 38260',11544,14696);
INSERT INTO "django_geo_db_zipcode" VALUES(16897,38261,-6,'Union City, Tennessee 38261',11545,14697);
INSERT INTO "django_geo_db_zipcode" VALUES(16898,38271,-6,'Woodland Mills, Tennessee 38271',11546,14698);
INSERT INTO "django_geo_db_zipcode" VALUES(16899,38281,-6,'Union City, Tennessee 38281',11545,14699);
INSERT INTO "django_geo_db_zipcode" VALUES(16900,38301,-6,'Jackson, Tennessee 38301',11547,14700);
INSERT INTO "django_geo_db_zipcode" VALUES(16901,38302,-6,'Jackson, Tennessee 38302',11547,14701);
INSERT INTO "django_geo_db_zipcode" VALUES(16902,38303,-6,'Jackson, Tennessee 38303',11547,14701);
INSERT INTO "django_geo_db_zipcode" VALUES(16903,38305,-6,'Jackson, Tennessee 38305',11547,14702);
INSERT INTO "django_geo_db_zipcode" VALUES(16904,38308,-6,'Jackson, Tennessee 38308',11547,14701);
INSERT INTO "django_geo_db_zipcode" VALUES(16905,38310,-6,'Adamsville, Tennessee 38310',11548,14703);
INSERT INTO "django_geo_db_zipcode" VALUES(16906,38311,-6,'Bath Springs, Tennessee 38311',11549,14704);
INSERT INTO "django_geo_db_zipcode" VALUES(16907,38313,-6,'Beech Bluff, Tennessee 38313',11550,14705);
INSERT INTO "django_geo_db_zipcode" VALUES(16908,38314,-6,'Jackson, Tennessee 38314',11547,14701);
INSERT INTO "django_geo_db_zipcode" VALUES(16909,38315,-6,'Bethel Springs, Tennessee 38315',11551,14706);
INSERT INTO "django_geo_db_zipcode" VALUES(16910,38316,-6,'Bradford, Tennessee 38316',11552,14707);
INSERT INTO "django_geo_db_zipcode" VALUES(16911,38317,-6,'Bruceton, Tennessee 38317',11553,14708);
INSERT INTO "django_geo_db_zipcode" VALUES(16912,38318,-6,'Buena Vista, Tennessee 38318',11554,14709);
INSERT INTO "django_geo_db_zipcode" VALUES(16913,38320,-6,'Camden, Tennessee 38320',11555,14710);
INSERT INTO "django_geo_db_zipcode" VALUES(16914,38321,-6,'Cedar Grove, Tennessee 38321',11556,14711);
INSERT INTO "django_geo_db_zipcode" VALUES(16915,38324,-6,'Clarksburg, Tennessee 38324',11557,14712);
INSERT INTO "django_geo_db_zipcode" VALUES(16916,38326,-6,'Counce, Tennessee 38326',11558,14713);
INSERT INTO "django_geo_db_zipcode" VALUES(16917,38327,-6,'Crump, Tennessee 38327',11559,14714);
INSERT INTO "django_geo_db_zipcode" VALUES(16918,38328,-6,'Darden, Tennessee 38328',11560,14715);
INSERT INTO "django_geo_db_zipcode" VALUES(16919,38329,-6,'Decaturville, Tennessee 38329',11561,14716);
INSERT INTO "django_geo_db_zipcode" VALUES(16920,38330,-6,'Dyer, Tennessee 38330',11562,14717);
INSERT INTO "django_geo_db_zipcode" VALUES(16921,38331,-6,'Eaton, Tennessee 38331',11563,14718);
INSERT INTO "django_geo_db_zipcode" VALUES(16922,38332,-6,'Enville, Tennessee 38332',11564,14719);
INSERT INTO "django_geo_db_zipcode" VALUES(16923,38333,-6,'Eva, Tennessee 38333',11565,14720);
INSERT INTO "django_geo_db_zipcode" VALUES(16924,38334,-6,'Finger, Tennessee 38334',11566,14721);
INSERT INTO "django_geo_db_zipcode" VALUES(16925,38336,-6,'Fruitvale, Tennessee 38336',11567,14722);
INSERT INTO "django_geo_db_zipcode" VALUES(16926,38337,-6,'Gadsden, Tennessee 38337',11568,14723);
INSERT INTO "django_geo_db_zipcode" VALUES(16927,38338,-6,'Gibson, Tennessee 38338',11569,14724);
INSERT INTO "django_geo_db_zipcode" VALUES(16928,38339,-6,'Guys, Tennessee 38339',11570,14725);
INSERT INTO "django_geo_db_zipcode" VALUES(16929,38340,-6,'Henderson, Tennessee 38340',11571,14726);
INSERT INTO "django_geo_db_zipcode" VALUES(16930,38341,-6,'Holladay, Tennessee 38341',11572,14727);
INSERT INTO "django_geo_db_zipcode" VALUES(16931,38342,-6,'Hollow Rock, Tennessee 38342',11573,14728);
INSERT INTO "django_geo_db_zipcode" VALUES(16932,38343,-6,'Humboldt, Tennessee 38343',11574,14729);
INSERT INTO "django_geo_db_zipcode" VALUES(16933,38344,-6,'Huntingdon, Tennessee 38344',11575,14730);
INSERT INTO "django_geo_db_zipcode" VALUES(16934,38345,-6,'Huron, Tennessee 38345',11576,14731);
INSERT INTO "django_geo_db_zipcode" VALUES(16935,38346,-6,'Idlewild, Tennessee 38346',11577,14732);
INSERT INTO "django_geo_db_zipcode" VALUES(16936,38347,-6,'Jacks Creek, Tennessee 38347',11578,14733);
INSERT INTO "django_geo_db_zipcode" VALUES(16937,38348,-6,'Lavinia, Tennessee 38348',11579,14734);
INSERT INTO "django_geo_db_zipcode" VALUES(16938,38350,-6,'Collinwood, Tennessee 38350',11580,14735);
INSERT INTO "django_geo_db_zipcode" VALUES(16939,38351,-6,'Lexington, Tennessee 38351',11581,14736);
INSERT INTO "django_geo_db_zipcode" VALUES(16940,38352,-6,'Luray, Tennessee 38352',11582,14737);
INSERT INTO "django_geo_db_zipcode" VALUES(16941,38355,-6,'Medina, Tennessee 38355',11583,14738);
INSERT INTO "django_geo_db_zipcode" VALUES(16942,38356,-6,'Medon, Tennessee 38356',11584,14739);
INSERT INTO "django_geo_db_zipcode" VALUES(16943,38357,-6,'Michie, Tennessee 38357',11585,14740);
INSERT INTO "django_geo_db_zipcode" VALUES(16944,38358,-6,'Milan, Tennessee 38358',11586,14741);
INSERT INTO "django_geo_db_zipcode" VALUES(16945,38359,-6,'Milledgeville, Tennessee 38359',11587,14742);
INSERT INTO "django_geo_db_zipcode" VALUES(16946,38361,-6,'Morris Chapel, Tennessee 38361',11588,14743);
INSERT INTO "django_geo_db_zipcode" VALUES(16947,38362,-6,'Oakfield, Tennessee 38362',11589,14744);
INSERT INTO "django_geo_db_zipcode" VALUES(16948,38363,-6,'Parsons, Tennessee 38363',11590,14745);
INSERT INTO "django_geo_db_zipcode" VALUES(16949,38365,-6,'Pickwick Dam, Tennessee 38365',11591,14746);
INSERT INTO "django_geo_db_zipcode" VALUES(16950,38366,-6,'Pinson, Tennessee 38366',11592,14747);
INSERT INTO "django_geo_db_zipcode" VALUES(16951,38367,-6,'Ramer, Tennessee 38367',11593,14748);
INSERT INTO "django_geo_db_zipcode" VALUES(16952,38368,-6,'Reagan, Tennessee 38368',11594,14749);
INSERT INTO "django_geo_db_zipcode" VALUES(16953,38369,-6,'Rutherford, Tennessee 38369',11595,14750);
INSERT INTO "django_geo_db_zipcode" VALUES(16954,38370,-6,'Saltillo, Tennessee 38370',11596,14751);
INSERT INTO "django_geo_db_zipcode" VALUES(16955,38371,-6,'Sardis, Tennessee 38371',11597,14752);
INSERT INTO "django_geo_db_zipcode" VALUES(16956,38372,-6,'Savannah, Tennessee 38372',11598,14753);
INSERT INTO "django_geo_db_zipcode" VALUES(16957,38374,-6,'Scotts Hill, Tennessee 38374',11599,14754);
INSERT INTO "django_geo_db_zipcode" VALUES(16958,38375,-6,'Selmer, Tennessee 38375',11600,14755);
INSERT INTO "django_geo_db_zipcode" VALUES(16959,38376,-6,'Shiloh, Tennessee 38376',11601,14756);
INSERT INTO "django_geo_db_zipcode" VALUES(16960,38377,-6,'Silerton, Tennessee 38377',11602,14757);
INSERT INTO "django_geo_db_zipcode" VALUES(16961,38378,-6,'Spring Creek, Tennessee 38378',11603,14758);
INSERT INTO "django_geo_db_zipcode" VALUES(16962,38379,-6,'Stantonville, Tennessee 38379',11604,14759);
INSERT INTO "django_geo_db_zipcode" VALUES(16963,38380,-6,'Sugar Tree, Tennessee 38380',11605,14760);
INSERT INTO "django_geo_db_zipcode" VALUES(16964,38381,-6,'Toone, Tennessee 38381',11606,14761);
INSERT INTO "django_geo_db_zipcode" VALUES(16965,38382,-6,'Trenton, Tennessee 38382',11607,14762);
INSERT INTO "django_geo_db_zipcode" VALUES(16966,38384,-6,'Toone, Tennessee 38384',11606,14763);
INSERT INTO "django_geo_db_zipcode" VALUES(16967,38387,-6,'Westport, Tennessee 38387',11608,14764);
INSERT INTO "django_geo_db_zipcode" VALUES(16968,38388,-6,'Wildersville, Tennessee 38388',11609,14765);
INSERT INTO "django_geo_db_zipcode" VALUES(16969,38389,-6,'Yorkville, Tennessee 38389',11610,14766);
INSERT INTO "django_geo_db_zipcode" VALUES(16970,38390,-6,'Yuma, Tennessee 38390',11611,14767);
INSERT INTO "django_geo_db_zipcode" VALUES(16971,38391,-6,'Denmark, Tennessee 38391',11612,14768);
INSERT INTO "django_geo_db_zipcode" VALUES(16972,38392,-6,'Mercer, Tennessee 38392',11613,14769);
INSERT INTO "django_geo_db_zipcode" VALUES(16973,38393,-6,'Chewalla, Tennessee 38393',11614,14770);
INSERT INTO "django_geo_db_zipcode" VALUES(16974,38401,-6,'Columbia, Tennessee 38401',11615,14771);
INSERT INTO "django_geo_db_zipcode" VALUES(16975,38402,-6,'Columbia, Tennessee 38402',11615,14772);
INSERT INTO "django_geo_db_zipcode" VALUES(16976,38425,-6,'Clifton, Tennessee 38425',11616,14773);
INSERT INTO "django_geo_db_zipcode" VALUES(16977,38449,-6,'Ardmore, Tennessee 38449',11617,14774);
INSERT INTO "django_geo_db_zipcode" VALUES(16978,38450,-6,'Collinwood, Tennessee 38450',11580,14775);
INSERT INTO "django_geo_db_zipcode" VALUES(16979,38451,-6,'Culleoka, Tennessee 38451',11618,14776);
INSERT INTO "django_geo_db_zipcode" VALUES(16980,38452,-6,'Cypress Inn, Tennessee 38452',11619,14777);
INSERT INTO "django_geo_db_zipcode" VALUES(16981,38453,-6,'Dellrose, Tennessee 38453',11620,14778);
INSERT INTO "django_geo_db_zipcode" VALUES(16982,38454,-6,'Duck River, Tennessee 38454',11621,14779);
INSERT INTO "django_geo_db_zipcode" VALUES(16983,38455,-6,'Elkton, Tennessee 38455',11622,14780);
INSERT INTO "django_geo_db_zipcode" VALUES(16984,38456,-6,'Ethridge, Tennessee 38456',11623,14781);
INSERT INTO "django_geo_db_zipcode" VALUES(16985,38457,-6,'Five Points, Tennessee 38457',11624,14782);
INSERT INTO "django_geo_db_zipcode" VALUES(16986,38459,-6,'Frankewing, Tennessee 38459',11625,14783);
INSERT INTO "django_geo_db_zipcode" VALUES(16987,38460,-6,'Goodspring, Tennessee 38460',11626,14784);
INSERT INTO "django_geo_db_zipcode" VALUES(16988,38461,-6,'Hampshire, Tennessee 38461',11627,14785);
INSERT INTO "django_geo_db_zipcode" VALUES(16989,38462,-6,'Hohenwald, Tennessee 38462',11628,14786);
INSERT INTO "django_geo_db_zipcode" VALUES(16990,38463,-6,'Iron City, Tennessee 38463',11629,14787);
INSERT INTO "django_geo_db_zipcode" VALUES(16991,38464,-6,'Lawrenceburg, Tennessee 38464',11630,14788);
INSERT INTO "django_geo_db_zipcode" VALUES(16992,38468,-6,'Leoma, Tennessee 38468',11631,14789);
INSERT INTO "django_geo_db_zipcode" VALUES(16993,38469,-6,'Loretto, Tennessee 38469',11632,14790);
INSERT INTO "django_geo_db_zipcode" VALUES(16994,38471,-6,'Lutts, Tennessee 38471',11633,14791);
INSERT INTO "django_geo_db_zipcode" VALUES(16995,38472,-6,'Lynnville, Tennessee 38472',11634,14792);
INSERT INTO "django_geo_db_zipcode" VALUES(16996,38473,-6,'Minor Hill, Tennessee 38473',11635,14793);
INSERT INTO "django_geo_db_zipcode" VALUES(16997,38474,-6,'Mount Pleasant, Tennessee 38474',11636,14794);
INSERT INTO "django_geo_db_zipcode" VALUES(16998,38475,-6,'Olivehill, Tennessee 38475',11637,14795);
INSERT INTO "django_geo_db_zipcode" VALUES(16999,38476,-6,'Primm Springs, Tennessee 38476',11638,14796);
INSERT INTO "django_geo_db_zipcode" VALUES(17000,38477,-6,'Prospect, Tennessee 38477',11639,14797);
INSERT INTO "django_geo_db_zipcode" VALUES(17001,38478,-6,'Pulaski, Tennessee 38478',11640,14798);
INSERT INTO "django_geo_db_zipcode" VALUES(17002,38481,-6,'Saint Joseph, Tennessee 38481',11641,14799);
INSERT INTO "django_geo_db_zipcode" VALUES(17003,38482,-6,'Santa Fe, Tennessee 38482',11642,14800);
INSERT INTO "django_geo_db_zipcode" VALUES(17004,38483,-6,'Summertown, Tennessee 38483',11643,14801);
INSERT INTO "django_geo_db_zipcode" VALUES(17005,38485,-6,'Waynesboro, Tennessee 38485',11644,14802);
INSERT INTO "django_geo_db_zipcode" VALUES(17006,38486,-6,'Westpoint, Tennessee 38486',11645,14803);
INSERT INTO "django_geo_db_zipcode" VALUES(17007,38487,-6,'Williamsport, Tennessee 38487',11646,14804);
INSERT INTO "django_geo_db_zipcode" VALUES(17008,38488,-6,'Taft, Tennessee 38488',11647,14805);
INSERT INTO "django_geo_db_zipcode" VALUES(17009,38501,-6,'Cookeville, Tennessee 38501',11648,14806);
INSERT INTO "django_geo_db_zipcode" VALUES(17010,38502,-6,'Cookeville, Tennessee 38502',11648,14807);
INSERT INTO "django_geo_db_zipcode" VALUES(17011,38503,-6,'Cookeville, Tennessee 38503',11648,14807);
INSERT INTO "django_geo_db_zipcode" VALUES(17012,38504,-6,'Allardt, Tennessee 38504',11649,14808);
INSERT INTO "django_geo_db_zipcode" VALUES(17013,38505,-6,'Cookeville, Tennessee 38505',11648,14807);
INSERT INTO "django_geo_db_zipcode" VALUES(17014,38506,-6,'Cookeville, Tennessee 38506',11648,14809);
INSERT INTO "django_geo_db_zipcode" VALUES(17015,38514,-6,'Clarksdale, Mississippi 38514',11650,14810);
INSERT INTO "django_geo_db_zipcode" VALUES(17016,38528,-6,'Trezevant, Tennessee 38528',11542,14811);
INSERT INTO "django_geo_db_zipcode" VALUES(17017,38541,-6,'Allons, Tennessee 38541',11651,14812);
INSERT INTO "django_geo_db_zipcode" VALUES(17018,38542,-6,'Allred, Tennessee 38542',11652,14813);
INSERT INTO "django_geo_db_zipcode" VALUES(17019,38543,-6,'Alpine, Tennessee 38543',11653,14814);
INSERT INTO "django_geo_db_zipcode" VALUES(17020,38544,-6,'Baxter, Tennessee 38544',11654,14815);
INSERT INTO "django_geo_db_zipcode" VALUES(17021,38545,-6,'Bloomington Springs, Tennessee 38545',11655,14816);
INSERT INTO "django_geo_db_zipcode" VALUES(17022,38547,-6,'Brush Creek, Tennessee 38547',11656,14817);
INSERT INTO "django_geo_db_zipcode" VALUES(17023,38548,-6,'Buffalo Valley, Tennessee 38548',11657,14818);
INSERT INTO "django_geo_db_zipcode" VALUES(17024,38549,-6,'Byrdstown, Tennessee 38549',11658,14819);
INSERT INTO "django_geo_db_zipcode" VALUES(17025,38550,-6,'Campaign, Tennessee 38550',11659,14820);
INSERT INTO "django_geo_db_zipcode" VALUES(17026,38551,-6,'Celina, Tennessee 38551',11660,14821);
INSERT INTO "django_geo_db_zipcode" VALUES(17027,38552,-6,'Chestnut Mound, Tennessee 38552',11661,14822);
INSERT INTO "django_geo_db_zipcode" VALUES(17028,38553,-6,'Clarkrange, Tennessee 38553',11662,14823);
INSERT INTO "django_geo_db_zipcode" VALUES(17029,38554,-6,'Crawford, Tennessee 38554',11663,14824);
INSERT INTO "django_geo_db_zipcode" VALUES(17030,38555,-6,'Crossville, Tennessee 38555',11664,14825);
INSERT INTO "django_geo_db_zipcode" VALUES(17031,38556,-6,'Jamestown, Tennessee 38556',11665,14826);
INSERT INTO "django_geo_db_zipcode" VALUES(17032,38557,-6,'Crossville, Tennessee 38557',11664,14827);
INSERT INTO "django_geo_db_zipcode" VALUES(17033,38558,-6,'Crossville, Tennessee 38558',11664,14828);
INSERT INTO "django_geo_db_zipcode" VALUES(17034,38559,-6,'Doyle, Tennessee 38559',11666,14829);
INSERT INTO "django_geo_db_zipcode" VALUES(17035,38560,-6,'Elmwood, Tennessee 38560',11667,14830);
INSERT INTO "django_geo_db_zipcode" VALUES(17036,38562,-6,'Gainesboro, Tennessee 38562',11668,14831);
INSERT INTO "django_geo_db_zipcode" VALUES(17037,38563,-6,'Gordonsville, Tennessee 38563',11669,14832);
INSERT INTO "django_geo_db_zipcode" VALUES(17038,38564,-6,'Granville, Tennessee 38564',11670,14833);
INSERT INTO "django_geo_db_zipcode" VALUES(17039,38565,-6,'Grimsley, Tennessee 38565',11671,14834);
INSERT INTO "django_geo_db_zipcode" VALUES(17040,38567,-6,'Hickman, Tennessee 38567',11672,14835);
INSERT INTO "django_geo_db_zipcode" VALUES(17041,38568,-6,'Hilham, Tennessee 38568',11673,14836);
INSERT INTO "django_geo_db_zipcode" VALUES(17042,38569,-6,'Lancaster, Tennessee 38569',11674,14837);
INSERT INTO "django_geo_db_zipcode" VALUES(17043,38570,-6,'Livingston, Tennessee 38570',11675,14838);
INSERT INTO "django_geo_db_zipcode" VALUES(17044,38571,-6,'Crossville, Tennessee 38571',11664,14839);
INSERT INTO "django_geo_db_zipcode" VALUES(17045,38572,-6,'Pleasant Hill, Tennessee 38572',11676,14840);
INSERT INTO "django_geo_db_zipcode" VALUES(17046,38573,-6,'Monroe, Tennessee 38573',11677,14841);
INSERT INTO "django_geo_db_zipcode" VALUES(17047,38574,-6,'Monterey, Tennessee 38574',11678,14842);
INSERT INTO "django_geo_db_zipcode" VALUES(17048,38575,-6,'Moss, Tennessee 38575',11679,14843);
INSERT INTO "django_geo_db_zipcode" VALUES(17049,38577,-6,'Pall Mall, Tennessee 38577',11680,14844);
INSERT INTO "django_geo_db_zipcode" VALUES(17050,38578,-6,'Pleasant Hill, Tennessee 38578',11676,14845);
INSERT INTO "django_geo_db_zipcode" VALUES(17051,38579,-6,'Quebeck, Tennessee 38579',11681,14846);
INSERT INTO "django_geo_db_zipcode" VALUES(17052,38580,-6,'Rickman, Tennessee 38580',11682,14847);
INSERT INTO "django_geo_db_zipcode" VALUES(17053,38581,-6,'Rock Island, Tennessee 38581',11683,14848);
INSERT INTO "django_geo_db_zipcode" VALUES(17054,38582,-6,'Silver Point, Tennessee 38582',11684,14849);
INSERT INTO "django_geo_db_zipcode" VALUES(17055,38583,-6,'Sparta, Tennessee 38583',11685,14850);
INSERT INTO "django_geo_db_zipcode" VALUES(17056,38585,-6,'Spencer, Tennessee 38585',11686,14851);
INSERT INTO "django_geo_db_zipcode" VALUES(17057,38587,-6,'Walling, Tennessee 38587',11687,14852);
INSERT INTO "django_geo_db_zipcode" VALUES(17058,38588,-6,'Whitleyville, Tennessee 38588',11688,14853);
INSERT INTO "django_geo_db_zipcode" VALUES(17059,38589,-6,'Wilder, Tennessee 38589',11689,14854);
INSERT INTO "django_geo_db_zipcode" VALUES(17060,38597,-6,'Sumner, Mississippi 38597',11690,14855);
INSERT INTO "django_geo_db_zipcode" VALUES(17061,38601,-6,'Abbeville, Mississippi 38601',11691,14856);
INSERT INTO "django_geo_db_zipcode" VALUES(17062,38602,-6,'Arkabutla, Mississippi 38602',11692,14857);
INSERT INTO "django_geo_db_zipcode" VALUES(17063,38603,-6,'Ashland, Mississippi 38603',11693,14858);
INSERT INTO "django_geo_db_zipcode" VALUES(17064,38606,-6,'Batesville, Mississippi 38606',11694,14859);
INSERT INTO "django_geo_db_zipcode" VALUES(17065,38609,-6,'Belen, Mississippi 38609',11695,14860);
INSERT INTO "django_geo_db_zipcode" VALUES(17066,38610,-6,'Blue Mountain, Mississippi 38610',11696,14861);
INSERT INTO "django_geo_db_zipcode" VALUES(17067,38611,-6,'Byhalia, Mississippi 38611',11697,14862);
INSERT INTO "django_geo_db_zipcode" VALUES(17068,38614,-6,'Clarksdale, Mississippi 38614',11650,14863);
INSERT INTO "django_geo_db_zipcode" VALUES(17069,38617,-6,'Coahoma, Mississippi 38617',11698,14864);
INSERT INTO "django_geo_db_zipcode" VALUES(17070,38618,-6,'Coldwater, Mississippi 38618',11699,14865);
INSERT INTO "django_geo_db_zipcode" VALUES(17071,38619,-6,'Como, Mississippi 38619',11700,14866);
INSERT INTO "django_geo_db_zipcode" VALUES(17072,38620,-6,'Courtland, Mississippi 38620',11701,14867);
INSERT INTO "django_geo_db_zipcode" VALUES(17073,38621,-6,'Crenshaw, Mississippi 38621',11702,14868);
INSERT INTO "django_geo_db_zipcode" VALUES(17074,38622,-6,'Crowder, Mississippi 38622',11703,14869);
INSERT INTO "django_geo_db_zipcode" VALUES(17075,38623,-6,'Darling, Mississippi 38623',11704,14870);
INSERT INTO "django_geo_db_zipcode" VALUES(17076,38625,-6,'Dumas, Mississippi 38625',11705,14871);
INSERT INTO "django_geo_db_zipcode" VALUES(17077,38626,-6,'Dundee, Mississippi 38626',11706,14872);
INSERT INTO "django_geo_db_zipcode" VALUES(17078,38627,-6,'Etta, Mississippi 38627',11707,14873);
INSERT INTO "django_geo_db_zipcode" VALUES(17079,38628,-6,'Falcon, Mississippi 38628',11708,14874);
INSERT INTO "django_geo_db_zipcode" VALUES(17080,38629,-6,'Falkner, Mississippi 38629',11709,14875);
INSERT INTO "django_geo_db_zipcode" VALUES(17081,38630,-6,'Farrell, Mississippi 38630',11710,14876);
INSERT INTO "django_geo_db_zipcode" VALUES(17082,38631,-6,'Friars Point, Mississippi 38631',11711,14877);
INSERT INTO "django_geo_db_zipcode" VALUES(17083,38632,-6,'Hernando, Mississippi 38632',11712,14878);
INSERT INTO "django_geo_db_zipcode" VALUES(17084,38633,-6,'Hickory Flat, Mississippi 38633',11713,14879);
INSERT INTO "django_geo_db_zipcode" VALUES(17085,38634,-6,'Holly Springs, Mississippi 38634',11714,14880);
INSERT INTO "django_geo_db_zipcode" VALUES(17086,38635,-6,'Holly Springs, Mississippi 38635',11714,14881);
INSERT INTO "django_geo_db_zipcode" VALUES(17087,38637,-6,'Horn Lake, Mississippi 38637',11715,14882);
INSERT INTO "django_geo_db_zipcode" VALUES(17088,38638,-6,'Independence, Mississippi 38638',11716,14883);
INSERT INTO "django_geo_db_zipcode" VALUES(17089,38639,-6,'Jonestown, Mississippi 38639',11717,14884);
INSERT INTO "django_geo_db_zipcode" VALUES(17090,38641,-6,'Lake Cormorant, Mississippi 38641',11718,14885);
INSERT INTO "django_geo_db_zipcode" VALUES(17091,38642,-6,'Lamar, Mississippi 38642',11719,14886);
INSERT INTO "django_geo_db_zipcode" VALUES(17092,38643,-6,'Lambert, Mississippi 38643',11720,14887);
INSERT INTO "django_geo_db_zipcode" VALUES(17093,38644,-6,'Lula, Mississippi 38644',11721,14888);
INSERT INTO "django_geo_db_zipcode" VALUES(17094,38645,-6,'Lyon, Mississippi 38645',11722,14889);
INSERT INTO "django_geo_db_zipcode" VALUES(17095,38646,-6,'Marks, Mississippi 38646',11723,14890);
INSERT INTO "django_geo_db_zipcode" VALUES(17096,38647,-6,'Michigan City, Mississippi 38647',11724,14891);
INSERT INTO "django_geo_db_zipcode" VALUES(17097,38649,-6,'Mount Pleasant, Mississippi 38649',11725,14892);
INSERT INTO "django_geo_db_zipcode" VALUES(17098,38650,-6,'Myrtle, Mississippi 38650',11726,14893);
INSERT INTO "django_geo_db_zipcode" VALUES(17099,38651,-6,'Nesbit, Mississippi 38651',11727,14894);
INSERT INTO "django_geo_db_zipcode" VALUES(17100,38652,-6,'New Albany, Mississippi 38652',11728,14895);
INSERT INTO "django_geo_db_zipcode" VALUES(17101,38654,-6,'Olive Branch, Mississippi 38654',11729,14896);
INSERT INTO "django_geo_db_zipcode" VALUES(17102,38655,-6,'Oxford, Mississippi 38655',11730,14897);
INSERT INTO "django_geo_db_zipcode" VALUES(17103,38658,-6,'Pope, Mississippi 38658',11731,14898);
INSERT INTO "django_geo_db_zipcode" VALUES(17104,38659,-6,'Potts Camp, Mississippi 38659',11732,14899);
INSERT INTO "django_geo_db_zipcode" VALUES(17105,38661,-6,'Red Banks, Mississippi 38661',11733,14900);
INSERT INTO "django_geo_db_zipcode" VALUES(17106,38663,-6,'Ripley, Mississippi 38663',11734,14901);
INSERT INTO "django_geo_db_zipcode" VALUES(17107,38664,-6,'Robinsonville, Mississippi 38664',11735,14902);
INSERT INTO "django_geo_db_zipcode" VALUES(17108,38665,-6,'Sarah, Mississippi 38665',11736,14903);
INSERT INTO "django_geo_db_zipcode" VALUES(17109,38666,-6,'Sardis, Mississippi 38666',11737,14904);
INSERT INTO "django_geo_db_zipcode" VALUES(17110,38668,-6,'Senatobia, Mississippi 38668',11738,14905);
INSERT INTO "django_geo_db_zipcode" VALUES(17111,38669,-6,'Sherard, Mississippi 38669',11739,14906);
INSERT INTO "django_geo_db_zipcode" VALUES(17112,38670,-6,'Sledge, Mississippi 38670',11740,14907);
INSERT INTO "django_geo_db_zipcode" VALUES(17113,38671,-6,'Southaven, Mississippi 38671',11741,14908);
INSERT INTO "django_geo_db_zipcode" VALUES(17114,38672,-6,'Southaven, Mississippi 38672',11741,14909);
INSERT INTO "django_geo_db_zipcode" VALUES(17115,38673,-6,'Taylor, Mississippi 38673',11742,14910);
INSERT INTO "django_geo_db_zipcode" VALUES(17116,38674,-6,'Tiplersville, Mississippi 38674',11743,14911);
INSERT INTO "django_geo_db_zipcode" VALUES(17117,38675,-6,'Tula, Mississippi 38675',11744,14912);
INSERT INTO "django_geo_db_zipcode" VALUES(17118,38676,-6,'Tunica, Mississippi 38676',11745,14913);
INSERT INTO "django_geo_db_zipcode" VALUES(17119,38677,-6,'University, Mississippi 38677',11746,14914);
INSERT INTO "django_geo_db_zipcode" VALUES(17120,38679,-6,'Victoria, Mississippi 38679',11747,14915);
INSERT INTO "django_geo_db_zipcode" VALUES(17121,38680,-6,'Walls, Mississippi 38680',11748,14916);
INSERT INTO "django_geo_db_zipcode" VALUES(17122,38683,-6,'Walnut, Mississippi 38683',11749,14917);
INSERT INTO "django_geo_db_zipcode" VALUES(17123,38685,-6,'Waterford, Mississippi 38685',11750,14918);
INSERT INTO "django_geo_db_zipcode" VALUES(17124,38686,-6,'Walls, Mississippi 38686',11748,14919);
INSERT INTO "django_geo_db_zipcode" VALUES(17125,38695,-6,'Water Valley, Mississippi 38695',11751,14920);
INSERT INTO "django_geo_db_zipcode" VALUES(17126,38701,-6,'Greenville, Mississippi 38701',11752,14921);
INSERT INTO "django_geo_db_zipcode" VALUES(17127,38702,-6,'Greenville, Mississippi 38702',11752,14922);
INSERT INTO "django_geo_db_zipcode" VALUES(17128,38703,-6,'Greenville, Mississippi 38703',11752,14923);
INSERT INTO "django_geo_db_zipcode" VALUES(17129,38704,-6,'Greenville, Mississippi 38704',11752,14924);
INSERT INTO "django_geo_db_zipcode" VALUES(17130,38720,-6,'Alligator, Mississippi 38720',11753,14925);
INSERT INTO "django_geo_db_zipcode" VALUES(17131,38721,-6,'Anguilla, Mississippi 38721',11754,14926);
INSERT INTO "django_geo_db_zipcode" VALUES(17132,38722,-6,'Arcola, Mississippi 38722',11755,14927);
INSERT INTO "django_geo_db_zipcode" VALUES(17133,38723,-6,'Avon, Mississippi 38723',11756,14928);
INSERT INTO "django_geo_db_zipcode" VALUES(17134,38725,-6,'Benoit, Mississippi 38725',11757,14929);
INSERT INTO "django_geo_db_zipcode" VALUES(17135,38726,-6,'Beulah, Mississippi 38726',11758,14930);
INSERT INTO "django_geo_db_zipcode" VALUES(17136,38730,-6,'Boyle, Mississippi 38730',11759,14931);
INSERT INTO "django_geo_db_zipcode" VALUES(17137,38731,-6,'Chatham, Mississippi 38731',11760,14932);
INSERT INTO "django_geo_db_zipcode" VALUES(17138,38732,-6,'Cleveland, Mississippi 38732',11761,14933);
INSERT INTO "django_geo_db_zipcode" VALUES(17139,38733,-6,'Cleveland, Mississippi 38733',11761,14934);
INSERT INTO "django_geo_db_zipcode" VALUES(17140,38736,-6,'Doddsville, Mississippi 38736',11762,14935);
INSERT INTO "django_geo_db_zipcode" VALUES(17141,38737,-6,'Drew, Mississippi 38737',11763,14936);
INSERT INTO "django_geo_db_zipcode" VALUES(17142,38738,-6,'Parchman, Mississippi 38738',11764,14937);
INSERT INTO "django_geo_db_zipcode" VALUES(17143,38739,-6,'Dublin, Mississippi 38739',11765,14938);
INSERT INTO "django_geo_db_zipcode" VALUES(17144,38740,-6,'Duncan, Mississippi 38740',11766,14939);
INSERT INTO "django_geo_db_zipcode" VALUES(17145,38744,-6,'Glen Allan, Mississippi 38744',11767,14940);
INSERT INTO "django_geo_db_zipcode" VALUES(17146,38745,-6,'Grace, Mississippi 38745',11768,14941);
INSERT INTO "django_geo_db_zipcode" VALUES(17147,38746,-6,'Gunnison, Mississippi 38746',11769,14942);
INSERT INTO "django_geo_db_zipcode" VALUES(17148,38748,-6,'Hollandale, Mississippi 38748',11770,14943);
INSERT INTO "django_geo_db_zipcode" VALUES(17149,38749,-6,'Holly Ridge, Mississippi 38749',11771,14944);
INSERT INTO "django_geo_db_zipcode" VALUES(17150,38751,-6,'Indianola, Mississippi 38751',11772,14945);
INSERT INTO "django_geo_db_zipcode" VALUES(17151,38753,-6,'Inverness, Mississippi 38753',11773,14946);
INSERT INTO "django_geo_db_zipcode" VALUES(17152,38754,-6,'Isola, Mississippi 38754',11774,14947);
INSERT INTO "django_geo_db_zipcode" VALUES(17153,38756,-6,'Leland, Mississippi 38756',11775,14948);
INSERT INTO "django_geo_db_zipcode" VALUES(17154,38758,-6,'Mattson, Mississippi 38758',11776,14949);
INSERT INTO "django_geo_db_zipcode" VALUES(17155,38759,-6,'Merigold, Mississippi 38759',11777,14950);
INSERT INTO "django_geo_db_zipcode" VALUES(17156,38760,-6,'Metcalfe, Mississippi 38760',11516,14951);
INSERT INTO "django_geo_db_zipcode" VALUES(17157,38761,-6,'Moorhead, Mississippi 38761',11778,14952);
INSERT INTO "django_geo_db_zipcode" VALUES(17158,38762,-6,'Mound Bayou, Mississippi 38762',11779,14953);
INSERT INTO "django_geo_db_zipcode" VALUES(17159,38763,-6,'Nitta Yuma, Mississippi 38763',11780,14954);
INSERT INTO "django_geo_db_zipcode" VALUES(17160,38764,-6,'Pace, Mississippi 38764',11781,14955);
INSERT INTO "django_geo_db_zipcode" VALUES(17161,38765,-6,'Panther Burn, Mississippi 38765',11782,14956);
INSERT INTO "django_geo_db_zipcode" VALUES(17162,38767,-6,'Rena Lara, Mississippi 38767',11783,14957);
INSERT INTO "django_geo_db_zipcode" VALUES(17163,38768,-6,'Rome, Mississippi 38768',11784,14958);
INSERT INTO "django_geo_db_zipcode" VALUES(17164,38769,-6,'Rosedale, Mississippi 38769',11785,14959);
INSERT INTO "django_geo_db_zipcode" VALUES(17165,38771,-6,'Ruleville, Mississippi 38771',11786,14960);
INSERT INTO "django_geo_db_zipcode" VALUES(17166,38772,-6,'Scott, Mississippi 38772',11787,14961);
INSERT INTO "django_geo_db_zipcode" VALUES(17167,38773,-6,'Shaw, Mississippi 38773',11788,14962);
INSERT INTO "django_geo_db_zipcode" VALUES(17168,38774,-6,'Shelby, Mississippi 38774',11789,14963);
INSERT INTO "django_geo_db_zipcode" VALUES(17169,38776,-6,'Stoneville, Mississippi 38776',11790,14964);
INSERT INTO "django_geo_db_zipcode" VALUES(17170,38778,-6,'Sunflower, Mississippi 38778',11791,14965);
INSERT INTO "django_geo_db_zipcode" VALUES(17171,38780,-6,'Wayside, Mississippi 38780',11792,14966);
INSERT INTO "django_geo_db_zipcode" VALUES(17172,38781,-6,'Winstonville, Mississippi 38781',11793,14967);
INSERT INTO "django_geo_db_zipcode" VALUES(17173,38782,-6,'Winterville, Mississippi 38782',11794,14968);
INSERT INTO "django_geo_db_zipcode" VALUES(17174,38801,-6,'Tupelo, Mississippi 38801',11795,14969);
INSERT INTO "django_geo_db_zipcode" VALUES(17175,38802,-6,'Tupelo, Mississippi 38802',11795,14970);
INSERT INTO "django_geo_db_zipcode" VALUES(17176,38803,-6,'Tupelo, Mississippi 38803',11795,14971);
INSERT INTO "django_geo_db_zipcode" VALUES(17177,38804,-6,'Tupelo, Mississippi 38804',11795,14972);
INSERT INTO "django_geo_db_zipcode" VALUES(17178,38820,-6,'Algoma, Mississippi 38820',11796,14973);
INSERT INTO "django_geo_db_zipcode" VALUES(17179,38821,-6,'Amory, Mississippi 38821',11797,14974);
INSERT INTO "django_geo_db_zipcode" VALUES(17180,38824,-6,'Baldwyn, Mississippi 38824',11798,14975);
INSERT INTO "django_geo_db_zipcode" VALUES(17181,38825,-6,'Becker, Mississippi 38825',11799,14976);
INSERT INTO "django_geo_db_zipcode" VALUES(17182,38826,-6,'Belden, Mississippi 38826',11800,14977);
INSERT INTO "django_geo_db_zipcode" VALUES(17183,38827,-6,'Belmont, Mississippi 38827',11801,14978);
INSERT INTO "django_geo_db_zipcode" VALUES(17184,38828,-6,'Blue Springs, Mississippi 38828',11802,14979);
INSERT INTO "django_geo_db_zipcode" VALUES(17185,38829,-6,'Booneville, Mississippi 38829',11803,14980);
INSERT INTO "django_geo_db_zipcode" VALUES(17186,38833,-6,'Burnsville, Mississippi 38833',11804,14981);
INSERT INTO "django_geo_db_zipcode" VALUES(17187,38834,-6,'Corinth, Mississippi 38834',11805,14982);
INSERT INTO "django_geo_db_zipcode" VALUES(17188,38835,-6,'Corinth, Mississippi 38835',11805,14983);
INSERT INTO "django_geo_db_zipcode" VALUES(17189,38838,-6,'Dennis, Mississippi 38838',11806,14984);
INSERT INTO "django_geo_db_zipcode" VALUES(17190,38839,-6,'Derma, Mississippi 38839',11807,14985);
INSERT INTO "django_geo_db_zipcode" VALUES(17191,38841,-6,'Ecru, Mississippi 38841',11808,14986);
INSERT INTO "django_geo_db_zipcode" VALUES(17192,38843,-6,'Fulton, Mississippi 38843',11809,14987);
INSERT INTO "django_geo_db_zipcode" VALUES(17193,38844,-6,'Gattman, Mississippi 38844',11810,14988);
INSERT INTO "django_geo_db_zipcode" VALUES(17194,38846,-6,'Glen, Mississippi 38846',11811,14989);
INSERT INTO "django_geo_db_zipcode" VALUES(17195,38847,-6,'Golden, Mississippi 38847',11812,14990);
INSERT INTO "django_geo_db_zipcode" VALUES(17196,38848,-6,'Greenwood Springs, Mississippi 38848',11813,14991);
INSERT INTO "django_geo_db_zipcode" VALUES(17197,38849,-6,'Guntown, Mississippi 38849',11814,14992);
INSERT INTO "django_geo_db_zipcode" VALUES(17198,38850,-6,'Houlka, Mississippi 38850',11815,14993);
INSERT INTO "django_geo_db_zipcode" VALUES(17199,38851,-6,'Houston, Mississippi 38851',11816,14994);
INSERT INTO "django_geo_db_zipcode" VALUES(17200,38852,-6,'Iuka, Alabama 38852',11817,14995);
INSERT INTO "django_geo_db_zipcode" VALUES(17201,38854,-6,'McCondy, Mississippi 38854',11818,14996);
INSERT INTO "django_geo_db_zipcode" VALUES(17202,38855,-6,'Mantachie, Mississippi 38855',11819,14997);
INSERT INTO "django_geo_db_zipcode" VALUES(17203,38856,-6,'Marietta, Mississippi 38856',11820,14998);
INSERT INTO "django_geo_db_zipcode" VALUES(17204,38857,-6,'Mooreville, Mississippi 38857',11821,14999);
INSERT INTO "django_geo_db_zipcode" VALUES(17205,38858,-6,'Nettleton, Mississippi 38858',11822,15000);
INSERT INTO "django_geo_db_zipcode" VALUES(17206,38859,-6,'New Site, Mississippi 38859',11823,15001);
INSERT INTO "django_geo_db_zipcode" VALUES(17207,38860,-6,'Okolona, Mississippi 38860',11824,15002);
INSERT INTO "django_geo_db_zipcode" VALUES(17208,38862,-6,'Plantersville, Mississippi 38862',11825,15003);
INSERT INTO "django_geo_db_zipcode" VALUES(17209,38863,-6,'Pontotoc, Mississippi 38863',11826,15004);
INSERT INTO "django_geo_db_zipcode" VALUES(17210,38864,-6,'Randolph, Mississippi 38864',11827,15005);
INSERT INTO "django_geo_db_zipcode" VALUES(17211,38865,-6,'Rienzi, Mississippi 38865',11828,15006);
INSERT INTO "django_geo_db_zipcode" VALUES(17212,38866,-6,'Saltillo, Mississippi 38866',11829,15007);
INSERT INTO "django_geo_db_zipcode" VALUES(17213,38868,-6,'Shannon, Mississippi 38868',11830,15008);
INSERT INTO "django_geo_db_zipcode" VALUES(17214,38869,-6,'Sherman, Mississippi 38869',11831,15009);
INSERT INTO "django_geo_db_zipcode" VALUES(17215,38870,-6,'Smithville, Mississippi 38870',11832,15010);
INSERT INTO "django_geo_db_zipcode" VALUES(17216,38871,-6,'Thaxton, Mississippi 38871',11833,15011);
INSERT INTO "django_geo_db_zipcode" VALUES(17217,38873,-6,'Tishomingo, Mississippi 38873',11834,15012);
INSERT INTO "django_geo_db_zipcode" VALUES(17218,38874,-6,'Toccopola, Mississippi 38874',11835,15013);
INSERT INTO "django_geo_db_zipcode" VALUES(17219,38875,-6,'Trebloc, Mississippi 38875',11836,14996);
INSERT INTO "django_geo_db_zipcode" VALUES(17220,38876,-6,'Tremont, Mississippi 38876',11837,15014);
INSERT INTO "django_geo_db_zipcode" VALUES(17221,38877,-6,'Van Vleet, Mississippi 38877',11838,15015);
INSERT INTO "django_geo_db_zipcode" VALUES(17222,38878,-6,'Vardaman, Mississippi 38878',11839,15016);
INSERT INTO "django_geo_db_zipcode" VALUES(17223,38879,-6,'Verona, Mississippi 38879',11840,15017);
INSERT INTO "django_geo_db_zipcode" VALUES(17224,38880,-6,'Wheeler, Mississippi 38880',11841,15018);
INSERT INTO "django_geo_db_zipcode" VALUES(17225,38901,-6,'Grenada, Mississippi 38901',11842,15019);
INSERT INTO "django_geo_db_zipcode" VALUES(17226,38902,-6,'Grenada, Mississippi 38902',11842,15020);
INSERT INTO "django_geo_db_zipcode" VALUES(17227,38912,-6,'Avalon, Mississippi 38912',11843,15021);
INSERT INTO "django_geo_db_zipcode" VALUES(17228,38913,-6,'Banner, Mississippi 38913',11844,15022);
INSERT INTO "django_geo_db_zipcode" VALUES(17229,38914,-6,'Big Creek, Mississippi 38914',11845,15023);
INSERT INTO "django_geo_db_zipcode" VALUES(17230,38915,-6,'Bruce, Mississippi 38915',11846,15024);
INSERT INTO "django_geo_db_zipcode" VALUES(17231,38916,-6,'Calhoun City, Mississippi 38916',11847,15025);
INSERT INTO "django_geo_db_zipcode" VALUES(17232,38917,-6,'Carrollton, Mississippi 38917',11848,15026);
INSERT INTO "django_geo_db_zipcode" VALUES(17233,38920,-6,'Cascilla, Mississippi 38920',11849,15027);
INSERT INTO "django_geo_db_zipcode" VALUES(17234,38921,-6,'Charleston, Mississippi 38921',11850,15028);
INSERT INTO "django_geo_db_zipcode" VALUES(17235,38922,-6,'Coffeeville, Mississippi 38922',11851,15029);
INSERT INTO "django_geo_db_zipcode" VALUES(17236,38923,-6,'Coila, Mississippi 38923',11852,15030);
INSERT INTO "django_geo_db_zipcode" VALUES(17237,38924,-6,'Cruger, Mississippi 38924',11853,15031);
INSERT INTO "django_geo_db_zipcode" VALUES(17238,38925,-6,'Duck Hill, Mississippi 38925',11854,15032);
INSERT INTO "django_geo_db_zipcode" VALUES(17239,38926,-6,'Elliott, Mississippi 38926',11855,15033);
INSERT INTO "django_geo_db_zipcode" VALUES(17240,38927,-6,'Enid, Mississippi 38927',11856,15034);
INSERT INTO "django_geo_db_zipcode" VALUES(17241,38928,-6,'Glendora, Mississippi 38928',11857,15035);
INSERT INTO "django_geo_db_zipcode" VALUES(17242,38929,-6,'Gore Springs, Mississippi 38929',11858,15036);
INSERT INTO "django_geo_db_zipcode" VALUES(17243,38930,-6,'Greenwood, Mississippi 38930',11859,15037);
INSERT INTO "django_geo_db_zipcode" VALUES(17244,38935,-6,'Greenwood, Mississippi 38935',11859,15038);
INSERT INTO "django_geo_db_zipcode" VALUES(17245,38940,-6,'Holcomb, Mississippi 38940',11860,15039);
INSERT INTO "django_geo_db_zipcode" VALUES(17246,38941,-6,'Itta Bena, Mississippi 38941',11861,15040);
INSERT INTO "django_geo_db_zipcode" VALUES(17247,38943,-6,'McCarley, Mississippi 38943',11862,15041);
INSERT INTO "django_geo_db_zipcode" VALUES(17248,38944,-6,'Minter City, Mississippi 38944',11863,15042);
INSERT INTO "django_geo_db_zipcode" VALUES(17249,38945,-6,'Money, Mississippi 38945',11864,15043);
INSERT INTO "django_geo_db_zipcode" VALUES(17250,38946,-6,'Morgan City, Mississippi 38946',11865,15044);
INSERT INTO "django_geo_db_zipcode" VALUES(17251,38947,-6,'North Carrollton, Mississippi 38947',11866,15045);
INSERT INTO "django_geo_db_zipcode" VALUES(17252,38948,-6,'Oakland, Mississippi 38948',11867,15046);
INSERT INTO "django_geo_db_zipcode" VALUES(17253,38949,-6,'Paris, Mississippi 38949',11868,15047);
INSERT INTO "django_geo_db_zipcode" VALUES(17254,38950,-6,'Philipp, Mississippi 38950',11869,15048);
INSERT INTO "django_geo_db_zipcode" VALUES(17255,38951,-6,'Pittsboro, Mississippi 38951',11870,15049);
INSERT INTO "django_geo_db_zipcode" VALUES(17256,38952,-6,'Schlater, Mississippi 38952',11871,15050);
INSERT INTO "django_geo_db_zipcode" VALUES(17257,38953,-6,'Scobey, Mississippi 38953',11872,15051);
INSERT INTO "django_geo_db_zipcode" VALUES(17258,38954,-6,'Sidon, Mississippi 38954',11873,15052);
INSERT INTO "django_geo_db_zipcode" VALUES(17259,38955,-6,'Slate Spring, Mississippi 38955',11874,15053);
INSERT INTO "django_geo_db_zipcode" VALUES(17260,38957,-6,'Sumner, Mississippi 38957',11690,15054);
INSERT INTO "django_geo_db_zipcode" VALUES(17261,38958,-6,'Swan Lake, Mississippi 38958',11875,15055);
INSERT INTO "django_geo_db_zipcode" VALUES(17262,38959,-6,'Swiftown, Mississippi 38959',11876,15056);
INSERT INTO "django_geo_db_zipcode" VALUES(17263,38960,-6,'Tie Plant, Mississippi 38960',11877,15057);
INSERT INTO "django_geo_db_zipcode" VALUES(17264,38961,-6,'Tillatoba, Mississippi 38961',11878,15058);
INSERT INTO "django_geo_db_zipcode" VALUES(17265,38962,-6,'Tippo, Mississippi 38962',11879,15059);
INSERT INTO "django_geo_db_zipcode" VALUES(17266,38963,-6,'Tutwiler, Mississippi 38963',11880,15060);
INSERT INTO "django_geo_db_zipcode" VALUES(17267,38964,-6,'Vance, Mississippi 38964',11881,15061);
INSERT INTO "django_geo_db_zipcode" VALUES(17268,38965,-6,'Water Valley, Mississippi 38965',11751,15062);
INSERT INTO "django_geo_db_zipcode" VALUES(17269,38966,-6,'Webb, Mississippi 38966',11882,15063);
INSERT INTO "django_geo_db_zipcode" VALUES(17270,38967,-6,'Winona, Mississippi 38967',11883,15064);
INSERT INTO "django_geo_db_zipcode" VALUES(17271,39038,-6,'Belzoni, Mississippi 39038',11884,15065);
INSERT INTO "django_geo_db_zipcode" VALUES(17272,39039,-6,'Benton, Mississippi 39039',11885,15066);
INSERT INTO "django_geo_db_zipcode" VALUES(17273,39040,-6,'Bentonia, Mississippi 39040',11886,15067);
INSERT INTO "django_geo_db_zipcode" VALUES(17274,39041,-6,'Bolton, Mississippi 39041',11887,15068);
INSERT INTO "django_geo_db_zipcode" VALUES(17275,39042,-6,'Brandon, Mississippi 39042',11888,15069);
INSERT INTO "django_geo_db_zipcode" VALUES(17276,39043,-6,'Brandon, Mississippi 39043',11888,15070);
INSERT INTO "django_geo_db_zipcode" VALUES(17277,39044,-6,'Braxton, Mississippi 39044',11889,15071);
INSERT INTO "django_geo_db_zipcode" VALUES(17278,39045,-6,'Camden, Mississippi 39045',11890,15072);
INSERT INTO "django_geo_db_zipcode" VALUES(17279,39046,-6,'Canton, Mississippi 39046',11891,15073);
INSERT INTO "django_geo_db_zipcode" VALUES(17280,39047,-6,'Brandon, Mississippi 39047',11888,15074);
INSERT INTO "django_geo_db_zipcode" VALUES(17281,39048,-6,'Bentonia, Mississippi 39048',11886,15075);
INSERT INTO "django_geo_db_zipcode" VALUES(17282,39051,-6,'Carthage, Mississippi 39051',11892,15076);
INSERT INTO "django_geo_db_zipcode" VALUES(17283,39054,-6,'Cary, Mississippi 39054',11893,15077);
INSERT INTO "django_geo_db_zipcode" VALUES(17284,39056,-6,'Clinton, Mississippi 39056',11894,15078);
INSERT INTO "django_geo_db_zipcode" VALUES(17285,39057,-6,'Conehatta, Mississippi 39057',11895,15079);
INSERT INTO "django_geo_db_zipcode" VALUES(17286,39058,-6,'Clinton, Mississippi 39058',11894,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17287,39059,-6,'Crystal Springs, Mississippi 39059',11896,15081);
INSERT INTO "django_geo_db_zipcode" VALUES(17288,39060,-6,'Clinton, Mississippi 39060',11894,15082);
INSERT INTO "django_geo_db_zipcode" VALUES(17289,39061,-6,'Delta City, Mississippi 39061',11897,15083);
INSERT INTO "django_geo_db_zipcode" VALUES(17290,39062,-6,'D Lo, Mississippi 39062',11898,15084);
INSERT INTO "django_geo_db_zipcode" VALUES(17291,39063,-6,'Durant, Mississippi 39063',11899,15085);
INSERT INTO "django_geo_db_zipcode" VALUES(17292,39066,-6,'Edwards, Mississippi 39066',11900,15086);
INSERT INTO "django_geo_db_zipcode" VALUES(17293,39067,-6,'Ethel, Mississippi 39067',11901,15087);
INSERT INTO "django_geo_db_zipcode" VALUES(17294,39069,-6,'Fayette, Mississippi 39069',11902,15088);
INSERT INTO "django_geo_db_zipcode" VALUES(17295,39071,-6,'Flora, Mississippi 39071',11903,15089);
INSERT INTO "django_geo_db_zipcode" VALUES(17296,39072,-6,'Pocahontas, Mississippi 39072',11904,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17297,39073,-6,'Florence, Mississippi 39073',11905,15090);
INSERT INTO "django_geo_db_zipcode" VALUES(17298,39074,-6,'Forest, Mississippi 39074',11906,15091);
INSERT INTO "django_geo_db_zipcode" VALUES(17299,39077,-6,'Gallman, Mississippi 39077',11907,15092);
INSERT INTO "django_geo_db_zipcode" VALUES(17300,39078,-6,'Georgetown, Mississippi 39078',11908,15093);
INSERT INTO "django_geo_db_zipcode" VALUES(17301,39079,-6,'Goodman, Mississippi 39079',11909,15094);
INSERT INTO "django_geo_db_zipcode" VALUES(17302,39080,-6,'Harperville, Mississippi 39080',11910,15095);
INSERT INTO "django_geo_db_zipcode" VALUES(17303,39081,-6,'Harriston, Mississippi 39081',11911,15096);
INSERT INTO "django_geo_db_zipcode" VALUES(17304,39082,-6,'Harrisville, Mississippi 39082',11912,15097);
INSERT INTO "django_geo_db_zipcode" VALUES(17305,39083,-6,'Hazlehurst, Mississippi 39083',11913,15098);
INSERT INTO "django_geo_db_zipcode" VALUES(17306,39086,-6,'Hermanville, Mississippi 39086',11914,15099);
INSERT INTO "django_geo_db_zipcode" VALUES(17307,39087,-6,'Hillsboro, Mississippi 39087',11915,15100);
INSERT INTO "django_geo_db_zipcode" VALUES(17308,39088,-6,'Holly Bluff, Mississippi 39088',11916,15101);
INSERT INTO "django_geo_db_zipcode" VALUES(17309,39090,-6,'Kosciusko, Mississippi 39090',11917,15102);
INSERT INTO "django_geo_db_zipcode" VALUES(17310,39092,-6,'Lake, Mississippi 39092',11918,15103);
INSERT INTO "django_geo_db_zipcode" VALUES(17311,39094,-6,'Lena, Mississippi 39094',11919,15104);
INSERT INTO "django_geo_db_zipcode" VALUES(17312,39095,-6,'Lexington, Mississippi 39095',11920,15105);
INSERT INTO "django_geo_db_zipcode" VALUES(17313,39096,-6,'Lorman, Mississippi 39096',11921,15106);
INSERT INTO "django_geo_db_zipcode" VALUES(17314,39097,-6,'Louise, Mississippi 39097',11922,15107);
INSERT INTO "django_geo_db_zipcode" VALUES(17315,39098,-6,'Ludlow, Mississippi 39098',11923,15108);
INSERT INTO "django_geo_db_zipcode" VALUES(17316,39107,-6,'McAdams, Mississippi 39107',11924,15109);
INSERT INTO "django_geo_db_zipcode" VALUES(17317,39108,-6,'McCool, Mississippi 39108',11925,15110);
INSERT INTO "django_geo_db_zipcode" VALUES(17318,39109,-6,'Madden, Mississippi 39109',11926,15111);
INSERT INTO "django_geo_db_zipcode" VALUES(17319,39110,-6,'Madison, Mississippi 39110',11927,15112);
INSERT INTO "django_geo_db_zipcode" VALUES(17320,39111,-6,'Magee, Mississippi 39111',11928,15113);
INSERT INTO "django_geo_db_zipcode" VALUES(17321,39112,-6,'Sanatorium, Mississippi 39112',11929,15114);
INSERT INTO "django_geo_db_zipcode" VALUES(17322,39113,-6,'Mayersville, Mississippi 39113',11930,15115);
INSERT INTO "django_geo_db_zipcode" VALUES(17323,39114,-6,'Mendenhall, Mississippi 39114',11931,15116);
INSERT INTO "django_geo_db_zipcode" VALUES(17324,39115,-6,'Midnight, Mississippi 39115',11932,15117);
INSERT INTO "django_geo_db_zipcode" VALUES(17325,39116,-6,'Mize, Mississippi 39116',11933,15118);
INSERT INTO "django_geo_db_zipcode" VALUES(17326,39117,-6,'Morton, Mississippi 39117',11934,15119);
INSERT INTO "django_geo_db_zipcode" VALUES(17327,39119,-6,'Mount Olive, Mississippi 39119',11935,15120);
INSERT INTO "django_geo_db_zipcode" VALUES(17328,39120,-6,'Natchez, Mississippi 39120',11936,15121);
INSERT INTO "django_geo_db_zipcode" VALUES(17329,39121,-6,'Natchez, Mississippi 39121',11936,15122);
INSERT INTO "django_geo_db_zipcode" VALUES(17330,39122,-6,'Natchez, Mississippi 39122',11936,15122);
INSERT INTO "django_geo_db_zipcode" VALUES(17331,39130,-6,'Madison, Mississippi 39130',11927,15123);
INSERT INTO "django_geo_db_zipcode" VALUES(17332,39140,-6,'Newhebron, Mississippi 39140',11937,15124);
INSERT INTO "django_geo_db_zipcode" VALUES(17333,39144,-6,'Pattison, Mississippi 39144',11938,15125);
INSERT INTO "django_geo_db_zipcode" VALUES(17334,39145,-6,'Pelahatchie, Mississippi 39145',11939,15126);
INSERT INTO "django_geo_db_zipcode" VALUES(17335,39146,-6,'Pickens, Mississippi 39146',11940,15127);
INSERT INTO "django_geo_db_zipcode" VALUES(17336,39148,-6,'Piney Woods, Mississippi 39148',11941,15128);
INSERT INTO "django_geo_db_zipcode" VALUES(17337,39149,-6,'Pinola, Mississippi 39149',11942,15129);
INSERT INTO "django_geo_db_zipcode" VALUES(17338,39150,-6,'Port Gibson, Mississippi 39150',11943,15130);
INSERT INTO "django_geo_db_zipcode" VALUES(17339,39151,-6,'Puckett, Mississippi 39151',11944,15131);
INSERT INTO "django_geo_db_zipcode" VALUES(17340,39152,-6,'Pulaski, Mississippi 39152',11945,15132);
INSERT INTO "django_geo_db_zipcode" VALUES(17341,39153,-6,'Raleigh, Mississippi 39153',11946,15133);
INSERT INTO "django_geo_db_zipcode" VALUES(17342,39154,-6,'Raymond, Mississippi 39154',11947,15134);
INSERT INTO "django_geo_db_zipcode" VALUES(17343,39156,-6,'Redwood, Mississippi 39156',11948,15135);
INSERT INTO "django_geo_db_zipcode" VALUES(17344,39157,-6,'Ridgeland, Mississippi 39157',11949,15136);
INSERT INTO "django_geo_db_zipcode" VALUES(17345,39158,-6,'Ridgeland, Mississippi 39158',11949,15123);
INSERT INTO "django_geo_db_zipcode" VALUES(17346,39159,-6,'Rolling Fork, Mississippi 39159',11950,15137);
INSERT INTO "django_geo_db_zipcode" VALUES(17347,39160,-6,'Sallis, Mississippi 39160',11951,15138);
INSERT INTO "django_geo_db_zipcode" VALUES(17348,39161,-6,'Sandhill, Mississippi 39161',11952,15139);
INSERT INTO "django_geo_db_zipcode" VALUES(17349,39162,-6,'Satartia, Mississippi 39162',11953,15140);
INSERT INTO "django_geo_db_zipcode" VALUES(17350,39163,-6,'Sharon, Mississippi 39163',11954,15123);
INSERT INTO "django_geo_db_zipcode" VALUES(17351,39165,-6,'Sibley, Mississippi 39165',11955,15122);
INSERT INTO "django_geo_db_zipcode" VALUES(17352,39166,-6,'Silver City, Mississippi 39166',11956,15141);
INSERT INTO "django_geo_db_zipcode" VALUES(17353,39167,-6,'Star, Mississippi 39167',11957,15142);
INSERT INTO "django_geo_db_zipcode" VALUES(17354,39168,-6,'Taylorsville, Mississippi 39168',11958,15143);
INSERT INTO "django_geo_db_zipcode" VALUES(17355,39169,-6,'Tchula, Mississippi 39169',11959,15144);
INSERT INTO "django_geo_db_zipcode" VALUES(17356,39170,-6,'Terry, Mississippi 39170',11960,15145);
INSERT INTO "django_geo_db_zipcode" VALUES(17357,39171,-6,'Thomastown, Mississippi 39171',11961,15146);
INSERT INTO "django_geo_db_zipcode" VALUES(17358,39173,-6,'Tinsley, Mississippi 39173',11962,15147);
INSERT INTO "django_geo_db_zipcode" VALUES(17359,39174,-6,'Tougaloo, Mississippi 39174',11963,15148);
INSERT INTO "django_geo_db_zipcode" VALUES(17360,39175,-6,'Utica, Mississippi 39175',11964,15149);
INSERT INTO "django_geo_db_zipcode" VALUES(17361,39176,-6,'Vaiden, Mississippi 39176',11965,15150);
INSERT INTO "django_geo_db_zipcode" VALUES(17362,39177,-6,'Valley Park, Mississippi 39177',11966,15151);
INSERT INTO "django_geo_db_zipcode" VALUES(17363,39179,-6,'Vaughan, Mississippi 39179',11967,15152);
INSERT INTO "django_geo_db_zipcode" VALUES(17364,39180,-6,'Vicksburg, Mississippi 39180',11968,15153);
INSERT INTO "django_geo_db_zipcode" VALUES(17365,39181,-6,'Vicksburg, Mississippi 39181',11968,15154);
INSERT INTO "django_geo_db_zipcode" VALUES(17366,39182,-6,'Vicksburg, Mississippi 39182',11968,15154);
INSERT INTO "django_geo_db_zipcode" VALUES(17367,39183,-6,'Vicksburg, Mississippi 39183',11968,15155);
INSERT INTO "django_geo_db_zipcode" VALUES(17368,39189,-6,'Walnut Grove, Mississippi 39189',11969,15156);
INSERT INTO "django_geo_db_zipcode" VALUES(17369,39190,-6,'Washington, Mississippi 39190',11970,15122);
INSERT INTO "django_geo_db_zipcode" VALUES(17370,39191,-6,'Wesson, Mississippi 39191',11971,15157);
INSERT INTO "django_geo_db_zipcode" VALUES(17371,39192,-6,'West, Mississippi 39192',11972,15158);
INSERT INTO "django_geo_db_zipcode" VALUES(17372,39193,-6,'Whitfield, Mississippi 39193',11973,15159);
INSERT INTO "django_geo_db_zipcode" VALUES(17373,39194,-6,'Yazoo City, Mississippi 39194',11974,15160);
INSERT INTO "django_geo_db_zipcode" VALUES(17374,39201,-6,'Jackson, Mississippi 39201',11975,15161);
INSERT INTO "django_geo_db_zipcode" VALUES(17375,39202,-6,'Jackson, Mississippi 39202',11975,15162);
INSERT INTO "django_geo_db_zipcode" VALUES(17376,39203,-6,'Jackson, Mississippi 39203',11975,15163);
INSERT INTO "django_geo_db_zipcode" VALUES(17377,39204,-6,'Jackson, Mississippi 39204',11975,15164);
INSERT INTO "django_geo_db_zipcode" VALUES(17378,39205,-6,'Jackson, Mississippi 39205',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17379,39206,-6,'Jackson, Mississippi 39206',11975,15165);
INSERT INTO "django_geo_db_zipcode" VALUES(17380,39207,-6,'Jackson, Mississippi 39207',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17381,39208,-6,'Jackson, Mississippi 39208',11975,15166);
INSERT INTO "django_geo_db_zipcode" VALUES(17382,39209,-6,'Jackson, Mississippi 39209',11975,15167);
INSERT INTO "django_geo_db_zipcode" VALUES(17383,39210,-6,'Jackson, Mississippi 39210',11975,15168);
INSERT INTO "django_geo_db_zipcode" VALUES(17384,39211,-6,'Jackson, Mississippi 39211',11975,15169);
INSERT INTO "django_geo_db_zipcode" VALUES(17385,39212,-6,'Jackson, Mississippi 39212',11975,15170);
INSERT INTO "django_geo_db_zipcode" VALUES(17386,39213,-6,'Jackson, Mississippi 39213',11975,15171);
INSERT INTO "django_geo_db_zipcode" VALUES(17387,39215,-6,'Jackson, Mississippi 39215',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17388,39216,-6,'Jackson, Mississippi 39216',11975,15172);
INSERT INTO "django_geo_db_zipcode" VALUES(17389,39217,-6,'Jackson, Mississippi 39217',11975,15173);
INSERT INTO "django_geo_db_zipcode" VALUES(17390,39218,-6,'Jackson, Mississippi 39218',11975,15174);
INSERT INTO "django_geo_db_zipcode" VALUES(17391,39219,-6,'Jackson, Mississippi 39219',11975,15175);
INSERT INTO "django_geo_db_zipcode" VALUES(17392,39225,-6,'Jackson, Mississippi 39225',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17393,39232,-6,'Jackson, Mississippi 39232',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17394,39235,-6,'Jackson, Mississippi 39235',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17395,39236,-6,'Jackson, Mississippi 39236',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17396,39250,-6,'Jackson, Mississippi 39250',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17397,39269,-6,'Jackson, Mississippi 39269',11975,15176);
INSERT INTO "django_geo_db_zipcode" VALUES(17398,39271,-6,'Jackson, Mississippi 39271',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17399,39272,-6,'Jackson, Mississippi 39272',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17400,39282,-6,'Jackson, Mississippi 39282',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17401,39283,-6,'Jackson, Mississippi 39283',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17402,39284,-6,'Jackson, Mississippi 39284',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17403,39286,-6,'Jackson, Mississippi 39286',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17404,39288,-6,'Jackson, Mississippi 39288',11975,15177);
INSERT INTO "django_geo_db_zipcode" VALUES(17405,39289,-6,'Jackson, Mississippi 39289',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17406,39296,-6,'Jackson, Mississippi 39296',11975,15080);
INSERT INTO "django_geo_db_zipcode" VALUES(17407,39298,-6,'Jackson, Mississippi 39298',11975,15178);
INSERT INTO "django_geo_db_zipcode" VALUES(17408,39301,-6,'Meridian, Mississippi 39301',11976,15179);
INSERT INTO "django_geo_db_zipcode" VALUES(17409,39302,-6,'Meridian, Mississippi 39302',11976,15180);
INSERT INTO "django_geo_db_zipcode" VALUES(17410,39303,-6,'Meridian, Mississippi 39303',11976,15181);
INSERT INTO "django_geo_db_zipcode" VALUES(17411,39304,-6,'Meridian, Mississippi 39304',11976,15182);
INSERT INTO "django_geo_db_zipcode" VALUES(17412,39305,-6,'Meridian, Mississippi 39305',11976,15183);
INSERT INTO "django_geo_db_zipcode" VALUES(17413,39307,-6,'Meridian, Mississippi 39307',11976,15184);
INSERT INTO "django_geo_db_zipcode" VALUES(17414,39309,-6,'Meridian, Mississippi 39309',11976,15185);
INSERT INTO "django_geo_db_zipcode" VALUES(17415,39320,-6,'Bailey, Mississippi 39320',11977,15186);
INSERT INTO "django_geo_db_zipcode" VALUES(17416,39322,-6,'Buckatunna, Mississippi 39322',11978,15187);
INSERT INTO "django_geo_db_zipcode" VALUES(17417,39323,-6,'Chunky, Mississippi 39323',11979,15188);
INSERT INTO "django_geo_db_zipcode" VALUES(17418,39324,-6,'Clara, Mississippi 39324',11980,15189);
INSERT INTO "django_geo_db_zipcode" VALUES(17419,39325,-6,'Collinsville, Mississippi 39325',11981,15190);
INSERT INTO "django_geo_db_zipcode" VALUES(17420,39326,-6,'Daleville, Mississippi 39326',11982,15191);
INSERT INTO "django_geo_db_zipcode" VALUES(17421,39327,-6,'Decatur, Mississippi 39327',11983,15192);
INSERT INTO "django_geo_db_zipcode" VALUES(17422,39328,-6,'De Kalb, Mississippi 39328',11984,15193);
INSERT INTO "django_geo_db_zipcode" VALUES(17423,39330,-6,'Enterprise, Mississippi 39330',11985,15194);
INSERT INTO "django_geo_db_zipcode" VALUES(17424,39332,-6,'Hickory, Mississippi 39332',11986,15195);
INSERT INTO "django_geo_db_zipcode" VALUES(17425,39335,-6,'Lauderdale, Mississippi 39335',11987,15196);
INSERT INTO "django_geo_db_zipcode" VALUES(17426,39336,-6,'Lawrence, Mississippi 39336',11988,15197);
INSERT INTO "django_geo_db_zipcode" VALUES(17427,39337,-6,'Little Rock, Mississippi 39337',11989,15198);
INSERT INTO "django_geo_db_zipcode" VALUES(17428,39338,-6,'Louin, Mississippi 39338',11990,15199);
INSERT INTO "django_geo_db_zipcode" VALUES(17429,39339,-6,'Louisville, Mississippi 39339',11991,15200);
INSERT INTO "django_geo_db_zipcode" VALUES(17430,39341,-6,'Macon, Mississippi 39341',11992,15201);
INSERT INTO "django_geo_db_zipcode" VALUES(17431,39342,-6,'Marion, Mississippi 39342',11993,15202);
INSERT INTO "django_geo_db_zipcode" VALUES(17432,39345,-6,'Newton, Mississippi 39345',11994,15203);
INSERT INTO "django_geo_db_zipcode" VALUES(17433,39346,-6,'Noxapater, Mississippi 39346',11995,15204);
INSERT INTO "django_geo_db_zipcode" VALUES(17434,39347,-6,'Pachuta, Mississippi 39347',11996,15205);
INSERT INTO "django_geo_db_zipcode" VALUES(17435,39348,-6,'Paulding, Mississippi 39348',11997,15206);
INSERT INTO "django_geo_db_zipcode" VALUES(17436,39350,-6,'Philadelphia, Mississippi 39350',11998,15207);
INSERT INTO "django_geo_db_zipcode" VALUES(17437,39352,-6,'Porterville, Mississippi 39352',11999,15208);
INSERT INTO "django_geo_db_zipcode" VALUES(17438,39354,-6,'Preston, Mississippi 39354',12000,15209);
INSERT INTO "django_geo_db_zipcode" VALUES(17439,39355,-6,'Quitman, Mississippi 39355',12001,15210);
INSERT INTO "django_geo_db_zipcode" VALUES(17440,39356,-6,'Rose Hill, Mississippi 39356',12002,15211);
INSERT INTO "django_geo_db_zipcode" VALUES(17441,39357,-6,'Louisville, Mississippi 39357',11991,15212);
INSERT INTO "django_geo_db_zipcode" VALUES(17442,39358,-6,'Scooba, Mississippi 39358',12003,15213);
INSERT INTO "django_geo_db_zipcode" VALUES(17443,39359,-6,'Sebastopol, Mississippi 39359',12004,15214);
INSERT INTO "django_geo_db_zipcode" VALUES(17444,39360,-6,'Shubuta, Mississippi 39360',12005,15215);
INSERT INTO "django_geo_db_zipcode" VALUES(17445,39361,-6,'Shuqualak, Mississippi 39361',12006,15216);
INSERT INTO "django_geo_db_zipcode" VALUES(17446,39362,-6,'State Line, Mississippi 39362',12007,15217);
INSERT INTO "django_geo_db_zipcode" VALUES(17447,39363,-6,'Stonewall, Mississippi 39363',12008,15218);
INSERT INTO "django_geo_db_zipcode" VALUES(17448,39364,-6,'Toomsuba, Mississippi 39364',12009,15219);
INSERT INTO "django_geo_db_zipcode" VALUES(17449,39365,-6,'Union, Mississippi 39365',12010,15220);
INSERT INTO "django_geo_db_zipcode" VALUES(17450,39366,-6,'Vossburg, Mississippi 39366',12011,15221);
INSERT INTO "django_geo_db_zipcode" VALUES(17451,39367,-6,'Waynesboro, Mississippi 39367',12012,15222);
INSERT INTO "django_geo_db_zipcode" VALUES(17452,39401,-6,'Hattiesburg, Mississippi 39401',12013,15223);
INSERT INTO "django_geo_db_zipcode" VALUES(17453,39402,-6,'Hattiesburg, Mississippi 39402',12013,15224);
INSERT INTO "django_geo_db_zipcode" VALUES(17454,39403,-6,'Hattiesburg, Mississippi 39403',12013,15225);
INSERT INTO "django_geo_db_zipcode" VALUES(17455,39404,-6,'Hattiesburg, Mississippi 39404',12013,15226);
INSERT INTO "django_geo_db_zipcode" VALUES(17456,39406,-6,'Hattiesburg, Mississippi 39406',12013,15226);
INSERT INTO "django_geo_db_zipcode" VALUES(17457,39407,-6,'Hattiesburg, Mississippi 39407',12013,15226);
INSERT INTO "django_geo_db_zipcode" VALUES(17458,39421,-6,'Bassfield, Mississippi 39421',12014,15227);
INSERT INTO "django_geo_db_zipcode" VALUES(17459,39422,-6,'Bay Springs, Mississippi 39422',12015,15228);
INSERT INTO "django_geo_db_zipcode" VALUES(17460,39423,-6,'Beaumont, Mississippi 39423',12016,15229);
INSERT INTO "django_geo_db_zipcode" VALUES(17461,39425,-6,'Brooklyn, Mississippi 39425',12017,15230);
INSERT INTO "django_geo_db_zipcode" VALUES(17462,39426,-6,'Carriere, Mississippi 39426',12018,15231);
INSERT INTO "django_geo_db_zipcode" VALUES(17463,39427,-6,'Carson, Mississippi 39427',12019,15232);
INSERT INTO "django_geo_db_zipcode" VALUES(17464,39428,-6,'Collins, Mississippi 39428',12020,15233);
INSERT INTO "django_geo_db_zipcode" VALUES(17465,39429,-6,'Columbia, Mississippi 39429',12021,15234);
INSERT INTO "django_geo_db_zipcode" VALUES(17466,39436,-6,'Eastabuchie, Mississippi 39436',12022,15235);
INSERT INTO "django_geo_db_zipcode" VALUES(17467,39437,-6,'Ellisville, Mississippi 39437',12023,15236);
INSERT INTO "django_geo_db_zipcode" VALUES(17468,39439,-6,'Heidelberg, Mississippi 39439',12024,15237);
INSERT INTO "django_geo_db_zipcode" VALUES(17469,39440,-6,'Laurel, Mississippi 39440',12025,15238);
INSERT INTO "django_geo_db_zipcode" VALUES(17470,39441,-6,'Laurel, Mississippi 39441',12025,15239);
INSERT INTO "django_geo_db_zipcode" VALUES(17471,39442,-6,'Laurel, Mississippi 39442',12025,15240);
INSERT INTO "django_geo_db_zipcode" VALUES(17472,39443,-6,'Laurel, Mississippi 39443',12025,15241);
INSERT INTO "django_geo_db_zipcode" VALUES(17473,39451,-6,'Leakesville, Mississippi 39451',12026,15242);
INSERT INTO "django_geo_db_zipcode" VALUES(17474,39452,-6,'Lucedale, Mississippi 39452',12027,15243);
INSERT INTO "django_geo_db_zipcode" VALUES(17475,39455,-6,'Lumberton, Mississippi 39455',12028,15244);
INSERT INTO "django_geo_db_zipcode" VALUES(17476,39456,-6,'McLain, Mississippi 39456',12029,15245);
INSERT INTO "django_geo_db_zipcode" VALUES(17477,39457,-6,'McNeill, Mississippi 39457',12030,15246);
INSERT INTO "django_geo_db_zipcode" VALUES(17478,39459,-6,'Moselle, Mississippi 39459',12031,15247);
INSERT INTO "django_geo_db_zipcode" VALUES(17479,39460,-6,'Moss, Mississippi 39460',12032,15248);
INSERT INTO "django_geo_db_zipcode" VALUES(17480,39461,-6,'Neely, Mississippi 39461',12033,15249);
INSERT INTO "django_geo_db_zipcode" VALUES(17481,39462,-6,'New Augusta, Mississippi 39462',12034,15250);
INSERT INTO "django_geo_db_zipcode" VALUES(17482,39463,-6,'Nicholson, Mississippi 39463',12035,15251);
INSERT INTO "django_geo_db_zipcode" VALUES(17483,39464,-6,'Ovett, Mississippi 39464',12036,15252);
INSERT INTO "django_geo_db_zipcode" VALUES(17484,39465,-6,'Petal, Mississippi 39465',12037,15253);
INSERT INTO "django_geo_db_zipcode" VALUES(17485,39466,-6,'Picayune, Mississippi 39466',12038,15254);
INSERT INTO "django_geo_db_zipcode" VALUES(17486,39470,-6,'Poplarville, Mississippi 39470',12039,15255);
INSERT INTO "django_geo_db_zipcode" VALUES(17487,39474,-6,'Prentiss, Mississippi 39474',12040,15256);
INSERT INTO "django_geo_db_zipcode" VALUES(17488,39475,-6,'Purvis, Mississippi 39475',12041,15257);
INSERT INTO "django_geo_db_zipcode" VALUES(17489,39476,-6,'Richton, Mississippi 39476',12042,15258);
INSERT INTO "django_geo_db_zipcode" VALUES(17490,39477,-6,'Sandersville, Mississippi 39477',12043,15259);
INSERT INTO "django_geo_db_zipcode" VALUES(17491,39478,-6,'Sandy Hook, Mississippi 39478',12044,15260);
INSERT INTO "django_geo_db_zipcode" VALUES(17492,39479,-6,'Seminary, Mississippi 39479',12045,15261);
INSERT INTO "django_geo_db_zipcode" VALUES(17493,39480,-6,'Soso, Mississippi 39480',12046,15262);
INSERT INTO "django_geo_db_zipcode" VALUES(17494,39481,-6,'Stringer, Mississippi 39481',12047,15263);
INSERT INTO "django_geo_db_zipcode" VALUES(17495,39482,-6,'Sumrall, Mississippi 39482',12048,15264);
INSERT INTO "django_geo_db_zipcode" VALUES(17496,39483,-6,'Foxworth, Mississippi 39483',12049,15265);
INSERT INTO "django_geo_db_zipcode" VALUES(17497,39501,-6,'Gulfport, Mississippi 39501',12050,15266);
INSERT INTO "django_geo_db_zipcode" VALUES(17498,39502,-6,'Gulfport, Mississippi 39502',12050,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17499,39503,-6,'Gulfport, Mississippi 39503',12050,15268);
INSERT INTO "django_geo_db_zipcode" VALUES(17500,39505,-6,'Gulfport, Mississippi 39505',12050,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17501,39506,-6,'Gulfport, Mississippi 39506',12050,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17502,39507,-6,'Gulfport, Mississippi 39507',12050,15269);
INSERT INTO "django_geo_db_zipcode" VALUES(17503,39520,-6,'Bay Saint Louis, Mississippi 39520',12051,15270);
INSERT INTO "django_geo_db_zipcode" VALUES(17504,39521,-6,'Bay Saint Louis, Mississippi 39521',12051,15271);
INSERT INTO "django_geo_db_zipcode" VALUES(17505,39522,-6,'Stennis Space Center, Mississippi 39522',12052,15271);
INSERT INTO "django_geo_db_zipcode" VALUES(17506,39525,-6,'Diamondhead, Mississippi 39525',12053,15272);
INSERT INTO "django_geo_db_zipcode" VALUES(17507,39529,-6,'Stennis Space Center, Mississippi 39529',12052,15271);
INSERT INTO "django_geo_db_zipcode" VALUES(17508,39530,-6,'Biloxi, Mississippi 39530',12054,15273);
INSERT INTO "django_geo_db_zipcode" VALUES(17509,39531,-6,'Biloxi, Mississippi 39531',12054,15274);
INSERT INTO "django_geo_db_zipcode" VALUES(17510,39532,-6,'Biloxi, Mississippi 39532',12054,15275);
INSERT INTO "django_geo_db_zipcode" VALUES(17511,39533,-6,'Biloxi, Mississippi 39533',12054,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17512,39534,-6,'Biloxi, Mississippi 39534',12054,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17513,39535,-6,'Biloxi, Mississippi 39535',12054,15267);
INSERT INTO "django_geo_db_zipcode" VALUES(17514,39540,-6,'D''Iberville, Mississippi 39540',12055,15276);
INSERT INTO "django_geo_db_zipcode" VALUES(17515,39552,-6,'Escatawpa, Mississippi 39552',12056,15277);
INSERT INTO "django_geo_db_zipcode" VALUES(17516,39553,-6,'Gautier, Mississippi 39553',12057,15278);
INSERT INTO "django_geo_db_zipcode" VALUES(17517,39555,-6,'Hurley, Mississippi 39555',12058,15279);
INSERT INTO "django_geo_db_zipcode" VALUES(17518,39556,-6,'Kiln, Mississippi 39556',12059,15280);
INSERT INTO "django_geo_db_zipcode" VALUES(17519,39558,-6,'Lakeshore, Mississippi 39558',12060,15281);
INSERT INTO "django_geo_db_zipcode" VALUES(17520,39560,-6,'Long Beach, Mississippi 39560',12061,15282);
INSERT INTO "django_geo_db_zipcode" VALUES(17521,39561,-6,'McHenry, Mississippi 39561',12062,15283);
INSERT INTO "django_geo_db_zipcode" VALUES(17522,39562,-6,'Moss Point, Mississippi 39562',12063,15284);
INSERT INTO "django_geo_db_zipcode" VALUES(17523,39563,-6,'Moss Point, Mississippi 39563',12063,15285);
INSERT INTO "django_geo_db_zipcode" VALUES(17524,39564,-6,'Ocean Springs, Mississippi 39564',12064,15286);
INSERT INTO "django_geo_db_zipcode" VALUES(17525,39565,-6,'Ocean Springs, Mississippi 39565',12064,15287);
INSERT INTO "django_geo_db_zipcode" VALUES(17526,39566,-6,'Ocean Springs, Mississippi 39566',12064,15277);
INSERT INTO "django_geo_db_zipcode" VALUES(17527,39567,-6,'Pascagoula, Mississippi 39567',12065,15288);
INSERT INTO "django_geo_db_zipcode" VALUES(17528,39568,-6,'Pascagoula, Mississippi 39568',12065,15277);
INSERT INTO "django_geo_db_zipcode" VALUES(17529,39569,-6,'Pascagoula, Mississippi 39569',12065,15277);
INSERT INTO "django_geo_db_zipcode" VALUES(17530,39571,-6,'Pass Christian, Mississippi 39571',12066,15289);
INSERT INTO "django_geo_db_zipcode" VALUES(17531,39572,-6,'Pearlington, Mississippi 39572',12067,15290);
INSERT INTO "django_geo_db_zipcode" VALUES(17532,39573,-6,'Perkinston, Mississippi 39573',12068,15291);
INSERT INTO "django_geo_db_zipcode" VALUES(17533,39574,-6,'Saucier, Mississippi 39574',12069,15292);
INSERT INTO "django_geo_db_zipcode" VALUES(17534,39576,-6,'Waveland, Mississippi 39576',12070,15293);
INSERT INTO "django_geo_db_zipcode" VALUES(17535,39577,-6,'Wiggins, Mississippi 39577',12071,15294);
INSERT INTO "django_geo_db_zipcode" VALUES(17536,39579,-6,'Pearlington, Mississippi 39579',12067,15295);
INSERT INTO "django_geo_db_zipcode" VALUES(17537,39581,-6,'Pascagoula, Mississippi 39581',12065,15296);
INSERT INTO "django_geo_db_zipcode" VALUES(17538,39595,-6,'Pascagoula, Mississippi 39595',12065,15277);
INSERT INTO "django_geo_db_zipcode" VALUES(17539,39601,-6,'Brookhaven, Mississippi 39601',12072,15297);
INSERT INTO "django_geo_db_zipcode" VALUES(17540,39602,-6,'Brookhaven, Mississippi 39602',12072,15298);
INSERT INTO "django_geo_db_zipcode" VALUES(17541,39603,-6,'Brookhaven, Mississippi 39603',12072,15299);
INSERT INTO "django_geo_db_zipcode" VALUES(17542,39629,-6,'Bogue Chitto, Mississippi 39629',12073,15300);
INSERT INTO "django_geo_db_zipcode" VALUES(17543,39630,-6,'Bude, Mississippi 39630',12074,15301);
INSERT INTO "django_geo_db_zipcode" VALUES(17544,39631,-6,'Centreville, Mississippi 39631',12075,15302);
INSERT INTO "django_geo_db_zipcode" VALUES(17545,39632,-6,'Chatawa, Mississippi 39632',12076,15303);
INSERT INTO "django_geo_db_zipcode" VALUES(17546,39633,-6,'Crosby, Mississippi 39633',12077,15304);
INSERT INTO "django_geo_db_zipcode" VALUES(17547,39635,-6,'Fernwood, Mississippi 39635',12078,15305);
INSERT INTO "django_geo_db_zipcode" VALUES(17548,39638,-6,'Gloster, Mississippi 39638',12079,15306);
INSERT INTO "django_geo_db_zipcode" VALUES(17549,39641,-6,'Jayess, Mississippi 39641',12080,15307);
INSERT INTO "django_geo_db_zipcode" VALUES(17550,39643,-6,'Kokomo, Mississippi 39643',12081,15308);
INSERT INTO "django_geo_db_zipcode" VALUES(17551,39645,-6,'Liberty, Mississippi 39645',12082,15309);
INSERT INTO "django_geo_db_zipcode" VALUES(17552,39647,-6,'McCall Creek, Mississippi 39647',12083,15310);
INSERT INTO "django_geo_db_zipcode" VALUES(17553,39648,-6,'Mccomb, Mississippi 39648',12084,15311);
INSERT INTO "django_geo_db_zipcode" VALUES(17554,39649,-6,'Mccomb, Mississippi 39649',12084,15312);
INSERT INTO "django_geo_db_zipcode" VALUES(17555,39652,-6,'Magnolia, Mississippi 39652',12085,15313);
INSERT INTO "django_geo_db_zipcode" VALUES(17556,39653,-6,'Meadville, Mississippi 39653',12086,15314);
INSERT INTO "django_geo_db_zipcode" VALUES(17557,39654,-6,'Monticello, Mississippi 39654',12087,15315);
INSERT INTO "django_geo_db_zipcode" VALUES(17558,39656,-6,'Oak Vale, Mississippi 39656',12088,15316);
INSERT INTO "django_geo_db_zipcode" VALUES(17559,39657,-6,'Osyka, Mississippi 39657',12089,15317);
INSERT INTO "django_geo_db_zipcode" VALUES(17560,39660,-6,'McComb, Mississippi 39660',12090,15318);
INSERT INTO "django_geo_db_zipcode" VALUES(17561,39661,-6,'Roxie, Mississippi 39661',12091,15319);
INSERT INTO "django_geo_db_zipcode" VALUES(17562,39662,-6,'Ruth, Mississippi 39662',12092,15320);
INSERT INTO "django_geo_db_zipcode" VALUES(17563,39663,-6,'Silver Creek, Mississippi 39663',12093,15321);
INSERT INTO "django_geo_db_zipcode" VALUES(17564,39664,-6,'Smithdale, Mississippi 39664',12094,15322);
INSERT INTO "django_geo_db_zipcode" VALUES(17565,39665,-6,'Sontag, Mississippi 39665',12095,15323);
INSERT INTO "django_geo_db_zipcode" VALUES(17566,39666,-6,'Summit, Mississippi 39666',12096,15324);
INSERT INTO "django_geo_db_zipcode" VALUES(17567,39667,-6,'Tylertown, Mississippi 39667',12097,15325);
INSERT INTO "django_geo_db_zipcode" VALUES(17568,39668,-6,'Union Church, Mississippi 39668',12098,15326);
INSERT INTO "django_geo_db_zipcode" VALUES(17569,39669,-6,'Woodville, Mississippi 39669',12099,15327);
INSERT INTO "django_geo_db_zipcode" VALUES(17570,39701,-6,'Columbus, Mississippi 39701',12100,15328);
INSERT INTO "django_geo_db_zipcode" VALUES(17571,39702,-6,'Columbus, Mississippi 39702',12100,15329);
INSERT INTO "django_geo_db_zipcode" VALUES(17572,39703,-6,'Columbus, Mississippi 39703',12100,15330);
INSERT INTO "django_geo_db_zipcode" VALUES(17573,39704,-6,'Columbus, Mississippi 39704',12100,15331);
INSERT INTO "django_geo_db_zipcode" VALUES(17574,39705,-6,'Columbus, Mississippi 39705',12100,15332);
INSERT INTO "django_geo_db_zipcode" VALUES(17575,39710,-6,'Columbus, Mississippi 39710',12100,15333);
INSERT INTO "django_geo_db_zipcode" VALUES(17576,39730,-6,'Aberdeen, Mississippi 39730',12101,15334);
INSERT INTO "django_geo_db_zipcode" VALUES(17577,39731,-6,'Brooksville, Mississippi 39731',12102,15335);
INSERT INTO "django_geo_db_zipcode" VALUES(17578,39735,-6,'Ackerman, Mississippi 39735',12103,15336);
INSERT INTO "django_geo_db_zipcode" VALUES(17579,39736,-6,'Artesia, Mississippi 39736',12104,15337);
INSERT INTO "django_geo_db_zipcode" VALUES(17580,39737,-6,'Bellefontaine, Mississippi 39737',12105,15338);
INSERT INTO "django_geo_db_zipcode" VALUES(17581,39739,-6,'Brooksville, Mississippi 39739',12102,15339);
INSERT INTO "django_geo_db_zipcode" VALUES(17582,39740,-6,'Caledonia, Mississippi 39740',12106,15340);
INSERT INTO "django_geo_db_zipcode" VALUES(17583,39741,-6,'Cedarbluff, Mississippi 39741',12107,15341);
INSERT INTO "django_geo_db_zipcode" VALUES(17584,39743,-6,'Crawford, Mississippi 39743',12108,15342);
INSERT INTO "django_geo_db_zipcode" VALUES(17585,39744,-6,'Eupora, Mississippi 39744',12109,15343);
INSERT INTO "django_geo_db_zipcode" VALUES(17586,39745,-6,'French Camp, Mississippi 39745',12110,15344);
INSERT INTO "django_geo_db_zipcode" VALUES(17587,39746,-6,'Hamilton, Mississippi 39746',12111,15345);
INSERT INTO "django_geo_db_zipcode" VALUES(17588,39747,-6,'Kilmichael, Mississippi 39747',12112,15346);
INSERT INTO "django_geo_db_zipcode" VALUES(17589,39750,-6,'Maben, Mississippi 39750',12113,15347);
INSERT INTO "django_geo_db_zipcode" VALUES(17590,39751,-6,'Mantee, Mississippi 39751',12114,15348);
INSERT INTO "django_geo_db_zipcode" VALUES(17591,39752,-6,'Mathiston, Mississippi 39752',12115,15349);
INSERT INTO "django_geo_db_zipcode" VALUES(17592,39753,-6,'Mayhew, Mississippi 39753',12116,15350);
INSERT INTO "django_geo_db_zipcode" VALUES(17593,39754,-6,'Montpelier, Mississippi 39754',12117,15351);
INSERT INTO "django_geo_db_zipcode" VALUES(17594,39755,-6,'Pheba, Mississippi 39755',12118,15352);
INSERT INTO "django_geo_db_zipcode" VALUES(17595,39756,-6,'Prairie, Mississippi 39756',12119,15353);
INSERT INTO "django_geo_db_zipcode" VALUES(17596,39758,-6,'Sturgis, Mississippi 39758',12120,15354);
INSERT INTO "django_geo_db_zipcode" VALUES(17597,39759,-6,'Starkville, Mississippi 39759',12121,15355);
INSERT INTO "django_geo_db_zipcode" VALUES(17598,39760,-6,'Starkville, Mississippi 39760',12121,15356);
INSERT INTO "django_geo_db_zipcode" VALUES(17599,39762,-6,'Mississippi State, Mississippi 39762',12122,15357);
INSERT INTO "django_geo_db_zipcode" VALUES(17600,39766,-6,'Steens, Mississippi 39766',12123,15358);
INSERT INTO "django_geo_db_zipcode" VALUES(17601,39767,-6,'Stewart, Mississippi 39767',12124,15359);
INSERT INTO "django_geo_db_zipcode" VALUES(17602,39769,-6,'Sturgis, Mississippi 39769',12120,15360);
INSERT INTO "django_geo_db_zipcode" VALUES(17603,39771,-6,'Walthall, Mississippi 39771',12125,15361);
INSERT INTO "django_geo_db_zipcode" VALUES(17604,39772,-6,'Weir, Mississippi 39772',12126,15362);
INSERT INTO "django_geo_db_zipcode" VALUES(17605,39773,-6,'West Point, Mississippi 39773',12127,15363);
INSERT INTO "django_geo_db_zipcode" VALUES(17606,39776,-6,'Woodland, Mississippi 39776',12128,15364);
INSERT INTO "django_geo_db_zipcode" VALUES(17607,39871,-6,'Flora, Mississippi 39871',11903,15365);
INSERT INTO "django_geo_db_zipcode" VALUES(17608,39901,-5,'Atlanta, Georgia 39901',9514,11369);
INSERT INTO "django_geo_db_zipcode" VALUES(17609,39940,-6,'Laurel, Mississippi 39940',12025,15366);
INSERT INTO "django_geo_db_zipcode" VALUES(17610,39956,-6,'Kiln, Mississippi 39956',12059,15367);
INSERT INTO "django_geo_db_zipcode" VALUES(17611,40003,-5,'Bagdad, Kentucky 40003',12129,15368);
INSERT INTO "django_geo_db_zipcode" VALUES(17612,40004,-5,'Bardstown, Kentucky 40004',12130,15369);
INSERT INTO "django_geo_db_zipcode" VALUES(17613,40006,-5,'Bedford, Kentucky 40006',12131,15370);
INSERT INTO "django_geo_db_zipcode" VALUES(17614,40007,-5,'Bethlehem, Kentucky 40007',12132,15371);
INSERT INTO "django_geo_db_zipcode" VALUES(17615,40008,-5,'Bloomfield, Kentucky 40008',12133,15372);
INSERT INTO "django_geo_db_zipcode" VALUES(17616,40009,-5,'Bradfordsville, Kentucky 40009',12134,15373);
INSERT INTO "django_geo_db_zipcode" VALUES(17617,40010,-5,'Buckner, Kentucky 40010',12135,15374);
INSERT INTO "django_geo_db_zipcode" VALUES(17618,40011,-5,'Campbellsburg, Kentucky 40011',12136,15375);
INSERT INTO "django_geo_db_zipcode" VALUES(17619,40012,-5,'Chaplin, Kentucky 40012',12137,15376);
INSERT INTO "django_geo_db_zipcode" VALUES(17620,40013,-5,'Coxs Creek, Kentucky 40013',12138,15377);
INSERT INTO "django_geo_db_zipcode" VALUES(17621,40014,-5,'Crestwood, Kentucky 40014',12139,15378);
INSERT INTO "django_geo_db_zipcode" VALUES(17622,40018,-5,'Eastwood, Kentucky 40018',12140,15379);
INSERT INTO "django_geo_db_zipcode" VALUES(17623,40019,-5,'Eminence, Kentucky 40019',12141,15380);
INSERT INTO "django_geo_db_zipcode" VALUES(17624,40020,-5,'Fairfield, Kentucky 40020',12142,15381);
INSERT INTO "django_geo_db_zipcode" VALUES(17625,40022,-5,'Finchville, Kentucky 40022',12143,15382);
INSERT INTO "django_geo_db_zipcode" VALUES(17626,40023,-5,'Fisherville, Kentucky 40023',12144,15383);
INSERT INTO "django_geo_db_zipcode" VALUES(17627,40025,-5,'Glenview, Kentucky 40025',12145,15384);
INSERT INTO "django_geo_db_zipcode" VALUES(17628,40026,-5,'Goshen, Kentucky 40026',12146,15385);
INSERT INTO "django_geo_db_zipcode" VALUES(17629,40027,-5,'Harrods Creek, Kentucky 40027',12147,15386);
INSERT INTO "django_geo_db_zipcode" VALUES(17630,40031,-5,'La Grange, Kentucky 40031',12148,15387);
INSERT INTO "django_geo_db_zipcode" VALUES(17631,40032,-5,'La Grange, Kentucky 40032',12148,15388);
INSERT INTO "django_geo_db_zipcode" VALUES(17632,40033,-5,'Lebanon, Kentucky 40033',12149,15389);
INSERT INTO "django_geo_db_zipcode" VALUES(17633,40036,-5,'Lockport, Kentucky 40036',12150,15390);
INSERT INTO "django_geo_db_zipcode" VALUES(17634,40037,-5,'Loretto, Kentucky 40037',12151,15391);
INSERT INTO "django_geo_db_zipcode" VALUES(17635,40040,-5,'Mackville, Kentucky 40040',12152,15392);
INSERT INTO "django_geo_db_zipcode" VALUES(17636,40041,-5,'Masonic Home, Kentucky 40041',12153,15393);
INSERT INTO "django_geo_db_zipcode" VALUES(17637,40045,-5,'Milton, Kentucky 40045',12154,15394);
INSERT INTO "django_geo_db_zipcode" VALUES(17638,40046,-5,'Mount Eden, Kentucky 40046',12155,15395);
INSERT INTO "django_geo_db_zipcode" VALUES(17639,40047,-5,'Mount Washington, Kentucky 40047',12156,15396);
INSERT INTO "django_geo_db_zipcode" VALUES(17640,40048,-5,'Nazareth, Kentucky 40048',12157,15397);
INSERT INTO "django_geo_db_zipcode" VALUES(17641,40049,-5,'Nerinx, Kentucky 40049',12158,15398);
INSERT INTO "django_geo_db_zipcode" VALUES(17642,40050,-5,'New Castle, Kentucky 40050',12159,15399);
INSERT INTO "django_geo_db_zipcode" VALUES(17643,40051,-5,'New Haven, Kentucky 40051',12160,15400);
INSERT INTO "django_geo_db_zipcode" VALUES(17644,40052,-5,'New Hope, Kentucky 40052',12161,15401);
INSERT INTO "django_geo_db_zipcode" VALUES(17645,40053,-5,'Pewee Valley, Kentucky 40053',12162,15402);
INSERT INTO "django_geo_db_zipcode" VALUES(17646,40055,-5,'Pendleton, Kentucky 40055',12163,15403);
INSERT INTO "django_geo_db_zipcode" VALUES(17647,40056,-5,'Pewee Valley, Kentucky 40056',12162,15404);
INSERT INTO "django_geo_db_zipcode" VALUES(17648,40057,-5,'Pleasureville, Kentucky 40057',12164,15405);
INSERT INTO "django_geo_db_zipcode" VALUES(17649,40058,-5,'Port Royal, Kentucky 40058',12165,15406);
INSERT INTO "django_geo_db_zipcode" VALUES(17650,40059,-5,'Prospect, Kentucky 40059',12166,15407);
INSERT INTO "django_geo_db_zipcode" VALUES(17651,40060,-5,'Raywick, Kentucky 40060',12167,15408);
INSERT INTO "django_geo_db_zipcode" VALUES(17652,40061,-5,'Saint Catharine, Kentucky 40061',12168,15409);
INSERT INTO "django_geo_db_zipcode" VALUES(17653,40062,-5,'Saint Francis, Kentucky 40062',12169,15410);
INSERT INTO "django_geo_db_zipcode" VALUES(17654,40063,-5,'Saint Mary, Kentucky 40063',12170,15411);
INSERT INTO "django_geo_db_zipcode" VALUES(17655,40065,-5,'Shelbyville, Kentucky 40065',12171,15412);
INSERT INTO "django_geo_db_zipcode" VALUES(17656,40066,-5,'Shelbyville, Kentucky 40066',12171,15413);
INSERT INTO "django_geo_db_zipcode" VALUES(17657,40067,-5,'Simpsonville, Kentucky 40067',12172,15414);
INSERT INTO "django_geo_db_zipcode" VALUES(17658,40068,-5,'Smithfield, Kentucky 40068',12173,15415);
INSERT INTO "django_geo_db_zipcode" VALUES(17659,40069,-5,'Springfield, Kentucky 40069',12174,15416);
INSERT INTO "django_geo_db_zipcode" VALUES(17660,40070,-5,'Sulphur, Kentucky 40070',12175,15417);
INSERT INTO "django_geo_db_zipcode" VALUES(17661,40071,-5,'Taylorsville, Kentucky 40071',12176,15418);
INSERT INTO "django_geo_db_zipcode" VALUES(17662,40075,-5,'Turners Station, Kentucky 40075',12177,15419);
INSERT INTO "django_geo_db_zipcode" VALUES(17663,40076,-5,'Waddy, Kentucky 40076',12178,15420);
INSERT INTO "django_geo_db_zipcode" VALUES(17664,40077,-5,'Westport, Kentucky 40077',12179,15421);
INSERT INTO "django_geo_db_zipcode" VALUES(17665,40078,-5,'Willisburg, Kentucky 40078',12180,15422);
INSERT INTO "django_geo_db_zipcode" VALUES(17666,40080,-5,'Fairfield, Kentucky 40080',12142,15423);
INSERT INTO "django_geo_db_zipcode" VALUES(17667,40081,-5,'Crestwood, Kentucky 40081',12139,15424);
INSERT INTO "django_geo_db_zipcode" VALUES(17668,40104,-5,'Battletown, Kentucky 40104',12181,15425);
INSERT INTO "django_geo_db_zipcode" VALUES(17669,40106,-6,'Big Spring, Kentucky 40106',12182,15426);
INSERT INTO "django_geo_db_zipcode" VALUES(17670,40107,-5,'Boston, Kentucky 40107',12183,15427);
INSERT INTO "django_geo_db_zipcode" VALUES(17671,40108,-5,'Brandenburg, Kentucky 40108',12184,15428);
INSERT INTO "django_geo_db_zipcode" VALUES(17672,40109,-5,'Brooks, Kentucky 40109',12185,15429);
INSERT INTO "django_geo_db_zipcode" VALUES(17673,40110,-5,'Clermont, Kentucky 40110',12186,15430);
INSERT INTO "django_geo_db_zipcode" VALUES(17674,40111,-6,'Cloverport, Kentucky 40111',12187,15431);
INSERT INTO "django_geo_db_zipcode" VALUES(17675,40115,-6,'Custer, Kentucky 40115',12188,15432);
INSERT INTO "django_geo_db_zipcode" VALUES(17676,40117,-5,'Ekron, Kentucky 40117',12189,15433);
INSERT INTO "django_geo_db_zipcode" VALUES(17677,40118,-5,'Fairdale, Kentucky 40118',12190,15434);
INSERT INTO "django_geo_db_zipcode" VALUES(17678,40119,-6,'Falls Of Rough, Kentucky 40119',12191,15435);
INSERT INTO "django_geo_db_zipcode" VALUES(17679,40121,-5,'Fort Knox, Kentucky 40121',12192,15436);
INSERT INTO "django_geo_db_zipcode" VALUES(17680,40140,-6,'Garfield, Kentucky 40140',12193,15437);
INSERT INTO "django_geo_db_zipcode" VALUES(17681,40142,-5,'Guston, Kentucky 40142',12194,15438);
INSERT INTO "django_geo_db_zipcode" VALUES(17682,40143,-6,'Hardinsburg, Kentucky 40143',12195,15439);
INSERT INTO "django_geo_db_zipcode" VALUES(17683,40144,-6,'Harned, Kentucky 40144',12196,15440);
INSERT INTO "django_geo_db_zipcode" VALUES(17684,40145,-6,'Hudson, Kentucky 40145',12197,15441);
INSERT INTO "django_geo_db_zipcode" VALUES(17685,40146,-6,'Irvington, Kentucky 40146',12198,15442);
INSERT INTO "django_geo_db_zipcode" VALUES(17686,40150,-5,'Lebanon Junction, Kentucky 40150',12199,15443);
INSERT INTO "django_geo_db_zipcode" VALUES(17687,40152,-6,'McDaniels, Kentucky 40152',12200,15444);
INSERT INTO "django_geo_db_zipcode" VALUES(17688,40153,-6,'McQuady, Kentucky 40153',12201,15445);
INSERT INTO "django_geo_db_zipcode" VALUES(17689,40155,-5,'Muldraugh, Kentucky 40155',12202,15446);
INSERT INTO "django_geo_db_zipcode" VALUES(17690,40157,-5,'Payneville, Kentucky 40157',12203,15447);
INSERT INTO "django_geo_db_zipcode" VALUES(17691,40159,-5,'Radcliff, Kentucky 40159',12204,15448);
INSERT INTO "django_geo_db_zipcode" VALUES(17692,40160,-5,'Radcliff, Kentucky 40160',12204,15449);
INSERT INTO "django_geo_db_zipcode" VALUES(17693,40161,-5,'Rhodelia, Kentucky 40161',12205,15450);
INSERT INTO "django_geo_db_zipcode" VALUES(17694,40162,-5,'Rineyville, Kentucky 40162',12206,15451);
INSERT INTO "django_geo_db_zipcode" VALUES(17695,40164,-6,'Se Ree, Kentucky 40164',12207,15452);
INSERT INTO "django_geo_db_zipcode" VALUES(17696,40165,-5,'Shepherdsville, Kentucky 40165',12208,15453);
INSERT INTO "django_geo_db_zipcode" VALUES(17697,40170,-6,'Stephensport, Kentucky 40170',12209,15454);
INSERT INTO "django_geo_db_zipcode" VALUES(17698,40171,-6,'Union Star, Kentucky 40171',12210,15455);
INSERT INTO "django_geo_db_zipcode" VALUES(17699,40175,-5,'Vine Grove, Kentucky 40175',12211,15456);
INSERT INTO "django_geo_db_zipcode" VALUES(17700,40176,-6,'Webster, Kentucky 40176',12212,15457);
INSERT INTO "django_geo_db_zipcode" VALUES(17701,40177,-5,'West Point, Kentucky 40177',12213,15458);
INSERT INTO "django_geo_db_zipcode" VALUES(17702,40178,-6,'Westview, Kentucky 40178',12214,15459);
INSERT INTO "django_geo_db_zipcode" VALUES(17703,40179,-5,'West Point, Kentucky 40179',12213,15460);
INSERT INTO "django_geo_db_zipcode" VALUES(17704,40201,-5,'Louisville, Kentucky 40201',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17705,40202,-5,'Louisville, Kentucky 40202',12215,15462);
INSERT INTO "django_geo_db_zipcode" VALUES(17706,40203,-5,'Louisville, Kentucky 40203',12215,15463);
INSERT INTO "django_geo_db_zipcode" VALUES(17707,40204,-5,'Louisville, Kentucky 40204',12215,15464);
INSERT INTO "django_geo_db_zipcode" VALUES(17708,40205,-5,'Louisville, Kentucky 40205',12215,15465);
INSERT INTO "django_geo_db_zipcode" VALUES(17709,40206,-5,'Louisville, Kentucky 40206',12215,15466);
INSERT INTO "django_geo_db_zipcode" VALUES(17710,40207,-5,'Louisville, Kentucky 40207',12215,15467);
INSERT INTO "django_geo_db_zipcode" VALUES(17711,40208,-5,'Louisville, Kentucky 40208',12215,15468);
INSERT INTO "django_geo_db_zipcode" VALUES(17712,40209,-5,'Louisville, Kentucky 40209',12215,15469);
INSERT INTO "django_geo_db_zipcode" VALUES(17713,40210,-5,'Louisville, Kentucky 40210',12215,15470);
INSERT INTO "django_geo_db_zipcode" VALUES(17714,40211,-5,'Louisville, Kentucky 40211',12215,15471);
INSERT INTO "django_geo_db_zipcode" VALUES(17715,40212,-5,'Louisville, Kentucky 40212',12215,15472);
INSERT INTO "django_geo_db_zipcode" VALUES(17716,40213,-5,'Louisville, Kentucky 40213',12215,15473);
INSERT INTO "django_geo_db_zipcode" VALUES(17717,40214,-5,'Louisville, Kentucky 40214',12215,15474);
INSERT INTO "django_geo_db_zipcode" VALUES(17718,40215,-5,'Louisville, Kentucky 40215',12215,15475);
INSERT INTO "django_geo_db_zipcode" VALUES(17719,40216,-5,'Louisville, Kentucky 40216',12215,15476);
INSERT INTO "django_geo_db_zipcode" VALUES(17720,40217,-5,'Louisville, Kentucky 40217',12215,15477);
INSERT INTO "django_geo_db_zipcode" VALUES(17721,40218,-5,'Louisville, Kentucky 40218',12215,15478);
INSERT INTO "django_geo_db_zipcode" VALUES(17722,40219,-5,'Louisville, Kentucky 40219',12215,15479);
INSERT INTO "django_geo_db_zipcode" VALUES(17723,40220,-5,'Louisville, Kentucky 40220',12215,15480);
INSERT INTO "django_geo_db_zipcode" VALUES(17724,40221,-5,'Louisville, Kentucky 40221',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17725,40222,-5,'Louisville, Kentucky 40222',12215,15481);
INSERT INTO "django_geo_db_zipcode" VALUES(17726,40223,-5,'Louisville, Kentucky 40223',12215,15482);
INSERT INTO "django_geo_db_zipcode" VALUES(17727,40224,-5,'Louisville, Kentucky 40224',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17728,40225,-5,'Louisville, Kentucky 40225',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17729,40228,-5,'Louisville, Kentucky 40228',12215,15483);
INSERT INTO "django_geo_db_zipcode" VALUES(17730,40229,-5,'Louisville, Kentucky 40229',12215,15484);
INSERT INTO "django_geo_db_zipcode" VALUES(17731,40231,-5,'Louisville, Kentucky 40231',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17732,40232,-5,'Louisville, Kentucky 40232',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17733,40233,-5,'Louisville, Kentucky 40233',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17734,40241,-5,'Louisville, Kentucky 40241',12215,15485);
INSERT INTO "django_geo_db_zipcode" VALUES(17735,40242,-5,'Louisville, Kentucky 40242',12215,15486);
INSERT INTO "django_geo_db_zipcode" VALUES(17736,40243,-5,'Louisville, Kentucky 40243',12215,15487);
INSERT INTO "django_geo_db_zipcode" VALUES(17737,40245,-5,'Louisville, Kentucky 40245',12215,15488);
INSERT INTO "django_geo_db_zipcode" VALUES(17738,40250,-5,'Louisville, Kentucky 40250',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17739,40251,-5,'Louisville, Kentucky 40251',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17740,40252,-5,'Louisville, Kentucky 40252',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17741,40253,-5,'Louisville, Kentucky 40253',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17742,40255,-5,'Louisville, Kentucky 40255',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17743,40256,-5,'Louisville, Kentucky 40256',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17744,40257,-5,'Louisville, Kentucky 40257',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17745,40258,-5,'Louisville, Kentucky 40258',12215,15489);
INSERT INTO "django_geo_db_zipcode" VALUES(17746,40259,-5,'Louisville, Kentucky 40259',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17747,40261,-5,'Louisville, Kentucky 40261',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17748,40266,-5,'Louisville, Kentucky 40266',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17749,40268,-5,'Louisville, Kentucky 40268',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17750,40269,-5,'Louisville, Kentucky 40269',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17751,40270,-5,'Louisville, Kentucky 40270',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17752,40272,-5,'Louisville, Kentucky 40272',12215,15490);
INSERT INTO "django_geo_db_zipcode" VALUES(17753,40280,-5,'Louisville, Kentucky 40280',12215,15491);
INSERT INTO "django_geo_db_zipcode" VALUES(17754,40281,-5,'Louisville, Kentucky 40281',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17755,40282,-5,'Louisville, Kentucky 40282',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17756,40283,-5,'Louisville, Kentucky 40283',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17757,40285,-5,'Louisville, Kentucky 40285',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17758,40287,-5,'Louisville, Kentucky 40287',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17759,40289,-5,'Louisville, Kentucky 40289',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17760,40290,-5,'Louisville, Kentucky 40290',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17761,40291,-5,'Louisville, Kentucky 40291',12215,15492);
INSERT INTO "django_geo_db_zipcode" VALUES(17762,40292,-5,'Louisville, Kentucky 40292',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17763,40293,-5,'Louisville, Kentucky 40293',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17764,40294,-5,'Louisville, Kentucky 40294',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17765,40295,-5,'Louisville, Kentucky 40295',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17766,40296,-5,'Louisville, Kentucky 40296',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17767,40297,-5,'Louisville, Kentucky 40297',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17768,40298,-5,'Louisville, Kentucky 40298',12215,15461);
INSERT INTO "django_geo_db_zipcode" VALUES(17769,40299,-5,'Louisville, Kentucky 40299',12215,15493);
INSERT INTO "django_geo_db_zipcode" VALUES(17770,40310,-5,'Burgin, Kentucky 40310',12216,15494);
INSERT INTO "django_geo_db_zipcode" VALUES(17771,40311,-5,'Carlisle, Kentucky 40311',12217,15495);
INSERT INTO "django_geo_db_zipcode" VALUES(17772,40312,-5,'Clay City, Kentucky 40312',12218,15496);
INSERT INTO "django_geo_db_zipcode" VALUES(17773,40313,-5,'Clearfield, Kentucky 40313',12219,15497);
INSERT INTO "django_geo_db_zipcode" VALUES(17774,40316,-5,'Denniston, Kentucky 40316',12220,15498);
INSERT INTO "django_geo_db_zipcode" VALUES(17775,40317,-5,'Elliottville, Kentucky 40317',12221,15499);
INSERT INTO "django_geo_db_zipcode" VALUES(17776,40319,-5,'Farmers, Kentucky 40319',12222,15500);
INSERT INTO "django_geo_db_zipcode" VALUES(17777,40320,-5,'Ford, Kentucky 40320',12223,15501);
INSERT INTO "django_geo_db_zipcode" VALUES(17778,40322,-5,'Frenchburg, Kentucky 40322',12224,15502);
INSERT INTO "django_geo_db_zipcode" VALUES(17779,40324,-5,'Georgetown, Kentucky 40324',12225,15503);
INSERT INTO "django_geo_db_zipcode" VALUES(17780,40328,-5,'Gravel Switch, Kentucky 40328',12226,15504);
INSERT INTO "django_geo_db_zipcode" VALUES(17781,40329,-5,'Haldeman, Kentucky 40329',12227,15505);
INSERT INTO "django_geo_db_zipcode" VALUES(17782,40330,-5,'Harrodsburg, Kentucky 40330',12228,15506);
INSERT INTO "django_geo_db_zipcode" VALUES(17783,40334,-5,'Hope, Kentucky 40334',12229,15507);
INSERT INTO "django_geo_db_zipcode" VALUES(17784,40336,-5,'Irvine, Kentucky 40336',12230,15508);
INSERT INTO "django_geo_db_zipcode" VALUES(17785,40337,-5,'Jeffersonville, Kentucky 40337',12231,15509);
INSERT INTO "django_geo_db_zipcode" VALUES(17786,40339,-5,'Keene, Kentucky 40339',12232,15510);
INSERT INTO "django_geo_db_zipcode" VALUES(17787,40340,-5,'Nicholasville, Kentucky 40340',12233,15511);
INSERT INTO "django_geo_db_zipcode" VALUES(17788,40342,-5,'Lawrenceburg, Kentucky 40342',12234,15512);
INSERT INTO "django_geo_db_zipcode" VALUES(17789,40346,-5,'Means, Kentucky 40346',12235,15513);
INSERT INTO "django_geo_db_zipcode" VALUES(17790,40347,-5,'Midway, Kentucky 40347',12236,15514);
INSERT INTO "django_geo_db_zipcode" VALUES(17791,40348,-5,'Millersburg, Kentucky 40348',12237,15515);
INSERT INTO "django_geo_db_zipcode" VALUES(17792,40350,-5,'Moorefield, Kentucky 40350',12238,15516);
INSERT INTO "django_geo_db_zipcode" VALUES(17793,40351,-5,'Morehead, Kentucky 40351',12239,15517);
INSERT INTO "django_geo_db_zipcode" VALUES(17794,40353,-5,'Mount Sterling, Kentucky 40353',12240,15518);
INSERT INTO "django_geo_db_zipcode" VALUES(17795,40355,-5,'New Liberty, Kentucky 40355',12241,15519);
INSERT INTO "django_geo_db_zipcode" VALUES(17796,40356,-5,'Nicholasville, Kentucky 40356',12233,15520);
INSERT INTO "django_geo_db_zipcode" VALUES(17797,40357,-5,'North Middletown, Kentucky 40357',12242,15521);
INSERT INTO "django_geo_db_zipcode" VALUES(17798,40358,-5,'Olympia, Kentucky 40358',12243,15522);
INSERT INTO "django_geo_db_zipcode" VALUES(17799,40359,-5,'Owenton, Kentucky 40359',12244,15523);
INSERT INTO "django_geo_db_zipcode" VALUES(17800,40360,-5,'Owingsville, Kentucky 40360',12245,15524);
INSERT INTO "django_geo_db_zipcode" VALUES(17801,40361,-5,'Paris, Kentucky 40361',12246,15525);
INSERT INTO "django_geo_db_zipcode" VALUES(17802,40362,-5,'Paris, Kentucky 40362',12246,15526);
INSERT INTO "django_geo_db_zipcode" VALUES(17803,40363,-5,'Perry Park, Kentucky 40363',12247,15527);
INSERT INTO "django_geo_db_zipcode" VALUES(17804,40366,-5,'Preston, Kentucky 40366',12248,15528);
INSERT INTO "django_geo_db_zipcode" VALUES(17805,40370,-5,'Sadieville, Kentucky 40370',12249,15529);
INSERT INTO "django_geo_db_zipcode" VALUES(17806,40371,-5,'Salt Lick, Kentucky 40371',12250,15530);
INSERT INTO "django_geo_db_zipcode" VALUES(17807,40372,-5,'Salvisa, Kentucky 40372',12251,15531);
INSERT INTO "django_geo_db_zipcode" VALUES(17808,40374,-5,'Sharpsburg, Kentucky 40374',12252,15532);
INSERT INTO "django_geo_db_zipcode" VALUES(17809,40376,-5,'Slade, Kentucky 40376',12253,15533);
INSERT INTO "django_geo_db_zipcode" VALUES(17810,40379,-5,'Stamping Ground, Kentucky 40379',12254,15534);
INSERT INTO "django_geo_db_zipcode" VALUES(17811,40380,-5,'Stanton, Kentucky 40380',12255,15535);
INSERT INTO "django_geo_db_zipcode" VALUES(17812,40383,-5,'Versailles, Kentucky 40383',12256,15536);
INSERT INTO "django_geo_db_zipcode" VALUES(17813,40384,-5,'Versailles, Kentucky 40384',12256,15537);
INSERT INTO "django_geo_db_zipcode" VALUES(17814,40385,-5,'Waco, Kentucky 40385',12257,15538);
INSERT INTO "django_geo_db_zipcode" VALUES(17815,40386,-5,'Versailles, Kentucky 40386',12256,15537);
INSERT INTO "django_geo_db_zipcode" VALUES(17816,40387,-5,'Wellington, Kentucky 40387',12258,15539);
INSERT INTO "django_geo_db_zipcode" VALUES(17817,40390,-5,'Wilmore, Kentucky 40390',12259,15540);
INSERT INTO "django_geo_db_zipcode" VALUES(17818,40391,-5,'Winchester, Kentucky 40391',12260,15541);
INSERT INTO "django_geo_db_zipcode" VALUES(17819,40392,-5,'Winchester, Kentucky 40392',12260,15501);
INSERT INTO "django_geo_db_zipcode" VALUES(17820,40402,-5,'Annville, Kentucky 40402',12261,15542);
INSERT INTO "django_geo_db_zipcode" VALUES(17821,40403,-5,'Berea, Kentucky 40403',12262,15543);
INSERT INTO "django_geo_db_zipcode" VALUES(17822,40404,-5,'Berea, Kentucky 40404',12262,15544);
INSERT INTO "django_geo_db_zipcode" VALUES(17823,40405,-5,'Bighill, Kentucky 40405',12263,15544);
INSERT INTO "django_geo_db_zipcode" VALUES(17824,40409,-5,'Brodhead, Kentucky 40409',12264,15545);
INSERT INTO "django_geo_db_zipcode" VALUES(17825,40410,-5,'Bryantsville, Kentucky 40410',12265,15546);
INSERT INTO "django_geo_db_zipcode" VALUES(17826,40419,-5,'Crab Orchard, Kentucky 40419',12266,15547);
INSERT INTO "django_geo_db_zipcode" VALUES(17827,40421,-5,'Dabolt, Kentucky 40421',12267,15548);
INSERT INTO "django_geo_db_zipcode" VALUES(17828,40422,-5,'Danville, Kentucky 40422',12268,15549);
INSERT INTO "django_geo_db_zipcode" VALUES(17829,40423,-5,'Danville, Kentucky 40423',12268,15550);
INSERT INTO "django_geo_db_zipcode" VALUES(17830,40434,-5,'Gray Hawk, Kentucky 40434',12269,15551);
INSERT INTO "django_geo_db_zipcode" VALUES(17831,40437,-5,'Hustonville, Kentucky 40437',12270,15552);
INSERT INTO "django_geo_db_zipcode" VALUES(17832,40440,-5,'Junction City, Kentucky 40440',12271,15553);
INSERT INTO "django_geo_db_zipcode" VALUES(17833,40442,-5,'Kings Mountain, Kentucky 40442',12272,15554);
INSERT INTO "django_geo_db_zipcode" VALUES(17834,40444,-5,'Lancaster, Kentucky 40444',12273,15555);
INSERT INTO "django_geo_db_zipcode" VALUES(17835,40445,-5,'Livingston, Kentucky 40445',12274,15556);
INSERT INTO "django_geo_db_zipcode" VALUES(17836,40446,-5,'Lancaster, Kentucky 40446',12273,15546);
INSERT INTO "django_geo_db_zipcode" VALUES(17837,40447,-5,'McKee, Kentucky 40447',12275,15557);
INSERT INTO "django_geo_db_zipcode" VALUES(17838,40448,-5,'McKinney, Kentucky 40448',12276,15558);
INSERT INTO "django_geo_db_zipcode" VALUES(17839,40452,-5,'Mitchellsburg, Kentucky 40452',12277,15559);
INSERT INTO "django_geo_db_zipcode" VALUES(17840,40456,-5,'Mount Vernon, Kentucky 40456',12278,15560);
INSERT INTO "django_geo_db_zipcode" VALUES(17841,40460,-5,'Orlando, Kentucky 40460',12279,15561);
INSERT INTO "django_geo_db_zipcode" VALUES(17842,40461,-5,'Paint Lick, Kentucky 40461',12280,15562);
INSERT INTO "django_geo_db_zipcode" VALUES(17843,40464,-5,'Parksville, Kentucky 40464',12281,15563);
INSERT INTO "django_geo_db_zipcode" VALUES(17844,40467,-5,'Peoples, Kentucky 40467',12282,15548);
INSERT INTO "django_geo_db_zipcode" VALUES(17845,40468,-5,'Perryville, Kentucky 40468',12283,15564);
INSERT INTO "django_geo_db_zipcode" VALUES(17846,40469,-5,'Brodhead, Kentucky 40469',12264,15565);
INSERT INTO "django_geo_db_zipcode" VALUES(17847,40472,-5,'Ravenna, Kentucky 40472',12284,15566);
INSERT INTO "django_geo_db_zipcode" VALUES(17848,40473,-5,'Renfro Valley, Kentucky 40473',12285,15567);
INSERT INTO "django_geo_db_zipcode" VALUES(17849,40475,-5,'Richmond, Kentucky 40475',12286,15568);
INSERT INTO "django_geo_db_zipcode" VALUES(17850,40476,-5,'Richmond, Kentucky 40476',12286,15544);
INSERT INTO "django_geo_db_zipcode" VALUES(17851,40481,-5,'Sandgap, Kentucky 40481',12287,15569);
INSERT INTO "django_geo_db_zipcode" VALUES(17852,40484,-5,'Stanford, Kentucky 40484',12288,15570);
INSERT INTO "django_geo_db_zipcode" VALUES(17853,40486,-5,'Tyner, Kentucky 40486',12289,15571);
INSERT INTO "django_geo_db_zipcode" VALUES(17854,40488,-5,'Waneta, Kentucky 40488',12290,15572);
INSERT INTO "django_geo_db_zipcode" VALUES(17855,40489,-5,'Waynesburg, Kentucky 40489',12291,15573);
INSERT INTO "django_geo_db_zipcode" VALUES(17856,40492,-5,'Wildie, Kentucky 40492',12292,15567);
INSERT INTO "django_geo_db_zipcode" VALUES(17857,40495,-5,'Winston, Kentucky 40495',12293,15574);
INSERT INTO "django_geo_db_zipcode" VALUES(17858,40501,-5,'Lexington, Kentucky 40501',12294,15575);
INSERT INTO "django_geo_db_zipcode" VALUES(17859,40502,-5,'Lexington, Kentucky 40502',12294,15576);
INSERT INTO "django_geo_db_zipcode" VALUES(17860,40503,-5,'Lexington, Kentucky 40503',12294,15577);
INSERT INTO "django_geo_db_zipcode" VALUES(17861,40504,-5,'Lexington, Kentucky 40504',12294,15578);
INSERT INTO "django_geo_db_zipcode" VALUES(17862,40505,-5,'Lexington, Kentucky 40505',12294,15579);
INSERT INTO "django_geo_db_zipcode" VALUES(17863,40506,-5,'Lexington, Kentucky 40506',12294,15580);
INSERT INTO "django_geo_db_zipcode" VALUES(17864,40507,-5,'Lexington, Kentucky 40507',12294,15581);
INSERT INTO "django_geo_db_zipcode" VALUES(17865,40508,-5,'Lexington, Kentucky 40508',12294,15582);
INSERT INTO "django_geo_db_zipcode" VALUES(17866,40509,-5,'Lexington, Kentucky 40509',12294,15583);
INSERT INTO "django_geo_db_zipcode" VALUES(17867,40510,-5,'Lexington, Kentucky 40510',12294,15584);
INSERT INTO "django_geo_db_zipcode" VALUES(17868,40511,-5,'Lexington, Kentucky 40511',12294,15585);
INSERT INTO "django_geo_db_zipcode" VALUES(17869,40512,-5,'Lexington, Kentucky 40512',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17870,40513,-5,'Lexington, Kentucky 40513',12294,15587);
INSERT INTO "django_geo_db_zipcode" VALUES(17871,40514,-5,'Lexington, Kentucky 40514',12294,15588);
INSERT INTO "django_geo_db_zipcode" VALUES(17872,40515,-5,'Lexington, Kentucky 40515',12294,15589);
INSERT INTO "django_geo_db_zipcode" VALUES(17873,40516,-5,'Lexington, Kentucky 40516',12294,15590);
INSERT INTO "django_geo_db_zipcode" VALUES(17874,40517,-5,'Lexington, Kentucky 40517',12294,15591);
INSERT INTO "django_geo_db_zipcode" VALUES(17875,40522,-5,'Lexington, Kentucky 40522',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17876,40523,-5,'Lexington, Kentucky 40523',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17877,40524,-5,'Lexington, Kentucky 40524',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17878,40526,-5,'Lexington, Kentucky 40526',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17879,40533,-5,'Lexington, Kentucky 40533',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17880,40536,-5,'Lexington, Kentucky 40536',12294,15592);
INSERT INTO "django_geo_db_zipcode" VALUES(17881,40544,-5,'Lexington, Kentucky 40544',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17882,40546,-5,'Lexington, Kentucky 40546',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17883,40550,-5,'Lexington, Kentucky 40550',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17884,40555,-5,'Lexington, Kentucky 40555',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17885,40574,-5,'Lexington, Kentucky 40574',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17886,40575,-5,'Lexington, Kentucky 40575',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17887,40576,-5,'Lexington, Kentucky 40576',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17888,40577,-5,'Lexington, Kentucky 40577',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17889,40578,-5,'Lexington, Kentucky 40578',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17890,40579,-5,'Lexington, Kentucky 40579',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17891,40580,-5,'Lexington, Kentucky 40580',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17892,40581,-5,'Lexington, Kentucky 40581',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17893,40582,-5,'Lexington, Kentucky 40582',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17894,40583,-5,'Lexington, Kentucky 40583',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17895,40584,-5,'Lexington, Kentucky 40584',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17896,40585,-5,'Lexington, Kentucky 40585',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17897,40586,-5,'Lexington, Kentucky 40586',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17898,40587,-5,'Lexington, Kentucky 40587',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17899,40588,-5,'Lexington, Kentucky 40588',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17900,40589,-5,'Lexington, Kentucky 40589',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17901,40590,-5,'Lexington, Kentucky 40590',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17902,40591,-5,'Lexington, Kentucky 40591',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17903,40592,-5,'Lexington, Kentucky 40592',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17904,40593,-5,'Lexington, Kentucky 40593',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17905,40594,-5,'Lexington, Kentucky 40594',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17906,40595,-5,'Lexington, Kentucky 40595',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17907,40596,-5,'Lexington, Kentucky 40596',12294,15586);
INSERT INTO "django_geo_db_zipcode" VALUES(17908,40601,-5,'Frankfort, Kentucky 40601',12295,15593);
INSERT INTO "django_geo_db_zipcode" VALUES(17909,40602,-5,'Frankfort, Kentucky 40602',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17910,40603,-5,'Frankfort, Kentucky 40603',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17911,40604,-5,'Frankfort, Kentucky 40604',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17912,40618,-5,'Frankfort, Kentucky 40618',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17913,40619,-5,'Frankfort, Kentucky 40619',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17914,40620,-5,'Frankfort, Kentucky 40620',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17915,40621,-5,'Frankfort, Kentucky 40621',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17916,40622,-5,'Frankfort, Kentucky 40622',12295,15594);
INSERT INTO "django_geo_db_zipcode" VALUES(17917,40695,-5,'Middlesborough, Kentucky 40695',12296,15595);
INSERT INTO "django_geo_db_zipcode" VALUES(17918,40701,-5,'Corbin, Kentucky 40701',12297,15596);
INSERT INTO "django_geo_db_zipcode" VALUES(17919,40702,-5,'Corbin, Kentucky 40702',12297,15597);
INSERT INTO "django_geo_db_zipcode" VALUES(17920,40724,-5,'Bush, Kentucky 40724',12298,15598);
INSERT INTO "django_geo_db_zipcode" VALUES(17921,40729,-5,'East Bernstadt, Kentucky 40729',12299,15599);
INSERT INTO "django_geo_db_zipcode" VALUES(17922,40730,-5,'Emlyn, Kentucky 40730',12300,15600);
INSERT INTO "django_geo_db_zipcode" VALUES(17923,40734,-5,'Gray, Kentucky 40734',12301,15601);
INSERT INTO "django_geo_db_zipcode" VALUES(17924,40737,-5,'Keavy, Kentucky 40737',12302,15602);
INSERT INTO "django_geo_db_zipcode" VALUES(17925,40740,-5,'Lily, Kentucky 40740',12303,15603);
INSERT INTO "django_geo_db_zipcode" VALUES(17926,40741,-5,'London, Kentucky 40741',12304,15604);
INSERT INTO "django_geo_db_zipcode" VALUES(17927,40742,-5,'London, Kentucky 40742',12304,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17928,40743,-5,'London, Kentucky 40743',12304,15606);
INSERT INTO "django_geo_db_zipcode" VALUES(17929,40744,-5,'London, Kentucky 40744',12304,15607);
INSERT INTO "django_geo_db_zipcode" VALUES(17930,40745,-5,'London, Kentucky 40745',12304,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17931,40746,-5,'London, Kentucky 40746',12304,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17932,40747,-5,'London, Kentucky 40747',12304,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17933,40748,-5,'London, Kentucky 40748',12304,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17934,40751,-5,'Marydell, Kentucky 40751',12305,15605);
INSERT INTO "django_geo_db_zipcode" VALUES(17935,40754,-5,'Nevisdale, Kentucky 40754',12306,15608);
INSERT INTO "django_geo_db_zipcode" VALUES(17936,40755,-5,'Pittsburg, Kentucky 40755',12307,15609);
INSERT INTO "django_geo_db_zipcode" VALUES(17937,40759,-5,'Rockholds, Kentucky 40759',12308,15610);
INSERT INTO "django_geo_db_zipcode" VALUES(17938,40763,-5,'Siler, Kentucky 40763',12309,15611);
INSERT INTO "django_geo_db_zipcode" VALUES(17939,40769,-5,'Williamsburg, Kentucky 40769',12310,15612);
INSERT INTO "django_geo_db_zipcode" VALUES(17940,40771,-5,'Woodbine, Kentucky 40771',12311,15613);
INSERT INTO "django_geo_db_zipcode" VALUES(17941,40801,-5,'Ages Brookside, Kentucky 40801',12312,15614);
INSERT INTO "django_geo_db_zipcode" VALUES(17942,40803,-5,'Asher, Kentucky 40803',12313,15615);
INSERT INTO "django_geo_db_zipcode" VALUES(17943,40806,-5,'Baxter, Kentucky 40806',12314,15616);
INSERT INTO "django_geo_db_zipcode" VALUES(17944,40807,-5,'Benham, Kentucky 40807',12315,15617);
INSERT INTO "django_geo_db_zipcode" VALUES(17945,40808,-5,'Big Laurel, Kentucky 40808',12316,15618);
INSERT INTO "django_geo_db_zipcode" VALUES(17946,40810,-5,'Bledsoe, Kentucky 40810',12317,15619);
INSERT INTO "django_geo_db_zipcode" VALUES(17947,40813,-5,'Calvin, Kentucky 40813',12318,15620);
INSERT INTO "django_geo_db_zipcode" VALUES(17948,40815,-5,'Cawood, Kentucky 40815',12319,15621);
INSERT INTO "django_geo_db_zipcode" VALUES(17949,40816,-5,'Chappell, Kentucky 40816',12320,15622);
INSERT INTO "django_geo_db_zipcode" VALUES(17950,40818,-5,'Coalgood, Kentucky 40818',12321,15623);
INSERT INTO "django_geo_db_zipcode" VALUES(17951,40819,-5,'Coldiron, Kentucky 40819',12322,15624);
INSERT INTO "django_geo_db_zipcode" VALUES(17952,40820,-5,'Cranks, Kentucky 40820',12323,15625);
INSERT INTO "django_geo_db_zipcode" VALUES(17953,40823,-5,'Cumberland, Kentucky 40823',12324,15626);
INSERT INTO "django_geo_db_zipcode" VALUES(17954,40824,-5,'Dayhoit, Kentucky 40824',12325,15627);
INSERT INTO "django_geo_db_zipcode" VALUES(17955,40826,-5,'Eolia, Kentucky 40826',12326,15628);
INSERT INTO "django_geo_db_zipcode" VALUES(17956,40827,-5,'Essie, Kentucky 40827',12327,15629);
INSERT INTO "django_geo_db_zipcode" VALUES(17957,40828,-5,'Evarts, Kentucky 40828',12328,15630);
INSERT INTO "django_geo_db_zipcode" VALUES(17958,40829,-5,'Grays Knob, Kentucky 40829',12329,15631);
INSERT INTO "django_geo_db_zipcode" VALUES(17959,40830,-5,'Gulston, Kentucky 40830',12330,15632);
INSERT INTO "django_geo_db_zipcode" VALUES(17960,40831,-5,'Harlan, Kentucky 40831',12331,15633);
INSERT INTO "django_geo_db_zipcode" VALUES(17961,40840,-5,'Helton, Kentucky 40840',12332,15634);
INSERT INTO "django_geo_db_zipcode" VALUES(17962,40843,-5,'Holmes Mill, Kentucky 40843',12333,15635);
INSERT INTO "django_geo_db_zipcode" VALUES(17963,40844,-5,'Hoskinston, Kentucky 40844',12334,15636);
INSERT INTO "django_geo_db_zipcode" VALUES(17964,40845,-5,'Hulen, Kentucky 40845',12335,15637);
INSERT INTO "django_geo_db_zipcode" VALUES(17965,40847,-5,'Kenvir, Kentucky 40847',12336,15638);
INSERT INTO "django_geo_db_zipcode" VALUES(17966,40849,-5,'Lejunior, Kentucky 40849',12337,15639);
INSERT INTO "django_geo_db_zipcode" VALUES(17967,40854,-5,'Loyall, Kentucky 40854',12338,15640);
INSERT INTO "django_geo_db_zipcode" VALUES(17968,40855,-5,'Lynch, Kentucky 40855',12339,15641);
INSERT INTO "django_geo_db_zipcode" VALUES(17969,40856,-5,'Miracle, Kentucky 40856',12340,15642);
INSERT INTO "django_geo_db_zipcode" VALUES(17970,40858,-5,'Mozelle, Kentucky 40858',12341,15643);
INSERT INTO "django_geo_db_zipcode" VALUES(17971,40862,-5,'Partridge, Kentucky 40862',12342,15644);
INSERT INTO "django_geo_db_zipcode" VALUES(17972,40863,-5,'Pathfork, Kentucky 40863',12343,15645);
INSERT INTO "django_geo_db_zipcode" VALUES(17973,40865,-5,'Putney, Kentucky 40865',12344,15646);
INSERT INTO "django_geo_db_zipcode" VALUES(17974,40867,-5,'Smith, Kentucky 40867',12345,15647);
INSERT INTO "django_geo_db_zipcode" VALUES(17975,40868,-5,'Stinnett, Kentucky 40868',12346,15648);
INSERT INTO "django_geo_db_zipcode" VALUES(17976,40870,-5,'Totz, Kentucky 40870',12347,15649);
INSERT INTO "django_geo_db_zipcode" VALUES(17977,40873,-5,'Wallins Creek, Kentucky 40873',12348,15650);
INSERT INTO "django_geo_db_zipcode" VALUES(17978,40874,-5,'Warbranch, Kentucky 40874',12349,15651);
INSERT INTO "django_geo_db_zipcode" VALUES(17979,40902,-5,'Arjay, Kentucky 40902',12350,15652);
INSERT INTO "django_geo_db_zipcode" VALUES(17980,40903,-5,'Artemus, Kentucky 40903',12351,15653);
INSERT INTO "django_geo_db_zipcode" VALUES(17981,40906,-5,'Barbourville, Kentucky 40906',12352,15654);
INSERT INTO "django_geo_db_zipcode" VALUES(17982,40913,-5,'Beverly, Kentucky 40913',12353,15655);
INSERT INTO "django_geo_db_zipcode" VALUES(17983,40914,-5,'Big Creek, Kentucky 40914',12354,15656);
INSERT INTO "django_geo_db_zipcode" VALUES(17984,40915,-5,'Bimble, Kentucky 40915',12355,15657);
INSERT INTO "django_geo_db_zipcode" VALUES(17985,40921,-5,'Bryants Store, Kentucky 40921',12356,15658);
INSERT INTO "django_geo_db_zipcode" VALUES(17986,40923,-5,'Cannon, Kentucky 40923',12357,15659);
INSERT INTO "django_geo_db_zipcode" VALUES(17987,40927,-5,'Closplint, Kentucky 40927',12358,15660);
INSERT INTO "django_geo_db_zipcode" VALUES(17988,40930,-5,'Dewitt, Kentucky 40930',12359,15661);
INSERT INTO "django_geo_db_zipcode" VALUES(17989,40931,-5,'Eriline, Kentucky 40931',12360,15662);
INSERT INTO "django_geo_db_zipcode" VALUES(17990,40932,-5,'Fall Rock, Kentucky 40932',12361,15662);
INSERT INTO "django_geo_db_zipcode" VALUES(17991,40935,-5,'Flat Lick, Kentucky 40935',12362,15663);
INSERT INTO "django_geo_db_zipcode" VALUES(17992,40939,-5,'Fourmile, Kentucky 40939',12363,15664);
INSERT INTO "django_geo_db_zipcode" VALUES(17993,40940,-5,'Frakes, Kentucky 40940',12364,15665);
INSERT INTO "django_geo_db_zipcode" VALUES(17994,40941,-5,'Garrard, Kentucky 40941',12365,15666);
INSERT INTO "django_geo_db_zipcode" VALUES(17995,40943,-5,'Girdler, Kentucky 40943',12366,15667);
INSERT INTO "django_geo_db_zipcode" VALUES(17996,40944,-5,'Goose Rock, Kentucky 40944',12367,15662);
INSERT INTO "django_geo_db_zipcode" VALUES(17997,40946,-5,'Green Road, Kentucky 40946',12368,15668);
INSERT INTO "django_geo_db_zipcode" VALUES(17998,40949,-5,'Heidrick, Kentucky 40949',12369,15669);
INSERT INTO "django_geo_db_zipcode" VALUES(17999,40951,-5,'Hima, Kentucky 40951',12370,15662);
INSERT INTO "django_geo_db_zipcode" VALUES(18000,40953,-5,'Hinkle, Kentucky 40953',12371,15670);
INSERT INTO "django_geo_db_zipcode" VALUES(18001,40955,-5,'Ingram, Kentucky 40955',12372,15671);
INSERT INTO "django_geo_db_zipcode" VALUES(18002,40958,-5,'Kettle Island, Kentucky 40958',12373,15672);
INSERT INTO "django_geo_db_zipcode" VALUES(18003,40962,-5,'Manchester, Kentucky 40962',12374,15673);
INSERT INTO "django_geo_db_zipcode" VALUES(18004,40964,-5,'Mary Alice, Kentucky 40964',12375,15674);
INSERT INTO "django_geo_db_zipcode" VALUES(18005,40965,-5,'Middlesboro, Kentucky 40965',12376,15675);
INSERT INTO "django_geo_db_zipcode" VALUES(18006,40972,-5,'Oneida, Kentucky 40972',12377,15676);
INSERT INTO "django_geo_db_zipcode" VALUES(18007,40977,-5,'Pineville, Kentucky 40977',12378,15677);
INSERT INTO "django_geo_db_zipcode" VALUES(18008,40979,-5,'Roark, Kentucky 40979',12379,15678);
INSERT INTO "django_geo_db_zipcode" VALUES(18009,40981,-5,'Saul, Kentucky 40981',12380,15679);
INSERT INTO "django_geo_db_zipcode" VALUES(18010,40982,-5,'Scalf, Kentucky 40982',12381,15680);
INSERT INTO "django_geo_db_zipcode" VALUES(18011,40983,-5,'Sextons Creek, Kentucky 40983',12382,15681);
INSERT INTO "django_geo_db_zipcode" VALUES(18012,40988,-5,'Stoney Fork, Kentucky 40988',12383,15682);
INSERT INTO "django_geo_db_zipcode" VALUES(18013,40995,-5,'Trosper, Kentucky 40995',12384,15683);
INSERT INTO "django_geo_db_zipcode" VALUES(18014,40997,-5,'Walker, Kentucky 40997',12385,15684);
INSERT INTO "django_geo_db_zipcode" VALUES(18015,40999,-5,'Woollum, Kentucky 40999',12386,15685);
INSERT INTO "django_geo_db_zipcode" VALUES(18016,41000,-5,'Fort Mitchell, Kentucky 41000',12387,15686);
INSERT INTO "django_geo_db_zipcode" VALUES(18017,41001,-5,'Alexandria, Kentucky 41001',12388,15687);
INSERT INTO "django_geo_db_zipcode" VALUES(18018,41002,-5,'Augusta, Kentucky 41002',12389,15688);
INSERT INTO "django_geo_db_zipcode" VALUES(18019,41003,-5,'Berry, Kentucky 41003',12390,15689);
INSERT INTO "django_geo_db_zipcode" VALUES(18020,41004,-5,'Brooksville, Kentucky 41004',12391,15690);
INSERT INTO "django_geo_db_zipcode" VALUES(18021,41005,-5,'Burlington, Kentucky 41005',12392,15691);
INSERT INTO "django_geo_db_zipcode" VALUES(18022,41006,-5,'Butler, Kentucky 41006',12393,15692);
INSERT INTO "django_geo_db_zipcode" VALUES(18023,41007,-5,'California, Kentucky 41007',12394,15693);
INSERT INTO "django_geo_db_zipcode" VALUES(18024,41008,-5,'Carrollton, Kentucky 41008',12395,15694);
INSERT INTO "django_geo_db_zipcode" VALUES(18025,41010,-5,'Corinth, Kentucky 41010',12396,15695);
INSERT INTO "django_geo_db_zipcode" VALUES(18026,41011,-5,'Covington, Kentucky 41011',12397,15696);
INSERT INTO "django_geo_db_zipcode" VALUES(18027,41012,-5,'Covington, Kentucky 41012',12397,15697);
INSERT INTO "django_geo_db_zipcode" VALUES(18028,41014,-5,'Covington, Kentucky 41014',12397,15698);
INSERT INTO "django_geo_db_zipcode" VALUES(18029,41015,-5,'Latonia, Kentucky 41015',12398,15699);
INSERT INTO "django_geo_db_zipcode" VALUES(18030,41016,-5,'Covington, Kentucky 41016',12397,15700);
INSERT INTO "django_geo_db_zipcode" VALUES(18031,41017,-5,'Ft Mitchell, Kentucky 41017',12399,15701);
INSERT INTO "django_geo_db_zipcode" VALUES(18032,41018,-5,'Erlanger, Kentucky 41018',12400,15702);
INSERT INTO "django_geo_db_zipcode" VALUES(18033,41019,-5,'Covington, Kentucky 41019',12397,15697);
INSERT INTO "django_geo_db_zipcode" VALUES(18034,41022,-5,'Florence, Kentucky 41022',12401,15703);
INSERT INTO "django_geo_db_zipcode" VALUES(18035,41030,-5,'Crittenden, Kentucky 41030',12402,15704);
INSERT INTO "django_geo_db_zipcode" VALUES(18036,41031,-5,'Cynthiana, Kentucky 41031',12403,15705);
INSERT INTO "django_geo_db_zipcode" VALUES(18037,41033,-5,'De Mossville, Kentucky 41033',12404,15706);
INSERT INTO "django_geo_db_zipcode" VALUES(18038,41034,-5,'Dover, Kentucky 41034',12405,15707);
INSERT INTO "django_geo_db_zipcode" VALUES(18039,41035,-5,'Dry Ridge, Kentucky 41035',12406,15708);
INSERT INTO "django_geo_db_zipcode" VALUES(18040,41037,-5,'Elizaville, Kentucky 41037',12407,15709);
INSERT INTO "django_geo_db_zipcode" VALUES(18041,41039,-5,'Ewing, Kentucky 41039',12408,15710);
INSERT INTO "django_geo_db_zipcode" VALUES(18042,41040,-5,'Falmouth, Kentucky 41040',12409,15711);
INSERT INTO "django_geo_db_zipcode" VALUES(18043,41041,-5,'Flemingsburg, Kentucky 41041',12410,15712);
INSERT INTO "django_geo_db_zipcode" VALUES(18044,41042,-5,'Florence, Kentucky 41042',12401,15713);
INSERT INTO "django_geo_db_zipcode" VALUES(18045,41043,-5,'Foster, Kentucky 41043',12411,15714);
INSERT INTO "django_geo_db_zipcode" VALUES(18046,41044,-5,'Germantown, Kentucky 41044',12412,15715);
INSERT INTO "django_geo_db_zipcode" VALUES(18047,41045,-5,'Ghent, Kentucky 41045',12413,15716);
INSERT INTO "django_geo_db_zipcode" VALUES(18048,41046,-5,'Glencoe, Kentucky 41046',12414,15717);
INSERT INTO "django_geo_db_zipcode" VALUES(18049,41048,-5,'Hebron, Kentucky 41048',12415,15718);
INSERT INTO "django_geo_db_zipcode" VALUES(18050,41049,-5,'Hillsboro, Kentucky 41049',12416,15719);
INSERT INTO "django_geo_db_zipcode" VALUES(18051,41051,-5,'Independence, Kentucky 41051',12417,15720);
INSERT INTO "django_geo_db_zipcode" VALUES(18052,41052,-5,'Jonesville, Kentucky 41052',12418,15721);
INSERT INTO "django_geo_db_zipcode" VALUES(18053,41053,-5,'Kenton, Kentucky 41053',12419,15697);
INSERT INTO "django_geo_db_zipcode" VALUES(18054,41054,-5,'Mason, Kentucky 41054',12420,15722);
INSERT INTO "django_geo_db_zipcode" VALUES(18055,41055,-5,'Mayslick, Kentucky 41055',12421,15723);
INSERT INTO "django_geo_db_zipcode" VALUES(18056,41056,-5,'Maysville, Kentucky 41056',12422,15724);
INSERT INTO "django_geo_db_zipcode" VALUES(18057,41059,-5,'Melbourne, Kentucky 41059',12423,15725);
INSERT INTO "django_geo_db_zipcode" VALUES(18058,41061,-5,'Milford, Kentucky 41061',12424,15726);
INSERT INTO "django_geo_db_zipcode" VALUES(18059,41062,-5,'Minerva, Kentucky 41062',12425,15727);
INSERT INTO "django_geo_db_zipcode" VALUES(18060,41063,-5,'Morning View, Kentucky 41063',12426,15728);
INSERT INTO "django_geo_db_zipcode" VALUES(18061,41064,-5,'Mount Olivet, Kentucky 41064',12427,15729);
INSERT INTO "django_geo_db_zipcode" VALUES(18062,41065,-5,'Muses Mills, Kentucky 41065',12428,15709);
INSERT INTO "django_geo_db_zipcode" VALUES(18063,41071,-5,'Newport, Kentucky 41071',12429,15730);
INSERT INTO "django_geo_db_zipcode" VALUES(18064,41072,-5,'Newport, Kentucky 41072',12429,15731);
INSERT INTO "django_geo_db_zipcode" VALUES(18065,41073,-5,'Bellevue, Kentucky 41073',12430,15732);
INSERT INTO "django_geo_db_zipcode" VALUES(18066,41074,-5,'Dayton, Kentucky 41074',12431,15733);
INSERT INTO "django_geo_db_zipcode" VALUES(18067,41075,-5,'Fort Thomas, Kentucky 41075',12432,15734);
INSERT INTO "django_geo_db_zipcode" VALUES(18068,41076,-5,'Newport, Kentucky 41076',12429,15735);
INSERT INTO "django_geo_db_zipcode" VALUES(18069,41080,-5,'Petersburg, Kentucky 41080',12433,15736);
INSERT INTO "django_geo_db_zipcode" VALUES(18070,41081,-5,'Plummers Landing, Kentucky 41081',12434,15709);
INSERT INTO "django_geo_db_zipcode" VALUES(18071,41083,-5,'Sanders, Kentucky 41083',12435,15737);
INSERT INTO "django_geo_db_zipcode" VALUES(18072,41085,-5,'Silver Grove, Kentucky 41085',12436,15738);
INSERT INTO "django_geo_db_zipcode" VALUES(18073,41086,-5,'Sparta, Kentucky 41086',12437,15739);
INSERT INTO "django_geo_db_zipcode" VALUES(18074,41091,-5,'Union, Kentucky 41091',12438,15740);
INSERT INTO "django_geo_db_zipcode" VALUES(18075,41092,-5,'Verona, Kentucky 41092',12439,15741);
INSERT INTO "django_geo_db_zipcode" VALUES(18076,41093,-5,'Wallingford, Kentucky 41093',12440,15742);
INSERT INTO "django_geo_db_zipcode" VALUES(18077,41094,-5,'Walton, Kentucky 41094',12441,15743);
INSERT INTO "django_geo_db_zipcode" VALUES(18078,41095,-5,'Warsaw, Kentucky 41095',12442,15744);
INSERT INTO "django_geo_db_zipcode" VALUES(18079,41096,-5,'Washington, Kentucky 41096',12443,15745);
INSERT INTO "django_geo_db_zipcode" VALUES(18080,41097,-5,'Williamstown, Kentucky 41097',12444,15746);
INSERT INTO "django_geo_db_zipcode" VALUES(18081,41098,-5,'Worthville, Kentucky 41098',12445,15747);
INSERT INTO "django_geo_db_zipcode" VALUES(18082,41099,-5,'Newport, Kentucky 41099',12429,15731);
INSERT INTO "django_geo_db_zipcode" VALUES(18083,41101,-5,'Ashland, Kentucky 41101',12446,15748);
INSERT INTO "django_geo_db_zipcode" VALUES(18084,41102,-5,'Ashland, Kentucky 41102',12446,15749);
INSERT INTO "django_geo_db_zipcode" VALUES(18085,41105,-5,'Ashland, Kentucky 41105',12446,15750);
INSERT INTO "django_geo_db_zipcode" VALUES(18086,41114,-5,'Ashland, Kentucky 41114',12446,15750);
INSERT INTO "django_geo_db_zipcode" VALUES(18087,41121,-5,'Argillite, Kentucky 41121',12447,15751);
INSERT INTO "django_geo_db_zipcode" VALUES(18088,41124,-5,'Blaine, Kentucky 41124',12448,15752);
INSERT INTO "django_geo_db_zipcode" VALUES(18089,41127,-5,'Camp Dix, Kentucky 41127',12449,15753);
INSERT INTO "django_geo_db_zipcode" VALUES(18090,41128,-5,'Carter, Kentucky 41128',12450,15754);
INSERT INTO "django_geo_db_zipcode" VALUES(18091,41129,-5,'Catlettsburg, Kentucky 41129',12451,15755);
INSERT INTO "django_geo_db_zipcode" VALUES(18092,41132,-5,'Denton, Kentucky 41132',12452,15756);
INSERT INTO "django_geo_db_zipcode" VALUES(18093,41135,-5,'Emerson, Kentucky 41135',12453,15757);
INSERT INTO "django_geo_db_zipcode" VALUES(18094,41137,-5,'Firebrick, Kentucky 41137',12454,15758);
INSERT INTO "django_geo_db_zipcode" VALUES(18095,41139,-5,'Flatwoods, Kentucky 41139',12455,15759);
INSERT INTO "django_geo_db_zipcode" VALUES(18096,41141,-5,'Garrison, Kentucky 41141',12456,15760);
INSERT INTO "django_geo_db_zipcode" VALUES(18097,41142,-5,'Grahn, Kentucky 41142',12457,15761);
INSERT INTO "django_geo_db_zipcode" VALUES(18098,41143,-5,'Grayson, Kentucky 41143',12458,15762);
INSERT INTO "django_geo_db_zipcode" VALUES(18099,41144,-5,'Greenup, Kentucky 41144',12459,15763);
INSERT INTO "django_geo_db_zipcode" VALUES(18100,41146,-5,'Hitchins, Kentucky 41146',12460,15764);
INSERT INTO "django_geo_db_zipcode" VALUES(18101,41149,-5,'Isonville, Kentucky 41149',12461,15765);
INSERT INTO "django_geo_db_zipcode" VALUES(18102,41150,-5,'Jacobs, Kentucky 41150',12462,15766);
INSERT INTO "django_geo_db_zipcode" VALUES(18103,41156,-5,'Lloyd, Kentucky 41156',12463,15767);
INSERT INTO "django_geo_db_zipcode" VALUES(18104,41159,-5,'Martha, Kentucky 41159',12464,15768);
INSERT INTO "django_geo_db_zipcode" VALUES(18105,41160,-5,'Mazie, Kentucky 41160',12465,15769);
INSERT INTO "django_geo_db_zipcode" VALUES(18106,41163,-5,'Grayson, Kentucky 41163',12458,15770);
INSERT INTO "django_geo_db_zipcode" VALUES(18107,41164,-5,'Olive Hill, Kentucky 41164',12466,15771);
INSERT INTO "django_geo_db_zipcode" VALUES(18108,41166,-5,'Quincy, Kentucky 41166',12467,15772);
INSERT INTO "django_geo_db_zipcode" VALUES(18109,41168,-5,'Rush, Kentucky 41168',12468,15773);
INSERT INTO "django_geo_db_zipcode" VALUES(18110,41169,-5,'Russell, Kentucky 41169',12469,15774);
INSERT INTO "django_geo_db_zipcode" VALUES(18111,41170,-5,'Saint Paul, Kentucky 41170',12470,15775);
INSERT INTO "django_geo_db_zipcode" VALUES(18112,41171,-5,'Sandy Hook, Kentucky 41171',12471,15776);
INSERT INTO "django_geo_db_zipcode" VALUES(18113,41173,-5,'Soldier, Kentucky 41173',12472,15777);
INSERT INTO "django_geo_db_zipcode" VALUES(18114,41174,-5,'South Portsmouth, Kentucky 41174',12473,15778);
INSERT INTO "django_geo_db_zipcode" VALUES(18115,41175,-5,'South Shore, Kentucky 41175',12474,15779);
INSERT INTO "django_geo_db_zipcode" VALUES(18116,41179,-5,'Vanceburg, Kentucky 41179',12475,15780);
INSERT INTO "django_geo_db_zipcode" VALUES(18117,41180,-5,'Webbville, Kentucky 41180',12476,15781);
INSERT INTO "django_geo_db_zipcode" VALUES(18118,41181,-5,'Willard, Kentucky 41181',12477,15782);
INSERT INTO "django_geo_db_zipcode" VALUES(18119,41183,-5,'Worthington, Kentucky 41183',12478,15783);
INSERT INTO "django_geo_db_zipcode" VALUES(18120,41189,-5,'Tollesboro, Kentucky 41189',12479,15784);
INSERT INTO "django_geo_db_zipcode" VALUES(18121,41201,-5,'Adams, Kentucky 41201',12480,15785);
INSERT INTO "django_geo_db_zipcode" VALUES(18122,41203,-5,'Beauty, Kentucky 41203',12481,15786);
INSERT INTO "django_geo_db_zipcode" VALUES(18123,41204,-5,'Boons Camp, Kentucky 41204',12482,15787);
INSERT INTO "django_geo_db_zipcode" VALUES(18124,41214,-5,'Debord, Kentucky 41214',12483,15788);
INSERT INTO "django_geo_db_zipcode" VALUES(18125,41215,-5,'Denver, Kentucky 41215',12484,15789);
INSERT INTO "django_geo_db_zipcode" VALUES(18126,41216,-5,'East Point, Kentucky 41216',12485,15790);
INSERT INTO "django_geo_db_zipcode" VALUES(18127,41219,-5,'Flatgap, Kentucky 41219',12486,15791);
INSERT INTO "django_geo_db_zipcode" VALUES(18128,41222,-5,'Hagerhill, Kentucky 41222',12487,15792);
INSERT INTO "django_geo_db_zipcode" VALUES(18129,41224,-5,'Inez, Kentucky 41224',12488,15793);
INSERT INTO "django_geo_db_zipcode" VALUES(18130,41226,-5,'Keaton, Kentucky 41226',12489,15794);
INSERT INTO "django_geo_db_zipcode" VALUES(18131,41228,-5,'Leander, Kentucky 41228',12490,15795);
INSERT INTO "django_geo_db_zipcode" VALUES(18132,41230,-5,'Louisa, Kentucky 41230',12491,15796);
INSERT INTO "django_geo_db_zipcode" VALUES(18133,41231,-5,'Lovely, Kentucky 41231',12492,15797);
INSERT INTO "django_geo_db_zipcode" VALUES(18134,41232,-5,'Lowmansville, Kentucky 41232',12493,15798);
INSERT INTO "django_geo_db_zipcode" VALUES(18135,41234,-5,'Meally, Kentucky 41234',12494,15799);
INSERT INTO "django_geo_db_zipcode" VALUES(18136,41238,-5,'Oil Springs, Kentucky 41238',12495,15800);
INSERT INTO "django_geo_db_zipcode" VALUES(18137,41240,-5,'Paintsville, Kentucky 41240',12496,15801);
INSERT INTO "django_geo_db_zipcode" VALUES(18138,41250,-5,'Pilgrim, Kentucky 41250',12497,15802);
INSERT INTO "django_geo_db_zipcode" VALUES(18139,41254,-5,'River, Kentucky 41254',12498,15803);
INSERT INTO "django_geo_db_zipcode" VALUES(18140,41255,-5,'Sitka, Kentucky 41255',12499,15804);
INSERT INTO "django_geo_db_zipcode" VALUES(18141,41256,-5,'Staffordsville, Kentucky 41256',12500,15805);
INSERT INTO "django_geo_db_zipcode" VALUES(18142,41257,-5,'Stambaugh, Kentucky 41257',12501,15806);
INSERT INTO "django_geo_db_zipcode" VALUES(18143,41260,-5,'Thelma, Kentucky 41260',12502,15807);
INSERT INTO "django_geo_db_zipcode" VALUES(18144,41262,-5,'Tomahawk, Kentucky 41262',12503,15808);
INSERT INTO "django_geo_db_zipcode" VALUES(18145,41263,-5,'Tutor Key, Kentucky 41263',12504,15809);
INSERT INTO "django_geo_db_zipcode" VALUES(18146,41264,-5,'Ulysses, Kentucky 41264',12505,15810);
INSERT INTO "django_geo_db_zipcode" VALUES(18147,41265,-5,'Van Lear, Kentucky 41265',12506,15811);
INSERT INTO "django_geo_db_zipcode" VALUES(18148,41267,-5,'Warfield, Kentucky 41267',12507,15812);
INSERT INTO "django_geo_db_zipcode" VALUES(18149,41268,-5,'West Van Lear, Kentucky 41268',12508,15813);
INSERT INTO "django_geo_db_zipcode" VALUES(18150,41271,-5,'Williamsport, Kentucky 41271',12509,15814);
INSERT INTO "django_geo_db_zipcode" VALUES(18151,41274,-5,'Wittensville, Kentucky 41274',12510,15815);
INSERT INTO "django_geo_db_zipcode" VALUES(18152,41301,-5,'Campton, Kentucky 41301',12511,15816);
INSERT INTO "django_geo_db_zipcode" VALUES(18153,41307,-5,'Athol, Kentucky 41307',12512,15817);
INSERT INTO "django_geo_db_zipcode" VALUES(18154,41310,-5,'Bays, Kentucky 41310',12513,15818);
INSERT INTO "django_geo_db_zipcode" VALUES(18155,41311,-5,'Beattyville, Kentucky 41311',12514,15819);
INSERT INTO "django_geo_db_zipcode" VALUES(18156,41313,-5,'Bethany, Kentucky 41313',12515,15820);
INSERT INTO "django_geo_db_zipcode" VALUES(18157,41314,-5,'Booneville, Kentucky 41314',12516,15821);
INSERT INTO "django_geo_db_zipcode" VALUES(18158,41317,-5,'Clayhole, Kentucky 41317',12517,15822);
INSERT INTO "django_geo_db_zipcode" VALUES(18159,41332,-5,'Hazel Green, Kentucky 41332',12518,15823);
INSERT INTO "django_geo_db_zipcode" VALUES(18160,41333,-5,'Heidelberg, Kentucky 41333',12519,15824);
INSERT INTO "django_geo_db_zipcode" VALUES(18161,41338,-5,'Island City, Kentucky 41338',12520,15825);
INSERT INTO "django_geo_db_zipcode" VALUES(18162,41339,-5,'Jackson, Kentucky 41339',12521,15826);
INSERT INTO "django_geo_db_zipcode" VALUES(18163,41342,-5,'Lee City, Kentucky 41342',12522,15820);
INSERT INTO "django_geo_db_zipcode" VALUES(18164,41344,-5,'Lerose, Kentucky 41344',12523,15827);
INSERT INTO "django_geo_db_zipcode" VALUES(18165,41347,-5,'Lone, Kentucky 41347',12524,15828);
INSERT INTO "django_geo_db_zipcode" VALUES(18166,41348,-5,'Lost Creek, Kentucky 41348',12525,15829);
INSERT INTO "django_geo_db_zipcode" VALUES(18167,41351,-5,'Mistletoe, Kentucky 41351',12526,15825);
INSERT INTO "django_geo_db_zipcode" VALUES(18168,41352,-5,'Mize, Kentucky 41352',12527,15830);
INSERT INTO "django_geo_db_zipcode" VALUES(18169,41360,-5,'Pine Ridge, Kentucky 41360',12528,15831);
INSERT INTO "django_geo_db_zipcode" VALUES(18170,41362,-5,'Primrose, Kentucky 41362',12529,15832);
INSERT INTO "django_geo_db_zipcode" VALUES(18171,41364,-5,'Ricetown, Kentucky 41364',12530,15833);
INSERT INTO "django_geo_db_zipcode" VALUES(18172,41365,-5,'Rogers, Kentucky 41365',12531,15834);
INSERT INTO "django_geo_db_zipcode" VALUES(18173,41366,-5,'Rousseau, Kentucky 41366',12532,15835);
INSERT INTO "django_geo_db_zipcode" VALUES(18174,41367,-5,'Rowdy, Kentucky 41367',12533,15836);
INSERT INTO "django_geo_db_zipcode" VALUES(18175,41368,-5,'Saint Helens, Kentucky 41368',12534,15837);
INSERT INTO "django_geo_db_zipcode" VALUES(18176,41377,-5,'Talbert, Kentucky 41377',12535,15838);
INSERT INTO "django_geo_db_zipcode" VALUES(18177,41385,-5,'Vancleve, Kentucky 41385',12536,15839);
INSERT INTO "django_geo_db_zipcode" VALUES(18178,41386,-5,'Vincent, Kentucky 41386',12537,15840);
INSERT INTO "django_geo_db_zipcode" VALUES(18179,41390,-5,'Whick, Kentucky 41390',12538,15841);
INSERT INTO "django_geo_db_zipcode" VALUES(18180,41397,-5,'Zoe, Kentucky 41397',12539,15842);
INSERT INTO "django_geo_db_zipcode" VALUES(18181,41408,-5,'Cannel City, Kentucky 41408',12540,15843);
INSERT INTO "django_geo_db_zipcode" VALUES(18182,41410,-5,'Cisco, Kentucky 41410',12541,15844);
INSERT INTO "django_geo_db_zipcode" VALUES(18183,41413,-5,'Crockett, Kentucky 41413',12542,15845);
INSERT INTO "django_geo_db_zipcode" VALUES(18184,41419,-5,'Edna, Kentucky 41419',12543,15844);
INSERT INTO "django_geo_db_zipcode" VALUES(18185,41421,-5,'Elkfork, Kentucky 41421',12544,15846);
INSERT INTO "django_geo_db_zipcode" VALUES(18186,41422,-5,'Elsie, Kentucky 41422',12545,15844);
INSERT INTO "django_geo_db_zipcode" VALUES(18187,41425,-5,'Ezel, Kentucky 41425',12546,15847);
INSERT INTO "django_geo_db_zipcode" VALUES(18188,41426,-5,'Falcon, Kentucky 41426',12547,15848);
INSERT INTO "django_geo_db_zipcode" VALUES(18189,41433,-5,'Gapville, Kentucky 41433',12548,15844);
INSERT INTO "django_geo_db_zipcode" VALUES(18190,41444,-5,'Ivyton, Kentucky 41444',12549,15844);
INSERT INTO "django_geo_db_zipcode" VALUES(18191,41451,-5,'Malone, Kentucky 41451',12550,15830);
INSERT INTO "django_geo_db_zipcode" VALUES(18192,41459,-5,'Ophir, Kentucky 41459',12551,15830);
INSERT INTO "django_geo_db_zipcode" VALUES(18193,41463,-5,'Salyersville, Kentucky 41463',12552,15849);
INSERT INTO "django_geo_db_zipcode" VALUES(18194,41464,-5,'Royalton, Kentucky 41464',12553,15850);
INSERT INTO "django_geo_db_zipcode" VALUES(18195,41465,-5,'Salyersville, Kentucky 41465',12552,15851);
INSERT INTO "django_geo_db_zipcode" VALUES(18196,41472,-5,'West Liberty, Kentucky 41472',12554,15852);
INSERT INTO "django_geo_db_zipcode" VALUES(18197,41477,-5,'Wrigley, Kentucky 41477',12555,15830);
INSERT INTO "django_geo_db_zipcode" VALUES(18198,41501,-5,'Pikeville, Kentucky 41501',12556,15853);
INSERT INTO "django_geo_db_zipcode" VALUES(18199,41502,-5,'Pikeville, Kentucky 41502',12556,15854);
INSERT INTO "django_geo_db_zipcode" VALUES(18200,41503,-5,'South Williamson, Kentucky 41503',12557,15855);
INSERT INTO "django_geo_db_zipcode" VALUES(18201,41512,-5,'Ashcamp, Kentucky 41512',12558,15856);
INSERT INTO "django_geo_db_zipcode" VALUES(18202,41513,-5,'Belcher, Kentucky 41513',12559,15857);
INSERT INTO "django_geo_db_zipcode" VALUES(18203,41514,-5,'Belfry, Kentucky 41514',12560,15858);
INSERT INTO "django_geo_db_zipcode" VALUES(18204,41517,-5,'Burdine, Kentucky 41517',12561,15859);
INSERT INTO "django_geo_db_zipcode" VALUES(18205,41519,-5,'Canada, Kentucky 41519',12562,15860);
INSERT INTO "django_geo_db_zipcode" VALUES(18206,41520,-5,'Dorton, Kentucky 41520',12563,15861);
INSERT INTO "django_geo_db_zipcode" VALUES(18207,41522,-5,'Elkhorn City, Kentucky 41522',12564,15862);
INSERT INTO "django_geo_db_zipcode" VALUES(18208,41524,-5,'Fedscreek, Kentucky 41524',12565,15863);
INSERT INTO "django_geo_db_zipcode" VALUES(18209,41526,-5,'Fords Branch, Kentucky 41526',12566,15864);
INSERT INTO "django_geo_db_zipcode" VALUES(18210,41527,-5,'Forest Hills, Kentucky 41527',12567,15865);
INSERT INTO "django_geo_db_zipcode" VALUES(18211,41528,-5,'Freeburn, Kentucky 41528',12568,15866);
INSERT INTO "django_geo_db_zipcode" VALUES(18212,41531,-5,'Hardy, Kentucky 41531',12569,15867);
INSERT INTO "django_geo_db_zipcode" VALUES(18213,41534,-5,'Hellier, Kentucky 41534',12570,15868);
INSERT INTO "django_geo_db_zipcode" VALUES(18214,41535,-5,'Huddy, Kentucky 41535',12571,15869);
INSERT INTO "django_geo_db_zipcode" VALUES(18215,41537,-5,'Jenkins, Kentucky 41537',12572,15870);
INSERT INTO "django_geo_db_zipcode" VALUES(18216,41538,-5,'Jonancy, Kentucky 41538',12573,15871);
INSERT INTO "django_geo_db_zipcode" VALUES(18217,41539,-5,'Kimper, Kentucky 41539',12574,15872);
INSERT INTO "django_geo_db_zipcode" VALUES(18218,41540,-5,'Lick Creek, Kentucky 41540',12575,15873);
INSERT INTO "django_geo_db_zipcode" VALUES(18219,41542,-5,'Lookout, Kentucky 41542',12576,15874);
INSERT INTO "django_geo_db_zipcode" VALUES(18220,41543,-5,'McAndrews, Kentucky 41543',12577,15875);
INSERT INTO "django_geo_db_zipcode" VALUES(18221,41544,-5,'McCarr, Kentucky 41544',12578,15876);
INSERT INTO "django_geo_db_zipcode" VALUES(18222,41546,-5,'McVeigh, Kentucky 41546',12579,15877);
INSERT INTO "django_geo_db_zipcode" VALUES(18223,41547,-5,'Majestic, Kentucky 41547',12580,15878);
INSERT INTO "django_geo_db_zipcode" VALUES(18224,41548,-5,'Mouthcard, Kentucky 41548',12581,15879);
INSERT INTO "django_geo_db_zipcode" VALUES(18225,41549,-5,'Myra, Kentucky 41549',12582,15880);
INSERT INTO "django_geo_db_zipcode" VALUES(18226,41553,-5,'Phelps, Kentucky 41553',12583,15881);
INSERT INTO "django_geo_db_zipcode" VALUES(18227,41554,-5,'Phyllis, Kentucky 41554',12584,15882);
INSERT INTO "django_geo_db_zipcode" VALUES(18228,41555,-5,'Pinsonfork, Kentucky 41555',12585,15883);
INSERT INTO "django_geo_db_zipcode" VALUES(18229,41557,-5,'Raccoon, Kentucky 41557',12586,15884);
INSERT INTO "django_geo_db_zipcode" VALUES(18230,41558,-5,'Ransom, Kentucky 41558',12587,15885);
INSERT INTO "django_geo_db_zipcode" VALUES(18231,41559,-5,'Regina, Kentucky 41559',12588,15886);
INSERT INTO "django_geo_db_zipcode" VALUES(18232,41560,-5,'Robinson Creek, Kentucky 41560',12589,15887);
INSERT INTO "django_geo_db_zipcode" VALUES(18233,41561,-5,'Rockhouse, Kentucky 41561',12590,15888);
INSERT INTO "django_geo_db_zipcode" VALUES(18234,41562,-5,'Shelbiana, Kentucky 41562',12591,15889);
INSERT INTO "django_geo_db_zipcode" VALUES(18235,41563,-5,'Shelby Gap, Kentucky 41563',12592,15890);
INSERT INTO "django_geo_db_zipcode" VALUES(18236,41564,-5,'Sidney, Kentucky 41564',12593,15891);
INSERT INTO "django_geo_db_zipcode" VALUES(18237,41566,-5,'Steele, Kentucky 41566',12594,15892);
INSERT INTO "django_geo_db_zipcode" VALUES(18238,41567,-5,'Stone, Kentucky 41567',12595,15893);
INSERT INTO "django_geo_db_zipcode" VALUES(18239,41568,-5,'Stopover, Kentucky 41568',12596,15894);
INSERT INTO "django_geo_db_zipcode" VALUES(18240,41569,-5,'Toler, Kentucky 41569',12597,15895);
INSERT INTO "django_geo_db_zipcode" VALUES(18241,41571,-5,'Varney, Kentucky 41571',12598,15896);
INSERT INTO "django_geo_db_zipcode" VALUES(18242,41572,-5,'Virgie, Kentucky 41572',12599,15897);
INSERT INTO "django_geo_db_zipcode" VALUES(18243,41601,-5,'Allen, Kentucky 41601',12600,15898);
INSERT INTO "django_geo_db_zipcode" VALUES(18244,41602,-5,'Auxier, Kentucky 41602',12601,15899);
INSERT INTO "django_geo_db_zipcode" VALUES(18245,41603,-5,'Banner, Kentucky 41603',12602,15900);
INSERT INTO "django_geo_db_zipcode" VALUES(18246,41604,-5,'Beaver, Kentucky 41604',12603,15901);
INSERT INTO "django_geo_db_zipcode" VALUES(18247,41605,-5,'Betsy Layne, Kentucky 41605',12604,15902);
INSERT INTO "django_geo_db_zipcode" VALUES(18248,41606,-5,'Bevinsville, Kentucky 41606',12605,15903);
INSERT INTO "django_geo_db_zipcode" VALUES(18249,41607,-5,'Blue River, Kentucky 41607',12606,15904);
INSERT INTO "django_geo_db_zipcode" VALUES(18250,41612,-5,'Bypro, Kentucky 41612',12607,15905);
INSERT INTO "django_geo_db_zipcode" VALUES(18251,41615,-5,'Dana, Kentucky 41615',12608,15906);
INSERT INTO "django_geo_db_zipcode" VALUES(18252,41616,-5,'David, Kentucky 41616',12609,15907);
INSERT INTO "django_geo_db_zipcode" VALUES(18253,41619,-5,'Drift, Kentucky 41619',12610,15908);
INSERT INTO "django_geo_db_zipcode" VALUES(18254,41621,-5,'Dwale, Kentucky 41621',12611,15909);
INSERT INTO "django_geo_db_zipcode" VALUES(18255,41622,-5,'Eastern, Kentucky 41622',12612,15910);
INSERT INTO "django_geo_db_zipcode" VALUES(18256,41630,-5,'Garrett, Kentucky 41630',12613,15911);
INSERT INTO "django_geo_db_zipcode" VALUES(18257,41631,-5,'Grethel, Kentucky 41631',12614,15912);
INSERT INTO "django_geo_db_zipcode" VALUES(18258,41632,-5,'Gunlock, Kentucky 41632',12615,15913);
INSERT INTO "django_geo_db_zipcode" VALUES(18259,41635,-5,'Harold, Kentucky 41635',12616,15914);
INSERT INTO "django_geo_db_zipcode" VALUES(18260,41636,-5,'Hi Hat, Kentucky 41636',12617,15915);
INSERT INTO "django_geo_db_zipcode" VALUES(18261,41640,-5,'Hueysville, Kentucky 41640',12618,15916);
INSERT INTO "django_geo_db_zipcode" VALUES(18262,41642,-5,'Ivel, Kentucky 41642',12619,15917);
INSERT INTO "django_geo_db_zipcode" VALUES(18263,41643,-5,'Lackey, Kentucky 41643',12620,15918);
INSERT INTO "django_geo_db_zipcode" VALUES(18264,41645,-5,'Langley, Kentucky 41645',12621,15919);
INSERT INTO "django_geo_db_zipcode" VALUES(18265,41647,-5,'McDowell, Kentucky 41647',12622,15920);
INSERT INTO "django_geo_db_zipcode" VALUES(18266,41649,-5,'Martin, Kentucky 41649',12623,15921);
INSERT INTO "django_geo_db_zipcode" VALUES(18267,41650,-5,'Melvin, Kentucky 41650',12624,15922);
INSERT INTO "django_geo_db_zipcode" VALUES(18268,41651,-5,'Minnie, Kentucky 41651',12625,15923);
INSERT INTO "django_geo_db_zipcode" VALUES(18269,41653,-5,'Prestonsburg, Kentucky 41653',12626,15924);
INSERT INTO "django_geo_db_zipcode" VALUES(18270,41655,-5,'Printer, Kentucky 41655',12627,15925);
INSERT INTO "django_geo_db_zipcode" VALUES(18271,41659,-5,'Stanville, Kentucky 41659',12628,15926);
INSERT INTO "django_geo_db_zipcode" VALUES(18272,41660,-5,'Teaberry, Kentucky 41660',12629,15927);
INSERT INTO "django_geo_db_zipcode" VALUES(18273,41663,-5,'Tram, Kentucky 41663',12630,15928);
INSERT INTO "django_geo_db_zipcode" VALUES(18274,41666,-5,'Wayland, Kentucky 41666',12631,15929);
INSERT INTO "django_geo_db_zipcode" VALUES(18275,41667,-5,'Weeksbury, Kentucky 41667',12632,15930);
INSERT INTO "django_geo_db_zipcode" VALUES(18276,41668,-5,'West Prestonsburg, Kentucky 41668',12633,15931);
INSERT INTO "django_geo_db_zipcode" VALUES(18277,41669,-5,'Wheelwright, Kentucky 41669',12634,15932);
INSERT INTO "django_geo_db_zipcode" VALUES(18278,41701,-5,'Hazard, Kentucky 41701',12635,15933);
INSERT INTO "django_geo_db_zipcode" VALUES(18279,41702,-5,'Hazard, Kentucky 41702',12635,15934);
INSERT INTO "django_geo_db_zipcode" VALUES(18280,41705,-5,'Fort Thomas, Kentucky 41705',12432,15935);
INSERT INTO "django_geo_db_zipcode" VALUES(18281,41712,-5,'Ary, Kentucky 41712',12636,15936);
INSERT INTO "django_geo_db_zipcode" VALUES(18282,41713,-5,'Avawam, Kentucky 41713',12637,15937);
INSERT INTO "django_geo_db_zipcode" VALUES(18283,41714,-5,'Bear Branch, Kentucky 41714',12638,15938);
INSERT INTO "django_geo_db_zipcode" VALUES(18284,41719,-5,'Bonnyman, Kentucky 41719',12639,15939);
INSERT INTO "django_geo_db_zipcode" VALUES(18285,41721,-5,'Buckhorn, Kentucky 41721',12640,15940);
INSERT INTO "django_geo_db_zipcode" VALUES(18286,41722,-5,'Bulan, Kentucky 41722',12641,15941);
INSERT INTO "django_geo_db_zipcode" VALUES(18287,41723,-5,'Busy, Kentucky 41723',12642,15942);
INSERT INTO "django_geo_db_zipcode" VALUES(18288,41725,-5,'Carrie, Kentucky 41725',12643,15943);
INSERT INTO "django_geo_db_zipcode" VALUES(18289,41727,-5,'Chavies, Kentucky 41727',12644,15944);
INSERT INTO "django_geo_db_zipcode" VALUES(18290,41729,-5,'Combs, Kentucky 41729',12645,15945);
INSERT INTO "django_geo_db_zipcode" VALUES(18291,41730,-5,'Confluence, Kentucky 41730',12646,15946);
INSERT INTO "django_geo_db_zipcode" VALUES(18292,41731,-5,'Cornettsville, Kentucky 41731',12647,15947);
INSERT INTO "django_geo_db_zipcode" VALUES(18293,41735,-5,'Delphia, Kentucky 41735',12648,15948);
INSERT INTO "django_geo_db_zipcode" VALUES(18294,41736,-5,'Dice, Kentucky 41736',12649,15949);
INSERT INTO "django_geo_db_zipcode" VALUES(18295,41739,-5,'Dwarf, Kentucky 41739',12650,15950);
INSERT INTO "django_geo_db_zipcode" VALUES(18296,41740,-5,'Emmalena, Kentucky 41740',12651,15951);
INSERT INTO "django_geo_db_zipcode" VALUES(18297,41743,-5,'Fisty, Kentucky 41743',12652,15952);
INSERT INTO "django_geo_db_zipcode" VALUES(18298,41745,-5,'Gays Creek, Kentucky 41745',12653,15953);
INSERT INTO "django_geo_db_zipcode" VALUES(18299,41746,-5,'Happy, Kentucky 41746',12654,15954);
INSERT INTO "django_geo_db_zipcode" VALUES(18300,41747,-5,'Hardburly, Kentucky 41747',12655,15955);
INSERT INTO "django_geo_db_zipcode" VALUES(18301,41749,-5,'Hyden, Kentucky 41749',12656,15956);
INSERT INTO "django_geo_db_zipcode" VALUES(18302,41751,-5,'Jeff, Kentucky 41751',12657,15957);
INSERT INTO "django_geo_db_zipcode" VALUES(18303,41754,-5,'Krypton, Kentucky 41754',12658,15958);
INSERT INTO "django_geo_db_zipcode" VALUES(18304,41759,-5,'Sassafras, Kentucky 41759',12659,15959);
INSERT INTO "django_geo_db_zipcode" VALUES(18305,41760,-5,'Scuddy, Kentucky 41760',12660,15960);
INSERT INTO "django_geo_db_zipcode" VALUES(18306,41762,-5,'Sizerock, Kentucky 41762',12661,15961);
INSERT INTO "django_geo_db_zipcode" VALUES(18307,41763,-5,'Slemp, Kentucky 41763',12662,15962);
INSERT INTO "django_geo_db_zipcode" VALUES(18308,41764,-5,'Smilax, Kentucky 41764',12663,15963);
INSERT INTO "django_geo_db_zipcode" VALUES(18309,41766,-5,'Thousandsticks, Kentucky 41766',12664,15964);
INSERT INTO "django_geo_db_zipcode" VALUES(18310,41772,-5,'Vest, Kentucky 41772',12665,15965);
INSERT INTO "django_geo_db_zipcode" VALUES(18311,41773,-5,'Vicco, Kentucky 41773',12666,15966);
INSERT INTO "django_geo_db_zipcode" VALUES(18312,41774,-5,'Viper, Kentucky 41774',12667,15967);
INSERT INTO "django_geo_db_zipcode" VALUES(18313,41775,-5,'Wendover, Kentucky 41775',12668,15968);
INSERT INTO "django_geo_db_zipcode" VALUES(18314,41776,-5,'Wooton, Kentucky 41776',12669,15969);
INSERT INTO "django_geo_db_zipcode" VALUES(18315,41777,-5,'Yeaddiss, Kentucky 41777',12670,15970);
INSERT INTO "django_geo_db_zipcode" VALUES(18316,41778,-5,'Yerkes, Kentucky 41778',12671,15971);
INSERT INTO "django_geo_db_zipcode" VALUES(18317,41804,-5,'Blackey, Kentucky 41804',12672,15972);
INSERT INTO "django_geo_db_zipcode" VALUES(18318,41810,-5,'Cromona, Kentucky 41810',12673,15973);
INSERT INTO "django_geo_db_zipcode" VALUES(18319,41812,-5,'Deane, Kentucky 41812',12674,15974);
INSERT INTO "django_geo_db_zipcode" VALUES(18320,41815,-5,'Ermine, Kentucky 41815',12675,15975);
INSERT INTO "django_geo_db_zipcode" VALUES(18321,41817,-5,'Garner, Kentucky 41817',12676,15976);
INSERT INTO "django_geo_db_zipcode" VALUES(18322,41819,-5,'Gordon, Kentucky 41819',12677,15977);
INSERT INTO "django_geo_db_zipcode" VALUES(18323,41821,-5,'Hallie, Kentucky 41821',12678,15978);
INSERT INTO "django_geo_db_zipcode" VALUES(18324,41822,-5,'Hindman, Kentucky 41822',12679,15979);
INSERT INTO "django_geo_db_zipcode" VALUES(18325,41824,-5,'Isom, Kentucky 41824',12680,15980);
INSERT INTO "django_geo_db_zipcode" VALUES(18326,41825,-5,'Jackhorn, Kentucky 41825',12681,15981);
INSERT INTO "django_geo_db_zipcode" VALUES(18327,41826,-5,'Jeremiah, Kentucky 41826',12682,15982);
INSERT INTO "django_geo_db_zipcode" VALUES(18328,41828,-5,'Kite, Kentucky 41828',12683,15983);
INSERT INTO "django_geo_db_zipcode" VALUES(18329,41831,-5,'Leburn, Kentucky 41831',12684,15984);
INSERT INTO "django_geo_db_zipcode" VALUES(18330,41832,-5,'Letcher, Kentucky 41832',12685,15985);
INSERT INTO "django_geo_db_zipcode" VALUES(18331,41833,-5,'Linefork, Kentucky 41833',12686,15986);
INSERT INTO "django_geo_db_zipcode" VALUES(18332,41834,-5,'Littcarr, Kentucky 41834',12687,15987);
INSERT INTO "django_geo_db_zipcode" VALUES(18333,41835,-5,'McRoberts, Kentucky 41835',12688,15988);
INSERT INTO "django_geo_db_zipcode" VALUES(18334,41836,-5,'Mallie, Kentucky 41836',12689,15989);
INSERT INTO "django_geo_db_zipcode" VALUES(18335,41837,-5,'Mayking, Kentucky 41837',12690,15990);
INSERT INTO "django_geo_db_zipcode" VALUES(18336,41838,-5,'Millstone, Kentucky 41838',12691,15991);
INSERT INTO "django_geo_db_zipcode" VALUES(18337,41839,-5,'Mousie, Kentucky 41839',12692,15992);
INSERT INTO "django_geo_db_zipcode" VALUES(18338,41840,-5,'Neon, Kentucky 41840',12693,15993);
INSERT INTO "django_geo_db_zipcode" VALUES(18339,41843,-5,'Pine Top, Kentucky 41843',12694,15994);
INSERT INTO "django_geo_db_zipcode" VALUES(18340,41844,-5,'Pippa Passes, Kentucky 41844',12695,15995);
INSERT INTO "django_geo_db_zipcode" VALUES(18341,41845,-5,'Premium, Kentucky 41845',12696,15996);
INSERT INTO "django_geo_db_zipcode" VALUES(18342,41847,-5,'Redfox, Kentucky 41847',12697,15997);
INSERT INTO "django_geo_db_zipcode" VALUES(18343,41848,-5,'Roxana, Kentucky 41848',12698,15998);
INSERT INTO "django_geo_db_zipcode" VALUES(18344,41849,-5,'Seco, Kentucky 41849',12699,15999);
INSERT INTO "django_geo_db_zipcode" VALUES(18345,41855,-5,'Thornton, Kentucky 41855',12700,16000);
INSERT INTO "django_geo_db_zipcode" VALUES(18346,41858,-5,'Whitesburg, Kentucky 41858',12701,16001);
INSERT INTO "django_geo_db_zipcode" VALUES(18347,41859,-5,'Dema, Kentucky 41859',12702,16002);
INSERT INTO "django_geo_db_zipcode" VALUES(18348,41861,-5,'Raven, Kentucky 41861',12703,16003);
INSERT INTO "django_geo_db_zipcode" VALUES(18349,41862,-5,'Topmost, Kentucky 41862',12704,16004);
INSERT INTO "django_geo_db_zipcode" VALUES(18350,42001,-6,'Paducah, Kentucky 42001',12705,16005);
INSERT INTO "django_geo_db_zipcode" VALUES(18351,42002,-6,'Paducah, Kentucky 42002',12705,16006);
INSERT INTO "django_geo_db_zipcode" VALUES(18352,42003,-6,'Paducah, Kentucky 42003',12705,16007);
INSERT INTO "django_geo_db_zipcode" VALUES(18353,42011,-6,'Fredonia, Kentucky 42011',12706,16008);
INSERT INTO "django_geo_db_zipcode" VALUES(18354,42020,-6,'Almo, Kentucky 42020',12707,16009);
INSERT INTO "django_geo_db_zipcode" VALUES(18355,42021,-6,'Arlington, Kentucky 42021',12708,16010);
INSERT INTO "django_geo_db_zipcode" VALUES(18356,42022,-6,'Bandana, Kentucky 42022',12709,16011);
INSERT INTO "django_geo_db_zipcode" VALUES(18357,42023,-6,'Bardwell, Kentucky 42023',12710,16012);
INSERT INTO "django_geo_db_zipcode" VALUES(18358,42024,-6,'Barlow, Kentucky 42024',12711,16013);
INSERT INTO "django_geo_db_zipcode" VALUES(18359,42025,-6,'Benton, Kentucky 42025',12712,16014);
INSERT INTO "django_geo_db_zipcode" VALUES(18360,42027,-6,'Boaz, Kentucky 42027',12713,16015);
INSERT INTO "django_geo_db_zipcode" VALUES(18361,42028,-6,'Burna, Kentucky 42028',12714,16016);
INSERT INTO "django_geo_db_zipcode" VALUES(18362,42029,-6,'Calvert City, Kentucky 42029',12715,16017);
INSERT INTO "django_geo_db_zipcode" VALUES(18363,42031,-6,'Clinton, Kentucky 42031',12716,16018);
INSERT INTO "django_geo_db_zipcode" VALUES(18364,42032,-6,'Columbus, Kentucky 42032',12717,16019);
INSERT INTO "django_geo_db_zipcode" VALUES(18365,42033,-6,'Crayne, Kentucky 42033',12718,16020);
INSERT INTO "django_geo_db_zipcode" VALUES(18366,42035,-6,'Cunningham, Kentucky 42035',12719,16021);
INSERT INTO "django_geo_db_zipcode" VALUES(18367,42036,-6,'Dexter, Kentucky 42036',12720,16022);
INSERT INTO "django_geo_db_zipcode" VALUES(18368,42037,-6,'Dycusburg, Kentucky 42037',12721,16023);
INSERT INTO "django_geo_db_zipcode" VALUES(18369,42038,-6,'Eddyville, Kentucky 42038',12722,16024);
INSERT INTO "django_geo_db_zipcode" VALUES(18370,42039,-6,'Fancy Farm, Kentucky 42039',12723,16025);
INSERT INTO "django_geo_db_zipcode" VALUES(18371,42040,-6,'Farmington, Kentucky 42040',12724,16026);
INSERT INTO "django_geo_db_zipcode" VALUES(18372,42041,-6,'Fulton, Kentucky 42041',12725,16027);
INSERT INTO "django_geo_db_zipcode" VALUES(18373,42044,-6,'Gilbertsville, Kentucky 42044',12726,16028);
INSERT INTO "django_geo_db_zipcode" VALUES(18374,42045,-6,'Grand Rivers, Kentucky 42045',12727,16029);
INSERT INTO "django_geo_db_zipcode" VALUES(18375,42046,-6,'Hamlin, Kentucky 42046',12728,16030);
INSERT INTO "django_geo_db_zipcode" VALUES(18376,42047,-6,'Hampton, Kentucky 42047',12729,16031);
INSERT INTO "django_geo_db_zipcode" VALUES(18377,42048,-6,'Hardin, Kentucky 42048',12730,16032);
INSERT INTO "django_geo_db_zipcode" VALUES(18378,42049,-6,'Hazel, Kentucky 42049',12731,16033);
INSERT INTO "django_geo_db_zipcode" VALUES(18379,42050,-6,'Hickman, Kentucky 42050',12732,16034);
INSERT INTO "django_geo_db_zipcode" VALUES(18380,42051,-6,'Hickory, Kentucky 42051',12733,16035);
INSERT INTO "django_geo_db_zipcode" VALUES(18381,42053,-6,'Kevil, Kentucky 42053',12734,16036);
INSERT INTO "django_geo_db_zipcode" VALUES(18382,42054,-6,'Kirksey, Kentucky 42054',12735,16037);
INSERT INTO "django_geo_db_zipcode" VALUES(18383,42055,-6,'Kuttawa, Kentucky 42055',12736,16038);
INSERT INTO "django_geo_db_zipcode" VALUES(18384,42056,-6,'La Center, Kentucky 42056',12737,16039);
INSERT INTO "django_geo_db_zipcode" VALUES(18385,42058,-6,'Ledbetter, Kentucky 42058',12738,16040);
INSERT INTO "django_geo_db_zipcode" VALUES(18386,42060,-6,'Lovelaceville, Kentucky 42060',12739,16041);
INSERT INTO "django_geo_db_zipcode" VALUES(18387,42061,-6,'Lowes, Kentucky 42061',12740,16042);
INSERT INTO "django_geo_db_zipcode" VALUES(18388,42063,-6,'Lynnville, Kentucky 42063',12741,16043);
INSERT INTO "django_geo_db_zipcode" VALUES(18389,42064,-6,'Marion, Kentucky 42064',12742,16044);
INSERT INTO "django_geo_db_zipcode" VALUES(18390,42066,-6,'Mayfield, Kentucky 42066',12743,16045);
INSERT INTO "django_geo_db_zipcode" VALUES(18391,42069,-6,'Melber, Kentucky 42069',12744,16046);
INSERT INTO "django_geo_db_zipcode" VALUES(18392,42070,-6,'Milburn, Kentucky 42070',12745,16047);
INSERT INTO "django_geo_db_zipcode" VALUES(18393,42071,-6,'Murray, Kentucky 42071',12746,16048);
INSERT INTO "django_geo_db_zipcode" VALUES(18394,42076,-6,'New Concord, Kentucky 42076',12747,16049);
INSERT INTO "django_geo_db_zipcode" VALUES(18395,42078,-6,'Salem, Kentucky 42078',12748,16050);
INSERT INTO "django_geo_db_zipcode" VALUES(18396,42079,-6,'Sedalia, Kentucky 42079',12749,16051);
INSERT INTO "django_geo_db_zipcode" VALUES(18397,42081,-6,'Smithland, Kentucky 42081',12750,16052);
INSERT INTO "django_geo_db_zipcode" VALUES(18398,42082,-6,'Symsonia, Kentucky 42082',12751,16053);
INSERT INTO "django_geo_db_zipcode" VALUES(18399,42083,-6,'Tiline, Kentucky 42083',12752,16054);
INSERT INTO "django_geo_db_zipcode" VALUES(18400,42084,-6,'Tolu, Kentucky 42084',12753,16055);
INSERT INTO "django_geo_db_zipcode" VALUES(18401,42085,-6,'Water Valley, Kentucky 42085',12754,16056);
INSERT INTO "django_geo_db_zipcode" VALUES(18402,42086,-6,'West Paducah, Kentucky 42086',12755,16057);
INSERT INTO "django_geo_db_zipcode" VALUES(18403,42087,-6,'Wickliffe, Kentucky 42087',12756,16058);
INSERT INTO "django_geo_db_zipcode" VALUES(18404,42088,-6,'Wingo, Kentucky 42088',12757,16059);
INSERT INTO "django_geo_db_zipcode" VALUES(18405,42101,-6,'Bowling Green, Kentucky 42101',12758,16060);
INSERT INTO "django_geo_db_zipcode" VALUES(18406,42102,-6,'Bowling Green, Kentucky 42102',12758,16061);
INSERT INTO "django_geo_db_zipcode" VALUES(18407,42103,-6,'Bowling Green, Kentucky 42103',12758,16062);
INSERT INTO "django_geo_db_zipcode" VALUES(18408,42104,-6,'Bowling Green, Kentucky 42104',12758,16063);
INSERT INTO "django_geo_db_zipcode" VALUES(18409,42109,-6,'Bowling Green, Kentucky 42109',12758,16064);
INSERT INTO "django_geo_db_zipcode" VALUES(18410,42120,-6,'Adolphus, Kentucky 42120',12759,16065);
INSERT INTO "django_geo_db_zipcode" VALUES(18411,42122,-6,'Alvaton, Kentucky 42122',12760,16066);
INSERT INTO "django_geo_db_zipcode" VALUES(18412,42123,-6,'Austin, Kentucky 42123',12761,16067);
INSERT INTO "django_geo_db_zipcode" VALUES(18413,42124,-6,'Beaumont, Kentucky 42124',12762,16068);
INSERT INTO "django_geo_db_zipcode" VALUES(18414,42127,-6,'Cave City, Kentucky 42127',12763,16069);
INSERT INTO "django_geo_db_zipcode" VALUES(18415,42128,-6,'Drake, Kentucky 42128',12764,16070);
INSERT INTO "django_geo_db_zipcode" VALUES(18416,42129,-6,'Edmonton, Kentucky 42129',12765,16071);
INSERT INTO "django_geo_db_zipcode" VALUES(18417,42130,-6,'Eighty Eight, Kentucky 42130',12766,16072);
INSERT INTO "django_geo_db_zipcode" VALUES(18418,42131,-6,'Etoile, Kentucky 42131',12767,16073);
INSERT INTO "django_geo_db_zipcode" VALUES(18419,42133,-6,'Fountain Run, Kentucky 42133',12768,16074);
INSERT INTO "django_geo_db_zipcode" VALUES(18420,42134,-6,'Franklin, Kentucky 42134',12769,16075);
INSERT INTO "django_geo_db_zipcode" VALUES(18421,42135,-6,'Franklin, Kentucky 42135',12769,16076);
INSERT INTO "django_geo_db_zipcode" VALUES(18422,42140,-6,'Gamaliel, Kentucky 42140',12770,16077);
INSERT INTO "django_geo_db_zipcode" VALUES(18423,42141,-6,'Glasgow, Kentucky 42141',12771,16078);
INSERT INTO "django_geo_db_zipcode" VALUES(18424,42142,-6,'Glasgow, Kentucky 42142',12771,16079);
INSERT INTO "django_geo_db_zipcode" VALUES(18425,42150,-6,'Halfway, Kentucky 42150',12772,16080);
INSERT INTO "django_geo_db_zipcode" VALUES(18426,42151,-6,'Hestand, Kentucky 42151',12773,16081);
INSERT INTO "django_geo_db_zipcode" VALUES(18427,42152,-6,'Hiseville, Kentucky 42152',12774,16082);
INSERT INTO "django_geo_db_zipcode" VALUES(18428,42153,-6,'Holland, Kentucky 42153',12775,16083);
INSERT INTO "django_geo_db_zipcode" VALUES(18429,42154,-6,'Knob Lick, Kentucky 42154',12776,16084);
INSERT INTO "django_geo_db_zipcode" VALUES(18430,42156,-6,'Lucas, Kentucky 42156',12777,16085);
INSERT INTO "django_geo_db_zipcode" VALUES(18431,42157,-6,'Mount Hermon, Kentucky 42157',12778,16086);
INSERT INTO "django_geo_db_zipcode" VALUES(18432,42159,-6,'Oakland, Kentucky 42159',12779,16087);
INSERT INTO "django_geo_db_zipcode" VALUES(18433,42160,-6,'Park City, Kentucky 42160',12780,16088);
INSERT INTO "django_geo_db_zipcode" VALUES(18434,42163,-6,'Rocky Hill, Kentucky 42163',12781,16089);
INSERT INTO "django_geo_db_zipcode" VALUES(18435,42164,-6,'Scottsville, Kentucky 42164',12782,16090);
INSERT INTO "django_geo_db_zipcode" VALUES(18436,42166,-6,'Summer Shade, Kentucky 42166',12783,16091);
INSERT INTO "django_geo_db_zipcode" VALUES(18437,42167,-6,'Tompkinsville, Kentucky 42167',12784,16092);
INSERT INTO "django_geo_db_zipcode" VALUES(18438,42170,-6,'Woodburn, Kentucky 42170',12785,16093);
INSERT INTO "django_geo_db_zipcode" VALUES(18439,42171,-6,'Smiths Grove, Kentucky 42171',12786,16094);
INSERT INTO "django_geo_db_zipcode" VALUES(18440,42201,-6,'Aberdeen, Kentucky 42201',12787,16095);
INSERT INTO "django_geo_db_zipcode" VALUES(18441,42202,-6,'Adairville, Kentucky 42202',12788,16096);
INSERT INTO "django_geo_db_zipcode" VALUES(18442,42203,-6,'Allegre, Kentucky 42203',12789,16097);
INSERT INTO "django_geo_db_zipcode" VALUES(18443,42204,-6,'Allensville, Kentucky 42204',12790,16098);
INSERT INTO "django_geo_db_zipcode" VALUES(18444,42206,-6,'Auburn, Kentucky 42206',12791,16099);
INSERT INTO "django_geo_db_zipcode" VALUES(18445,42207,-6,'Bee Spring, Kentucky 42207',12792,16100);
INSERT INTO "django_geo_db_zipcode" VALUES(18446,42209,-6,'Brooklyn, Kentucky 42209',12793,16101);
INSERT INTO "django_geo_db_zipcode" VALUES(18447,42210,-6,'Brownsville, Kentucky 42210',12794,16102);
INSERT INTO "django_geo_db_zipcode" VALUES(18448,42211,-6,'Cadiz, Kentucky 42211',12795,16103);
INSERT INTO "django_geo_db_zipcode" VALUES(18449,42214,-6,'Center, Kentucky 42214',12796,16104);
INSERT INTO "django_geo_db_zipcode" VALUES(18450,42215,-6,'Cerulean, Kentucky 42215',12797,16105);
INSERT INTO "django_geo_db_zipcode" VALUES(18451,42216,-6,'Clifty, Kentucky 42216',12798,16106);
INSERT INTO "django_geo_db_zipcode" VALUES(18452,42217,-6,'Crofton, Kentucky 42217',12799,16107);
INSERT INTO "django_geo_db_zipcode" VALUES(18453,42219,-6,'Dunbar, Kentucky 42219',12800,16108);
INSERT INTO "django_geo_db_zipcode" VALUES(18454,42220,-6,'Elkton, Kentucky 42220',12801,16109);
INSERT INTO "django_geo_db_zipcode" VALUES(18455,42221,-6,'Fairview, Kentucky 42221',12802,16110);
INSERT INTO "django_geo_db_zipcode" VALUES(18456,42223,-6,'Fort Campbell, Kentucky 42223',12803,16111);
INSERT INTO "django_geo_db_zipcode" VALUES(18457,42232,-6,'Gracey, Kentucky 42232',12804,16112);
INSERT INTO "django_geo_db_zipcode" VALUES(18458,42234,-6,'Guthrie, Kentucky 42234',12805,16113);
INSERT INTO "django_geo_db_zipcode" VALUES(18459,42235,-6,'Hadley, Kentucky 42235',12806,16070);
INSERT INTO "django_geo_db_zipcode" VALUES(18460,42236,-6,'Herndon, Kentucky 42236',12807,16114);
INSERT INTO "django_geo_db_zipcode" VALUES(18461,42240,-6,'Hopkinsville, Kentucky 42240',12808,16115);
INSERT INTO "django_geo_db_zipcode" VALUES(18462,42241,-6,'Hopkinsville, Kentucky 42241',12808,16110);
INSERT INTO "django_geo_db_zipcode" VALUES(18463,42251,-6,'Huntsville, Kentucky 42251',12809,16116);
INSERT INTO "django_geo_db_zipcode" VALUES(18464,42252,-6,'Jetson, Kentucky 42252',12810,16117);
INSERT INTO "django_geo_db_zipcode" VALUES(18465,42253,-5,'Science Hill, Kentucky 42253',12811,16118);
INSERT INTO "django_geo_db_zipcode" VALUES(18466,42254,-6,'La Fayette, Kentucky 42254',12812,16119);
INSERT INTO "django_geo_db_zipcode" VALUES(18467,42256,-6,'Lewisburg, Kentucky 42256',12813,16120);
INSERT INTO "django_geo_db_zipcode" VALUES(18468,42257,-6,'Lindseyville, Kentucky 42257',12814,16121);
INSERT INTO "django_geo_db_zipcode" VALUES(18469,42259,-6,'Mammoth Cave, Kentucky 42259',12815,16122);
INSERT INTO "django_geo_db_zipcode" VALUES(18470,42261,-6,'Morgantown, Kentucky 42261',12816,16123);
INSERT INTO "django_geo_db_zipcode" VALUES(18471,42262,-6,'Oak Grove, Kentucky 42262',12817,16124);
INSERT INTO "django_geo_db_zipcode" VALUES(18472,42265,-6,'Olmstead, Kentucky 42265',12818,16125);
INSERT INTO "django_geo_db_zipcode" VALUES(18473,42266,-6,'Pembroke, Kentucky 42266',12819,16126);
INSERT INTO "django_geo_db_zipcode" VALUES(18474,42267,-6,'Provo, Kentucky 42267',12820,16127);
INSERT INTO "django_geo_db_zipcode" VALUES(18475,42270,-6,'Richardsville, Kentucky 42270',12821,16070);
INSERT INTO "django_geo_db_zipcode" VALUES(18476,42273,-6,'Rochester, Kentucky 42273',12822,16128);
INSERT INTO "django_geo_db_zipcode" VALUES(18477,42274,-6,'Rockfield, Kentucky 42274',12823,16129);
INSERT INTO "django_geo_db_zipcode" VALUES(18478,42275,-6,'Roundhill, Kentucky 42275',12824,16130);
INSERT INTO "django_geo_db_zipcode" VALUES(18479,42276,-6,'Russellville, Kentucky 42276',12825,16131);
INSERT INTO "django_geo_db_zipcode" VALUES(18480,42280,-6,'Sharon Grove, Kentucky 42280',12826,16132);
INSERT INTO "django_geo_db_zipcode" VALUES(18481,42283,-6,'South Union, Kentucky 42283',12827,16133);
INSERT INTO "django_geo_db_zipcode" VALUES(18482,42285,-6,'Sweeden, Kentucky 42285',12828,16134);
INSERT INTO "django_geo_db_zipcode" VALUES(18483,42286,-6,'Trenton, Kentucky 42286',12829,16135);
INSERT INTO "django_geo_db_zipcode" VALUES(18484,42287,-6,'Welchs Creek, Kentucky 42287',12830,16136);
INSERT INTO "django_geo_db_zipcode" VALUES(18485,42288,-6,'Woodbury, Kentucky 42288',12831,16101);
INSERT INTO "django_geo_db_zipcode" VALUES(18486,42301,-6,'Owensboro, Kentucky 42301',12832,16137);
INSERT INTO "django_geo_db_zipcode" VALUES(18487,42302,-6,'Owensboro, Kentucky 42302',12832,16138);
INSERT INTO "django_geo_db_zipcode" VALUES(18488,42303,-6,'Owensboro, Kentucky 42303',12832,16139);
INSERT INTO "django_geo_db_zipcode" VALUES(18489,42304,-6,'Owensboro, Kentucky 42304',12832,16138);
INSERT INTO "django_geo_db_zipcode" VALUES(18490,42320,-6,'Beaver Dam, Kentucky 42320',12833,16140);
INSERT INTO "django_geo_db_zipcode" VALUES(18491,42321,-6,'Beech Creek, Kentucky 42321',12834,16141);
INSERT INTO "django_geo_db_zipcode" VALUES(18492,42322,-6,'Beech Grove, Kentucky 42322',12835,16142);
INSERT INTO "django_geo_db_zipcode" VALUES(18493,42323,-6,'Beechmont, Kentucky 42323',12836,16143);
INSERT INTO "django_geo_db_zipcode" VALUES(18494,42324,-6,'Belton, Kentucky 42324',12837,16144);
INSERT INTO "django_geo_db_zipcode" VALUES(18495,42325,-6,'Bremen, Kentucky 42325',12838,16145);
INSERT INTO "django_geo_db_zipcode" VALUES(18496,42326,-6,'Browder, Kentucky 42326',12839,16146);
INSERT INTO "django_geo_db_zipcode" VALUES(18497,42327,-6,'Calhoun, Kentucky 42327',12840,16147);
INSERT INTO "django_geo_db_zipcode" VALUES(18498,42328,-6,'Centertown, Kentucky 42328',12841,16148);
INSERT INTO "django_geo_db_zipcode" VALUES(18499,42330,-6,'Central City, Kentucky 42330',12842,16149);
INSERT INTO "django_geo_db_zipcode" VALUES(18500,42332,-6,'Cleaton, Kentucky 42332',12843,16150);
INSERT INTO "django_geo_db_zipcode" VALUES(18501,42333,-6,'Cromwell, Kentucky 42333',12844,16151);
INSERT INTO "django_geo_db_zipcode" VALUES(18502,42334,-6,'Curdsville, Kentucky 42334',12845,16138);
INSERT INTO "django_geo_db_zipcode" VALUES(18503,42337,-6,'Drakesboro, Kentucky 42337',12846,16152);
INSERT INTO "django_geo_db_zipcode" VALUES(18504,42338,-6,'Dundee, Kentucky 42338',12847,16153);
INSERT INTO "django_geo_db_zipcode" VALUES(18505,42339,-6,'Dunmor, Kentucky 42339',12848,16154);
INSERT INTO "django_geo_db_zipcode" VALUES(18506,42343,-6,'Fordsville, Kentucky 42343',12849,16155);
INSERT INTO "django_geo_db_zipcode" VALUES(18507,42344,-6,'Graham, Kentucky 42344',12850,16156);
INSERT INTO "django_geo_db_zipcode" VALUES(18508,42345,-6,'Greenville, Kentucky 42345',12851,16157);
INSERT INTO "django_geo_db_zipcode" VALUES(18509,42347,-6,'Hartford, Kentucky 42347',12852,16158);
INSERT INTO "django_geo_db_zipcode" VALUES(18510,42348,-6,'Hawesville, Kentucky 42348',12853,16159);
INSERT INTO "django_geo_db_zipcode" VALUES(18511,42349,-6,'Horse Branch, Kentucky 42349',12854,16160);
INSERT INTO "django_geo_db_zipcode" VALUES(18512,42350,-6,'Island, Kentucky 42350',12855,16161);
INSERT INTO "django_geo_db_zipcode" VALUES(18513,42351,-6,'Lewisport, Kentucky 42351',12856,16162);
INSERT INTO "django_geo_db_zipcode" VALUES(18514,42352,-6,'Livermore, Kentucky 42352',12857,16163);
INSERT INTO "django_geo_db_zipcode" VALUES(18515,42354,-6,'McHenry, Kentucky 42354',12858,16164);
INSERT INTO "django_geo_db_zipcode" VALUES(18516,42355,-6,'Maceo, Kentucky 42355',12859,16165);
INSERT INTO "django_geo_db_zipcode" VALUES(18517,42356,-6,'Maple Mount, Kentucky 42356',12860,16166);
INSERT INTO "django_geo_db_zipcode" VALUES(18518,42361,-6,'Olaton, Kentucky 42361',12861,16167);
INSERT INTO "django_geo_db_zipcode" VALUES(18519,42364,-6,'Pellville, Kentucky 42364',12862,16168);
INSERT INTO "django_geo_db_zipcode" VALUES(18520,42365,-6,'Penrod, Kentucky 42365',12863,16169);
INSERT INTO "django_geo_db_zipcode" VALUES(18521,42366,-6,'Philpot, Kentucky 42366',12864,16170);
INSERT INTO "django_geo_db_zipcode" VALUES(18522,42367,-6,'Powderly, Kentucky 42367',12865,16171);
INSERT INTO "django_geo_db_zipcode" VALUES(18523,42368,-6,'Reynolds Station, Kentucky 42368',12866,16172);
INSERT INTO "django_geo_db_zipcode" VALUES(18524,42369,-6,'Rockport, Kentucky 42369',12867,16173);
INSERT INTO "django_geo_db_zipcode" VALUES(18525,42370,-6,'Rosine, Kentucky 42370',12868,16174);
INSERT INTO "django_geo_db_zipcode" VALUES(18526,42371,-6,'Rumsey, Kentucky 42371',12869,16175);
INSERT INTO "django_geo_db_zipcode" VALUES(18527,42372,-6,'Sacramento, Kentucky 42372',12870,16176);
INSERT INTO "django_geo_db_zipcode" VALUES(18528,42374,-6,'South Carrollton, Kentucky 42374',12871,16177);
INSERT INTO "django_geo_db_zipcode" VALUES(18529,42375,-6,'Stanley, Kentucky 42375',12872,16138);
INSERT INTO "django_geo_db_zipcode" VALUES(18530,42376,-6,'Utica, Kentucky 42376',12873,16178);
INSERT INTO "django_geo_db_zipcode" VALUES(18531,42377,-6,'West Louisville, Kentucky 42377',12874,16138);
INSERT INTO "django_geo_db_zipcode" VALUES(18532,42378,-6,'Whitesville, Kentucky 42378',12875,16179);
INSERT INTO "django_geo_db_zipcode" VALUES(18533,42400,-6,'Morganfield, Kentucky 42400',12876,16180);
INSERT INTO "django_geo_db_zipcode" VALUES(18534,42402,-6,'Baskett, Kentucky 42402',12877,16181);
INSERT INTO "django_geo_db_zipcode" VALUES(18535,42403,-6,'Blackford, Kentucky 42403',12878,16182);
INSERT INTO "django_geo_db_zipcode" VALUES(18536,42404,-6,'Clay, Kentucky 42404',12879,16183);
INSERT INTO "django_geo_db_zipcode" VALUES(18537,42406,-6,'Corydon, Kentucky 42406',12880,16184);
INSERT INTO "django_geo_db_zipcode" VALUES(18538,42408,-6,'Dawson Springs, Kentucky 42408',12881,16185);
INSERT INTO "django_geo_db_zipcode" VALUES(18539,42409,-6,'Dixon, Kentucky 42409',12882,16186);
INSERT INTO "django_geo_db_zipcode" VALUES(18540,42410,-6,'Earlington, Kentucky 42410',12883,16187);
INSERT INTO "django_geo_db_zipcode" VALUES(18541,42411,-6,'Fredonia, Kentucky 42411',12706,16188);
INSERT INTO "django_geo_db_zipcode" VALUES(18542,42413,-6,'Hanson, Kentucky 42413',12884,16189);
INSERT INTO "django_geo_db_zipcode" VALUES(18543,42419,-6,'Henderson, Kentucky 42419',12885,16190);
INSERT INTO "django_geo_db_zipcode" VALUES(18544,42420,-6,'Henderson, Kentucky 42420',12885,16191);
INSERT INTO "django_geo_db_zipcode" VALUES(18545,42431,-6,'Madisonville, Kentucky 42431',12886,16192);
INSERT INTO "django_geo_db_zipcode" VALUES(18546,42436,-6,'Manitou, Kentucky 42436',12887,16193);
INSERT INTO "django_geo_db_zipcode" VALUES(18547,42437,-6,'Morganfield, Kentucky 42437',12876,16194);
INSERT INTO "django_geo_db_zipcode" VALUES(18548,42440,-6,'Mortons Gap, Kentucky 42440',12888,16195);
INSERT INTO "django_geo_db_zipcode" VALUES(18549,42441,-6,'Nebo, Kentucky 42441',12889,16196);
INSERT INTO "django_geo_db_zipcode" VALUES(18550,42442,-6,'Nortonville, Kentucky 42442',12890,16197);
INSERT INTO "django_geo_db_zipcode" VALUES(18551,42444,-6,'Poole, Kentucky 42444',12891,16198);
INSERT INTO "django_geo_db_zipcode" VALUES(18552,42445,-6,'Princeton, Kentucky 42445',12892,16199);
INSERT INTO "django_geo_db_zipcode" VALUES(18553,42450,-6,'Providence, Kentucky 42450',12893,16200);
INSERT INTO "django_geo_db_zipcode" VALUES(18554,42451,-6,'Reed, Kentucky 42451',12894,16201);
INSERT INTO "django_geo_db_zipcode" VALUES(18555,42452,-6,'Robards, Kentucky 42452',12895,16202);
INSERT INTO "django_geo_db_zipcode" VALUES(18556,42453,-6,'Saint Charles, Kentucky 42453',12896,16203);
INSERT INTO "django_geo_db_zipcode" VALUES(18557,42455,-6,'Sebree, Kentucky 42455',12897,16204);
INSERT INTO "django_geo_db_zipcode" VALUES(18558,42456,-6,'Slaughters, Kentucky 42456',12898,16205);
INSERT INTO "django_geo_db_zipcode" VALUES(18559,42457,-6,'Smith Mills, Kentucky 42457',12899,16206);
INSERT INTO "django_geo_db_zipcode" VALUES(18560,42458,-6,'Spottsville, Kentucky 42458',12900,16207);
INSERT INTO "django_geo_db_zipcode" VALUES(18561,42459,-6,'Sturgis, Kentucky 42459',12901,16208);
INSERT INTO "django_geo_db_zipcode" VALUES(18562,42460,-6,'Sullivan, Kentucky 42460',12902,16209);
INSERT INTO "django_geo_db_zipcode" VALUES(18563,42461,-6,'Uniontown, Kentucky 42461',12903,16210);
INSERT INTO "django_geo_db_zipcode" VALUES(18564,42462,-6,'Waverly, Kentucky 42462',12904,16211);
INSERT INTO "django_geo_db_zipcode" VALUES(18565,42463,-6,'Wheatcroft, Kentucky 42463',12905,16212);
INSERT INTO "django_geo_db_zipcode" VALUES(18566,42464,-6,'White Plains, Kentucky 42464',12906,16213);
INSERT INTO "django_geo_db_zipcode" VALUES(18567,42501,-5,'Somerset, Kentucky 42501',12907,16214);
INSERT INTO "django_geo_db_zipcode" VALUES(18568,42502,-5,'Somerset, Kentucky 42502',12907,16215);
INSERT INTO "django_geo_db_zipcode" VALUES(18569,42503,-5,'Somerset, Kentucky 42503',12907,16216);
INSERT INTO "django_geo_db_zipcode" VALUES(18570,42516,-5,'Bethelridge, Kentucky 42516',12908,16217);
INSERT INTO "django_geo_db_zipcode" VALUES(18571,42518,-5,'Bronston, Kentucky 42518',12909,16218);
INSERT INTO "django_geo_db_zipcode" VALUES(18572,42519,-5,'Burnside, Kentucky 42519',12910,16219);
INSERT INTO "django_geo_db_zipcode" VALUES(18573,42528,-5,'Dunnville, Kentucky 42528',12911,16220);
INSERT INTO "django_geo_db_zipcode" VALUES(18574,42533,-5,'Ferguson, Kentucky 42533',12912,16221);
INSERT INTO "django_geo_db_zipcode" VALUES(18575,42539,-5,'Liberty, Kentucky 42539',12913,16222);
INSERT INTO "django_geo_db_zipcode" VALUES(18576,42541,-5,'Middleburg, Kentucky 42541',12914,16223);
INSERT INTO "django_geo_db_zipcode" VALUES(18577,42544,-5,'Nancy, Kentucky 42544',12915,16224);
INSERT INTO "django_geo_db_zipcode" VALUES(18578,42553,-5,'Science Hill, Kentucky 42553',12811,16225);
INSERT INTO "django_geo_db_zipcode" VALUES(18579,42558,-5,'Tateville, Kentucky 42558',12916,16226);
INSERT INTO "django_geo_db_zipcode" VALUES(18580,42564,-5,'West Somerset, Kentucky 42564',12917,16227);
INSERT INTO "django_geo_db_zipcode" VALUES(18581,42565,-5,'Windsor, Kentucky 42565',12918,16228);
INSERT INTO "django_geo_db_zipcode" VALUES(18582,42566,-5,'Yosemite, Kentucky 42566',12919,16229);
INSERT INTO "django_geo_db_zipcode" VALUES(18583,42567,-5,'Eubank, Kentucky 42567',12920,16230);
INSERT INTO "django_geo_db_zipcode" VALUES(18584,42602,-6,'Albany, Kentucky 42602',12921,16231);
INSERT INTO "django_geo_db_zipcode" VALUES(18585,42603,-6,'Alpha, Kentucky 42603',12922,16232);
INSERT INTO "django_geo_db_zipcode" VALUES(18586,42629,-6,'Jamestown, Kentucky 42629',12923,16233);
INSERT INTO "django_geo_db_zipcode" VALUES(18587,42631,-5,'Marshes Siding, Kentucky 42631',12924,16234);
INSERT INTO "django_geo_db_zipcode" VALUES(18588,42632,-5,'Mill Springs, Kentucky 42632',12925,16235);
INSERT INTO "django_geo_db_zipcode" VALUES(18589,42633,-5,'Monticello, Kentucky 42633',12926,16236);
INSERT INTO "django_geo_db_zipcode" VALUES(18590,42634,-5,'Parkers Lake, Kentucky 42634',12927,16237);
INSERT INTO "django_geo_db_zipcode" VALUES(18591,42635,-5,'Pine Knot, Kentucky 42635',12928,16238);
INSERT INTO "django_geo_db_zipcode" VALUES(18592,42637,-5,'Monticello, Kentucky 42637',12926,16239);
INSERT INTO "django_geo_db_zipcode" VALUES(18593,42638,-5,'Revelo, Kentucky 42638',12929,16240);
INSERT INTO "django_geo_db_zipcode" VALUES(18594,42642,-6,'Russell Springs, Kentucky 42642',12930,16241);
INSERT INTO "django_geo_db_zipcode" VALUES(18595,42647,-5,'Stearns, Kentucky 42647',12931,16242);
INSERT INTO "django_geo_db_zipcode" VALUES(18596,42649,-5,'Strunk, Kentucky 42649',12932,16243);
INSERT INTO "django_geo_db_zipcode" VALUES(18597,42653,-5,'Whitley City, Kentucky 42653',12933,16244);
INSERT INTO "django_geo_db_zipcode" VALUES(18598,42701,-5,'Elizabethtown, Kentucky 42701',12934,16245);
INSERT INTO "django_geo_db_zipcode" VALUES(18599,42702,-5,'Elizabethtown, Kentucky 42702',12934,15448);
INSERT INTO "django_geo_db_zipcode" VALUES(18600,42711,-6,'Bakerton, Kentucky 42711',12935,16246);
INSERT INTO "django_geo_db_zipcode" VALUES(18601,42712,-5,'Big Clifty, Kentucky 42712',12936,16247);
INSERT INTO "django_geo_db_zipcode" VALUES(18602,42713,-6,'Bonnieville, Kentucky 42713',12937,16248);
INSERT INTO "django_geo_db_zipcode" VALUES(18603,42715,-6,'Breeding, Kentucky 42715',12938,16249);
INSERT INTO "django_geo_db_zipcode" VALUES(18604,42716,-5,'Buffalo, Kentucky 42716',12939,16250);
INSERT INTO "django_geo_db_zipcode" VALUES(18605,42717,-6,'Burkesville, Kentucky 42717',12940,16251);
INSERT INTO "django_geo_db_zipcode" VALUES(18606,42718,-5,'Campbellsville, Kentucky 42718',12941,16252);
INSERT INTO "django_geo_db_zipcode" VALUES(18607,42719,-5,'Campbellsville, Kentucky 42719',12941,16253);
INSERT INTO "django_geo_db_zipcode" VALUES(18608,42720,-6,'Cane Valley, Kentucky 42720',12942,16254);
INSERT INTO "django_geo_db_zipcode" VALUES(18609,42721,-6,'Caneyville, Kentucky 42721',12943,16255);
INSERT INTO "django_geo_db_zipcode" VALUES(18610,42722,-6,'Canmer, Kentucky 42722',12944,16256);
INSERT INTO "django_geo_db_zipcode" VALUES(18611,42724,-5,'Cecilia, Kentucky 42724',12945,16257);
INSERT INTO "django_geo_db_zipcode" VALUES(18612,42726,-6,'Clarkson, Kentucky 42726',12946,16258);
INSERT INTO "django_geo_db_zipcode" VALUES(18613,42728,-6,'Columbia, Kentucky 42728',12947,16259);
INSERT INTO "django_geo_db_zipcode" VALUES(18614,42729,-6,'Cub Run, Kentucky 42729',12948,16260);
INSERT INTO "django_geo_db_zipcode" VALUES(18615,42731,-6,'Dubre, Kentucky 42731',12949,16261);
INSERT INTO "django_geo_db_zipcode" VALUES(18616,42732,-5,'Eastview, Kentucky 42732',12950,16262);
INSERT INTO "django_geo_db_zipcode" VALUES(18617,42733,-5,'Elk Horn, Kentucky 42733',12951,16263);
INSERT INTO "django_geo_db_zipcode" VALUES(18618,42735,-6,'Fairplay, Kentucky 42735',12952,16264);
INSERT INTO "django_geo_db_zipcode" VALUES(18619,42740,-5,'Glendale, Kentucky 42740',12953,16265);
INSERT INTO "django_geo_db_zipcode" VALUES(18620,42741,-6,'Glens Fork, Kentucky 42741',12954,16266);
INSERT INTO "django_geo_db_zipcode" VALUES(18621,42742,-6,'Gradyville, Kentucky 42742',12955,16267);
INSERT INTO "django_geo_db_zipcode" VALUES(18622,42743,-6,'Greensburg, Kentucky 42743',12956,16268);
INSERT INTO "django_geo_db_zipcode" VALUES(18623,42746,-6,'Hardyville, Kentucky 42746',12957,16269);
INSERT INTO "django_geo_db_zipcode" VALUES(18624,42748,-5,'Hodgenville, Kentucky 42748',12958,16270);
INSERT INTO "django_geo_db_zipcode" VALUES(18625,42749,-6,'Horse Cave, Kentucky 42749',12959,16271);
INSERT INTO "django_geo_db_zipcode" VALUES(18626,42753,-6,'Knifley, Kentucky 42753',12960,16272);
INSERT INTO "django_geo_db_zipcode" VALUES(18627,42754,-6,'Leitchfield, Kentucky 42754',12961,16273);
INSERT INTO "django_geo_db_zipcode" VALUES(18628,42755,-6,'Leitchfield, Kentucky 42755',12961,16274);
INSERT INTO "django_geo_db_zipcode" VALUES(18629,42757,-6,'Magnolia, Kentucky 42757',12962,16275);
INSERT INTO "django_geo_db_zipcode" VALUES(18630,42758,-5,'Mannsville, Kentucky 42758',12963,16276);
INSERT INTO "django_geo_db_zipcode" VALUES(18631,42759,-6,'Marrowbone, Kentucky 42759',12964,16277);
INSERT INTO "django_geo_db_zipcode" VALUES(18632,42761,-6,'Milltown, Kentucky 42761',12965,16278);
INSERT INTO "django_geo_db_zipcode" VALUES(18633,42762,-6,'Millwood, Kentucky 42762',12966,16279);
INSERT INTO "django_geo_db_zipcode" VALUES(18634,42764,-5,'Mount Sherman, Kentucky 42764',12967,16280);
INSERT INTO "django_geo_db_zipcode" VALUES(18635,42765,-6,'Munfordville, Kentucky 42765',12968,16281);
INSERT INTO "django_geo_db_zipcode" VALUES(18636,42776,-5,'Sonora, Kentucky 42776',12969,16282);
INSERT INTO "django_geo_db_zipcode" VALUES(18637,42782,-6,'Summersville, Kentucky 42782',12970,16283);
INSERT INTO "django_geo_db_zipcode" VALUES(18638,42783,-5,'Summit, Kentucky 42783',12971,16284);
INSERT INTO "django_geo_db_zipcode" VALUES(18639,42784,-5,'Upton, Kentucky 42784',12972,16285);
INSERT INTO "django_geo_db_zipcode" VALUES(18640,42786,-6,'Waterview, Kentucky 42786',12973,16286);
INSERT INTO "django_geo_db_zipcode" VALUES(18641,42788,-5,'White Mills, Kentucky 42788',12974,16287);
INSERT INTO "django_geo_db_zipcode" VALUES(18642,43001,-5,'Alexandria, Ohio 43001',12975,16288);
INSERT INTO "django_geo_db_zipcode" VALUES(18643,43002,-5,'Amlin, Ohio 43002',12976,16289);
INSERT INTO "django_geo_db_zipcode" VALUES(18644,43003,-5,'Ashley, Ohio 43003',12977,16290);
INSERT INTO "django_geo_db_zipcode" VALUES(18645,43004,-5,'Blacklick, Ohio 43004',12978,16291);
INSERT INTO "django_geo_db_zipcode" VALUES(18646,43005,-5,'Bladensburg, Ohio 43005',12979,16292);
INSERT INTO "django_geo_db_zipcode" VALUES(18647,43006,-5,'Brinkhaven, Ohio 43006',12980,16293);
INSERT INTO "django_geo_db_zipcode" VALUES(18648,43007,-5,'Broadway, Ohio 43007',12981,16294);
INSERT INTO "django_geo_db_zipcode" VALUES(18649,43008,-5,'Buckeye Lake, Ohio 43008',12982,16295);
INSERT INTO "django_geo_db_zipcode" VALUES(18650,43009,-5,'Cable, Ohio 43009',12983,16296);
INSERT INTO "django_geo_db_zipcode" VALUES(18651,43010,-5,'Catawba, Ohio 43010',12984,16297);
INSERT INTO "django_geo_db_zipcode" VALUES(18652,43011,-5,'Centerburg, Ohio 43011',12985,16298);
INSERT INTO "django_geo_db_zipcode" VALUES(18653,43013,-5,'Croton, Ohio 43013',12986,16299);
INSERT INTO "django_geo_db_zipcode" VALUES(18654,43014,-5,'Danville, Ohio 43014',12987,16300);
INSERT INTO "django_geo_db_zipcode" VALUES(18655,43015,-5,'Delaware, Ohio 43015',12988,16301);
INSERT INTO "django_geo_db_zipcode" VALUES(18656,43016,-5,'Dublin, Ohio 43016',12989,16302);
INSERT INTO "django_geo_db_zipcode" VALUES(18657,43017,-5,'Dublin, Ohio 43017',12989,16303);
INSERT INTO "django_geo_db_zipcode" VALUES(18658,43018,-5,'Etna, Ohio 43018',12990,16304);
INSERT INTO "django_geo_db_zipcode" VALUES(18659,43019,-5,'Fredericktown, Ohio 43019',12991,16305);
INSERT INTO "django_geo_db_zipcode" VALUES(18660,43021,-5,'Galena, Ohio 43021',12992,16306);
INSERT INTO "django_geo_db_zipcode" VALUES(18661,43022,-5,'Gambier, Ohio 43022',12993,16307);
INSERT INTO "django_geo_db_zipcode" VALUES(18662,43023,-5,'Granville, Ohio 43023',12994,16308);
INSERT INTO "django_geo_db_zipcode" VALUES(18663,43025,-5,'Hebron, Ohio 43025',12995,16309);
INSERT INTO "django_geo_db_zipcode" VALUES(18664,43026,-5,'Hilliard, Ohio 43026',12996,16310);
INSERT INTO "django_geo_db_zipcode" VALUES(18665,43027,-5,'Homer, Ohio 43027',12997,16311);
INSERT INTO "django_geo_db_zipcode" VALUES(18666,43028,-5,'Howard, Ohio 43028',12998,16312);
INSERT INTO "django_geo_db_zipcode" VALUES(18667,43029,-5,'Irwin, Ohio 43029',12999,16313);
INSERT INTO "django_geo_db_zipcode" VALUES(18668,43030,-5,'Jacksontown, Ohio 43030',13000,16314);
INSERT INTO "django_geo_db_zipcode" VALUES(18669,43031,-5,'Johnstown, Ohio 43031',13001,16315);
INSERT INTO "django_geo_db_zipcode" VALUES(18670,43032,-5,'Kilbourne, Ohio 43032',13002,16316);
INSERT INTO "django_geo_db_zipcode" VALUES(18671,43033,-5,'Kirkersville, Ohio 43033',13003,16317);
INSERT INTO "django_geo_db_zipcode" VALUES(18672,43035,-5,'Lewis Center, Ohio 43035',13004,16318);
INSERT INTO "django_geo_db_zipcode" VALUES(18673,43036,-5,'Magnetic Springs, Ohio 43036',13005,16319);
INSERT INTO "django_geo_db_zipcode" VALUES(18674,43037,-5,'Martinsburg, Ohio 43037',13006,16320);
INSERT INTO "django_geo_db_zipcode" VALUES(18675,43040,-5,'Marysville, Ohio 43040',13007,16321);
INSERT INTO "django_geo_db_zipcode" VALUES(18676,43041,-5,'Marysville, Ohio 43041',13007,16322);
INSERT INTO "django_geo_db_zipcode" VALUES(18677,43044,-5,'Mechanicsburg, Ohio 43044',13008,16323);
INSERT INTO "django_geo_db_zipcode" VALUES(18678,43045,-5,'Milford Center, Ohio 43045',13009,16324);
INSERT INTO "django_geo_db_zipcode" VALUES(18679,43046,-5,'Millersport, Ohio 43046',13010,16325);
INSERT INTO "django_geo_db_zipcode" VALUES(18680,43047,-5,'Mingo, Ohio 43047',13011,16326);
INSERT INTO "django_geo_db_zipcode" VALUES(18681,43048,-5,'Mount Liberty, Ohio 43048',13012,16327);
INSERT INTO "django_geo_db_zipcode" VALUES(18682,43050,-5,'Mount Vernon, Ohio 43050',13013,16328);
INSERT INTO "django_geo_db_zipcode" VALUES(18683,43054,-5,'New Albany, Ohio 43054',13014,16329);
INSERT INTO "django_geo_db_zipcode" VALUES(18684,43055,-5,'Newark, Ohio 43055',13015,16330);
INSERT INTO "django_geo_db_zipcode" VALUES(18685,43056,-5,'Heath, Ohio 43056',13016,16331);
INSERT INTO "django_geo_db_zipcode" VALUES(18686,43058,-5,'Newark, Ohio 43058',13015,16332);
INSERT INTO "django_geo_db_zipcode" VALUES(18687,43060,-5,'North Lewisburg, Ohio 43060',13017,16333);
INSERT INTO "django_geo_db_zipcode" VALUES(18688,43061,-5,'Ostrander, Ohio 43061',13018,16334);
INSERT INTO "django_geo_db_zipcode" VALUES(18689,43062,-5,'Pataskala, Ohio 43062',13019,16335);
INSERT INTO "django_geo_db_zipcode" VALUES(18690,43064,-5,'Plain City, Ohio 43064',13020,16336);
INSERT INTO "django_geo_db_zipcode" VALUES(18691,43065,-5,'Powell, Ohio 43065',13021,16337);
INSERT INTO "django_geo_db_zipcode" VALUES(18692,43066,-5,'Radnor, Ohio 43066',13022,16338);
INSERT INTO "django_geo_db_zipcode" VALUES(18693,43067,-5,'Raymond, Ohio 43067',13023,16339);
INSERT INTO "django_geo_db_zipcode" VALUES(18694,43068,-5,'Reynoldsburg, Ohio 43068',13024,16340);
INSERT INTO "django_geo_db_zipcode" VALUES(18695,43070,-5,'Rosewood, Ohio 43070',13025,16341);
INSERT INTO "django_geo_db_zipcode" VALUES(18696,43071,-5,'Saint Louisville, Ohio 43071',13026,16342);
INSERT INTO "django_geo_db_zipcode" VALUES(18697,43072,-5,'Saint Paris, Ohio 43072',13027,16343);
INSERT INTO "django_geo_db_zipcode" VALUES(18698,43073,-5,'Summit Station, Ohio 43073',13028,16344);
INSERT INTO "django_geo_db_zipcode" VALUES(18699,43074,-5,'Sunbury, Ohio 43074',13029,16345);
INSERT INTO "django_geo_db_zipcode" VALUES(18700,43076,-5,'Thornville, Ohio 43076',13030,16346);
INSERT INTO "django_geo_db_zipcode" VALUES(18701,43077,-5,'Unionville Center, Ohio 43077',13031,16347);
INSERT INTO "django_geo_db_zipcode" VALUES(18702,43078,-5,'Urbana, Ohio 43078',13032,16348);
INSERT INTO "django_geo_db_zipcode" VALUES(18703,43080,-5,'Utica, Ohio 43080',13033,16349);
INSERT INTO "django_geo_db_zipcode" VALUES(18704,43081,-5,'Westerville, Ohio 43081',13034,16350);
INSERT INTO "django_geo_db_zipcode" VALUES(18705,43082,-5,'Westerville, Ohio 43082',13034,16351);
INSERT INTO "django_geo_db_zipcode" VALUES(18706,43083,-5,'Westville, Ohio 43083',13035,16352);
INSERT INTO "django_geo_db_zipcode" VALUES(18707,43084,-5,'Woodstock, Ohio 43084',13036,16353);
INSERT INTO "django_geo_db_zipcode" VALUES(18708,43085,-5,'Columbus, Ohio 43085',13037,16354);
INSERT INTO "django_geo_db_zipcode" VALUES(18709,43086,-5,'Westerville, Ohio 43086',13034,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18710,43093,-5,'Newark, Ohio 43093',13015,16332);
INSERT INTO "django_geo_db_zipcode" VALUES(18711,43098,-5,'Hebron, Ohio 43098',12995,16332);
INSERT INTO "django_geo_db_zipcode" VALUES(18712,43101,-5,'Adelphi, Ohio 43101',13038,16356);
INSERT INTO "django_geo_db_zipcode" VALUES(18713,43102,-5,'Amanda, Ohio 43102',13039,16357);
INSERT INTO "django_geo_db_zipcode" VALUES(18714,43103,-5,'Ashville, Ohio 43103',13040,16358);
INSERT INTO "django_geo_db_zipcode" VALUES(18715,43105,-5,'Baltimore, Ohio 43105',13041,16359);
INSERT INTO "django_geo_db_zipcode" VALUES(18716,43106,-5,'Bloomingburg, Ohio 43106',13042,16360);
INSERT INTO "django_geo_db_zipcode" VALUES(18717,43107,-5,'Bremen, Ohio 43107',13043,16361);
INSERT INTO "django_geo_db_zipcode" VALUES(18718,43109,-5,'Brice, Ohio 43109',13044,16362);
INSERT INTO "django_geo_db_zipcode" VALUES(18719,43110,-5,'Canal Winchester, Ohio 43110',13045,16363);
INSERT INTO "django_geo_db_zipcode" VALUES(18720,43111,-5,'Carbon Hill, Ohio 43111',13046,16364);
INSERT INTO "django_geo_db_zipcode" VALUES(18721,43112,-5,'Carroll, Ohio 43112',13047,16365);
INSERT INTO "django_geo_db_zipcode" VALUES(18722,43113,-5,'Circleville, Ohio 43113',13048,16366);
INSERT INTO "django_geo_db_zipcode" VALUES(18723,43115,-5,'Clarksburg, Ohio 43115',13049,16367);
INSERT INTO "django_geo_db_zipcode" VALUES(18724,43116,-5,'Commercial Point, Ohio 43116',13050,16368);
INSERT INTO "django_geo_db_zipcode" VALUES(18725,43117,-5,'Derby, Ohio 43117',13051,16369);
INSERT INTO "django_geo_db_zipcode" VALUES(18726,43119,-5,'Galloway, Ohio 43119',13052,16370);
INSERT INTO "django_geo_db_zipcode" VALUES(18727,43123,-5,'Grove City, Ohio 43123',13053,16371);
INSERT INTO "django_geo_db_zipcode" VALUES(18728,43125,-5,'Groveport, Ohio 43125',13054,16372);
INSERT INTO "django_geo_db_zipcode" VALUES(18729,43126,-5,'Harrisburg, Ohio 43126',13055,16373);
INSERT INTO "django_geo_db_zipcode" VALUES(18730,43127,-5,'Haydenville, Ohio 43127',13056,16374);
INSERT INTO "django_geo_db_zipcode" VALUES(18731,43128,-5,'Jeffersonville, Ohio 43128',13057,16375);
INSERT INTO "django_geo_db_zipcode" VALUES(18732,43130,-5,'Lancaster, Ohio 43130',13058,16376);
INSERT INTO "django_geo_db_zipcode" VALUES(18733,43135,-5,'Laurelville, Ohio 43135',13059,16377);
INSERT INTO "django_geo_db_zipcode" VALUES(18734,43136,-5,'Lithopolis, Ohio 43136',13060,16378);
INSERT INTO "django_geo_db_zipcode" VALUES(18735,43137,-5,'Lockbourne, Ohio 43137',13061,16379);
INSERT INTO "django_geo_db_zipcode" VALUES(18736,43138,-5,'Logan, Ohio 43138',13062,16380);
INSERT INTO "django_geo_db_zipcode" VALUES(18737,43140,-5,'London, Ohio 43140',13063,16381);
INSERT INTO "django_geo_db_zipcode" VALUES(18738,43142,-5,'Milledgeville, Ohio 43142',13064,16382);
INSERT INTO "django_geo_db_zipcode" VALUES(18739,43143,-5,'Mount Sterling, Ohio 43143',13065,16383);
INSERT INTO "django_geo_db_zipcode" VALUES(18740,43144,-5,'Murray City, Ohio 43144',13066,16384);
INSERT INTO "django_geo_db_zipcode" VALUES(18741,43145,-5,'New Holland, Ohio 43145',13067,16385);
INSERT INTO "django_geo_db_zipcode" VALUES(18742,43146,-5,'Orient, Ohio 43146',13068,16386);
INSERT INTO "django_geo_db_zipcode" VALUES(18743,43147,-5,'Pickerington, Ohio 43147',13069,16387);
INSERT INTO "django_geo_db_zipcode" VALUES(18744,43148,-5,'Pleasantville, Ohio 43148',13070,16388);
INSERT INTO "django_geo_db_zipcode" VALUES(18745,43149,-5,'Rockbridge, Ohio 43149',13071,16389);
INSERT INTO "django_geo_db_zipcode" VALUES(18746,43150,-5,'Rushville, Ohio 43150',13072,16390);
INSERT INTO "django_geo_db_zipcode" VALUES(18747,43151,-5,'Sedalia, Ohio 43151',13073,16391);
INSERT INTO "django_geo_db_zipcode" VALUES(18748,43152,-5,'South Bloomingville, Ohio 43152',13074,16392);
INSERT INTO "django_geo_db_zipcode" VALUES(18749,43153,-5,'South Solon, Ohio 43153',13075,16393);
INSERT INTO "django_geo_db_zipcode" VALUES(18750,43154,-5,'Stoutsville, Ohio 43154',13076,16394);
INSERT INTO "django_geo_db_zipcode" VALUES(18751,43155,-5,'Sugar Grove, Ohio 43155',13077,16395);
INSERT INTO "django_geo_db_zipcode" VALUES(18752,43156,-5,'Tarlton, Ohio 43156',13078,16396);
INSERT INTO "django_geo_db_zipcode" VALUES(18753,43157,-5,'Thurston, Ohio 43157',13079,16397);
INSERT INTO "django_geo_db_zipcode" VALUES(18754,43158,-5,'Union Furnace, Ohio 43158',13080,16398);
INSERT INTO "django_geo_db_zipcode" VALUES(18755,43160,-5,'Washington Court House, Ohio 43160',13081,16399);
INSERT INTO "django_geo_db_zipcode" VALUES(18756,43162,-5,'West Jefferson, Ohio 43162',13082,16400);
INSERT INTO "django_geo_db_zipcode" VALUES(18757,43163,-5,'West Rushville, Ohio 43163',13083,16401);
INSERT INTO "django_geo_db_zipcode" VALUES(18758,43164,-5,'Williamsport, Ohio 43164',13084,16402);
INSERT INTO "django_geo_db_zipcode" VALUES(18759,43187,-5,'Pickerington, Ohio 43187',13069,16403);
INSERT INTO "django_geo_db_zipcode" VALUES(18760,43199,-5,'Groveport, Ohio 43199',13054,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18761,43201,-5,'Columbus, Ohio 43201',13037,16404);
INSERT INTO "django_geo_db_zipcode" VALUES(18762,43202,-5,'Columbus, Ohio 43202',13037,16405);
INSERT INTO "django_geo_db_zipcode" VALUES(18763,43203,-5,'Columbus, Ohio 43203',13037,16406);
INSERT INTO "django_geo_db_zipcode" VALUES(18764,43204,-5,'Columbus, Ohio 43204',13037,16407);
INSERT INTO "django_geo_db_zipcode" VALUES(18765,43205,-5,'Columbus, Ohio 43205',13037,16408);
INSERT INTO "django_geo_db_zipcode" VALUES(18766,43206,-5,'Columbus, Ohio 43206',13037,16409);
INSERT INTO "django_geo_db_zipcode" VALUES(18767,43207,-5,'Columbus, Ohio 43207',13037,16410);
INSERT INTO "django_geo_db_zipcode" VALUES(18768,43209,-5,'Columbus, Ohio 43209',13037,16411);
INSERT INTO "django_geo_db_zipcode" VALUES(18769,43210,-5,'Columbus, Ohio 43210',13037,16412);
INSERT INTO "django_geo_db_zipcode" VALUES(18770,43211,-5,'Columbus, Ohio 43211',13037,16413);
INSERT INTO "django_geo_db_zipcode" VALUES(18771,43212,-5,'Columbus, Ohio 43212',13037,16414);
INSERT INTO "django_geo_db_zipcode" VALUES(18772,43213,-5,'Columbus, Ohio 43213',13037,16415);
INSERT INTO "django_geo_db_zipcode" VALUES(18773,43214,-5,'Columbus, Ohio 43214',13037,16416);
INSERT INTO "django_geo_db_zipcode" VALUES(18774,43215,-5,'Columbus, Ohio 43215',13037,16417);
INSERT INTO "django_geo_db_zipcode" VALUES(18775,43216,-5,'Columbus, Ohio 43216',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18776,43217,-5,'Columbus, Ohio 43217',13037,16418);
INSERT INTO "django_geo_db_zipcode" VALUES(18777,43218,-5,'Columbus, Ohio 43218',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18778,43219,-5,'Columbus, Ohio 43219',13037,16419);
INSERT INTO "django_geo_db_zipcode" VALUES(18779,43220,-5,'Columbus, Ohio 43220',13037,16420);
INSERT INTO "django_geo_db_zipcode" VALUES(18780,43221,-5,'Columbus, Ohio 43221',13037,16421);
INSERT INTO "django_geo_db_zipcode" VALUES(18781,43222,-5,'Columbus, Ohio 43222',13037,16422);
INSERT INTO "django_geo_db_zipcode" VALUES(18782,43223,-5,'Columbus, Ohio 43223',13037,16423);
INSERT INTO "django_geo_db_zipcode" VALUES(18783,43224,-5,'Columbus, Ohio 43224',13037,16424);
INSERT INTO "django_geo_db_zipcode" VALUES(18784,43226,-5,'Columbus, Ohio 43226',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18785,43227,-5,'Columbus, Ohio 43227',13037,16425);
INSERT INTO "django_geo_db_zipcode" VALUES(18786,43228,-5,'Columbus, Ohio 43228',13037,16426);
INSERT INTO "django_geo_db_zipcode" VALUES(18787,43229,-5,'Columbus, Ohio 43229',13037,16427);
INSERT INTO "django_geo_db_zipcode" VALUES(18788,43230,-5,'Columbus, Ohio 43230',13037,16428);
INSERT INTO "django_geo_db_zipcode" VALUES(18789,43231,-5,'Columbus, Ohio 43231',13037,16429);
INSERT INTO "django_geo_db_zipcode" VALUES(18790,43232,-5,'Columbus, Ohio 43232',13037,16430);
INSERT INTO "django_geo_db_zipcode" VALUES(18791,43234,-5,'Columbus, Ohio 43234',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18792,43235,-5,'Columbus, Ohio 43235',13037,16431);
INSERT INTO "django_geo_db_zipcode" VALUES(18793,43236,-5,'Columbus, Ohio 43236',13037,16432);
INSERT INTO "django_geo_db_zipcode" VALUES(18794,43240,-5,'Columbus, Ohio 43240',13037,16433);
INSERT INTO "django_geo_db_zipcode" VALUES(18795,43251,-5,'Columbus, Ohio 43251',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18796,43260,-5,'Columbus, Ohio 43260',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18797,43265,-5,'Columbus, Ohio 43265',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18798,43266,-5,'Columbus, Ohio 43266',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18799,43268,-5,'Columbus, Ohio 43268',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18800,43270,-5,'Columbus, Ohio 43270',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18801,43271,-5,'Columbus, Ohio 43271',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18802,43272,-5,'Columbus, Ohio 43272',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18803,43279,-5,'Columbus, Ohio 43279',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18804,43284,-5,'Columbus, Ohio 43284',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18805,43287,-5,'Columbus, Ohio 43287',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18806,43291,-5,'Columbus, Ohio 43291',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18807,43299,-5,'Columbus, Ohio 43299',13037,16355);
INSERT INTO "django_geo_db_zipcode" VALUES(18808,43301,-5,'Marion, Ohio 43301',13085,16434);
INSERT INTO "django_geo_db_zipcode" VALUES(18809,43302,-5,'Marion, Ohio 43302',13085,16435);
INSERT INTO "django_geo_db_zipcode" VALUES(18810,43306,-5,'Marion, Ohio 43306',13085,16436);
INSERT INTO "django_geo_db_zipcode" VALUES(18811,43307,-5,'Marion, Ohio 43307',13085,16436);
INSERT INTO "django_geo_db_zipcode" VALUES(18812,43310,-5,'Belle Center, Ohio 43310',13086,16437);
INSERT INTO "django_geo_db_zipcode" VALUES(18813,43311,-5,'Bellefontaine, Ohio 43311',13087,16438);
INSERT INTO "django_geo_db_zipcode" VALUES(18814,43314,-5,'Caledonia, Ohio 43314',13088,16439);
INSERT INTO "django_geo_db_zipcode" VALUES(18815,43315,-5,'Cardington, Ohio 43315',13089,16440);
INSERT INTO "django_geo_db_zipcode" VALUES(18816,43316,-5,'Carey, Ohio 43316',13090,16441);
INSERT INTO "django_geo_db_zipcode" VALUES(18817,43317,-5,'Chesterville, Ohio 43317',13091,16442);
INSERT INTO "django_geo_db_zipcode" VALUES(18818,43318,-5,'De Graff, Ohio 43318',13092,16443);
INSERT INTO "django_geo_db_zipcode" VALUES(18819,43319,-5,'East Liberty, Ohio 43319',13093,16444);
INSERT INTO "django_geo_db_zipcode" VALUES(18820,43320,-5,'Edison, Ohio 43320',13094,16445);
INSERT INTO "django_geo_db_zipcode" VALUES(18821,43321,-5,'Fulton, Ohio 43321',13095,16446);
INSERT INTO "django_geo_db_zipcode" VALUES(18822,43322,-5,'Green Camp, Ohio 43322',13096,16447);
INSERT INTO "django_geo_db_zipcode" VALUES(18823,43323,-5,'Harpster, Ohio 43323',13097,16448);
INSERT INTO "django_geo_db_zipcode" VALUES(18824,43324,-5,'Huntsville, Ohio 43324',13098,16449);
INSERT INTO "django_geo_db_zipcode" VALUES(18825,43325,-5,'Iberia, Ohio 43325',13099,16450);
INSERT INTO "django_geo_db_zipcode" VALUES(18826,43326,-5,'Kenton, Ohio 43326',13100,16451);
INSERT INTO "django_geo_db_zipcode" VALUES(18827,43330,-5,'Kirby, Ohio 43330',13101,16452);
INSERT INTO "django_geo_db_zipcode" VALUES(18828,43331,-5,'Lakeview, Ohio 43331',13102,16453);
INSERT INTO "django_geo_db_zipcode" VALUES(18829,43332,-5,'La Rue, Ohio 43332',13103,16454);
INSERT INTO "django_geo_db_zipcode" VALUES(18830,43333,-5,'Lewistown, Ohio 43333',13104,16455);
INSERT INTO "django_geo_db_zipcode" VALUES(18831,43334,-5,'Marengo, Ohio 43334',13105,16456);
INSERT INTO "django_geo_db_zipcode" VALUES(18832,43335,-5,'Martel, Ohio 43335',13106,16457);
INSERT INTO "django_geo_db_zipcode" VALUES(18833,43336,-5,'Middleburg, Ohio 43336',13107,16458);
INSERT INTO "django_geo_db_zipcode" VALUES(18834,43337,-5,'Morral, Ohio 43337',13108,16459);
INSERT INTO "django_geo_db_zipcode" VALUES(18835,43338,-5,'Mount Gilead, Ohio 43338',13109,16460);
INSERT INTO "django_geo_db_zipcode" VALUES(18836,43340,-5,'Mount Victory, Ohio 43340',13110,16461);
INSERT INTO "django_geo_db_zipcode" VALUES(18837,43341,-5,'New Bloomington, Ohio 43341',13111,16462);
INSERT INTO "django_geo_db_zipcode" VALUES(18838,43342,-5,'Prospect, Ohio 43342',13112,16463);
INSERT INTO "django_geo_db_zipcode" VALUES(18839,43343,-5,'Quincy, Ohio 43343',13113,16464);
INSERT INTO "django_geo_db_zipcode" VALUES(18840,43344,-5,'Richwood, Ohio 43344',13114,16465);
INSERT INTO "django_geo_db_zipcode" VALUES(18841,43345,-5,'Ridgeway, Ohio 43345',13115,16466);
INSERT INTO "django_geo_db_zipcode" VALUES(18842,43346,-5,'Roundhead, Ohio 43346',13116,16467);
INSERT INTO "django_geo_db_zipcode" VALUES(18843,43347,-5,'Rushsylvania, Ohio 43347',13117,16468);
INSERT INTO "django_geo_db_zipcode" VALUES(18844,43348,-5,'Russells Point, Ohio 43348',13118,16469);
INSERT INTO "django_geo_db_zipcode" VALUES(18845,43349,-5,'Shauck, Ohio 43349',13119,16470);
INSERT INTO "django_geo_db_zipcode" VALUES(18846,43350,-5,'Sparta, Ohio 43350',13120,16471);
INSERT INTO "django_geo_db_zipcode" VALUES(18847,43351,-5,'Upper Sandusky, Ohio 43351',13121,16472);
INSERT INTO "django_geo_db_zipcode" VALUES(18848,43355,-5,'Ridgeville, Ohio 43355',13122,16473);
INSERT INTO "django_geo_db_zipcode" VALUES(18849,43356,-5,'Waldo, Ohio 43356',13123,16474);
INSERT INTO "django_geo_db_zipcode" VALUES(18850,43357,-5,'West Liberty, Ohio 43357',13124,16475);
INSERT INTO "django_geo_db_zipcode" VALUES(18851,43358,-5,'West Mansfield, Ohio 43358',13125,16476);
INSERT INTO "django_geo_db_zipcode" VALUES(18852,43359,-5,'Wharton, Ohio 43359',13126,16477);
INSERT INTO "django_geo_db_zipcode" VALUES(18853,43360,-5,'Zanesfield, Ohio 43360',13127,16478);
INSERT INTO "django_geo_db_zipcode" VALUES(18854,43381,-5,'Stokes, Ohio 43381',13128,16479);
INSERT INTO "django_geo_db_zipcode" VALUES(18855,43400,-5,'Danbury, Ohio 43400',13129,16480);
INSERT INTO "django_geo_db_zipcode" VALUES(18856,43402,-5,'Bowling Green, Ohio 43402',13130,16481);
INSERT INTO "django_geo_db_zipcode" VALUES(18857,43403,-5,'Bowling Green, Ohio 43403',13130,16482);
INSERT INTO "django_geo_db_zipcode" VALUES(18858,43406,-5,'Bradner, Ohio 43406',13131,16483);
INSERT INTO "django_geo_db_zipcode" VALUES(18859,43407,-5,'Burgoon, Ohio 43407',13132,16484);
INSERT INTO "django_geo_db_zipcode" VALUES(18860,43408,-5,'Clay Center, Ohio 43408',13133,16485);
INSERT INTO "django_geo_db_zipcode" VALUES(18861,43410,-5,'Clyde, Ohio 43410',13134,16486);
INSERT INTO "django_geo_db_zipcode" VALUES(18862,43412,-5,'Curtice, Ohio 43412',13135,16487);
INSERT INTO "django_geo_db_zipcode" VALUES(18863,43413,-5,'Cygnet, Ohio 43413',13136,16488);
INSERT INTO "django_geo_db_zipcode" VALUES(18864,43414,-5,'Dunbridge, Ohio 43414',13137,16482);
INSERT INTO "django_geo_db_zipcode" VALUES(18865,43416,-5,'Elmore, Ohio 43416',13138,16489);
INSERT INTO "django_geo_db_zipcode" VALUES(18866,43420,-5,'Fremont, Ohio 43420',13139,16490);
INSERT INTO "django_geo_db_zipcode" VALUES(18867,43430,-5,'Genoa, Ohio 43430',13140,16491);
INSERT INTO "django_geo_db_zipcode" VALUES(18868,43431,-5,'Gibsonburg, Ohio 43431',13141,16492);
INSERT INTO "django_geo_db_zipcode" VALUES(18869,43432,-5,'Graytown, Ohio 43432',13142,16493);
INSERT INTO "django_geo_db_zipcode" VALUES(18870,43433,-5,'Gypsum, Ohio 43433',13143,16494);
INSERT INTO "django_geo_db_zipcode" VALUES(18871,43434,-5,'Harbor View, Ohio 43434',13144,16495);
INSERT INTO "django_geo_db_zipcode" VALUES(18872,43435,-5,'Helena, Ohio 43435',13145,16496);
INSERT INTO "django_geo_db_zipcode" VALUES(18873,43436,-5,'Isle Saint George, Ohio 43436',13146,16497);
INSERT INTO "django_geo_db_zipcode" VALUES(18874,43437,-5,'Jerry City, Ohio 43437',13147,16498);
INSERT INTO "django_geo_db_zipcode" VALUES(18875,43438,-5,'Kelleys Island, Ohio 43438',13148,16499);
INSERT INTO "django_geo_db_zipcode" VALUES(18876,43439,-5,'Lacarne, Ohio 43439',13149,16500);
INSERT INTO "django_geo_db_zipcode" VALUES(18877,43440,-5,'Lakeside Marblehead, Ohio 43440',13150,16501);
INSERT INTO "django_geo_db_zipcode" VALUES(18878,43441,-5,'Lemoyne, Ohio 43441',13151,16502);
INSERT INTO "django_geo_db_zipcode" VALUES(18879,43442,-5,'Lindsey, Ohio 43442',13152,16503);
INSERT INTO "django_geo_db_zipcode" VALUES(18880,43443,-5,'Luckey, Ohio 43443',13153,16504);
INSERT INTO "django_geo_db_zipcode" VALUES(18881,43445,-5,'Martin, Ohio 43445',13154,16505);
INSERT INTO "django_geo_db_zipcode" VALUES(18882,43446,-5,'Middle Bass, Ohio 43446',13155,16506);
INSERT INTO "django_geo_db_zipcode" VALUES(18883,43447,-5,'Millbury, Ohio 43447',13156,16507);
INSERT INTO "django_geo_db_zipcode" VALUES(18884,43449,-5,'Oak Harbor, Ohio 43449',13157,16508);
INSERT INTO "django_geo_db_zipcode" VALUES(18885,43450,-5,'Pemberville, Ohio 43450',13158,16509);
INSERT INTO "django_geo_db_zipcode" VALUES(18886,43451,-5,'Portage, Ohio 43451',13159,16510);
INSERT INTO "django_geo_db_zipcode" VALUES(18887,43452,-5,'Port Clinton, Ohio 43452',13160,16511);
INSERT INTO "django_geo_db_zipcode" VALUES(18888,43456,-5,'Put In Bay, Ohio 43456',13161,16512);
INSERT INTO "django_geo_db_zipcode" VALUES(18889,43457,-5,'Risingsun, Ohio 43457',13162,16513);
INSERT INTO "django_geo_db_zipcode" VALUES(18890,43458,-5,'Rocky Ridge, Ohio 43458',13163,16514);
INSERT INTO "django_geo_db_zipcode" VALUES(18891,43460,-5,'Rossford, Ohio 43460',13164,16515);
INSERT INTO "django_geo_db_zipcode" VALUES(18892,43462,-5,'Rudolph, Ohio 43462',13165,16516);
INSERT INTO "django_geo_db_zipcode" VALUES(18893,43463,-5,'Stony Ridge, Ohio 43463',13166,16517);
INSERT INTO "django_geo_db_zipcode" VALUES(18894,43464,-5,'Vickery, Ohio 43464',13167,16518);
INSERT INTO "django_geo_db_zipcode" VALUES(18895,43465,-5,'Walbridge, Ohio 43465',13168,16519);
INSERT INTO "django_geo_db_zipcode" VALUES(18896,43466,-5,'Wayne, Ohio 43466',13169,16520);
INSERT INTO "django_geo_db_zipcode" VALUES(18897,43467,-5,'West Millgrove, Ohio 43467',13170,16521);
INSERT INTO "django_geo_db_zipcode" VALUES(18898,43468,-5,'Williston, Ohio 43468',13171,16522);
INSERT INTO "django_geo_db_zipcode" VALUES(18899,43469,-5,'Woodville, Ohio 43469',13172,16523);
INSERT INTO "django_geo_db_zipcode" VALUES(18900,43501,-5,'Alvordton, Ohio 43501',13173,16524);
INSERT INTO "django_geo_db_zipcode" VALUES(18901,43502,-5,'Archbold, Ohio 43502',13174,16525);
INSERT INTO "django_geo_db_zipcode" VALUES(18902,43504,-5,'Berkey, Ohio 43504',13175,16526);
INSERT INTO "django_geo_db_zipcode" VALUES(18903,43505,-5,'Blakeslee, Ohio 43505',13176,16527);
INSERT INTO "django_geo_db_zipcode" VALUES(18904,43506,-5,'Bryan, Ohio 43506',13177,16528);
INSERT INTO "django_geo_db_zipcode" VALUES(18905,43510,-5,'Colton, Ohio 43510',13178,16529);
INSERT INTO "django_geo_db_zipcode" VALUES(18906,43511,-5,'Custar, Ohio 43511',13179,16530);
INSERT INTO "django_geo_db_zipcode" VALUES(18907,43512,-5,'Defiance, Ohio 43512',13180,16531);
INSERT INTO "django_geo_db_zipcode" VALUES(18908,43515,-5,'Delta, Ohio 43515',13181,16532);
INSERT INTO "django_geo_db_zipcode" VALUES(18909,43516,-5,'Deshler, Ohio 43516',13182,16533);
INSERT INTO "django_geo_db_zipcode" VALUES(18910,43517,-5,'Edgerton, Ohio 43517',13183,16534);
INSERT INTO "django_geo_db_zipcode" VALUES(18911,43518,-5,'Edon, Ohio 43518',13184,16535);
INSERT INTO "django_geo_db_zipcode" VALUES(18912,43519,-5,'Evansport, Ohio 43519',13185,16536);
INSERT INTO "django_geo_db_zipcode" VALUES(18913,43520,-5,'Farmer, Ohio 43520',13186,16537);
INSERT INTO "django_geo_db_zipcode" VALUES(18914,43521,-5,'Fayette, Ohio 43521',13187,16538);
INSERT INTO "django_geo_db_zipcode" VALUES(18915,43522,-5,'Grand Rapids, Ohio 43522',13188,16539);
INSERT INTO "django_geo_db_zipcode" VALUES(18916,43523,-5,'Grelton, Ohio 43523',13189,16540);
INSERT INTO "django_geo_db_zipcode" VALUES(18917,43524,-5,'Hamler, Ohio 43524',13190,16541);
INSERT INTO "django_geo_db_zipcode" VALUES(18918,43525,-5,'Haskins, Ohio 43525',13191,16542);
INSERT INTO "django_geo_db_zipcode" VALUES(18919,43526,-5,'Hicksville, Ohio 43526',13192,16543);
INSERT INTO "django_geo_db_zipcode" VALUES(18920,43527,-5,'Holgate, Ohio 43527',13193,16544);
INSERT INTO "django_geo_db_zipcode" VALUES(18921,43528,-5,'Holland, Ohio 43528',13194,16545);
INSERT INTO "django_geo_db_zipcode" VALUES(18922,43529,-5,'Hoytville, Ohio 43529',13195,16546);
INSERT INTO "django_geo_db_zipcode" VALUES(18923,43530,-5,'Jewell, Ohio 43530',13196,16547);
INSERT INTO "django_geo_db_zipcode" VALUES(18924,43531,-5,'Kunkle, Ohio 43531',13197,16548);
INSERT INTO "django_geo_db_zipcode" VALUES(18925,43532,-5,'Liberty Center, Ohio 43532',13198,16549);
INSERT INTO "django_geo_db_zipcode" VALUES(18926,43533,-5,'Lyons, Ohio 43533',13199,16550);
INSERT INTO "django_geo_db_zipcode" VALUES(18927,43534,-5,'McClure, Ohio 43534',13200,16551);
INSERT INTO "django_geo_db_zipcode" VALUES(18928,43535,-5,'Malinta, Ohio 43535',13201,16552);
INSERT INTO "django_geo_db_zipcode" VALUES(18929,43536,-5,'Mark Center, Ohio 43536',13202,16553);
INSERT INTO "django_geo_db_zipcode" VALUES(18930,43537,-5,'Maumee, Ohio 43537',13203,16554);
INSERT INTO "django_geo_db_zipcode" VALUES(18931,43538,-5,'Monclova, Ohio 43538',13204,16555);
INSERT INTO "django_geo_db_zipcode" VALUES(18932,43540,-5,'Metamora, Ohio 43540',13205,16556);
INSERT INTO "django_geo_db_zipcode" VALUES(18933,43541,-5,'Milton Center, Ohio 43541',13206,16557);
INSERT INTO "django_geo_db_zipcode" VALUES(18934,43542,-5,'Monclova, Ohio 43542',13204,16558);
INSERT INTO "django_geo_db_zipcode" VALUES(18935,43543,-5,'Montpelier, Ohio 43543',13207,16559);
INSERT INTO "django_geo_db_zipcode" VALUES(18936,43545,-5,'Napoleon, Ohio 43545',13208,16560);
INSERT INTO "django_geo_db_zipcode" VALUES(18937,43547,-5,'Neapolis, Ohio 43547',13209,16561);
INSERT INTO "django_geo_db_zipcode" VALUES(18938,43548,-5,'New Bavaria, Ohio 43548',13210,16562);
INSERT INTO "django_geo_db_zipcode" VALUES(18939,43549,-5,'Ney, Ohio 43549',13211,16563);
INSERT INTO "django_geo_db_zipcode" VALUES(18940,43550,-5,'Okolona, Ohio 43550',13212,16564);
INSERT INTO "django_geo_db_zipcode" VALUES(18941,43551,-5,'Perrysburg, Ohio 43551',13213,16565);
INSERT INTO "django_geo_db_zipcode" VALUES(18942,43552,-5,'Perrysburg, Ohio 43552',13213,16482);
INSERT INTO "django_geo_db_zipcode" VALUES(18943,43553,-5,'Pettisville, Ohio 43553',13214,16566);
INSERT INTO "django_geo_db_zipcode" VALUES(18944,43554,-5,'Pioneer, Ohio 43554',13215,16567);
INSERT INTO "django_geo_db_zipcode" VALUES(18945,43555,-5,'Ridgeville Corners, Ohio 43555',13216,16568);
INSERT INTO "django_geo_db_zipcode" VALUES(18946,43556,-5,'Sherwood, Ohio 43556',13217,16569);
INSERT INTO "django_geo_db_zipcode" VALUES(18947,43557,-5,'Stryker, Ohio 43557',13218,16570);
INSERT INTO "django_geo_db_zipcode" VALUES(18948,43558,-5,'Swanton, Ohio 43558',13219,16571);
INSERT INTO "django_geo_db_zipcode" VALUES(18949,43560,-5,'Sylvania, Ohio 43560',13220,16572);
INSERT INTO "django_geo_db_zipcode" VALUES(18950,43565,-5,'Tontogany, Ohio 43565',13221,16573);
INSERT INTO "django_geo_db_zipcode" VALUES(18951,43566,-5,'Waterville, Ohio 43566',13222,16574);
INSERT INTO "django_geo_db_zipcode" VALUES(18952,43567,-5,'Wauseon, Ohio 43567',13223,16575);
INSERT INTO "django_geo_db_zipcode" VALUES(18953,43569,-5,'Weston, Ohio 43569',13224,16576);
INSERT INTO "django_geo_db_zipcode" VALUES(18954,43570,-5,'West Unity, Ohio 43570',13225,16577);
INSERT INTO "django_geo_db_zipcode" VALUES(18955,43571,-5,'Whitehouse, Ohio 43571',13226,16578);
INSERT INTO "django_geo_db_zipcode" VALUES(18956,43579,-5,'Tiffin, Ohio 43579',13227,16579);
INSERT INTO "django_geo_db_zipcode" VALUES(18957,43601,-5,'Toledo, Ohio 43601',13228,16580);
INSERT INTO "django_geo_db_zipcode" VALUES(18958,43602,-5,'Toledo, Ohio 43602',13228,16581);
INSERT INTO "django_geo_db_zipcode" VALUES(18959,43603,-5,'Toledo, Ohio 43603',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18960,43604,-5,'Toledo, Ohio 43604',13228,16583);
INSERT INTO "django_geo_db_zipcode" VALUES(18961,43605,-5,'Toledo, Ohio 43605',13228,16584);
INSERT INTO "django_geo_db_zipcode" VALUES(18962,43606,-5,'Toledo, Ohio 43606',13228,16585);
INSERT INTO "django_geo_db_zipcode" VALUES(18963,43607,-5,'Toledo, Ohio 43607',13228,16586);
INSERT INTO "django_geo_db_zipcode" VALUES(18964,43608,-5,'Toledo, Ohio 43608',13228,16587);
INSERT INTO "django_geo_db_zipcode" VALUES(18965,43609,-5,'Toledo, Ohio 43609',13228,16588);
INSERT INTO "django_geo_db_zipcode" VALUES(18966,43610,-5,'Toledo, Ohio 43610',13228,16589);
INSERT INTO "django_geo_db_zipcode" VALUES(18967,43611,-5,'Toledo, Ohio 43611',13228,16590);
INSERT INTO "django_geo_db_zipcode" VALUES(18968,43612,-5,'Toledo, Ohio 43612',13228,16591);
INSERT INTO "django_geo_db_zipcode" VALUES(18969,43613,-5,'Toledo, Ohio 43613',13228,16592);
INSERT INTO "django_geo_db_zipcode" VALUES(18970,43614,-5,'Toledo, Ohio 43614',13228,16593);
INSERT INTO "django_geo_db_zipcode" VALUES(18971,43615,-5,'Toledo, Ohio 43615',13228,16594);
INSERT INTO "django_geo_db_zipcode" VALUES(18972,43616,-5,'Oregon, Ohio 43616',13229,16595);
INSERT INTO "django_geo_db_zipcode" VALUES(18973,43617,-5,'Toledo, Ohio 43617',13228,16596);
INSERT INTO "django_geo_db_zipcode" VALUES(18974,43618,-5,'Oregon, Ohio 43618',13229,16597);
INSERT INTO "django_geo_db_zipcode" VALUES(18975,43619,-5,'Northwood, Ohio 43619',13230,16598);
INSERT INTO "django_geo_db_zipcode" VALUES(18976,43620,-5,'Toledo, Ohio 43620',13228,16599);
INSERT INTO "django_geo_db_zipcode" VALUES(18977,43623,-5,'Toledo, Ohio 43623',13228,16600);
INSERT INTO "django_geo_db_zipcode" VALUES(18978,43624,-5,'Toledo, Ohio 43624',13228,16601);
INSERT INTO "django_geo_db_zipcode" VALUES(18979,43628,-5,'Howard, Ohio 43628',12998,16602);
INSERT INTO "django_geo_db_zipcode" VALUES(18980,43635,-5,'Toledo, Ohio 43635',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18981,43652,-5,'Toledo, Ohio 43652',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18982,43653,-5,'Toledo, Ohio 43653',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18983,43654,-5,'Toledo, Ohio 43654',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18984,43655,-5,'Toledo, Ohio 43655',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18985,43656,-5,'Toledo, Ohio 43656',13228,16603);
INSERT INTO "django_geo_db_zipcode" VALUES(18986,43657,-5,'Toledo, Ohio 43657',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18987,43659,-5,'Toledo, Ohio 43659',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18988,43660,-5,'Toledo, Ohio 43660',13228,16604);
INSERT INTO "django_geo_db_zipcode" VALUES(18989,43661,-5,'Toledo, Ohio 43661',13228,16603);
INSERT INTO "django_geo_db_zipcode" VALUES(18990,43666,-5,'Toledo, Ohio 43666',13228,16603);
INSERT INTO "django_geo_db_zipcode" VALUES(18991,43667,-5,'Toledo, Ohio 43667',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18992,43681,-5,'Toledo, Ohio 43681',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18993,43682,-5,'Toledo, Ohio 43682',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18994,43697,-5,'Toledo, Ohio 43697',13228,16582);
INSERT INTO "django_geo_db_zipcode" VALUES(18995,43699,-5,'Toledo, Ohio 43699',13228,16605);
INSERT INTO "django_geo_db_zipcode" VALUES(18996,43701,-5,'Zanesville, Ohio 43701',13231,16606);
INSERT INTO "django_geo_db_zipcode" VALUES(18997,43702,-5,'Zanesville, Ohio 43702',13231,16607);
INSERT INTO "django_geo_db_zipcode" VALUES(18998,43704,-5,'Columbus, Ohio 43704',13037,16608);
INSERT INTO "django_geo_db_zipcode" VALUES(18999,43708,-5,'Wayne, Ohio 43708',13169,16609);
INSERT INTO "django_geo_db_zipcode" VALUES(19000,43711,-5,'Ava, Ohio 43711',13232,16610);
INSERT INTO "django_geo_db_zipcode" VALUES(19001,43713,-5,'Barnesville, Ohio 43713',13233,16611);
INSERT INTO "django_geo_db_zipcode" VALUES(19002,43716,-5,'Beallsville, Ohio 43716',13234,16612);
INSERT INTO "django_geo_db_zipcode" VALUES(19003,43717,-5,'Belle Valley, Ohio 43717',13235,16613);
INSERT INTO "django_geo_db_zipcode" VALUES(19004,43718,-5,'Belmont, Ohio 43718',13236,16614);
INSERT INTO "django_geo_db_zipcode" VALUES(19005,43719,-5,'Bethesda, Ohio 43719',13237,16615);
INSERT INTO "django_geo_db_zipcode" VALUES(19006,43720,-5,'Blue Rock, Ohio 43720',13238,16616);
INSERT INTO "django_geo_db_zipcode" VALUES(19007,43721,-5,'Brownsville, Ohio 43721',13239,16617);
INSERT INTO "django_geo_db_zipcode" VALUES(19008,43722,-5,'Buffalo, Ohio 43722',13240,16618);
INSERT INTO "django_geo_db_zipcode" VALUES(19009,43723,-5,'Byesville, Ohio 43723',13241,16619);
INSERT INTO "django_geo_db_zipcode" VALUES(19010,43724,-5,'Caldwell, Ohio 43724',13242,16620);
INSERT INTO "django_geo_db_zipcode" VALUES(19011,43725,-5,'Cambridge, Ohio 43725',13243,16621);
INSERT INTO "django_geo_db_zipcode" VALUES(19012,43727,-5,'Chandlersville, Ohio 43727',13244,16622);
INSERT INTO "django_geo_db_zipcode" VALUES(19013,43728,-5,'Chesterhill, Ohio 43728',13245,16623);
INSERT INTO "django_geo_db_zipcode" VALUES(19014,43730,-5,'Corning, Ohio 43730',13246,16624);
INSERT INTO "django_geo_db_zipcode" VALUES(19015,43731,-5,'Crooksville, Ohio 43731',13247,16625);
INSERT INTO "django_geo_db_zipcode" VALUES(19016,43732,-5,'Cumberland, Ohio 43732',13248,16626);
INSERT INTO "django_geo_db_zipcode" VALUES(19017,43733,-5,'Derwent, Ohio 43733',13249,16627);
INSERT INTO "django_geo_db_zipcode" VALUES(19018,43734,-5,'Duncan Falls, Ohio 43734',13250,16628);
INSERT INTO "django_geo_db_zipcode" VALUES(19019,43735,-5,'East Fultonham, Ohio 43735',13251,16629);
INSERT INTO "django_geo_db_zipcode" VALUES(19020,43736,-5,'Fairview, Ohio 43736',13252,16630);
INSERT INTO "django_geo_db_zipcode" VALUES(19021,43738,-5,'Fultonham, Ohio 43738',13253,16631);
INSERT INTO "django_geo_db_zipcode" VALUES(19022,43739,-5,'Glenford, Ohio 43739',13254,16632);
INSERT INTO "django_geo_db_zipcode" VALUES(19023,43740,-5,'Gratiot, Ohio 43740',13255,16633);
INSERT INTO "django_geo_db_zipcode" VALUES(19024,43741,-5,'Wayne, Ohio 43741',13169,16634);
INSERT INTO "django_geo_db_zipcode" VALUES(19025,43746,-5,'Hopewell, Ohio 43746',13256,16635);
INSERT INTO "django_geo_db_zipcode" VALUES(19026,43747,-5,'Jerusalem, Ohio 43747',13257,16636);
INSERT INTO "django_geo_db_zipcode" VALUES(19027,43748,-5,'Junction City, Ohio 43748',13258,16637);
INSERT INTO "django_geo_db_zipcode" VALUES(19028,43749,-5,'Kimbolton, Ohio 43749',13259,16638);
INSERT INTO "django_geo_db_zipcode" VALUES(19029,43750,-5,'Kipling, Ohio 43750',13260,16639);
INSERT INTO "django_geo_db_zipcode" VALUES(19030,43752,-5,'Laings, Ohio 43752',13261,16640);
INSERT INTO "django_geo_db_zipcode" VALUES(19031,43754,-5,'Lewisville, Ohio 43754',13262,16641);
INSERT INTO "django_geo_db_zipcode" VALUES(19032,43755,-5,'Lore City, Ohio 43755',13263,16642);
INSERT INTO "django_geo_db_zipcode" VALUES(19033,43756,-5,'McConnelsville, Ohio 43756',13264,16643);
INSERT INTO "django_geo_db_zipcode" VALUES(19034,43757,-5,'Malaga, Ohio 43757',13265,16644);
INSERT INTO "django_geo_db_zipcode" VALUES(19035,43758,-5,'Malta, Ohio 43758',13266,16645);
INSERT INTO "django_geo_db_zipcode" VALUES(19036,43759,-5,'Morristown, Ohio 43759',13267,16646);
INSERT INTO "django_geo_db_zipcode" VALUES(19037,43760,-5,'Mount Perry, Ohio 43760',13268,16647);
INSERT INTO "django_geo_db_zipcode" VALUES(19038,43761,-5,'Moxahala, Ohio 43761',13269,16648);
INSERT INTO "django_geo_db_zipcode" VALUES(19039,43762,-5,'New Concord, Ohio 43762',13270,16649);
INSERT INTO "django_geo_db_zipcode" VALUES(19040,43764,-5,'New Lexington, Ohio 43764',13271,16650);
INSERT INTO "django_geo_db_zipcode" VALUES(19041,43766,-5,'New Straitsville, Ohio 43766',13272,16651);
INSERT INTO "django_geo_db_zipcode" VALUES(19042,43767,-5,'Norwich, Ohio 43767',13273,16652);
INSERT INTO "django_geo_db_zipcode" VALUES(19043,43768,-5,'Old Washington, Ohio 43768',13274,16653);
INSERT INTO "django_geo_db_zipcode" VALUES(19044,43771,-5,'Philo, Ohio 43771',13275,16654);
INSERT INTO "django_geo_db_zipcode" VALUES(19045,43772,-5,'Pleasant City, Ohio 43772',13276,16655);
INSERT INTO "django_geo_db_zipcode" VALUES(19046,43773,-5,'Quaker City, Ohio 43773',13277,16656);
INSERT INTO "django_geo_db_zipcode" VALUES(19047,43777,-5,'Roseville, Ohio 43777',13278,16657);
INSERT INTO "django_geo_db_zipcode" VALUES(19048,43778,-5,'Salesville, Ohio 43778',13279,16658);
INSERT INTO "django_geo_db_zipcode" VALUES(19049,43779,-5,'Sarahsville, Ohio 43779',13280,16659);
INSERT INTO "django_geo_db_zipcode" VALUES(19050,43780,-5,'Senecaville, Ohio 43780',13281,16660);
INSERT INTO "django_geo_db_zipcode" VALUES(19051,43782,-5,'Shawnee, Ohio 43782',13282,16661);
INSERT INTO "django_geo_db_zipcode" VALUES(19052,43783,-5,'Somerset, Ohio 43783',13283,16662);
INSERT INTO "django_geo_db_zipcode" VALUES(19053,43786,-5,'Stafford, Ohio 43786',13284,16663);
INSERT INTO "django_geo_db_zipcode" VALUES(19054,43787,-5,'Stockport, Ohio 43787',13285,16664);
INSERT INTO "django_geo_db_zipcode" VALUES(19055,43788,-5,'Summerfield, Ohio 43788',13286,16665);
INSERT INTO "django_geo_db_zipcode" VALUES(19056,43789,-5,'Sycamore Valley, Ohio 43789',13287,16666);
INSERT INTO "django_geo_db_zipcode" VALUES(19057,43791,-5,'White Cottage, Ohio 43791',13288,16667);
INSERT INTO "django_geo_db_zipcode" VALUES(19058,43793,-5,'Woodsfield, Ohio 43793',13289,16668);
INSERT INTO "django_geo_db_zipcode" VALUES(19059,43799,-5,'Center, Ohio 43799',13290,16669);
INSERT INTO "django_geo_db_zipcode" VALUES(19060,43802,-5,'Adamsville, Ohio 43802',13291,16670);
INSERT INTO "django_geo_db_zipcode" VALUES(19061,43803,-5,'Bakersville, Ohio 43803',13292,16671);
INSERT INTO "django_geo_db_zipcode" VALUES(19062,43804,-5,'Baltic, Ohio 43804',13293,16672);
INSERT INTO "django_geo_db_zipcode" VALUES(19063,43805,-5,'Blissfield, Ohio 43805',13294,16673);
INSERT INTO "django_geo_db_zipcode" VALUES(19064,43811,-5,'Conesville, Ohio 43811',13295,16674);
INSERT INTO "django_geo_db_zipcode" VALUES(19065,43812,-5,'Coshocton, Ohio 43812',13296,16675);
INSERT INTO "django_geo_db_zipcode" VALUES(19066,43821,-5,'Dresden, Ohio 43821',13297,16676);
INSERT INTO "django_geo_db_zipcode" VALUES(19067,43822,-5,'Frazeysburg, Ohio 43822',13298,16677);
INSERT INTO "django_geo_db_zipcode" VALUES(19068,43824,-5,'Fresno, Ohio 43824',13299,16678);
INSERT INTO "django_geo_db_zipcode" VALUES(19069,43828,-5,'Keene, Ohio 43828',13300,16679);
INSERT INTO "django_geo_db_zipcode" VALUES(19070,43830,-5,'Nashport, Ohio 43830',13301,16680);
INSERT INTO "django_geo_db_zipcode" VALUES(19071,43832,-5,'Newcomerstown, Ohio 43832',13302,16681);
INSERT INTO "django_geo_db_zipcode" VALUES(19072,43836,-5,'Plainfield, Ohio 43836',13303,16682);
INSERT INTO "django_geo_db_zipcode" VALUES(19073,43837,-5,'Port Washington, Ohio 43837',13304,16683);
INSERT INTO "django_geo_db_zipcode" VALUES(19074,43840,-5,'Stone Creek, Ohio 43840',13305,16684);
INSERT INTO "django_geo_db_zipcode" VALUES(19075,43842,-5,'Trinway, Ohio 43842',13306,16685);
INSERT INTO "django_geo_db_zipcode" VALUES(19076,43843,-5,'Walhonding, Ohio 43843',13307,16686);
INSERT INTO "django_geo_db_zipcode" VALUES(19077,43844,-5,'Warsaw, Ohio 43844',13308,16687);
INSERT INTO "django_geo_db_zipcode" VALUES(19078,43845,-5,'West Lafayette, Ohio 43845',13309,16688);
INSERT INTO "django_geo_db_zipcode" VALUES(19079,43901,-5,'Adena, Ohio 43901',13310,16689);
INSERT INTO "django_geo_db_zipcode" VALUES(19080,43902,-5,'Alledonia, Ohio 43902',13311,16690);
INSERT INTO "django_geo_db_zipcode" VALUES(19081,43903,-5,'Amsterdam, Ohio 43903',13312,16691);
INSERT INTO "django_geo_db_zipcode" VALUES(19082,43905,-5,'Barton, Ohio 43905',13313,16692);
INSERT INTO "django_geo_db_zipcode" VALUES(19083,43906,-5,'Bellaire, Ohio 43906',13314,16693);
INSERT INTO "django_geo_db_zipcode" VALUES(19084,43907,-5,'Cadiz, Ohio 43907',13315,16694);
INSERT INTO "django_geo_db_zipcode" VALUES(19085,43908,-5,'Bergholz, Ohio 43908',13316,16695);
INSERT INTO "django_geo_db_zipcode" VALUES(19086,43909,-5,'Blaine, Ohio 43909',13317,16696);
INSERT INTO "django_geo_db_zipcode" VALUES(19087,43910,-5,'Bloomingdale, Ohio 43910',13318,16697);
INSERT INTO "django_geo_db_zipcode" VALUES(19088,43912,-5,'Bridgeport, Ohio 43912',13319,16698);
INSERT INTO "django_geo_db_zipcode" VALUES(19089,43913,-5,'Brilliant, Ohio 43913',13320,16699);
INSERT INTO "django_geo_db_zipcode" VALUES(19090,43914,-5,'Cameron, Ohio 43914',13321,16700);
INSERT INTO "django_geo_db_zipcode" VALUES(19091,43915,-5,'Clarington, Ohio 43915',13322,16701);
INSERT INTO "django_geo_db_zipcode" VALUES(19092,43916,-5,'Colerain, Ohio 43916',13323,16702);
INSERT INTO "django_geo_db_zipcode" VALUES(19093,43917,-5,'Dillonvale, Ohio 43917',13324,16703);
INSERT INTO "django_geo_db_zipcode" VALUES(19094,43920,-5,'East Liverpool, Ohio 43920',13325,16704);
INSERT INTO "django_geo_db_zipcode" VALUES(19095,43924,-5,'Noble, Ohio 43924',13326,16705);
INSERT INTO "django_geo_db_zipcode" VALUES(19096,43925,-5,'East Springfield, Ohio 43925',13327,16706);
INSERT INTO "django_geo_db_zipcode" VALUES(19097,43926,-5,'Empire, Ohio 43926',13328,16707);
INSERT INTO "django_geo_db_zipcode" VALUES(19098,43927,-5,'Fairpoint, Ohio 43927',13329,16708);
INSERT INTO "django_geo_db_zipcode" VALUES(19099,43928,-5,'Glencoe, Ohio 43928',13330,16709);
INSERT INTO "django_geo_db_zipcode" VALUES(19100,43930,-5,'Hammondsville, Ohio 43930',13331,16710);
INSERT INTO "django_geo_db_zipcode" VALUES(19101,43931,-5,'Hannibal, Ohio 43931',13332,16711);
INSERT INTO "django_geo_db_zipcode" VALUES(19102,43932,-5,'Irondale, Ohio 43932',13333,16712);
INSERT INTO "django_geo_db_zipcode" VALUES(19103,43933,-5,'Jacobsburg, Ohio 43933',13334,16713);
INSERT INTO "django_geo_db_zipcode" VALUES(19104,43934,-5,'Lansing, Ohio 43934',13335,16714);
INSERT INTO "django_geo_db_zipcode" VALUES(19105,43935,-5,'Martins Ferry, Ohio 43935',13336,16715);
INSERT INTO "django_geo_db_zipcode" VALUES(19106,43937,-5,'Maynard, Ohio 43937',13337,16716);
INSERT INTO "django_geo_db_zipcode" VALUES(19107,43938,-5,'Mingo Junction, Ohio 43938',13338,16717);
INSERT INTO "django_geo_db_zipcode" VALUES(19108,43939,-5,'Mount Pleasant, Ohio 43939',13339,16718);
INSERT INTO "django_geo_db_zipcode" VALUES(19109,43940,-5,'Neffs, Ohio 43940',13340,16719);
INSERT INTO "django_geo_db_zipcode" VALUES(19110,43941,-5,'Piney Fork, Ohio 43941',13341,16720);
INSERT INTO "django_geo_db_zipcode" VALUES(19111,43942,-5,'Powhatan Point, Ohio 43942',13342,16721);
INSERT INTO "django_geo_db_zipcode" VALUES(19112,43943,-5,'Rayland, Ohio 43943',13343,16722);
INSERT INTO "django_geo_db_zipcode" VALUES(19113,43944,-5,'Richmond, Ohio 43944',13344,16723);
INSERT INTO "django_geo_db_zipcode" VALUES(19114,43945,-5,'Salineville, Ohio 43945',13345,16724);
INSERT INTO "django_geo_db_zipcode" VALUES(19115,43946,-5,'Sardis, Ohio 43946',13346,16725);
INSERT INTO "django_geo_db_zipcode" VALUES(19116,43947,-5,'Shadyside, Ohio 43947',13347,16726);
INSERT INTO "django_geo_db_zipcode" VALUES(19117,43948,-5,'Smithfield, Ohio 43948',13348,16727);
INSERT INTO "django_geo_db_zipcode" VALUES(19118,43950,-5,'Saint Clairsville, Ohio 43950',13349,16728);
INSERT INTO "django_geo_db_zipcode" VALUES(19119,43951,-5,'Lafferty, Ohio 43951',13350,16729);
INSERT INTO "django_geo_db_zipcode" VALUES(19120,43952,-5,'Steubenville, Ohio 43952',13351,16730);
INSERT INTO "django_geo_db_zipcode" VALUES(19121,43953,-5,'Steubenville, Ohio 43953',13351,16731);
INSERT INTO "django_geo_db_zipcode" VALUES(19122,43960,-5,'Richland, Ohio 43960',13352,16732);
INSERT INTO "django_geo_db_zipcode" VALUES(19123,43961,-5,'Stratton, Ohio 43961',13353,16733);
INSERT INTO "django_geo_db_zipcode" VALUES(19124,43962,-5,'Summitville, Ohio 43962',13354,16734);
INSERT INTO "django_geo_db_zipcode" VALUES(19125,43963,-5,'Tiltonsville, Ohio 43963',13355,16735);
INSERT INTO "django_geo_db_zipcode" VALUES(19126,43964,-5,'Toronto, Ohio 43964',13356,16736);
INSERT INTO "django_geo_db_zipcode" VALUES(19127,43966,-5,'Unionport, Ohio 43966',13357,16737);
INSERT INTO "django_geo_db_zipcode" VALUES(19128,43967,-5,'Warnock, Ohio 43967',13358,16738);
INSERT INTO "django_geo_db_zipcode" VALUES(19129,43968,-5,'Wellsville, Ohio 43968',13359,16739);
INSERT INTO "django_geo_db_zipcode" VALUES(19130,43970,-5,'Wolf Run, Ohio 43970',13360,16740);
INSERT INTO "django_geo_db_zipcode" VALUES(19131,43971,-5,'Yorkville, Ohio 43971',13361,16741);
INSERT INTO "django_geo_db_zipcode" VALUES(19132,43972,-5,'Bannock, Ohio 43972',13362,16742);
INSERT INTO "django_geo_db_zipcode" VALUES(19133,43973,-5,'Freeport, Ohio 43973',13363,16743);
INSERT INTO "django_geo_db_zipcode" VALUES(19134,43974,-5,'Harrisville, Ohio 43974',13364,16744);
INSERT INTO "django_geo_db_zipcode" VALUES(19135,43976,-5,'Hopedale, Ohio 43976',13365,16745);
INSERT INTO "django_geo_db_zipcode" VALUES(19136,43977,-5,'Flushing, Ohio 43977',13366,16746);
INSERT INTO "django_geo_db_zipcode" VALUES(19137,43981,-5,'New Athens, Ohio 43981',13367,16747);
INSERT INTO "django_geo_db_zipcode" VALUES(19138,43983,-5,'Piedmont, Ohio 43983',13368,16748);
INSERT INTO "django_geo_db_zipcode" VALUES(19139,43984,-5,'New Rumley, Ohio 43984',13369,16749);
INSERT INTO "django_geo_db_zipcode" VALUES(19140,43985,-5,'Holloway, Ohio 43985',13370,16646);
INSERT INTO "django_geo_db_zipcode" VALUES(19141,43986,-5,'Jewett, Ohio 43986',13371,16750);
INSERT INTO "django_geo_db_zipcode" VALUES(19142,43988,-5,'Scio, Ohio 43988',13372,16751);
INSERT INTO "django_geo_db_zipcode" VALUES(19143,43989,-5,'Short Creek, Ohio 43989',13373,16749);
INSERT INTO "django_geo_db_zipcode" VALUES(19144,44001,-5,'Amherst, Ohio 44001',13374,16752);
INSERT INTO "django_geo_db_zipcode" VALUES(19145,44003,-5,'Andover, Ohio 44003',13375,16753);
INSERT INTO "django_geo_db_zipcode" VALUES(19146,44004,-5,'Ashtabula, Ohio 44004',13376,16754);
INSERT INTO "django_geo_db_zipcode" VALUES(19147,44005,-5,'Ashtabula, Ohio 44005',13376,16755);
INSERT INTO "django_geo_db_zipcode" VALUES(19148,44010,-5,'Austinburg, Ohio 44010',13377,16756);
INSERT INTO "django_geo_db_zipcode" VALUES(19149,44011,-5,'Avon, Ohio 44011',13378,16757);
INSERT INTO "django_geo_db_zipcode" VALUES(19150,44012,-5,'Avon Lake, Ohio 44012',13379,16758);
INSERT INTO "django_geo_db_zipcode" VALUES(19151,44017,-5,'Berea, Ohio 44017',13380,16759);
INSERT INTO "django_geo_db_zipcode" VALUES(19152,44021,-5,'Burton, Ohio 44021',13381,16760);
INSERT INTO "django_geo_db_zipcode" VALUES(19153,44022,-5,'Chagrin Falls, Ohio 44022',13382,16761);
INSERT INTO "django_geo_db_zipcode" VALUES(19154,44023,-5,'Chagrin Falls, Ohio 44023',13382,16762);
INSERT INTO "django_geo_db_zipcode" VALUES(19155,44024,-5,'Chardon, Ohio 44024',13383,16763);
INSERT INTO "django_geo_db_zipcode" VALUES(19156,44026,-5,'Chesterland, Ohio 44026',13384,16764);
INSERT INTO "django_geo_db_zipcode" VALUES(19157,44028,-5,'Columbia Station, Ohio 44028',13385,16765);
INSERT INTO "django_geo_db_zipcode" VALUES(19158,44030,-5,'Conneaut, Ohio 44030',13386,16766);
INSERT INTO "django_geo_db_zipcode" VALUES(19159,44032,-5,'Dorset, Ohio 44032',13387,16767);
INSERT INTO "django_geo_db_zipcode" VALUES(19160,44033,-5,'East Claridon, Ohio 44033',13388,16768);
INSERT INTO "django_geo_db_zipcode" VALUES(19161,44035,-5,'Elyria, Ohio 44035',13389,16769);
INSERT INTO "django_geo_db_zipcode" VALUES(19162,44036,-5,'Elyria, Ohio 44036',13389,16770);
INSERT INTO "django_geo_db_zipcode" VALUES(19163,44039,-5,'North Ridgeville, Ohio 44039',13390,16771);
INSERT INTO "django_geo_db_zipcode" VALUES(19164,44040,-5,'Gates Mills, Ohio 44040',13391,16772);
INSERT INTO "django_geo_db_zipcode" VALUES(19165,44041,-5,'Geneva, Ohio 44041',13392,16773);
INSERT INTO "django_geo_db_zipcode" VALUES(19166,44044,-5,'Grafton, Ohio 44044',13393,16774);
INSERT INTO "django_geo_db_zipcode" VALUES(19167,44045,-5,'Grand River, Ohio 44045',13394,16775);
INSERT INTO "django_geo_db_zipcode" VALUES(19168,44046,-5,'Huntsburg, Ohio 44046',13395,16776);
INSERT INTO "django_geo_db_zipcode" VALUES(19169,44047,-5,'Jefferson, Ohio 44047',13396,16777);
INSERT INTO "django_geo_db_zipcode" VALUES(19170,44048,-5,'Kingsville, Ohio 44048',13397,16778);
INSERT INTO "django_geo_db_zipcode" VALUES(19171,44049,-5,'Kipton, Ohio 44049',13398,16779);
INSERT INTO "django_geo_db_zipcode" VALUES(19172,44050,-5,'Lagrange, Ohio 44050',13399,16780);
INSERT INTO "django_geo_db_zipcode" VALUES(19173,44052,-5,'Lorain, Ohio 44052',13400,16781);
INSERT INTO "django_geo_db_zipcode" VALUES(19174,44053,-5,'Lorain, Ohio 44053',13400,16782);
INSERT INTO "django_geo_db_zipcode" VALUES(19175,44054,-5,'Sheffield Lake, Ohio 44054',13401,16783);
INSERT INTO "django_geo_db_zipcode" VALUES(19176,44055,-5,'Lorain, Ohio 44055',13400,16784);
INSERT INTO "django_geo_db_zipcode" VALUES(19177,44056,-5,'Macedonia, Ohio 44056',13402,16785);
INSERT INTO "django_geo_db_zipcode" VALUES(19178,44057,-5,'Madison, Ohio 44057',13403,16786);
INSERT INTO "django_geo_db_zipcode" VALUES(19179,44060,-5,'Mentor, Ohio 44060',13404,16787);
INSERT INTO "django_geo_db_zipcode" VALUES(19180,44061,-5,'Mentor, Ohio 44061',13404,16788);
INSERT INTO "django_geo_db_zipcode" VALUES(19181,44062,-5,'Middlefield, Ohio 44062',13405,16789);
INSERT INTO "django_geo_db_zipcode" VALUES(19182,44064,-5,'Montville, Ohio 44064',13406,16790);
INSERT INTO "django_geo_db_zipcode" VALUES(19183,44065,-5,'Newbury, Ohio 44065',13407,16791);
INSERT INTO "django_geo_db_zipcode" VALUES(19184,44067,-5,'Northfield, Ohio 44067',13408,16792);
INSERT INTO "django_geo_db_zipcode" VALUES(19185,44068,-5,'North Kingsville, Ohio 44068',13409,16793);
INSERT INTO "django_geo_db_zipcode" VALUES(19186,44070,-5,'North Olmsted, Ohio 44070',13410,16794);
INSERT INTO "django_geo_db_zipcode" VALUES(19187,44072,-5,'Novelty, Ohio 44072',13411,16795);
INSERT INTO "django_geo_db_zipcode" VALUES(19188,44073,-5,'Novelty, Ohio 44073',13411,16796);
INSERT INTO "django_geo_db_zipcode" VALUES(19189,44074,-5,'Oberlin, Ohio 44074',13412,16797);
INSERT INTO "django_geo_db_zipcode" VALUES(19190,44076,-5,'Orwell, Ohio 44076',13413,16798);
INSERT INTO "django_geo_db_zipcode" VALUES(19191,44077,-5,'Painesville, Ohio 44077',13414,16799);
INSERT INTO "django_geo_db_zipcode" VALUES(19192,44080,-5,'Parkman, Ohio 44080',13415,16800);
INSERT INTO "django_geo_db_zipcode" VALUES(19193,44081,-5,'Perry, Ohio 44081',13416,16801);
INSERT INTO "django_geo_db_zipcode" VALUES(19194,44082,-5,'Pierpont, Ohio 44082',13417,16802);
INSERT INTO "django_geo_db_zipcode" VALUES(19195,44084,-5,'Rock Creek, Ohio 44084',13418,16803);
INSERT INTO "django_geo_db_zipcode" VALUES(19196,44085,-5,'Rome, Ohio 44085',13419,16804);
INSERT INTO "django_geo_db_zipcode" VALUES(19197,44086,-5,'Thompson, Ohio 44086',13420,16805);
INSERT INTO "django_geo_db_zipcode" VALUES(19198,44087,-5,'Twinsburg, Ohio 44087',13421,16806);
INSERT INTO "django_geo_db_zipcode" VALUES(19199,44088,-5,'Unionville, Ohio 44088',13422,16807);
INSERT INTO "django_geo_db_zipcode" VALUES(19200,44089,-5,'Vermilion, Ohio 44089',13423,16808);
INSERT INTO "django_geo_db_zipcode" VALUES(19201,44090,-5,'Wellington, Ohio 44090',13424,16809);
INSERT INTO "django_geo_db_zipcode" VALUES(19202,44092,-5,'Wickliffe, Ohio 44092',13425,16810);
INSERT INTO "django_geo_db_zipcode" VALUES(19203,44093,-5,'Williamsfield, Ohio 44093',13426,16811);
INSERT INTO "django_geo_db_zipcode" VALUES(19204,44094,-5,'Willoughby, Ohio 44094',13427,16812);
INSERT INTO "django_geo_db_zipcode" VALUES(19205,44095,-5,'Eastlake, Ohio 44095',13428,16813);
INSERT INTO "django_geo_db_zipcode" VALUES(19206,44096,-5,'Willoughby, Ohio 44096',13427,16788);
INSERT INTO "django_geo_db_zipcode" VALUES(19207,44097,-5,'Eastlake, Ohio 44097',13428,16788);
INSERT INTO "django_geo_db_zipcode" VALUES(19208,44099,-5,'Windsor, Ohio 44099',13429,16814);
INSERT INTO "django_geo_db_zipcode" VALUES(19209,44101,-5,'Cleveland, Ohio 44101',13430,16815);
INSERT INTO "django_geo_db_zipcode" VALUES(19210,44102,-5,'Cleveland, Ohio 44102',13430,16816);
INSERT INTO "django_geo_db_zipcode" VALUES(19211,44103,-5,'Cleveland, Ohio 44103',13430,16817);
INSERT INTO "django_geo_db_zipcode" VALUES(19212,44104,-5,'Cleveland, Ohio 44104',13430,16818);
INSERT INTO "django_geo_db_zipcode" VALUES(19213,44105,-5,'Cleveland, Ohio 44105',13430,16819);
INSERT INTO "django_geo_db_zipcode" VALUES(19214,44106,-5,'Cleveland, Ohio 44106',13430,16820);
INSERT INTO "django_geo_db_zipcode" VALUES(19215,44107,-5,'Lakewood, Ohio 44107',13431,16821);
INSERT INTO "django_geo_db_zipcode" VALUES(19216,44108,-5,'Cleveland, Ohio 44108',13430,16822);
INSERT INTO "django_geo_db_zipcode" VALUES(19217,44109,-5,'Cleveland, Ohio 44109',13430,16823);
INSERT INTO "django_geo_db_zipcode" VALUES(19218,44110,-5,'Cleveland, Ohio 44110',13430,16824);
INSERT INTO "django_geo_db_zipcode" VALUES(19219,44111,-5,'Cleveland, Ohio 44111',13430,16825);
INSERT INTO "django_geo_db_zipcode" VALUES(19220,44112,-5,'Cleveland, Ohio 44112',13430,16826);
INSERT INTO "django_geo_db_zipcode" VALUES(19221,44113,-5,'Cleveland, Ohio 44113',13430,16827);
INSERT INTO "django_geo_db_zipcode" VALUES(19222,44114,-5,'Cleveland, Ohio 44114',13430,16828);
INSERT INTO "django_geo_db_zipcode" VALUES(19223,44115,-5,'Cleveland, Ohio 44115',13430,16829);
INSERT INTO "django_geo_db_zipcode" VALUES(19224,44116,-5,'Rocky River, Ohio 44116',13432,16830);
INSERT INTO "django_geo_db_zipcode" VALUES(19225,44117,-5,'Euclid, Ohio 44117',13433,16831);
INSERT INTO "django_geo_db_zipcode" VALUES(19226,44118,-5,'Cleveland, Ohio 44118',13430,16832);
INSERT INTO "django_geo_db_zipcode" VALUES(19227,44119,-5,'Cleveland, Ohio 44119',13430,16833);
INSERT INTO "django_geo_db_zipcode" VALUES(19228,44120,-5,'Cleveland, Ohio 44120',13430,16834);
INSERT INTO "django_geo_db_zipcode" VALUES(19229,44121,-5,'Cleveland, Ohio 44121',13430,16835);
INSERT INTO "django_geo_db_zipcode" VALUES(19230,44122,-5,'Beachwood, Ohio 44122',13434,16836);
INSERT INTO "django_geo_db_zipcode" VALUES(19231,44123,-5,'Euclid, Ohio 44123',13433,16837);
INSERT INTO "django_geo_db_zipcode" VALUES(19232,44124,-5,'Cleveland, Ohio 44124',13430,16838);
INSERT INTO "django_geo_db_zipcode" VALUES(19233,44125,-5,'Cleveland, Ohio 44125',13430,16839);
INSERT INTO "django_geo_db_zipcode" VALUES(19234,44126,-5,'Cleveland, Ohio 44126',13430,16840);
INSERT INTO "django_geo_db_zipcode" VALUES(19235,44127,-5,'Cleveland, Ohio 44127',13430,16841);
INSERT INTO "django_geo_db_zipcode" VALUES(19236,44128,-5,'Cleveland, Ohio 44128',13430,16842);
INSERT INTO "django_geo_db_zipcode" VALUES(19237,44129,-5,'Cleveland, Ohio 44129',13430,16843);
INSERT INTO "django_geo_db_zipcode" VALUES(19238,44130,-5,'Cleveland, Ohio 44130',13430,16844);
INSERT INTO "django_geo_db_zipcode" VALUES(19239,44131,-5,'Independence, Ohio 44131',13435,16845);
INSERT INTO "django_geo_db_zipcode" VALUES(19240,44132,-5,'Euclid, Ohio 44132',13433,16846);
INSERT INTO "django_geo_db_zipcode" VALUES(19241,44133,-5,'North Royalton, Ohio 44133',13436,16847);
INSERT INTO "django_geo_db_zipcode" VALUES(19242,44134,-5,'Cleveland, Ohio 44134',13430,16848);
INSERT INTO "django_geo_db_zipcode" VALUES(19243,44135,-5,'Cleveland, Ohio 44135',13430,16849);
INSERT INTO "django_geo_db_zipcode" VALUES(19244,44136,-5,'Strongsville, Ohio 44136',13437,16850);
INSERT INTO "django_geo_db_zipcode" VALUES(19245,44137,-5,'Maple Heights, Ohio 44137',13438,16851);
INSERT INTO "django_geo_db_zipcode" VALUES(19246,44138,-5,'Olmsted Falls, Ohio 44138',13439,16852);
INSERT INTO "django_geo_db_zipcode" VALUES(19247,44139,-5,'Solon, Ohio 44139',13440,16853);
INSERT INTO "django_geo_db_zipcode" VALUES(19248,44140,-5,'Bay Village, Ohio 44140',13441,16854);
INSERT INTO "django_geo_db_zipcode" VALUES(19249,44141,-5,'Brecksville, Ohio 44141',13442,16855);
INSERT INTO "django_geo_db_zipcode" VALUES(19250,44142,-5,'Brookpark, Ohio 44142',13443,16856);
INSERT INTO "django_geo_db_zipcode" VALUES(19251,44143,-5,'Cleveland, Ohio 44143',13430,16857);
INSERT INTO "django_geo_db_zipcode" VALUES(19252,44144,-5,'Cleveland, Ohio 44144',13430,16858);
INSERT INTO "django_geo_db_zipcode" VALUES(19253,44145,-5,'Westlake, Ohio 44145',13444,16859);
INSERT INTO "django_geo_db_zipcode" VALUES(19254,44146,-5,'Bedford, Ohio 44146',13445,16860);
INSERT INTO "django_geo_db_zipcode" VALUES(19255,44147,-5,'Broadview Heights, Ohio 44147',13446,16861);
INSERT INTO "django_geo_db_zipcode" VALUES(19256,44149,-5,'Brunswick, Ohio 44149',13447,16862);
INSERT INTO "django_geo_db_zipcode" VALUES(19257,44168,-5,'Dalton, Ohio 44168',13448,16863);
INSERT INTO "django_geo_db_zipcode" VALUES(19258,44177,-5,'Cleveland, Ohio 44177',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19259,44178,-5,'Cleveland, Ohio 44178',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19260,44179,-5,'Cleveland, Ohio 44179',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19261,44181,-5,'Cleveland, Ohio 44181',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19262,44184,-5,'Cleveland, Ohio 44184',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19263,44185,-5,'Cleveland, Ohio 44185',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19264,44186,-5,'Cleveland, Ohio 44186',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19265,44188,-5,'Cleveland, Ohio 44188',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19266,44189,-5,'Cleveland, Ohio 44189',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19267,44190,-5,'Cleveland, Ohio 44190',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19268,44191,-5,'Cleveland, Ohio 44191',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19269,44192,-5,'Cleveland, Ohio 44192',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19270,44193,-5,'Cleveland, Ohio 44193',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19271,44194,-5,'Cleveland, Ohio 44194',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19272,44195,-5,'Cleveland, Ohio 44195',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19273,44197,-5,'Cleveland, Ohio 44197',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19274,44198,-5,'Cleveland, Ohio 44198',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19275,44199,-5,'Cleveland, Ohio 44199',13430,16864);
INSERT INTO "django_geo_db_zipcode" VALUES(19276,44201,-5,'Atwater, Ohio 44201',13449,16865);
INSERT INTO "django_geo_db_zipcode" VALUES(19277,44202,-5,'Aurora, Ohio 44202',13450,16866);
INSERT INTO "django_geo_db_zipcode" VALUES(19278,44203,-5,'Barberton, Ohio 44203',13451,16867);
INSERT INTO "django_geo_db_zipcode" VALUES(19279,44210,-5,'Bath, Ohio 44210',13452,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19280,44211,-5,'Brady Lake, Ohio 44211',13453,16869);
INSERT INTO "django_geo_db_zipcode" VALUES(19281,44212,-5,'Brunswick, Ohio 44212',13447,16870);
INSERT INTO "django_geo_db_zipcode" VALUES(19282,44214,-5,'Burbank, Ohio 44214',13454,16871);
INSERT INTO "django_geo_db_zipcode" VALUES(19283,44215,-5,'Chippewa Lake, Ohio 44215',13455,16872);
INSERT INTO "django_geo_db_zipcode" VALUES(19284,44216,-5,'Clinton, Ohio 44216',13456,16873);
INSERT INTO "django_geo_db_zipcode" VALUES(19285,44217,-5,'Creston, Ohio 44217',13457,16874);
INSERT INTO "django_geo_db_zipcode" VALUES(19286,44221,-5,'Cuyahoga Falls, Ohio 44221',13458,16875);
INSERT INTO "django_geo_db_zipcode" VALUES(19287,44222,-5,'Cuyahoga Falls, Ohio 44222',13458,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19288,44223,-5,'Cuyahoga Falls, Ohio 44223',13458,16876);
INSERT INTO "django_geo_db_zipcode" VALUES(19289,44224,-5,'Stow, Ohio 44224',13459,16877);
INSERT INTO "django_geo_db_zipcode" VALUES(19290,44230,-5,'Doylestown, Ohio 44230',13460,16878);
INSERT INTO "django_geo_db_zipcode" VALUES(19291,44231,-5,'Garrettsville, Ohio 44231',13461,16879);
INSERT INTO "django_geo_db_zipcode" VALUES(19292,44232,-5,'Green, Ohio 44232',13462,16880);
INSERT INTO "django_geo_db_zipcode" VALUES(19293,44233,-5,'Hinckley, Ohio 44233',13463,16881);
INSERT INTO "django_geo_db_zipcode" VALUES(19294,44234,-5,'Hiram, Ohio 44234',13464,16882);
INSERT INTO "django_geo_db_zipcode" VALUES(19295,44235,-5,'Homerville, Ohio 44235',13465,16883);
INSERT INTO "django_geo_db_zipcode" VALUES(19296,44236,-5,'Hudson, Ohio 44236',13466,16884);
INSERT INTO "django_geo_db_zipcode" VALUES(19297,44237,-5,'Hudson, Ohio 44237',13466,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19298,44238,-5,'Hudson, Ohio 44238',13466,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19299,44240,-5,'Kent, Ohio 44240',13467,16885);
INSERT INTO "django_geo_db_zipcode" VALUES(19300,44241,-5,'Streetsboro, Ohio 44241',13468,16886);
INSERT INTO "django_geo_db_zipcode" VALUES(19301,44242,-5,'Kent, Ohio 44242',13467,16887);
INSERT INTO "django_geo_db_zipcode" VALUES(19302,44243,-5,'Kent, Ohio 44243',13467,16888);
INSERT INTO "django_geo_db_zipcode" VALUES(19303,44250,-5,'Lakemore, Ohio 44250',13469,16889);
INSERT INTO "django_geo_db_zipcode" VALUES(19304,44251,-5,'Westfield Center, Ohio 44251',13470,16890);
INSERT INTO "django_geo_db_zipcode" VALUES(19305,44253,-5,'Litchfield, Ohio 44253',13471,16891);
INSERT INTO "django_geo_db_zipcode" VALUES(19306,44254,-5,'Lodi, Ohio 44254',13472,16892);
INSERT INTO "django_geo_db_zipcode" VALUES(19307,44255,-5,'Mantua, Ohio 44255',13473,16893);
INSERT INTO "django_geo_db_zipcode" VALUES(19308,44256,-5,'Medina, Ohio 44256',13474,16894);
INSERT INTO "django_geo_db_zipcode" VALUES(19309,44258,-5,'Medina, Ohio 44258',13474,16895);
INSERT INTO "django_geo_db_zipcode" VALUES(19310,44260,-5,'Mogadore, Ohio 44260',13475,16896);
INSERT INTO "django_geo_db_zipcode" VALUES(19311,44262,-5,'Munroe Falls, Ohio 44262',13476,16897);
INSERT INTO "django_geo_db_zipcode" VALUES(19312,44264,-5,'Peninsula, Ohio 44264',13477,16898);
INSERT INTO "django_geo_db_zipcode" VALUES(19313,44265,-5,'Randolph, Ohio 44265',13478,16899);
INSERT INTO "django_geo_db_zipcode" VALUES(19314,44266,-5,'Ravenna, Ohio 44266',13479,16900);
INSERT INTO "django_geo_db_zipcode" VALUES(19315,44270,-5,'Rittman, Ohio 44270',13480,16901);
INSERT INTO "django_geo_db_zipcode" VALUES(19316,44272,-5,'Rootstown, Ohio 44272',13481,16902);
INSERT INTO "django_geo_db_zipcode" VALUES(19317,44273,-5,'Seville, Ohio 44273',13482,16903);
INSERT INTO "django_geo_db_zipcode" VALUES(19318,44274,-5,'Sharon Center, Ohio 44274',13483,16904);
INSERT INTO "django_geo_db_zipcode" VALUES(19319,44275,-5,'Spencer, Ohio 44275',13484,16905);
INSERT INTO "django_geo_db_zipcode" VALUES(19320,44276,-5,'Sterling, Ohio 44276',13485,16906);
INSERT INTO "django_geo_db_zipcode" VALUES(19321,44278,-5,'Tallmadge, Ohio 44278',13486,16907);
INSERT INTO "django_geo_db_zipcode" VALUES(19322,44280,-5,'Valley City, Ohio 44280',13487,16908);
INSERT INTO "django_geo_db_zipcode" VALUES(19323,44281,-5,'Wadsworth, Ohio 44281',13488,16909);
INSERT INTO "django_geo_db_zipcode" VALUES(19324,44282,-5,'Wadsworth, Ohio 44282',13488,16910);
INSERT INTO "django_geo_db_zipcode" VALUES(19325,44285,-5,'Wayland, Ohio 44285',13489,16911);
INSERT INTO "django_geo_db_zipcode" VALUES(19326,44286,-5,'Richfield, Ohio 44286',13490,16912);
INSERT INTO "django_geo_db_zipcode" VALUES(19327,44287,-5,'West Salem, Ohio 44287',13491,16913);
INSERT INTO "django_geo_db_zipcode" VALUES(19328,44288,-5,'Windham, Ohio 44288',13492,16914);
INSERT INTO "django_geo_db_zipcode" VALUES(19329,44301,-5,'Akron, Ohio 44301',13493,16915);
INSERT INTO "django_geo_db_zipcode" VALUES(19330,44302,-5,'Akron, Ohio 44302',13493,16916);
INSERT INTO "django_geo_db_zipcode" VALUES(19331,44303,-5,'Akron, Ohio 44303',13493,16917);
INSERT INTO "django_geo_db_zipcode" VALUES(19332,44304,-5,'Akron, Ohio 44304',13493,16918);
INSERT INTO "django_geo_db_zipcode" VALUES(19333,44305,-5,'Akron, Ohio 44305',13493,16919);
INSERT INTO "django_geo_db_zipcode" VALUES(19334,44306,-5,'Akron, Ohio 44306',13493,16920);
INSERT INTO "django_geo_db_zipcode" VALUES(19335,44307,-5,'Akron, Ohio 44307',13493,16921);
INSERT INTO "django_geo_db_zipcode" VALUES(19336,44308,-5,'Akron, Ohio 44308',13493,16922);
INSERT INTO "django_geo_db_zipcode" VALUES(19337,44309,-5,'Akron, Ohio 44309',13493,16923);
INSERT INTO "django_geo_db_zipcode" VALUES(19338,44310,-5,'Akron, Ohio 44310',13493,16924);
INSERT INTO "django_geo_db_zipcode" VALUES(19339,44311,-5,'Akron, Ohio 44311',13493,16925);
INSERT INTO "django_geo_db_zipcode" VALUES(19340,44312,-5,'Akron, Ohio 44312',13493,16926);
INSERT INTO "django_geo_db_zipcode" VALUES(19341,44313,-5,'Akron, Ohio 44313',13493,16927);
INSERT INTO "django_geo_db_zipcode" VALUES(19342,44314,-5,'Akron, Ohio 44314',13493,16928);
INSERT INTO "django_geo_db_zipcode" VALUES(19343,44315,-5,'Akron, Ohio 44315',13493,16929);
INSERT INTO "django_geo_db_zipcode" VALUES(19344,44316,-5,'Akron, Ohio 44316',13493,16930);
INSERT INTO "django_geo_db_zipcode" VALUES(19345,44317,-5,'Akron, Ohio 44317',13493,16931);
INSERT INTO "django_geo_db_zipcode" VALUES(19346,44319,-5,'Akron, Ohio 44319',13493,16932);
INSERT INTO "django_geo_db_zipcode" VALUES(19347,44320,-5,'Akron, Ohio 44320',13493,16933);
INSERT INTO "django_geo_db_zipcode" VALUES(19348,44321,-5,'Akron, Ohio 44321',13493,16934);
INSERT INTO "django_geo_db_zipcode" VALUES(19349,44322,-5,'Akron, Ohio 44322',13493,16935);
INSERT INTO "django_geo_db_zipcode" VALUES(19350,44325,-5,'Akron, Ohio 44325',13493,16936);
INSERT INTO "django_geo_db_zipcode" VALUES(19351,44326,-5,'Akron, Ohio 44326',13493,16937);
INSERT INTO "django_geo_db_zipcode" VALUES(19352,44328,-5,'Akron, Ohio 44328',13493,16938);
INSERT INTO "django_geo_db_zipcode" VALUES(19353,44331,-5,'Paint, Ohio 44331',13494,16939);
INSERT INTO "django_geo_db_zipcode" VALUES(19354,44333,-5,'Akron, Ohio 44333',13493,16940);
INSERT INTO "django_geo_db_zipcode" VALUES(19355,44334,-5,'Akron, Ohio 44334',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19356,44372,-5,'Akron, Ohio 44372',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19357,44393,-5,'Akron, Ohio 44393',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19358,44396,-5,'Akron, Ohio 44396',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19359,44397,-5,'Akron, Ohio 44397',13493,16941);
INSERT INTO "django_geo_db_zipcode" VALUES(19360,44398,-5,'Akron, Ohio 44398',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19361,44399,-5,'Akron, Ohio 44399',13493,16868);
INSERT INTO "django_geo_db_zipcode" VALUES(19362,44401,-5,'Berlin Center, Ohio 44401',13495,16942);
INSERT INTO "django_geo_db_zipcode" VALUES(19363,44402,-5,'Bristolville, Ohio 44402',13496,16943);
INSERT INTO "django_geo_db_zipcode" VALUES(19364,44403,-5,'Brookfield, Ohio 44403',13497,16944);
INSERT INTO "django_geo_db_zipcode" VALUES(19365,44404,-5,'Burghill, Ohio 44404',13498,16945);
INSERT INTO "django_geo_db_zipcode" VALUES(19366,44405,-5,'Campbell, Ohio 44405',13499,16946);
INSERT INTO "django_geo_db_zipcode" VALUES(19367,44406,-5,'Canfield, Ohio 44406',13500,16947);
INSERT INTO "django_geo_db_zipcode" VALUES(19368,44408,-5,'Columbiana, Ohio 44408',13501,16948);
INSERT INTO "django_geo_db_zipcode" VALUES(19369,44410,-5,'Cortland, Ohio 44410',13502,16949);
INSERT INTO "django_geo_db_zipcode" VALUES(19370,44411,-5,'Deerfield, Ohio 44411',13503,16950);
INSERT INTO "django_geo_db_zipcode" VALUES(19371,44412,-5,'Diamond, Ohio 44412',13504,16951);
INSERT INTO "django_geo_db_zipcode" VALUES(19372,44413,-5,'East Palestine, Ohio 44413',13505,16952);
INSERT INTO "django_geo_db_zipcode" VALUES(19373,44415,-5,'Elkton, Ohio 44415',13506,16953);
INSERT INTO "django_geo_db_zipcode" VALUES(19374,44416,-5,'Ellsworth, Ohio 44416',13507,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19375,44417,-5,'Farmdale, Ohio 44417',13508,16955);
INSERT INTO "django_geo_db_zipcode" VALUES(19376,44418,-5,'Fowler, Ohio 44418',13509,16956);
INSERT INTO "django_geo_db_zipcode" VALUES(19377,44420,-5,'Girard, Ohio 44420',13510,16957);
INSERT INTO "django_geo_db_zipcode" VALUES(19378,44422,-5,'Greenford, Ohio 44422',13511,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19379,44423,-5,'Hanoverton, Ohio 44423',13512,16958);
INSERT INTO "django_geo_db_zipcode" VALUES(19380,44424,-5,'Hartford, Ohio 44424',13513,16959);
INSERT INTO "django_geo_db_zipcode" VALUES(19381,44425,-5,'Hubbard, Ohio 44425',13514,16960);
INSERT INTO "django_geo_db_zipcode" VALUES(19382,44427,-5,'Kensington, Ohio 44427',13515,16961);
INSERT INTO "django_geo_db_zipcode" VALUES(19383,44428,-5,'Kinsman, Ohio 44428',13516,16962);
INSERT INTO "django_geo_db_zipcode" VALUES(19384,44429,-5,'Lake Milton, Ohio 44429',13517,16963);
INSERT INTO "django_geo_db_zipcode" VALUES(19385,44430,-5,'Leavittsburg, Ohio 44430',13518,16964);
INSERT INTO "django_geo_db_zipcode" VALUES(19386,44431,-5,'Leetonia, Ohio 44431',13519,16965);
INSERT INTO "django_geo_db_zipcode" VALUES(19387,44432,-5,'Lisbon, Ohio 44432',13520,16966);
INSERT INTO "django_geo_db_zipcode" VALUES(19388,44436,-5,'Lowellville, Ohio 44436',13521,16967);
INSERT INTO "django_geo_db_zipcode" VALUES(19389,44437,-5,'McDonald, Ohio 44437',13522,16968);
INSERT INTO "django_geo_db_zipcode" VALUES(19390,44438,-5,'Masury, Ohio 44438',13523,16969);
INSERT INTO "django_geo_db_zipcode" VALUES(19391,44439,-5,'Mesopotamia, Ohio 44439',13524,16970);
INSERT INTO "django_geo_db_zipcode" VALUES(19392,44440,-5,'Mineral Ridge, Ohio 44440',13525,16971);
INSERT INTO "django_geo_db_zipcode" VALUES(19393,44441,-5,'Negley, Ohio 44441',13526,16972);
INSERT INTO "django_geo_db_zipcode" VALUES(19394,44442,-5,'New Middletown, Ohio 44442',13527,16973);
INSERT INTO "django_geo_db_zipcode" VALUES(19395,44443,-5,'New Springfield, Ohio 44443',13528,16974);
INSERT INTO "django_geo_db_zipcode" VALUES(19396,44444,-5,'Newton Falls, Ohio 44444',13529,16975);
INSERT INTO "django_geo_db_zipcode" VALUES(19397,44445,-5,'New Waterford, Ohio 44445',13530,16976);
INSERT INTO "django_geo_db_zipcode" VALUES(19398,44446,-5,'Niles, Ohio 44446',13531,16977);
INSERT INTO "django_geo_db_zipcode" VALUES(19399,44449,-5,'North Benton, Ohio 44449',13532,16978);
INSERT INTO "django_geo_db_zipcode" VALUES(19400,44450,-5,'North Bloomfield, Ohio 44450',13533,16979);
INSERT INTO "django_geo_db_zipcode" VALUES(19401,44451,-5,'North Jackson, Ohio 44451',13534,16980);
INSERT INTO "django_geo_db_zipcode" VALUES(19402,44452,-5,'North Lima, Ohio 44452',13535,16981);
INSERT INTO "django_geo_db_zipcode" VALUES(19403,44453,-5,'Orangeville, Ohio 44453',13536,16982);
INSERT INTO "django_geo_db_zipcode" VALUES(19404,44454,-5,'Petersburg, Ohio 44454',13537,16983);
INSERT INTO "django_geo_db_zipcode" VALUES(19405,44455,-5,'Rogers, Ohio 44455',13538,16984);
INSERT INTO "django_geo_db_zipcode" VALUES(19406,44460,-5,'Salem, Ohio 44460',13539,16985);
INSERT INTO "django_geo_db_zipcode" VALUES(19407,44470,-5,'Southington, Ohio 44470',13540,16986);
INSERT INTO "django_geo_db_zipcode" VALUES(19408,44471,-5,'Struthers, Ohio 44471',13541,16987);
INSERT INTO "django_geo_db_zipcode" VALUES(19409,44473,-5,'Vienna, Ohio 44473',13542,16988);
INSERT INTO "django_geo_db_zipcode" VALUES(19410,44481,-5,'Warren, Ohio 44481',13543,16989);
INSERT INTO "django_geo_db_zipcode" VALUES(19411,44482,-5,'Warren, Ohio 44482',13543,16990);
INSERT INTO "django_geo_db_zipcode" VALUES(19412,44483,-5,'Warren, Ohio 44483',13543,16991);
INSERT INTO "django_geo_db_zipcode" VALUES(19413,44484,-5,'Warren, Ohio 44484',13543,16992);
INSERT INTO "django_geo_db_zipcode" VALUES(19414,44485,-5,'Warren, Ohio 44485',13543,16993);
INSERT INTO "django_geo_db_zipcode" VALUES(19415,44486,-5,'Warren, Ohio 44486',13543,16990);
INSERT INTO "django_geo_db_zipcode" VALUES(19416,44487,-5,'Warren, Ohio 44487',13543,16990);
INSERT INTO "django_geo_db_zipcode" VALUES(19417,44488,-5,'Warren, Ohio 44488',13543,16990);
INSERT INTO "django_geo_db_zipcode" VALUES(19418,44490,-5,'Washingtonville, Ohio 44490',13544,16994);
INSERT INTO "django_geo_db_zipcode" VALUES(19419,44491,-5,'West Farmington, Ohio 44491',13545,16995);
INSERT INTO "django_geo_db_zipcode" VALUES(19420,44492,-5,'West Point, Ohio 44492',13546,16996);
INSERT INTO "django_geo_db_zipcode" VALUES(19421,44493,-5,'Winona, Ohio 44493',13547,16997);
INSERT INTO "django_geo_db_zipcode" VALUES(19422,44501,-5,'Youngstown, Ohio 44501',13548,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19423,44502,-5,'Youngstown, Ohio 44502',13548,16998);
INSERT INTO "django_geo_db_zipcode" VALUES(19424,44503,-5,'Youngstown, Ohio 44503',13548,16999);
INSERT INTO "django_geo_db_zipcode" VALUES(19425,44504,-5,'Youngstown, Ohio 44504',13548,17000);
INSERT INTO "django_geo_db_zipcode" VALUES(19426,44505,-5,'Youngstown, Ohio 44505',13548,17001);
INSERT INTO "django_geo_db_zipcode" VALUES(19427,44506,-5,'Youngstown, Ohio 44506',13548,17002);
INSERT INTO "django_geo_db_zipcode" VALUES(19428,44507,-5,'Youngstown, Ohio 44507',13548,17003);
INSERT INTO "django_geo_db_zipcode" VALUES(19429,44509,-5,'Youngstown, Ohio 44509',13548,17004);
INSERT INTO "django_geo_db_zipcode" VALUES(19430,44510,-5,'Youngstown, Ohio 44510',13548,17005);
INSERT INTO "django_geo_db_zipcode" VALUES(19431,44511,-5,'Youngstown, Ohio 44511',13548,17006);
INSERT INTO "django_geo_db_zipcode" VALUES(19432,44512,-5,'Youngstown, Ohio 44512',13548,17007);
INSERT INTO "django_geo_db_zipcode" VALUES(19433,44513,-5,'Youngstown, Ohio 44513',13548,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19434,44514,-5,'Youngstown, Ohio 44514',13548,17008);
INSERT INTO "django_geo_db_zipcode" VALUES(19435,44515,-5,'Youngstown, Ohio 44515',13548,17009);
INSERT INTO "django_geo_db_zipcode" VALUES(19436,44555,-5,'Youngstown, Ohio 44555',13548,17010);
INSERT INTO "django_geo_db_zipcode" VALUES(19437,44598,-5,'Youngstown, Ohio 44598',13548,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19438,44599,-5,'Youngstown, Ohio 44599',13548,16954);
INSERT INTO "django_geo_db_zipcode" VALUES(19439,44601,-5,'Alliance, Ohio 44601',13549,17011);
INSERT INTO "django_geo_db_zipcode" VALUES(19440,44606,-5,'Apple Creek, Ohio 44606',13550,17012);
INSERT INTO "django_geo_db_zipcode" VALUES(19441,44607,-5,'Augusta, Ohio 44607',13551,17013);
INSERT INTO "django_geo_db_zipcode" VALUES(19442,44608,-5,'Beach City, Ohio 44608',13552,17014);
INSERT INTO "django_geo_db_zipcode" VALUES(19443,44609,-5,'Beloit, Ohio 44609',13553,17015);
INSERT INTO "django_geo_db_zipcode" VALUES(19444,44610,-5,'Berlin, Ohio 44610',13554,17016);
INSERT INTO "django_geo_db_zipcode" VALUES(19445,44611,-5,'Big Prairie, Ohio 44611',13555,17017);
INSERT INTO "django_geo_db_zipcode" VALUES(19446,44612,-5,'Bolivar, Ohio 44612',13556,17018);
INSERT INTO "django_geo_db_zipcode" VALUES(19447,44613,-5,'Brewster, Ohio 44613',13557,17019);
INSERT INTO "django_geo_db_zipcode" VALUES(19448,44614,-5,'Canal Fulton, Ohio 44614',13558,17020);
INSERT INTO "django_geo_db_zipcode" VALUES(19449,44615,-5,'Carrollton, Ohio 44615',13559,17021);
INSERT INTO "django_geo_db_zipcode" VALUES(19450,44617,-5,'Charm, Ohio 44617',13560,17022);
INSERT INTO "django_geo_db_zipcode" VALUES(19451,44618,-5,'Dalton, Ohio 44618',13448,17023);
INSERT INTO "django_geo_db_zipcode" VALUES(19452,44619,-5,'Damascus, Ohio 44619',13561,17024);
INSERT INTO "django_geo_db_zipcode" VALUES(19453,44620,-5,'Dellroy, Ohio 44620',13562,17025);
INSERT INTO "django_geo_db_zipcode" VALUES(19454,44621,-5,'Dennison, Ohio 44621',13563,17026);
INSERT INTO "django_geo_db_zipcode" VALUES(19455,44622,-5,'Dover, Ohio 44622',13564,17027);
INSERT INTO "django_geo_db_zipcode" VALUES(19456,44624,-5,'Dundee, Ohio 44624',13565,17028);
INSERT INTO "django_geo_db_zipcode" VALUES(19457,44625,-5,'East Rochester, Ohio 44625',13566,17029);
INSERT INTO "django_geo_db_zipcode" VALUES(19458,44626,-5,'East Sparta, Ohio 44626',13567,17030);
INSERT INTO "django_geo_db_zipcode" VALUES(19459,44627,-5,'Fredericksburg, Ohio 44627',13568,17031);
INSERT INTO "django_geo_db_zipcode" VALUES(19460,44628,-5,'Glenmont, Ohio 44628',13569,17032);
INSERT INTO "django_geo_db_zipcode" VALUES(19461,44629,-5,'Gnadenhutten, Ohio 44629',13570,17033);
INSERT INTO "django_geo_db_zipcode" VALUES(19462,44630,-5,'Greentown, Ohio 44630',13571,17034);
INSERT INTO "django_geo_db_zipcode" VALUES(19463,44631,-5,'Harlem Springs, Ohio 44631',13572,17035);
INSERT INTO "django_geo_db_zipcode" VALUES(19464,44632,-5,'Hartville, Ohio 44632',13573,17036);
INSERT INTO "django_geo_db_zipcode" VALUES(19465,44633,-5,'Holmesville, Ohio 44633',13574,17037);
INSERT INTO "django_geo_db_zipcode" VALUES(19466,44634,-5,'Homeworth, Ohio 44634',13575,17038);
INSERT INTO "django_geo_db_zipcode" VALUES(19467,44636,-5,'Kidron, Ohio 44636',13576,17039);
INSERT INTO "django_geo_db_zipcode" VALUES(19468,44637,-5,'Killbuck, Ohio 44637',13577,17040);
INSERT INTO "django_geo_db_zipcode" VALUES(19469,44638,-5,'Lakeville, Ohio 44638',13578,17041);
INSERT INTO "django_geo_db_zipcode" VALUES(19470,44639,-5,'Leesville, Ohio 44639',13579,17042);
INSERT INTO "django_geo_db_zipcode" VALUES(19471,44640,-5,'Limaville, Ohio 44640',13580,17043);
INSERT INTO "django_geo_db_zipcode" VALUES(19472,44641,-5,'Louisville, Ohio 44641',13581,17044);
INSERT INTO "django_geo_db_zipcode" VALUES(19473,44643,-5,'Magnolia, Ohio 44643',13582,17045);
INSERT INTO "django_geo_db_zipcode" VALUES(19474,44644,-5,'Malvern, Ohio 44644',13583,17046);
INSERT INTO "django_geo_db_zipcode" VALUES(19475,44645,-5,'Marshallville, Ohio 44645',13584,17047);
INSERT INTO "django_geo_db_zipcode" VALUES(19476,44646,-5,'Massillon, Ohio 44646',13585,17048);
INSERT INTO "django_geo_db_zipcode" VALUES(19477,44647,-5,'Massillon, Ohio 44647',13585,17049);
INSERT INTO "django_geo_db_zipcode" VALUES(19478,44648,-5,'Massillon, Ohio 44648',13585,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19479,44650,-5,'Maximo, Ohio 44650',13586,17051);
INSERT INTO "django_geo_db_zipcode" VALUES(19480,44651,-5,'Mechanicstown, Ohio 44651',13587,17052);
INSERT INTO "django_geo_db_zipcode" VALUES(19481,44652,-5,'Middlebranch, Ohio 44652',13588,17053);
INSERT INTO "django_geo_db_zipcode" VALUES(19482,44653,-5,'Midvale, Ohio 44653',13589,17054);
INSERT INTO "django_geo_db_zipcode" VALUES(19483,44654,-5,'Millersburg, Ohio 44654',13590,17055);
INSERT INTO "django_geo_db_zipcode" VALUES(19484,44656,-5,'Mineral City, Ohio 44656',13591,17056);
INSERT INTO "django_geo_db_zipcode" VALUES(19485,44657,-5,'Minerva, Ohio 44657',13592,17057);
INSERT INTO "django_geo_db_zipcode" VALUES(19486,44659,-5,'Mount Eaton, Ohio 44659',13593,17058);
INSERT INTO "django_geo_db_zipcode" VALUES(19487,44660,-5,'Mount Hope, Ohio 44660',13594,17059);
INSERT INTO "django_geo_db_zipcode" VALUES(19488,44661,-5,'Nashville, Ohio 44661',13595,17060);
INSERT INTO "django_geo_db_zipcode" VALUES(19489,44662,-5,'Navarre, Ohio 44662',13596,17061);
INSERT INTO "django_geo_db_zipcode" VALUES(19490,44663,-5,'New Philadelphia, Ohio 44663',13597,17062);
INSERT INTO "django_geo_db_zipcode" VALUES(19491,44665,-5,'North Georgetown, Ohio 44665',13598,17063);
INSERT INTO "django_geo_db_zipcode" VALUES(19492,44666,-5,'North Lawrence, Ohio 44666',13599,17064);
INSERT INTO "django_geo_db_zipcode" VALUES(19493,44667,-5,'Orrville, Ohio 44667',13600,17065);
INSERT INTO "django_geo_db_zipcode" VALUES(19494,44669,-5,'Paris, Ohio 44669',13601,17066);
INSERT INTO "django_geo_db_zipcode" VALUES(19495,44670,-5,'Robertsville, Ohio 44670',13602,17067);
INSERT INTO "django_geo_db_zipcode" VALUES(19496,44671,-5,'Sandyville, Ohio 44671',13603,17068);
INSERT INTO "django_geo_db_zipcode" VALUES(19497,44672,-5,'Sebring, Ohio 44672',13604,17069);
INSERT INTO "django_geo_db_zipcode" VALUES(19498,44675,-5,'Sherrodsville, Ohio 44675',13605,17070);
INSERT INTO "django_geo_db_zipcode" VALUES(19499,44676,-5,'Shreve, Ohio 44676',13606,17071);
INSERT INTO "django_geo_db_zipcode" VALUES(19500,44677,-5,'Smithville, Ohio 44677',13607,17072);
INSERT INTO "django_geo_db_zipcode" VALUES(19501,44678,-5,'Somerdale, Ohio 44678',13608,17073);
INSERT INTO "django_geo_db_zipcode" VALUES(19502,44679,-5,'Stillwater, Ohio 44679',13609,17074);
INSERT INTO "django_geo_db_zipcode" VALUES(19503,44680,-5,'Strasburg, Ohio 44680',13610,17075);
INSERT INTO "django_geo_db_zipcode" VALUES(19504,44681,-5,'Sugarcreek, Ohio 44681',13611,17076);
INSERT INTO "django_geo_db_zipcode" VALUES(19505,44682,-5,'Tuscarawas, Ohio 44682',13612,17077);
INSERT INTO "django_geo_db_zipcode" VALUES(19506,44683,-5,'Uhrichsville, Ohio 44683',13613,17078);
INSERT INTO "django_geo_db_zipcode" VALUES(19507,44684,-5,'Walnut Creek, Ohio 44684',13614,17079);
INSERT INTO "django_geo_db_zipcode" VALUES(19508,44685,-5,'Uniontown, Ohio 44685',13615,17080);
INSERT INTO "django_geo_db_zipcode" VALUES(19509,44687,-5,'Walnut Creek, Ohio 44687',13614,17081);
INSERT INTO "django_geo_db_zipcode" VALUES(19510,44688,-5,'Waynesburg, Ohio 44688',13616,17082);
INSERT INTO "django_geo_db_zipcode" VALUES(19511,44689,-5,'Wilmot, Ohio 44689',13617,17083);
INSERT INTO "django_geo_db_zipcode" VALUES(19512,44690,-5,'Winesburg, Ohio 44690',13618,17084);
INSERT INTO "django_geo_db_zipcode" VALUES(19513,44691,-5,'Wooster, Ohio 44691',13619,17085);
INSERT INTO "django_geo_db_zipcode" VALUES(19514,44692,-5,'Tuscarawas, Ohio 44692',13612,17086);
INSERT INTO "django_geo_db_zipcode" VALUES(19515,44693,-5,'Deersville, Ohio 44693',13620,17087);
INSERT INTO "django_geo_db_zipcode" VALUES(19516,44695,-5,'Bowerston, Ohio 44695',13621,17088);
INSERT INTO "django_geo_db_zipcode" VALUES(19517,44697,-5,'Zoar, Ohio 44697',13622,17089);
INSERT INTO "django_geo_db_zipcode" VALUES(19518,44699,-5,'Tippecanoe, Ohio 44699',13623,17090);
INSERT INTO "django_geo_db_zipcode" VALUES(19519,44701,-5,'Canton, Ohio 44701',13624,17091);
INSERT INTO "django_geo_db_zipcode" VALUES(19520,44702,-5,'Canton, Ohio 44702',13624,17092);
INSERT INTO "django_geo_db_zipcode" VALUES(19521,44703,-5,'Canton, Ohio 44703',13624,17093);
INSERT INTO "django_geo_db_zipcode" VALUES(19522,44704,-5,'Canton, Ohio 44704',13624,17094);
INSERT INTO "django_geo_db_zipcode" VALUES(19523,44705,-5,'Canton, Ohio 44705',13624,17095);
INSERT INTO "django_geo_db_zipcode" VALUES(19524,44706,-5,'Canton, Ohio 44706',13624,17096);
INSERT INTO "django_geo_db_zipcode" VALUES(19525,44707,-5,'Canton, Ohio 44707',13624,17097);
INSERT INTO "django_geo_db_zipcode" VALUES(19526,44708,-5,'Canton, Ohio 44708',13624,17098);
INSERT INTO "django_geo_db_zipcode" VALUES(19527,44709,-5,'Canton, Ohio 44709',13624,17099);
INSERT INTO "django_geo_db_zipcode" VALUES(19528,44710,-5,'Canton, Ohio 44710',13624,17100);
INSERT INTO "django_geo_db_zipcode" VALUES(19529,44711,-5,'Canton, Ohio 44711',13624,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19530,44712,-5,'Canton, Ohio 44712',13624,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19531,44714,-5,'Canton, Ohio 44714',13624,17101);
INSERT INTO "django_geo_db_zipcode" VALUES(19532,44718,-5,'Canton, Ohio 44718',13624,17102);
INSERT INTO "django_geo_db_zipcode" VALUES(19533,44720,-5,'Canton, Ohio 44720',13624,17103);
INSERT INTO "django_geo_db_zipcode" VALUES(19534,44721,-5,'Canton, Ohio 44721',13624,17104);
INSERT INTO "django_geo_db_zipcode" VALUES(19535,44730,-5,'Canton, Ohio 44730',13624,17105);
INSERT INTO "django_geo_db_zipcode" VALUES(19536,44735,-5,'Canton, Ohio 44735',13624,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19537,44750,-5,'Canton, Ohio 44750',13624,17106);
INSERT INTO "django_geo_db_zipcode" VALUES(19538,44760,-5,'Canton, Ohio 44760',13624,17107);
INSERT INTO "django_geo_db_zipcode" VALUES(19539,44767,-5,'Canton, Ohio 44767',13624,17108);
INSERT INTO "django_geo_db_zipcode" VALUES(19540,44798,-5,'Canton, Ohio 44798',13624,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19541,44799,-5,'Canton, Ohio 44799',13624,17050);
INSERT INTO "django_geo_db_zipcode" VALUES(19542,44801,-5,'Adrian, Ohio 44801',13625,17109);
INSERT INTO "django_geo_db_zipcode" VALUES(19543,44802,-5,'Alvada, Ohio 44802',13626,17110);
INSERT INTO "django_geo_db_zipcode" VALUES(19544,44803,-5,'Amsden, Ohio 44803',13627,17111);
INSERT INTO "django_geo_db_zipcode" VALUES(19545,44804,-5,'Arcadia, Ohio 44804',13628,17112);
INSERT INTO "django_geo_db_zipcode" VALUES(19546,44805,-5,'Ashland, Ohio 44805',13629,17113);
INSERT INTO "django_geo_db_zipcode" VALUES(19547,44807,-5,'Attica, Ohio 44807',13630,17114);
INSERT INTO "django_geo_db_zipcode" VALUES(19548,44809,-5,'Bascom, Ohio 44809',13631,17115);
INSERT INTO "django_geo_db_zipcode" VALUES(19549,44811,-5,'Bellevue, Ohio 44811',13632,17116);
INSERT INTO "django_geo_db_zipcode" VALUES(19550,44813,-5,'Bellville, Ohio 44813',13633,17117);
INSERT INTO "django_geo_db_zipcode" VALUES(19551,44814,-5,'Berlin Heights, Ohio 44814',13634,17118);
INSERT INTO "django_geo_db_zipcode" VALUES(19552,44815,-5,'Bettsville, Ohio 44815',13635,17119);
INSERT INTO "django_geo_db_zipcode" VALUES(19553,44816,-5,'Birmingham, Ohio 44816',13636,17120);
INSERT INTO "django_geo_db_zipcode" VALUES(19554,44817,-5,'Bloomdale, Ohio 44817',13637,17121);
INSERT INTO "django_geo_db_zipcode" VALUES(19555,44818,-5,'Bloomville, Ohio 44818',13638,17122);
INSERT INTO "django_geo_db_zipcode" VALUES(19556,44820,-5,'Bucyrus, Ohio 44820',13639,17123);
INSERT INTO "django_geo_db_zipcode" VALUES(19557,44822,-5,'Butler, Ohio 44822',13640,17124);
INSERT INTO "django_geo_db_zipcode" VALUES(19558,44824,-5,'Castalia, Ohio 44824',13641,17125);
INSERT INTO "django_geo_db_zipcode" VALUES(19559,44825,-5,'Chatfield, Ohio 44825',13642,17126);
INSERT INTO "django_geo_db_zipcode" VALUES(19560,44826,-5,'Collins, Ohio 44826',13643,17127);
INSERT INTO "django_geo_db_zipcode" VALUES(19561,44827,-5,'Crestline, Ohio 44827',13644,17128);
INSERT INTO "django_geo_db_zipcode" VALUES(19562,44828,-5,'Flat Rock, Ohio 44828',13645,17129);
INSERT INTO "django_geo_db_zipcode" VALUES(19563,44830,-5,'Fostoria, Ohio 44830',13646,17130);
INSERT INTO "django_geo_db_zipcode" VALUES(19564,44833,-5,'Galion, Ohio 44833',13647,17131);
INSERT INTO "django_geo_db_zipcode" VALUES(19565,44836,-5,'Green Springs, Ohio 44836',13648,17132);
INSERT INTO "django_geo_db_zipcode" VALUES(19566,44837,-5,'Greenwich, Ohio 44837',13649,17133);
INSERT INTO "django_geo_db_zipcode" VALUES(19567,44838,-5,'Hayesville, Ohio 44838',13650,17134);
INSERT INTO "django_geo_db_zipcode" VALUES(19568,44839,-5,'Huron, Ohio 44839',13651,17135);
INSERT INTO "django_geo_db_zipcode" VALUES(19569,44840,-5,'Jeromesville, Ohio 44840',13652,17136);
INSERT INTO "django_geo_db_zipcode" VALUES(19570,44841,-5,'Kansas, Ohio 44841',13653,17137);
INSERT INTO "django_geo_db_zipcode" VALUES(19571,44842,-5,'Loudonville, Ohio 44842',13654,17138);
INSERT INTO "django_geo_db_zipcode" VALUES(19572,44843,-5,'Lucas, Ohio 44843',13655,17139);
INSERT INTO "django_geo_db_zipcode" VALUES(19573,44844,-5,'McCutchenville, Ohio 44844',13656,17140);
INSERT INTO "django_geo_db_zipcode" VALUES(19574,44845,-5,'Melmore, Ohio 44845',13657,17141);
INSERT INTO "django_geo_db_zipcode" VALUES(19575,44846,-5,'Milan, Ohio 44846',13658,17142);
INSERT INTO "django_geo_db_zipcode" VALUES(19576,44847,-5,'Monroeville, Ohio 44847',13659,17143);
INSERT INTO "django_geo_db_zipcode" VALUES(19577,44848,-5,'Nankin, Ohio 44848',13660,17144);
INSERT INTO "django_geo_db_zipcode" VALUES(19578,44849,-5,'Nevada, Ohio 44849',13661,17145);
INSERT INTO "django_geo_db_zipcode" VALUES(19579,44850,-5,'New Haven, Ohio 44850',13662,17146);
INSERT INTO "django_geo_db_zipcode" VALUES(19580,44851,-5,'New London, Ohio 44851',13663,17147);
INSERT INTO "django_geo_db_zipcode" VALUES(19581,44853,-5,'New Riegel, Ohio 44853',13664,17148);
INSERT INTO "django_geo_db_zipcode" VALUES(19582,44854,-5,'New Washington, Ohio 44854',13665,17149);
INSERT INTO "django_geo_db_zipcode" VALUES(19583,44855,-5,'North Fairfield, Ohio 44855',13666,17150);
INSERT INTO "django_geo_db_zipcode" VALUES(19584,44856,-5,'North Robinson, Ohio 44856',13667,17151);
INSERT INTO "django_geo_db_zipcode" VALUES(19585,44857,-5,'Norwalk, Ohio 44857',13668,17152);
INSERT INTO "django_geo_db_zipcode" VALUES(19586,44858,-5,'Norwalk, Ohio 44858',13668,17153);
INSERT INTO "django_geo_db_zipcode" VALUES(19587,44859,-5,'Nova, Ohio 44859',13669,17154);
INSERT INTO "django_geo_db_zipcode" VALUES(19588,44860,-5,'Oceola, Ohio 44860',13670,17155);
INSERT INTO "django_geo_db_zipcode" VALUES(19589,44861,-5,'Old Fort, Ohio 44861',13671,17156);
INSERT INTO "django_geo_db_zipcode" VALUES(19590,44862,-5,'Ontario, Ohio 44862',13672,17157);
INSERT INTO "django_geo_db_zipcode" VALUES(19591,44864,-5,'Perrysville, Ohio 44864',13673,17158);
INSERT INTO "django_geo_db_zipcode" VALUES(19592,44865,-5,'Plymouth, Ohio 44865',13674,17159);
INSERT INTO "django_geo_db_zipcode" VALUES(19593,44866,-5,'Polk, Ohio 44866',13675,17160);
INSERT INTO "django_geo_db_zipcode" VALUES(19594,44867,-5,'Republic, Ohio 44867',13676,17161);
INSERT INTO "django_geo_db_zipcode" VALUES(19595,44870,-5,'Sandusky, Ohio 44870',13677,17162);
INSERT INTO "django_geo_db_zipcode" VALUES(19596,44871,-5,'Sandusky, Ohio 44871',13677,17163);
INSERT INTO "django_geo_db_zipcode" VALUES(19597,44874,-5,'Savannah, Ohio 44874',13678,17164);
INSERT INTO "django_geo_db_zipcode" VALUES(19598,44875,-5,'Shelby, Ohio 44875',13679,17165);
INSERT INTO "django_geo_db_zipcode" VALUES(19599,44878,-5,'Shiloh, Ohio 44878',13680,17166);
INSERT INTO "django_geo_db_zipcode" VALUES(19600,44880,-5,'Sullivan, Ohio 44880',13681,17167);
INSERT INTO "django_geo_db_zipcode" VALUES(19601,44881,-5,'Sulphur Springs, Ohio 44881',13682,17168);
INSERT INTO "django_geo_db_zipcode" VALUES(19602,44882,-5,'Sycamore, Ohio 44882',13683,17169);
INSERT INTO "django_geo_db_zipcode" VALUES(19603,44883,-5,'Tiffin, Ohio 44883',13227,17170);
INSERT INTO "django_geo_db_zipcode" VALUES(19604,44887,-5,'Tiro, Ohio 44887',13684,17171);
INSERT INTO "django_geo_db_zipcode" VALUES(19605,44888,-5,'Willard, Ohio 44888',13685,17172);
INSERT INTO "django_geo_db_zipcode" VALUES(19606,44889,-5,'Wakeman, Ohio 44889',13686,17173);
INSERT INTO "django_geo_db_zipcode" VALUES(19607,44890,-5,'Willard, Ohio 44890',13685,17174);
INSERT INTO "django_geo_db_zipcode" VALUES(19608,44901,-5,'Mansfield, Ohio 44901',13687,17175);
INSERT INTO "django_geo_db_zipcode" VALUES(19609,44902,-5,'Mansfield, Ohio 44902',13687,17176);
INSERT INTO "django_geo_db_zipcode" VALUES(19610,44903,-5,'Mansfield, Ohio 44903',13687,17177);
INSERT INTO "django_geo_db_zipcode" VALUES(19611,44904,-5,'Mansfield, Ohio 44904',13687,17178);
INSERT INTO "django_geo_db_zipcode" VALUES(19612,44905,-5,'Mansfield, Ohio 44905',13687,17179);
INSERT INTO "django_geo_db_zipcode" VALUES(19613,44906,-5,'Mansfield, Ohio 44906',13687,17180);
INSERT INTO "django_geo_db_zipcode" VALUES(19614,44907,-5,'Mansfield, Ohio 44907',13687,17181);
INSERT INTO "django_geo_db_zipcode" VALUES(19615,44999,-5,'Mansfield, Ohio 44999',13687,17157);
INSERT INTO "django_geo_db_zipcode" VALUES(19616,45000,-5,'North Bend, Ohio 45000',13688,17182);
INSERT INTO "django_geo_db_zipcode" VALUES(19617,45001,-5,'Addyston, Ohio 45001',13689,17183);
INSERT INTO "django_geo_db_zipcode" VALUES(19618,45002,-5,'Cleves, Ohio 45002',13690,17184);
INSERT INTO "django_geo_db_zipcode" VALUES(19619,45003,-5,'College Corner, Ohio 45003',13691,17185);
INSERT INTO "django_geo_db_zipcode" VALUES(19620,45004,-5,'Collinsville, Ohio 45004',13692,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19621,45005,-5,'Franklin, Ohio 45005',13693,17187);
INSERT INTO "django_geo_db_zipcode" VALUES(19622,45010,-5,'Catawba, Ohio 45010',12984,17188);
INSERT INTO "django_geo_db_zipcode" VALUES(19623,45011,-5,'Hamilton, Ohio 45011',13694,17189);
INSERT INTO "django_geo_db_zipcode" VALUES(19624,45012,-5,'Hamilton, Ohio 45012',13694,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19625,45013,-5,'Hamilton, Ohio 45013',13694,17190);
INSERT INTO "django_geo_db_zipcode" VALUES(19626,45014,-5,'Fairfield, Ohio 45014',13695,17191);
INSERT INTO "django_geo_db_zipcode" VALUES(19627,45015,-5,'Hamilton, Ohio 45015',13694,17192);
INSERT INTO "django_geo_db_zipcode" VALUES(19628,45018,-5,'Fairfield, Ohio 45018',13695,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19629,45020,-5,'Hamilton, Ohio 45020',13694,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19630,45023,-5,'Hamilton, Ohio 45023',13694,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19631,45025,-5,'Hamilton, Ohio 45025',13694,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19632,45026,-5,'Hamilton, Ohio 45026',13694,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19633,45030,-5,'Harrison, Ohio 45030',13696,17193);
INSERT INTO "django_geo_db_zipcode" VALUES(19634,45032,-5,'Harveysburg, Ohio 45032',13697,17194);
INSERT INTO "django_geo_db_zipcode" VALUES(19635,45033,-5,'Hooven, Ohio 45033',13698,17195);
INSERT INTO "django_geo_db_zipcode" VALUES(19636,45034,-5,'Kings Mills, Ohio 45034',13699,17196);
INSERT INTO "django_geo_db_zipcode" VALUES(19637,45036,-5,'Lebanon, Ohio 45036',13700,17197);
INSERT INTO "django_geo_db_zipcode" VALUES(19638,45039,-5,'Maineville, Ohio 45039',13701,17198);
INSERT INTO "django_geo_db_zipcode" VALUES(19639,45040,-5,'Mason, Ohio 45040',13702,17199);
INSERT INTO "django_geo_db_zipcode" VALUES(19640,45041,-5,'Miamitown, Ohio 45041',13703,17200);
INSERT INTO "django_geo_db_zipcode" VALUES(19641,45042,-5,'Middletown, Ohio 45042',13704,17201);
INSERT INTO "django_geo_db_zipcode" VALUES(19642,45043,-5,'Middletown, Ohio 45043',13704,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19643,45044,-5,'Middletown, Ohio 45044',13704,17202);
INSERT INTO "django_geo_db_zipcode" VALUES(19644,45050,-5,'Monroe, Ohio 45050',13705,17203);
INSERT INTO "django_geo_db_zipcode" VALUES(19645,45051,-5,'Mount Saint Joseph, Ohio 45051',13706,17204);
INSERT INTO "django_geo_db_zipcode" VALUES(19646,45052,-5,'North Bend, Ohio 45052',13688,17205);
INSERT INTO "django_geo_db_zipcode" VALUES(19647,45053,-5,'Okeana, Ohio 45053',13707,17206);
INSERT INTO "django_geo_db_zipcode" VALUES(19648,45054,-5,'Oregonia, Ohio 45054',13708,17207);
INSERT INTO "django_geo_db_zipcode" VALUES(19649,45055,-5,'Overpeck, Ohio 45055',13709,17208);
INSERT INTO "django_geo_db_zipcode" VALUES(19650,45056,-5,'Oxford, Ohio 45056',13710,17209);
INSERT INTO "django_geo_db_zipcode" VALUES(19651,45061,-5,'Ross, Ohio 45061',13711,17210);
INSERT INTO "django_geo_db_zipcode" VALUES(19652,45062,-5,'Seven Mile, Ohio 45062',13712,17211);
INSERT INTO "django_geo_db_zipcode" VALUES(19653,45063,-5,'Shandon, Ohio 45063',13713,17212);
INSERT INTO "django_geo_db_zipcode" VALUES(19654,45064,-5,'Somerville, Ohio 45064',13714,17213);
INSERT INTO "django_geo_db_zipcode" VALUES(19655,45065,-5,'South Lebanon, Ohio 45065',13715,17214);
INSERT INTO "django_geo_db_zipcode" VALUES(19656,45066,-5,'Springboro, Ohio 45066',13716,17215);
INSERT INTO "django_geo_db_zipcode" VALUES(19657,45067,-5,'Trenton, Ohio 45067',13717,17216);
INSERT INTO "django_geo_db_zipcode" VALUES(19658,45068,-5,'Waynesville, Ohio 45068',13718,17217);
INSERT INTO "django_geo_db_zipcode" VALUES(19659,45069,-5,'West Chester, Ohio 45069',13719,17218);
INSERT INTO "django_geo_db_zipcode" VALUES(19660,45070,-5,'West Elkton, Ohio 45070',13720,17219);
INSERT INTO "django_geo_db_zipcode" VALUES(19661,45071,-5,'West Chester, Ohio 45071',13719,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19662,45073,-5,'Monroe, Ohio 45073',13705,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19663,45099,-5,'Monroe, Ohio 45099',13705,17186);
INSERT INTO "django_geo_db_zipcode" VALUES(19664,45101,-5,'Aberdeen, Ohio 45101',13721,17220);
INSERT INTO "django_geo_db_zipcode" VALUES(19665,45102,-5,'Amelia, Ohio 45102',13722,17221);
INSERT INTO "django_geo_db_zipcode" VALUES(19666,45103,-5,'Batavia, Ohio 45103',13723,17222);
INSERT INTO "django_geo_db_zipcode" VALUES(19667,45105,-5,'Bentonville, Ohio 45105',13724,17223);
INSERT INTO "django_geo_db_zipcode" VALUES(19668,45106,-5,'Bethel, Ohio 45106',13725,17224);
INSERT INTO "django_geo_db_zipcode" VALUES(19669,45107,-5,'Blanchester, Ohio 45107',13726,17225);
INSERT INTO "django_geo_db_zipcode" VALUES(19670,45110,-5,'Buford, Ohio 45110',13727,17226);
INSERT INTO "django_geo_db_zipcode" VALUES(19671,45111,-5,'Camp Dennison, Ohio 45111',13728,17227);
INSERT INTO "django_geo_db_zipcode" VALUES(19672,45112,-5,'Chilo, Ohio 45112',13729,17228);
INSERT INTO "django_geo_db_zipcode" VALUES(19673,45113,-5,'Clarksville, Ohio 45113',13730,17229);
INSERT INTO "django_geo_db_zipcode" VALUES(19674,45114,-5,'Cuba, Ohio 45114',13731,17230);
INSERT INTO "django_geo_db_zipcode" VALUES(19675,45115,-5,'Decatur, Ohio 45115',13732,17231);
INSERT INTO "django_geo_db_zipcode" VALUES(19676,45118,-5,'Fayetteville, Ohio 45118',13733,17232);
INSERT INTO "django_geo_db_zipcode" VALUES(19677,45119,-5,'Feesburg, Ohio 45119',13734,17233);
INSERT INTO "django_geo_db_zipcode" VALUES(19678,45120,-5,'Felicity, Ohio 45120',13735,17234);
INSERT INTO "django_geo_db_zipcode" VALUES(19679,45121,-5,'Georgetown, Ohio 45121',13736,17235);
INSERT INTO "django_geo_db_zipcode" VALUES(19680,45122,-5,'Goshen, Ohio 45122',13737,17236);
INSERT INTO "django_geo_db_zipcode" VALUES(19681,45123,-5,'Greenfield, Ohio 45123',13738,17237);
INSERT INTO "django_geo_db_zipcode" VALUES(19682,45125,-5,'Union, Ohio 45125',13739,17238);
INSERT INTO "django_geo_db_zipcode" VALUES(19683,45127,-5,'Columbia, Ohio 45127',13740,17239);
INSERT INTO "django_geo_db_zipcode" VALUES(19684,45130,-5,'Hamersville, Ohio 45130',13741,17240);
INSERT INTO "django_geo_db_zipcode" VALUES(19685,45131,-5,'Higginsport, Ohio 45131',13742,17241);
INSERT INTO "django_geo_db_zipcode" VALUES(19686,45132,-5,'Highland, Ohio 45132',13743,17242);
INSERT INTO "django_geo_db_zipcode" VALUES(19687,45133,-5,'Hillsboro, Ohio 45133',13744,17243);
INSERT INTO "django_geo_db_zipcode" VALUES(19688,45135,-5,'Leesburg, Ohio 45135',13745,17244);
INSERT INTO "django_geo_db_zipcode" VALUES(19689,45138,-5,'Lees Creek, Ohio 45138',13746,17245);
INSERT INTO "django_geo_db_zipcode" VALUES(19690,45140,-5,'Loveland, Ohio 45140',13747,17246);
INSERT INTO "django_geo_db_zipcode" VALUES(19691,45142,-5,'Lynchburg, Ohio 45142',13748,17247);
INSERT INTO "django_geo_db_zipcode" VALUES(19692,45144,-5,'Manchester, Ohio 45144',13749,17248);
INSERT INTO "django_geo_db_zipcode" VALUES(19693,45145,-5,'Marathon, Ohio 45145',13750,17249);
INSERT INTO "django_geo_db_zipcode" VALUES(19694,45146,-5,'Martinsville, Ohio 45146',13751,17250);
INSERT INTO "django_geo_db_zipcode" VALUES(19695,45147,-5,'Miamiville, Ohio 45147',13752,17251);
INSERT INTO "django_geo_db_zipcode" VALUES(19696,45148,-5,'Midland, Ohio 45148',13753,17252);
INSERT INTO "django_geo_db_zipcode" VALUES(19697,45150,-5,'Milford, Ohio 45150',13754,17253);
INSERT INTO "django_geo_db_zipcode" VALUES(19698,45152,-5,'Morrow, Ohio 45152',13755,17254);
INSERT INTO "django_geo_db_zipcode" VALUES(19699,45153,-5,'Moscow, Ohio 45153',13756,17255);
INSERT INTO "django_geo_db_zipcode" VALUES(19700,45154,-5,'Mount Orab, Ohio 45154',13757,17256);
INSERT INTO "django_geo_db_zipcode" VALUES(19701,45155,-5,'Mowrystown, Ohio 45155',13758,17257);
INSERT INTO "django_geo_db_zipcode" VALUES(19702,45156,-5,'Neville, Ohio 45156',13759,17258);
INSERT INTO "django_geo_db_zipcode" VALUES(19703,45157,-5,'New Richmond, Ohio 45157',13760,17259);
INSERT INTO "django_geo_db_zipcode" VALUES(19704,45158,-5,'Newtonsville, Ohio 45158',13761,17260);
INSERT INTO "django_geo_db_zipcode" VALUES(19705,45159,-5,'New Vienna, Ohio 45159',13762,17261);
INSERT INTO "django_geo_db_zipcode" VALUES(19706,45160,-5,'Owensville, Ohio 45160',13763,17262);
INSERT INTO "django_geo_db_zipcode" VALUES(19707,45162,-5,'Pleasant Plain, Ohio 45162',13764,17263);
INSERT INTO "django_geo_db_zipcode" VALUES(19708,45164,-5,'Port William, Ohio 45164',13765,17264);
INSERT INTO "django_geo_db_zipcode" VALUES(19709,45165,-5,'Greenfield, Ohio 45165',13738,17265);
INSERT INTO "django_geo_db_zipcode" VALUES(19710,45166,-5,'Reesville, Ohio 45166',13766,17266);
INSERT INTO "django_geo_db_zipcode" VALUES(19711,45167,-5,'Ripley, Ohio 45167',13767,17267);
INSERT INTO "django_geo_db_zipcode" VALUES(19712,45168,-5,'Russellville, Ohio 45168',13768,17268);
INSERT INTO "django_geo_db_zipcode" VALUES(19713,45169,-5,'Sabina, Ohio 45169',13769,17269);
INSERT INTO "django_geo_db_zipcode" VALUES(19714,45171,-5,'Sardinia, Ohio 45171',13770,17270);
INSERT INTO "django_geo_db_zipcode" VALUES(19715,45172,-5,'Sinking Spring, Ohio 45172',13771,17271);
INSERT INTO "django_geo_db_zipcode" VALUES(19716,45174,-5,'Terrace Park, Ohio 45174',13772,17272);
INSERT INTO "django_geo_db_zipcode" VALUES(19717,45176,-5,'Williamsburg, Ohio 45176',13773,17273);
INSERT INTO "django_geo_db_zipcode" VALUES(19718,45177,-5,'Wilmington, Ohio 45177',13774,17274);
INSERT INTO "django_geo_db_zipcode" VALUES(19719,45201,-5,'Cincinnati, Ohio 45201',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19720,45202,-5,'Cincinnati, Ohio 45202',13775,17276);
INSERT INTO "django_geo_db_zipcode" VALUES(19721,45203,-5,'Cincinnati, Ohio 45203',13775,17277);
INSERT INTO "django_geo_db_zipcode" VALUES(19722,45204,-5,'Cincinnati, Ohio 45204',13775,17278);
INSERT INTO "django_geo_db_zipcode" VALUES(19723,45205,-5,'Cincinnati, Ohio 45205',13775,17279);
INSERT INTO "django_geo_db_zipcode" VALUES(19724,45206,-5,'Cincinnati, Ohio 45206',13775,17280);
INSERT INTO "django_geo_db_zipcode" VALUES(19725,45207,-5,'Cincinnati, Ohio 45207',13775,17281);
INSERT INTO "django_geo_db_zipcode" VALUES(19726,45208,-5,'Cincinnati, Ohio 45208',13775,17282);
INSERT INTO "django_geo_db_zipcode" VALUES(19727,45209,-5,'Cincinnati, Ohio 45209',13775,17283);
INSERT INTO "django_geo_db_zipcode" VALUES(19728,45210,-5,'Cincinnati, Ohio 45210',13775,17284);
INSERT INTO "django_geo_db_zipcode" VALUES(19729,45211,-5,'Cincinnati, Ohio 45211',13775,17285);
INSERT INTO "django_geo_db_zipcode" VALUES(19730,45212,-5,'Cincinnati, Ohio 45212',13775,17286);
INSERT INTO "django_geo_db_zipcode" VALUES(19731,45213,-5,'Cincinnati, Ohio 45213',13775,17287);
INSERT INTO "django_geo_db_zipcode" VALUES(19732,45214,-5,'Cincinnati, Ohio 45214',13775,17288);
INSERT INTO "django_geo_db_zipcode" VALUES(19733,45215,-5,'Cincinnati, Ohio 45215',13775,17289);
INSERT INTO "django_geo_db_zipcode" VALUES(19734,45216,-5,'Cincinnati, Ohio 45216',13775,17290);
INSERT INTO "django_geo_db_zipcode" VALUES(19735,45217,-5,'Cincinnati, Ohio 45217',13775,17291);
INSERT INTO "django_geo_db_zipcode" VALUES(19736,45218,-5,'Cincinnati, Ohio 45218',13775,17292);
INSERT INTO "django_geo_db_zipcode" VALUES(19737,45219,-5,'Cincinnati, Ohio 45219',13775,17293);
INSERT INTO "django_geo_db_zipcode" VALUES(19738,45220,-5,'Cincinnati, Ohio 45220',13775,17294);
INSERT INTO "django_geo_db_zipcode" VALUES(19739,45221,-5,'Cincinnati, Ohio 45221',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19740,45222,-5,'Cincinnati, Ohio 45222',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19741,45223,-5,'Cincinnati, Ohio 45223',13775,17295);
INSERT INTO "django_geo_db_zipcode" VALUES(19742,45224,-5,'Cincinnati, Ohio 45224',13775,17296);
INSERT INTO "django_geo_db_zipcode" VALUES(19743,45225,-5,'Cincinnati, Ohio 45225',13775,17297);
INSERT INTO "django_geo_db_zipcode" VALUES(19744,45226,-5,'Cincinnati, Ohio 45226',13775,17298);
INSERT INTO "django_geo_db_zipcode" VALUES(19745,45227,-5,'Cincinnati, Ohio 45227',13775,17299);
INSERT INTO "django_geo_db_zipcode" VALUES(19746,45228,-5,'Cincinnati, Ohio 45228',13775,17300);
INSERT INTO "django_geo_db_zipcode" VALUES(19747,45229,-5,'Cincinnati, Ohio 45229',13775,17301);
INSERT INTO "django_geo_db_zipcode" VALUES(19748,45230,-5,'Cincinnati, Ohio 45230',13775,17302);
INSERT INTO "django_geo_db_zipcode" VALUES(19749,45231,-5,'Cincinnati, Ohio 45231',13775,17303);
INSERT INTO "django_geo_db_zipcode" VALUES(19750,45232,-5,'Cincinnati, Ohio 45232',13775,17304);
INSERT INTO "django_geo_db_zipcode" VALUES(19751,45233,-5,'Cincinnati, Ohio 45233',13775,17305);
INSERT INTO "django_geo_db_zipcode" VALUES(19752,45234,-5,'Cincinnati, Ohio 45234',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19753,45235,-5,'Cincinnati, Ohio 45235',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19754,45236,-5,'Cincinnati, Ohio 45236',13775,17306);
INSERT INTO "django_geo_db_zipcode" VALUES(19755,45237,-5,'Cincinnati, Ohio 45237',13775,17307);
INSERT INTO "django_geo_db_zipcode" VALUES(19756,45238,-5,'Cincinnati, Ohio 45238',13775,17308);
INSERT INTO "django_geo_db_zipcode" VALUES(19757,45239,-5,'Cincinnati, Ohio 45239',13775,17309);
INSERT INTO "django_geo_db_zipcode" VALUES(19758,45240,-5,'Cincinnati, Ohio 45240',13775,17310);
INSERT INTO "django_geo_db_zipcode" VALUES(19759,45241,-5,'Cincinnati, Ohio 45241',13775,17311);
INSERT INTO "django_geo_db_zipcode" VALUES(19760,45242,-5,'Cincinnati, Ohio 45242',13775,17312);
INSERT INTO "django_geo_db_zipcode" VALUES(19761,45243,-5,'Cincinnati, Ohio 45243',13775,17313);
INSERT INTO "django_geo_db_zipcode" VALUES(19762,45244,-5,'Cincinnati, Ohio 45244',13775,17314);
INSERT INTO "django_geo_db_zipcode" VALUES(19763,45245,-5,'Cincinnati, Ohio 45245',13775,17315);
INSERT INTO "django_geo_db_zipcode" VALUES(19764,45246,-5,'Cincinnati, Ohio 45246',13775,17316);
INSERT INTO "django_geo_db_zipcode" VALUES(19765,45247,-5,'Cincinnati, Ohio 45247',13775,17317);
INSERT INTO "django_geo_db_zipcode" VALUES(19766,45248,-5,'Cincinnati, Ohio 45248',13775,17318);
INSERT INTO "django_geo_db_zipcode" VALUES(19767,45249,-5,'Cincinnati, Ohio 45249',13775,17319);
INSERT INTO "django_geo_db_zipcode" VALUES(19768,45250,-5,'Cincinnati, Ohio 45250',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19769,45251,-5,'Cincinnati, Ohio 45251',13775,17320);
INSERT INTO "django_geo_db_zipcode" VALUES(19770,45252,-5,'Cincinnati, Ohio 45252',13775,17321);
INSERT INTO "django_geo_db_zipcode" VALUES(19771,45253,-5,'Cincinnati, Ohio 45253',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19772,45254,-5,'Cincinnati, Ohio 45254',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19773,45255,-5,'Cincinnati, Ohio 45255',13775,17322);
INSERT INTO "django_geo_db_zipcode" VALUES(19774,45258,-5,'Cincinnati, Ohio 45258',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19775,45262,-5,'Cincinnati, Ohio 45262',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19776,45263,-5,'Cincinnati, Ohio 45263',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19777,45264,-5,'Cincinnati, Ohio 45264',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19778,45267,-5,'Cincinnati, Ohio 45267',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19779,45268,-5,'Cincinnati, Ohio 45268',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19780,45269,-5,'Cincinnati, Ohio 45269',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19781,45270,-5,'Cincinnati, Ohio 45270',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19782,45271,-5,'Cincinnati, Ohio 45271',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19783,45273,-5,'Cincinnati, Ohio 45273',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19784,45274,-5,'Cincinnati, Ohio 45274',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19785,45275,-5,'Cincinnati, Ohio 45275',13775,17323);
INSERT INTO "django_geo_db_zipcode" VALUES(19786,45277,-5,'Cincinnati, Ohio 45277',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19787,45296,-5,'Cincinnati, Ohio 45296',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19788,45298,-5,'Cincinnati, Ohio 45298',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(19789,45299,-5,'Cincinnati, Ohio 45299',13775,17324);
INSERT INTO "django_geo_db_zipcode" VALUES(19790,45301,-5,'Alpha, Ohio 45301',13776,17325);
INSERT INTO "django_geo_db_zipcode" VALUES(19791,45302,-5,'Anna, Ohio 45302',13777,17326);
INSERT INTO "django_geo_db_zipcode" VALUES(19792,45303,-5,'Ansonia, Ohio 45303',13778,17327);
INSERT INTO "django_geo_db_zipcode" VALUES(19793,45304,-5,'Arcanum, Ohio 45304',13779,17328);
INSERT INTO "django_geo_db_zipcode" VALUES(19794,45305,-5,'Bellbrook, Ohio 45305',13780,17329);
INSERT INTO "django_geo_db_zipcode" VALUES(19795,45306,-5,'Botkins, Ohio 45306',13781,17330);
INSERT INTO "django_geo_db_zipcode" VALUES(19796,45307,-5,'Bowersville, Ohio 45307',13782,17331);
INSERT INTO "django_geo_db_zipcode" VALUES(19797,45308,-5,'Bradford, Ohio 45308',13783,17332);
INSERT INTO "django_geo_db_zipcode" VALUES(19798,45309,-5,'Brookville, Ohio 45309',13784,17333);
INSERT INTO "django_geo_db_zipcode" VALUES(19799,45310,-5,'Burkettsville, Ohio 45310',13785,17334);
INSERT INTO "django_geo_db_zipcode" VALUES(19800,45311,-5,'Camden, Ohio 45311',13786,17335);
INSERT INTO "django_geo_db_zipcode" VALUES(19801,45312,-5,'Casstown, Ohio 45312',13787,17336);
INSERT INTO "django_geo_db_zipcode" VALUES(19802,45314,-5,'Cedarville, Ohio 45314',13788,17337);
INSERT INTO "django_geo_db_zipcode" VALUES(19803,45315,-5,'Clayton, Ohio 45315',13789,17338);
INSERT INTO "django_geo_db_zipcode" VALUES(19804,45316,-5,'Clifton, Ohio 45316',13790,17339);
INSERT INTO "django_geo_db_zipcode" VALUES(19805,45317,-5,'Conover, Ohio 45317',13791,17340);
INSERT INTO "django_geo_db_zipcode" VALUES(19806,45318,-5,'Covington, Ohio 45318',13792,17341);
INSERT INTO "django_geo_db_zipcode" VALUES(19807,45319,-5,'Donnelsville, Ohio 45319',13793,17342);
INSERT INTO "django_geo_db_zipcode" VALUES(19808,45320,-5,'Eaton, Ohio 45320',13794,17343);
INSERT INTO "django_geo_db_zipcode" VALUES(19809,45321,-5,'Eldorado, Ohio 45321',13795,17344);
INSERT INTO "django_geo_db_zipcode" VALUES(19810,45322,-5,'Englewood, Ohio 45322',13796,17345);
INSERT INTO "django_geo_db_zipcode" VALUES(19811,45323,-5,'Enon, Ohio 45323',13797,17346);
INSERT INTO "django_geo_db_zipcode" VALUES(19812,45324,-5,'Fairborn, Ohio 45324',13798,17347);
INSERT INTO "django_geo_db_zipcode" VALUES(19813,45325,-5,'Farmersville, Ohio 45325',13799,17348);
INSERT INTO "django_geo_db_zipcode" VALUES(19814,45326,-5,'Fletcher, Ohio 45326',13800,17349);
INSERT INTO "django_geo_db_zipcode" VALUES(19815,45327,-5,'Germantown, Ohio 45327',13801,17350);
INSERT INTO "django_geo_db_zipcode" VALUES(19816,45328,-5,'Gettysburg, Ohio 45328',13802,17351);
INSERT INTO "django_geo_db_zipcode" VALUES(19817,45329,-5,'Gordon, Ohio 45329',13803,17352);
INSERT INTO "django_geo_db_zipcode" VALUES(19818,45330,-5,'Gratis, Ohio 45330',13804,17353);
INSERT INTO "django_geo_db_zipcode" VALUES(19819,45331,-5,'Greenville, Ohio 45331',13805,17354);
INSERT INTO "django_geo_db_zipcode" VALUES(19820,45332,-5,'Hollansburg, Ohio 45332',13806,17355);
INSERT INTO "django_geo_db_zipcode" VALUES(19821,45333,-5,'Houston, Ohio 45333',13807,17356);
INSERT INTO "django_geo_db_zipcode" VALUES(19822,45334,-5,'Jackson Center, Ohio 45334',13808,17357);
INSERT INTO "django_geo_db_zipcode" VALUES(19823,45335,-5,'Jamestown, Ohio 45335',13809,17358);
INSERT INTO "django_geo_db_zipcode" VALUES(19824,45336,-5,'Kettlersville, Ohio 45336',13810,17359);
INSERT INTO "django_geo_db_zipcode" VALUES(19825,45337,-5,'Laura, Ohio 45337',13811,17360);
INSERT INTO "django_geo_db_zipcode" VALUES(19826,45338,-5,'Lewisburg, Ohio 45338',13812,17361);
INSERT INTO "django_geo_db_zipcode" VALUES(19827,45339,-5,'Ludlow Falls, Ohio 45339',13813,17362);
INSERT INTO "django_geo_db_zipcode" VALUES(19828,45340,-5,'Maplewood, Ohio 45340',13814,17363);
INSERT INTO "django_geo_db_zipcode" VALUES(19829,45341,-5,'Medway, Ohio 45341',13815,17364);
INSERT INTO "django_geo_db_zipcode" VALUES(19830,45342,-5,'Miamisburg, Ohio 45342',13816,17365);
INSERT INTO "django_geo_db_zipcode" VALUES(19831,45343,-5,'Miamisburg, Ohio 45343',13816,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19832,45344,-5,'New Carlisle, Ohio 45344',13817,17367);
INSERT INTO "django_geo_db_zipcode" VALUES(19833,45345,-5,'New Lebanon, Ohio 45345',13818,17368);
INSERT INTO "django_geo_db_zipcode" VALUES(19834,45346,-5,'New Madison, Ohio 45346',13819,17369);
INSERT INTO "django_geo_db_zipcode" VALUES(19835,45347,-5,'New Paris, Ohio 45347',13820,17370);
INSERT INTO "django_geo_db_zipcode" VALUES(19836,45348,-5,'New Weston, Ohio 45348',13821,17371);
INSERT INTO "django_geo_db_zipcode" VALUES(19837,45349,-5,'North Hampton, Ohio 45349',13822,17372);
INSERT INTO "django_geo_db_zipcode" VALUES(19838,45350,-5,'North Star, Ohio 45350',13823,17352);
INSERT INTO "django_geo_db_zipcode" VALUES(19839,45351,-5,'Osgood, Ohio 45351',13824,17373);
INSERT INTO "django_geo_db_zipcode" VALUES(19840,45352,-5,'Palestine, Ohio 45352',13825,17374);
INSERT INTO "django_geo_db_zipcode" VALUES(19841,45353,-5,'Pemberton, Ohio 45353',13826,17375);
INSERT INTO "django_geo_db_zipcode" VALUES(19842,45354,-5,'Phillipsburg, Ohio 45354',13827,17376);
INSERT INTO "django_geo_db_zipcode" VALUES(19843,45356,-5,'Piqua, Ohio 45356',13828,17377);
INSERT INTO "django_geo_db_zipcode" VALUES(19844,45358,-5,'Pitsburg, Ohio 45358',13829,17378);
INSERT INTO "django_geo_db_zipcode" VALUES(19845,45359,-5,'Pleasant Hill, Ohio 45359',13830,17379);
INSERT INTO "django_geo_db_zipcode" VALUES(19846,45360,-5,'Port Jefferson, Ohio 45360',13831,17380);
INSERT INTO "django_geo_db_zipcode" VALUES(19847,45361,-5,'Potsdam, Ohio 45361',13832,17381);
INSERT INTO "django_geo_db_zipcode" VALUES(19848,45362,-5,'Rossburg, Ohio 45362',13833,17382);
INSERT INTO "django_geo_db_zipcode" VALUES(19849,45363,-5,'Russia, Ohio 45363',13834,17383);
INSERT INTO "django_geo_db_zipcode" VALUES(19850,45365,-5,'Sidney, Ohio 45365',13835,17384);
INSERT INTO "django_geo_db_zipcode" VALUES(19851,45367,-5,'Sidney, Ohio 45367',13835,17385);
INSERT INTO "django_geo_db_zipcode" VALUES(19852,45368,-5,'South Charleston, Ohio 45368',13836,17386);
INSERT INTO "django_geo_db_zipcode" VALUES(19853,45369,-5,'South Vienna, Ohio 45369',13837,17387);
INSERT INTO "django_geo_db_zipcode" VALUES(19854,45370,-5,'Spring Valley, Ohio 45370',13838,17388);
INSERT INTO "django_geo_db_zipcode" VALUES(19855,45371,-5,'Tipp City, Ohio 45371',13839,17389);
INSERT INTO "django_geo_db_zipcode" VALUES(19856,45372,-5,'Tremont City, Ohio 45372',13840,17390);
INSERT INTO "django_geo_db_zipcode" VALUES(19857,45373,-5,'Troy, Ohio 45373',13841,17391);
INSERT INTO "django_geo_db_zipcode" VALUES(19858,45374,-5,'Troy, Ohio 45374',13841,17392);
INSERT INTO "django_geo_db_zipcode" VALUES(19859,45377,-5,'Vandalia, Ohio 45377',13842,17393);
INSERT INTO "django_geo_db_zipcode" VALUES(19860,45378,-5,'Verona, Ohio 45378',13843,17394);
INSERT INTO "django_geo_db_zipcode" VALUES(19861,45380,-5,'Versailles, Ohio 45380',13844,17395);
INSERT INTO "django_geo_db_zipcode" VALUES(19862,45381,-5,'West Alexandria, Ohio 45381',13845,17396);
INSERT INTO "django_geo_db_zipcode" VALUES(19863,45382,-5,'West Manchester, Ohio 45382',13846,17397);
INSERT INTO "django_geo_db_zipcode" VALUES(19864,45383,-5,'West Milton, Ohio 45383',13847,17398);
INSERT INTO "django_geo_db_zipcode" VALUES(19865,45384,-5,'Wilberforce, Ohio 45384',13848,17399);
INSERT INTO "django_geo_db_zipcode" VALUES(19866,45385,-5,'Xenia, Ohio 45385',13849,17400);
INSERT INTO "django_geo_db_zipcode" VALUES(19867,45387,-5,'Yellow Springs, Ohio 45387',13850,17401);
INSERT INTO "django_geo_db_zipcode" VALUES(19868,45388,-5,'Yorkshire, Ohio 45388',13851,17402);
INSERT INTO "django_geo_db_zipcode" VALUES(19869,45389,-5,'Christiansburg, Ohio 45389',13852,17403);
INSERT INTO "django_geo_db_zipcode" VALUES(19870,45390,-5,'Union City, Ohio 45390',13853,17404);
INSERT INTO "django_geo_db_zipcode" VALUES(19871,45401,-5,'Dayton, Ohio 45401',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19872,45402,-5,'Dayton, Ohio 45402',13854,17405);
INSERT INTO "django_geo_db_zipcode" VALUES(19873,45403,-5,'Dayton, Ohio 45403',13854,17406);
INSERT INTO "django_geo_db_zipcode" VALUES(19874,45404,-5,'Dayton, Ohio 45404',13854,17407);
INSERT INTO "django_geo_db_zipcode" VALUES(19875,45405,-5,'Dayton, Ohio 45405',13854,17408);
INSERT INTO "django_geo_db_zipcode" VALUES(19876,45406,-5,'Dayton, Ohio 45406',13854,17409);
INSERT INTO "django_geo_db_zipcode" VALUES(19877,45407,-5,'Dayton, Ohio 45407',13854,17410);
INSERT INTO "django_geo_db_zipcode" VALUES(19878,45408,-5,'Dayton, Ohio 45408',13854,17411);
INSERT INTO "django_geo_db_zipcode" VALUES(19879,45409,-5,'Dayton, Ohio 45409',13854,17412);
INSERT INTO "django_geo_db_zipcode" VALUES(19880,45410,-5,'Dayton, Ohio 45410',13854,17413);
INSERT INTO "django_geo_db_zipcode" VALUES(19881,45412,-5,'Dayton, Ohio 45412',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19882,45413,-5,'Dayton, Ohio 45413',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19883,45414,-5,'Dayton, Ohio 45414',13854,17414);
INSERT INTO "django_geo_db_zipcode" VALUES(19884,45415,-5,'Dayton, Ohio 45415',13854,17415);
INSERT INTO "django_geo_db_zipcode" VALUES(19885,45416,-5,'Dayton, Ohio 45416',13854,17416);
INSERT INTO "django_geo_db_zipcode" VALUES(19886,45417,-5,'Dayton, Ohio 45417',13854,17417);
INSERT INTO "django_geo_db_zipcode" VALUES(19887,45418,-5,'Dayton, Ohio 45418',13854,17418);
INSERT INTO "django_geo_db_zipcode" VALUES(19888,45419,-5,'Dayton, Ohio 45419',13854,17419);
INSERT INTO "django_geo_db_zipcode" VALUES(19889,45420,-5,'Dayton, Ohio 45420',13854,17420);
INSERT INTO "django_geo_db_zipcode" VALUES(19890,45422,-5,'Dayton, Ohio 45422',13854,17421);
INSERT INTO "django_geo_db_zipcode" VALUES(19891,45423,-5,'Dayton, Ohio 45423',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19892,45424,-5,'Dayton, Ohio 45424',13854,17422);
INSERT INTO "django_geo_db_zipcode" VALUES(19893,45426,-5,'Dayton, Ohio 45426',13854,17423);
INSERT INTO "django_geo_db_zipcode" VALUES(19894,45427,-5,'Dayton, Ohio 45427',13854,17424);
INSERT INTO "django_geo_db_zipcode" VALUES(19895,45428,-5,'Dayton, Ohio 45428',13854,17425);
INSERT INTO "django_geo_db_zipcode" VALUES(19896,45429,-5,'Dayton, Ohio 45429',13854,17426);
INSERT INTO "django_geo_db_zipcode" VALUES(19897,45430,-5,'Dayton, Ohio 45430',13854,17427);
INSERT INTO "django_geo_db_zipcode" VALUES(19898,45431,-5,'Dayton, Ohio 45431',13854,17428);
INSERT INTO "django_geo_db_zipcode" VALUES(19899,45432,-5,'Dayton, Ohio 45432',13854,17429);
INSERT INTO "django_geo_db_zipcode" VALUES(19900,45433,-5,'Dayton, Ohio 45433',13854,17430);
INSERT INTO "django_geo_db_zipcode" VALUES(19901,45434,-5,'Dayton, Ohio 45434',13854,17431);
INSERT INTO "django_geo_db_zipcode" VALUES(19902,45435,-5,'Dayton, Ohio 45435',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19903,45437,-5,'Dayton, Ohio 45437',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19904,45439,-5,'Dayton, Ohio 45439',13854,17432);
INSERT INTO "django_geo_db_zipcode" VALUES(19905,45440,-5,'Dayton, Ohio 45440',13854,17433);
INSERT INTO "django_geo_db_zipcode" VALUES(19906,45441,-5,'Dayton, Ohio 45441',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19907,45448,-5,'Dayton, Ohio 45448',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19908,45449,-5,'Dayton, Ohio 45449',13854,17434);
INSERT INTO "django_geo_db_zipcode" VALUES(19909,45454,-5,'Dayton, Ohio 45454',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19910,45458,-5,'Dayton, Ohio 45458',13854,17435);
INSERT INTO "django_geo_db_zipcode" VALUES(19911,45459,-5,'Dayton, Ohio 45459',13854,17436);
INSERT INTO "django_geo_db_zipcode" VALUES(19912,45463,-5,'Dayton, Ohio 45463',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19913,45469,-5,'Dayton, Ohio 45469',13854,17437);
INSERT INTO "django_geo_db_zipcode" VALUES(19914,45470,-5,'Dayton, Ohio 45470',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19915,45475,-5,'Dayton, Ohio 45475',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19916,45479,-5,'Dayton, Ohio 45479',13854,17438);
INSERT INTO "django_geo_db_zipcode" VALUES(19917,45481,-5,'Dayton, Ohio 45481',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19918,45482,-5,'Dayton, Ohio 45482',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19919,45490,-5,'Dayton, Ohio 45490',13854,17366);
INSERT INTO "django_geo_db_zipcode" VALUES(19920,45501,-5,'Springfield, Ohio 45501',13855,17439);
INSERT INTO "django_geo_db_zipcode" VALUES(19921,45502,-5,'Springfield, Ohio 45502',13855,17440);
INSERT INTO "django_geo_db_zipcode" VALUES(19922,45503,-5,'Springfield, Ohio 45503',13855,17441);
INSERT INTO "django_geo_db_zipcode" VALUES(19923,45504,-5,'Springfield, Ohio 45504',13855,17442);
INSERT INTO "django_geo_db_zipcode" VALUES(19924,45505,-5,'Springfield, Ohio 45505',13855,17443);
INSERT INTO "django_geo_db_zipcode" VALUES(19925,45506,-5,'Springfield, Ohio 45506',13855,17444);
INSERT INTO "django_geo_db_zipcode" VALUES(19926,45553,-5,'West Union, Ohio 45553',13856,17445);
INSERT INTO "django_geo_db_zipcode" VALUES(19927,45601,-5,'Chillicothe, Ohio 45601',13857,17446);
INSERT INTO "django_geo_db_zipcode" VALUES(19928,45612,-5,'Bainbridge, Ohio 45612',13858,17447);
INSERT INTO "django_geo_db_zipcode" VALUES(19929,45613,-5,'Beaver, Ohio 45613',13859,17448);
INSERT INTO "django_geo_db_zipcode" VALUES(19930,45614,-5,'Bidwell, Ohio 45614',13860,17449);
INSERT INTO "django_geo_db_zipcode" VALUES(19931,45616,-5,'Blue Creek, Ohio 45616',13861,17450);
INSERT INTO "django_geo_db_zipcode" VALUES(19932,45617,-5,'Bourneville, Ohio 45617',13862,17451);
INSERT INTO "django_geo_db_zipcode" VALUES(19933,45618,-5,'Cherry Fork, Ohio 45618',13863,17452);
INSERT INTO "django_geo_db_zipcode" VALUES(19934,45619,-5,'Chesapeake, Ohio 45619',13864,17453);
INSERT INTO "django_geo_db_zipcode" VALUES(19935,45620,-5,'Cheshire, Ohio 45620',13865,17454);
INSERT INTO "django_geo_db_zipcode" VALUES(19936,45621,-5,'Coalton, Ohio 45621',13866,17455);
INSERT INTO "django_geo_db_zipcode" VALUES(19937,45622,-5,'Creola, Ohio 45622',13867,17456);
INSERT INTO "django_geo_db_zipcode" VALUES(19938,45623,-5,'Crown City, Ohio 45623',13868,17457);
INSERT INTO "django_geo_db_zipcode" VALUES(19939,45624,-5,'Cynthiana, Ohio 45624',13869,17458);
INSERT INTO "django_geo_db_zipcode" VALUES(19940,45628,-5,'Frankfort, Ohio 45628',13870,17459);
INSERT INTO "django_geo_db_zipcode" VALUES(19941,45629,-5,'Franklin Furnace, Ohio 45629',13871,17460);
INSERT INTO "django_geo_db_zipcode" VALUES(19942,45630,-5,'Friendship, Ohio 45630',13872,17461);
INSERT INTO "django_geo_db_zipcode" VALUES(19943,45631,-5,'Gallipolis, Ohio 45631',13873,17462);
INSERT INTO "django_geo_db_zipcode" VALUES(19944,45633,-5,'Hallsville, Ohio 45633',13874,17463);
INSERT INTO "django_geo_db_zipcode" VALUES(19945,45634,-5,'Hamden, Ohio 45634',13875,17464);
INSERT INTO "django_geo_db_zipcode" VALUES(19946,45636,-5,'Haverhill, Ohio 45636',13876,17465);
INSERT INTO "django_geo_db_zipcode" VALUES(19947,45638,-5,'Ironton, Ohio 45638',13877,17466);
INSERT INTO "django_geo_db_zipcode" VALUES(19948,45640,-5,'Jackson, Ohio 45640',13878,17467);
INSERT INTO "django_geo_db_zipcode" VALUES(19949,45641,-5,'Morgan, Ohio 45641',13879,17468);
INSERT INTO "django_geo_db_zipcode" VALUES(19950,45642,-5,'Jasper, Ohio 45642',13880,17469);
INSERT INTO "django_geo_db_zipcode" VALUES(19951,45643,-5,'Kerr, Ohio 45643',13881,17470);
INSERT INTO "django_geo_db_zipcode" VALUES(19952,45644,-5,'Kingston, Ohio 45644',13882,17471);
INSERT INTO "django_geo_db_zipcode" VALUES(19953,45645,-5,'Kitts Hill, Ohio 45645',13883,17472);
INSERT INTO "django_geo_db_zipcode" VALUES(19954,45646,-5,'Latham, Ohio 45646',13884,17473);
INSERT INTO "django_geo_db_zipcode" VALUES(19955,45647,-5,'Londonderry, Ohio 45647',13885,17474);
INSERT INTO "django_geo_db_zipcode" VALUES(19956,45648,-5,'Lucasville, Ohio 45648',13886,17475);
INSERT INTO "django_geo_db_zipcode" VALUES(19957,45650,-5,'Lynx, Ohio 45650',13887,17476);
INSERT INTO "django_geo_db_zipcode" VALUES(19958,45651,-5,'McArthur, Ohio 45651',13888,17477);
INSERT INTO "django_geo_db_zipcode" VALUES(19959,45652,-5,'McDermott, Ohio 45652',13889,17478);
INSERT INTO "django_geo_db_zipcode" VALUES(19960,45653,-5,'Minford, Ohio 45653',13890,17479);
INSERT INTO "django_geo_db_zipcode" VALUES(19961,45654,-5,'New Plymouth, Ohio 45654',13891,17480);
INSERT INTO "django_geo_db_zipcode" VALUES(19962,45656,-5,'Oak Hill, Ohio 45656',13892,17481);
INSERT INTO "django_geo_db_zipcode" VALUES(19963,45657,-5,'Otway, Ohio 45657',13893,17482);
INSERT INTO "django_geo_db_zipcode" VALUES(19964,45658,-5,'Patriot, Ohio 45658',13894,17483);
INSERT INTO "django_geo_db_zipcode" VALUES(19965,45659,-5,'Pedro, Ohio 45659',13895,17484);
INSERT INTO "django_geo_db_zipcode" VALUES(19966,45660,-5,'Peebles, Ohio 45660',13896,17485);
INSERT INTO "django_geo_db_zipcode" VALUES(19967,45661,-5,'Piketon, Ohio 45661',13897,17486);
INSERT INTO "django_geo_db_zipcode" VALUES(19968,45662,-5,'Portsmouth, Ohio 45662',13898,17487);
INSERT INTO "django_geo_db_zipcode" VALUES(19969,45663,-5,'West Portsmouth, Ohio 45663',13899,17488);
INSERT INTO "django_geo_db_zipcode" VALUES(19970,45669,-5,'Proctorville, Ohio 45669',13900,17489);
INSERT INTO "django_geo_db_zipcode" VALUES(19971,45670,-5,'Wilkesville, Ohio 45670',13901,17490);
INSERT INTO "django_geo_db_zipcode" VALUES(19972,45671,-5,'Rarden, Ohio 45671',13902,17491);
INSERT INTO "django_geo_db_zipcode" VALUES(19973,45672,-5,'Ray, Ohio 45672',13903,17492);
INSERT INTO "django_geo_db_zipcode" VALUES(19974,45673,-5,'Richmond Dale, Ohio 45673',13904,17493);
INSERT INTO "django_geo_db_zipcode" VALUES(19975,45674,-5,'Rio Grande, Ohio 45674',13905,17494);
INSERT INTO "django_geo_db_zipcode" VALUES(19976,45675,-5,'Rock Camp, Ohio 45675',13906,17495);
INSERT INTO "django_geo_db_zipcode" VALUES(19977,45677,-5,'Scioto Furnace, Ohio 45677',13907,17496);
INSERT INTO "django_geo_db_zipcode" VALUES(19978,45678,-5,'Scottown, Ohio 45678',13908,17497);
INSERT INTO "django_geo_db_zipcode" VALUES(19979,45679,-5,'Seaman, Ohio 45679',13909,17498);
INSERT INTO "django_geo_db_zipcode" VALUES(19980,45680,-5,'South Point, Ohio 45680',13910,17499);
INSERT INTO "django_geo_db_zipcode" VALUES(19981,45681,-5,'South Salem, Ohio 45681',13911,17500);
INSERT INTO "django_geo_db_zipcode" VALUES(19982,45682,-5,'South Webster, Ohio 45682',13912,17501);
INSERT INTO "django_geo_db_zipcode" VALUES(19983,45683,-5,'Stockdale, Ohio 45683',13913,17502);
INSERT INTO "django_geo_db_zipcode" VALUES(19984,45684,-5,'Stout, Ohio 45684',13914,17503);
INSERT INTO "django_geo_db_zipcode" VALUES(19985,45685,-5,'Thurman, Ohio 45685',13915,17504);
INSERT INTO "django_geo_db_zipcode" VALUES(19986,45686,-5,'Vinton, Ohio 45686',13916,17505);
INSERT INTO "django_geo_db_zipcode" VALUES(19987,45687,-5,'Wakefield, Ohio 45687',13917,17506);
INSERT INTO "django_geo_db_zipcode" VALUES(19988,45688,-5,'Waterloo, Ohio 45688',13918,17507);
INSERT INTO "django_geo_db_zipcode" VALUES(19989,45690,-5,'Waverly, Ohio 45690',13919,17508);
INSERT INTO "django_geo_db_zipcode" VALUES(19990,45692,-5,'Wellston, Ohio 45692',13920,17509);
INSERT INTO "django_geo_db_zipcode" VALUES(19991,45693,-5,'West Union, Ohio 45693',13856,17510);
INSERT INTO "django_geo_db_zipcode" VALUES(19992,45694,-5,'Wheelersburg, Ohio 45694',13921,17511);
INSERT INTO "django_geo_db_zipcode" VALUES(19993,45695,-5,'Wilkesville, Ohio 45695',13901,17512);
INSERT INTO "django_geo_db_zipcode" VALUES(19994,45696,-5,'Willow Wood, Ohio 45696',13922,17513);
INSERT INTO "django_geo_db_zipcode" VALUES(19995,45697,-5,'Winchester, Ohio 45697',13923,17514);
INSERT INTO "django_geo_db_zipcode" VALUES(19996,45698,-5,'Zaleski, Ohio 45698',13924,17515);
INSERT INTO "django_geo_db_zipcode" VALUES(19997,45699,-5,'Lucasville, Ohio 45699',13886,17461);
INSERT INTO "django_geo_db_zipcode" VALUES(19998,45701,-5,'Athens, Ohio 45701',13925,17516);
INSERT INTO "django_geo_db_zipcode" VALUES(19999,45710,-5,'Albany, Ohio 45710',13926,17517);
INSERT INTO "django_geo_db_zipcode" VALUES(20000,45711,-5,'Amesville, Ohio 45711',13927,17518);
INSERT INTO "django_geo_db_zipcode" VALUES(20001,45712,-5,'Barlow, Ohio 45712',13928,17519);
INSERT INTO "django_geo_db_zipcode" VALUES(20002,45713,-5,'Bartlett, Ohio 45713',13929,17520);
INSERT INTO "django_geo_db_zipcode" VALUES(20003,45714,-5,'Belpre, Ohio 45714',13930,17521);
INSERT INTO "django_geo_db_zipcode" VALUES(20004,45715,-5,'Beverly, Ohio 45715',13931,17522);
INSERT INTO "django_geo_db_zipcode" VALUES(20005,45716,-5,'Buchtel, Ohio 45716',13932,17523);
INSERT INTO "django_geo_db_zipcode" VALUES(20006,45717,-5,'Carbondale, Ohio 45717',13933,17524);
INSERT INTO "django_geo_db_zipcode" VALUES(20007,45719,-5,'Chauncey, Ohio 45719',13934,17525);
INSERT INTO "django_geo_db_zipcode" VALUES(20008,45720,-5,'Chester, Ohio 45720',13935,17526);
INSERT INTO "django_geo_db_zipcode" VALUES(20009,45721,-5,'Coal Run, Ohio 45721',13936,17527);
INSERT INTO "django_geo_db_zipcode" VALUES(20010,45723,-5,'Coolville, Ohio 45723',13937,17528);
INSERT INTO "django_geo_db_zipcode" VALUES(20011,45724,-5,'Cutler, Ohio 45724',13938,17529);
INSERT INTO "django_geo_db_zipcode" VALUES(20012,45727,-5,'Dexter City, Ohio 45727',13939,17530);
INSERT INTO "django_geo_db_zipcode" VALUES(20013,45729,-5,'Fleming, Ohio 45729',13940,17531);
INSERT INTO "django_geo_db_zipcode" VALUES(20014,45732,-5,'Glouster, Ohio 45732',13941,17532);
INSERT INTO "django_geo_db_zipcode" VALUES(20015,45734,-5,'Graysville, Ohio 45734',13942,17533);
INSERT INTO "django_geo_db_zipcode" VALUES(20016,45735,-5,'Guysville, Ohio 45735',13943,17534);
INSERT INTO "django_geo_db_zipcode" VALUES(20017,45739,-5,'Hockingport, Ohio 45739',13944,17535);
INSERT INTO "django_geo_db_zipcode" VALUES(20018,45740,-5,'Jacksonville, Ohio 45740',13945,17536);
INSERT INTO "django_geo_db_zipcode" VALUES(20019,45741,-5,'Langsville, Ohio 45741',13946,17537);
INSERT INTO "django_geo_db_zipcode" VALUES(20020,45742,-5,'Little Hocking, Ohio 45742',13947,17538);
INSERT INTO "django_geo_db_zipcode" VALUES(20021,45743,-5,'Long Bottom, Ohio 45743',13948,17539);
INSERT INTO "django_geo_db_zipcode" VALUES(20022,45744,-5,'Lowell, Ohio 45744',13949,17540);
INSERT INTO "django_geo_db_zipcode" VALUES(20023,45745,-5,'Lower Salem, Ohio 45745',13950,17541);
INSERT INTO "django_geo_db_zipcode" VALUES(20024,45746,-5,'Macksburg, Ohio 45746',13951,17542);
INSERT INTO "django_geo_db_zipcode" VALUES(20025,45750,-5,'Marietta, Ohio 45750',13952,17543);
INSERT INTO "django_geo_db_zipcode" VALUES(20026,45757,-5,'Dexter City, Ohio 45757',13939,17544);
INSERT INTO "django_geo_db_zipcode" VALUES(20027,45760,-5,'Middleport, Ohio 45760',13953,17545);
INSERT INTO "django_geo_db_zipcode" VALUES(20028,45761,-5,'Millfield, Ohio 45761',13954,17546);
INSERT INTO "django_geo_db_zipcode" VALUES(20029,45764,-5,'Nelsonville, Ohio 45764',13955,17547);
INSERT INTO "django_geo_db_zipcode" VALUES(20030,45766,-5,'New Marshfield, Ohio 45766',13956,17548);
INSERT INTO "django_geo_db_zipcode" VALUES(20031,45767,-5,'New Matamoras, Ohio 45767',13957,17549);
INSERT INTO "django_geo_db_zipcode" VALUES(20032,45768,-5,'Newport, Ohio 45768',13958,17550);
INSERT INTO "django_geo_db_zipcode" VALUES(20033,45769,-5,'Pomeroy, Ohio 45769',13959,17551);
INSERT INTO "django_geo_db_zipcode" VALUES(20034,45770,-5,'Portland, Ohio 45770',13960,17552);
INSERT INTO "django_geo_db_zipcode" VALUES(20035,45771,-5,'Racine, Ohio 45771',13961,17553);
INSERT INTO "django_geo_db_zipcode" VALUES(20036,45772,-5,'Reedsville, Ohio 45772',13962,17554);
INSERT INTO "django_geo_db_zipcode" VALUES(20037,45773,-5,'Reno, Ohio 45773',13963,17555);
INSERT INTO "django_geo_db_zipcode" VALUES(20038,45775,-5,'Rutland, Ohio 45775',13964,17556);
INSERT INTO "django_geo_db_zipcode" VALUES(20039,45776,-5,'Shade, Ohio 45776',13965,17557);
INSERT INTO "django_geo_db_zipcode" VALUES(20040,45777,-5,'Sharpsburg, Ohio 45777',13966,17524);
INSERT INTO "django_geo_db_zipcode" VALUES(20041,45778,-5,'Stewart, Ohio 45778',13967,17558);
INSERT INTO "django_geo_db_zipcode" VALUES(20042,45779,-5,'Syracuse, Ohio 45779',13968,17559);
INSERT INTO "django_geo_db_zipcode" VALUES(20043,45780,-5,'The Plains, Ohio 45780',13969,17560);
INSERT INTO "django_geo_db_zipcode" VALUES(20044,45781,-5,'Torch, Ohio 45781',13970,17524);
INSERT INTO "django_geo_db_zipcode" VALUES(20045,45782,-5,'Trimble, Ohio 45782',13971,17561);
INSERT INTO "django_geo_db_zipcode" VALUES(20046,45783,-5,'Tuppers Plains, Ohio 45783',13972,17562);
INSERT INTO "django_geo_db_zipcode" VALUES(20047,45784,-5,'Vincent, Ohio 45784',13973,17563);
INSERT INTO "django_geo_db_zipcode" VALUES(20048,45786,-5,'Waterford, Ohio 45786',13974,17564);
INSERT INTO "django_geo_db_zipcode" VALUES(20049,45787,-5,'Watertown, Ohio 45787',13975,17527);
INSERT INTO "django_geo_db_zipcode" VALUES(20050,45788,-5,'Whipple, Ohio 45788',13976,17565);
INSERT INTO "django_geo_db_zipcode" VALUES(20051,45789,-5,'Wingett Run, Ohio 45789',13977,17566);
INSERT INTO "django_geo_db_zipcode" VALUES(20052,45801,-5,'Lima, Ohio 45801',13978,17567);
INSERT INTO "django_geo_db_zipcode" VALUES(20053,45802,-5,'Lima, Ohio 45802',13978,17568);
INSERT INTO "django_geo_db_zipcode" VALUES(20054,45804,-5,'Lima, Ohio 45804',13978,17569);
INSERT INTO "django_geo_db_zipcode" VALUES(20055,45805,-5,'Lima, Ohio 45805',13978,17570);
INSERT INTO "django_geo_db_zipcode" VALUES(20056,45806,-5,'Lima, Ohio 45806',13978,17571);
INSERT INTO "django_geo_db_zipcode" VALUES(20057,45807,-5,'Lima, Ohio 45807',13978,17572);
INSERT INTO "django_geo_db_zipcode" VALUES(20058,45808,-5,'Beaverdam, Ohio 45808',13979,17573);
INSERT INTO "django_geo_db_zipcode" VALUES(20059,45809,-5,'Gomer, Ohio 45809',13980,17574);
INSERT INTO "django_geo_db_zipcode" VALUES(20060,45810,-5,'Ada, Ohio 45810',13981,17575);
INSERT INTO "django_geo_db_zipcode" VALUES(20061,45812,-5,'Alger, Ohio 45812',13982,17576);
INSERT INTO "django_geo_db_zipcode" VALUES(20062,45813,-5,'Antwerp, Ohio 45813',13983,17577);
INSERT INTO "django_geo_db_zipcode" VALUES(20063,45814,-5,'Arlington, Ohio 45814',13984,17578);
INSERT INTO "django_geo_db_zipcode" VALUES(20064,45815,-5,'Belmore, Ohio 45815',13985,17579);
INSERT INTO "django_geo_db_zipcode" VALUES(20065,45816,-5,'Benton Ridge, Ohio 45816',13986,17580);
INSERT INTO "django_geo_db_zipcode" VALUES(20066,45817,-5,'Bluffton, Ohio 45817',13987,17581);
INSERT INTO "django_geo_db_zipcode" VALUES(20067,45819,-5,'Buckland, Ohio 45819',13988,17582);
INSERT INTO "django_geo_db_zipcode" VALUES(20068,45820,-5,'Cairo, Ohio 45820',13989,17583);
INSERT INTO "django_geo_db_zipcode" VALUES(20069,45821,-5,'Cecil, Ohio 45821',13990,17584);
INSERT INTO "django_geo_db_zipcode" VALUES(20070,45822,-5,'Celina, Ohio 45822',13991,17585);
INSERT INTO "django_geo_db_zipcode" VALUES(20071,45826,-5,'Chickasaw, Ohio 45826',13992,17586);
INSERT INTO "django_geo_db_zipcode" VALUES(20072,45827,-5,'Cloverdale, Ohio 45827',13993,17587);
INSERT INTO "django_geo_db_zipcode" VALUES(20073,45828,-5,'Coldwater, Ohio 45828',13994,17588);
INSERT INTO "django_geo_db_zipcode" VALUES(20074,45829,-5,'Crane, Ohio 45829',13995,17589);
INSERT INTO "django_geo_db_zipcode" VALUES(20075,45830,-5,'Columbus Grove, Ohio 45830',13996,17590);
INSERT INTO "django_geo_db_zipcode" VALUES(20076,45831,-5,'Continental, Ohio 45831',13997,17591);
INSERT INTO "django_geo_db_zipcode" VALUES(20077,45832,-5,'Convoy, Ohio 45832',13998,17592);
INSERT INTO "django_geo_db_zipcode" VALUES(20078,45833,-5,'Delphos, Ohio 45833',13999,17593);
INSERT INTO "django_geo_db_zipcode" VALUES(20079,45835,-5,'Dola, Ohio 45835',14000,17594);
INSERT INTO "django_geo_db_zipcode" VALUES(20080,45836,-5,'Dunkirk, Ohio 45836',14001,17595);
INSERT INTO "django_geo_db_zipcode" VALUES(20081,45837,-5,'Dupont, Ohio 45837',14002,17596);
INSERT INTO "django_geo_db_zipcode" VALUES(20082,45838,-5,'Elgin, Ohio 45838',14003,17597);
INSERT INTO "django_geo_db_zipcode" VALUES(20083,45839,-5,'Findlay, Ohio 45839',14004,17598);
INSERT INTO "django_geo_db_zipcode" VALUES(20084,45840,-5,'Findlay, Ohio 45840',14004,17599);
INSERT INTO "django_geo_db_zipcode" VALUES(20085,45841,-5,'Jenera, Ohio 45841',14005,17600);
INSERT INTO "django_geo_db_zipcode" VALUES(20086,45843,-5,'Forest, Ohio 45843',14006,17601);
INSERT INTO "django_geo_db_zipcode" VALUES(20087,45844,-5,'Fort Jennings, Ohio 45844',14007,17602);
INSERT INTO "django_geo_db_zipcode" VALUES(20088,45845,-5,'Fort Loramie, Ohio 45845',14008,17603);
INSERT INTO "django_geo_db_zipcode" VALUES(20089,45846,-5,'Fort Recovery, Ohio 45846',14009,17604);
INSERT INTO "django_geo_db_zipcode" VALUES(20090,45848,-5,'Glandorf, Ohio 45848',14010,17605);
INSERT INTO "django_geo_db_zipcode" VALUES(20091,45849,-5,'Grover Hill, Ohio 45849',14011,17606);
INSERT INTO "django_geo_db_zipcode" VALUES(20092,45850,-5,'Harrod, Ohio 45850',14012,17607);
INSERT INTO "django_geo_db_zipcode" VALUES(20093,45851,-5,'Haviland, Ohio 45851',14013,17608);
INSERT INTO "django_geo_db_zipcode" VALUES(20094,45853,-5,'Kalida, Ohio 45853',14014,17609);
INSERT INTO "django_geo_db_zipcode" VALUES(20095,45854,-5,'Lafayette, Ohio 45854',14015,17610);
INSERT INTO "django_geo_db_zipcode" VALUES(20096,45855,-5,'Latty, Ohio 45855',14016,17611);
INSERT INTO "django_geo_db_zipcode" VALUES(20097,45856,-5,'Leipsic, Ohio 45856',14017,17612);
INSERT INTO "django_geo_db_zipcode" VALUES(20098,45858,-5,'McComb, Ohio 45858',14018,17613);
INSERT INTO "django_geo_db_zipcode" VALUES(20099,45859,-5,'McGuffey, Ohio 45859',14019,17614);
INSERT INTO "django_geo_db_zipcode" VALUES(20100,45860,-5,'Maria Stein, Ohio 45860',14020,17615);
INSERT INTO "django_geo_db_zipcode" VALUES(20101,45861,-5,'Melrose, Ohio 45861',14021,17616);
INSERT INTO "django_geo_db_zipcode" VALUES(20102,45862,-5,'Mendon, Ohio 45862',14022,17617);
INSERT INTO "django_geo_db_zipcode" VALUES(20103,45863,-5,'Middle Point, Ohio 45863',14023,17618);
INSERT INTO "django_geo_db_zipcode" VALUES(20104,45864,-5,'Miller City, Ohio 45864',14024,17619);
INSERT INTO "django_geo_db_zipcode" VALUES(20105,45865,-5,'Minster, Ohio 45865',14025,17620);
INSERT INTO "django_geo_db_zipcode" VALUES(20106,45866,-5,'Montezuma, Ohio 45866',14026,17621);
INSERT INTO "django_geo_db_zipcode" VALUES(20107,45867,-5,'Mount Blanchard, Ohio 45867',14027,17622);
INSERT INTO "django_geo_db_zipcode" VALUES(20108,45868,-5,'Mount Cory, Ohio 45868',14028,17623);
INSERT INTO "django_geo_db_zipcode" VALUES(20109,45869,-5,'New Bremen, Ohio 45869',14029,17624);
INSERT INTO "django_geo_db_zipcode" VALUES(20110,45870,-5,'New Hampshire, Ohio 45870',14030,17625);
INSERT INTO "django_geo_db_zipcode" VALUES(20111,45871,-5,'New Knoxville, Ohio 45871',14031,17626);
INSERT INTO "django_geo_db_zipcode" VALUES(20112,45872,-5,'North Baltimore, Ohio 45872',14032,17627);
INSERT INTO "django_geo_db_zipcode" VALUES(20113,45873,-5,'Oakwood, Ohio 45873',14033,17628);
INSERT INTO "django_geo_db_zipcode" VALUES(20114,45874,-5,'Ohio City, Ohio 45874',14034,17629);
INSERT INTO "django_geo_db_zipcode" VALUES(20115,45875,-5,'Ottawa, Ohio 45875',14035,17630);
INSERT INTO "django_geo_db_zipcode" VALUES(20116,45876,-5,'Ottoville, Ohio 45876',14036,17631);
INSERT INTO "django_geo_db_zipcode" VALUES(20117,45877,-5,'Pandora, Ohio 45877',14037,17632);
INSERT INTO "django_geo_db_zipcode" VALUES(20118,45879,-5,'Paulding, Ohio 45879',14038,17633);
INSERT INTO "django_geo_db_zipcode" VALUES(20119,45880,-5,'Payne, Ohio 45880',14039,17634);
INSERT INTO "django_geo_db_zipcode" VALUES(20120,45881,-5,'Rawson, Ohio 45881',14040,17635);
INSERT INTO "django_geo_db_zipcode" VALUES(20121,45882,-5,'Rockford, Ohio 45882',14041,17636);
INSERT INTO "django_geo_db_zipcode" VALUES(20122,45883,-5,'Saint Henry, Ohio 45883',14042,17637);
INSERT INTO "django_geo_db_zipcode" VALUES(20123,45884,-5,'Saint Johns, Ohio 45884',14043,17638);
INSERT INTO "django_geo_db_zipcode" VALUES(20124,45885,-5,'Saint Marys, Ohio 45885',14044,17639);
INSERT INTO "django_geo_db_zipcode" VALUES(20125,45886,-5,'Scott, Ohio 45886',14045,17640);
INSERT INTO "django_geo_db_zipcode" VALUES(20126,45887,-5,'Spencerville, Ohio 45887',14046,17641);
INSERT INTO "django_geo_db_zipcode" VALUES(20127,45888,-5,'Uniopolis, Ohio 45888',14047,17642);
INSERT INTO "django_geo_db_zipcode" VALUES(20128,45889,-5,'Van Buren, Ohio 45889',14048,17643);
INSERT INTO "django_geo_db_zipcode" VALUES(20129,45890,-5,'Vanlue, Ohio 45890',14049,17644);
INSERT INTO "django_geo_db_zipcode" VALUES(20130,45891,-5,'Van Wert, Ohio 45891',14050,17645);
INSERT INTO "django_geo_db_zipcode" VALUES(20131,45893,-5,'Vaughnsville, Ohio 45893',14051,17646);
INSERT INTO "django_geo_db_zipcode" VALUES(20132,45894,-5,'Venedocia, Ohio 45894',14052,17647);
INSERT INTO "django_geo_db_zipcode" VALUES(20133,45895,-5,'Wapakoneta, Ohio 45895',14053,17648);
INSERT INTO "django_geo_db_zipcode" VALUES(20134,45896,-5,'Waynesfield, Ohio 45896',14054,17649);
INSERT INTO "django_geo_db_zipcode" VALUES(20135,45897,-5,'Williamstown, Ohio 45897',14055,17650);
INSERT INTO "django_geo_db_zipcode" VALUES(20136,45898,-5,'Willshire, Ohio 45898',14056,17651);
INSERT INTO "django_geo_db_zipcode" VALUES(20137,45899,-5,'Wren, Ohio 45899',14057,17652);
INSERT INTO "django_geo_db_zipcode" VALUES(20138,45944,-5,'Cincinnati, Ohio 45944',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(20139,45999,-5,'Cincinnati, Ohio 45999',13775,17275);
INSERT INTO "django_geo_db_zipcode" VALUES(20140,46001,-5,'Alexandria, Indiana 46001',14058,17653);
INSERT INTO "django_geo_db_zipcode" VALUES(20141,46011,-5,'Anderson, Indiana 46011',14059,17654);
INSERT INTO "django_geo_db_zipcode" VALUES(20142,46012,-5,'Anderson, Indiana 46012',14059,17655);
INSERT INTO "django_geo_db_zipcode" VALUES(20143,46013,-5,'Anderson, Indiana 46013',14059,17656);
INSERT INTO "django_geo_db_zipcode" VALUES(20144,46014,-5,'Anderson, Indiana 46014',14059,17657);
INSERT INTO "django_geo_db_zipcode" VALUES(20145,46015,-5,'Anderson, Indiana 46015',14059,17658);
INSERT INTO "django_geo_db_zipcode" VALUES(20146,46016,-5,'Anderson, Indiana 46016',14059,17659);
INSERT INTO "django_geo_db_zipcode" VALUES(20147,46017,-5,'Anderson, Indiana 46017',14059,17660);
INSERT INTO "django_geo_db_zipcode" VALUES(20148,46018,-5,'Anderson, Indiana 46018',14059,17657);
INSERT INTO "django_geo_db_zipcode" VALUES(20149,46030,-5,'Arcadia, Indiana 46030',14060,17661);
INSERT INTO "django_geo_db_zipcode" VALUES(20150,46031,-5,'Atlanta, Indiana 46031',14061,17662);
INSERT INTO "django_geo_db_zipcode" VALUES(20151,46032,-5,'Carmel, Indiana 46032',14062,17663);
INSERT INTO "django_geo_db_zipcode" VALUES(20152,46033,-5,'Carmel, Indiana 46033',14062,17664);
INSERT INTO "django_geo_db_zipcode" VALUES(20153,46034,-5,'Cicero, Indiana 46034',14063,17665);
INSERT INTO "django_geo_db_zipcode" VALUES(20154,46035,-5,'Colfax, Indiana 46035',14064,17666);
INSERT INTO "django_geo_db_zipcode" VALUES(20155,46036,-5,'Elwood, Indiana 46036',14065,17667);
INSERT INTO "django_geo_db_zipcode" VALUES(20156,46038,-5,'Fishers, Indiana 46038',14066,17668);
INSERT INTO "django_geo_db_zipcode" VALUES(20157,46039,-5,'Forest, Indiana 46039',14067,17669);
INSERT INTO "django_geo_db_zipcode" VALUES(20158,46040,-5,'Fortville, Indiana 46040',14068,17670);
INSERT INTO "django_geo_db_zipcode" VALUES(20159,46041,-5,'Frankfort, Indiana 46041',14069,17671);
INSERT INTO "django_geo_db_zipcode" VALUES(20160,46044,-5,'Frankton, Indiana 46044',14070,17672);
INSERT INTO "django_geo_db_zipcode" VALUES(20161,46045,-5,'Goldsmith, Indiana 46045',14071,17673);
INSERT INTO "django_geo_db_zipcode" VALUES(20162,46046,-5,'Hillisburg, Indiana 46046',14072,17674);
INSERT INTO "django_geo_db_zipcode" VALUES(20163,46047,-5,'Hobbs, Indiana 46047',14073,17675);
INSERT INTO "django_geo_db_zipcode" VALUES(20164,46048,-5,'Ingalls, Indiana 46048',14074,17676);
INSERT INTO "django_geo_db_zipcode" VALUES(20165,46049,-5,'Kempton, Indiana 46049',14075,17677);
INSERT INTO "django_geo_db_zipcode" VALUES(20166,46050,-5,'Kirklin, Indiana 46050',14076,17678);
INSERT INTO "django_geo_db_zipcode" VALUES(20167,46051,-5,'Lapel, Indiana 46051',14077,17679);
INSERT INTO "django_geo_db_zipcode" VALUES(20168,46052,-5,'Lebanon, Indiana 46052',14078,17680);
INSERT INTO "django_geo_db_zipcode" VALUES(20169,46055,-5,'McCordsville, Indiana 46055',14079,17681);
INSERT INTO "django_geo_db_zipcode" VALUES(20170,46056,-5,'Markleville, Indiana 46056',14080,17682);
INSERT INTO "django_geo_db_zipcode" VALUES(20171,46057,-5,'Michigantown, Indiana 46057',14081,17683);
INSERT INTO "django_geo_db_zipcode" VALUES(20172,46058,-5,'Mulberry, Indiana 46058',14082,17684);
INSERT INTO "django_geo_db_zipcode" VALUES(20173,46060,-5,'Noblesville, Indiana 46060',14083,17685);
INSERT INTO "django_geo_db_zipcode" VALUES(20174,46061,-5,'Noblesville, Indiana 46061',14083,17686);
INSERT INTO "django_geo_db_zipcode" VALUES(20175,46063,-5,'Orestes, Indiana 46063',14084,17687);
INSERT INTO "django_geo_db_zipcode" VALUES(20176,46064,-5,'Pendleton, Indiana 46064',14085,17688);
INSERT INTO "django_geo_db_zipcode" VALUES(20177,46065,-5,'Rossville, Indiana 46065',14086,17689);
INSERT INTO "django_geo_db_zipcode" VALUES(20178,46067,-5,'Sedalia, Indiana 46067',14087,17674);
INSERT INTO "django_geo_db_zipcode" VALUES(20179,46068,-5,'Sharpsville, Indiana 46068',14088,17690);
INSERT INTO "django_geo_db_zipcode" VALUES(20180,46069,-5,'Sheridan, Indiana 46069',14089,17691);
INSERT INTO "django_geo_db_zipcode" VALUES(20181,46070,-5,'Summitville, Indiana 46070',14090,17692);
INSERT INTO "django_geo_db_zipcode" VALUES(20182,46071,-5,'Thorntown, Indiana 46071',14091,17693);
INSERT INTO "django_geo_db_zipcode" VALUES(20183,46072,-5,'Tipton, Indiana 46072',14092,17694);
INSERT INTO "django_geo_db_zipcode" VALUES(20184,46074,-5,'Westfield, Indiana 46074',14093,17695);
INSERT INTO "django_geo_db_zipcode" VALUES(20185,46075,-5,'Whitestown, Indiana 46075',14094,17696);
INSERT INTO "django_geo_db_zipcode" VALUES(20186,46076,-5,'Windfall, Indiana 46076',14095,17697);
INSERT INTO "django_geo_db_zipcode" VALUES(20187,46077,-5,'Zionsville, Indiana 46077',14096,17698);
INSERT INTO "django_geo_db_zipcode" VALUES(20188,46082,-5,'Carmel, Indiana 46082',14062,17686);
INSERT INTO "django_geo_db_zipcode" VALUES(20189,46102,-5,'Advance, Indiana 46102',14097,17699);
INSERT INTO "django_geo_db_zipcode" VALUES(20190,46103,-5,'Amo, Indiana 46103',14098,17700);
INSERT INTO "django_geo_db_zipcode" VALUES(20191,46104,-5,'Arlington, Indiana 46104',14099,17701);
INSERT INTO "django_geo_db_zipcode" VALUES(20192,46105,-5,'Bainbridge, Indiana 46105',14100,17702);
INSERT INTO "django_geo_db_zipcode" VALUES(20193,46106,-5,'Bargersville, Indiana 46106',14101,17703);
INSERT INTO "django_geo_db_zipcode" VALUES(20194,46107,-5,'Beech Grove, Indiana 46107',14102,17704);
INSERT INTO "django_geo_db_zipcode" VALUES(20195,46110,-5,'Boggstown, Indiana 46110',14103,17705);
INSERT INTO "django_geo_db_zipcode" VALUES(20196,46111,-5,'Brooklyn, Indiana 46111',14104,17706);
INSERT INTO "django_geo_db_zipcode" VALUES(20197,46112,-5,'Brownsburg, Indiana 46112',14105,17707);
INSERT INTO "django_geo_db_zipcode" VALUES(20198,46113,-5,'Camby, Indiana 46113',14106,17708);
INSERT INTO "django_geo_db_zipcode" VALUES(20199,46114,-5,'Cartersburg, Indiana 46114',14107,17709);
INSERT INTO "django_geo_db_zipcode" VALUES(20200,46115,-5,'Carthage, Indiana 46115',14108,17710);
INSERT INTO "django_geo_db_zipcode" VALUES(20201,46117,-5,'Charlottesville, Indiana 46117',14109,17711);
INSERT INTO "django_geo_db_zipcode" VALUES(20202,46118,-5,'Clayton, Indiana 46118',14110,17712);
INSERT INTO "django_geo_db_zipcode" VALUES(20203,46120,-5,'Cloverdale, Indiana 46120',14111,17713);
INSERT INTO "django_geo_db_zipcode" VALUES(20204,46121,-5,'Coatesville, Indiana 46121',14112,17714);
INSERT INTO "django_geo_db_zipcode" VALUES(20205,46122,-5,'Danville, Indiana 46122',14113,17715);
INSERT INTO "django_geo_db_zipcode" VALUES(20206,46123,-5,'Avon, Indiana 46123',14114,17716);
INSERT INTO "django_geo_db_zipcode" VALUES(20207,46124,-5,'Edinburgh, Indiana 46124',14115,17717);
INSERT INTO "django_geo_db_zipcode" VALUES(20208,46125,-5,'Eminence, Indiana 46125',14116,17718);
INSERT INTO "django_geo_db_zipcode" VALUES(20209,46126,-5,'Fairland, Indiana 46126',14117,17719);
INSERT INTO "django_geo_db_zipcode" VALUES(20210,46127,-5,'Falmouth, Indiana 46127',14118,17720);
INSERT INTO "django_geo_db_zipcode" VALUES(20211,46128,-5,'Fillmore, Indiana 46128',14119,17721);
INSERT INTO "django_geo_db_zipcode" VALUES(20212,46129,-5,'Finly, Indiana 46129',14120,17722);
INSERT INTO "django_geo_db_zipcode" VALUES(20213,46130,-5,'Fountaintown, Indiana 46130',14121,17723);
INSERT INTO "django_geo_db_zipcode" VALUES(20214,46131,-5,'Franklin, Indiana 46131',14122,17724);
INSERT INTO "django_geo_db_zipcode" VALUES(20215,46133,-5,'Glenwood, Indiana 46133',14123,17725);
INSERT INTO "django_geo_db_zipcode" VALUES(20216,46135,-5,'Greencastle, Indiana 46135',14124,17726);
INSERT INTO "django_geo_db_zipcode" VALUES(20217,46140,-5,'Greenfield, Indiana 46140',14125,17727);
INSERT INTO "django_geo_db_zipcode" VALUES(20218,46142,-5,'Greenwood, Indiana 46142',14126,17728);
INSERT INTO "django_geo_db_zipcode" VALUES(20219,46143,-5,'Greenwood, Indiana 46143',14126,17729);
INSERT INTO "django_geo_db_zipcode" VALUES(20220,46144,-5,'Gwynneville, Indiana 46144',14127,17730);
INSERT INTO "django_geo_db_zipcode" VALUES(20221,46145,-5,'Greenwood, Indiana 46145',14126,17731);
INSERT INTO "django_geo_db_zipcode" VALUES(20222,46146,-5,'Homer, Indiana 46146',14128,17732);
INSERT INTO "django_geo_db_zipcode" VALUES(20223,46147,-5,'Jamestown, Indiana 46147',14129,17733);
INSERT INTO "django_geo_db_zipcode" VALUES(20224,46148,-5,'Knightstown, Indiana 46148',14130,17734);
INSERT INTO "django_geo_db_zipcode" VALUES(20225,46149,-5,'Lizton, Indiana 46149',14131,17735);
INSERT INTO "django_geo_db_zipcode" VALUES(20226,46150,-5,'Manilla, Indiana 46150',14132,17736);
INSERT INTO "django_geo_db_zipcode" VALUES(20227,46151,-5,'Martinsville, Indiana 46151',14133,17737);
INSERT INTO "django_geo_db_zipcode" VALUES(20228,46154,-5,'Maxwell, Indiana 46154',14134,17738);
INSERT INTO "django_geo_db_zipcode" VALUES(20229,46155,-5,'Mays, Indiana 46155',14135,17739);
INSERT INTO "django_geo_db_zipcode" VALUES(20230,46156,-5,'Milroy, Indiana 46156',14136,17740);
INSERT INTO "django_geo_db_zipcode" VALUES(20231,46157,-5,'Monrovia, Indiana 46157',14137,17741);
INSERT INTO "django_geo_db_zipcode" VALUES(20232,46158,-5,'Mooresville, Indiana 46158',14138,17742);
INSERT INTO "django_geo_db_zipcode" VALUES(20233,46160,-5,'Morgantown, Indiana 46160',14139,17743);
INSERT INTO "django_geo_db_zipcode" VALUES(20234,46161,-5,'Morristown, Indiana 46161',14140,17744);
INSERT INTO "django_geo_db_zipcode" VALUES(20235,46162,-5,'Needham, Indiana 46162',14141,17745);
INSERT INTO "django_geo_db_zipcode" VALUES(20236,46163,-5,'New Palestine, Indiana 46163',14142,17746);
INSERT INTO "django_geo_db_zipcode" VALUES(20237,46164,-5,'Nineveh, Indiana 46164',14143,17747);
INSERT INTO "django_geo_db_zipcode" VALUES(20238,46165,-5,'North Salem, Indiana 46165',14144,17748);
INSERT INTO "django_geo_db_zipcode" VALUES(20239,46166,-5,'Paragon, Indiana 46166',14145,17749);
INSERT INTO "django_geo_db_zipcode" VALUES(20240,46167,-5,'Pittsboro, Indiana 46167',14146,17750);
INSERT INTO "django_geo_db_zipcode" VALUES(20241,46168,-5,'Plainfield, Indiana 46168',14147,17751);
INSERT INTO "django_geo_db_zipcode" VALUES(20242,46170,-5,'Putnamville, Indiana 46170',14148,17752);
INSERT INTO "django_geo_db_zipcode" VALUES(20243,46171,-5,'Reelsville, Indiana 46171',14149,17753);
INSERT INTO "django_geo_db_zipcode" VALUES(20244,46172,-5,'Roachdale, Indiana 46172',14150,17754);
INSERT INTO "django_geo_db_zipcode" VALUES(20245,46173,-5,'Rushville, Indiana 46173',14151,17755);
INSERT INTO "django_geo_db_zipcode" VALUES(20246,46175,-5,'Russellville, Indiana 46175',14152,17756);
INSERT INTO "django_geo_db_zipcode" VALUES(20247,46176,-5,'Shelbyville, Indiana 46176',14153,17757);
INSERT INTO "django_geo_db_zipcode" VALUES(20248,46180,-5,'Stilesville, Indiana 46180',14154,17758);
INSERT INTO "django_geo_db_zipcode" VALUES(20249,46181,-5,'Trafalgar, Indiana 46181',14155,17759);
INSERT INTO "django_geo_db_zipcode" VALUES(20250,46182,-5,'Waldron, Indiana 46182',14156,17760);
INSERT INTO "django_geo_db_zipcode" VALUES(20251,46183,-5,'West Newton, Indiana 46183',14157,17761);
INSERT INTO "django_geo_db_zipcode" VALUES(20252,46184,-5,'Whiteland, Indiana 46184',14158,17762);
INSERT INTO "django_geo_db_zipcode" VALUES(20253,46186,-5,'Wilkinson, Indiana 46186',14159,17763);
INSERT INTO "django_geo_db_zipcode" VALUES(20254,46201,-5,'Indianapolis, Indiana 46201',14160,17764);
INSERT INTO "django_geo_db_zipcode" VALUES(20255,46202,-5,'Indianapolis, Indiana 46202',14160,17765);
INSERT INTO "django_geo_db_zipcode" VALUES(20256,46203,-5,'Indianapolis, Indiana 46203',14160,17766);
INSERT INTO "django_geo_db_zipcode" VALUES(20257,46204,-5,'Indianapolis, Indiana 46204',14160,17767);
INSERT INTO "django_geo_db_zipcode" VALUES(20258,46205,-5,'Indianapolis, Indiana 46205',14160,17768);
INSERT INTO "django_geo_db_zipcode" VALUES(20259,46206,-5,'Indianapolis, Indiana 46206',14160,17769);
INSERT INTO "django_geo_db_zipcode" VALUES(20260,46207,-5,'Indianapolis, Indiana 46207',14160,17770);
INSERT INTO "django_geo_db_zipcode" VALUES(20261,46208,-5,'Indianapolis, Indiana 46208',14160,17771);
INSERT INTO "django_geo_db_zipcode" VALUES(20262,46209,-5,'Indianapolis, Indiana 46209',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20263,46211,-5,'Indianapolis, Indiana 46211',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20264,46214,-5,'Indianapolis, Indiana 46214',14160,17773);
INSERT INTO "django_geo_db_zipcode" VALUES(20265,46216,-5,'Indianapolis, Indiana 46216',14160,17774);
INSERT INTO "django_geo_db_zipcode" VALUES(20266,46217,-5,'Indianapolis, Indiana 46217',14160,17775);
INSERT INTO "django_geo_db_zipcode" VALUES(20267,46218,-5,'Indianapolis, Indiana 46218',14160,17776);
INSERT INTO "django_geo_db_zipcode" VALUES(20268,46219,-5,'Indianapolis, Indiana 46219',14160,17777);
INSERT INTO "django_geo_db_zipcode" VALUES(20269,46220,-5,'Indianapolis, Indiana 46220',14160,17778);
INSERT INTO "django_geo_db_zipcode" VALUES(20270,46221,-5,'Indianapolis, Indiana 46221',14160,17779);
INSERT INTO "django_geo_db_zipcode" VALUES(20271,46222,-5,'Indianapolis, Indiana 46222',14160,17780);
INSERT INTO "django_geo_db_zipcode" VALUES(20272,46223,-5,'Indianapolis, Indiana 46223',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20273,46224,-5,'Indianapolis, Indiana 46224',14160,17781);
INSERT INTO "django_geo_db_zipcode" VALUES(20274,46225,-5,'Indianapolis, Indiana 46225',14160,17782);
INSERT INTO "django_geo_db_zipcode" VALUES(20275,46226,-5,'Indianapolis, Indiana 46226',14160,17783);
INSERT INTO "django_geo_db_zipcode" VALUES(20276,46227,-5,'Indianapolis, Indiana 46227',14160,17784);
INSERT INTO "django_geo_db_zipcode" VALUES(20277,46228,-5,'Indianapolis, Indiana 46228',14160,17785);
INSERT INTO "django_geo_db_zipcode" VALUES(20278,46229,-5,'Indianapolis, Indiana 46229',14160,17786);
INSERT INTO "django_geo_db_zipcode" VALUES(20279,46230,-5,'Indianapolis, Indiana 46230',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20280,46231,-5,'Indianapolis, Indiana 46231',14160,17787);
INSERT INTO "django_geo_db_zipcode" VALUES(20281,46234,-5,'Indianapolis, Indiana 46234',14160,17788);
INSERT INTO "django_geo_db_zipcode" VALUES(20282,46235,-5,'Indianapolis, Indiana 46235',14160,17789);
INSERT INTO "django_geo_db_zipcode" VALUES(20283,46236,-5,'Indianapolis, Indiana 46236',14160,17790);
INSERT INTO "django_geo_db_zipcode" VALUES(20284,46237,-5,'Indianapolis, Indiana 46237',14160,17791);
INSERT INTO "django_geo_db_zipcode" VALUES(20285,46239,-5,'Indianapolis, Indiana 46239',14160,17792);
INSERT INTO "django_geo_db_zipcode" VALUES(20286,46240,-5,'Indianapolis, Indiana 46240',14160,17793);
INSERT INTO "django_geo_db_zipcode" VALUES(20287,46241,-5,'Indianapolis, Indiana 46241',14160,17794);
INSERT INTO "django_geo_db_zipcode" VALUES(20288,46242,-5,'Indianapolis, Indiana 46242',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20289,46243,-5,'Washington, Indiana 46243',14161,17795);
INSERT INTO "django_geo_db_zipcode" VALUES(20290,46244,-5,'Indianapolis, Indiana 46244',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20291,46247,-5,'Indianapolis, Indiana 46247',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20292,46249,-5,'Indianapolis, Indiana 46249',14160,17796);
INSERT INTO "django_geo_db_zipcode" VALUES(20293,46250,-5,'Indianapolis, Indiana 46250',14160,17797);
INSERT INTO "django_geo_db_zipcode" VALUES(20294,46251,-5,'Indianapolis, Indiana 46251',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20295,46253,-5,'Indianapolis, Indiana 46253',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20296,46254,-5,'Indianapolis, Indiana 46254',14160,17798);
INSERT INTO "django_geo_db_zipcode" VALUES(20297,46255,-5,'Indianapolis, Indiana 46255',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20298,46256,-5,'Indianapolis, Indiana 46256',14160,17799);
INSERT INTO "django_geo_db_zipcode" VALUES(20299,46259,-5,'Indianapolis, Indiana 46259',14160,17800);
INSERT INTO "django_geo_db_zipcode" VALUES(20300,46260,-5,'Indianapolis, Indiana 46260',14160,17801);
INSERT INTO "django_geo_db_zipcode" VALUES(20301,46266,-5,'Indianapolis, Indiana 46266',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20302,46268,-5,'Indianapolis, Indiana 46268',14160,17802);
INSERT INTO "django_geo_db_zipcode" VALUES(20303,46274,-5,'Indianapolis, Indiana 46274',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20304,46275,-5,'Indianapolis, Indiana 46275',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20305,46277,-5,'Indianapolis, Indiana 46277',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20306,46278,-5,'Indianapolis, Indiana 46278',14160,17803);
INSERT INTO "django_geo_db_zipcode" VALUES(20307,46280,-5,'Indianapolis, Indiana 46280',14160,17804);
INSERT INTO "django_geo_db_zipcode" VALUES(20308,46282,-5,'Indianapolis, Indiana 46282',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20309,46283,-5,'Indianapolis, Indiana 46283',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20310,46285,-5,'Indianapolis, Indiana 46285',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20311,46290,-5,'Indianapolis, Indiana 46290',14160,17805);
INSERT INTO "django_geo_db_zipcode" VALUES(20312,46291,-5,'Indianapolis, Indiana 46291',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20313,46295,-5,'Indianapolis, Indiana 46295',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20314,46298,-5,'Indianapolis, Indiana 46298',14160,17772);
INSERT INTO "django_geo_db_zipcode" VALUES(20315,46301,-6,'Beverly Shores, Indiana 46301',14162,17806);
INSERT INTO "django_geo_db_zipcode" VALUES(20316,46302,-6,'Boone Grove, Indiana 46302',14163,17807);
INSERT INTO "django_geo_db_zipcode" VALUES(20317,46303,-6,'Cedar Lake, Indiana 46303',14164,17808);
INSERT INTO "django_geo_db_zipcode" VALUES(20318,46304,-6,'Chesterton, Indiana 46304',14165,17809);
INSERT INTO "django_geo_db_zipcode" VALUES(20319,46305,-5,'Granger, Indiana 46305',14166,17810);
INSERT INTO "django_geo_db_zipcode" VALUES(20320,46307,-6,'Crown Point, Indiana 46307',14167,17811);
INSERT INTO "django_geo_db_zipcode" VALUES(20321,46308,-6,'Crown Point, Indiana 46308',14167,17812);
INSERT INTO "django_geo_db_zipcode" VALUES(20322,46310,-6,'Demotte, Indiana 46310',14168,17813);
INSERT INTO "django_geo_db_zipcode" VALUES(20323,46311,-6,'Dyer, Indiana 46311',14169,17814);
INSERT INTO "django_geo_db_zipcode" VALUES(20324,46312,-6,'East Chicago, Indiana 46312',14170,17815);
INSERT INTO "django_geo_db_zipcode" VALUES(20325,46319,-6,'Griffith, Indiana 46319',14171,17816);
INSERT INTO "django_geo_db_zipcode" VALUES(20326,46320,-6,'Hammond, Indiana 46320',14172,17817);
INSERT INTO "django_geo_db_zipcode" VALUES(20327,46321,-6,'Munster, Indiana 46321',14173,17818);
INSERT INTO "django_geo_db_zipcode" VALUES(20328,46322,-6,'Highland, Indiana 46322',14174,17819);
INSERT INTO "django_geo_db_zipcode" VALUES(20329,46323,-6,'Hammond, Indiana 46323',14172,17820);
INSERT INTO "django_geo_db_zipcode" VALUES(20330,46324,-6,'Hammond, Indiana 46324',14172,17821);
INSERT INTO "django_geo_db_zipcode" VALUES(20331,46325,-6,'Hammond, Indiana 46325',14172,17812);
INSERT INTO "django_geo_db_zipcode" VALUES(20332,46327,-6,'Hammond, Indiana 46327',14172,17822);
INSERT INTO "django_geo_db_zipcode" VALUES(20333,46332,-5,'Washington, Indiana 46332',14161,17823);
INSERT INTO "django_geo_db_zipcode" VALUES(20334,46340,-6,'Hanna, Indiana 46340',14175,17824);
INSERT INTO "django_geo_db_zipcode" VALUES(20335,46341,-6,'Hebron, Indiana 46341',14176,17825);
INSERT INTO "django_geo_db_zipcode" VALUES(20336,46342,-6,'Hobart, Indiana 46342',14177,17826);
INSERT INTO "django_geo_db_zipcode" VALUES(20337,46345,-6,'Kingsbury, Indiana 46345',14178,17827);
INSERT INTO "django_geo_db_zipcode" VALUES(20338,46346,-6,'Kingsford Heights, Indiana 46346',14179,17828);
INSERT INTO "django_geo_db_zipcode" VALUES(20339,46347,-6,'Kouts, Indiana 46347',14180,17829);
INSERT INTO "django_geo_db_zipcode" VALUES(20340,46348,-6,'La Crosse, Indiana 46348',14181,17830);
INSERT INTO "django_geo_db_zipcode" VALUES(20341,46349,-6,'Lake Village, Indiana 46349',14182,17831);
INSERT INTO "django_geo_db_zipcode" VALUES(20342,46350,-6,'La Porte, Indiana 46350',14183,17832);
INSERT INTO "django_geo_db_zipcode" VALUES(20343,46352,-6,'La Porte, Indiana 46352',14183,17833);
INSERT INTO "django_geo_db_zipcode" VALUES(20344,46355,-6,'Leroy, Indiana 46355',14184,17834);
INSERT INTO "django_geo_db_zipcode" VALUES(20345,46356,-6,'Lowell, Indiana 46356',14185,17835);
INSERT INTO "django_geo_db_zipcode" VALUES(20346,46360,-6,'Michigan City, Indiana 46360',14186,17836);
INSERT INTO "django_geo_db_zipcode" VALUES(20347,46361,-6,'Michigan City, Indiana 46361',14186,17837);
INSERT INTO "django_geo_db_zipcode" VALUES(20348,46365,-6,'Mill Creek, Indiana 46365',14187,17838);
INSERT INTO "django_geo_db_zipcode" VALUES(20349,46366,-5,'North Judson, Indiana 46366',14188,17839);
INSERT INTO "django_geo_db_zipcode" VALUES(20350,46368,-6,'Portage, Indiana 46368',14189,17840);
INSERT INTO "django_geo_db_zipcode" VALUES(20351,46369,-5,'Russiaville, Indiana 46369',14190,17841);
INSERT INTO "django_geo_db_zipcode" VALUES(20352,46371,-6,'Rolling Prairie, Indiana 46371',14191,17842);
INSERT INTO "django_geo_db_zipcode" VALUES(20353,46372,-6,'Roselawn, Indiana 46372',14192,17843);
INSERT INTO "django_geo_db_zipcode" VALUES(20354,46373,-6,'Saint John, Indiana 46373',14193,17844);
INSERT INTO "django_geo_db_zipcode" VALUES(20355,46374,-5,'San Pierre, Indiana 46374',14194,17845);
INSERT INTO "django_geo_db_zipcode" VALUES(20356,46375,-6,'Schererville, Indiana 46375',14195,17846);
INSERT INTO "django_geo_db_zipcode" VALUES(20357,46376,-6,'Schneider, Indiana 46376',14196,17847);
INSERT INTO "django_geo_db_zipcode" VALUES(20358,46377,-6,'Shelby, Indiana 46377',14197,17848);
INSERT INTO "django_geo_db_zipcode" VALUES(20359,46379,-6,'Sumava Resorts, Indiana 46379',14198,17849);
INSERT INTO "django_geo_db_zipcode" VALUES(20360,46380,-6,'Tefft, Indiana 46380',14199,17850);
INSERT INTO "django_geo_db_zipcode" VALUES(20361,46381,-6,'Thayer, Indiana 46381',14200,17851);
INSERT INTO "django_geo_db_zipcode" VALUES(20362,46382,-6,'Union Mills, Indiana 46382',14201,17852);
INSERT INTO "django_geo_db_zipcode" VALUES(20363,46383,-6,'Valparaiso, Indiana 46383',14202,17853);
INSERT INTO "django_geo_db_zipcode" VALUES(20364,46384,-6,'Valparaiso, Indiana 46384',14202,17854);
INSERT INTO "django_geo_db_zipcode" VALUES(20365,46385,-6,'Valparaiso, Indiana 46385',14202,17855);
INSERT INTO "django_geo_db_zipcode" VALUES(20366,46386,-6,'Porter, Indiana 46386',14203,17856);
INSERT INTO "django_geo_db_zipcode" VALUES(20367,46390,-6,'Wanatah, Indiana 46390',14204,17857);
INSERT INTO "django_geo_db_zipcode" VALUES(20368,46391,-6,'Westville, Indiana 46391',14205,17858);
INSERT INTO "django_geo_db_zipcode" VALUES(20369,46392,-6,'Wheatfield, Indiana 46392',14206,17859);
INSERT INTO "django_geo_db_zipcode" VALUES(20370,46393,-6,'Wheeler, Indiana 46393',14207,17860);
INSERT INTO "django_geo_db_zipcode" VALUES(20371,46394,-6,'Whiting, Indiana 46394',14208,17861);
INSERT INTO "django_geo_db_zipcode" VALUES(20372,46401,-6,'Gary, Indiana 46401',14209,17862);
INSERT INTO "django_geo_db_zipcode" VALUES(20373,46402,-6,'Gary, Indiana 46402',14209,17863);
INSERT INTO "django_geo_db_zipcode" VALUES(20374,46403,-6,'Gary, Indiana 46403',14209,17864);
INSERT INTO "django_geo_db_zipcode" VALUES(20375,46404,-6,'Gary, Indiana 46404',14209,17865);
INSERT INTO "django_geo_db_zipcode" VALUES(20376,46405,-6,'Lake Station, Indiana 46405',14210,17866);
INSERT INTO "django_geo_db_zipcode" VALUES(20377,46406,-6,'Gary, Indiana 46406',14209,17867);
INSERT INTO "django_geo_db_zipcode" VALUES(20378,46407,-6,'Gary, Indiana 46407',14209,17868);
INSERT INTO "django_geo_db_zipcode" VALUES(20379,46408,-6,'Gary, Indiana 46408',14209,17869);
INSERT INTO "django_geo_db_zipcode" VALUES(20380,46409,-6,'Gary, Indiana 46409',14209,17870);
INSERT INTO "django_geo_db_zipcode" VALUES(20381,46410,-6,'Merrillville, Indiana 46410',14211,17871);
INSERT INTO "django_geo_db_zipcode" VALUES(20382,46411,-6,'Merrillville, Indiana 46411',14211,17812);
INSERT INTO "django_geo_db_zipcode" VALUES(20383,46415,-5,'Burlington, Indiana 46415',14212,17872);
INSERT INTO "django_geo_db_zipcode" VALUES(20384,46501,-5,'Argos, Indiana 46501',14213,17873);
INSERT INTO "django_geo_db_zipcode" VALUES(20385,46502,-5,'Atwood, Indiana 46502',14214,17874);
INSERT INTO "django_geo_db_zipcode" VALUES(20386,46504,-5,'Bourbon, Indiana 46504',14215,17875);
INSERT INTO "django_geo_db_zipcode" VALUES(20387,46506,-5,'Bremen, Indiana 46506',14216,17876);
INSERT INTO "django_geo_db_zipcode" VALUES(20388,46507,-5,'Bristol, Indiana 46507',14217,17877);
INSERT INTO "django_geo_db_zipcode" VALUES(20389,46508,-5,'Burket, Indiana 46508',14218,17878);
INSERT INTO "django_geo_db_zipcode" VALUES(20390,46510,-5,'Claypool, Indiana 46510',14219,17879);
INSERT INTO "django_geo_db_zipcode" VALUES(20391,46511,-5,'Culver, Indiana 46511',14220,17880);
INSERT INTO "django_geo_db_zipcode" VALUES(20392,46513,-5,'Donaldson, Indiana 46513',14221,17881);
INSERT INTO "django_geo_db_zipcode" VALUES(20393,46514,-5,'Elkhart, Indiana 46514',14222,17882);
INSERT INTO "django_geo_db_zipcode" VALUES(20394,46515,-5,'Elkhart, Indiana 46515',14222,17883);
INSERT INTO "django_geo_db_zipcode" VALUES(20395,46516,-5,'Elkhart, Indiana 46516',14222,17884);
INSERT INTO "django_geo_db_zipcode" VALUES(20396,46517,-5,'Elkhart, Indiana 46517',14222,17885);
INSERT INTO "django_geo_db_zipcode" VALUES(20397,46518,-5,'Madison, Indiana 46518',14223,17886);
INSERT INTO "django_geo_db_zipcode" VALUES(20398,46524,-5,'Etna Green, Indiana 46524',14224,17887);
INSERT INTO "django_geo_db_zipcode" VALUES(20399,46526,-5,'Goshen, Indiana 46526',14225,17888);
INSERT INTO "django_geo_db_zipcode" VALUES(20400,46527,-5,'Goshen, Indiana 46527',14225,17889);
INSERT INTO "django_geo_db_zipcode" VALUES(20401,46528,-5,'Goshen, Indiana 46528',14225,17890);
INSERT INTO "django_geo_db_zipcode" VALUES(20402,46530,-5,'Granger, Indiana 46530',14166,17891);
INSERT INTO "django_geo_db_zipcode" VALUES(20403,46531,-5,'Grovertown, Indiana 46531',14226,17892);
INSERT INTO "django_geo_db_zipcode" VALUES(20404,46532,-5,'Hamlet, Indiana 46532',14227,17893);
INSERT INTO "django_geo_db_zipcode" VALUES(20405,46534,-5,'Knox, Indiana 46534',14228,17894);
INSERT INTO "django_geo_db_zipcode" VALUES(20406,46535,-5,'Granger, Indiana 46535',14166,17895);
INSERT INTO "django_geo_db_zipcode" VALUES(20407,46536,-5,'Lakeville, Indiana 46536',14229,17896);
INSERT INTO "django_geo_db_zipcode" VALUES(20408,46537,-5,'Lapaz, Indiana 46537',14230,17897);
INSERT INTO "django_geo_db_zipcode" VALUES(20409,46538,-5,'Leesburg, Indiana 46538',14231,17898);
INSERT INTO "django_geo_db_zipcode" VALUES(20410,46539,-5,'Mentone, Indiana 46539',14232,17899);
INSERT INTO "django_geo_db_zipcode" VALUES(20411,46540,-5,'Middlebury, Indiana 46540',14233,17900);
INSERT INTO "django_geo_db_zipcode" VALUES(20412,46542,-5,'Milford, Indiana 46542',14234,17901);
INSERT INTO "django_geo_db_zipcode" VALUES(20413,46543,-5,'Millersburg, Indiana 46543',14235,17902);
INSERT INTO "django_geo_db_zipcode" VALUES(20414,46544,-5,'Mishawaka, Indiana 46544',14236,17903);
INSERT INTO "django_geo_db_zipcode" VALUES(20415,46545,-5,'Mishawaka, Indiana 46545',14236,17904);
INSERT INTO "django_geo_db_zipcode" VALUES(20416,46546,-5,'Mishawaka, Indiana 46546',14236,17905);
INSERT INTO "django_geo_db_zipcode" VALUES(20417,46550,-5,'Nappanee, Indiana 46550',14237,17906);
INSERT INTO "django_geo_db_zipcode" VALUES(20418,46552,-5,'New Carlisle, Indiana 46552',14238,17907);
INSERT INTO "django_geo_db_zipcode" VALUES(20419,46553,-5,'New Paris, Indiana 46553',14239,17908);
INSERT INTO "django_geo_db_zipcode" VALUES(20420,46554,-5,'North Liberty, Indiana 46554',14240,17909);
INSERT INTO "django_geo_db_zipcode" VALUES(20421,46555,-5,'North Webster, Indiana 46555',14241,17910);
INSERT INTO "django_geo_db_zipcode" VALUES(20422,46556,-5,'Notre Dame, Indiana 46556',14242,17911);
INSERT INTO "django_geo_db_zipcode" VALUES(20423,46561,-5,'Osceola, Indiana 46561',14243,17912);
INSERT INTO "django_geo_db_zipcode" VALUES(20424,46562,-5,'Pierceton, Indiana 46562',14244,17913);
INSERT INTO "django_geo_db_zipcode" VALUES(20425,46563,-5,'Plymouth, Indiana 46563',14245,17914);
INSERT INTO "django_geo_db_zipcode" VALUES(20426,46565,-5,'Shipshewana, Indiana 46565',14246,17915);
INSERT INTO "django_geo_db_zipcode" VALUES(20427,46566,-5,'Sidney, Indiana 46566',14247,17916);
INSERT INTO "django_geo_db_zipcode" VALUES(20428,46567,-5,'Syracuse, Indiana 46567',14248,17917);
INSERT INTO "django_geo_db_zipcode" VALUES(20429,46570,-5,'Tippecanoe, Indiana 46570',14249,17918);
INSERT INTO "django_geo_db_zipcode" VALUES(20430,46571,-5,'Topeka, Indiana 46571',14250,17919);
INSERT INTO "django_geo_db_zipcode" VALUES(20431,46572,-5,'Tyner, Indiana 46572',14251,17920);
INSERT INTO "django_geo_db_zipcode" VALUES(20432,46573,-5,'Wakarusa, Indiana 46573',14252,17921);
INSERT INTO "django_geo_db_zipcode" VALUES(20433,46574,-5,'Walkerton, Indiana 46574',14253,17922);
INSERT INTO "django_geo_db_zipcode" VALUES(20434,46580,-5,'Warsaw, Indiana 46580',14254,17923);
INSERT INTO "django_geo_db_zipcode" VALUES(20435,46581,-5,'Warsaw, Indiana 46581',14254,17924);
INSERT INTO "django_geo_db_zipcode" VALUES(20436,46582,-5,'Warsaw, Indiana 46582',14254,17925);
INSERT INTO "django_geo_db_zipcode" VALUES(20437,46590,-5,'Winona Lake, Indiana 46590',14255,17926);
INSERT INTO "django_geo_db_zipcode" VALUES(20438,46595,-5,'Wyatt, Indiana 46595',14256,17927);
INSERT INTO "django_geo_db_zipcode" VALUES(20439,46601,-5,'South Bend, Indiana 46601',14257,17928);
INSERT INTO "django_geo_db_zipcode" VALUES(20440,46604,-5,'South Bend, Indiana 46604',14257,17929);
INSERT INTO "django_geo_db_zipcode" VALUES(20441,46612,-5,'South Bend, Indiana 46612',14257,17930);
INSERT INTO "django_geo_db_zipcode" VALUES(20442,46613,-5,'South Bend, Indiana 46613',14257,17931);
INSERT INTO "django_geo_db_zipcode" VALUES(20443,46614,-5,'South Bend, Indiana 46614',14257,17932);
INSERT INTO "django_geo_db_zipcode" VALUES(20444,46615,-5,'South Bend, Indiana 46615',14257,17933);
INSERT INTO "django_geo_db_zipcode" VALUES(20445,46616,-5,'South Bend, Indiana 46616',14257,17934);
INSERT INTO "django_geo_db_zipcode" VALUES(20446,46617,-5,'South Bend, Indiana 46617',14257,17935);
INSERT INTO "django_geo_db_zipcode" VALUES(20447,46619,-5,'South Bend, Indiana 46619',14257,17936);
INSERT INTO "django_geo_db_zipcode" VALUES(20448,46620,-5,'South Bend, Indiana 46620',14257,17937);
INSERT INTO "django_geo_db_zipcode" VALUES(20449,46624,-5,'South Bend, Indiana 46624',14257,17938);
INSERT INTO "django_geo_db_zipcode" VALUES(20450,46626,-5,'South Bend, Indiana 46626',14257,17939);
INSERT INTO "django_geo_db_zipcode" VALUES(20451,46628,-5,'South Bend, Indiana 46628',14257,17940);
INSERT INTO "django_geo_db_zipcode" VALUES(20452,46629,-5,'South Bend, Indiana 46629',14257,17941);
INSERT INTO "django_geo_db_zipcode" VALUES(20453,46634,-5,'South Bend, Indiana 46634',14257,17937);
INSERT INTO "django_geo_db_zipcode" VALUES(20454,46635,-5,'South Bend, Indiana 46635',14257,17942);
INSERT INTO "django_geo_db_zipcode" VALUES(20455,46637,-5,'South Bend, Indiana 46637',14257,17943);
INSERT INTO "django_geo_db_zipcode" VALUES(20456,46660,-5,'South Bend, Indiana 46660',14257,17937);
INSERT INTO "django_geo_db_zipcode" VALUES(20457,46671,-5,'Topeka, Indiana 46671',14250,17944);
INSERT INTO "django_geo_db_zipcode" VALUES(20458,46680,-5,'South Bend, Indiana 46680',14257,17937);
INSERT INTO "django_geo_db_zipcode" VALUES(20459,46692,-5,'Noble, Indiana 46692',14258,17945);
INSERT INTO "django_geo_db_zipcode" VALUES(20460,46696,-5,'Franklin, Indiana 46696',14122,17946);
INSERT INTO "django_geo_db_zipcode" VALUES(20461,46699,-5,'South Bend, Indiana 46699',14257,17937);
INSERT INTO "django_geo_db_zipcode" VALUES(20462,46701,-5,'Albion, Indiana 46701',14259,17947);
INSERT INTO "django_geo_db_zipcode" VALUES(20463,46702,-5,'Andrews, Indiana 46702',14260,17948);
INSERT INTO "django_geo_db_zipcode" VALUES(20464,46703,-5,'Angola, Indiana 46703',14261,17949);
INSERT INTO "django_geo_db_zipcode" VALUES(20465,46704,-5,'Arcola, Indiana 46704',14262,17950);
INSERT INTO "django_geo_db_zipcode" VALUES(20466,46705,-5,'Ashley, Indiana 46705',14263,17951);
INSERT INTO "django_geo_db_zipcode" VALUES(20467,46706,-5,'Auburn, Indiana 46706',14264,17952);
INSERT INTO "django_geo_db_zipcode" VALUES(20468,46710,-5,'Avilla, Indiana 46710',14265,17953);
INSERT INTO "django_geo_db_zipcode" VALUES(20469,46711,-5,'Berne, Indiana 46711',14266,17954);
INSERT INTO "django_geo_db_zipcode" VALUES(20470,46713,-5,'Bippus, Indiana 46713',14267,17955);
INSERT INTO "django_geo_db_zipcode" VALUES(20471,46714,-5,'Bluffton, Indiana 46714',14268,17956);
INSERT INTO "django_geo_db_zipcode" VALUES(20472,46720,-5,'Brimfield, Indiana 46720',14269,17957);
INSERT INTO "django_geo_db_zipcode" VALUES(20473,46721,-5,'Butler, Indiana 46721',14270,17958);
INSERT INTO "django_geo_db_zipcode" VALUES(20474,46723,-5,'Churubusco, Indiana 46723',14271,17959);
INSERT INTO "django_geo_db_zipcode" VALUES(20475,46725,-5,'Columbia City, Indiana 46725',14272,17960);
INSERT INTO "django_geo_db_zipcode" VALUES(20476,46730,-5,'Corunna, Indiana 46730',14273,17961);
INSERT INTO "django_geo_db_zipcode" VALUES(20477,46731,-5,'Craigville, Indiana 46731',14274,17962);
INSERT INTO "django_geo_db_zipcode" VALUES(20478,46732,-5,'Cromwell, Indiana 46732',14275,17963);
INSERT INTO "django_geo_db_zipcode" VALUES(20479,46733,-5,'Decatur, Indiana 46733',14276,17964);
INSERT INTO "django_geo_db_zipcode" VALUES(20480,46737,-5,'Fremont, Indiana 46737',14277,17965);
INSERT INTO "django_geo_db_zipcode" VALUES(20481,46738,-5,'Garrett, Indiana 46738',14278,17966);
INSERT INTO "django_geo_db_zipcode" VALUES(20482,46740,-5,'Geneva, Indiana 46740',14279,17967);
INSERT INTO "django_geo_db_zipcode" VALUES(20483,46741,-5,'Grabill, Indiana 46741',14280,17968);
INSERT INTO "django_geo_db_zipcode" VALUES(20484,46742,-5,'Hamilton, Indiana 46742',14281,17969);
INSERT INTO "django_geo_db_zipcode" VALUES(20485,46743,-5,'Harlan, Indiana 46743',14282,17970);
INSERT INTO "django_geo_db_zipcode" VALUES(20486,46745,-5,'Hoagland, Indiana 46745',14283,17971);
INSERT INTO "django_geo_db_zipcode" VALUES(20487,46746,-5,'Howe, Indiana 46746',14284,17972);
INSERT INTO "django_geo_db_zipcode" VALUES(20488,46747,-5,'Hudson, Indiana 46747',14285,17973);
INSERT INTO "django_geo_db_zipcode" VALUES(20489,46748,-5,'Huntertown, Indiana 46748',14286,17974);
INSERT INTO "django_geo_db_zipcode" VALUES(20490,46750,-5,'Huntington, Indiana 46750',14287,17975);
INSERT INTO "django_geo_db_zipcode" VALUES(20491,46755,-5,'Kendallville, Indiana 46755',14288,17976);
INSERT INTO "django_geo_db_zipcode" VALUES(20492,46759,-5,'Keystone, Indiana 46759',14289,17977);
INSERT INTO "django_geo_db_zipcode" VALUES(20493,46760,-5,'Kimmell, Indiana 46760',14290,17978);
INSERT INTO "django_geo_db_zipcode" VALUES(20494,46761,-5,'Lagrange, Indiana 46761',14291,17979);
INSERT INTO "django_geo_db_zipcode" VALUES(20495,46763,-5,'Laotto, Indiana 46763',14292,17980);
INSERT INTO "django_geo_db_zipcode" VALUES(20496,46764,-5,'Larwill, Indiana 46764',14293,17981);
INSERT INTO "django_geo_db_zipcode" VALUES(20497,46765,-5,'Leo, Indiana 46765',14294,17982);
INSERT INTO "django_geo_db_zipcode" VALUES(20498,46766,-5,'Liberty Center, Indiana 46766',14295,17983);
INSERT INTO "django_geo_db_zipcode" VALUES(20499,46767,-5,'Ligonier, Indiana 46767',14296,17984);
INSERT INTO "django_geo_db_zipcode" VALUES(20500,46768,-5,'Plainfield, Indiana 46768',14147,17985);
INSERT INTO "django_geo_db_zipcode" VALUES(20501,46769,-5,'Linn Grove, Indiana 46769',14297,17986);
INSERT INTO "django_geo_db_zipcode" VALUES(20502,46770,-5,'Markle, Indiana 46770',14298,17987);
INSERT INTO "django_geo_db_zipcode" VALUES(20503,46771,-5,'Mongo, Indiana 46771',14299,17988);
INSERT INTO "django_geo_db_zipcode" VALUES(20504,46772,-5,'Monroe, Indiana 46772',14300,17989);
INSERT INTO "django_geo_db_zipcode" VALUES(20505,46773,-5,'Monroeville, Indiana 46773',14301,17990);
INSERT INTO "django_geo_db_zipcode" VALUES(20506,46774,-5,'New Haven, Indiana 46774',14302,17991);
INSERT INTO "django_geo_db_zipcode" VALUES(20507,46776,-5,'Orland, Indiana 46776',14303,17992);
INSERT INTO "django_geo_db_zipcode" VALUES(20508,46777,-5,'Ossian, Indiana 46777',14304,17993);
INSERT INTO "django_geo_db_zipcode" VALUES(20509,46778,-5,'Petroleum, Indiana 46778',14305,17994);
INSERT INTO "django_geo_db_zipcode" VALUES(20510,46779,-5,'Pleasant Lake, Indiana 46779',14306,17995);
INSERT INTO "django_geo_db_zipcode" VALUES(20511,46780,-5,'Pleasant Mills, Indiana 46780',14307,17986);
INSERT INTO "django_geo_db_zipcode" VALUES(20512,46781,-5,'Poneto, Indiana 46781',14308,17996);
INSERT INTO "django_geo_db_zipcode" VALUES(20513,46782,-5,'Preble, Indiana 46782',14309,17997);
INSERT INTO "django_geo_db_zipcode" VALUES(20514,46783,-5,'Roanoke, Indiana 46783',14310,17998);
INSERT INTO "django_geo_db_zipcode" VALUES(20515,46784,-5,'Rome City, Indiana 46784',14311,17999);
INSERT INTO "django_geo_db_zipcode" VALUES(20516,46785,-5,'Saint Joe, Indiana 46785',14312,18000);
INSERT INTO "django_geo_db_zipcode" VALUES(20517,46786,-5,'South Milford, Indiana 46786',14313,18001);
INSERT INTO "django_geo_db_zipcode" VALUES(20518,46787,-5,'South Whitley, Indiana 46787',14314,18002);
INSERT INTO "django_geo_db_zipcode" VALUES(20519,46788,-5,'Spencerville, Indiana 46788',14315,18003);
INSERT INTO "django_geo_db_zipcode" VALUES(20520,46789,-5,'Stroh, Indiana 46789',14316,18004);
INSERT INTO "django_geo_db_zipcode" VALUES(20521,46791,-5,'Uniondale, Indiana 46791',14317,18005);
INSERT INTO "django_geo_db_zipcode" VALUES(20522,46792,-5,'Warren, Indiana 46792',14318,18006);
INSERT INTO "django_geo_db_zipcode" VALUES(20523,46793,-5,'Waterloo, Indiana 46793',14319,18007);
INSERT INTO "django_geo_db_zipcode" VALUES(20524,46794,-5,'Wawaka, Indiana 46794',14320,18008);
INSERT INTO "django_geo_db_zipcode" VALUES(20525,46795,-5,'Wolcottville, Indiana 46795',14321,18009);
INSERT INTO "django_geo_db_zipcode" VALUES(20526,46796,-5,'Wolflake, Indiana 46796',14322,18010);
INSERT INTO "django_geo_db_zipcode" VALUES(20527,46797,-5,'Woodburn, Indiana 46797',14323,18011);
INSERT INTO "django_geo_db_zipcode" VALUES(20528,46798,-5,'Yoder, Indiana 46798',14324,18012);
INSERT INTO "django_geo_db_zipcode" VALUES(20529,46799,-5,'Zanesville, Indiana 46799',14325,18013);
INSERT INTO "django_geo_db_zipcode" VALUES(20530,46801,-5,'Fort Wayne, Indiana 46801',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20531,46802,-5,'Fort Wayne, Indiana 46802',14326,18015);
INSERT INTO "django_geo_db_zipcode" VALUES(20532,46803,-5,'Fort Wayne, Indiana 46803',14326,18016);
INSERT INTO "django_geo_db_zipcode" VALUES(20533,46804,-5,'Fort Wayne, Indiana 46804',14326,18017);
INSERT INTO "django_geo_db_zipcode" VALUES(20534,46805,-5,'Fort Wayne, Indiana 46805',14326,18018);
INSERT INTO "django_geo_db_zipcode" VALUES(20535,46806,-5,'Fort Wayne, Indiana 46806',14326,18019);
INSERT INTO "django_geo_db_zipcode" VALUES(20536,46807,-5,'Fort Wayne, Indiana 46807',14326,18020);
INSERT INTO "django_geo_db_zipcode" VALUES(20537,46808,-5,'Fort Wayne, Indiana 46808',14326,18021);
INSERT INTO "django_geo_db_zipcode" VALUES(20538,46809,-5,'Fort Wayne, Indiana 46809',14326,18022);
INSERT INTO "django_geo_db_zipcode" VALUES(20539,46814,-5,'Fort Wayne, Indiana 46814',14326,18023);
INSERT INTO "django_geo_db_zipcode" VALUES(20540,46815,-5,'Fort Wayne, Indiana 46815',14326,18024);
INSERT INTO "django_geo_db_zipcode" VALUES(20541,46816,-5,'Fort Wayne, Indiana 46816',14326,18025);
INSERT INTO "django_geo_db_zipcode" VALUES(20542,46818,-5,'Fort Wayne, Indiana 46818',14326,18026);
INSERT INTO "django_geo_db_zipcode" VALUES(20543,46819,-5,'Fort Wayne, Indiana 46819',14326,18027);
INSERT INTO "django_geo_db_zipcode" VALUES(20544,46825,-5,'Fort Wayne, Indiana 46825',14326,18028);
INSERT INTO "django_geo_db_zipcode" VALUES(20545,46835,-5,'Fort Wayne, Indiana 46835',14326,18029);
INSERT INTO "django_geo_db_zipcode" VALUES(20546,46845,-5,'Fort Wayne, Indiana 46845',14326,18030);
INSERT INTO "django_geo_db_zipcode" VALUES(20547,46848,-5,'Huntertown, Indiana 46848',14286,18031);
INSERT INTO "django_geo_db_zipcode" VALUES(20548,46850,-5,'Fort Wayne, Indiana 46850',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20549,46851,-5,'Fort Wayne, Indiana 46851',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20550,46852,-5,'Fort Wayne, Indiana 46852',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20551,46853,-5,'Fort Wayne, Indiana 46853',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20552,46854,-5,'Fort Wayne, Indiana 46854',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20553,46855,-5,'Fort Wayne, Indiana 46855',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20554,46856,-5,'Fort Wayne, Indiana 46856',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20555,46857,-5,'Fort Wayne, Indiana 46857',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20556,46858,-5,'Fort Wayne, Indiana 46858',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20557,46859,-5,'Fort Wayne, Indiana 46859',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20558,46860,-5,'Fort Wayne, Indiana 46860',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20559,46861,-5,'Fort Wayne, Indiana 46861',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20560,46862,-5,'Fort Wayne, Indiana 46862',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20561,46863,-5,'Fort Wayne, Indiana 46863',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20562,46864,-5,'Fort Wayne, Indiana 46864',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20563,46865,-5,'Fort Wayne, Indiana 46865',14326,18032);
INSERT INTO "django_geo_db_zipcode" VALUES(20564,46866,-5,'Fort Wayne, Indiana 46866',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20565,46867,-5,'Fort Wayne, Indiana 46867',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20566,46868,-5,'Fort Wayne, Indiana 46868',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20567,46869,-5,'Fort Wayne, Indiana 46869',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20568,46885,-5,'Fort Wayne, Indiana 46885',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20569,46891,-5,'Fort Wayne, Indiana 46891',14326,18033);
INSERT INTO "django_geo_db_zipcode" VALUES(20570,46895,-5,'Fort Wayne, Indiana 46895',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20571,46896,-5,'Fort Wayne, Indiana 46896',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20572,46897,-5,'Fort Wayne, Indiana 46897',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20573,46898,-5,'Fort Wayne, Indiana 46898',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20574,46899,-5,'Fort Wayne, Indiana 46899',14326,18014);
INSERT INTO "django_geo_db_zipcode" VALUES(20575,46901,-5,'Kokomo, Indiana 46901',14327,18034);
INSERT INTO "django_geo_db_zipcode" VALUES(20576,46902,-5,'Kokomo, Indiana 46902',14327,18035);
INSERT INTO "django_geo_db_zipcode" VALUES(20577,46903,-5,'Kokomo, Indiana 46903',14327,18036);
INSERT INTO "django_geo_db_zipcode" VALUES(20578,46904,-5,'Kokomo, Indiana 46904',14327,18036);
INSERT INTO "django_geo_db_zipcode" VALUES(20579,46910,-5,'Akron, Indiana 46910',14328,18037);
INSERT INTO "django_geo_db_zipcode" VALUES(20580,46911,-5,'Amboy, Indiana 46911',14329,18038);
INSERT INTO "django_geo_db_zipcode" VALUES(20581,46912,-5,'Athens, Indiana 46912',14330,18039);
INSERT INTO "django_geo_db_zipcode" VALUES(20582,46913,-5,'Bringhurst, Indiana 46913',14331,18040);
INSERT INTO "django_geo_db_zipcode" VALUES(20583,46914,-5,'Bunker Hill, Indiana 46914',14332,18041);
INSERT INTO "django_geo_db_zipcode" VALUES(20584,46915,-5,'Burlington, Indiana 46915',14212,18042);
INSERT INTO "django_geo_db_zipcode" VALUES(20585,46916,-5,'Burrows, Indiana 46916',14333,18043);
INSERT INTO "django_geo_db_zipcode" VALUES(20586,46917,-5,'Camden, Indiana 46917',14334,18044);
INSERT INTO "django_geo_db_zipcode" VALUES(20587,46919,-5,'Converse, Indiana 46919',14335,18045);
INSERT INTO "django_geo_db_zipcode" VALUES(20588,46920,-5,'Cutler, Indiana 46920',14336,18046);
INSERT INTO "django_geo_db_zipcode" VALUES(20589,46921,-5,'Deedsville, Indiana 46921',14337,18047);
INSERT INTO "django_geo_db_zipcode" VALUES(20590,46922,-5,'Delong, Indiana 46922',14338,18039);
INSERT INTO "django_geo_db_zipcode" VALUES(20591,46923,-5,'Delphi, Indiana 46923',14339,18048);
INSERT INTO "django_geo_db_zipcode" VALUES(20592,46926,-5,'Denver, Indiana 46926',14340,18049);
INSERT INTO "django_geo_db_zipcode" VALUES(20593,46928,-5,'Fairmount, Indiana 46928',14341,18050);
INSERT INTO "django_geo_db_zipcode" VALUES(20594,46929,-5,'Flora, Indiana 46929',14342,18051);
INSERT INTO "django_geo_db_zipcode" VALUES(20595,46930,-5,'Fowlerton, Indiana 46930',14343,18052);
INSERT INTO "django_geo_db_zipcode" VALUES(20596,46931,-5,'Fulton, Indiana 46931',14344,18053);
INSERT INTO "django_geo_db_zipcode" VALUES(20597,46932,-5,'Galveston, Indiana 46932',14345,18054);
INSERT INTO "django_geo_db_zipcode" VALUES(20598,46933,-5,'Gas City, Indiana 46933',14346,18055);
INSERT INTO "django_geo_db_zipcode" VALUES(20599,46935,-5,'Grass Creek, Indiana 46935',14347,18039);
INSERT INTO "django_geo_db_zipcode" VALUES(20600,46936,-5,'Greentown, Indiana 46936',14348,18056);
INSERT INTO "django_geo_db_zipcode" VALUES(20601,46937,-5,'Hemlock, Indiana 46937',14349,18057);
INSERT INTO "django_geo_db_zipcode" VALUES(20602,46938,-5,'Jonesboro, Indiana 46938',14350,18058);
INSERT INTO "django_geo_db_zipcode" VALUES(20603,46939,-5,'Kewanna, Indiana 46939',14351,18059);
INSERT INTO "django_geo_db_zipcode" VALUES(20604,46940,-5,'La Fontaine, Indiana 46940',14352,18060);
INSERT INTO "django_geo_db_zipcode" VALUES(20605,46941,-5,'Lagro, Indiana 46941',14353,18061);
INSERT INTO "django_geo_db_zipcode" VALUES(20606,46942,-5,'Lake Cicott, Indiana 46942',14354,18062);
INSERT INTO "django_geo_db_zipcode" VALUES(20607,46943,-5,'Laketon, Indiana 46943',14355,18063);
INSERT INTO "django_geo_db_zipcode" VALUES(20608,46945,-5,'Leiters Ford, Indiana 46945',14356,18039);
INSERT INTO "django_geo_db_zipcode" VALUES(20609,46946,-5,'Liberty Mills, Indiana 46946',14357,18064);
INSERT INTO "django_geo_db_zipcode" VALUES(20610,46947,-5,'Logansport, Indiana 46947',14358,18065);
INSERT INTO "django_geo_db_zipcode" VALUES(20611,46950,-5,'Lucerne, Indiana 46950',14359,18066);
INSERT INTO "django_geo_db_zipcode" VALUES(20612,46951,-5,'Macy, Indiana 46951',14360,18067);
INSERT INTO "django_geo_db_zipcode" VALUES(20613,46952,-5,'Marion, Indiana 46952',14361,18068);
INSERT INTO "django_geo_db_zipcode" VALUES(20614,46953,-5,'Marion, Indiana 46953',14361,18069);
INSERT INTO "django_geo_db_zipcode" VALUES(20615,46957,-5,'Matthews, Indiana 46957',14362,18070);
INSERT INTO "django_geo_db_zipcode" VALUES(20616,46958,-5,'Mexico, Indiana 46958',14363,18071);
INSERT INTO "django_geo_db_zipcode" VALUES(20617,46959,-5,'Miami, Indiana 46959',14364,18072);
INSERT INTO "django_geo_db_zipcode" VALUES(20618,46960,-5,'Monterey, Indiana 46960',14365,18073);
INSERT INTO "django_geo_db_zipcode" VALUES(20619,46961,-5,'New Waverly, Indiana 46961',14366,18074);
INSERT INTO "django_geo_db_zipcode" VALUES(20620,46962,-5,'North Manchester, Indiana 46962',14367,18075);
INSERT INTO "django_geo_db_zipcode" VALUES(20621,46965,-5,'Oakford, Indiana 46965',14368,18076);
INSERT INTO "django_geo_db_zipcode" VALUES(20622,46966,-5,'Harrison, Indiana 46966',14369,18077);
INSERT INTO "django_geo_db_zipcode" VALUES(20623,46967,-5,'Onward, Indiana 46967',14370,18078);
INSERT INTO "django_geo_db_zipcode" VALUES(20624,46968,-5,'Ora, Indiana 46968',14371,18079);
INSERT INTO "django_geo_db_zipcode" VALUES(20625,46970,-5,'Peru, Indiana 46970',14372,18080);
INSERT INTO "django_geo_db_zipcode" VALUES(20626,46971,-5,'Grissom AFB, Indiana 46971',14373,18081);
INSERT INTO "django_geo_db_zipcode" VALUES(20627,46974,-5,'Roann, Indiana 46974',14374,18082);
INSERT INTO "django_geo_db_zipcode" VALUES(20628,46975,-5,'Rochester, Indiana 46975',14375,18083);
INSERT INTO "django_geo_db_zipcode" VALUES(20629,46977,-5,'Rockfield, Indiana 46977',14376,18043);
INSERT INTO "django_geo_db_zipcode" VALUES(20630,46978,-5,'Royal Center, Indiana 46978',14377,18084);
INSERT INTO "django_geo_db_zipcode" VALUES(20631,46979,-5,'Russiaville, Indiana 46979',14190,18085);
INSERT INTO "django_geo_db_zipcode" VALUES(20632,46980,-5,'Servia, Indiana 46980',14378,18086);
INSERT INTO "django_geo_db_zipcode" VALUES(20633,46982,-5,'Silver Lake, Indiana 46982',14379,18087);
INSERT INTO "django_geo_db_zipcode" VALUES(20634,46984,-5,'Somerset, Indiana 46984',14380,18088);
INSERT INTO "django_geo_db_zipcode" VALUES(20635,46985,-5,'Star City, Indiana 46985',14381,18089);
INSERT INTO "django_geo_db_zipcode" VALUES(20636,46986,-5,'Swayzee, Indiana 46986',14382,18090);
INSERT INTO "django_geo_db_zipcode" VALUES(20637,46987,-5,'Sweetser, Indiana 46987',14383,18091);
INSERT INTO "django_geo_db_zipcode" VALUES(20638,46988,-5,'Twelve Mile, Indiana 46988',14384,18092);
INSERT INTO "django_geo_db_zipcode" VALUES(20639,46989,-5,'Upland, Indiana 46989',14385,18093);
INSERT INTO "django_geo_db_zipcode" VALUES(20640,46990,-5,'Urbana, Indiana 46990',14386,18094);
INSERT INTO "django_geo_db_zipcode" VALUES(20641,46991,-5,'Van Buren, Indiana 46991',14387,18095);
INSERT INTO "django_geo_db_zipcode" VALUES(20642,46992,-5,'Wabash, Indiana 46992',14388,18096);
INSERT INTO "django_geo_db_zipcode" VALUES(20643,46994,-5,'Walton, Indiana 46994',14389,18097);
INSERT INTO "django_geo_db_zipcode" VALUES(20644,46995,-5,'West Middleton, Indiana 46995',14390,18098);
INSERT INTO "django_geo_db_zipcode" VALUES(20645,46996,-5,'Winamac, Indiana 46996',14391,18099);
INSERT INTO "django_geo_db_zipcode" VALUES(20646,46998,-5,'Young America, Indiana 46998',14392,18100);
INSERT INTO "django_geo_db_zipcode" VALUES(20647,47001,-5,'Aurora, Indiana 47001',14393,18101);
INSERT INTO "django_geo_db_zipcode" VALUES(20648,47003,-5,'West College Corner, Indiana 47003',14394,18102);
INSERT INTO "django_geo_db_zipcode" VALUES(20649,47006,-5,'Batesville, Indiana 47006',14395,18103);
INSERT INTO "django_geo_db_zipcode" VALUES(20650,47010,-5,'Bath, Indiana 47010',14396,18104);
INSERT INTO "django_geo_db_zipcode" VALUES(20651,47011,-5,'Bennington, Indiana 47011',14397,18105);
INSERT INTO "django_geo_db_zipcode" VALUES(20652,47012,-5,'Brookville, Indiana 47012',14398,18106);
INSERT INTO "django_geo_db_zipcode" VALUES(20653,47016,-5,'Cedar Grove, Indiana 47016',14399,18107);
INSERT INTO "django_geo_db_zipcode" VALUES(20654,47017,-5,'Cross Plains, Indiana 47017',14400,18108);
INSERT INTO "django_geo_db_zipcode" VALUES(20655,47018,-5,'Dillsboro, Indiana 47018',14401,18109);
INSERT INTO "django_geo_db_zipcode" VALUES(20656,47019,-5,'East Enterprise, Indiana 47019',14402,18110);
INSERT INTO "django_geo_db_zipcode" VALUES(20657,47020,-5,'Florence, Indiana 47020',14403,18111);
INSERT INTO "django_geo_db_zipcode" VALUES(20658,47021,-5,'Friendship, Indiana 47021',14404,18112);
INSERT INTO "django_geo_db_zipcode" VALUES(20659,47022,-5,'Guilford, Indiana 47022',14405,18113);
INSERT INTO "django_geo_db_zipcode" VALUES(20660,47023,-5,'Holton, Indiana 47023',14406,18114);
INSERT INTO "django_geo_db_zipcode" VALUES(20661,47024,-5,'Laurel, Indiana 47024',14407,18115);
INSERT INTO "django_geo_db_zipcode" VALUES(20662,47025,-5,'Lawrenceburg, Indiana 47025',14408,18116);
INSERT INTO "django_geo_db_zipcode" VALUES(20663,47030,-5,'Metamora, Indiana 47030',14409,18117);
INSERT INTO "django_geo_db_zipcode" VALUES(20664,47031,-5,'Milan, Indiana 47031',14410,18118);
INSERT INTO "django_geo_db_zipcode" VALUES(20665,47032,-5,'Moores Hill, Indiana 47032',14411,18119);
INSERT INTO "django_geo_db_zipcode" VALUES(20666,47033,-5,'Morris, Indiana 47033',14412,18120);
INSERT INTO "django_geo_db_zipcode" VALUES(20667,47034,-5,'Napoleon, Indiana 47034',14413,18121);
INSERT INTO "django_geo_db_zipcode" VALUES(20668,47035,-5,'New Trenton, Indiana 47035',14414,18122);
INSERT INTO "django_geo_db_zipcode" VALUES(20669,47036,-5,'Oldenburg, Indiana 47036',14415,18123);
INSERT INTO "django_geo_db_zipcode" VALUES(20670,47037,-5,'Osgood, Indiana 47037',14416,18124);
INSERT INTO "django_geo_db_zipcode" VALUES(20671,47038,-5,'Patriot, Indiana 47038',14417,18125);
INSERT INTO "django_geo_db_zipcode" VALUES(20672,47039,-5,'Pierceville, Indiana 47039',14418,18126);
INSERT INTO "django_geo_db_zipcode" VALUES(20673,47040,-5,'Rising Sun, Indiana 47040',14419,18127);
INSERT INTO "django_geo_db_zipcode" VALUES(20674,47041,-5,'Sunman, Indiana 47041',14420,18128);
INSERT INTO "django_geo_db_zipcode" VALUES(20675,47042,-5,'Versailles, Indiana 47042',14421,18129);
INSERT INTO "django_geo_db_zipcode" VALUES(20676,47043,-5,'Vevay, Indiana 47043',14422,18130);
INSERT INTO "django_geo_db_zipcode" VALUES(20677,47045,-5,'Jefferson, Indiana 47045',14423,18131);
INSERT INTO "django_geo_db_zipcode" VALUES(20678,47048,-5,'Bloomington, Indiana 47048',14424,18132);
INSERT INTO "django_geo_db_zipcode" VALUES(20679,47060,-5,'West Harrison, Indiana 47060',14425,18133);
INSERT INTO "django_geo_db_zipcode" VALUES(20680,47070,-5,'Lovett, Indiana 47070',14426,18134);
INSERT INTO "django_geo_db_zipcode" VALUES(20681,47093,-5,'Jefferson, Indiana 47093',14423,18135);
INSERT INTO "django_geo_db_zipcode" VALUES(20682,47102,-5,'Austin, Indiana 47102',14427,18136);
INSERT INTO "django_geo_db_zipcode" VALUES(20683,47104,-5,'Bethlehem, Indiana 47104',14428,18137);
INSERT INTO "django_geo_db_zipcode" VALUES(20684,47106,-5,'Borden, Indiana 47106',14429,18138);
INSERT INTO "django_geo_db_zipcode" VALUES(20685,47107,-5,'Bradford, Indiana 47107',14430,18139);
INSERT INTO "django_geo_db_zipcode" VALUES(20686,47108,-5,'Campbellsburg, Indiana 47108',14431,18140);
INSERT INTO "django_geo_db_zipcode" VALUES(20687,47110,-5,'Central, Indiana 47110',14432,18141);
INSERT INTO "django_geo_db_zipcode" VALUES(20688,47111,-5,'Charlestown, Indiana 47111',14433,18142);
INSERT INTO "django_geo_db_zipcode" VALUES(20689,47112,-5,'Corydon, Indiana 47112',14434,18143);
INSERT INTO "django_geo_db_zipcode" VALUES(20690,47114,-5,'Crandall, Indiana 47114',14435,18144);
INSERT INTO "django_geo_db_zipcode" VALUES(20691,47115,-5,'Depauw, Indiana 47115',14436,18145);
INSERT INTO "django_geo_db_zipcode" VALUES(20692,47116,-5,'Eckerty, Indiana 47116',14437,18146);
INSERT INTO "django_geo_db_zipcode" VALUES(20693,47117,-5,'Elizabeth, Indiana 47117',14438,18147);
INSERT INTO "django_geo_db_zipcode" VALUES(20694,47118,-5,'English, Indiana 47118',14439,18148);
INSERT INTO "django_geo_db_zipcode" VALUES(20695,47119,-5,'Floyds Knobs, Indiana 47119',14440,18149);
INSERT INTO "django_geo_db_zipcode" VALUES(20696,47120,-5,'Fredericksburg, Indiana 47120',14441,18150);
INSERT INTO "django_geo_db_zipcode" VALUES(20697,47122,-5,'Georgetown, Indiana 47122',14442,18151);
INSERT INTO "django_geo_db_zipcode" VALUES(20698,47123,-5,'Grantsburg, Indiana 47123',14443,18152);
INSERT INTO "django_geo_db_zipcode" VALUES(20699,47124,-5,'Greenville, Indiana 47124',14444,18153);
INSERT INTO "django_geo_db_zipcode" VALUES(20700,47125,-5,'Hardinsburg, Indiana 47125',14445,18154);
INSERT INTO "django_geo_db_zipcode" VALUES(20701,47126,-5,'Henryville, Indiana 47126',14446,18155);
INSERT INTO "django_geo_db_zipcode" VALUES(20702,47128,-5,'Madison, Indiana 47128',14223,18156);
INSERT INTO "django_geo_db_zipcode" VALUES(20703,47129,-5,'Clarksville, Indiana 47129',14447,18157);
INSERT INTO "django_geo_db_zipcode" VALUES(20704,47130,-5,'Jeffersonville, Indiana 47130',14448,18158);
INSERT INTO "django_geo_db_zipcode" VALUES(20705,47131,-5,'Jeffersonville, Indiana 47131',14448,18159);
INSERT INTO "django_geo_db_zipcode" VALUES(20706,47132,-5,'Jeffersonville, Indiana 47132',14448,18160);
INSERT INTO "django_geo_db_zipcode" VALUES(20707,47133,-5,'Jeffersonville, Indiana 47133',14448,18160);
INSERT INTO "django_geo_db_zipcode" VALUES(20708,47134,-5,'Jeffersonville, Indiana 47134',14448,18160);
INSERT INTO "django_geo_db_zipcode" VALUES(20709,47135,-5,'Laconia, Indiana 47135',14449,18161);
INSERT INTO "django_geo_db_zipcode" VALUES(20710,47136,-5,'Lanesville, Indiana 47136',14450,18162);
INSERT INTO "django_geo_db_zipcode" VALUES(20711,47137,-5,'Leavenworth, Indiana 47137',14451,18163);
INSERT INTO "django_geo_db_zipcode" VALUES(20712,47138,-5,'Lexington, Indiana 47138',14452,18164);
INSERT INTO "django_geo_db_zipcode" VALUES(20713,47139,-5,'Little York, Indiana 47139',14453,18165);
INSERT INTO "django_geo_db_zipcode" VALUES(20714,47140,-5,'Marengo, Indiana 47140',14454,18166);
INSERT INTO "django_geo_db_zipcode" VALUES(20715,47141,-5,'Marysville, Indiana 47141',14455,18167);
INSERT INTO "django_geo_db_zipcode" VALUES(20716,47142,-5,'Mauckport, Indiana 47142',14456,18168);
INSERT INTO "django_geo_db_zipcode" VALUES(20717,47143,-5,'Memphis, Indiana 47143',14457,18169);
INSERT INTO "django_geo_db_zipcode" VALUES(20718,47144,-5,'Jeffersonville, Indiana 47144',14448,18160);
INSERT INTO "django_geo_db_zipcode" VALUES(20719,47145,-5,'Milltown, Indiana 47145',14458,18170);
INSERT INTO "django_geo_db_zipcode" VALUES(20720,47146,-5,'Mount Saint Francis, Indiana 47146',14459,18171);
INSERT INTO "django_geo_db_zipcode" VALUES(20721,47147,-5,'Nabb, Indiana 47147',14460,18172);
INSERT INTO "django_geo_db_zipcode" VALUES(20722,47150,-5,'New Albany, Indiana 47150',14461,18173);
INSERT INTO "django_geo_db_zipcode" VALUES(20723,47151,-5,'New Albany, Indiana 47151',14461,18171);
INSERT INTO "django_geo_db_zipcode" VALUES(20724,47160,-5,'New Middletown, Indiana 47160',14462,18174);
INSERT INTO "django_geo_db_zipcode" VALUES(20725,47161,-5,'New Salisbury, Indiana 47161',14463,18175);
INSERT INTO "django_geo_db_zipcode" VALUES(20726,47162,-5,'New Washington, Indiana 47162',14464,18176);
INSERT INTO "django_geo_db_zipcode" VALUES(20727,47163,-5,'Otisco, Indiana 47163',14465,18177);
INSERT INTO "django_geo_db_zipcode" VALUES(20728,47164,-5,'Palmyra, Indiana 47164',14466,18178);
INSERT INTO "django_geo_db_zipcode" VALUES(20729,47165,-5,'Pekin, Indiana 47165',14467,18179);
INSERT INTO "django_geo_db_zipcode" VALUES(20730,47166,-5,'Ramsey, Indiana 47166',14468,18180);
INSERT INTO "django_geo_db_zipcode" VALUES(20731,47167,-5,'Salem, Indiana 47167',14469,18181);
INSERT INTO "django_geo_db_zipcode" VALUES(20732,47169,-5,'Washington, Indiana 47169',14161,18182);
INSERT INTO "django_geo_db_zipcode" VALUES(20733,47170,-5,'Scottsburg, Indiana 47170',14470,18183);
INSERT INTO "django_geo_db_zipcode" VALUES(20734,47172,-5,'Sellersburg, Indiana 47172',14471,18184);
INSERT INTO "django_geo_db_zipcode" VALUES(20735,47174,-5,'Sulphur, Indiana 47174',14472,18185);
INSERT INTO "django_geo_db_zipcode" VALUES(20736,47175,-5,'Taswell, Indiana 47175',14473,18186);
INSERT INTO "django_geo_db_zipcode" VALUES(20737,47177,-5,'Underwood, Indiana 47177',14474,18187);
INSERT INTO "django_geo_db_zipcode" VALUES(20738,47190,-5,'Jeffersonville, Indiana 47190',14448,18159);
INSERT INTO "django_geo_db_zipcode" VALUES(20739,47199,-5,'Jeffersonville, Indiana 47199',14448,18160);
INSERT INTO "django_geo_db_zipcode" VALUES(20740,47201,-5,'Columbus, Indiana 47201',14475,18188);
INSERT INTO "django_geo_db_zipcode" VALUES(20741,47202,-5,'Columbus, Indiana 47202',14475,18189);
INSERT INTO "django_geo_db_zipcode" VALUES(20742,47203,-5,'Columbus, Indiana 47203',14475,18190);
INSERT INTO "django_geo_db_zipcode" VALUES(20743,47220,-5,'Brownstown, Indiana 47220',14476,18191);
INSERT INTO "django_geo_db_zipcode" VALUES(20744,47223,-5,'Butlerville, Indiana 47223',14477,18192);
INSERT INTO "django_geo_db_zipcode" VALUES(20745,47224,-5,'Canaan, Indiana 47224',14478,18193);
INSERT INTO "django_geo_db_zipcode" VALUES(20746,47225,-5,'Clarksburg, Indiana 47225',14479,18194);
INSERT INTO "django_geo_db_zipcode" VALUES(20747,47226,-5,'Clifford, Indiana 47226',14480,18195);
INSERT INTO "django_geo_db_zipcode" VALUES(20748,47227,-5,'Commiskey, Indiana 47227',14481,18196);
INSERT INTO "django_geo_db_zipcode" VALUES(20749,47228,-5,'Cortland, Indiana 47228',14482,18197);
INSERT INTO "django_geo_db_zipcode" VALUES(20750,47229,-5,'Crothersville, Indiana 47229',14483,18198);
INSERT INTO "django_geo_db_zipcode" VALUES(20751,47230,-5,'Deputy, Indiana 47230',14484,18199);
INSERT INTO "django_geo_db_zipcode" VALUES(20752,47231,-5,'Dupont, Indiana 47231',14485,18200);
INSERT INTO "django_geo_db_zipcode" VALUES(20753,47232,-5,'Elizabethtown, Indiana 47232',14486,18201);
INSERT INTO "django_geo_db_zipcode" VALUES(20754,47234,-5,'Flat Rock, Indiana 47234',14487,18202);
INSERT INTO "django_geo_db_zipcode" VALUES(20755,47235,-5,'Freetown, Indiana 47235',14488,18203);
INSERT INTO "django_geo_db_zipcode" VALUES(20756,47236,-5,'Grammer, Indiana 47236',14489,18204);
INSERT INTO "django_geo_db_zipcode" VALUES(20757,47240,-5,'Greensburg, Indiana 47240',14490,18205);
INSERT INTO "django_geo_db_zipcode" VALUES(20758,47241,-5,'Bedford, Indiana 47241',14491,18206);
INSERT INTO "django_geo_db_zipcode" VALUES(20759,47243,-5,'Hanover, Indiana 47243',14492,18207);
INSERT INTO "django_geo_db_zipcode" VALUES(20760,47244,-5,'Hartsville, Indiana 47244',14493,18208);
INSERT INTO "django_geo_db_zipcode" VALUES(20761,47245,-5,'Hayden, Indiana 47245',14494,18209);
INSERT INTO "django_geo_db_zipcode" VALUES(20762,47246,-5,'Hope, Indiana 47246',14495,18210);
INSERT INTO "django_geo_db_zipcode" VALUES(20763,47247,-5,'Jonesville, Indiana 47247',14496,18211);
INSERT INTO "django_geo_db_zipcode" VALUES(20764,47249,-5,'Kurtz, Indiana 47249',14497,18212);
INSERT INTO "django_geo_db_zipcode" VALUES(20765,47250,-5,'Madison, Indiana 47250',14223,18213);
INSERT INTO "django_geo_db_zipcode" VALUES(20766,47256,-5,'North Vernon, Indiana 47256',14498,18214);
INSERT INTO "django_geo_db_zipcode" VALUES(20767,47257,-5,'North Vernon, Indiana 47257',14498,18215);
INSERT INTO "django_geo_db_zipcode" VALUES(20768,47260,-5,'Medora, Indiana 47260',14499,18216);
INSERT INTO "django_geo_db_zipcode" VALUES(20769,47261,-5,'Millhousen, Indiana 47261',14500,18217);
INSERT INTO "django_geo_db_zipcode" VALUES(20770,47262,-5,'Nebraska, Indiana 47262',14501,18209);
INSERT INTO "django_geo_db_zipcode" VALUES(20771,47263,-5,'New Point, Indiana 47263',14502,18218);
INSERT INTO "django_geo_db_zipcode" VALUES(20772,47264,-5,'Norman, Indiana 47264',14503,18219);
INSERT INTO "django_geo_db_zipcode" VALUES(20773,47265,-5,'North Vernon, Indiana 47265',14498,18220);
INSERT INTO "django_geo_db_zipcode" VALUES(20774,47270,-5,'Paris Crossing, Indiana 47270',14504,18221);
INSERT INTO "django_geo_db_zipcode" VALUES(20775,47272,-5,'Saint Paul, Indiana 47272',14505,18222);
INSERT INTO "django_geo_db_zipcode" VALUES(20776,47273,-5,'Scipio, Indiana 47273',14506,18223);
INSERT INTO "django_geo_db_zipcode" VALUES(20777,47274,-5,'Seymour, Indiana 47274',14507,18224);
INSERT INTO "django_geo_db_zipcode" VALUES(20778,47280,-5,'Taylorsville, Indiana 47280',14508,18225);
INSERT INTO "django_geo_db_zipcode" VALUES(20779,47281,-5,'Vallonia, Indiana 47281',14509,18226);
INSERT INTO "django_geo_db_zipcode" VALUES(20780,47282,-5,'Vernon, Indiana 47282',14510,18227);
INSERT INTO "django_geo_db_zipcode" VALUES(20781,47283,-5,'Westport, Indiana 47283',14511,18228);
INSERT INTO "django_geo_db_zipcode" VALUES(20782,47288,-5,'Cayuga, Indiana 47288',14512,18229);
INSERT INTO "django_geo_db_zipcode" VALUES(20783,47302,-5,'Muncie, Indiana 47302',14513,18230);
INSERT INTO "django_geo_db_zipcode" VALUES(20784,47303,-5,'Muncie, Indiana 47303',14513,18231);
INSERT INTO "django_geo_db_zipcode" VALUES(20785,47304,-5,'Muncie, Indiana 47304',14513,18232);
INSERT INTO "django_geo_db_zipcode" VALUES(20786,47305,-5,'Muncie, Indiana 47305',14513,18233);
INSERT INTO "django_geo_db_zipcode" VALUES(20787,47306,-5,'Muncie, Indiana 47306',14513,18234);
INSERT INTO "django_geo_db_zipcode" VALUES(20788,47307,-5,'Muncie, Indiana 47307',14513,18235);
INSERT INTO "django_geo_db_zipcode" VALUES(20789,47308,-5,'Muncie, Indiana 47308',14513,18236);
INSERT INTO "django_geo_db_zipcode" VALUES(20790,47317,-5,'Kennard, Indiana 47317',14514,18237);
INSERT INTO "django_geo_db_zipcode" VALUES(20791,47320,-5,'Albany, Indiana 47320',14515,18238);
INSERT INTO "django_geo_db_zipcode" VALUES(20792,47322,-5,'Bentonville, Indiana 47322',14516,18239);
INSERT INTO "django_geo_db_zipcode" VALUES(20793,47324,-5,'Boston, Indiana 47324',14517,18240);
INSERT INTO "django_geo_db_zipcode" VALUES(20794,47325,-5,'Brownsville, Indiana 47325',14518,18241);
INSERT INTO "django_geo_db_zipcode" VALUES(20795,47326,-5,'Bryant, Indiana 47326',14519,18242);
INSERT INTO "django_geo_db_zipcode" VALUES(20796,47327,-5,'Cambridge City, Indiana 47327',14520,18243);
INSERT INTO "django_geo_db_zipcode" VALUES(20797,47330,-5,'Centerville, Indiana 47330',14521,18244);
INSERT INTO "django_geo_db_zipcode" VALUES(20798,47331,-5,'Connersville, Indiana 47331',14522,18245);
INSERT INTO "django_geo_db_zipcode" VALUES(20799,47334,-5,'Daleville, Indiana 47334',14523,18246);
INSERT INTO "django_geo_db_zipcode" VALUES(20800,47335,-5,'Dublin, Indiana 47335',14524,18247);
INSERT INTO "django_geo_db_zipcode" VALUES(20801,47336,-5,'Dunkirk, Indiana 47336',14525,18248);
INSERT INTO "django_geo_db_zipcode" VALUES(20802,47337,-5,'Dunreith, Indiana 47337',14526,18249);
INSERT INTO "django_geo_db_zipcode" VALUES(20803,47338,-5,'Eaton, Indiana 47338',14527,18250);
INSERT INTO "django_geo_db_zipcode" VALUES(20804,47339,-5,'Economy, Indiana 47339',14528,18251);
INSERT INTO "django_geo_db_zipcode" VALUES(20805,47340,-5,'Farmland, Indiana 47340',14529,18252);
INSERT INTO "django_geo_db_zipcode" VALUES(20806,47341,-5,'Fountain City, Indiana 47341',14530,18253);
INSERT INTO "django_geo_db_zipcode" VALUES(20807,47342,-5,'Gaston, Indiana 47342',14531,18254);
INSERT INTO "django_geo_db_zipcode" VALUES(20808,47344,-5,'Greensboro, Indiana 47344',14532,18255);
INSERT INTO "django_geo_db_zipcode" VALUES(20809,47345,-5,'Greens Fork, Indiana 47345',14533,18256);
INSERT INTO "django_geo_db_zipcode" VALUES(20810,47346,-5,'Hagerstown, Indiana 47346',14534,18257);
INSERT INTO "django_geo_db_zipcode" VALUES(20811,47348,-5,'Hartford City, Indiana 47348',14535,18258);
INSERT INTO "django_geo_db_zipcode" VALUES(20812,47351,-5,'Kennard, Indiana 47351',14514,18259);
INSERT INTO "django_geo_db_zipcode" VALUES(20813,47352,-5,'Lewisville, Indiana 47352',14536,18260);
INSERT INTO "django_geo_db_zipcode" VALUES(20814,47353,-5,'Liberty, Indiana 47353',14537,18261);
INSERT INTO "django_geo_db_zipcode" VALUES(20815,47354,-5,'Losantville, Indiana 47354',14538,18262);
INSERT INTO "django_geo_db_zipcode" VALUES(20816,47355,-5,'Lynn, Indiana 47355',14539,18263);
INSERT INTO "django_geo_db_zipcode" VALUES(20817,47356,-5,'Middletown, Indiana 47356',14540,18264);
INSERT INTO "django_geo_db_zipcode" VALUES(20818,47357,-5,'Milton, Indiana 47357',14541,18265);
INSERT INTO "django_geo_db_zipcode" VALUES(20819,47358,-5,'Modoc, Indiana 47358',14542,18266);
INSERT INTO "django_geo_db_zipcode" VALUES(20820,47359,-5,'Montpelier, Indiana 47359',14543,18267);
INSERT INTO "django_geo_db_zipcode" VALUES(20821,47360,-5,'Mooreland, Indiana 47360',14544,18268);
INSERT INTO "django_geo_db_zipcode" VALUES(20822,47361,-5,'Mount Summit, Indiana 47361',14545,18269);
INSERT INTO "django_geo_db_zipcode" VALUES(20823,47362,-5,'New Castle, Indiana 47362',14546,18270);
INSERT INTO "django_geo_db_zipcode" VALUES(20824,47366,-5,'New Lisbon, Indiana 47366',14547,18271);
INSERT INTO "django_geo_db_zipcode" VALUES(20825,47367,-5,'Oakville, Indiana 47367',14548,18272);
INSERT INTO "django_geo_db_zipcode" VALUES(20826,47368,-5,'Parker City, Indiana 47368',14549,18273);
INSERT INTO "django_geo_db_zipcode" VALUES(20827,47369,-5,'Pennville, Indiana 47369',14550,18274);
INSERT INTO "django_geo_db_zipcode" VALUES(20828,47370,-5,'Pershing, Indiana 47370',14551,18275);
INSERT INTO "django_geo_db_zipcode" VALUES(20829,47371,-5,'Portland, Indiana 47371',14552,18276);
INSERT INTO "django_geo_db_zipcode" VALUES(20830,47373,-5,'Redkey, Indiana 47373',14553,18277);
INSERT INTO "django_geo_db_zipcode" VALUES(20831,47374,-5,'Richmond, Indiana 47374',14554,18278);
INSERT INTO "django_geo_db_zipcode" VALUES(20832,47375,-5,'Richmond, Indiana 47375',14554,18279);
INSERT INTO "django_geo_db_zipcode" VALUES(20833,47380,-5,'Ridgeville, Indiana 47380',14555,18280);
INSERT INTO "django_geo_db_zipcode" VALUES(20834,47381,-5,'Salamonia, Indiana 47381',14556,18281);
INSERT INTO "django_geo_db_zipcode" VALUES(20835,47382,-5,'Saratoga, Indiana 47382',14557,18282);
INSERT INTO "django_geo_db_zipcode" VALUES(20836,47383,-5,'Selma, Indiana 47383',14558,18283);
INSERT INTO "django_geo_db_zipcode" VALUES(20837,47384,-5,'Shirley, Indiana 47384',14559,18284);
INSERT INTO "django_geo_db_zipcode" VALUES(20838,47385,-5,'Spiceland, Indiana 47385',14560,18285);
INSERT INTO "django_geo_db_zipcode" VALUES(20839,47386,-5,'Springport, Indiana 47386',14561,18286);
INSERT INTO "django_geo_db_zipcode" VALUES(20840,47387,-5,'Straughn, Indiana 47387',14562,18287);
INSERT INTO "django_geo_db_zipcode" VALUES(20841,47388,-5,'Sulphur Springs, Indiana 47388',14563,18288);
INSERT INTO "django_geo_db_zipcode" VALUES(20842,47390,-5,'Union City, Indiana 47390',14564,18289);
INSERT INTO "django_geo_db_zipcode" VALUES(20843,47392,-5,'Webster, Indiana 47392',14565,18290);
INSERT INTO "django_geo_db_zipcode" VALUES(20844,47393,-5,'Williamsburg, Indiana 47393',14566,18291);
INSERT INTO "django_geo_db_zipcode" VALUES(20845,47394,-5,'Winchester, Indiana 47394',14567,18292);
INSERT INTO "django_geo_db_zipcode" VALUES(20846,47395,-5,'Lynn, Indiana 47395',14539,18293);
INSERT INTO "django_geo_db_zipcode" VALUES(20847,47396,-5,'Yorktown, Indiana 47396',14568,18294);
INSERT INTO "django_geo_db_zipcode" VALUES(20848,47398,-5,'Hartford City, Indiana 47398',14535,18295);
INSERT INTO "django_geo_db_zipcode" VALUES(20849,47401,-5,'Bloomington, Indiana 47401',14424,18296);
INSERT INTO "django_geo_db_zipcode" VALUES(20850,47402,-5,'Bloomington, Indiana 47402',14424,18297);
INSERT INTO "django_geo_db_zipcode" VALUES(20851,47403,-5,'Bloomington, Indiana 47403',14424,18298);
INSERT INTO "django_geo_db_zipcode" VALUES(20852,47404,-5,'Bloomington, Indiana 47404',14424,18299);
INSERT INTO "django_geo_db_zipcode" VALUES(20853,47405,-5,'Bloomington, Indiana 47405',14424,18300);
INSERT INTO "django_geo_db_zipcode" VALUES(20854,47406,-5,'Bloomington, Indiana 47406',14424,18301);
INSERT INTO "django_geo_db_zipcode" VALUES(20855,47407,-5,'Bloomington, Indiana 47407',14424,18297);
INSERT INTO "django_geo_db_zipcode" VALUES(20856,47408,-5,'Bloomington, Indiana 47408',14424,18302);
INSERT INTO "django_geo_db_zipcode" VALUES(20857,47412,-6,'Evansville, Indiana 47412',14569,18303);
INSERT INTO "django_geo_db_zipcode" VALUES(20858,47420,-5,'Avoca, Indiana 47420',14570,18304);
INSERT INTO "django_geo_db_zipcode" VALUES(20859,47421,-5,'Bedford, Indiana 47421',14491,18305);
INSERT INTO "django_geo_db_zipcode" VALUES(20860,47424,-5,'Bloomfield, Indiana 47424',14571,18306);
INSERT INTO "django_geo_db_zipcode" VALUES(20861,47426,-5,'Clear Creek, Indiana 47426',14572,18297);
INSERT INTO "django_geo_db_zipcode" VALUES(20862,47427,-5,'Coal City, Indiana 47427',14573,18307);
INSERT INTO "django_geo_db_zipcode" VALUES(20863,47429,-5,'Ellettsville, Indiana 47429',14574,18308);
INSERT INTO "django_geo_db_zipcode" VALUES(20864,47430,-5,'Fort Ritner, Indiana 47430',14575,18309);
INSERT INTO "django_geo_db_zipcode" VALUES(20865,47431,-5,'Freedom, Indiana 47431',14576,18310);
INSERT INTO "django_geo_db_zipcode" VALUES(20866,47432,-5,'French Lick, Indiana 47432',14577,18311);
INSERT INTO "django_geo_db_zipcode" VALUES(20867,47433,-5,'Gosport, Indiana 47433',14578,18312);
INSERT INTO "django_geo_db_zipcode" VALUES(20868,47434,-5,'Harrodsburg, Indiana 47434',14579,18313);
INSERT INTO "django_geo_db_zipcode" VALUES(20869,47435,-5,'Helmsburg, Indiana 47435',14580,18314);
INSERT INTO "django_geo_db_zipcode" VALUES(20870,47436,-5,'Heltonville, Indiana 47436',14581,18315);
INSERT INTO "django_geo_db_zipcode" VALUES(20871,47437,-5,'Huron, Indiana 47437',14582,18316);
INSERT INTO "django_geo_db_zipcode" VALUES(20872,47438,-5,'Jasonville, Indiana 47438',14583,18317);
INSERT INTO "django_geo_db_zipcode" VALUES(20873,47439,-5,'Koleen, Indiana 47439',14584,18318);
INSERT INTO "django_geo_db_zipcode" VALUES(20874,47441,-5,'Linton, Indiana 47441',14585,18319);
INSERT INTO "django_geo_db_zipcode" VALUES(20875,47443,-5,'Lyons, Indiana 47443',14586,18320);
INSERT INTO "django_geo_db_zipcode" VALUES(20876,47445,-5,'Midland, Indiana 47445',14587,18321);
INSERT INTO "django_geo_db_zipcode" VALUES(20877,47446,-5,'Mitchell, Indiana 47446',14588,18322);
INSERT INTO "django_geo_db_zipcode" VALUES(20878,47448,-5,'Nashville, Indiana 47448',14589,18323);
INSERT INTO "django_geo_db_zipcode" VALUES(20879,47449,-5,'Newberry, Indiana 47449',14590,18324);
INSERT INTO "django_geo_db_zipcode" VALUES(20880,47451,-5,'Oolitic, Indiana 47451',14591,18325);
INSERT INTO "django_geo_db_zipcode" VALUES(20881,47452,-5,'Orleans, Indiana 47452',14592,18326);
INSERT INTO "django_geo_db_zipcode" VALUES(20882,47453,-5,'Owensburg, Indiana 47453',14593,18327);
INSERT INTO "django_geo_db_zipcode" VALUES(20883,47454,-5,'Paoli, Indiana 47454',14594,18328);
INSERT INTO "django_geo_db_zipcode" VALUES(20884,47455,-5,'Patricksburg, Indiana 47455',14595,18329);
INSERT INTO "django_geo_db_zipcode" VALUES(20885,47456,-5,'Quincy, Indiana 47456',14596,18330);
INSERT INTO "django_geo_db_zipcode" VALUES(20886,47457,-5,'Scotland, Indiana 47457',14597,18318);
INSERT INTO "django_geo_db_zipcode" VALUES(20887,47458,-5,'Smithville, Indiana 47458',14598,18297);
INSERT INTO "django_geo_db_zipcode" VALUES(20888,47459,-5,'Solsberry, Indiana 47459',14599,18331);
INSERT INTO "django_geo_db_zipcode" VALUES(20889,47460,-5,'Spencer, Indiana 47460',14600,18332);
INSERT INTO "django_geo_db_zipcode" VALUES(20890,47462,-5,'Springville, Indiana 47462',14601,18333);
INSERT INTO "django_geo_db_zipcode" VALUES(20891,47463,-5,'Stanford, Indiana 47463',14602,18334);
INSERT INTO "django_geo_db_zipcode" VALUES(20892,47464,-5,'Stinesville, Indiana 47464',14603,18335);
INSERT INTO "django_geo_db_zipcode" VALUES(20893,47465,-5,'Switz City, Indiana 47465',14604,18336);
INSERT INTO "django_geo_db_zipcode" VALUES(20894,47467,-5,'Tunnelton, Indiana 47467',14605,18337);
INSERT INTO "django_geo_db_zipcode" VALUES(20895,47468,-5,'Unionville, Indiana 47468',14606,18338);
INSERT INTO "django_geo_db_zipcode" VALUES(20896,47469,-5,'West Baden Springs, Indiana 47469',14607,18339);
INSERT INTO "django_geo_db_zipcode" VALUES(20897,47470,-5,'Williams, Indiana 47470',14608,18340);
INSERT INTO "django_geo_db_zipcode" VALUES(20898,47471,-5,'Worthington, Indiana 47471',14609,18341);
INSERT INTO "django_geo_db_zipcode" VALUES(20899,47485,-5,'Lewis, Indiana 47485',14610,18342);
INSERT INTO "django_geo_db_zipcode" VALUES(20900,47488,-5,'Hamblen, Indiana 47488',14611,18343);
INSERT INTO "django_geo_db_zipcode" VALUES(20901,47490,-5,'Bloomington, Indiana 47490',14424,18297);
INSERT INTO "django_geo_db_zipcode" VALUES(20902,47501,-5,'Washington, Indiana 47501',14161,18344);
INSERT INTO "django_geo_db_zipcode" VALUES(20903,47512,-5,'Bicknell, Indiana 47512',14612,18345);
INSERT INTO "django_geo_db_zipcode" VALUES(20904,47513,-5,'Birdseye, Indiana 47513',14613,18346);
INSERT INTO "django_geo_db_zipcode" VALUES(20905,47514,-5,'Branchville, Indiana 47514',14614,18347);
INSERT INTO "django_geo_db_zipcode" VALUES(20906,47515,-5,'Bristow, Indiana 47515',14615,18348);
INSERT INTO "django_geo_db_zipcode" VALUES(20907,47516,-5,'Bruceville, Indiana 47516',14616,18349);
INSERT INTO "django_geo_db_zipcode" VALUES(20908,47519,-5,'Cannelburg, Indiana 47519',14617,18350);
INSERT INTO "django_geo_db_zipcode" VALUES(20909,47520,-5,'Cannelton, Indiana 47520',14618,18351);
INSERT INTO "django_geo_db_zipcode" VALUES(20910,47521,-5,'Celestine, Indiana 47521',14619,18352);
INSERT INTO "django_geo_db_zipcode" VALUES(20911,47522,-5,'Crane, Indiana 47522',14620,18353);
INSERT INTO "django_geo_db_zipcode" VALUES(20912,47523,-6,'Dale, Indiana 47523',14621,18354);
INSERT INTO "django_geo_db_zipcode" VALUES(20913,47524,-5,'Decker, Indiana 47524',14622,18355);
INSERT INTO "django_geo_db_zipcode" VALUES(20914,47525,-5,'Derby, Indiana 47525',14623,18356);
INSERT INTO "django_geo_db_zipcode" VALUES(20915,47527,-5,'Dubois, Indiana 47527',14624,18357);
INSERT INTO "django_geo_db_zipcode" VALUES(20916,47528,-5,'Edwardsport, Indiana 47528',14625,18358);
INSERT INTO "django_geo_db_zipcode" VALUES(20917,47529,-5,'Elnora, Indiana 47529',14626,18359);
INSERT INTO "django_geo_db_zipcode" VALUES(20918,47531,-6,'Evanston, Indiana 47531',14627,18360);
INSERT INTO "django_geo_db_zipcode" VALUES(20919,47532,-5,'Ferdinand, Indiana 47532',14628,18361);
INSERT INTO "django_geo_db_zipcode" VALUES(20920,47535,-5,'Freelandville, Indiana 47535',14629,18362);
INSERT INTO "django_geo_db_zipcode" VALUES(20921,47536,-6,'Fulda, Indiana 47536',14630,18363);
INSERT INTO "django_geo_db_zipcode" VALUES(20922,47537,-6,'Gentryville, Indiana 47537',14631,18364);
INSERT INTO "django_geo_db_zipcode" VALUES(20923,47541,-5,'Holland, Indiana 47541',14632,18365);
INSERT INTO "django_geo_db_zipcode" VALUES(20924,47542,-5,'Huntingburg, Indiana 47542',14633,18366);
INSERT INTO "django_geo_db_zipcode" VALUES(20925,47545,-5,'Ireland, Indiana 47545',14634,18367);
INSERT INTO "django_geo_db_zipcode" VALUES(20926,47546,-5,'Jasper, Indiana 47546',14635,18368);
INSERT INTO "django_geo_db_zipcode" VALUES(20927,47547,-5,'Jasper, Indiana 47547',14635,18369);
INSERT INTO "django_geo_db_zipcode" VALUES(20928,47549,-5,'Jasper, Indiana 47549',14635,18369);
INSERT INTO "django_geo_db_zipcode" VALUES(20929,47550,-6,'Lamar, Indiana 47550',14636,18370);
INSERT INTO "django_geo_db_zipcode" VALUES(20930,47551,-5,'Leopold, Indiana 47551',14637,18371);
INSERT INTO "django_geo_db_zipcode" VALUES(20931,47552,-6,'Lincoln City, Indiana 47552',14638,18372);
INSERT INTO "django_geo_db_zipcode" VALUES(20932,47553,-5,'Loogootee, Indiana 47553',14639,18373);
INSERT INTO "django_geo_db_zipcode" VALUES(20933,47556,-6,'Mariah Hill, Indiana 47556',14640,18374);
INSERT INTO "django_geo_db_zipcode" VALUES(20934,47557,-5,'Monroe City, Indiana 47557',14641,18375);
INSERT INTO "django_geo_db_zipcode" VALUES(20935,47558,-5,'Montgomery, Indiana 47558',14642,18376);
INSERT INTO "django_geo_db_zipcode" VALUES(20936,47561,-5,'Oaktown, Indiana 47561',14643,18377);
INSERT INTO "django_geo_db_zipcode" VALUES(20937,47562,-5,'Odon, Indiana 47562',14644,18378);
INSERT INTO "django_geo_db_zipcode" VALUES(20938,47564,-5,'Otwell, Indiana 47564',14645,18379);
INSERT INTO "django_geo_db_zipcode" VALUES(20939,47567,-5,'Petersburg, Indiana 47567',14646,18380);
INSERT INTO "django_geo_db_zipcode" VALUES(20940,47568,-5,'Plainville, Indiana 47568',14647,18381);
INSERT INTO "django_geo_db_zipcode" VALUES(20941,47573,-5,'Ragsdale, Indiana 47573',14648,18382);
INSERT INTO "django_geo_db_zipcode" VALUES(20942,47574,-5,'Rome, Indiana 47574',14649,18383);
INSERT INTO "django_geo_db_zipcode" VALUES(20943,47575,-5,'Saint Anthony, Indiana 47575',14650,18384);
INSERT INTO "django_geo_db_zipcode" VALUES(20944,47576,-5,'Saint Croix, Indiana 47576',14651,18385);
INSERT INTO "django_geo_db_zipcode" VALUES(20945,47577,-6,'Saint Meinrad, Indiana 47577',14652,18386);
INSERT INTO "django_geo_db_zipcode" VALUES(20946,47578,-5,'Sandborn, Indiana 47578',14653,18387);
INSERT INTO "django_geo_db_zipcode" VALUES(20947,47579,-6,'Santa Claus, Indiana 47579',14654,18388);
INSERT INTO "django_geo_db_zipcode" VALUES(20948,47580,-5,'Schnellville, Indiana 47580',14655,18389);
INSERT INTO "django_geo_db_zipcode" VALUES(20949,47581,-5,'Shoals, Indiana 47581',14656,18390);
INSERT INTO "django_geo_db_zipcode" VALUES(20950,47584,-5,'Spurgeon, Indiana 47584',14657,18391);
INSERT INTO "django_geo_db_zipcode" VALUES(20951,47585,-5,'Stendal, Indiana 47585',14658,18392);
INSERT INTO "django_geo_db_zipcode" VALUES(20952,47586,-5,'Tell City, Indiana 47586',14659,18393);
INSERT INTO "django_geo_db_zipcode" VALUES(20953,47588,-6,'Troy, Indiana 47588',14660,18394);
INSERT INTO "django_geo_db_zipcode" VALUES(20954,47590,-5,'Velpen, Indiana 47590',14661,18395);
INSERT INTO "django_geo_db_zipcode" VALUES(20955,47591,-5,'Vincennes, Indiana 47591',14662,18396);
INSERT INTO "django_geo_db_zipcode" VALUES(20956,47596,-5,'Westphalia, Indiana 47596',14663,18397);
INSERT INTO "django_geo_db_zipcode" VALUES(20957,47597,-5,'Wheatland, Indiana 47597',14664,18398);
INSERT INTO "django_geo_db_zipcode" VALUES(20958,47598,-5,'Winslow, Indiana 47598',14665,18399);
INSERT INTO "django_geo_db_zipcode" VALUES(20959,47601,-6,'Boonville, Indiana 47601',14666,18400);
INSERT INTO "django_geo_db_zipcode" VALUES(20960,47610,-6,'Chandler, Indiana 47610',14667,18401);
INSERT INTO "django_geo_db_zipcode" VALUES(20961,47611,-6,'Chrisney, Indiana 47611',14668,18402);
INSERT INTO "django_geo_db_zipcode" VALUES(20962,47612,-6,'Cynthiana, Indiana 47612',14669,18403);
INSERT INTO "django_geo_db_zipcode" VALUES(20963,47613,-6,'Elberfeld, Indiana 47613',14670,18404);
INSERT INTO "django_geo_db_zipcode" VALUES(20964,47614,-6,'Folsomville, Indiana 47614',14671,18405);
INSERT INTO "django_geo_db_zipcode" VALUES(20965,47615,-6,'Grandview, Indiana 47615',14672,18406);
INSERT INTO "django_geo_db_zipcode" VALUES(20966,47616,-6,'Griffin, Indiana 47616',14673,18407);
INSERT INTO "django_geo_db_zipcode" VALUES(20967,47617,-6,'Hatfield, Indiana 47617',14674,18408);
INSERT INTO "django_geo_db_zipcode" VALUES(20968,47618,-6,'Inglefield, Indiana 47618',14675,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20969,47619,-6,'Lynnville, Indiana 47619',14676,18410);
INSERT INTO "django_geo_db_zipcode" VALUES(20970,47620,-6,'Mount Vernon, Indiana 47620',14677,18411);
INSERT INTO "django_geo_db_zipcode" VALUES(20971,47625,-5,'North Vernon, Indiana 47625',14498,18412);
INSERT INTO "django_geo_db_zipcode" VALUES(20972,47629,-6,'Newburgh, Indiana 47629',14678,18413);
INSERT INTO "django_geo_db_zipcode" VALUES(20973,47630,-6,'Newburgh, Indiana 47630',14678,18414);
INSERT INTO "django_geo_db_zipcode" VALUES(20974,47631,-6,'New Harmony, Indiana 47631',14679,18415);
INSERT INTO "django_geo_db_zipcode" VALUES(20975,47633,-6,'Poseyville, Indiana 47633',14680,18416);
INSERT INTO "django_geo_db_zipcode" VALUES(20976,47634,-6,'Richland, Indiana 47634',14681,18417);
INSERT INTO "django_geo_db_zipcode" VALUES(20977,47635,-6,'Rockport, Indiana 47635',14682,18418);
INSERT INTO "django_geo_db_zipcode" VALUES(20978,47637,-6,'Tennyson, Indiana 47637',14683,18419);
INSERT INTO "django_geo_db_zipcode" VALUES(20979,47638,-6,'Wadesville, Indiana 47638',14684,18420);
INSERT INTO "django_geo_db_zipcode" VALUES(20980,47639,-6,'Haubstadt, Indiana 47639',14685,18421);
INSERT INTO "django_geo_db_zipcode" VALUES(20981,47640,-6,'Hazleton, Indiana 47640',14686,18422);
INSERT INTO "django_geo_db_zipcode" VALUES(20982,47647,-6,'Buckskin, Indiana 47647',14687,18423);
INSERT INTO "django_geo_db_zipcode" VALUES(20983,47648,-6,'Fort Branch, Indiana 47648',14688,18424);
INSERT INTO "django_geo_db_zipcode" VALUES(20984,47649,-6,'Francisco, Indiana 47649',14689,18425);
INSERT INTO "django_geo_db_zipcode" VALUES(20985,47654,-6,'Mackey, Indiana 47654',14690,18426);
INSERT INTO "django_geo_db_zipcode" VALUES(20986,47660,-6,'Oakland City, Indiana 47660',14691,18427);
INSERT INTO "django_geo_db_zipcode" VALUES(20987,47665,-6,'Owensville, Indiana 47665',14692,18428);
INSERT INTO "django_geo_db_zipcode" VALUES(20988,47666,-6,'Patoka, Indiana 47666',14693,18429);
INSERT INTO "django_geo_db_zipcode" VALUES(20989,47667,-6,'Owensville, Indiana 47667',14692,18430);
INSERT INTO "django_geo_db_zipcode" VALUES(20990,47670,-6,'Princeton, Indiana 47670',14694,18431);
INSERT INTO "django_geo_db_zipcode" VALUES(20991,47671,-5,'Oxford, Indiana 47671',14695,18432);
INSERT INTO "django_geo_db_zipcode" VALUES(20992,47672,-6,'Cynthiana, Indiana 47672',14669,18433);
INSERT INTO "django_geo_db_zipcode" VALUES(20993,47683,-6,'Somerville, Indiana 47683',14696,18434);
INSERT INTO "django_geo_db_zipcode" VALUES(20994,47701,-6,'Evansville, Indiana 47701',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20995,47702,-6,'Evansville, Indiana 47702',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20996,47703,-6,'Evansville, Indiana 47703',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20997,47704,-6,'Evansville, Indiana 47704',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20998,47705,-6,'Evansville, Indiana 47705',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(20999,47706,-6,'Evansville, Indiana 47706',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21000,47708,-6,'Evansville, Indiana 47708',14569,18435);
INSERT INTO "django_geo_db_zipcode" VALUES(21001,47710,-6,'Evansville, Indiana 47710',14569,18436);
INSERT INTO "django_geo_db_zipcode" VALUES(21002,47711,-6,'Evansville, Indiana 47711',14569,18437);
INSERT INTO "django_geo_db_zipcode" VALUES(21003,47712,-6,'Evansville, Indiana 47712',14569,18438);
INSERT INTO "django_geo_db_zipcode" VALUES(21004,47713,-6,'Evansville, Indiana 47713',14569,18439);
INSERT INTO "django_geo_db_zipcode" VALUES(21005,47714,-6,'Evansville, Indiana 47714',14569,18440);
INSERT INTO "django_geo_db_zipcode" VALUES(21006,47715,-6,'Evansville, Indiana 47715',14569,18441);
INSERT INTO "django_geo_db_zipcode" VALUES(21007,47716,-6,'Evansville, Indiana 47716',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21008,47718,-5,'Jackson, Indiana 47718',14697,18442);
INSERT INTO "django_geo_db_zipcode" VALUES(21009,47719,-6,'Evansville, Indiana 47719',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21010,47720,-6,'Evansville, Indiana 47720',14569,18443);
INSERT INTO "django_geo_db_zipcode" VALUES(21011,47721,-6,'Evansville, Indiana 47721',14569,18444);
INSERT INTO "django_geo_db_zipcode" VALUES(21012,47722,-6,'Evansville, Indiana 47722',14569,18445);
INSERT INTO "django_geo_db_zipcode" VALUES(21013,47724,-6,'Evansville, Indiana 47724',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21014,47725,-6,'Evansville, Indiana 47725',14569,18446);
INSERT INTO "django_geo_db_zipcode" VALUES(21015,47727,-6,'Evansville, Indiana 47727',14569,18447);
INSERT INTO "django_geo_db_zipcode" VALUES(21016,47728,-6,'Evansville, Indiana 47728',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21017,47729,-6,'Scott, Indiana 47729',14698,18448);
INSERT INTO "django_geo_db_zipcode" VALUES(21018,47730,-6,'Evansville, Indiana 47730',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21019,47731,-6,'Evansville, Indiana 47731',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21020,47732,-6,'Evansville, Indiana 47732',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21021,47733,-6,'Evansville, Indiana 47733',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21022,47734,-6,'Evansville, Indiana 47734',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21023,47735,-6,'Evansville, Indiana 47735',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21024,47736,-6,'Evansville, Indiana 47736',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21025,47737,-6,'Evansville, Indiana 47737',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21026,47739,-6,'Evansville, Indiana 47739',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21027,47740,-6,'Evansville, Indiana 47740',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21028,47741,-6,'Evansville, Indiana 47741',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21029,47744,-6,'Evansville, Indiana 47744',14569,18449);
INSERT INTO "django_geo_db_zipcode" VALUES(21030,47747,-6,'Evansville, Indiana 47747',14569,18409);
INSERT INTO "django_geo_db_zipcode" VALUES(21031,47750,-6,'Evansville, Indiana 47750',14569,18450);
INSERT INTO "django_geo_db_zipcode" VALUES(21032,47765,-5,'New Market, Indiana 47765',14699,18451);
INSERT INTO "django_geo_db_zipcode" VALUES(21033,47801,-5,'Terre Haute, Indiana 47801',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21034,47802,-5,'Terre Haute, Indiana 47802',14700,18453);
INSERT INTO "django_geo_db_zipcode" VALUES(21035,47803,-5,'Terre Haute, Indiana 47803',14700,18454);
INSERT INTO "django_geo_db_zipcode" VALUES(21036,47804,-5,'Terre Haute, Indiana 47804',14700,18455);
INSERT INTO "django_geo_db_zipcode" VALUES(21037,47805,-5,'Terre Haute, Indiana 47805',14700,18456);
INSERT INTO "django_geo_db_zipcode" VALUES(21038,47807,-5,'Terre Haute, Indiana 47807',14700,18457);
INSERT INTO "django_geo_db_zipcode" VALUES(21039,47808,-5,'Terre Haute, Indiana 47808',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21040,47809,-5,'Terre Haute, Indiana 47809',14700,18458);
INSERT INTO "django_geo_db_zipcode" VALUES(21041,47811,-5,'Terre Haute, Indiana 47811',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21042,47812,-5,'Terre Haute, Indiana 47812',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21043,47813,-5,'Terre Haute, Indiana 47813',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21044,47814,-5,'Terre Haute, Indiana 47814',14700,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21045,47830,-5,'Bellmore, Indiana 47830',14701,18459);
INSERT INTO "django_geo_db_zipcode" VALUES(21046,47831,-5,'Blanford, Indiana 47831',14702,18460);
INSERT INTO "django_geo_db_zipcode" VALUES(21047,47832,-5,'Bloomingdale, Indiana 47832',14703,18461);
INSERT INTO "django_geo_db_zipcode" VALUES(21048,47833,-5,'Bowling Green, Indiana 47833',14704,18462);
INSERT INTO "django_geo_db_zipcode" VALUES(21049,47834,-5,'Brazil, Indiana 47834',14705,18463);
INSERT INTO "django_geo_db_zipcode" VALUES(21050,47836,-5,'Bridgeton, Indiana 47836',14706,18464);
INSERT INTO "django_geo_db_zipcode" VALUES(21051,47837,-5,'Carbon, Indiana 47837',14707,18465);
INSERT INTO "django_geo_db_zipcode" VALUES(21052,47838,-5,'Carlisle, Indiana 47838',14708,18466);
INSERT INTO "django_geo_db_zipcode" VALUES(21053,47840,-5,'Centerpoint, Indiana 47840',14709,18467);
INSERT INTO "django_geo_db_zipcode" VALUES(21054,47841,-5,'Clay City, Indiana 47841',14710,18468);
INSERT INTO "django_geo_db_zipcode" VALUES(21055,47842,-5,'Clinton, Indiana 47842',14711,18469);
INSERT INTO "django_geo_db_zipcode" VALUES(21056,47845,-5,'Coalmont, Indiana 47845',14712,18470);
INSERT INTO "django_geo_db_zipcode" VALUES(21057,47846,-5,'Cory, Indiana 47846',14713,18471);
INSERT INTO "django_geo_db_zipcode" VALUES(21058,47847,-5,'Dana, Indiana 47847',14714,18472);
INSERT INTO "django_geo_db_zipcode" VALUES(21059,47848,-5,'Dugger, Indiana 47848',14715,18473);
INSERT INTO "django_geo_db_zipcode" VALUES(21060,47849,-5,'Fairbanks, Indiana 47849',14716,18474);
INSERT INTO "django_geo_db_zipcode" VALUES(21061,47850,-5,'Farmersburg, Indiana 47850',14717,18475);
INSERT INTO "django_geo_db_zipcode" VALUES(21062,47851,-5,'Fontanet, Indiana 47851',14718,18476);
INSERT INTO "django_geo_db_zipcode" VALUES(21063,47852,-5,'Graysville, Indiana 47852',14719,18477);
INSERT INTO "django_geo_db_zipcode" VALUES(21064,47853,-5,'Harmony, Indiana 47853',14720,18478);
INSERT INTO "django_geo_db_zipcode" VALUES(21065,47854,-5,'Hillsdale, Indiana 47854',14721,18479);
INSERT INTO "django_geo_db_zipcode" VALUES(21066,47855,-5,'Hymera, Indiana 47855',14722,18480);
INSERT INTO "django_geo_db_zipcode" VALUES(21067,47856,-5,'Judson, Indiana 47856',14723,18481);
INSERT INTO "django_geo_db_zipcode" VALUES(21068,47857,-5,'Knightsville, Indiana 47857',14724,18482);
INSERT INTO "django_geo_db_zipcode" VALUES(21069,47858,-5,'Lewis, Indiana 47858',14610,18483);
INSERT INTO "django_geo_db_zipcode" VALUES(21070,47859,-5,'Marshall, Indiana 47859',14725,18484);
INSERT INTO "django_geo_db_zipcode" VALUES(21071,47860,-5,'Mecca, Indiana 47860',14726,18485);
INSERT INTO "django_geo_db_zipcode" VALUES(21072,47861,-5,'Merom, Indiana 47861',14727,18486);
INSERT INTO "django_geo_db_zipcode" VALUES(21073,47862,-5,'Montezuma, Indiana 47862',14728,18487);
INSERT INTO "django_geo_db_zipcode" VALUES(21074,47863,-5,'New Goshen, Indiana 47863',14729,18488);
INSERT INTO "django_geo_db_zipcode" VALUES(21075,47864,-5,'New Lebanon, Indiana 47864',14730,18489);
INSERT INTO "django_geo_db_zipcode" VALUES(21076,47865,-5,'Paxton, Indiana 47865',14731,18490);
INSERT INTO "django_geo_db_zipcode" VALUES(21077,47866,-5,'Pimento, Indiana 47866',14732,18491);
INSERT INTO "django_geo_db_zipcode" VALUES(21078,47868,-5,'Poland, Indiana 47868',14733,18492);
INSERT INTO "django_geo_db_zipcode" VALUES(21079,47869,-5,'Prairie Creek, Indiana 47869',14734,18452);
INSERT INTO "django_geo_db_zipcode" VALUES(21080,47870,-5,'Prairieton, Indiana 47870',14735,18493);
INSERT INTO "django_geo_db_zipcode" VALUES(21081,47871,-5,'Riley, Indiana 47871',14736,18494);
INSERT INTO "django_geo_db_zipcode" VALUES(21082,47872,-5,'Rockville, Indiana 47872',14737,18495);
INSERT INTO "django_geo_db_zipcode" VALUES(21083,47874,-5,'Rosedale, Indiana 47874',14738,18496);
INSERT INTO "django_geo_db_zipcode" VALUES(21084,47875,-5,'Saint Bernice, Indiana 47875',14739,18460);
INSERT INTO "django_geo_db_zipcode" VALUES(21085,47876,-5,'Saint Mary Of The Woods, Indiana 47876',14740,18497);
INSERT INTO "django_geo_db_zipcode" VALUES(21086,47878,-5,'Seelyville, Indiana 47878',14741,18498);
INSERT INTO "django_geo_db_zipcode" VALUES(21087,47879,-5,'Shelburn, Indiana 47879',14742,18499);
INSERT INTO "django_geo_db_zipcode" VALUES(21088,47880,-5,'Shepardsville, Indiana 47880',14743,18500);
INSERT INTO "django_geo_db_zipcode" VALUES(21089,47881,-5,'Staunton, Indiana 47881',14744,18501);
INSERT INTO "django_geo_db_zipcode" VALUES(21090,47882,-5,'Sullivan, Indiana 47882',14745,18502);
INSERT INTO "django_geo_db_zipcode" VALUES(21091,47884,-5,'Universal, Indiana 47884',14746,18503);
INSERT INTO "django_geo_db_zipcode" VALUES(21092,47885,-5,'West Terre Haute, Indiana 47885',14747,18504);
INSERT INTO "django_geo_db_zipcode" VALUES(21093,47895,-5,'Helt, Indiana 47895',14748,18505);
INSERT INTO "django_geo_db_zipcode" VALUES(21094,47901,-5,'Lafayette, Indiana 47901',14749,18506);
INSERT INTO "django_geo_db_zipcode" VALUES(21095,47902,-5,'Lafayette, Indiana 47902',14749,18507);
INSERT INTO "django_geo_db_zipcode" VALUES(21096,47903,-5,'Lafayette, Indiana 47903',14749,18508);
INSERT INTO "django_geo_db_zipcode" VALUES(21097,47904,-5,'Lafayette, Indiana 47904',14749,18509);
INSERT INTO "django_geo_db_zipcode" VALUES(21098,47905,-5,'Lafayette, Indiana 47905',14749,18510);
INSERT INTO "django_geo_db_zipcode" VALUES(21099,47906,-5,'West Lafayette, Indiana 47906',14750,18511);
INSERT INTO "django_geo_db_zipcode" VALUES(21100,47907,-5,'West Lafayette, Indiana 47907',14750,18512);
INSERT INTO "django_geo_db_zipcode" VALUES(21101,47909,-5,'Lafayette, Indiana 47909',14749,18513);
INSERT INTO "django_geo_db_zipcode" VALUES(21102,47916,-5,'Alamo, Indiana 47916',14751,18514);
INSERT INTO "django_geo_db_zipcode" VALUES(21103,47917,-5,'Ambia, Indiana 47917',14752,18515);
INSERT INTO "django_geo_db_zipcode" VALUES(21104,47918,-5,'Attica, Indiana 47918',14753,18516);
INSERT INTO "django_geo_db_zipcode" VALUES(21105,47920,-5,'Battle Ground, Indiana 47920',14754,18517);
INSERT INTO "django_geo_db_zipcode" VALUES(21106,47921,-5,'Boswell, Indiana 47921',14755,18518);
INSERT INTO "django_geo_db_zipcode" VALUES(21107,47922,-6,'Brook, Indiana 47922',14756,18519);
INSERT INTO "django_geo_db_zipcode" VALUES(21108,47923,-5,'Brookston, Indiana 47923',14757,18520);
INSERT INTO "django_geo_db_zipcode" VALUES(21109,47924,-5,'Buck Creek, Indiana 47924',14758,18521);
INSERT INTO "django_geo_db_zipcode" VALUES(21110,47925,-5,'Buffalo, Indiana 47925',14759,18522);
INSERT INTO "django_geo_db_zipcode" VALUES(21111,47926,-5,'Burnettsville, Indiana 47926',14760,18523);
INSERT INTO "django_geo_db_zipcode" VALUES(21112,47928,-5,'Cayuga, Indiana 47928',14512,18524);
INSERT INTO "django_geo_db_zipcode" VALUES(21113,47929,-5,'Chalmers, Indiana 47929',14761,18525);
INSERT INTO "django_geo_db_zipcode" VALUES(21114,47930,-5,'Clarks Hill, Indiana 47930',14762,18526);
INSERT INTO "django_geo_db_zipcode" VALUES(21115,47932,-5,'Covington, Indiana 47932',14763,18527);
INSERT INTO "django_geo_db_zipcode" VALUES(21116,47933,-5,'Crawfordsville, Indiana 47933',14764,18528);
INSERT INTO "django_geo_db_zipcode" VALUES(21117,47934,-5,'Crawfordsville, Indiana 47934',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21118,47935,-5,'Crawfordsville, Indiana 47935',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21119,47936,-5,'Crawfordsville, Indiana 47936',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21120,47937,-5,'Crawfordsville, Indiana 47937',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21121,47938,-5,'Crawfordsville, Indiana 47938',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21122,47939,-5,'Crawfordsville, Indiana 47939',14764,18529);
INSERT INTO "django_geo_db_zipcode" VALUES(21123,47940,-5,'Darlington, Indiana 47940',14765,18530);
INSERT INTO "django_geo_db_zipcode" VALUES(21124,47941,-5,'Dayton, Indiana 47941',14766,18531);
INSERT INTO "django_geo_db_zipcode" VALUES(21125,47942,-5,'Earl Park, Indiana 47942',14767,18532);
INSERT INTO "django_geo_db_zipcode" VALUES(21126,47943,-6,'Fair Oaks, Indiana 47943',14768,18533);
INSERT INTO "django_geo_db_zipcode" VALUES(21127,47944,-5,'Fowler, Indiana 47944',14769,18534);
INSERT INTO "django_geo_db_zipcode" VALUES(21128,47946,-5,'Francesville, Indiana 47946',14770,18535);
INSERT INTO "django_geo_db_zipcode" VALUES(21129,47948,-6,'Goodland, Indiana 47948',14771,18536);
INSERT INTO "django_geo_db_zipcode" VALUES(21130,47949,-5,'Hillsboro, Indiana 47949',14772,18537);
INSERT INTO "django_geo_db_zipcode" VALUES(21131,47950,-5,'Idaville, Indiana 47950',14773,18538);
INSERT INTO "django_geo_db_zipcode" VALUES(21132,47951,-6,'Kentland, Indiana 47951',14774,18539);
INSERT INTO "django_geo_db_zipcode" VALUES(21133,47952,-5,'Kingman, Indiana 47952',14775,18540);
INSERT INTO "django_geo_db_zipcode" VALUES(21134,47954,-5,'Ladoga, Indiana 47954',14776,18541);
INSERT INTO "django_geo_db_zipcode" VALUES(21135,47955,-5,'Linden, Indiana 47955',14777,18542);
INSERT INTO "django_geo_db_zipcode" VALUES(21136,47957,-5,'Medaryville, Indiana 47957',14778,18543);
INSERT INTO "django_geo_db_zipcode" VALUES(21137,47958,-5,'Mellott, Indiana 47958',14779,18544);
INSERT INTO "django_geo_db_zipcode" VALUES(21138,47959,-5,'Monon, Indiana 47959',14780,18545);
INSERT INTO "django_geo_db_zipcode" VALUES(21139,47960,-5,'Monticello, Indiana 47960',14781,18546);
INSERT INTO "django_geo_db_zipcode" VALUES(21140,47962,-5,'Montmorenci, Indiana 47962',14782,18547);
INSERT INTO "django_geo_db_zipcode" VALUES(21141,47963,-6,'Morocco, Indiana 47963',14783,18548);
INSERT INTO "django_geo_db_zipcode" VALUES(21142,47964,-6,'Mount Ayr, Indiana 47964',14784,18549);
INSERT INTO "django_geo_db_zipcode" VALUES(21143,47965,-5,'New Market, Indiana 47965',14699,18550);
INSERT INTO "django_geo_db_zipcode" VALUES(21144,47966,-5,'Newport, Indiana 47966',14785,18551);
INSERT INTO "django_geo_db_zipcode" VALUES(21145,47967,-5,'New Richmond, Indiana 47967',14786,18552);
INSERT INTO "django_geo_db_zipcode" VALUES(21146,47968,-5,'New Ross, Indiana 47968',14787,18553);
INSERT INTO "django_geo_db_zipcode" VALUES(21147,47969,-5,'Newtown, Indiana 47969',14788,18554);
INSERT INTO "django_geo_db_zipcode" VALUES(21148,47970,-5,'Otterbein, Indiana 47970',14789,18555);
INSERT INTO "django_geo_db_zipcode" VALUES(21149,47971,-5,'Oxford, Indiana 47971',14695,18556);
INSERT INTO "django_geo_db_zipcode" VALUES(21150,47974,-5,'Perrysville, Indiana 47974',14790,18557);
INSERT INTO "django_geo_db_zipcode" VALUES(21151,47975,-5,'Pine Village, Indiana 47975',14791,18558);
INSERT INTO "django_geo_db_zipcode" VALUES(21152,47976,-5,'Earl Park, Indiana 47976',14767,18559);
INSERT INTO "django_geo_db_zipcode" VALUES(21153,47977,-6,'Remington, Indiana 47977',14792,18560);
INSERT INTO "django_geo_db_zipcode" VALUES(21154,47978,-6,'Rensselaer, Indiana 47978',14793,18561);
INSERT INTO "django_geo_db_zipcode" VALUES(21155,47980,-5,'Reynolds, Indiana 47980',14794,18562);
INSERT INTO "django_geo_db_zipcode" VALUES(21156,47981,-5,'Romney, Indiana 47981',14795,18563);
INSERT INTO "django_geo_db_zipcode" VALUES(21157,47982,-5,'State Line, Indiana 47982',14796,18564);
INSERT INTO "django_geo_db_zipcode" VALUES(21158,47983,-5,'Stockwell, Indiana 47983',14797,18565);
INSERT INTO "django_geo_db_zipcode" VALUES(21159,47984,-5,'Talbot, Indiana 47984',14798,18559);
INSERT INTO "django_geo_db_zipcode" VALUES(21160,47986,-5,'Templeton, Indiana 47986',14799,18566);
INSERT INTO "django_geo_db_zipcode" VALUES(21161,47987,-5,'Veedersburg, Indiana 47987',14800,18567);
INSERT INTO "django_geo_db_zipcode" VALUES(21162,47988,-5,'Wallace, Indiana 47988',14801,18568);
INSERT INTO "django_geo_db_zipcode" VALUES(21163,47989,-5,'Waveland, Indiana 47989',14802,18569);
INSERT INTO "django_geo_db_zipcode" VALUES(21164,47990,-5,'Waynetown, Indiana 47990',14803,18570);
INSERT INTO "django_geo_db_zipcode" VALUES(21165,47991,-5,'West Lebanon, Indiana 47991',14804,18571);
INSERT INTO "django_geo_db_zipcode" VALUES(21166,47992,-5,'Westpoint, Indiana 47992',14805,18572);
INSERT INTO "django_geo_db_zipcode" VALUES(21167,47993,-5,'Williamsport, Indiana 47993',14806,18573);
INSERT INTO "django_geo_db_zipcode" VALUES(21168,47994,-5,'Wingate, Indiana 47994',14807,18574);
INSERT INTO "django_geo_db_zipcode" VALUES(21169,47995,-5,'Wolcott, Indiana 47995',14808,18575);
INSERT INTO "django_geo_db_zipcode" VALUES(21170,47996,-5,'West Lafayette, Indiana 47996',14750,18507);
INSERT INTO "django_geo_db_zipcode" VALUES(21171,47997,-5,'Yeoman, Indiana 47997',14809,18576);
INSERT INTO "django_geo_db_zipcode" VALUES(21172,48001,-5,'Algonac, Michigan 48001',14810,18577);
INSERT INTO "django_geo_db_zipcode" VALUES(21173,48002,-5,'Allenton, Michigan 48002',14811,18578);
INSERT INTO "django_geo_db_zipcode" VALUES(21174,48003,-5,'Almont, Michigan 48003',14812,18579);
INSERT INTO "django_geo_db_zipcode" VALUES(21175,48004,-5,'Anchorville, Michigan 48004',14813,18580);
INSERT INTO "django_geo_db_zipcode" VALUES(21176,48005,-5,'Armada, Michigan 48005',14814,18581);
INSERT INTO "django_geo_db_zipcode" VALUES(21177,48006,-5,'Avoca, Michigan 48006',14815,18582);
INSERT INTO "django_geo_db_zipcode" VALUES(21178,48007,-5,'Troy, Michigan 48007',14816,18583);
INSERT INTO "django_geo_db_zipcode" VALUES(21179,48009,-5,'Birmingham, Michigan 48009',14817,18584);
INSERT INTO "django_geo_db_zipcode" VALUES(21180,48012,-5,'Birmingham, Michigan 48012',14817,18585);
INSERT INTO "django_geo_db_zipcode" VALUES(21181,48014,-5,'Capac, Michigan 48014',14818,18586);
INSERT INTO "django_geo_db_zipcode" VALUES(21182,48015,-5,'Center Line, Michigan 48015',14819,18587);
INSERT INTO "django_geo_db_zipcode" VALUES(21183,48017,-5,'Clawson, Michigan 48017',14820,18588);
INSERT INTO "django_geo_db_zipcode" VALUES(21184,48019,-5,'Rose, Michigan 48019',14821,18589);
INSERT INTO "django_geo_db_zipcode" VALUES(21185,48021,-5,'Eastpointe, Michigan 48021',14822,18590);
INSERT INTO "django_geo_db_zipcode" VALUES(21186,48022,-5,'Emmett, Michigan 48022',14823,18591);
INSERT INTO "django_geo_db_zipcode" VALUES(21187,48023,-5,'Fair Haven, Michigan 48023',14824,18592);
INSERT INTO "django_geo_db_zipcode" VALUES(21188,48025,-5,'Franklin, Michigan 48025',14825,18593);
INSERT INTO "django_geo_db_zipcode" VALUES(21189,48026,-5,'Fraser, Michigan 48026',14826,18594);
INSERT INTO "django_geo_db_zipcode" VALUES(21190,48027,-5,'Goodells, Michigan 48027',14827,18595);
INSERT INTO "django_geo_db_zipcode" VALUES(21191,48028,-5,'Harsens Island, Michigan 48028',14828,18596);
INSERT INTO "django_geo_db_zipcode" VALUES(21192,48030,-5,'Hazel Park, Michigan 48030',14829,18597);
INSERT INTO "django_geo_db_zipcode" VALUES(21193,48032,-5,'Jeddo, Michigan 48032',14830,18598);
INSERT INTO "django_geo_db_zipcode" VALUES(21194,48034,-5,'Southfield, Michigan 48034',14831,18599);
INSERT INTO "django_geo_db_zipcode" VALUES(21195,48035,-5,'Clinton Township, Michigan 48035',14832,18600);
INSERT INTO "django_geo_db_zipcode" VALUES(21196,48036,-5,'Clinton Township, Michigan 48036',14832,18601);
INSERT INTO "django_geo_db_zipcode" VALUES(21197,48037,-5,'Southfield, Michigan 48037',14831,18602);
INSERT INTO "django_geo_db_zipcode" VALUES(21198,48038,-5,'Clinton Township, Michigan 48038',14832,18603);
INSERT INTO "django_geo_db_zipcode" VALUES(21199,48039,-5,'Marine City, Michigan 48039',14833,18604);
INSERT INTO "django_geo_db_zipcode" VALUES(21200,48040,-5,'Marysville, Michigan 48040',14834,18605);
INSERT INTO "django_geo_db_zipcode" VALUES(21201,48041,-5,'Memphis, Michigan 48041',14835,18606);
INSERT INTO "django_geo_db_zipcode" VALUES(21202,48042,-5,'Macomb, Michigan 48042',14836,18607);
INSERT INTO "django_geo_db_zipcode" VALUES(21203,48043,-5,'Mount Clemens, Michigan 48043',14837,18608);
INSERT INTO "django_geo_db_zipcode" VALUES(21204,48044,-5,'Macomb, Michigan 48044',14836,18609);
INSERT INTO "django_geo_db_zipcode" VALUES(21205,48045,-5,'Harrison Township, Michigan 48045',14838,18610);
INSERT INTO "django_geo_db_zipcode" VALUES(21206,48046,-5,'Mount Clemens, Michigan 48046',14837,18611);
INSERT INTO "django_geo_db_zipcode" VALUES(21207,48047,-5,'New Baltimore, Michigan 48047',14839,18612);
INSERT INTO "django_geo_db_zipcode" VALUES(21208,48048,-5,'New Haven, Michigan 48048',14840,18613);
INSERT INTO "django_geo_db_zipcode" VALUES(21209,48049,-5,'North Street, Michigan 48049',14841,18614);
INSERT INTO "django_geo_db_zipcode" VALUES(21210,48050,-5,'New Haven, Michigan 48050',14840,18615);
INSERT INTO "django_geo_db_zipcode" VALUES(21211,48051,-5,'New Baltimore, Michigan 48051',14839,18616);
INSERT INTO "django_geo_db_zipcode" VALUES(21212,48054,-5,'East China, Michigan 48054',14842,18617);
INSERT INTO "django_geo_db_zipcode" VALUES(21213,48059,-5,'Fort Gratiot, Michigan 48059',14843,18618);
INSERT INTO "django_geo_db_zipcode" VALUES(21214,48060,-5,'Port Huron, Michigan 48060',14844,18619);
INSERT INTO "django_geo_db_zipcode" VALUES(21215,48061,-5,'Port Huron, Michigan 48061',14844,18580);
INSERT INTO "django_geo_db_zipcode" VALUES(21216,48062,-5,'Richmond, Michigan 48062',14845,18620);
INSERT INTO "django_geo_db_zipcode" VALUES(21217,48063,-5,'Columbus, Michigan 48063',14846,18621);
INSERT INTO "django_geo_db_zipcode" VALUES(21218,48064,-5,'Casco, Michigan 48064',14847,18622);
INSERT INTO "django_geo_db_zipcode" VALUES(21219,48065,-5,'Romeo, Michigan 48065',14848,18623);
INSERT INTO "django_geo_db_zipcode" VALUES(21220,48066,-5,'Roseville, Michigan 48066',14849,18624);
INSERT INTO "django_geo_db_zipcode" VALUES(21221,48067,-5,'Royal Oak, Michigan 48067',14850,18625);
INSERT INTO "django_geo_db_zipcode" VALUES(21222,48068,-5,'Royal Oak, Michigan 48068',14850,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21223,48069,-5,'Pleasant Ridge, Michigan 48069',14851,18627);
INSERT INTO "django_geo_db_zipcode" VALUES(21224,48070,-5,'Huntington Woods, Michigan 48070',14852,18628);
INSERT INTO "django_geo_db_zipcode" VALUES(21225,48071,-5,'Madison Heights, Michigan 48071',14853,18629);
INSERT INTO "django_geo_db_zipcode" VALUES(21226,48072,-5,'Berkley, Michigan 48072',14854,18630);
INSERT INTO "django_geo_db_zipcode" VALUES(21227,48073,-5,'Royal Oak, Michigan 48073',14850,18631);
INSERT INTO "django_geo_db_zipcode" VALUES(21228,48074,-5,'Smiths Creek, Michigan 48074',14855,18632);
INSERT INTO "django_geo_db_zipcode" VALUES(21229,48075,-5,'Southfield, Michigan 48075',14831,18633);
INSERT INTO "django_geo_db_zipcode" VALUES(21230,48076,-5,'Southfield, Michigan 48076',14831,18634);
INSERT INTO "django_geo_db_zipcode" VALUES(21231,48079,-5,'Saint Clair, Michigan 48079',14856,18635);
INSERT INTO "django_geo_db_zipcode" VALUES(21232,48080,-5,'Saint Clair Shores, Michigan 48080',14857,18636);
INSERT INTO "django_geo_db_zipcode" VALUES(21233,48081,-5,'Saint Clair Shores, Michigan 48081',14857,18637);
INSERT INTO "django_geo_db_zipcode" VALUES(21234,48082,-5,'Saint Clair Shores, Michigan 48082',14857,18638);
INSERT INTO "django_geo_db_zipcode" VALUES(21235,48083,-5,'Troy, Michigan 48083',14816,18639);
INSERT INTO "django_geo_db_zipcode" VALUES(21236,48084,-5,'Troy, Michigan 48084',14816,18640);
INSERT INTO "django_geo_db_zipcode" VALUES(21237,48085,-5,'Troy, Michigan 48085',14816,18641);
INSERT INTO "django_geo_db_zipcode" VALUES(21238,48086,-5,'Southfield, Michigan 48086',14831,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21239,48088,-5,'Warren, Michigan 48088',14858,18642);
INSERT INTO "django_geo_db_zipcode" VALUES(21240,48089,-5,'Warren, Michigan 48089',14858,18643);
INSERT INTO "django_geo_db_zipcode" VALUES(21241,48090,-5,'Warren, Michigan 48090',14858,18611);
INSERT INTO "django_geo_db_zipcode" VALUES(21242,48091,-5,'Warren, Michigan 48091',14858,18644);
INSERT INTO "django_geo_db_zipcode" VALUES(21243,48092,-5,'Warren, Michigan 48092',14858,18645);
INSERT INTO "django_geo_db_zipcode" VALUES(21244,48093,-5,'Warren, Michigan 48093',14858,18646);
INSERT INTO "django_geo_db_zipcode" VALUES(21245,48094,-5,'Washington, Michigan 48094',14859,18647);
INSERT INTO "django_geo_db_zipcode" VALUES(21246,48095,-5,'Washington, Michigan 48095',14859,18648);
INSERT INTO "django_geo_db_zipcode" VALUES(21247,48096,-5,'Ray, Michigan 48096',14860,18649);
INSERT INTO "django_geo_db_zipcode" VALUES(21248,48097,-5,'Yale, Michigan 48097',14861,18650);
INSERT INTO "django_geo_db_zipcode" VALUES(21249,48098,-5,'Troy, Michigan 48098',14816,18651);
INSERT INTO "django_geo_db_zipcode" VALUES(21250,48099,-5,'Troy, Michigan 48099',14816,18652);
INSERT INTO "django_geo_db_zipcode" VALUES(21251,48101,-5,'Allen Park, Michigan 48101',14862,18653);
INSERT INTO "django_geo_db_zipcode" VALUES(21252,48103,-5,'Ann Arbor, Michigan 48103',14863,18654);
INSERT INTO "django_geo_db_zipcode" VALUES(21253,48104,-5,'Ann Arbor, Michigan 48104',14863,18655);
INSERT INTO "django_geo_db_zipcode" VALUES(21254,48105,-5,'Ann Arbor, Michigan 48105',14863,18656);
INSERT INTO "django_geo_db_zipcode" VALUES(21255,48106,-5,'Ann Arbor, Michigan 48106',14863,18657);
INSERT INTO "django_geo_db_zipcode" VALUES(21256,48107,-5,'Ann Arbor, Michigan 48107',14863,18657);
INSERT INTO "django_geo_db_zipcode" VALUES(21257,48108,-5,'Ann Arbor, Michigan 48108',14863,18658);
INSERT INTO "django_geo_db_zipcode" VALUES(21258,48109,-5,'Ann Arbor, Michigan 48109',14863,18659);
INSERT INTO "django_geo_db_zipcode" VALUES(21259,48110,-5,'Azalia, Michigan 48110',14864,18660);
INSERT INTO "django_geo_db_zipcode" VALUES(21260,48111,-5,'Belleville, Michigan 48111',14865,18661);
INSERT INTO "django_geo_db_zipcode" VALUES(21261,48112,-5,'Belleville, Michigan 48112',14865,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21262,48113,-5,'Ann Arbor, Michigan 48113',14863,18657);
INSERT INTO "django_geo_db_zipcode" VALUES(21263,48114,-5,'Brighton, Michigan 48114',14866,18663);
INSERT INTO "django_geo_db_zipcode" VALUES(21264,48115,-5,'Bridgewater, Michigan 48115',14867,18664);
INSERT INTO "django_geo_db_zipcode" VALUES(21265,48116,-5,'Brighton, Michigan 48116',14866,18665);
INSERT INTO "django_geo_db_zipcode" VALUES(21266,48117,-5,'Carleton, Michigan 48117',14868,18666);
INSERT INTO "django_geo_db_zipcode" VALUES(21267,48118,-5,'Chelsea, Michigan 48118',14869,18667);
INSERT INTO "django_geo_db_zipcode" VALUES(21268,48120,-5,'Dearborn, Michigan 48120',14870,18668);
INSERT INTO "django_geo_db_zipcode" VALUES(21269,48121,-5,'Dearborn, Michigan 48121',14870,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21270,48122,-5,'Melvindale, Michigan 48122',14871,18669);
INSERT INTO "django_geo_db_zipcode" VALUES(21271,48123,-5,'Dearborn, Michigan 48123',14870,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21272,48124,-5,'Dearborn, Michigan 48124',14870,18670);
INSERT INTO "django_geo_db_zipcode" VALUES(21273,48125,-5,'Dearborn Heights, Michigan 48125',14872,18671);
INSERT INTO "django_geo_db_zipcode" VALUES(21274,48126,-5,'Dearborn, Michigan 48126',14870,18672);
INSERT INTO "django_geo_db_zipcode" VALUES(21275,48127,-5,'Dearborn Heights, Michigan 48127',14872,18673);
INSERT INTO "django_geo_db_zipcode" VALUES(21276,48128,-5,'Dearborn, Michigan 48128',14870,18674);
INSERT INTO "django_geo_db_zipcode" VALUES(21277,48130,-5,'Dexter, Michigan 48130',14873,18675);
INSERT INTO "django_geo_db_zipcode" VALUES(21278,48131,-5,'Dundee, Michigan 48131',14874,18676);
INSERT INTO "django_geo_db_zipcode" VALUES(21279,48133,-5,'Erie, Michigan 48133',14875,18677);
INSERT INTO "django_geo_db_zipcode" VALUES(21280,48134,-5,'Flat Rock, Michigan 48134',14876,18678);
INSERT INTO "django_geo_db_zipcode" VALUES(21281,48135,-5,'Garden City, Michigan 48135',14877,18679);
INSERT INTO "django_geo_db_zipcode" VALUES(21282,48136,-5,'Garden City, Michigan 48136',14877,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21283,48137,-5,'Gregory, Michigan 48137',14878,18680);
INSERT INTO "django_geo_db_zipcode" VALUES(21284,48138,-5,'Grosse Ile, Michigan 48138',14879,18681);
INSERT INTO "django_geo_db_zipcode" VALUES(21285,48139,-5,'Hamburg, Michigan 48139',14880,18682);
INSERT INTO "django_geo_db_zipcode" VALUES(21286,48140,-5,'Ida, Michigan 48140',14881,18683);
INSERT INTO "django_geo_db_zipcode" VALUES(21287,48141,-5,'Inkster, Michigan 48141',14882,18684);
INSERT INTO "django_geo_db_zipcode" VALUES(21288,48143,-5,'Lakeland, Michigan 48143',14883,18685);
INSERT INTO "django_geo_db_zipcode" VALUES(21289,48144,-5,'Lambertville, Michigan 48144',14884,18686);
INSERT INTO "django_geo_db_zipcode" VALUES(21290,48145,-5,'La Salle, Michigan 48145',14885,18687);
INSERT INTO "django_geo_db_zipcode" VALUES(21291,48146,-5,'Lincoln Park, Michigan 48146',14886,18688);
INSERT INTO "django_geo_db_zipcode" VALUES(21292,48150,-5,'Livonia, Michigan 48150',14887,18689);
INSERT INTO "django_geo_db_zipcode" VALUES(21293,48151,-5,'Livonia, Michigan 48151',14887,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21294,48152,-5,'Livonia, Michigan 48152',14887,18690);
INSERT INTO "django_geo_db_zipcode" VALUES(21295,48153,-5,'Livonia, Michigan 48153',14887,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21296,48154,-5,'Livonia, Michigan 48154',14887,18691);
INSERT INTO "django_geo_db_zipcode" VALUES(21297,48157,-5,'Luna Pier, Michigan 48157',14888,18692);
INSERT INTO "django_geo_db_zipcode" VALUES(21298,48158,-5,'Manchester, Michigan 48158',14889,18693);
INSERT INTO "django_geo_db_zipcode" VALUES(21299,48159,-5,'Maybee, Michigan 48159',14890,18694);
INSERT INTO "django_geo_db_zipcode" VALUES(21300,48160,-5,'Milan, Michigan 48160',14891,18695);
INSERT INTO "django_geo_db_zipcode" VALUES(21301,48161,-5,'Monroe, Michigan 48161',14892,18696);
INSERT INTO "django_geo_db_zipcode" VALUES(21302,48162,-5,'Monroe, Michigan 48162',14892,18697);
INSERT INTO "django_geo_db_zipcode" VALUES(21303,48164,-5,'New Boston, Michigan 48164',14893,18698);
INSERT INTO "django_geo_db_zipcode" VALUES(21304,48165,-5,'New Hudson, Michigan 48165',14894,18699);
INSERT INTO "django_geo_db_zipcode" VALUES(21305,48166,-5,'Newport, Michigan 48166',14895,18700);
INSERT INTO "django_geo_db_zipcode" VALUES(21306,48167,-5,'Northville, Michigan 48167',14896,18701);
INSERT INTO "django_geo_db_zipcode" VALUES(21307,48168,-5,'South Monroe, Michigan 48168',14897,18702);
INSERT INTO "django_geo_db_zipcode" VALUES(21308,48169,-5,'Pinckney, Michigan 48169',14898,18703);
INSERT INTO "django_geo_db_zipcode" VALUES(21309,48170,-5,'Plymouth, Michigan 48170',14899,18704);
INSERT INTO "django_geo_db_zipcode" VALUES(21310,48173,-5,'Rockwood, Michigan 48173',14900,18705);
INSERT INTO "django_geo_db_zipcode" VALUES(21311,48174,-5,'Romulus, Michigan 48174',14901,18706);
INSERT INTO "django_geo_db_zipcode" VALUES(21312,48175,-5,'Salem, Michigan 48175',14902,18707);
INSERT INTO "django_geo_db_zipcode" VALUES(21313,48176,-5,'Saline, Michigan 48176',14903,18708);
INSERT INTO "django_geo_db_zipcode" VALUES(21314,48177,-5,'Samaria, Michigan 48177',14904,18709);
INSERT INTO "django_geo_db_zipcode" VALUES(21315,48178,-5,'South Lyon, Michigan 48178',14905,18710);
INSERT INTO "django_geo_db_zipcode" VALUES(21316,48179,-5,'South Rockwood, Michigan 48179',14906,18711);
INSERT INTO "django_geo_db_zipcode" VALUES(21317,48180,-5,'Taylor, Michigan 48180',14907,18712);
INSERT INTO "django_geo_db_zipcode" VALUES(21318,48182,-5,'Temperance, Michigan 48182',14908,18713);
INSERT INTO "django_geo_db_zipcode" VALUES(21319,48183,-5,'Trenton, Michigan 48183',14909,18714);
INSERT INTO "django_geo_db_zipcode" VALUES(21320,48184,-5,'Wayne, Michigan 48184',14910,18715);
INSERT INTO "django_geo_db_zipcode" VALUES(21321,48185,-5,'Westland, Michigan 48185',14911,18716);
INSERT INTO "django_geo_db_zipcode" VALUES(21322,48186,-5,'Westland, Michigan 48186',14911,18717);
INSERT INTO "django_geo_db_zipcode" VALUES(21323,48187,-5,'Canton, Michigan 48187',14912,18718);
INSERT INTO "django_geo_db_zipcode" VALUES(21324,48188,-5,'Canton, Michigan 48188',14912,18719);
INSERT INTO "django_geo_db_zipcode" VALUES(21325,48189,-5,'Whitmore Lake, Michigan 48189',14913,18720);
INSERT INTO "django_geo_db_zipcode" VALUES(21326,48190,-5,'Whittaker, Michigan 48190',14914,18721);
INSERT INTO "django_geo_db_zipcode" VALUES(21327,48191,-5,'Willis, Michigan 48191',14915,18722);
INSERT INTO "django_geo_db_zipcode" VALUES(21328,48192,-5,'Wyandotte, Michigan 48192',14916,18723);
INSERT INTO "django_geo_db_zipcode" VALUES(21329,48195,-5,'Southgate, Michigan 48195',14917,18724);
INSERT INTO "django_geo_db_zipcode" VALUES(21330,48197,-5,'Ypsilanti, Michigan 48197',14918,18725);
INSERT INTO "django_geo_db_zipcode" VALUES(21331,48198,-5,'Ypsilanti, Michigan 48198',14918,18726);
INSERT INTO "django_geo_db_zipcode" VALUES(21332,48201,-5,'Detroit, Michigan 48201',14919,18727);
INSERT INTO "django_geo_db_zipcode" VALUES(21333,48202,-5,'Detroit, Michigan 48202',14919,18728);
INSERT INTO "django_geo_db_zipcode" VALUES(21334,48203,-5,'Highland Park, Michigan 48203',14920,18729);
INSERT INTO "django_geo_db_zipcode" VALUES(21335,48204,-5,'Detroit, Michigan 48204',14919,18730);
INSERT INTO "django_geo_db_zipcode" VALUES(21336,48205,-5,'Detroit, Michigan 48205',14919,18731);
INSERT INTO "django_geo_db_zipcode" VALUES(21337,48206,-5,'Detroit, Michigan 48206',14919,18732);
INSERT INTO "django_geo_db_zipcode" VALUES(21338,48207,-5,'Detroit, Michigan 48207',14919,18733);
INSERT INTO "django_geo_db_zipcode" VALUES(21339,48208,-5,'Detroit, Michigan 48208',14919,18734);
INSERT INTO "django_geo_db_zipcode" VALUES(21340,48209,-5,'Detroit, Michigan 48209',14919,18735);
INSERT INTO "django_geo_db_zipcode" VALUES(21341,48210,-5,'Detroit, Michigan 48210',14919,18736);
INSERT INTO "django_geo_db_zipcode" VALUES(21342,48211,-5,'Detroit, Michigan 48211',14919,18737);
INSERT INTO "django_geo_db_zipcode" VALUES(21343,48212,-5,'Hamtramck, Michigan 48212',14921,18738);
INSERT INTO "django_geo_db_zipcode" VALUES(21344,48213,-5,'Detroit, Michigan 48213',14919,18739);
INSERT INTO "django_geo_db_zipcode" VALUES(21345,48214,-5,'Detroit, Michigan 48214',14919,18740);
INSERT INTO "django_geo_db_zipcode" VALUES(21346,48215,-5,'Detroit, Michigan 48215',14919,18741);
INSERT INTO "django_geo_db_zipcode" VALUES(21347,48216,-5,'Detroit, Michigan 48216',14919,18742);
INSERT INTO "django_geo_db_zipcode" VALUES(21348,48217,-5,'Detroit, Michigan 48217',14919,18743);
INSERT INTO "django_geo_db_zipcode" VALUES(21349,48218,-5,'River Rouge, Michigan 48218',14922,18744);
INSERT INTO "django_geo_db_zipcode" VALUES(21350,48219,-5,'Detroit, Michigan 48219',14919,18745);
INSERT INTO "django_geo_db_zipcode" VALUES(21351,48220,-5,'Ferndale, Michigan 48220',14923,18746);
INSERT INTO "django_geo_db_zipcode" VALUES(21352,48221,-5,'Detroit, Michigan 48221',14919,18747);
INSERT INTO "django_geo_db_zipcode" VALUES(21353,48222,-5,'Detroit, Michigan 48222',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21354,48223,-5,'Detroit, Michigan 48223',14919,18748);
INSERT INTO "django_geo_db_zipcode" VALUES(21355,48224,-5,'Detroit, Michigan 48224',14919,18749);
INSERT INTO "django_geo_db_zipcode" VALUES(21356,48225,-5,'Harper Woods, Michigan 48225',14924,18750);
INSERT INTO "django_geo_db_zipcode" VALUES(21357,48226,-5,'Detroit, Michigan 48226',14919,18751);
INSERT INTO "django_geo_db_zipcode" VALUES(21358,48227,-5,'Detroit, Michigan 48227',14919,18752);
INSERT INTO "django_geo_db_zipcode" VALUES(21359,48228,-5,'Detroit, Michigan 48228',14919,18753);
INSERT INTO "django_geo_db_zipcode" VALUES(21360,48229,-5,'Ecorse, Michigan 48229',14925,18754);
INSERT INTO "django_geo_db_zipcode" VALUES(21361,48230,-5,'Grosse Pointe, Michigan 48230',14926,18755);
INSERT INTO "django_geo_db_zipcode" VALUES(21362,48231,-5,'Detroit, Michigan 48231',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21363,48232,-5,'Detroit, Michigan 48232',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21364,48233,-5,'Detroit, Michigan 48233',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21365,48234,-5,'Detroit, Michigan 48234',14919,18756);
INSERT INTO "django_geo_db_zipcode" VALUES(21366,48235,-5,'Detroit, Michigan 48235',14919,18757);
INSERT INTO "django_geo_db_zipcode" VALUES(21367,48236,-5,'Grosse Pointe, Michigan 48236',14926,18758);
INSERT INTO "django_geo_db_zipcode" VALUES(21368,48237,-5,'Oak Park, Michigan 48237',14927,18759);
INSERT INTO "django_geo_db_zipcode" VALUES(21369,48238,-5,'Detroit, Michigan 48238',14919,18760);
INSERT INTO "django_geo_db_zipcode" VALUES(21370,48239,-5,'Redford, Michigan 48239',14928,18761);
INSERT INTO "django_geo_db_zipcode" VALUES(21371,48240,-5,'Redford, Michigan 48240',14928,18762);
INSERT INTO "django_geo_db_zipcode" VALUES(21372,48242,-5,'Detroit, Michigan 48242',14919,18763);
INSERT INTO "django_geo_db_zipcode" VALUES(21373,48243,-5,'Detroit, Michigan 48243',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21374,48244,-5,'Detroit, Michigan 48244',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21375,48246,-5,'Independence, Michigan 48246',14929,18764);
INSERT INTO "django_geo_db_zipcode" VALUES(21376,48254,-5,'Detroit, Michigan 48254',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21377,48255,-5,'Detroit, Michigan 48255',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21378,48258,-5,'Detroit, Michigan 48258',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21379,48260,-5,'Detroit, Michigan 48260',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21380,48264,-5,'Detroit, Michigan 48264',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21381,48265,-5,'Detroit, Michigan 48265',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21382,48266,-5,'Detroit, Michigan 48266',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21383,48267,-5,'Detroit, Michigan 48267',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21384,48268,-5,'Detroit, Michigan 48268',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21385,48269,-5,'Detroit, Michigan 48269',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21386,48272,-5,'Detroit, Michigan 48272',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21387,48274,-5,'Detroit, Michigan 48274',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21388,48275,-5,'Detroit, Michigan 48275',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21389,48277,-5,'Detroit, Michigan 48277',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21390,48278,-5,'Detroit, Michigan 48278',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21391,48279,-5,'Detroit, Michigan 48279',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21392,48288,-5,'Detroit, Michigan 48288',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21393,48295,-5,'Detroit, Michigan 48295',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21394,48297,-5,'Detroit, Michigan 48297',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21395,48299,-5,'Detroit, Michigan 48299',14919,18662);
INSERT INTO "django_geo_db_zipcode" VALUES(21396,48301,-5,'Bloomfield Hills, Michigan 48301',14930,18765);
INSERT INTO "django_geo_db_zipcode" VALUES(21397,48302,-5,'Bloomfield Hills, Michigan 48302',14930,18766);
INSERT INTO "django_geo_db_zipcode" VALUES(21398,48303,-5,'Bloomfield Hills, Michigan 48303',14930,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21399,48304,-5,'Bloomfield Hills, Michigan 48304',14930,18767);
INSERT INTO "django_geo_db_zipcode" VALUES(21400,48305,-5,'Clinton, Michigan 48305',14931,18768);
INSERT INTO "django_geo_db_zipcode" VALUES(21401,48306,-5,'Rochester, Michigan 48306',14932,18769);
INSERT INTO "django_geo_db_zipcode" VALUES(21402,48307,-5,'Rochester, Michigan 48307',14932,18770);
INSERT INTO "django_geo_db_zipcode" VALUES(21403,48308,-5,'Rochester, Michigan 48308',14932,18771);
INSERT INTO "django_geo_db_zipcode" VALUES(21404,48309,-5,'Rochester, Michigan 48309',14932,18772);
INSERT INTO "django_geo_db_zipcode" VALUES(21405,48310,-5,'Sterling Heights, Michigan 48310',14933,18773);
INSERT INTO "django_geo_db_zipcode" VALUES(21406,48311,-5,'Sterling Heights, Michigan 48311',14933,18611);
INSERT INTO "django_geo_db_zipcode" VALUES(21407,48312,-5,'Sterling Heights, Michigan 48312',14933,18774);
INSERT INTO "django_geo_db_zipcode" VALUES(21408,48313,-5,'Sterling Heights, Michigan 48313',14933,18775);
INSERT INTO "django_geo_db_zipcode" VALUES(21409,48314,-5,'Sterling Heights, Michigan 48314',14933,18776);
INSERT INTO "django_geo_db_zipcode" VALUES(21410,48315,-5,'Utica, Michigan 48315',14934,18777);
INSERT INTO "django_geo_db_zipcode" VALUES(21411,48316,-5,'Utica, Michigan 48316',14934,18778);
INSERT INTO "django_geo_db_zipcode" VALUES(21412,48317,-5,'Utica, Michigan 48317',14934,18779);
INSERT INTO "django_geo_db_zipcode" VALUES(21413,48318,-5,'Utica, Michigan 48318',14934,18611);
INSERT INTO "django_geo_db_zipcode" VALUES(21414,48320,-5,'Keego Harbor, Michigan 48320',14935,18780);
INSERT INTO "django_geo_db_zipcode" VALUES(21415,48321,-5,'Auburn Hills, Michigan 48321',14936,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21416,48322,-5,'West Bloomfield, Michigan 48322',14937,18781);
INSERT INTO "django_geo_db_zipcode" VALUES(21417,48323,-5,'West Bloomfield, Michigan 48323',14937,18782);
INSERT INTO "django_geo_db_zipcode" VALUES(21418,48324,-5,'West Bloomfield, Michigan 48324',14937,18783);
INSERT INTO "django_geo_db_zipcode" VALUES(21419,48325,-5,'West Bloomfield, Michigan 48325',14937,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21420,48326,-5,'Auburn Hills, Michigan 48326',14936,18784);
INSERT INTO "django_geo_db_zipcode" VALUES(21421,48327,-5,'Waterford, Michigan 48327',14938,18785);
INSERT INTO "django_geo_db_zipcode" VALUES(21422,48328,-5,'Waterford, Michigan 48328',14938,18786);
INSERT INTO "django_geo_db_zipcode" VALUES(21423,48329,-5,'Waterford, Michigan 48329',14938,18787);
INSERT INTO "django_geo_db_zipcode" VALUES(21424,48330,-5,'Drayton Plains, Michigan 48330',14939,18788);
INSERT INTO "django_geo_db_zipcode" VALUES(21425,48331,-5,'Farmington, Michigan 48331',14940,18789);
INSERT INTO "django_geo_db_zipcode" VALUES(21426,48332,-5,'Farmington, Michigan 48332',14940,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21427,48333,-5,'Farmington, Michigan 48333',14940,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21428,48334,-5,'Farmington, Michigan 48334',14940,18790);
INSERT INTO "django_geo_db_zipcode" VALUES(21429,48335,-5,'Farmington, Michigan 48335',14940,18791);
INSERT INTO "django_geo_db_zipcode" VALUES(21430,48336,-5,'Farmington, Michigan 48336',14940,18792);
INSERT INTO "django_geo_db_zipcode" VALUES(21431,48340,-5,'Pontiac, Michigan 48340',14941,18793);
INSERT INTO "django_geo_db_zipcode" VALUES(21432,48341,-5,'Pontiac, Michigan 48341',14941,18794);
INSERT INTO "django_geo_db_zipcode" VALUES(21433,48342,-5,'Pontiac, Michigan 48342',14941,18795);
INSERT INTO "django_geo_db_zipcode" VALUES(21434,48343,-5,'Pontiac, Michigan 48343',14941,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21435,48346,-5,'Clarkston, Michigan 48346',14942,18796);
INSERT INTO "django_geo_db_zipcode" VALUES(21436,48347,-5,'Clarkston, Michigan 48347',14942,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21437,48348,-5,'Clarkston, Michigan 48348',14942,18797);
INSERT INTO "django_geo_db_zipcode" VALUES(21438,48350,-5,'Davisburg, Michigan 48350',14943,18798);
INSERT INTO "django_geo_db_zipcode" VALUES(21439,48353,-5,'Hartland, Michigan 48353',14944,18799);
INSERT INTO "django_geo_db_zipcode" VALUES(21440,48356,-5,'Highland, Michigan 48356',14945,18800);
INSERT INTO "django_geo_db_zipcode" VALUES(21441,48357,-5,'Highland, Michigan 48357',14945,18801);
INSERT INTO "django_geo_db_zipcode" VALUES(21442,48359,-5,'Lake Orion, Michigan 48359',14946,18802);
INSERT INTO "django_geo_db_zipcode" VALUES(21443,48360,-5,'Lake Orion, Michigan 48360',14946,18803);
INSERT INTO "django_geo_db_zipcode" VALUES(21444,48361,-5,'Lake Orion, Michigan 48361',14946,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21445,48362,-5,'Lake Orion, Michigan 48362',14946,18804);
INSERT INTO "django_geo_db_zipcode" VALUES(21446,48363,-5,'Oakland, Michigan 48363',14947,18805);
INSERT INTO "django_geo_db_zipcode" VALUES(21447,48366,-5,'Lakeville, Michigan 48366',14948,18806);
INSERT INTO "django_geo_db_zipcode" VALUES(21448,48367,-5,'Leonard, Michigan 48367',14949,18807);
INSERT INTO "django_geo_db_zipcode" VALUES(21449,48370,-5,'Oxford, Michigan 48370',14950,18808);
INSERT INTO "django_geo_db_zipcode" VALUES(21450,48371,-5,'Oxford, Michigan 48371',14950,18809);
INSERT INTO "django_geo_db_zipcode" VALUES(21451,48374,-5,'Novi, Michigan 48374',14951,18810);
INSERT INTO "django_geo_db_zipcode" VALUES(21452,48375,-5,'Novi, Michigan 48375',14951,18811);
INSERT INTO "django_geo_db_zipcode" VALUES(21453,48376,-5,'Novi, Michigan 48376',14951,18812);
INSERT INTO "django_geo_db_zipcode" VALUES(21454,48377,-5,'Novi, Michigan 48377',14951,18813);
INSERT INTO "django_geo_db_zipcode" VALUES(21455,48380,-5,'Milford, Michigan 48380',14952,18814);
INSERT INTO "django_geo_db_zipcode" VALUES(21456,48381,-5,'Milford, Michigan 48381',14952,18815);
INSERT INTO "django_geo_db_zipcode" VALUES(21457,48382,-5,'Commerce Township, Michigan 48382',14953,18816);
INSERT INTO "django_geo_db_zipcode" VALUES(21458,48383,-5,'White Lake, Michigan 48383',14954,18817);
INSERT INTO "django_geo_db_zipcode" VALUES(21459,48386,-5,'White Lake, Michigan 48386',14954,18818);
INSERT INTO "django_geo_db_zipcode" VALUES(21460,48387,-5,'Union Lake, Michigan 48387',14955,18819);
INSERT INTO "django_geo_db_zipcode" VALUES(21461,48390,-5,'Walled Lake, Michigan 48390',14956,18820);
INSERT INTO "django_geo_db_zipcode" VALUES(21462,48391,-5,'Walled Lake, Michigan 48391',14956,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21463,48393,-5,'Wixom, Michigan 48393',14957,18821);
INSERT INTO "django_geo_db_zipcode" VALUES(21464,48396,-5,'Wixom, Michigan 48396',14957,18822);
INSERT INTO "django_geo_db_zipcode" VALUES(21465,48397,-5,'Warren, Michigan 48397',14858,18823);
INSERT INTO "django_geo_db_zipcode" VALUES(21466,48398,-5,'Clawson, Michigan 48398',14820,18626);
INSERT INTO "django_geo_db_zipcode" VALUES(21467,48401,-5,'Applegate, Michigan 48401',14958,18824);
INSERT INTO "django_geo_db_zipcode" VALUES(21468,48410,-5,'Argyle, Michigan 48410',14959,18825);
INSERT INTO "django_geo_db_zipcode" VALUES(21469,48411,-5,'Atlas, Michigan 48411',14960,18826);
INSERT INTO "django_geo_db_zipcode" VALUES(21470,48412,-5,'Attica, Michigan 48412',14961,18827);
INSERT INTO "django_geo_db_zipcode" VALUES(21471,48413,-5,'Bad Axe, Michigan 48413',14962,18828);
INSERT INTO "django_geo_db_zipcode" VALUES(21472,48414,-5,'Bancroft, Michigan 48414',14963,18829);
INSERT INTO "django_geo_db_zipcode" VALUES(21473,48415,-5,'Birch Run, Michigan 48415',14964,18830);
INSERT INTO "django_geo_db_zipcode" VALUES(21474,48416,-5,'Brown City, Michigan 48416',14965,18831);
INSERT INTO "django_geo_db_zipcode" VALUES(21475,48417,-5,'Burt, Michigan 48417',14966,18832);
INSERT INTO "django_geo_db_zipcode" VALUES(21476,48418,-5,'Byron, Michigan 48418',14967,18833);
INSERT INTO "django_geo_db_zipcode" VALUES(21477,48419,-5,'Carsonville, Michigan 48419',14968,18834);
INSERT INTO "django_geo_db_zipcode" VALUES(21478,48420,-5,'Clio, Michigan 48420',14969,18835);
INSERT INTO "django_geo_db_zipcode" VALUES(21479,48421,-5,'Columbiaville, Michigan 48421',14970,18836);
INSERT INTO "django_geo_db_zipcode" VALUES(21480,48422,-5,'Croswell, Michigan 48422',14971,18837);
INSERT INTO "django_geo_db_zipcode" VALUES(21481,48423,-5,'Davison, Michigan 48423',14972,18838);
INSERT INTO "django_geo_db_zipcode" VALUES(21482,48426,-5,'Decker, Michigan 48426',14973,18839);
INSERT INTO "django_geo_db_zipcode" VALUES(21483,48427,-5,'Deckerville, Michigan 48427',14974,18840);
INSERT INTO "django_geo_db_zipcode" VALUES(21484,48428,-5,'Dryden, Michigan 48428',14975,18841);
INSERT INTO "django_geo_db_zipcode" VALUES(21485,48429,-5,'Durand, Michigan 48429',14976,18842);
INSERT INTO "django_geo_db_zipcode" VALUES(21486,48430,-5,'Fenton, Michigan 48430',14977,18843);
INSERT INTO "django_geo_db_zipcode" VALUES(21487,48432,-5,'Filion, Michigan 48432',14978,18844);
INSERT INTO "django_geo_db_zipcode" VALUES(21488,48433,-5,'Flushing, Michigan 48433',14979,18845);
INSERT INTO "django_geo_db_zipcode" VALUES(21489,48434,-5,'Forestville, Michigan 48434',14980,18846);
INSERT INTO "django_geo_db_zipcode" VALUES(21490,48435,-5,'Fostoria, Michigan 48435',14981,18847);
INSERT INTO "django_geo_db_zipcode" VALUES(21491,48436,-5,'Gaines, Michigan 48436',14982,18848);
INSERT INTO "django_geo_db_zipcode" VALUES(21492,48437,-5,'Genesee, Michigan 48437',14983,18849);
INSERT INTO "django_geo_db_zipcode" VALUES(21493,48438,-5,'Goodrich, Michigan 48438',14984,18850);
INSERT INTO "django_geo_db_zipcode" VALUES(21494,48439,-5,'Grand Blanc, Michigan 48439',14985,18851);
INSERT INTO "django_geo_db_zipcode" VALUES(21495,48440,-5,'Hadley, Michigan 48440',14986,18852);
INSERT INTO "django_geo_db_zipcode" VALUES(21496,48441,-5,'Harbor Beach, Michigan 48441',14987,18853);
INSERT INTO "django_geo_db_zipcode" VALUES(21497,48442,-5,'Holly, Michigan 48442',14988,18854);
INSERT INTO "django_geo_db_zipcode" VALUES(21498,48444,-5,'Imlay City, Michigan 48444',14989,18855);
INSERT INTO "django_geo_db_zipcode" VALUES(21499,48445,-5,'Kinde, Michigan 48445',14990,18856);
INSERT INTO "django_geo_db_zipcode" VALUES(21500,48446,-5,'Lapeer, Michigan 48446',14991,18857);
INSERT INTO "django_geo_db_zipcode" VALUES(21501,48448,-5,'Sciota, Michigan 48448',14992,18858);
INSERT INTO "django_geo_db_zipcode" VALUES(21502,48449,-5,'Lennon, Michigan 48449',14993,18859);
INSERT INTO "django_geo_db_zipcode" VALUES(21503,48450,-5,'Lexington, Michigan 48450',14994,18860);
INSERT INTO "django_geo_db_zipcode" VALUES(21504,48451,-5,'Linden, Michigan 48451',14995,18861);
INSERT INTO "django_geo_db_zipcode" VALUES(21505,48453,-5,'Marlette, Michigan 48453',14996,18862);
INSERT INTO "django_geo_db_zipcode" VALUES(21506,48454,-5,'Melvin, Michigan 48454',14997,18863);
INSERT INTO "django_geo_db_zipcode" VALUES(21507,48455,-5,'Metamora, Michigan 48455',14998,18864);
INSERT INTO "django_geo_db_zipcode" VALUES(21508,48456,-5,'Minden City, Michigan 48456',14999,18865);
INSERT INTO "django_geo_db_zipcode" VALUES(21509,48457,-5,'Montrose, Michigan 48457',15000,18866);
INSERT INTO "django_geo_db_zipcode" VALUES(21510,48458,-5,'Mount Morris, Michigan 48458',15001,18867);
INSERT INTO "django_geo_db_zipcode" VALUES(21511,48460,-5,'New Lothrop, Michigan 48460',15002,18868);
INSERT INTO "django_geo_db_zipcode" VALUES(21512,48461,-5,'North Branch, Michigan 48461',15003,18869);
INSERT INTO "django_geo_db_zipcode" VALUES(21513,48462,-5,'Ortonville, Michigan 48462',15004,18870);
INSERT INTO "django_geo_db_zipcode" VALUES(21514,48463,-5,'Otisville, Michigan 48463',15005,18871);
INSERT INTO "django_geo_db_zipcode" VALUES(21515,48464,-5,'Otter Lake, Michigan 48464',15006,18872);
INSERT INTO "django_geo_db_zipcode" VALUES(21516,48465,-5,'Palms, Michigan 48465',15007,18873);
INSERT INTO "django_geo_db_zipcode" VALUES(21517,48466,-5,'Peck, Michigan 48466',15008,18874);
INSERT INTO "django_geo_db_zipcode" VALUES(21518,48467,-5,'Port Austin, Michigan 48467',15009,18875);
INSERT INTO "django_geo_db_zipcode" VALUES(21519,48468,-5,'Port Hope, Michigan 48468',15010,18876);
INSERT INTO "django_geo_db_zipcode" VALUES(21520,48469,-5,'Port Sanilac, Michigan 48469',15011,18877);
INSERT INTO "django_geo_db_zipcode" VALUES(21521,48470,-5,'Ruth, Michigan 48470',15012,18878);
INSERT INTO "django_geo_db_zipcode" VALUES(21522,48471,-5,'Sandusky, Michigan 48471',15013,18879);
INSERT INTO "django_geo_db_zipcode" VALUES(21523,48472,-5,'Snover, Michigan 48472',15014,18880);
INSERT INTO "django_geo_db_zipcode" VALUES(21524,48473,-5,'Swartz Creek, Michigan 48473',15015,18881);
INSERT INTO "django_geo_db_zipcode" VALUES(21525,48475,-5,'Ubly, Michigan 48475',15016,18882);
INSERT INTO "django_geo_db_zipcode" VALUES(21526,48476,-5,'Vernon, Michigan 48476',15017,18883);
INSERT INTO "django_geo_db_zipcode" VALUES(21527,48501,-5,'Flint, Michigan 48501',15018,18884);
INSERT INTO "django_geo_db_zipcode" VALUES(21528,48502,-5,'Flint, Michigan 48502',15018,18885);
INSERT INTO "django_geo_db_zipcode" VALUES(21529,48503,-5,'Flint, Michigan 48503',15018,18886);
INSERT INTO "django_geo_db_zipcode" VALUES(21530,48504,-5,'Flint, Michigan 48504',15018,18887);
INSERT INTO "django_geo_db_zipcode" VALUES(21531,48505,-5,'Flint, Michigan 48505',15018,18888);
INSERT INTO "django_geo_db_zipcode" VALUES(21532,48506,-5,'Flint, Michigan 48506',15018,18889);
INSERT INTO "django_geo_db_zipcode" VALUES(21533,48507,-5,'Flint, Michigan 48507',15018,18890);
INSERT INTO "django_geo_db_zipcode" VALUES(21534,48509,-5,'Burton, Michigan 48509',15019,18891);
INSERT INTO "django_geo_db_zipcode" VALUES(21535,48519,-5,'Burton, Michigan 48519',15019,18892);
INSERT INTO "django_geo_db_zipcode" VALUES(21536,48529,-5,'Burton, Michigan 48529',15019,18893);
INSERT INTO "django_geo_db_zipcode" VALUES(21537,48531,-5,'Flint, Michigan 48531',15018,18894);
INSERT INTO "django_geo_db_zipcode" VALUES(21538,48532,-5,'Flint, Michigan 48532',15018,18895);
INSERT INTO "django_geo_db_zipcode" VALUES(21539,48550,-5,'Flint, Michigan 48550',15018,18896);
INSERT INTO "django_geo_db_zipcode" VALUES(21540,48551,-5,'Flint, Michigan 48551',15018,18897);
INSERT INTO "django_geo_db_zipcode" VALUES(21541,48552,-5,'Flint, Michigan 48552',15018,18898);
INSERT INTO "django_geo_db_zipcode" VALUES(21542,48553,-5,'Flint, Michigan 48553',15018,18899);
INSERT INTO "django_geo_db_zipcode" VALUES(21543,48554,-5,'Flint, Michigan 48554',15018,18900);
INSERT INTO "django_geo_db_zipcode" VALUES(21544,48555,-5,'Flint, Michigan 48555',15018,18901);
INSERT INTO "django_geo_db_zipcode" VALUES(21545,48556,-5,'Flint, Michigan 48556',15018,18902);
INSERT INTO "django_geo_db_zipcode" VALUES(21546,48557,-5,'Flint, Michigan 48557',15018,18903);
INSERT INTO "django_geo_db_zipcode" VALUES(21547,48559,-5,'Flint, Michigan 48559',15018,18894);
INSERT INTO "django_geo_db_zipcode" VALUES(21548,48563,-5,'Markey, Michigan 48563',15020,18904);
INSERT INTO "django_geo_db_zipcode" VALUES(21549,48567,-5,'Flint, Michigan 48567',15018,18905);
INSERT INTO "django_geo_db_zipcode" VALUES(21550,48601,-5,'Saginaw, Michigan 48601',15021,18906);
INSERT INTO "django_geo_db_zipcode" VALUES(21551,48602,-5,'Saginaw, Michigan 48602',15021,18907);
INSERT INTO "django_geo_db_zipcode" VALUES(21552,48603,-5,'Saginaw, Michigan 48603',15021,18908);
INSERT INTO "django_geo_db_zipcode" VALUES(21553,48604,-5,'Saginaw, Michigan 48604',15021,18909);
INSERT INTO "django_geo_db_zipcode" VALUES(21554,48605,-5,'Saginaw, Michigan 48605',15021,18910);
INSERT INTO "django_geo_db_zipcode" VALUES(21555,48606,-5,'Saginaw, Michigan 48606',15021,18911);
INSERT INTO "django_geo_db_zipcode" VALUES(21556,48607,-5,'Saginaw, Michigan 48607',15021,18912);
INSERT INTO "django_geo_db_zipcode" VALUES(21557,48608,-5,'Saginaw, Michigan 48608',15021,18911);
INSERT INTO "django_geo_db_zipcode" VALUES(21558,48609,-5,'Saginaw, Michigan 48609',15021,18913);
INSERT INTO "django_geo_db_zipcode" VALUES(21559,48610,-5,'Alger, Michigan 48610',15022,18914);
INSERT INTO "django_geo_db_zipcode" VALUES(21560,48611,-5,'Auburn, Michigan 48611',15023,18915);
INSERT INTO "django_geo_db_zipcode" VALUES(21561,48612,-5,'Beaverton, Michigan 48612',15024,18916);
INSERT INTO "django_geo_db_zipcode" VALUES(21562,48613,-5,'Bentley, Michigan 48613',15025,18917);
INSERT INTO "django_geo_db_zipcode" VALUES(21563,48614,-5,'Brant, Michigan 48614',15026,18918);
INSERT INTO "django_geo_db_zipcode" VALUES(21564,48615,-5,'Breckenridge, Michigan 48615',15027,18919);
INSERT INTO "django_geo_db_zipcode" VALUES(21565,48616,-5,'Chesaning, Michigan 48616',15028,18920);
INSERT INTO "django_geo_db_zipcode" VALUES(21566,48617,-5,'Clare, Michigan 48617',15029,18921);
INSERT INTO "django_geo_db_zipcode" VALUES(21567,48618,-5,'Coleman, Michigan 48618',15030,18922);
INSERT INTO "django_geo_db_zipcode" VALUES(21568,48619,-5,'Comins, Michigan 48619',15031,18923);
INSERT INTO "django_geo_db_zipcode" VALUES(21569,48620,-5,'Edenville, Michigan 48620',15032,18924);
INSERT INTO "django_geo_db_zipcode" VALUES(21570,48621,-5,'Fairview, Michigan 48621',15033,18925);
INSERT INTO "django_geo_db_zipcode" VALUES(21571,48622,-5,'Farwell, Michigan 48622',15034,18926);
INSERT INTO "django_geo_db_zipcode" VALUES(21572,48623,-5,'Freeland, Michigan 48623',15035,18927);
INSERT INTO "django_geo_db_zipcode" VALUES(21573,48624,-5,'Gladwin, Michigan 48624',15036,18928);
INSERT INTO "django_geo_db_zipcode" VALUES(21574,48625,-5,'Harrison, Michigan 48625',15037,18929);
INSERT INTO "django_geo_db_zipcode" VALUES(21575,48626,-5,'Hemlock, Michigan 48626',15038,18930);
INSERT INTO "django_geo_db_zipcode" VALUES(21576,48627,-5,'Higgins Lake, Michigan 48627',15039,18931);
INSERT INTO "django_geo_db_zipcode" VALUES(21577,48628,-5,'Hope, Michigan 48628',15040,18932);
INSERT INTO "django_geo_db_zipcode" VALUES(21578,48629,-5,'Houghton Lake, Michigan 48629',15041,18933);
INSERT INTO "django_geo_db_zipcode" VALUES(21579,48630,-5,'Houghton Lake Heights, Michigan 48630',15042,18934);
INSERT INTO "django_geo_db_zipcode" VALUES(21580,48631,-5,'Kawkawlin, Michigan 48631',15043,18935);
INSERT INTO "django_geo_db_zipcode" VALUES(21581,48632,-5,'Lake, Michigan 48632',15044,18936);
INSERT INTO "django_geo_db_zipcode" VALUES(21582,48633,-5,'Lake George, Michigan 48633',15045,18937);
INSERT INTO "django_geo_db_zipcode" VALUES(21583,48634,-5,'Linwood, Michigan 48634',15046,18938);
INSERT INTO "django_geo_db_zipcode" VALUES(21584,48635,-5,'Lupton, Michigan 48635',15047,18939);
INSERT INTO "django_geo_db_zipcode" VALUES(21585,48636,-5,'Luzerne, Michigan 48636',15048,18940);
INSERT INTO "django_geo_db_zipcode" VALUES(21586,48637,-5,'Merrill, Michigan 48637',15049,18941);
INSERT INTO "django_geo_db_zipcode" VALUES(21587,48640,-5,'Midland, Michigan 48640',15050,18942);
INSERT INTO "django_geo_db_zipcode" VALUES(21588,48641,-5,'Midland, Michigan 48641',15050,18943);
INSERT INTO "django_geo_db_zipcode" VALUES(21589,48642,-5,'Midland, Michigan 48642',15050,18944);
INSERT INTO "django_geo_db_zipcode" VALUES(21590,48647,-5,'Mio, Michigan 48647',15051,18945);
INSERT INTO "django_geo_db_zipcode" VALUES(21591,48649,-5,'Oakley, Michigan 48649',15052,18946);
INSERT INTO "django_geo_db_zipcode" VALUES(21592,48650,-5,'Pinconning, Michigan 48650',15053,18947);
INSERT INTO "django_geo_db_zipcode" VALUES(21593,48651,-5,'Prudenville, Michigan 48651',15054,18948);
INSERT INTO "django_geo_db_zipcode" VALUES(21594,48652,-5,'Rhodes, Michigan 48652',15055,18949);
INSERT INTO "django_geo_db_zipcode" VALUES(21595,48653,-5,'Roscommon, Michigan 48653',15056,18950);
INSERT INTO "django_geo_db_zipcode" VALUES(21596,48654,-5,'Rose City, Michigan 48654',15057,18951);
INSERT INTO "django_geo_db_zipcode" VALUES(21597,48655,-5,'Saint Charles, Michigan 48655',15058,18952);
INSERT INTO "django_geo_db_zipcode" VALUES(21598,48656,-5,'Saint Helen, Michigan 48656',15059,18953);
INSERT INTO "django_geo_db_zipcode" VALUES(21599,48657,-5,'Sanford, Michigan 48657',15060,18954);
INSERT INTO "django_geo_db_zipcode" VALUES(21600,48658,-5,'Standish, Michigan 48658',15061,18955);
INSERT INTO "django_geo_db_zipcode" VALUES(21601,48659,-5,'Sterling, Michigan 48659',15062,18956);
INSERT INTO "django_geo_db_zipcode" VALUES(21602,48661,-5,'West Branch, Michigan 48661',15063,18957);
INSERT INTO "django_geo_db_zipcode" VALUES(21603,48662,-5,'Wheeler, Michigan 48662',15064,18958);
INSERT INTO "django_geo_db_zipcode" VALUES(21604,48663,-5,'Saginaw, Michigan 48663',15021,18959);
INSERT INTO "django_geo_db_zipcode" VALUES(21605,48667,-5,'Midland, Michigan 48667',15050,18960);
INSERT INTO "django_geo_db_zipcode" VALUES(21606,48670,-5,'Midland, Michigan 48670',15050,18961);
INSERT INTO "django_geo_db_zipcode" VALUES(21607,48674,-5,'Midland, Michigan 48674',15050,18962);
INSERT INTO "django_geo_db_zipcode" VALUES(21608,48686,-5,'Midland, Michigan 48686',15050,18960);
INSERT INTO "django_geo_db_zipcode" VALUES(21609,48701,-5,'Akron, Michigan 48701',15065,18963);
INSERT INTO "django_geo_db_zipcode" VALUES(21610,48703,-5,'Au Gres, Michigan 48703',15066,18964);
INSERT INTO "django_geo_db_zipcode" VALUES(21611,48705,-5,'Barton City, Michigan 48705',15067,18965);
INSERT INTO "django_geo_db_zipcode" VALUES(21612,48706,-5,'Bay City, Michigan 48706',15068,18966);
INSERT INTO "django_geo_db_zipcode" VALUES(21613,48707,-5,'Bay City, Michigan 48707',15068,18967);
INSERT INTO "django_geo_db_zipcode" VALUES(21614,48708,-5,'Bay City, Michigan 48708',15068,18968);
INSERT INTO "django_geo_db_zipcode" VALUES(21615,48710,-5,'University Center, Michigan 48710',15069,18969);
INSERT INTO "django_geo_db_zipcode" VALUES(21616,48720,-5,'Bay Port, Michigan 48720',15070,18970);
INSERT INTO "django_geo_db_zipcode" VALUES(21617,48721,-5,'Black River, Michigan 48721',15071,18971);
INSERT INTO "django_geo_db_zipcode" VALUES(21618,48722,-5,'Bridgeport, Michigan 48722',15072,18972);
INSERT INTO "django_geo_db_zipcode" VALUES(21619,48723,-5,'Caro, Michigan 48723',15073,18973);
INSERT INTO "django_geo_db_zipcode" VALUES(21620,48724,-5,'Carrollton, Michigan 48724',15074,18974);
INSERT INTO "django_geo_db_zipcode" VALUES(21621,48725,-5,'Caseville, Michigan 48725',15075,18975);
INSERT INTO "django_geo_db_zipcode" VALUES(21622,48726,-5,'Cass City, Michigan 48726',15076,18976);
INSERT INTO "django_geo_db_zipcode" VALUES(21623,48727,-5,'Clifford, Michigan 48727',15077,18977);
INSERT INTO "django_geo_db_zipcode" VALUES(21624,48728,-5,'Curran, Michigan 48728',15078,18978);
INSERT INTO "django_geo_db_zipcode" VALUES(21625,48729,-5,'Deford, Michigan 48729',15079,18979);
INSERT INTO "django_geo_db_zipcode" VALUES(21626,48730,-5,'East Tawas, Michigan 48730',15080,18980);
INSERT INTO "django_geo_db_zipcode" VALUES(21627,48731,-5,'Elkton, Michigan 48731',15081,18981);
INSERT INTO "django_geo_db_zipcode" VALUES(21628,48732,-5,'Essexville, Michigan 48732',15082,18982);
INSERT INTO "django_geo_db_zipcode" VALUES(21629,48733,-5,'Fairgrove, Michigan 48733',15083,18983);
INSERT INTO "django_geo_db_zipcode" VALUES(21630,48734,-5,'Frankenmuth, Michigan 48734',15084,18984);
INSERT INTO "django_geo_db_zipcode" VALUES(21631,48735,-5,'Gagetown, Michigan 48735',15085,18985);
INSERT INTO "django_geo_db_zipcode" VALUES(21632,48736,-5,'Gilford, Michigan 48736',15086,18986);
INSERT INTO "django_geo_db_zipcode" VALUES(21633,48737,-5,'Glennie, Michigan 48737',15087,18987);
INSERT INTO "django_geo_db_zipcode" VALUES(21634,48738,-5,'Greenbush, Michigan 48738',15088,18988);
INSERT INTO "django_geo_db_zipcode" VALUES(21635,48739,-5,'Hale, Michigan 48739',15089,18989);
INSERT INTO "django_geo_db_zipcode" VALUES(21636,48740,-5,'Harrisville, Michigan 48740',15090,18990);
INSERT INTO "django_geo_db_zipcode" VALUES(21637,48741,-5,'Kingston, Michigan 48741',15091,18991);
INSERT INTO "django_geo_db_zipcode" VALUES(21638,48742,-5,'Lincoln, Michigan 48742',15092,18992);
INSERT INTO "django_geo_db_zipcode" VALUES(21639,48743,-5,'Long Lake, Michigan 48743',15093,18993);
INSERT INTO "django_geo_db_zipcode" VALUES(21640,48744,-5,'Mayville, Michigan 48744',15094,18994);
INSERT INTO "django_geo_db_zipcode" VALUES(21641,48745,-5,'Mikado, Michigan 48745',15095,18995);
INSERT INTO "django_geo_db_zipcode" VALUES(21642,48746,-5,'Millington, Michigan 48746',15096,18996);
INSERT INTO "django_geo_db_zipcode" VALUES(21643,48747,-5,'Munger, Michigan 48747',15097,18997);
INSERT INTO "django_geo_db_zipcode" VALUES(21644,48748,-5,'National City, Michigan 48748',15098,18998);
INSERT INTO "django_geo_db_zipcode" VALUES(21645,48749,-5,'Omer, Michigan 48749',15099,18999);
INSERT INTO "django_geo_db_zipcode" VALUES(21646,48750,-5,'Oscoda, Michigan 48750',15100,19000);
INSERT INTO "django_geo_db_zipcode" VALUES(21647,48754,-5,'Owendale, Michigan 48754',15101,19001);
INSERT INTO "django_geo_db_zipcode" VALUES(21648,48755,-5,'Pigeon, Michigan 48755',15102,19002);
INSERT INTO "django_geo_db_zipcode" VALUES(21649,48756,-5,'Prescott, Michigan 48756',15103,19003);
INSERT INTO "django_geo_db_zipcode" VALUES(21650,48757,-5,'Reese, Michigan 48757',15104,19004);
INSERT INTO "django_geo_db_zipcode" VALUES(21651,48758,-5,'Richville, Michigan 48758',15105,19005);
INSERT INTO "django_geo_db_zipcode" VALUES(21652,48759,-5,'Sebewaing, Michigan 48759',15106,19006);
INSERT INTO "django_geo_db_zipcode" VALUES(21653,48760,-5,'Silverwood, Michigan 48760',15107,19007);
INSERT INTO "django_geo_db_zipcode" VALUES(21654,48761,-5,'South Branch, Michigan 48761',15108,19008);
INSERT INTO "django_geo_db_zipcode" VALUES(21655,48762,-5,'Spruce, Michigan 48762',15109,19009);
INSERT INTO "django_geo_db_zipcode" VALUES(21656,48763,-5,'Tawas City, Michigan 48763',15110,19010);
INSERT INTO "django_geo_db_zipcode" VALUES(21657,48764,-5,'Tawas City, Michigan 48764',15110,19011);
INSERT INTO "django_geo_db_zipcode" VALUES(21658,48765,-5,'Turner, Michigan 48765',15111,19012);
INSERT INTO "django_geo_db_zipcode" VALUES(21659,48766,-5,'Twining, Michigan 48766',15112,19013);
INSERT INTO "django_geo_db_zipcode" VALUES(21660,48767,-5,'Unionville, Michigan 48767',15113,19014);
INSERT INTO "django_geo_db_zipcode" VALUES(21661,48768,-5,'Vassar, Michigan 48768',15114,19015);
INSERT INTO "django_geo_db_zipcode" VALUES(21662,48769,-5,'Tuscola, Michigan 48769',15115,19016);
INSERT INTO "django_geo_db_zipcode" VALUES(21663,48770,-5,'Whittemore, Michigan 48770',15116,19017);
INSERT INTO "django_geo_db_zipcode" VALUES(21664,48787,-5,'Frankenmuth, Michigan 48787',15084,19018);
INSERT INTO "django_geo_db_zipcode" VALUES(21665,48801,-5,'Alma, Michigan 48801',15117,19019);
INSERT INTO "django_geo_db_zipcode" VALUES(21666,48802,-5,'Alma, Michigan 48802',15117,19020);
INSERT INTO "django_geo_db_zipcode" VALUES(21667,48803,-5,'Troy, Michigan 48803',14816,19021);
INSERT INTO "django_geo_db_zipcode" VALUES(21668,48804,-5,'Mount Pleasant, Michigan 48804',15118,19022);
INSERT INTO "django_geo_db_zipcode" VALUES(21669,48805,-5,'Okemos, Michigan 48805',15119,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21670,48806,-5,'Ashley, Michigan 48806',15120,19024);
INSERT INTO "django_geo_db_zipcode" VALUES(21671,48807,-5,'Bannister, Michigan 48807',15121,19025);
INSERT INTO "django_geo_db_zipcode" VALUES(21672,48808,-5,'Bath, Michigan 48808',15122,19026);
INSERT INTO "django_geo_db_zipcode" VALUES(21673,48809,-5,'Belding, Michigan 48809',15123,19027);
INSERT INTO "django_geo_db_zipcode" VALUES(21674,48811,-5,'Carson City, Michigan 48811',15124,19028);
INSERT INTO "django_geo_db_zipcode" VALUES(21675,48812,-5,'Cedar Lake, Michigan 48812',15125,19029);
INSERT INTO "django_geo_db_zipcode" VALUES(21676,48813,-5,'Charlotte, Michigan 48813',15126,19030);
INSERT INTO "django_geo_db_zipcode" VALUES(21677,48815,-5,'Clarksville, Michigan 48815',15127,19031);
INSERT INTO "django_geo_db_zipcode" VALUES(21678,48816,-5,'Cohoctah, Michigan 48816',15128,19032);
INSERT INTO "django_geo_db_zipcode" VALUES(21679,48817,-5,'Corunna, Michigan 48817',15129,19033);
INSERT INTO "django_geo_db_zipcode" VALUES(21680,48818,-5,'Crystal, Michigan 48818',15130,19034);
INSERT INTO "django_geo_db_zipcode" VALUES(21681,48819,-5,'Dansville, Michigan 48819',15131,19035);
INSERT INTO "django_geo_db_zipcode" VALUES(21682,48820,-5,'Dewitt, Michigan 48820',15132,19036);
INSERT INTO "django_geo_db_zipcode" VALUES(21683,48821,-5,'Dimondale, Michigan 48821',15133,19037);
INSERT INTO "django_geo_db_zipcode" VALUES(21684,48822,-5,'Eagle, Michigan 48822',15134,19038);
INSERT INTO "django_geo_db_zipcode" VALUES(21685,48823,-5,'East Lansing, Michigan 48823',15135,19039);
INSERT INTO "django_geo_db_zipcode" VALUES(21686,48824,-5,'East Lansing, Michigan 48824',15135,19040);
INSERT INTO "django_geo_db_zipcode" VALUES(21687,48825,-5,'East Lansing, Michigan 48825',15135,19041);
INSERT INTO "django_geo_db_zipcode" VALUES(21688,48826,-5,'East Lansing, Michigan 48826',15135,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21689,48827,-5,'Eaton Rapids, Michigan 48827',15136,19042);
INSERT INTO "django_geo_db_zipcode" VALUES(21690,48829,-5,'Edmore, Michigan 48829',15137,19043);
INSERT INTO "django_geo_db_zipcode" VALUES(21691,48830,-5,'Elm Hall, Michigan 48830',15138,19044);
INSERT INTO "django_geo_db_zipcode" VALUES(21692,48831,-5,'Elsie, Michigan 48831',15139,19045);
INSERT INTO "django_geo_db_zipcode" VALUES(21693,48832,-5,'Elwell, Michigan 48832',15140,19046);
INSERT INTO "django_geo_db_zipcode" VALUES(21694,48833,-5,'Eureka, Michigan 48833',15141,19047);
INSERT INTO "django_geo_db_zipcode" VALUES(21695,48834,-5,'Fenwick, Michigan 48834',15142,19048);
INSERT INTO "django_geo_db_zipcode" VALUES(21696,48835,-5,'Fowler, Michigan 48835',15143,19049);
INSERT INTO "django_geo_db_zipcode" VALUES(21697,48836,-5,'Fowlerville, Michigan 48836',15144,19050);
INSERT INTO "django_geo_db_zipcode" VALUES(21698,48837,-5,'Grand Ledge, Michigan 48837',15145,19051);
INSERT INTO "django_geo_db_zipcode" VALUES(21699,48838,-5,'Greenville, Michigan 48838',15146,19052);
INSERT INTO "django_geo_db_zipcode" VALUES(21700,48840,-5,'Haslett, Michigan 48840',15147,19053);
INSERT INTO "django_geo_db_zipcode" VALUES(21701,48841,-5,'Henderson, Michigan 48841',15148,19054);
INSERT INTO "django_geo_db_zipcode" VALUES(21702,48842,-5,'Holt, Michigan 48842',15149,19055);
INSERT INTO "django_geo_db_zipcode" VALUES(21703,48843,-5,'Howell, Michigan 48843',15150,19056);
INSERT INTO "django_geo_db_zipcode" VALUES(21704,48844,-5,'Howell, Michigan 48844',15150,19057);
INSERT INTO "django_geo_db_zipcode" VALUES(21705,48845,-5,'Hubbardston, Michigan 48845',15151,19058);
INSERT INTO "django_geo_db_zipcode" VALUES(21706,48846,-5,'Ionia, Michigan 48846',15152,19059);
INSERT INTO "django_geo_db_zipcode" VALUES(21707,48847,-5,'Ithaca, Michigan 48847',15153,19060);
INSERT INTO "django_geo_db_zipcode" VALUES(21708,48848,-5,'Laingsburg, Michigan 48848',15154,19061);
INSERT INTO "django_geo_db_zipcode" VALUES(21709,48849,-5,'Lake Odessa, Michigan 48849',15155,19062);
INSERT INTO "django_geo_db_zipcode" VALUES(21710,48850,-5,'Lakeview, Michigan 48850',15156,19063);
INSERT INTO "django_geo_db_zipcode" VALUES(21711,48851,-5,'Lyons, Michigan 48851',15157,19064);
INSERT INTO "django_geo_db_zipcode" VALUES(21712,48852,-5,'Mcbrides, Michigan 48852',15158,19065);
INSERT INTO "django_geo_db_zipcode" VALUES(21713,48853,-5,'Maple Rapids, Michigan 48853',15159,19066);
INSERT INTO "django_geo_db_zipcode" VALUES(21714,48854,-5,'Mason, Michigan 48854',15160,19067);
INSERT INTO "django_geo_db_zipcode" VALUES(21715,48855,-5,'Howell, Michigan 48855',15150,19068);
INSERT INTO "django_geo_db_zipcode" VALUES(21716,48856,-5,'Middleton, Michigan 48856',15161,19069);
INSERT INTO "django_geo_db_zipcode" VALUES(21717,48857,-5,'Morrice, Michigan 48857',15162,19070);
INSERT INTO "django_geo_db_zipcode" VALUES(21718,48858,-5,'Mount Pleasant, Michigan 48858',15118,19071);
INSERT INTO "django_geo_db_zipcode" VALUES(21719,48859,-5,'Mount Pleasant, Michigan 48859',15118,19072);
INSERT INTO "django_geo_db_zipcode" VALUES(21720,48860,-5,'Muir, Michigan 48860',15163,19073);
INSERT INTO "django_geo_db_zipcode" VALUES(21721,48861,-5,'Mulliken, Michigan 48861',15164,19074);
INSERT INTO "django_geo_db_zipcode" VALUES(21722,48862,-5,'North Star, Michigan 48862',15165,19075);
INSERT INTO "django_geo_db_zipcode" VALUES(21723,48863,-5,'Oak Grove, Michigan 48863',15166,19057);
INSERT INTO "django_geo_db_zipcode" VALUES(21724,48864,-5,'Okemos, Michigan 48864',15119,19076);
INSERT INTO "django_geo_db_zipcode" VALUES(21725,48865,-5,'Orleans, Michigan 48865',15167,19077);
INSERT INTO "django_geo_db_zipcode" VALUES(21726,48866,-5,'Ovid, Michigan 48866',15168,19078);
INSERT INTO "django_geo_db_zipcode" VALUES(21727,48867,-5,'Owosso, Michigan 48867',15169,19079);
INSERT INTO "django_geo_db_zipcode" VALUES(21728,48870,-5,'Palo, Michigan 48870',15170,19080);
INSERT INTO "django_geo_db_zipcode" VALUES(21729,48871,-5,'Perrinton, Michigan 48871',15171,19081);
INSERT INTO "django_geo_db_zipcode" VALUES(21730,48872,-5,'Perry, Michigan 48872',15172,19082);
INSERT INTO "django_geo_db_zipcode" VALUES(21731,48873,-5,'Pewamo, Michigan 48873',15173,19083);
INSERT INTO "django_geo_db_zipcode" VALUES(21732,48874,-5,'Pompeii, Michigan 48874',15174,19084);
INSERT INTO "django_geo_db_zipcode" VALUES(21733,48875,-5,'Portland, Michigan 48875',15175,19085);
INSERT INTO "django_geo_db_zipcode" VALUES(21734,48876,-5,'Potterville, Michigan 48876',15176,19086);
INSERT INTO "django_geo_db_zipcode" VALUES(21735,48877,-5,'Riverdale, Michigan 48877',15177,19087);
INSERT INTO "django_geo_db_zipcode" VALUES(21736,48878,-5,'Rosebush, Michigan 48878',15178,19088);
INSERT INTO "django_geo_db_zipcode" VALUES(21737,48879,-5,'Saint Johns, Michigan 48879',15179,19089);
INSERT INTO "django_geo_db_zipcode" VALUES(21738,48880,-5,'Saint Louis, Michigan 48880',15180,19090);
INSERT INTO "django_geo_db_zipcode" VALUES(21739,48881,-5,'Saranac, Michigan 48881',15181,19091);
INSERT INTO "django_geo_db_zipcode" VALUES(21740,48882,-5,'Shaftsburg, Michigan 48882',15182,19092);
INSERT INTO "django_geo_db_zipcode" VALUES(21741,48883,-5,'Shepherd, Michigan 48883',15183,19093);
INSERT INTO "django_geo_db_zipcode" VALUES(21742,48884,-5,'Sheridan, Michigan 48884',15184,19094);
INSERT INTO "django_geo_db_zipcode" VALUES(21743,48885,-5,'Sidney, Michigan 48885',15185,19095);
INSERT INTO "django_geo_db_zipcode" VALUES(21744,48886,-5,'Six Lakes, Michigan 48886',15186,19096);
INSERT INTO "django_geo_db_zipcode" VALUES(21745,48887,-5,'Smyrna, Michigan 48887',15187,19097);
INSERT INTO "django_geo_db_zipcode" VALUES(21746,48888,-5,'Stanton, Michigan 48888',15188,19098);
INSERT INTO "django_geo_db_zipcode" VALUES(21747,48889,-5,'Sumner, Michigan 48889',15189,19099);
INSERT INTO "django_geo_db_zipcode" VALUES(21748,48890,-5,'Sunfield, Michigan 48890',15190,19100);
INSERT INTO "django_geo_db_zipcode" VALUES(21749,48891,-5,'Vestaburg, Michigan 48891',15191,19101);
INSERT INTO "django_geo_db_zipcode" VALUES(21750,48892,-5,'Webberville, Michigan 48892',15192,19102);
INSERT INTO "django_geo_db_zipcode" VALUES(21751,48893,-5,'Weidman, Michigan 48893',15193,19103);
INSERT INTO "django_geo_db_zipcode" VALUES(21752,48894,-5,'Westphalia, Michigan 48894',15194,19104);
INSERT INTO "django_geo_db_zipcode" VALUES(21753,48895,-5,'Williamston, Michigan 48895',15195,19105);
INSERT INTO "django_geo_db_zipcode" VALUES(21754,48896,-5,'Winn, Michigan 48896',15196,19106);
INSERT INTO "django_geo_db_zipcode" VALUES(21755,48897,-5,'Woodland, Michigan 48897',15197,19107);
INSERT INTO "django_geo_db_zipcode" VALUES(21756,48901,-5,'Lansing, Michigan 48901',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21757,48906,-5,'Lansing, Michigan 48906',15198,19108);
INSERT INTO "django_geo_db_zipcode" VALUES(21758,48907,-5,'Lansing, Michigan 48907',15198,19109);
INSERT INTO "django_geo_db_zipcode" VALUES(21759,48908,-5,'Lansing, Michigan 48908',15198,19109);
INSERT INTO "django_geo_db_zipcode" VALUES(21760,48909,-5,'Lansing, Michigan 48909',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21761,48910,-5,'Lansing, Michigan 48910',15198,19110);
INSERT INTO "django_geo_db_zipcode" VALUES(21762,48911,-5,'Lansing, Michigan 48911',15198,19111);
INSERT INTO "django_geo_db_zipcode" VALUES(21763,48912,-5,'Lansing, Michigan 48912',15198,19112);
INSERT INTO "django_geo_db_zipcode" VALUES(21764,48913,-5,'Lansing, Michigan 48913',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21765,48915,-5,'Lansing, Michigan 48915',15198,19113);
INSERT INTO "django_geo_db_zipcode" VALUES(21766,48916,-5,'Lansing, Michigan 48916',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21767,48917,-5,'Lansing, Michigan 48917',15198,19114);
INSERT INTO "django_geo_db_zipcode" VALUES(21768,48918,-5,'Lansing, Michigan 48918',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21769,48919,-5,'Lansing, Michigan 48919',15198,19115);
INSERT INTO "django_geo_db_zipcode" VALUES(21770,48921,-5,'Lansing, Michigan 48921',15198,19116);
INSERT INTO "django_geo_db_zipcode" VALUES(21771,48922,-5,'Lansing, Michigan 48922',15198,19117);
INSERT INTO "django_geo_db_zipcode" VALUES(21772,48924,-5,'Lansing, Michigan 48924',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21773,48929,-5,'Lansing, Michigan 48929',15198,19117);
INSERT INTO "django_geo_db_zipcode" VALUES(21774,48930,-5,'Lansing, Michigan 48930',15198,19117);
INSERT INTO "django_geo_db_zipcode" VALUES(21775,48933,-5,'Lansing, Michigan 48933',15198,19118);
INSERT INTO "django_geo_db_zipcode" VALUES(21776,48937,-5,'Lansing, Michigan 48937',15198,19119);
INSERT INTO "django_geo_db_zipcode" VALUES(21777,48950,-5,'Lansing, Michigan 48950',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21778,48956,-5,'Lansing, Michigan 48956',15198,19117);
INSERT INTO "django_geo_db_zipcode" VALUES(21779,48980,-5,'Lansing, Michigan 48980',15198,19023);
INSERT INTO "django_geo_db_zipcode" VALUES(21780,49001,-5,'Kalamazoo, Michigan 49001',15199,19120);
INSERT INTO "django_geo_db_zipcode" VALUES(21781,49002,-5,'Portage, Michigan 49002',15200,19121);
INSERT INTO "django_geo_db_zipcode" VALUES(21782,49003,-5,'Kalamazoo, Michigan 49003',15199,19122);
INSERT INTO "django_geo_db_zipcode" VALUES(21783,49004,-5,'Kalamazoo, Michigan 49004',15199,19123);
INSERT INTO "django_geo_db_zipcode" VALUES(21784,49005,-5,'Kalamazoo, Michigan 49005',15199,19124);
INSERT INTO "django_geo_db_zipcode" VALUES(21785,49006,-5,'Kalamazoo, Michigan 49006',15199,19125);
INSERT INTO "django_geo_db_zipcode" VALUES(21786,49007,-5,'Kalamazoo, Michigan 49007',15199,19126);
INSERT INTO "django_geo_db_zipcode" VALUES(21787,49008,-5,'Kalamazoo, Michigan 49008',15199,19127);
INSERT INTO "django_geo_db_zipcode" VALUES(21788,49009,-5,'Kalamazoo, Michigan 49009',15199,19128);
INSERT INTO "django_geo_db_zipcode" VALUES(21789,49010,-5,'Allegan, Michigan 49010',15201,19129);
INSERT INTO "django_geo_db_zipcode" VALUES(21790,49011,-5,'Athens, Michigan 49011',15202,19130);
INSERT INTO "django_geo_db_zipcode" VALUES(21791,49012,-5,'Augusta, Michigan 49012',15203,19131);
INSERT INTO "django_geo_db_zipcode" VALUES(21792,49013,-5,'Bangor, Michigan 49013',15204,19132);
INSERT INTO "django_geo_db_zipcode" VALUES(21793,49014,-5,'Battle Creek, Michigan 49014',15205,19133);
INSERT INTO "django_geo_db_zipcode" VALUES(21794,49015,-5,'Battle Creek, Michigan 49015',15205,19134);
INSERT INTO "django_geo_db_zipcode" VALUES(21795,49016,-5,'Battle Creek, Michigan 49016',15205,19135);
INSERT INTO "django_geo_db_zipcode" VALUES(21796,49017,-5,'Battle Creek, Michigan 49017',15205,19136);
INSERT INTO "django_geo_db_zipcode" VALUES(21797,49018,-5,'Battle Creek, Michigan 49018',15205,19137);
INSERT INTO "django_geo_db_zipcode" VALUES(21798,49019,-5,'Kalamazoo, Michigan 49019',15199,19122);
INSERT INTO "django_geo_db_zipcode" VALUES(21799,49020,-5,'Bedford, Michigan 49020',15206,19137);
INSERT INTO "django_geo_db_zipcode" VALUES(21800,49021,-5,'Bellevue, Michigan 49021',15207,19138);
INSERT INTO "django_geo_db_zipcode" VALUES(21801,49022,-5,'Benton Harbor, Michigan 49022',15208,19139);
INSERT INTO "django_geo_db_zipcode" VALUES(21802,49023,-5,'Benton Harbor, Michigan 49023',15208,19140);
INSERT INTO "django_geo_db_zipcode" VALUES(21803,49024,-5,'Portage, Michigan 49024',15200,19141);
INSERT INTO "django_geo_db_zipcode" VALUES(21804,49026,-5,'Bloomingdale, Michigan 49026',15209,19142);
INSERT INTO "django_geo_db_zipcode" VALUES(21805,49027,-5,'Breedsville, Michigan 49027',15210,19143);
INSERT INTO "django_geo_db_zipcode" VALUES(21806,49028,-5,'Bronson, Michigan 49028',15211,19144);
INSERT INTO "django_geo_db_zipcode" VALUES(21807,49029,-5,'Burlington, Michigan 49029',15212,19145);
INSERT INTO "django_geo_db_zipcode" VALUES(21808,49030,-5,'Burr Oak, Michigan 49030',15213,19146);
INSERT INTO "django_geo_db_zipcode" VALUES(21809,49031,-5,'Cassopolis, Michigan 49031',15214,19147);
INSERT INTO "django_geo_db_zipcode" VALUES(21810,49032,-5,'Centreville, Michigan 49032',15215,19148);
INSERT INTO "django_geo_db_zipcode" VALUES(21811,49033,-5,'Ceresco, Michigan 49033',15216,19149);
INSERT INTO "django_geo_db_zipcode" VALUES(21812,49034,-5,'Climax, Michigan 49034',15217,19150);
INSERT INTO "django_geo_db_zipcode" VALUES(21813,49035,-5,'Cloverdale, Michigan 49035',15218,19151);
INSERT INTO "django_geo_db_zipcode" VALUES(21814,49036,-5,'Coldwater, Michigan 49036',15219,19152);
INSERT INTO "django_geo_db_zipcode" VALUES(21815,49038,-5,'Coloma, Michigan 49038',15220,19153);
INSERT INTO "django_geo_db_zipcode" VALUES(21816,49039,-5,'Hagar Shores, Michigan 49039',15221,19154);
INSERT INTO "django_geo_db_zipcode" VALUES(21817,49040,-5,'Colon, Michigan 49040',15222,19155);
INSERT INTO "django_geo_db_zipcode" VALUES(21818,49041,-5,'Comstock, Michigan 49041',15223,19122);
INSERT INTO "django_geo_db_zipcode" VALUES(21819,49042,-5,'Constantine, Michigan 49042',15224,19156);
INSERT INTO "django_geo_db_zipcode" VALUES(21820,49043,-5,'Covert, Michigan 49043',15225,19157);
INSERT INTO "django_geo_db_zipcode" VALUES(21821,49045,-5,'Decatur, Michigan 49045',15226,19158);
INSERT INTO "django_geo_db_zipcode" VALUES(21822,49046,-5,'Delton, Michigan 49046',15227,19159);
INSERT INTO "django_geo_db_zipcode" VALUES(21823,49047,-5,'Dowagiac, Michigan 49047',15228,19160);
INSERT INTO "django_geo_db_zipcode" VALUES(21824,49048,-5,'Kalamazoo, Michigan 49048',15199,19161);
INSERT INTO "django_geo_db_zipcode" VALUES(21825,49050,-5,'Dowling, Michigan 49050',15229,19162);
INSERT INTO "django_geo_db_zipcode" VALUES(21826,49051,-5,'East Leroy, Michigan 49051',15230,19163);
INSERT INTO "django_geo_db_zipcode" VALUES(21827,49052,-5,'Fulton, Michigan 49052',15231,19164);
INSERT INTO "django_geo_db_zipcode" VALUES(21828,49053,-5,'Galesburg, Michigan 49053',15232,19165);
INSERT INTO "django_geo_db_zipcode" VALUES(21829,49055,-5,'Gobles, Michigan 49055',15233,19166);
INSERT INTO "django_geo_db_zipcode" VALUES(21830,49056,-5,'Grand Junction, Michigan 49056',15234,19167);
INSERT INTO "django_geo_db_zipcode" VALUES(21831,49057,-5,'Hartford, Michigan 49057',15235,19168);
INSERT INTO "django_geo_db_zipcode" VALUES(21832,49058,-5,'Hastings, Michigan 49058',15236,19169);
INSERT INTO "django_geo_db_zipcode" VALUES(21833,49060,-5,'Hickory Corners, Michigan 49060',15237,19170);
INSERT INTO "django_geo_db_zipcode" VALUES(21834,49061,-5,'Jones, Michigan 49061',15238,19171);
INSERT INTO "django_geo_db_zipcode" VALUES(21835,49062,-5,'Kendall, Michigan 49062',15239,19172);
INSERT INTO "django_geo_db_zipcode" VALUES(21836,49063,-5,'Lacota, Michigan 49063',15240,19173);
INSERT INTO "django_geo_db_zipcode" VALUES(21837,49064,-5,'Lawrence, Michigan 49064',15241,19174);
INSERT INTO "django_geo_db_zipcode" VALUES(21838,49065,-5,'Lawton, Michigan 49065',15242,19175);
INSERT INTO "django_geo_db_zipcode" VALUES(21839,49066,-5,'Leonidas, Michigan 49066',15243,19176);
INSERT INTO "django_geo_db_zipcode" VALUES(21840,49067,-5,'Marcellus, Michigan 49067',15244,19177);
INSERT INTO "django_geo_db_zipcode" VALUES(21841,49068,-5,'Marshall, Michigan 49068',15245,19178);
INSERT INTO "django_geo_db_zipcode" VALUES(21842,49069,-5,'Marshall, Michigan 49069',15245,19179);
INSERT INTO "django_geo_db_zipcode" VALUES(21843,49070,-5,'Martin, Michigan 49070',15246,19180);
INSERT INTO "django_geo_db_zipcode" VALUES(21844,49071,-5,'Mattawan, Michigan 49071',15247,19181);
INSERT INTO "django_geo_db_zipcode" VALUES(21845,49072,-5,'Mendon, Michigan 49072',15248,19182);
INSERT INTO "django_geo_db_zipcode" VALUES(21846,49073,-5,'Nashville, Michigan 49073',15249,19183);
INSERT INTO "django_geo_db_zipcode" VALUES(21847,49074,-5,'Nazareth, Michigan 49074',15250,19122);
INSERT INTO "django_geo_db_zipcode" VALUES(21848,49075,-5,'Nottawa, Michigan 49075',15251,19184);
INSERT INTO "django_geo_db_zipcode" VALUES(21849,49076,-5,'Olivet, Michigan 49076',15252,19185);
INSERT INTO "django_geo_db_zipcode" VALUES(21850,49077,-5,'Oshtemo, Michigan 49077',15253,19122);
INSERT INTO "django_geo_db_zipcode" VALUES(21851,49078,-5,'Otsego, Michigan 49078',15254,19186);
INSERT INTO "django_geo_db_zipcode" VALUES(21852,49079,-5,'Paw Paw, Michigan 49079',15255,19187);
INSERT INTO "django_geo_db_zipcode" VALUES(21853,49080,-5,'Plainwell, Michigan 49080',15256,19188);
INSERT INTO "django_geo_db_zipcode" VALUES(21854,49081,-5,'Portage, Michigan 49081',15200,19189);
INSERT INTO "django_geo_db_zipcode" VALUES(21855,49082,-5,'Quincy, Michigan 49082',15257,19190);
INSERT INTO "django_geo_db_zipcode" VALUES(21856,49083,-5,'Richland, Michigan 49083',15258,19191);
INSERT INTO "django_geo_db_zipcode" VALUES(21857,49084,-5,'Riverside, Michigan 49084',15259,19192);
INSERT INTO "django_geo_db_zipcode" VALUES(21858,49085,-5,'Saint Joseph, Michigan 49085',15260,19193);
INSERT INTO "django_geo_db_zipcode" VALUES(21859,49087,-5,'Schoolcraft, Michigan 49087',15261,19194);
INSERT INTO "django_geo_db_zipcode" VALUES(21860,49088,-5,'Scotts, Michigan 49088',15262,19195);
INSERT INTO "django_geo_db_zipcode" VALUES(21861,49089,-5,'Sherwood, Michigan 49089',15263,19196);
INSERT INTO "django_geo_db_zipcode" VALUES(21862,49090,-5,'South Haven, Michigan 49090',15264,19197);
INSERT INTO "django_geo_db_zipcode" VALUES(21863,49091,-5,'Sturgis, Michigan 49091',15265,19198);
INSERT INTO "django_geo_db_zipcode" VALUES(21864,49092,-5,'Tekonsha, Michigan 49092',15266,19199);
INSERT INTO "django_geo_db_zipcode" VALUES(21865,49093,-5,'Three Rivers, Michigan 49093',15267,19200);
INSERT INTO "django_geo_db_zipcode" VALUES(21866,49094,-5,'Union City, Michigan 49094',15268,19201);
INSERT INTO "django_geo_db_zipcode" VALUES(21867,49095,-5,'Vandalia, Michigan 49095',15269,19202);
INSERT INTO "django_geo_db_zipcode" VALUES(21868,49096,-5,'Vermontville, Michigan 49096',15270,19203);
INSERT INTO "django_geo_db_zipcode" VALUES(21869,49097,-5,'Vicksburg, Michigan 49097',15271,19204);
INSERT INTO "django_geo_db_zipcode" VALUES(21870,49098,-5,'Watervliet, Michigan 49098',15272,19205);
INSERT INTO "django_geo_db_zipcode" VALUES(21871,49099,-5,'White Pigeon, Michigan 49099',15273,19206);
INSERT INTO "django_geo_db_zipcode" VALUES(21872,49101,-5,'Baroda, Michigan 49101',15274,19207);
INSERT INTO "django_geo_db_zipcode" VALUES(21873,49102,-5,'Berrien Center, Michigan 49102',15275,19208);
INSERT INTO "django_geo_db_zipcode" VALUES(21874,49103,-5,'Berrien Springs, Michigan 49103',15276,19209);
INSERT INTO "django_geo_db_zipcode" VALUES(21875,49104,-5,'Berrien Springs, Michigan 49104',15276,19140);
INSERT INTO "django_geo_db_zipcode" VALUES(21876,49106,-5,'Bridgman, Michigan 49106',15277,19210);
INSERT INTO "django_geo_db_zipcode" VALUES(21877,49107,-5,'Buchanan, Michigan 49107',15278,19211);
INSERT INTO "django_geo_db_zipcode" VALUES(21878,49111,-5,'Eau Claire, Michigan 49111',15279,19212);
INSERT INTO "django_geo_db_zipcode" VALUES(21879,49112,-5,'Edwardsburg, Michigan 49112',15280,19213);
INSERT INTO "django_geo_db_zipcode" VALUES(21880,49113,-5,'Galien, Michigan 49113',15281,19214);
INSERT INTO "django_geo_db_zipcode" VALUES(21881,49115,-5,'Harbert, Michigan 49115',15282,19215);
INSERT INTO "django_geo_db_zipcode" VALUES(21882,49116,-5,'Lakeside, Michigan 49116',15283,19216);
INSERT INTO "django_geo_db_zipcode" VALUES(21883,49117,-5,'New Buffalo, Michigan 49117',15284,19217);
INSERT INTO "django_geo_db_zipcode" VALUES(21884,49119,-5,'New Troy, Michigan 49119',15285,19218);
INSERT INTO "django_geo_db_zipcode" VALUES(21885,49120,-5,'Niles, Michigan 49120',15286,19219);
INSERT INTO "django_geo_db_zipcode" VALUES(21886,49121,-5,'Niles, Michigan 49121',15286,19140);
INSERT INTO "django_geo_db_zipcode" VALUES(21887,49125,-5,'Sawyer, Michigan 49125',15287,19220);
INSERT INTO "django_geo_db_zipcode" VALUES(21888,49126,-5,'Sodus, Michigan 49126',15288,19221);
INSERT INTO "django_geo_db_zipcode" VALUES(21889,49127,-5,'Stevensville, Michigan 49127',15289,19222);
INSERT INTO "django_geo_db_zipcode" VALUES(21890,49128,-5,'Three Oaks, Michigan 49128',15290,19223);
INSERT INTO "django_geo_db_zipcode" VALUES(21891,49129,-5,'Union Pier, Michigan 49129',15291,19224);
INSERT INTO "django_geo_db_zipcode" VALUES(21892,49130,-5,'Union, Michigan 49130',15292,19225);
INSERT INTO "django_geo_db_zipcode" VALUES(21893,49137,-5,'Lyndon, Michigan 49137',15293,19226);
INSERT INTO "django_geo_db_zipcode" VALUES(21894,49157,-5,'Richland, Michigan 49157',15258,19227);
INSERT INTO "django_geo_db_zipcode" VALUES(21895,49169,-5,'Dickson, Michigan 49169',15294,19228);
INSERT INTO "django_geo_db_zipcode" VALUES(21896,49201,-5,'Jackson, Michigan 49201',15295,19229);
INSERT INTO "django_geo_db_zipcode" VALUES(21897,49202,-5,'Jackson, Michigan 49202',15295,19230);
INSERT INTO "django_geo_db_zipcode" VALUES(21898,49203,-5,'Jackson, Michigan 49203',15295,19231);
INSERT INTO "django_geo_db_zipcode" VALUES(21899,49204,-5,'Jackson, Michigan 49204',15295,19232);
INSERT INTO "django_geo_db_zipcode" VALUES(21900,49220,-5,'Addison, Michigan 49220',15296,19233);
INSERT INTO "django_geo_db_zipcode" VALUES(21901,49221,-5,'Adrian, Michigan 49221',15297,19234);
INSERT INTO "django_geo_db_zipcode" VALUES(21902,49224,-5,'Albion, Michigan 49224',15298,19235);
INSERT INTO "django_geo_db_zipcode" VALUES(21903,49226,-5,'Bloomingdale, Michigan 49226',15209,19236);
INSERT INTO "django_geo_db_zipcode" VALUES(21904,49227,-5,'Allen, Michigan 49227',15299,19237);
INSERT INTO "django_geo_db_zipcode" VALUES(21905,49228,-5,'Blissfield, Michigan 49228',15300,19238);
INSERT INTO "django_geo_db_zipcode" VALUES(21906,49229,-5,'Britton, Michigan 49229',15301,19239);
INSERT INTO "django_geo_db_zipcode" VALUES(21907,49230,-5,'Brooklyn, Michigan 49230',15302,19240);
INSERT INTO "django_geo_db_zipcode" VALUES(21908,49232,-5,'Camden, Michigan 49232',15303,19241);
INSERT INTO "django_geo_db_zipcode" VALUES(21909,49233,-5,'Cement City, Michigan 49233',15304,19242);
INSERT INTO "django_geo_db_zipcode" VALUES(21910,49234,-5,'Clarklake, Michigan 49234',15305,19243);
INSERT INTO "django_geo_db_zipcode" VALUES(21911,49235,-5,'Clayton, Michigan 49235',15306,19244);
INSERT INTO "django_geo_db_zipcode" VALUES(21912,49236,-5,'Clinton, Michigan 49236',14931,19245);
INSERT INTO "django_geo_db_zipcode" VALUES(21913,49237,-5,'Concord, Michigan 49237',15307,19246);
INSERT INTO "django_geo_db_zipcode" VALUES(21914,49238,-5,'Deerfield, Michigan 49238',15308,19247);
INSERT INTO "django_geo_db_zipcode" VALUES(21915,49239,-5,'Frontier, Michigan 49239',15309,19248);
INSERT INTO "django_geo_db_zipcode" VALUES(21916,49240,-5,'Grass Lake, Michigan 49240',15310,19249);
INSERT INTO "django_geo_db_zipcode" VALUES(21917,49241,-5,'Hanover, Michigan 49241',15311,19250);
INSERT INTO "django_geo_db_zipcode" VALUES(21918,49242,-5,'Hillsdale, Michigan 49242',15312,19251);
INSERT INTO "django_geo_db_zipcode" VALUES(21919,49245,-5,'Homer, Michigan 49245',15313,19252);
INSERT INTO "django_geo_db_zipcode" VALUES(21920,49246,-5,'Horton, Michigan 49246',15314,19253);
INSERT INTO "django_geo_db_zipcode" VALUES(21921,49247,-5,'Hudson, Michigan 49247',15315,19254);
INSERT INTO "django_geo_db_zipcode" VALUES(21922,49248,-5,'Jasper, Michigan 49248',15316,19255);
INSERT INTO "django_geo_db_zipcode" VALUES(21923,49249,-5,'Jerome, Michigan 49249',15317,19256);
INSERT INTO "django_geo_db_zipcode" VALUES(21924,49250,-5,'Jonesville, Michigan 49250',15318,19257);
INSERT INTO "django_geo_db_zipcode" VALUES(21925,49251,-5,'Leslie, Michigan 49251',15319,19258);
INSERT INTO "django_geo_db_zipcode" VALUES(21926,49252,-5,'Litchfield, Michigan 49252',15320,19259);
INSERT INTO "django_geo_db_zipcode" VALUES(21927,49253,-5,'Manitou Beach, Michigan 49253',15321,19260);
INSERT INTO "django_geo_db_zipcode" VALUES(21928,49254,-5,'Michigan Center, Michigan 49254',15322,19261);
INSERT INTO "django_geo_db_zipcode" VALUES(21929,49255,-5,'Montgomery, Michigan 49255',15323,19262);
INSERT INTO "django_geo_db_zipcode" VALUES(21930,49256,-5,'Morenci, Michigan 49256',15324,19263);
INSERT INTO "django_geo_db_zipcode" VALUES(21931,49257,-5,'Moscow, Michigan 49257',15325,19264);
INSERT INTO "django_geo_db_zipcode" VALUES(21932,49258,-5,'Mosherville, Michigan 49258',15326,19265);
INSERT INTO "django_geo_db_zipcode" VALUES(21933,49259,-5,'Munith, Michigan 49259',15327,19266);
INSERT INTO "django_geo_db_zipcode" VALUES(21934,49261,-5,'Napoleon, Michigan 49261',15328,19267);
INSERT INTO "django_geo_db_zipcode" VALUES(21935,49262,-5,'North Adams, Michigan 49262',15329,19268);
INSERT INTO "django_geo_db_zipcode" VALUES(21936,49263,-5,'Norvell, Michigan 49263',15330,19269);
INSERT INTO "django_geo_db_zipcode" VALUES(21937,49264,-5,'Onondaga, Michigan 49264',15331,19270);
INSERT INTO "django_geo_db_zipcode" VALUES(21938,49265,-5,'Onsted, Michigan 49265',15332,19271);
INSERT INTO "django_geo_db_zipcode" VALUES(21939,49266,-5,'Osseo, Michigan 49266',15333,19272);
INSERT INTO "django_geo_db_zipcode" VALUES(21940,49267,-5,'Ottawa Lake, Michigan 49267',15334,19273);
INSERT INTO "django_geo_db_zipcode" VALUES(21941,49268,-5,'Palmyra, Michigan 49268',15335,19274);
INSERT INTO "django_geo_db_zipcode" VALUES(21942,49269,-5,'Parma, Michigan 49269',15336,19275);
INSERT INTO "django_geo_db_zipcode" VALUES(21943,49270,-5,'Petersburg, Michigan 49270',15337,19276);
INSERT INTO "django_geo_db_zipcode" VALUES(21944,49271,-5,'Pittsford, Michigan 49271',15338,19277);
INSERT INTO "django_geo_db_zipcode" VALUES(21945,49272,-5,'Pleasant Lake, Michigan 49272',15339,19278);
INSERT INTO "django_geo_db_zipcode" VALUES(21946,49274,-5,'Reading, Michigan 49274',15340,19279);
INSERT INTO "django_geo_db_zipcode" VALUES(21947,49275,-5,'Ridgeway, Michigan 49275',15341,19280);
INSERT INTO "django_geo_db_zipcode" VALUES(21948,49276,-5,'Riga, Michigan 49276',15342,19281);
INSERT INTO "django_geo_db_zipcode" VALUES(21949,49277,-5,'Rives Junction, Michigan 49277',15343,19282);
INSERT INTO "django_geo_db_zipcode" VALUES(21950,49278,-5,'Rollin, Michigan 49278',15344,19283);
INSERT INTO "django_geo_db_zipcode" VALUES(21951,49279,-5,'Sand Creek, Michigan 49279',15345,19284);
INSERT INTO "django_geo_db_zipcode" VALUES(21952,49280,-5,'Seneca, Michigan 49280',15346,19285);
INSERT INTO "django_geo_db_zipcode" VALUES(21953,49281,-5,'Somerset, Michigan 49281',15347,19286);
INSERT INTO "django_geo_db_zipcode" VALUES(21954,49282,-5,'Somerset Center, Michigan 49282',15348,19287);
INSERT INTO "django_geo_db_zipcode" VALUES(21955,49283,-5,'Spring Arbor, Michigan 49283',15349,19288);
INSERT INTO "django_geo_db_zipcode" VALUES(21956,49284,-5,'Springport, Michigan 49284',15350,19289);
INSERT INTO "django_geo_db_zipcode" VALUES(21957,49285,-5,'Stockbridge, Michigan 49285',15351,19290);
INSERT INTO "django_geo_db_zipcode" VALUES(21958,49286,-5,'Tecumseh, Michigan 49286',15352,19291);
INSERT INTO "django_geo_db_zipcode" VALUES(21959,49287,-5,'Tipton, Michigan 49287',15353,19292);
INSERT INTO "django_geo_db_zipcode" VALUES(21960,49288,-5,'Waldron, Michigan 49288',15354,19293);
INSERT INTO "django_geo_db_zipcode" VALUES(21961,49289,-5,'Weston, Michigan 49289',15355,19294);
INSERT INTO "django_geo_db_zipcode" VALUES(21962,49301,-5,'Ada, Michigan 49301',15356,19295);
INSERT INTO "django_geo_db_zipcode" VALUES(21963,49302,-5,'Alto, Michigan 49302',15357,19296);
INSERT INTO "django_geo_db_zipcode" VALUES(21964,49303,-5,'Bailey, Michigan 49303',15358,19297);
INSERT INTO "django_geo_db_zipcode" VALUES(21965,49304,-5,'Baldwin, Michigan 49304',15359,19298);
INSERT INTO "django_geo_db_zipcode" VALUES(21966,49305,-5,'Barryton, Michigan 49305',15360,19299);
INSERT INTO "django_geo_db_zipcode" VALUES(21967,49306,-5,'Belmont, Michigan 49306',15361,19300);
INSERT INTO "django_geo_db_zipcode" VALUES(21968,49307,-5,'Big Rapids, Michigan 49307',15362,19301);
INSERT INTO "django_geo_db_zipcode" VALUES(21969,49309,-5,'Bitely, Michigan 49309',15363,19302);
INSERT INTO "django_geo_db_zipcode" VALUES(21970,49310,-5,'Blanchard, Michigan 49310',15364,19303);
INSERT INTO "django_geo_db_zipcode" VALUES(21971,49311,-5,'Bradley, Michigan 49311',15365,19304);
INSERT INTO "django_geo_db_zipcode" VALUES(21972,49312,-5,'Brohman, Michigan 49312',15366,19305);
INSERT INTO "django_geo_db_zipcode" VALUES(21973,49314,-5,'Burnips, Michigan 49314',15367,19306);
INSERT INTO "django_geo_db_zipcode" VALUES(21974,49315,-5,'Byron Center, Michigan 49315',15368,19307);
INSERT INTO "django_geo_db_zipcode" VALUES(21975,49316,-5,'Caledonia, Michigan 49316',15369,19308);
INSERT INTO "django_geo_db_zipcode" VALUES(21976,49317,-5,'Cannonsburg, Michigan 49317',15370,19309);
INSERT INTO "django_geo_db_zipcode" VALUES(21977,49318,-5,'Casnovia, Michigan 49318',15371,19310);
INSERT INTO "django_geo_db_zipcode" VALUES(21978,49319,-5,'Cedar Springs, Michigan 49319',15372,19311);
INSERT INTO "django_geo_db_zipcode" VALUES(21979,49320,-5,'Chippewa Lake, Michigan 49320',15373,19312);
INSERT INTO "django_geo_db_zipcode" VALUES(21980,49321,-5,'Comstock Park, Michigan 49321',15374,19313);
INSERT INTO "django_geo_db_zipcode" VALUES(21981,49322,-5,'Coral, Michigan 49322',15375,19314);
INSERT INTO "django_geo_db_zipcode" VALUES(21982,49323,-5,'Dorr, Michigan 49323',15376,19315);
INSERT INTO "django_geo_db_zipcode" VALUES(21983,49325,-5,'Freeport, Michigan 49325',15377,19316);
INSERT INTO "django_geo_db_zipcode" VALUES(21984,49326,-5,'Gowen, Michigan 49326',15378,19317);
INSERT INTO "django_geo_db_zipcode" VALUES(21985,49327,-5,'Grant, Michigan 49327',15379,19318);
INSERT INTO "django_geo_db_zipcode" VALUES(21986,49328,-5,'Hopkins, Michigan 49328',15380,19319);
INSERT INTO "django_geo_db_zipcode" VALUES(21987,49329,-5,'Howard City, Michigan 49329',15381,19320);
INSERT INTO "django_geo_db_zipcode" VALUES(21988,49330,-5,'Kent City, Michigan 49330',15382,19321);
INSERT INTO "django_geo_db_zipcode" VALUES(21989,49331,-5,'Lowell, Michigan 49331',15383,19322);
INSERT INTO "django_geo_db_zipcode" VALUES(21990,49332,-5,'Mecosta, Michigan 49332',15384,19323);
INSERT INTO "django_geo_db_zipcode" VALUES(21991,49333,-5,'Middleville, Michigan 49333',15385,19324);
INSERT INTO "django_geo_db_zipcode" VALUES(21992,49335,-5,'Moline, Michigan 49335',15386,19325);
INSERT INTO "django_geo_db_zipcode" VALUES(21993,49336,-5,'Morley, Michigan 49336',15387,19326);
INSERT INTO "django_geo_db_zipcode" VALUES(21994,49337,-5,'Newaygo, Michigan 49337',15388,19327);
INSERT INTO "django_geo_db_zipcode" VALUES(21995,49338,-5,'Paris, Michigan 49338',15389,19328);
INSERT INTO "django_geo_db_zipcode" VALUES(21996,49339,-5,'Pierson, Michigan 49339',15390,19329);
INSERT INTO "django_geo_db_zipcode" VALUES(21997,49340,-5,'Remus, Michigan 49340',15391,19330);
INSERT INTO "django_geo_db_zipcode" VALUES(21998,49341,-5,'Rockford, Michigan 49341',15392,19331);
INSERT INTO "django_geo_db_zipcode" VALUES(21999,49342,-5,'Rodney, Michigan 49342',15393,19332);
INSERT INTO "django_geo_db_zipcode" VALUES(22000,49343,-5,'Sand Lake, Michigan 49343',15394,19333);
INSERT INTO "django_geo_db_zipcode" VALUES(22001,49344,-5,'Shelbyville, Michigan 49344',15395,19334);
INSERT INTO "django_geo_db_zipcode" VALUES(22002,49345,-5,'Sparta, Michigan 49345',15396,19335);
INSERT INTO "django_geo_db_zipcode" VALUES(22003,49346,-5,'Stanwood, Michigan 49346',15397,19336);
INSERT INTO "django_geo_db_zipcode" VALUES(22004,49347,-5,'Trufant, Michigan 49347',15398,19337);
INSERT INTO "django_geo_db_zipcode" VALUES(22005,49348,-5,'Wayland, Michigan 49348',15399,19338);
INSERT INTO "django_geo_db_zipcode" VALUES(22006,49349,-5,'White Cloud, Michigan 49349',15400,19339);
INSERT INTO "django_geo_db_zipcode" VALUES(22007,49351,-5,'Rockford, Michigan 49351',15392,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22008,49355,-5,'Ada, Michigan 49355',15356,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22009,49356,-5,'Ada, Michigan 49356',15356,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22010,49357,-5,'Ada, Michigan 49357',15356,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22011,49368,-5,'Slagle, Michigan 49368',15401,19341);
INSERT INTO "django_geo_db_zipcode" VALUES(22012,49394,-5,'Lincoln, Michigan 49394',15092,19342);
INSERT INTO "django_geo_db_zipcode" VALUES(22013,49401,-5,'Allendale, Michigan 49401',15402,19343);
INSERT INTO "django_geo_db_zipcode" VALUES(22014,49402,-5,'Branch, Michigan 49402',15403,19344);
INSERT INTO "django_geo_db_zipcode" VALUES(22015,49403,-5,'Conklin, Michigan 49403',15404,19345);
INSERT INTO "django_geo_db_zipcode" VALUES(22016,49404,-5,'Coopersville, Michigan 49404',15405,19346);
INSERT INTO "django_geo_db_zipcode" VALUES(22017,49405,-5,'Custer, Michigan 49405',15406,19347);
INSERT INTO "django_geo_db_zipcode" VALUES(22018,49406,-5,'Douglas, Michigan 49406',15407,19348);
INSERT INTO "django_geo_db_zipcode" VALUES(22019,49408,-5,'Fennville, Michigan 49408',15408,19349);
INSERT INTO "django_geo_db_zipcode" VALUES(22020,49409,-5,'Ferrysburg, Michigan 49409',15409,19350);
INSERT INTO "django_geo_db_zipcode" VALUES(22021,49410,-5,'Fountain, Michigan 49410',15410,19351);
INSERT INTO "django_geo_db_zipcode" VALUES(22022,49411,-5,'Free Soil, Michigan 49411',15411,19352);
INSERT INTO "django_geo_db_zipcode" VALUES(22023,49412,-5,'Fremont, Michigan 49412',15412,19353);
INSERT INTO "django_geo_db_zipcode" VALUES(22024,49413,-5,'Fremont, Michigan 49413',15412,19354);
INSERT INTO "django_geo_db_zipcode" VALUES(22025,49415,-5,'Fruitport, Michigan 49415',15413,19355);
INSERT INTO "django_geo_db_zipcode" VALUES(22026,49416,-5,'Glenn, Michigan 49416',15414,19356);
INSERT INTO "django_geo_db_zipcode" VALUES(22027,49417,-5,'Grand Haven, Michigan 49417',15415,19357);
INSERT INTO "django_geo_db_zipcode" VALUES(22028,49418,-5,'Grandville, Michigan 49418',15416,19358);
INSERT INTO "django_geo_db_zipcode" VALUES(22029,49419,-5,'Hamilton, Michigan 49419',15417,19359);
INSERT INTO "django_geo_db_zipcode" VALUES(22030,49420,-5,'Hart, Michigan 49420',15418,19360);
INSERT INTO "django_geo_db_zipcode" VALUES(22031,49421,-5,'Hesperia, Michigan 49421',15419,19361);
INSERT INTO "django_geo_db_zipcode" VALUES(22032,49422,-5,'Holland, Michigan 49422',15420,19362);
INSERT INTO "django_geo_db_zipcode" VALUES(22033,49423,-5,'Holland, Michigan 49423',15420,19363);
INSERT INTO "django_geo_db_zipcode" VALUES(22034,49424,-5,'Holland, Michigan 49424',15420,19364);
INSERT INTO "django_geo_db_zipcode" VALUES(22035,49425,-5,'Holton, Michigan 49425',15421,19365);
INSERT INTO "django_geo_db_zipcode" VALUES(22036,49426,-5,'Hudsonville, Michigan 49426',15422,19366);
INSERT INTO "django_geo_db_zipcode" VALUES(22037,49427,-5,'Jamestown, Michigan 49427',15423,19367);
INSERT INTO "django_geo_db_zipcode" VALUES(22038,49428,-5,'Jenison, Michigan 49428',15424,19368);
INSERT INTO "django_geo_db_zipcode" VALUES(22039,49429,-5,'Jenison, Michigan 49429',15424,19362);
INSERT INTO "django_geo_db_zipcode" VALUES(22040,49430,-5,'Lamont, Michigan 49430',15425,19369);
INSERT INTO "django_geo_db_zipcode" VALUES(22041,49431,-5,'Ludington, Michigan 49431',15426,19370);
INSERT INTO "django_geo_db_zipcode" VALUES(22042,49434,-5,'Macatawa, Michigan 49434',15427,19371);
INSERT INTO "django_geo_db_zipcode" VALUES(22043,49435,-5,'Marne, Michigan 49435',15428,19372);
INSERT INTO "django_geo_db_zipcode" VALUES(22044,49436,-5,'Mears, Michigan 49436',15429,19373);
INSERT INTO "django_geo_db_zipcode" VALUES(22045,49437,-5,'Montague, Michigan 49437',15430,19374);
INSERT INTO "django_geo_db_zipcode" VALUES(22046,49440,-5,'Muskegon, Michigan 49440',15431,19375);
INSERT INTO "django_geo_db_zipcode" VALUES(22047,49441,-5,'Muskegon, Michigan 49441',15431,19376);
INSERT INTO "django_geo_db_zipcode" VALUES(22048,49442,-5,'Muskegon, Michigan 49442',15431,19377);
INSERT INTO "django_geo_db_zipcode" VALUES(22049,49443,-5,'Muskegon, Michigan 49443',15431,19378);
INSERT INTO "django_geo_db_zipcode" VALUES(22050,49444,-5,'Muskegon, Michigan 49444',15431,19379);
INSERT INTO "django_geo_db_zipcode" VALUES(22051,49445,-5,'Muskegon, Michigan 49445',15431,19380);
INSERT INTO "django_geo_db_zipcode" VALUES(22052,49446,-5,'New Era, Michigan 49446',15432,19381);
INSERT INTO "django_geo_db_zipcode" VALUES(22053,49448,-5,'Nunica, Michigan 49448',15433,19382);
INSERT INTO "django_geo_db_zipcode" VALUES(22054,49449,-5,'Pentwater, Michigan 49449',15434,19383);
INSERT INTO "django_geo_db_zipcode" VALUES(22055,49450,-5,'Pullman, Michigan 49450',15435,19384);
INSERT INTO "django_geo_db_zipcode" VALUES(22056,49451,-5,'Ravenna, Michigan 49451',15436,19385);
INSERT INTO "django_geo_db_zipcode" VALUES(22057,49452,-5,'Rothbury, Michigan 49452',15437,19386);
INSERT INTO "django_geo_db_zipcode" VALUES(22058,49453,-5,'Saugatuck, Michigan 49453',15438,19387);
INSERT INTO "django_geo_db_zipcode" VALUES(22059,49454,-5,'Scottville, Michigan 49454',15439,19388);
INSERT INTO "django_geo_db_zipcode" VALUES(22060,49455,-5,'Shelby, Michigan 49455',15440,19389);
INSERT INTO "django_geo_db_zipcode" VALUES(22061,49456,-5,'Spring Lake, Michigan 49456',15441,19390);
INSERT INTO "django_geo_db_zipcode" VALUES(22062,49457,-5,'Twin Lake, Michigan 49457',15442,19391);
INSERT INTO "django_geo_db_zipcode" VALUES(22063,49458,-5,'Walhalla, Michigan 49458',15443,19392);
INSERT INTO "django_geo_db_zipcode" VALUES(22064,49459,-5,'Walkerville, Michigan 49459',15444,19393);
INSERT INTO "django_geo_db_zipcode" VALUES(22065,49460,-5,'West Olive, Michigan 49460',15445,19394);
INSERT INTO "django_geo_db_zipcode" VALUES(22066,49461,-5,'Whitehall, Michigan 49461',15446,19395);
INSERT INTO "django_geo_db_zipcode" VALUES(22067,49463,-5,'Wabaningo, Michigan 49463',15447,19378);
INSERT INTO "django_geo_db_zipcode" VALUES(22068,49464,-5,'Zeeland, Michigan 49464',15448,19396);
INSERT INTO "django_geo_db_zipcode" VALUES(22069,49468,-5,'Grandville, Michigan 49468',15416,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22070,49501,-5,'Grand Rapids, Michigan 49501',15449,19397);
INSERT INTO "django_geo_db_zipcode" VALUES(22071,49502,-5,'Grand Rapids, Michigan 49502',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22072,49503,-5,'Grand Rapids, Michigan 49503',15449,19398);
INSERT INTO "django_geo_db_zipcode" VALUES(22073,49504,-5,'Grand Rapids, Michigan 49504',15449,19399);
INSERT INTO "django_geo_db_zipcode" VALUES(22074,49505,-5,'Grand Rapids, Michigan 49505',15449,19400);
INSERT INTO "django_geo_db_zipcode" VALUES(22075,49506,-5,'Grand Rapids, Michigan 49506',15449,19401);
INSERT INTO "django_geo_db_zipcode" VALUES(22076,49507,-5,'Grand Rapids, Michigan 49507',15449,19402);
INSERT INTO "django_geo_db_zipcode" VALUES(22077,49508,-5,'Grand Rapids, Michigan 49508',15449,19403);
INSERT INTO "django_geo_db_zipcode" VALUES(22078,49509,-5,'Grand Rapids, Michigan 49509',15449,19404);
INSERT INTO "django_geo_db_zipcode" VALUES(22079,49510,-5,'Grand Rapids, Michigan 49510',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22080,49512,-5,'Grand Rapids, Michigan 49512',15449,19405);
INSERT INTO "django_geo_db_zipcode" VALUES(22081,49514,-5,'Grand Rapids, Michigan 49514',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22082,49515,-5,'Grand Rapids, Michigan 49515',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22083,49516,-5,'Grand Rapids, Michigan 49516',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22084,49518,-5,'Grand Rapids, Michigan 49518',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22085,49523,-5,'Grand Rapids, Michigan 49523',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22086,49525,-5,'Grand Rapids, Michigan 49525',15449,19406);
INSERT INTO "django_geo_db_zipcode" VALUES(22087,49530,-5,'Grand Rapids, Michigan 49530',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22088,49544,-5,'Grand Rapids, Michigan 49544',15449,19407);
INSERT INTO "django_geo_db_zipcode" VALUES(22089,49546,-5,'Grand Rapids, Michigan 49546',15449,19408);
INSERT INTO "django_geo_db_zipcode" VALUES(22090,49548,-5,'Grand Rapids, Michigan 49548',15449,19409);
INSERT INTO "django_geo_db_zipcode" VALUES(22091,49550,-5,'Grand Rapids, Michigan 49550',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22092,49555,-5,'Grand Rapids, Michigan 49555',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22093,49560,-5,'Grand Rapids, Michigan 49560',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22094,49564,-5,'Glen Arbor, Michigan 49564',15450,19410);
INSERT INTO "django_geo_db_zipcode" VALUES(22095,49565,-5,'Newkirk, Michigan 49565',15451,19411);
INSERT INTO "django_geo_db_zipcode" VALUES(22096,49582,-5,'Colfax, Michigan 49582',15452,19412);
INSERT INTO "django_geo_db_zipcode" VALUES(22097,49588,-5,'Grand Rapids, Michigan 49588',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22098,49590,-5,'Whitewater, Michigan 49590',15453,19413);
INSERT INTO "django_geo_db_zipcode" VALUES(22099,49599,-5,'Grand Rapids, Michigan 49599',15449,19340);
INSERT INTO "django_geo_db_zipcode" VALUES(22100,49601,-5,'Cadillac, Michigan 49601',15454,19414);
INSERT INTO "django_geo_db_zipcode" VALUES(22101,49610,-5,'Acme, Michigan 49610',15455,19415);
INSERT INTO "django_geo_db_zipcode" VALUES(22102,49611,-5,'Alba, Michigan 49611',15456,19416);
INSERT INTO "django_geo_db_zipcode" VALUES(22103,49612,-5,'Alden, Michigan 49612',15457,19417);
INSERT INTO "django_geo_db_zipcode" VALUES(22104,49613,-5,'Arcadia, Michigan 49613',15458,19418);
INSERT INTO "django_geo_db_zipcode" VALUES(22105,49614,-5,'Bear Lake, Michigan 49614',15459,19419);
INSERT INTO "django_geo_db_zipcode" VALUES(22106,49615,-5,'Bellaire, Michigan 49615',15460,19420);
INSERT INTO "django_geo_db_zipcode" VALUES(22107,49616,-5,'Benzonia, Michigan 49616',15461,19421);
INSERT INTO "django_geo_db_zipcode" VALUES(22108,49617,-5,'Beulah, Michigan 49617',15462,19422);
INSERT INTO "django_geo_db_zipcode" VALUES(22109,49618,-5,'Boon, Michigan 49618',15463,19423);
INSERT INTO "django_geo_db_zipcode" VALUES(22110,49619,-5,'Brethren, Michigan 49619',15464,19424);
INSERT INTO "django_geo_db_zipcode" VALUES(22111,49620,-5,'Buckley, Michigan 49620',15465,19425);
INSERT INTO "django_geo_db_zipcode" VALUES(22112,49621,-5,'Cedar, Michigan 49621',15466,19426);
INSERT INTO "django_geo_db_zipcode" VALUES(22113,49622,-5,'Central Lake, Michigan 49622',15467,19427);
INSERT INTO "django_geo_db_zipcode" VALUES(22114,49623,-5,'Chase, Michigan 49623',15468,19428);
INSERT INTO "django_geo_db_zipcode" VALUES(22115,49625,-5,'Copemish, Michigan 49625',15469,19429);
INSERT INTO "django_geo_db_zipcode" VALUES(22116,49626,-5,'Eastlake, Michigan 49626',15470,19430);
INSERT INTO "django_geo_db_zipcode" VALUES(22117,49627,-5,'Eastport, Michigan 49627',15471,19431);
INSERT INTO "django_geo_db_zipcode" VALUES(22118,49628,-5,'Elberta, Michigan 49628',15472,19432);
INSERT INTO "django_geo_db_zipcode" VALUES(22119,49629,-5,'Elk Rapids, Michigan 49629',15473,19433);
INSERT INTO "django_geo_db_zipcode" VALUES(22120,49630,-5,'Empire, Michigan 49630',15474,19434);
INSERT INTO "django_geo_db_zipcode" VALUES(22121,49631,-5,'Evart, Michigan 49631',15475,19435);
INSERT INTO "django_geo_db_zipcode" VALUES(22122,49632,-5,'Falmouth, Michigan 49632',15476,19436);
INSERT INTO "django_geo_db_zipcode" VALUES(22123,49633,-5,'Fife Lake, Michigan 49633',15477,19437);
INSERT INTO "django_geo_db_zipcode" VALUES(22124,49634,-5,'Filer City, Michigan 49634',15478,19438);
INSERT INTO "django_geo_db_zipcode" VALUES(22125,49635,-5,'Frankfort, Michigan 49635',15479,19439);
INSERT INTO "django_geo_db_zipcode" VALUES(22126,49636,-5,'Glen Arbor, Michigan 49636',15450,19440);
INSERT INTO "django_geo_db_zipcode" VALUES(22127,49637,-5,'Grawn, Michigan 49637',15480,19441);
INSERT INTO "django_geo_db_zipcode" VALUES(22128,49638,-5,'Harrietta, Michigan 49638',15481,19442);
INSERT INTO "django_geo_db_zipcode" VALUES(22129,49639,-5,'Hersey, Michigan 49639',15482,19443);
INSERT INTO "django_geo_db_zipcode" VALUES(22130,49640,-5,'Honor, Michigan 49640',15483,19444);
INSERT INTO "django_geo_db_zipcode" VALUES(22131,49642,-5,'Idlewild, Michigan 49642',15484,19445);
INSERT INTO "django_geo_db_zipcode" VALUES(22132,49643,-5,'Interlochen, Michigan 49643',15485,19446);
INSERT INTO "django_geo_db_zipcode" VALUES(22133,49644,-5,'Irons, Michigan 49644',15486,19447);
INSERT INTO "django_geo_db_zipcode" VALUES(22134,49645,-5,'Kaleva, Michigan 49645',15487,19448);
INSERT INTO "django_geo_db_zipcode" VALUES(22135,49646,-5,'Kalkaska, Michigan 49646',15488,19449);
INSERT INTO "django_geo_db_zipcode" VALUES(22136,49647,-5,'Paradise, Michigan 49647',15489,19450);
INSERT INTO "django_geo_db_zipcode" VALUES(22137,49648,-5,'Kewadin, Michigan 49648',15490,19451);
INSERT INTO "django_geo_db_zipcode" VALUES(22138,49649,-5,'Kingsley, Michigan 49649',15491,19452);
INSERT INTO "django_geo_db_zipcode" VALUES(22139,49650,-5,'Lake Ann, Michigan 49650',15492,19453);
INSERT INTO "django_geo_db_zipcode" VALUES(22140,49651,-5,'Lake City, Michigan 49651',15493,19454);
INSERT INTO "django_geo_db_zipcode" VALUES(22141,49652,-5,'Yates, Michigan 49652',15494,19455);
INSERT INTO "django_geo_db_zipcode" VALUES(22142,49653,-5,'Lake Leelanau, Michigan 49653',15495,19456);
INSERT INTO "django_geo_db_zipcode" VALUES(22143,49654,-5,'Leland, Michigan 49654',15496,19457);
INSERT INTO "django_geo_db_zipcode" VALUES(22144,49655,-5,'Leroy, Michigan 49655',15497,19458);
INSERT INTO "django_geo_db_zipcode" VALUES(22145,49656,-5,'Luther, Michigan 49656',15498,19459);
INSERT INTO "django_geo_db_zipcode" VALUES(22146,49657,-5,'McBain, Michigan 49657',15499,19460);
INSERT INTO "django_geo_db_zipcode" VALUES(22147,49659,-5,'Mancelona, Michigan 49659',15500,19461);
INSERT INTO "django_geo_db_zipcode" VALUES(22148,49660,-5,'Manistee, Michigan 49660',15501,19462);
INSERT INTO "django_geo_db_zipcode" VALUES(22149,49663,-5,'Manton, Michigan 49663',15502,19463);
INSERT INTO "django_geo_db_zipcode" VALUES(22150,49664,-5,'Maple City, Michigan 49664',15503,19464);
INSERT INTO "django_geo_db_zipcode" VALUES(22151,49665,-5,'Marion, Michigan 49665',15504,19465);
INSERT INTO "django_geo_db_zipcode" VALUES(22152,49666,-5,'Mayfield, Michigan 49666',15505,19466);
INSERT INTO "django_geo_db_zipcode" VALUES(22153,49667,-5,'Merritt, Michigan 49667',15506,19467);
INSERT INTO "django_geo_db_zipcode" VALUES(22154,49668,-5,'Mesick, Michigan 49668',15507,19468);
INSERT INTO "django_geo_db_zipcode" VALUES(22155,49670,-5,'Northport, Michigan 49670',15508,19469);
INSERT INTO "django_geo_db_zipcode" VALUES(22156,49673,-5,'Old Mission, Michigan 49673',15509,19470);
INSERT INTO "django_geo_db_zipcode" VALUES(22157,49674,-5,'Omena, Michigan 49674',15510,19471);
INSERT INTO "django_geo_db_zipcode" VALUES(22158,49675,-5,'Onekama, Michigan 49675',15511,19472);
INSERT INTO "django_geo_db_zipcode" VALUES(22159,49676,-5,'Rapid City, Michigan 49676',15512,19473);
INSERT INTO "django_geo_db_zipcode" VALUES(22160,49677,-5,'Reed City, Michigan 49677',15513,19474);
INSERT INTO "django_geo_db_zipcode" VALUES(22161,49679,-5,'Sears, Michigan 49679',15514,19475);
INSERT INTO "django_geo_db_zipcode" VALUES(22162,49680,-5,'South Boardman, Michigan 49680',15515,19476);
INSERT INTO "django_geo_db_zipcode" VALUES(22163,49682,-5,'Suttons Bay, Michigan 49682',15516,19477);
INSERT INTO "django_geo_db_zipcode" VALUES(22164,49683,-5,'Thompsonville, Michigan 49683',15517,19478);
INSERT INTO "django_geo_db_zipcode" VALUES(22165,49684,-5,'Traverse City, Michigan 49684',15518,19479);
INSERT INTO "django_geo_db_zipcode" VALUES(22166,49685,-5,'Traverse City, Michigan 49685',15518,19480);
INSERT INTO "django_geo_db_zipcode" VALUES(22167,49686,-5,'Traverse City, Michigan 49686',15518,19481);
INSERT INTO "django_geo_db_zipcode" VALUES(22168,49688,-5,'Tustin, Michigan 49688',15519,19482);
INSERT INTO "django_geo_db_zipcode" VALUES(22169,49689,-5,'Wellston, Michigan 49689',15520,19483);
INSERT INTO "django_geo_db_zipcode" VALUES(22170,49690,-5,'Williamsburg, Michigan 49690',15521,19484);
INSERT INTO "django_geo_db_zipcode" VALUES(22171,49695,-5,'Custer, Michigan 49695',15406,19485);
INSERT INTO "django_geo_db_zipcode" VALUES(22172,49696,-5,'Traverse City, Michigan 49696',15518,19480);
INSERT INTO "django_geo_db_zipcode" VALUES(22173,49701,-5,'Mackinaw City, Michigan 49701',15522,19486);
INSERT INTO "django_geo_db_zipcode" VALUES(22174,49705,-5,'Afton, Michigan 49705',15523,19487);
INSERT INTO "django_geo_db_zipcode" VALUES(22175,49706,-5,'Alanson, Michigan 49706',15524,19488);
INSERT INTO "django_geo_db_zipcode" VALUES(22176,49707,-5,'Alpena, Michigan 49707',15525,19489);
INSERT INTO "django_geo_db_zipcode" VALUES(22177,49709,-5,'Atlanta, Michigan 49709',15526,19490);
INSERT INTO "django_geo_db_zipcode" VALUES(22178,49710,-5,'Barbeau, Michigan 49710',15527,19491);
INSERT INTO "django_geo_db_zipcode" VALUES(22179,49711,-5,'Bay Shore, Michigan 49711',15528,19492);
INSERT INTO "django_geo_db_zipcode" VALUES(22180,49712,-5,'Boyne City, Michigan 49712',15529,19493);
INSERT INTO "django_geo_db_zipcode" VALUES(22181,49713,-5,'Boyne Falls, Michigan 49713',15530,19494);
INSERT INTO "django_geo_db_zipcode" VALUES(22182,49715,-5,'Brimley, Michigan 49715',15531,19495);
INSERT INTO "django_geo_db_zipcode" VALUES(22183,49716,-5,'Brutus, Michigan 49716',15532,19496);
INSERT INTO "django_geo_db_zipcode" VALUES(22184,49717,-5,'Burt Lake, Michigan 49717',15533,19497);
INSERT INTO "django_geo_db_zipcode" VALUES(22185,49718,-5,'Carp Lake, Michigan 49718',15534,19498);
INSERT INTO "django_geo_db_zipcode" VALUES(22186,49719,-5,'Cedarville, Michigan 49719',15535,19499);
INSERT INTO "django_geo_db_zipcode" VALUES(22187,49720,-5,'Charlevoix, Michigan 49720',15536,19500);
INSERT INTO "django_geo_db_zipcode" VALUES(22188,49721,-5,'Cheboygan, Michigan 49721',15537,19501);
INSERT INTO "django_geo_db_zipcode" VALUES(22189,49722,-5,'Conway, Michigan 49722',15538,19502);
INSERT INTO "django_geo_db_zipcode" VALUES(22190,49723,-5,'Cross Village, Michigan 49723',15539,19503);
INSERT INTO "django_geo_db_zipcode" VALUES(22191,49724,-5,'Dafter, Michigan 49724',15540,19504);
INSERT INTO "django_geo_db_zipcode" VALUES(22192,49725,-5,'De Tour Village, Michigan 49725',15541,19505);
INSERT INTO "django_geo_db_zipcode" VALUES(22193,49726,-5,'Drummond Island, Michigan 49726',15542,19506);
INSERT INTO "django_geo_db_zipcode" VALUES(22194,49727,-5,'East Jordan, Michigan 49727',15543,19507);
INSERT INTO "django_geo_db_zipcode" VALUES(22195,49728,-5,'Eckerman, Michigan 49728',15544,19508);
INSERT INTO "django_geo_db_zipcode" VALUES(22196,49729,-5,'Ellsworth, Michigan 49729',15545,19509);
INSERT INTO "django_geo_db_zipcode" VALUES(22197,49730,-5,'Elmira, Michigan 49730',15546,19510);
INSERT INTO "django_geo_db_zipcode" VALUES(22198,49732,-5,'Forest, Michigan 49732',15547,19511);
INSERT INTO "django_geo_db_zipcode" VALUES(22199,49733,-5,'Frederic, Michigan 49733',15548,19512);
INSERT INTO "django_geo_db_zipcode" VALUES(22200,49734,-5,'Gaylord, Michigan 49734',15549,19513);
INSERT INTO "django_geo_db_zipcode" VALUES(22201,49735,-5,'Gaylord, Michigan 49735',15549,19514);
INSERT INTO "django_geo_db_zipcode" VALUES(22202,49736,-5,'Goetzville, Michigan 49736',15550,19515);
INSERT INTO "django_geo_db_zipcode" VALUES(22203,49737,-5,'Good Hart, Michigan 49737',15551,19516);
INSERT INTO "django_geo_db_zipcode" VALUES(22204,49738,-5,'Grayling, Michigan 49738',15552,19517);
INSERT INTO "django_geo_db_zipcode" VALUES(22205,49739,-5,'Grayling, Michigan 49739',15552,19518);
INSERT INTO "django_geo_db_zipcode" VALUES(22206,49740,-5,'Harbor Springs, Michigan 49740',15553,19519);
INSERT INTO "django_geo_db_zipcode" VALUES(22207,49743,-5,'Hawks, Michigan 49743',15554,19520);
INSERT INTO "django_geo_db_zipcode" VALUES(22208,49744,-5,'Herron, Michigan 49744',15555,19521);
INSERT INTO "django_geo_db_zipcode" VALUES(22209,49745,-5,'Hessel, Michigan 49745',15556,19522);
INSERT INTO "django_geo_db_zipcode" VALUES(22210,49746,-5,'Hillman, Michigan 49746',15557,19523);
INSERT INTO "django_geo_db_zipcode" VALUES(22211,49747,-5,'Hubbard Lake, Michigan 49747',15558,19524);
INSERT INTO "django_geo_db_zipcode" VALUES(22212,49748,-5,'Hulbert, Michigan 49748',15559,19525);
INSERT INTO "django_geo_db_zipcode" VALUES(22213,49749,-5,'Indian River, Michigan 49749',15560,19526);
INSERT INTO "django_geo_db_zipcode" VALUES(22214,49750,-5,'Lewiston, Michigan 49750',15561,19527);
INSERT INTO "django_geo_db_zipcode" VALUES(22215,49751,-5,'Johannesburg, Michigan 49751',15562,19528);
INSERT INTO "django_geo_db_zipcode" VALUES(22216,49752,-5,'Kinross, Michigan 49752',15563,19529);
INSERT INTO "django_geo_db_zipcode" VALUES(22217,49753,-5,'Lachine, Michigan 49753',15564,19530);
INSERT INTO "django_geo_db_zipcode" VALUES(22218,49755,-5,'Levering, Michigan 49755',15565,19531);
INSERT INTO "django_geo_db_zipcode" VALUES(22219,49756,-5,'Lewiston, Michigan 49756',15561,19532);
INSERT INTO "django_geo_db_zipcode" VALUES(22220,49757,-5,'Mackinac Island, Michigan 49757',15566,19533);
INSERT INTO "django_geo_db_zipcode" VALUES(22221,49758,-5,'Greenwood, Michigan 49758',15567,19534);
INSERT INTO "django_geo_db_zipcode" VALUES(22222,49759,-5,'Millersburg, Michigan 49759',15568,19535);
INSERT INTO "django_geo_db_zipcode" VALUES(22223,49760,-5,'Moran, Michigan 49760',15569,19536);
INSERT INTO "django_geo_db_zipcode" VALUES(22224,49761,-5,'Mullett Lake, Michigan 49761',15570,19537);
INSERT INTO "django_geo_db_zipcode" VALUES(22225,49762,-5,'Naubinway, Michigan 49762',15571,19538);
INSERT INTO "django_geo_db_zipcode" VALUES(22226,49764,-5,'Oden, Michigan 49764',15572,19539);
INSERT INTO "django_geo_db_zipcode" VALUES(22227,49765,-5,'Onaway, Michigan 49765',15573,19540);
INSERT INTO "django_geo_db_zipcode" VALUES(22228,49766,-5,'Ossineke, Michigan 49766',15574,19541);
INSERT INTO "django_geo_db_zipcode" VALUES(22229,49768,-5,'Paradise, Michigan 49768',15489,19542);
INSERT INTO "django_geo_db_zipcode" VALUES(22230,49769,-5,'Pellston, Michigan 49769',15575,19543);
INSERT INTO "django_geo_db_zipcode" VALUES(22231,49770,-5,'Petoskey, Michigan 49770',15576,19544);
INSERT INTO "django_geo_db_zipcode" VALUES(22232,49774,-5,'Pickford, Michigan 49774',15577,19545);
INSERT INTO "django_geo_db_zipcode" VALUES(22233,49775,-5,'Pointe Aux Pins, Michigan 49775',15578,19546);
INSERT INTO "django_geo_db_zipcode" VALUES(22234,49776,-5,'Posen, Michigan 49776',15579,19547);
INSERT INTO "django_geo_db_zipcode" VALUES(22235,49777,-5,'Presque Isle, Michigan 49777',15580,19548);
INSERT INTO "django_geo_db_zipcode" VALUES(22236,49778,-5,'Brimley, Michigan 49778',15531,19549);
INSERT INTO "django_geo_db_zipcode" VALUES(22237,49779,-5,'Rogers City, Michigan 49779',15581,19550);
INSERT INTO "django_geo_db_zipcode" VALUES(22238,49780,-5,'Rudyard, Michigan 49780',15582,19551);
INSERT INTO "django_geo_db_zipcode" VALUES(22239,49781,-5,'Saint Ignace, Michigan 49781',15583,19552);
INSERT INTO "django_geo_db_zipcode" VALUES(22240,49782,-5,'Beaver Island, Michigan 49782',15584,19553);
INSERT INTO "django_geo_db_zipcode" VALUES(22241,49783,-5,'Sault Sainte Marie, Michigan 49783',15585,19554);
INSERT INTO "django_geo_db_zipcode" VALUES(22242,49784,-5,'Kincheloe, Michigan 49784',15586,19549);
INSERT INTO "django_geo_db_zipcode" VALUES(22243,49785,-5,'Kincheloe, Michigan 49785',15586,19555);
INSERT INTO "django_geo_db_zipcode" VALUES(22244,49786,-5,'Kincheloe, Michigan 49786',15586,19549);
INSERT INTO "django_geo_db_zipcode" VALUES(22245,49788,-5,'Kincheloe, Michigan 49788',15586,19556);
INSERT INTO "django_geo_db_zipcode" VALUES(22246,49790,-5,'Strongs, Michigan 49790',15587,19557);
INSERT INTO "django_geo_db_zipcode" VALUES(22247,49791,-5,'Topinabee, Michigan 49791',15588,19558);
INSERT INTO "django_geo_db_zipcode" VALUES(22248,49792,-5,'Tower, Michigan 49792',15589,19559);
INSERT INTO "django_geo_db_zipcode" VALUES(22249,49793,-5,'Trout Lake, Michigan 49793',15590,19560);
INSERT INTO "django_geo_db_zipcode" VALUES(22250,49795,-5,'Vanderbilt, Michigan 49795',15591,19561);
INSERT INTO "django_geo_db_zipcode" VALUES(22251,49796,-5,'Walloon Lake, Michigan 49796',15592,19562);
INSERT INTO "django_geo_db_zipcode" VALUES(22252,49797,-5,'Waters, Michigan 49797',15593,19563);
INSERT INTO "django_geo_db_zipcode" VALUES(22253,49799,-5,'Wolverine, Michigan 49799',15594,19564);
INSERT INTO "django_geo_db_zipcode" VALUES(22254,49801,-6,'Iron Mountain, Michigan 49801',15595,19565);
INSERT INTO "django_geo_db_zipcode" VALUES(22255,49802,-6,'Kingsford, Michigan 49802',15596,19566);
INSERT INTO "django_geo_db_zipcode" VALUES(22256,49805,-5,'Allouez, Michigan 49805',15597,19567);
INSERT INTO "django_geo_db_zipcode" VALUES(22257,49806,-5,'Au Train, Michigan 49806',15598,19568);
INSERT INTO "django_geo_db_zipcode" VALUES(22258,49807,-6,'Bark River, Michigan 49807',15599,19569);
INSERT INTO "django_geo_db_zipcode" VALUES(22259,49808,-5,'Big Bay, Michigan 49808',15600,19570);
INSERT INTO "django_geo_db_zipcode" VALUES(22260,49812,-6,'Carney, Michigan 49812',15601,19571);
INSERT INTO "django_geo_db_zipcode" VALUES(22261,49813,-6,'Cedar River, Michigan 49813',15602,19572);
INSERT INTO "django_geo_db_zipcode" VALUES(22262,49814,-5,'Champion, Michigan 49814',15603,19573);
INSERT INTO "django_geo_db_zipcode" VALUES(22263,49815,-6,'Channing, Michigan 49815',15604,19574);
INSERT INTO "django_geo_db_zipcode" VALUES(22264,49816,-5,'Chatham, Michigan 49816',15605,19575);
INSERT INTO "django_geo_db_zipcode" VALUES(22265,49817,-5,'Cooks, Michigan 49817',15606,19576);
INSERT INTO "django_geo_db_zipcode" VALUES(22266,49818,-5,'Cornell, Michigan 49818',15607,19577);
INSERT INTO "django_geo_db_zipcode" VALUES(22267,49819,-5,'Arnold, Michigan 49819',15608,19578);
INSERT INTO "django_geo_db_zipcode" VALUES(22268,49820,-5,'Curtis, Michigan 49820',15609,19579);
INSERT INTO "django_geo_db_zipcode" VALUES(22269,49821,-6,'Daggett, Michigan 49821',15610,19580);
INSERT INTO "django_geo_db_zipcode" VALUES(22270,49822,-5,'Deerton, Michigan 49822',15611,19581);
INSERT INTO "django_geo_db_zipcode" VALUES(22271,49825,-5,'Eben Junction, Michigan 49825',15612,19582);
INSERT INTO "django_geo_db_zipcode" VALUES(22272,49826,-5,'Rumely, Michigan 49826',15613,19583);
INSERT INTO "django_geo_db_zipcode" VALUES(22273,49827,-5,'Engadine, Michigan 49827',15614,19584);
INSERT INTO "django_geo_db_zipcode" VALUES(22274,49829,-5,'Escanaba, Michigan 49829',15615,19585);
INSERT INTO "django_geo_db_zipcode" VALUES(22275,49831,-6,'Felch, Michigan 49831',15616,19586);
INSERT INTO "django_geo_db_zipcode" VALUES(22276,49833,-5,'Little Lake, Michigan 49833',15617,19587);
INSERT INTO "django_geo_db_zipcode" VALUES(22277,49834,-6,'Foster City, Michigan 49834',15618,19588);
INSERT INTO "django_geo_db_zipcode" VALUES(22278,49835,-5,'Garden, Michigan 49835',15619,19589);
INSERT INTO "django_geo_db_zipcode" VALUES(22279,49836,-5,'Germfask, Michigan 49836',15620,19590);
INSERT INTO "django_geo_db_zipcode" VALUES(22280,49837,-5,'Gladstone, Michigan 49837',15621,19591);
INSERT INTO "django_geo_db_zipcode" VALUES(22281,49838,-5,'Gould City, Michigan 49838',15622,19592);
INSERT INTO "django_geo_db_zipcode" VALUES(22282,49839,-5,'Grand Marais, Michigan 49839',15623,19593);
INSERT INTO "django_geo_db_zipcode" VALUES(22283,49840,-5,'Gulliver, Michigan 49840',15624,19594);
INSERT INTO "django_geo_db_zipcode" VALUES(22284,49841,-5,'Gwinn, Michigan 49841',15625,19595);
INSERT INTO "django_geo_db_zipcode" VALUES(22285,49845,-6,'Harris, Michigan 49845',15626,19596);
INSERT INTO "django_geo_db_zipcode" VALUES(22286,49847,-6,'Hermansville, Michigan 49847',15627,19597);
INSERT INTO "django_geo_db_zipcode" VALUES(22287,49848,-6,'Ingalls, Michigan 49848',15628,19598);
INSERT INTO "django_geo_db_zipcode" VALUES(22288,49849,-5,'Ishpeming, Michigan 49849',15629,19599);
INSERT INTO "django_geo_db_zipcode" VALUES(22289,49852,-6,'Loretto, Michigan 49852',15630,19600);
INSERT INTO "django_geo_db_zipcode" VALUES(22290,49853,-5,'McMillan, Michigan 49853',15631,19601);
INSERT INTO "django_geo_db_zipcode" VALUES(22291,49854,-5,'Manistique, Michigan 49854',15632,19602);
INSERT INTO "django_geo_db_zipcode" VALUES(22292,49855,-5,'Marquette, Michigan 49855',15633,19603);
INSERT INTO "django_geo_db_zipcode" VALUES(22293,49858,-6,'Menominee, Michigan 49858',15634,19604);
INSERT INTO "django_geo_db_zipcode" VALUES(22294,49861,-5,'Michigamme, Michigan 49861',15635,19605);
INSERT INTO "django_geo_db_zipcode" VALUES(22295,49862,-5,'Munising, Michigan 49862',15636,19606);
INSERT INTO "django_geo_db_zipcode" VALUES(22296,49863,-6,'Nadeau, Michigan 49863',15637,19607);
INSERT INTO "django_geo_db_zipcode" VALUES(22297,49864,-5,'Nahma, Michigan 49864',15638,19608);
INSERT INTO "django_geo_db_zipcode" VALUES(22298,49865,-5,'National Mine, Michigan 49865',15639,19578);
INSERT INTO "django_geo_db_zipcode" VALUES(22299,49866,-5,'Negaunee, Michigan 49866',15640,19609);
INSERT INTO "django_geo_db_zipcode" VALUES(22300,49868,-5,'Newberry, Michigan 49868',15641,19610);
INSERT INTO "django_geo_db_zipcode" VALUES(22301,49869,-5,'Wells, Michigan 49869',15642,19611);
INSERT INTO "django_geo_db_zipcode" VALUES(22302,49870,-6,'Norway, Michigan 49870',15643,19612);
INSERT INTO "django_geo_db_zipcode" VALUES(22303,49871,-5,'Palmer, Michigan 49871',15644,19613);
INSERT INTO "django_geo_db_zipcode" VALUES(22304,49872,-5,'Perkins, Michigan 49872',15645,19614);
INSERT INTO "django_geo_db_zipcode" VALUES(22305,49873,-6,'Perronville, Michigan 49873',15646,19615);
INSERT INTO "django_geo_db_zipcode" VALUES(22306,49874,-6,'Powers, Michigan 49874',15647,19616);
INSERT INTO "django_geo_db_zipcode" VALUES(22307,49876,-6,'Quinnesec, Michigan 49876',15648,19617);
INSERT INTO "django_geo_db_zipcode" VALUES(22308,49877,-6,'Ralph, Michigan 49877',15649,19618);
INSERT INTO "django_geo_db_zipcode" VALUES(22309,49878,-5,'Rapid River, Michigan 49878',15650,19619);
INSERT INTO "django_geo_db_zipcode" VALUES(22310,49879,-5,'Republic, Michigan 49879',15651,19620);
INSERT INTO "django_geo_db_zipcode" VALUES(22311,49880,-5,'Rock, Michigan 49880',15652,19621);
INSERT INTO "django_geo_db_zipcode" VALUES(22312,49881,-6,'Sagola, Michigan 49881',15653,19622);
INSERT INTO "django_geo_db_zipcode" VALUES(22313,49883,-5,'Seney, Michigan 49883',15654,19623);
INSERT INTO "django_geo_db_zipcode" VALUES(22314,49884,-5,'Shingleton, Michigan 49884',15655,19624);
INSERT INTO "django_geo_db_zipcode" VALUES(22315,49885,-5,'Skandia, Michigan 49885',15656,19625);
INSERT INTO "django_geo_db_zipcode" VALUES(22316,49886,-6,'Spalding, Michigan 49886',15657,19626);
INSERT INTO "django_geo_db_zipcode" VALUES(22317,49887,-6,'Stephenson, Michigan 49887',15658,19627);
INSERT INTO "django_geo_db_zipcode" VALUES(22318,49891,-5,'Trenary, Michigan 49891',15659,19628);
INSERT INTO "django_geo_db_zipcode" VALUES(22319,49892,-6,'Vulcan, Michigan 49892',15660,19629);
INSERT INTO "django_geo_db_zipcode" VALUES(22320,49893,-6,'Wallace, Michigan 49893',15661,19630);
INSERT INTO "django_geo_db_zipcode" VALUES(22321,49894,-5,'Wells, Michigan 49894',15642,19631);
INSERT INTO "django_geo_db_zipcode" VALUES(22322,49895,-5,'Wetmore, Michigan 49895',15662,19632);
INSERT INTO "django_geo_db_zipcode" VALUES(22323,49896,-6,'Wilson, Michigan 49896',15663,19633);
INSERT INTO "django_geo_db_zipcode" VALUES(22324,49901,-5,'Ahmeek, Michigan 49901',15664,19634);
INSERT INTO "django_geo_db_zipcode" VALUES(22325,49902,-6,'Alpha, Michigan 49902',15665,19635);
INSERT INTO "django_geo_db_zipcode" VALUES(22326,49903,-6,'Amasa, Michigan 49903',15666,19636);
INSERT INTO "django_geo_db_zipcode" VALUES(22327,49905,-5,'Atlantic Mine, Michigan 49905',15667,19637);
INSERT INTO "django_geo_db_zipcode" VALUES(22328,49908,-5,'Baraga, Michigan 49908',15668,19638);
INSERT INTO "django_geo_db_zipcode" VALUES(22329,49910,-5,'Bergland, Michigan 49910',15669,19639);
INSERT INTO "django_geo_db_zipcode" VALUES(22330,49911,-6,'Bessemer, Michigan 49911',15670,19640);
INSERT INTO "django_geo_db_zipcode" VALUES(22331,49912,-5,'Bruce Crossing, Michigan 49912',15671,19641);
INSERT INTO "django_geo_db_zipcode" VALUES(22332,49913,-5,'Calumet, Michigan 49913',15672,19642);
INSERT INTO "django_geo_db_zipcode" VALUES(22333,49915,-6,'Caspian, Michigan 49915',15673,19643);
INSERT INTO "django_geo_db_zipcode" VALUES(22334,49916,-5,'Chassell, Michigan 49916',15674,19644);
INSERT INTO "django_geo_db_zipcode" VALUES(22335,49917,-5,'Copper City, Michigan 49917',15675,19645);
INSERT INTO "django_geo_db_zipcode" VALUES(22336,49918,-5,'Copper Harbor, Michigan 49918',15676,19646);
INSERT INTO "django_geo_db_zipcode" VALUES(22337,49919,-5,'Covington, Michigan 49919',15677,19647);
INSERT INTO "django_geo_db_zipcode" VALUES(22338,49920,-6,'Crystal Falls, Michigan 49920',15678,19648);
INSERT INTO "django_geo_db_zipcode" VALUES(22339,49921,-5,'Dodgeville, Michigan 49921',15679,19649);
INSERT INTO "django_geo_db_zipcode" VALUES(22340,49922,-5,'Dollar Bay, Michigan 49922',15680,19650);
INSERT INTO "django_geo_db_zipcode" VALUES(22341,49924,-5,'Houghton, Michigan 49924',15681,19651);
INSERT INTO "django_geo_db_zipcode" VALUES(22342,49925,-5,'Ewen, Michigan 49925',15682,19652);
INSERT INTO "django_geo_db_zipcode" VALUES(22343,49927,-6,'Gaastra, Michigan 49927',15683,19653);
INSERT INTO "django_geo_db_zipcode" VALUES(22344,49929,-5,'Greenland, Michigan 49929',15684,19654);
INSERT INTO "django_geo_db_zipcode" VALUES(22345,49930,-5,'Hancock, Michigan 49930',15685,19655);
INSERT INTO "django_geo_db_zipcode" VALUES(22346,49931,-5,'Houghton, Michigan 49931',15681,19656);
INSERT INTO "django_geo_db_zipcode" VALUES(22347,49934,-5,'Hubbell, Michigan 49934',15686,19657);
INSERT INTO "django_geo_db_zipcode" VALUES(22348,49935,-6,'Iron River, Michigan 49935',15687,19658);
INSERT INTO "django_geo_db_zipcode" VALUES(22349,49938,-6,'Ironwood, Michigan 49938',15688,19659);
INSERT INTO "django_geo_db_zipcode" VALUES(22350,49942,-5,'Kearsarge, Michigan 49942',15689,19660);
INSERT INTO "django_geo_db_zipcode" VALUES(22351,49943,-5,'Iron River, Michigan 49943',15687,19661);
INSERT INTO "django_geo_db_zipcode" VALUES(22352,49945,-5,'Lake Linden, Michigan 49945',15690,19662);
INSERT INTO "django_geo_db_zipcode" VALUES(22353,49946,-5,'Lanse, Michigan 49946',15691,19663);
INSERT INTO "django_geo_db_zipcode" VALUES(22354,49947,-6,'Marenisco, Michigan 49947',15692,19664);
INSERT INTO "django_geo_db_zipcode" VALUES(22355,49948,-5,'Mass City, Michigan 49948',15693,19665);
INSERT INTO "django_geo_db_zipcode" VALUES(22356,49950,-5,'Mohawk, Michigan 49950',15694,19666);
INSERT INTO "django_geo_db_zipcode" VALUES(22357,49952,-5,'Nisula, Michigan 49952',15695,19667);
INSERT INTO "django_geo_db_zipcode" VALUES(22358,49953,-5,'Ontonagon, Michigan 49953',15696,19668);
INSERT INTO "django_geo_db_zipcode" VALUES(22359,49955,-5,'Painesdale, Michigan 49955',15697,19669);
INSERT INTO "django_geo_db_zipcode" VALUES(22360,49958,-5,'Pelkie, Michigan 49958',15698,19670);
INSERT INTO "django_geo_db_zipcode" VALUES(22361,49959,-6,'Ramsay, Michigan 49959',15699,19671);
INSERT INTO "django_geo_db_zipcode" VALUES(22362,49960,-5,'Rockland, Michigan 49960',15700,19672);
INSERT INTO "django_geo_db_zipcode" VALUES(22363,49961,-5,'Sidnaw, Michigan 49961',15701,19673);
INSERT INTO "django_geo_db_zipcode" VALUES(22364,49962,-5,'Skanee, Michigan 49962',15702,19674);
INSERT INTO "django_geo_db_zipcode" VALUES(22365,49963,-5,'South Range, Michigan 49963',15703,19675);
INSERT INTO "django_geo_db_zipcode" VALUES(22366,49964,-6,'Stambaugh, Michigan 49964',15704,19676);
INSERT INTO "django_geo_db_zipcode" VALUES(22367,49965,-5,'Toivola, Michigan 49965',15705,19677);
INSERT INTO "django_geo_db_zipcode" VALUES(22368,49967,-5,'Trout Creek, Michigan 49967',15706,19678);
INSERT INTO "django_geo_db_zipcode" VALUES(22369,49968,-6,'Wakefield, Michigan 49968',15707,19679);
INSERT INTO "django_geo_db_zipcode" VALUES(22370,49969,-6,'Watersmeet, Michigan 49969',15708,19680);
INSERT INTO "django_geo_db_zipcode" VALUES(22371,49970,-5,'Watton, Michigan 49970',15709,19681);
INSERT INTO "django_geo_db_zipcode" VALUES(22372,49971,-5,'White Pine, Michigan 49971',15710,19682);
INSERT INTO "django_geo_db_zipcode" VALUES(22373,49974,-5,'Pickford, Michigan 49974',15577,19683);
INSERT INTO "django_geo_db_zipcode" VALUES(22374,49990,-6,'Alpha, Michigan 49990',15665,19684);
INSERT INTO "django_geo_db_zipcode" VALUES(22375,50001,-6,'Ackworth, Iowa 50001',15711,19685);
INSERT INTO "django_geo_db_zipcode" VALUES(22376,50002,-6,'Adair, Iowa 50002',15712,19686);
INSERT INTO "django_geo_db_zipcode" VALUES(22377,50003,-6,'Adel, Iowa 50003',15713,19687);
INSERT INTO "django_geo_db_zipcode" VALUES(22378,50005,-6,'Albion, Iowa 50005',15714,19688);
INSERT INTO "django_geo_db_zipcode" VALUES(22379,50006,-6,'Alden, Iowa 50006',15715,19689);
INSERT INTO "django_geo_db_zipcode" VALUES(22380,50007,-6,'Alleman, Iowa 50007',15716,19690);
INSERT INTO "django_geo_db_zipcode" VALUES(22381,50008,-6,'Allerton, Iowa 50008',15717,19691);
INSERT INTO "django_geo_db_zipcode" VALUES(22382,50009,-6,'Altoona, Iowa 50009',15718,19692);
INSERT INTO "django_geo_db_zipcode" VALUES(22383,50010,-6,'Ames, Iowa 50010',15719,19693);
INSERT INTO "django_geo_db_zipcode" VALUES(22384,50011,-6,'Ames, Iowa 50011',15719,19694);
INSERT INTO "django_geo_db_zipcode" VALUES(22385,50012,-6,'Ames, Iowa 50012',15719,19695);
INSERT INTO "django_geo_db_zipcode" VALUES(22386,50013,-6,'Ames, Iowa 50013',15719,19696);
INSERT INTO "django_geo_db_zipcode" VALUES(22387,50014,-6,'Ames, Iowa 50014',15719,19697);
INSERT INTO "django_geo_db_zipcode" VALUES(22388,50015,-6,'Ankeny, Iowa 50015',15720,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22389,50020,-6,'Anita, Iowa 50020',15721,19699);
INSERT INTO "django_geo_db_zipcode" VALUES(22390,50021,-6,'Ankeny, Iowa 50021',15720,19700);
INSERT INTO "django_geo_db_zipcode" VALUES(22391,50022,-6,'Atlantic, Iowa 50022',15722,19701);
INSERT INTO "django_geo_db_zipcode" VALUES(22392,50025,-6,'Audubon, Iowa 50025',15723,19702);
INSERT INTO "django_geo_db_zipcode" VALUES(22393,50026,-6,'Bagley, Iowa 50026',15724,19703);
INSERT INTO "django_geo_db_zipcode" VALUES(22394,50027,-6,'Barnes City, Iowa 50027',15725,19704);
INSERT INTO "django_geo_db_zipcode" VALUES(22395,50028,-6,'Baxter, Iowa 50028',15726,19705);
INSERT INTO "django_geo_db_zipcode" VALUES(22396,50029,-6,'Bayard, Iowa 50029',15727,19706);
INSERT INTO "django_geo_db_zipcode" VALUES(22397,50031,-6,'Beaver, Iowa 50031',15728,19707);
INSERT INTO "django_geo_db_zipcode" VALUES(22398,50032,-6,'Berwick, Iowa 50032',15729,19708);
INSERT INTO "django_geo_db_zipcode" VALUES(22399,50033,-6,'Bevington, Iowa 50033',15730,19709);
INSERT INTO "django_geo_db_zipcode" VALUES(22400,50034,-6,'Blairsburg, Iowa 50034',15731,19710);
INSERT INTO "django_geo_db_zipcode" VALUES(22401,50035,-6,'Bondurant, Iowa 50035',15732,19711);
INSERT INTO "django_geo_db_zipcode" VALUES(22402,50036,-6,'Boone, Iowa 50036',15733,19712);
INSERT INTO "django_geo_db_zipcode" VALUES(22403,50037,-6,'Boone, Iowa 50037',15733,19713);
INSERT INTO "django_geo_db_zipcode" VALUES(22404,50038,-6,'Booneville, Iowa 50038',15734,19714);
INSERT INTO "django_geo_db_zipcode" VALUES(22405,50039,-6,'Bouton, Iowa 50039',15735,19715);
INSERT INTO "django_geo_db_zipcode" VALUES(22406,50040,-6,'Boxholm, Iowa 50040',15736,19716);
INSERT INTO "django_geo_db_zipcode" VALUES(22407,50041,-6,'Bradford, Iowa 50041',15737,19717);
INSERT INTO "django_geo_db_zipcode" VALUES(22408,50042,-6,'Brayton, Iowa 50042',15738,19718);
INSERT INTO "django_geo_db_zipcode" VALUES(22409,50043,-6,'Buckeye, Iowa 50043',15739,19719);
INSERT INTO "django_geo_db_zipcode" VALUES(22410,50044,-6,'Bussey, Iowa 50044',15740,19720);
INSERT INTO "django_geo_db_zipcode" VALUES(22411,50046,-6,'Cambridge, Iowa 50046',15741,19721);
INSERT INTO "django_geo_db_zipcode" VALUES(22412,50047,-6,'Carlisle, Iowa 50047',15742,19722);
INSERT INTO "django_geo_db_zipcode" VALUES(22413,50048,-6,'Casey, Iowa 50048',15743,19723);
INSERT INTO "django_geo_db_zipcode" VALUES(22414,50049,-6,'Chariton, Iowa 50049',15744,19724);
INSERT INTO "django_geo_db_zipcode" VALUES(22415,50050,-6,'Churdan, Iowa 50050',15745,19725);
INSERT INTO "django_geo_db_zipcode" VALUES(22416,50051,-6,'Clemons, Iowa 50051',15746,19726);
INSERT INTO "django_geo_db_zipcode" VALUES(22417,50052,-6,'Clio, Iowa 50052',15747,19727);
INSERT INTO "django_geo_db_zipcode" VALUES(22418,50054,-6,'Colfax, Iowa 50054',15748,19728);
INSERT INTO "django_geo_db_zipcode" VALUES(22419,50055,-6,'Collins, Iowa 50055',15749,19729);
INSERT INTO "django_geo_db_zipcode" VALUES(22420,50056,-6,'Colo, Iowa 50056',15750,19730);
INSERT INTO "django_geo_db_zipcode" VALUES(22421,50057,-6,'Columbia, Iowa 50057',15751,19731);
INSERT INTO "django_geo_db_zipcode" VALUES(22422,50058,-6,'Coon Rapids, Iowa 50058',15752,19732);
INSERT INTO "django_geo_db_zipcode" VALUES(22423,50059,-6,'Cooper, Iowa 50059',15753,19733);
INSERT INTO "django_geo_db_zipcode" VALUES(22424,50060,-6,'Corydon, Iowa 50060',15754,19734);
INSERT INTO "django_geo_db_zipcode" VALUES(22425,50061,-6,'Cumming, Iowa 50061',15755,19735);
INSERT INTO "django_geo_db_zipcode" VALUES(22426,50062,-6,'Dallas, Iowa 50062',15756,19736);
INSERT INTO "django_geo_db_zipcode" VALUES(22427,50063,-6,'Dallas Center, Iowa 50063',15757,19737);
INSERT INTO "django_geo_db_zipcode" VALUES(22428,50064,-6,'Dana, Iowa 50064',15758,19738);
INSERT INTO "django_geo_db_zipcode" VALUES(22429,50065,-6,'Davis City, Iowa 50065',15759,19739);
INSERT INTO "django_geo_db_zipcode" VALUES(22430,50066,-6,'Dawson, Iowa 50066',15760,19740);
INSERT INTO "django_geo_db_zipcode" VALUES(22431,50067,-6,'Decatur, Iowa 50067',15761,19741);
INSERT INTO "django_geo_db_zipcode" VALUES(22432,50068,-6,'Derby, Iowa 50068',15762,19742);
INSERT INTO "django_geo_db_zipcode" VALUES(22433,50069,-6,'De Soto, Iowa 50069',15763,19743);
INSERT INTO "django_geo_db_zipcode" VALUES(22434,50070,-6,'Dexter, Iowa 50070',15764,19744);
INSERT INTO "django_geo_db_zipcode" VALUES(22435,50071,-6,'Dows, Iowa 50071',15765,19745);
INSERT INTO "django_geo_db_zipcode" VALUES(22436,50072,-6,'Earlham, Iowa 50072',15766,19746);
INSERT INTO "django_geo_db_zipcode" VALUES(22437,50073,-6,'Elkhart, Iowa 50073',15767,19747);
INSERT INTO "django_geo_db_zipcode" VALUES(22438,50074,-6,'Ellston, Iowa 50074',15768,19748);
INSERT INTO "django_geo_db_zipcode" VALUES(22439,50075,-6,'Ellsworth, Iowa 50075',15769,19749);
INSERT INTO "django_geo_db_zipcode" VALUES(22440,50076,-6,'Exira, Iowa 50076',15770,19750);
INSERT INTO "django_geo_db_zipcode" VALUES(22441,50078,-6,'Ferguson, Iowa 50078',15771,19751);
INSERT INTO "django_geo_db_zipcode" VALUES(22442,50101,-6,'Galt, Iowa 50101',15772,19752);
INSERT INTO "django_geo_db_zipcode" VALUES(22443,50102,-6,'Garden City, Iowa 50102',15773,19753);
INSERT INTO "django_geo_db_zipcode" VALUES(22444,50103,-6,'Garden Grove, Iowa 50103',15774,19754);
INSERT INTO "django_geo_db_zipcode" VALUES(22445,50104,-6,'Gibson, Iowa 50104',15775,19755);
INSERT INTO "django_geo_db_zipcode" VALUES(22446,50105,-6,'Gilbert, Iowa 50105',15776,19756);
INSERT INTO "django_geo_db_zipcode" VALUES(22447,50106,-6,'Gilman, Iowa 50106',15777,19757);
INSERT INTO "django_geo_db_zipcode" VALUES(22448,50107,-6,'Grand Junction, Iowa 50107',15778,19758);
INSERT INTO "django_geo_db_zipcode" VALUES(22449,50108,-6,'Grand River, Iowa 50108',15779,19759);
INSERT INTO "django_geo_db_zipcode" VALUES(22450,50109,-6,'Granger, Iowa 50109',15780,19760);
INSERT INTO "django_geo_db_zipcode" VALUES(22451,50110,-6,'Gray, Iowa 50110',15781,19761);
INSERT INTO "django_geo_db_zipcode" VALUES(22452,50111,-6,'Grimes, Iowa 50111',15782,19762);
INSERT INTO "django_geo_db_zipcode" VALUES(22453,50112,-6,'Grinnell, Iowa 50112',15783,19763);
INSERT INTO "django_geo_db_zipcode" VALUES(22454,50115,-6,'Guthrie Center, Iowa 50115',15784,19764);
INSERT INTO "django_geo_db_zipcode" VALUES(22455,50116,-6,'Hamilton, Iowa 50116',15785,19765);
INSERT INTO "django_geo_db_zipcode" VALUES(22456,50117,-6,'Hamlin, Iowa 50117',15786,19766);
INSERT INTO "django_geo_db_zipcode" VALUES(22457,50118,-6,'Hartford, Iowa 50118',15787,19767);
INSERT INTO "django_geo_db_zipcode" VALUES(22458,50119,-6,'Harvey, Iowa 50119',15788,19768);
INSERT INTO "django_geo_db_zipcode" VALUES(22459,50120,-6,'Haverhill, Iowa 50120',15789,19769);
INSERT INTO "django_geo_db_zipcode" VALUES(22460,50122,-6,'Hubbard, Iowa 50122',15790,19770);
INSERT INTO "django_geo_db_zipcode" VALUES(22461,50123,-6,'Humeston, Iowa 50123',15791,19771);
INSERT INTO "django_geo_db_zipcode" VALUES(22462,50124,-6,'Huxley, Iowa 50124',15792,19772);
INSERT INTO "django_geo_db_zipcode" VALUES(22463,50125,-6,'Indianola, Iowa 50125',15793,19773);
INSERT INTO "django_geo_db_zipcode" VALUES(22464,50126,-6,'Iowa Falls, Iowa 50126',15794,19774);
INSERT INTO "django_geo_db_zipcode" VALUES(22465,50127,-6,'Ira, Iowa 50127',15795,19775);
INSERT INTO "django_geo_db_zipcode" VALUES(22466,50128,-6,'Jamaica, Iowa 50128',15796,19776);
INSERT INTO "django_geo_db_zipcode" VALUES(22467,50129,-6,'Jefferson, Iowa 50129',15797,19777);
INSERT INTO "django_geo_db_zipcode" VALUES(22468,50130,-6,'Jewell, Iowa 50130',15798,19778);
INSERT INTO "django_geo_db_zipcode" VALUES(22469,50131,-6,'Johnston, Iowa 50131',15799,19779);
INSERT INTO "django_geo_db_zipcode" VALUES(22470,50132,-6,'Kamrar, Iowa 50132',15800,19780);
INSERT INTO "django_geo_db_zipcode" VALUES(22471,50133,-6,'Kellerton, Iowa 50133',15801,19781);
INSERT INTO "django_geo_db_zipcode" VALUES(22472,50134,-6,'Kelley, Iowa 50134',15802,19782);
INSERT INTO "django_geo_db_zipcode" VALUES(22473,50135,-6,'Kellogg, Iowa 50135',15803,19783);
INSERT INTO "django_geo_db_zipcode" VALUES(22474,50136,-6,'Keswick, Iowa 50136',15804,19784);
INSERT INTO "django_geo_db_zipcode" VALUES(22475,50137,-6,'Killduff, Iowa 50137',15805,19785);
INSERT INTO "django_geo_db_zipcode" VALUES(22476,50138,-6,'Knoxville, Iowa 50138',15806,19786);
INSERT INTO "django_geo_db_zipcode" VALUES(22477,50139,-6,'Lacona, Iowa 50139',15807,19787);
INSERT INTO "django_geo_db_zipcode" VALUES(22478,50140,-6,'Lamoni, Iowa 50140',15808,19788);
INSERT INTO "django_geo_db_zipcode" VALUES(22479,50141,-6,'Laurel, Iowa 50141',15809,19789);
INSERT INTO "django_geo_db_zipcode" VALUES(22480,50142,-6,'Le Grand, Iowa 50142',15810,19790);
INSERT INTO "django_geo_db_zipcode" VALUES(22481,50143,-6,'Leighton, Iowa 50143',15811,19791);
INSERT INTO "django_geo_db_zipcode" VALUES(22482,50144,-6,'Leon, Iowa 50144',15812,19792);
INSERT INTO "django_geo_db_zipcode" VALUES(22483,50145,-6,'Liberty Center, Iowa 50145',15813,19793);
INSERT INTO "django_geo_db_zipcode" VALUES(22484,50146,-6,'Linden, Iowa 50146',15814,19794);
INSERT INTO "django_geo_db_zipcode" VALUES(22485,50147,-6,'Lineville, Iowa 50147',15815,19795);
INSERT INTO "django_geo_db_zipcode" VALUES(22486,50148,-6,'Liscomb, Iowa 50148',15816,19796);
INSERT INTO "django_geo_db_zipcode" VALUES(22487,50149,-6,'Lorimor, Iowa 50149',15817,19797);
INSERT INTO "django_geo_db_zipcode" VALUES(22488,50150,-6,'Lovilia, Iowa 50150',15818,19798);
INSERT INTO "django_geo_db_zipcode" VALUES(22489,50151,-6,'Lucas, Iowa 50151',15819,19799);
INSERT INTO "django_geo_db_zipcode" VALUES(22490,50152,-6,'Luther, Iowa 50152',15820,19800);
INSERT INTO "django_geo_db_zipcode" VALUES(22491,50153,-6,'Lynnville, Iowa 50153',15821,19801);
INSERT INTO "django_geo_db_zipcode" VALUES(22492,50154,-6,'McCallsburg, Iowa 50154',15822,19802);
INSERT INTO "django_geo_db_zipcode" VALUES(22493,50155,-6,'Macksburg, Iowa 50155',15823,19803);
INSERT INTO "django_geo_db_zipcode" VALUES(22494,50156,-6,'Madrid, Iowa 50156',15824,19804);
INSERT INTO "django_geo_db_zipcode" VALUES(22495,50157,-6,'Malcom, Iowa 50157',15825,19805);
INSERT INTO "django_geo_db_zipcode" VALUES(22496,50158,-6,'Marshalltown, Iowa 50158',15826,19806);
INSERT INTO "django_geo_db_zipcode" VALUES(22497,50160,-6,'Martensdale, Iowa 50160',15827,19807);
INSERT INTO "django_geo_db_zipcode" VALUES(22498,50161,-6,'Maxwell, Iowa 50161',15828,19808);
INSERT INTO "django_geo_db_zipcode" VALUES(22499,50162,-6,'Melbourne, Iowa 50162',15829,19809);
INSERT INTO "django_geo_db_zipcode" VALUES(22500,50163,-6,'Melcher, Iowa 50163',15830,19810);
INSERT INTO "django_geo_db_zipcode" VALUES(22501,50164,-6,'Menlo, Iowa 50164',15831,19811);
INSERT INTO "django_geo_db_zipcode" VALUES(22502,50165,-6,'Millerton, Iowa 50165',15832,19812);
INSERT INTO "django_geo_db_zipcode" VALUES(22503,50166,-6,'Milo, Iowa 50166',15833,19813);
INSERT INTO "django_geo_db_zipcode" VALUES(22504,50167,-6,'Minburn, Iowa 50167',15834,19814);
INSERT INTO "django_geo_db_zipcode" VALUES(22505,50168,-6,'Mingo, Iowa 50168',15835,19815);
INSERT INTO "django_geo_db_zipcode" VALUES(22506,50169,-6,'Mitchellville, Iowa 50169',15836,19816);
INSERT INTO "django_geo_db_zipcode" VALUES(22507,50170,-6,'Monroe, Iowa 50170',15837,19817);
INSERT INTO "django_geo_db_zipcode" VALUES(22508,50171,-6,'Montezuma, Iowa 50171',15838,19818);
INSERT INTO "django_geo_db_zipcode" VALUES(22509,50173,-6,'Montour, Iowa 50173',15839,19819);
INSERT INTO "django_geo_db_zipcode" VALUES(22510,50174,-6,'Murray, Iowa 50174',15840,19820);
INSERT INTO "django_geo_db_zipcode" VALUES(22511,50177,-6,'Grinnell, Iowa 50177',15783,19821);
INSERT INTO "django_geo_db_zipcode" VALUES(22512,50197,-6,'Knoxville, Iowa 50197',15806,19822);
INSERT INTO "django_geo_db_zipcode" VALUES(22513,50198,-6,'Knoxville, Iowa 50198',15806,19822);
INSERT INTO "django_geo_db_zipcode" VALUES(22514,50201,-6,'Nevada, Iowa 50201',15841,19823);
INSERT INTO "django_geo_db_zipcode" VALUES(22515,50206,-6,'New Providence, Iowa 50206',15842,19824);
INSERT INTO "django_geo_db_zipcode" VALUES(22516,50207,-6,'New Sharon, Iowa 50207',15843,19825);
INSERT INTO "django_geo_db_zipcode" VALUES(22517,50208,-6,'Newton, Iowa 50208',15844,19826);
INSERT INTO "django_geo_db_zipcode" VALUES(22518,50210,-6,'New Virginia, Iowa 50210',15845,19827);
INSERT INTO "django_geo_db_zipcode" VALUES(22519,50211,-6,'Norwalk, Iowa 50211',15846,19828);
INSERT INTO "django_geo_db_zipcode" VALUES(22520,50212,-6,'Ogden, Iowa 50212',15847,19829);
INSERT INTO "django_geo_db_zipcode" VALUES(22521,50213,-6,'Osceola, Iowa 50213',15848,19830);
INSERT INTO "django_geo_db_zipcode" VALUES(22522,50214,-6,'Otley, Iowa 50214',15849,19831);
INSERT INTO "django_geo_db_zipcode" VALUES(22523,50216,-6,'Panora, Iowa 50216',15850,19832);
INSERT INTO "django_geo_db_zipcode" VALUES(22524,50217,-6,'Paton, Iowa 50217',15851,19833);
INSERT INTO "django_geo_db_zipcode" VALUES(22525,50218,-6,'Patterson, Iowa 50218',15852,19834);
INSERT INTO "django_geo_db_zipcode" VALUES(22526,50219,-6,'Pella, Iowa 50219',15853,19835);
INSERT INTO "django_geo_db_zipcode" VALUES(22527,50220,-6,'Perry, Iowa 50220',15854,19836);
INSERT INTO "django_geo_db_zipcode" VALUES(22528,50222,-6,'Peru, Iowa 50222',15855,19837);
INSERT INTO "django_geo_db_zipcode" VALUES(22529,50223,-6,'Pilot Mound, Iowa 50223',15856,19838);
INSERT INTO "django_geo_db_zipcode" VALUES(22530,50225,-6,'Pleasantville, Iowa 50225',15857,19839);
INSERT INTO "django_geo_db_zipcode" VALUES(22531,50226,-6,'Polk City, Iowa 50226',15858,19840);
INSERT INTO "django_geo_db_zipcode" VALUES(22532,50227,-6,'Popejoy, Iowa 50227',15859,19841);
INSERT INTO "django_geo_db_zipcode" VALUES(22533,50228,-6,'Prairie City, Iowa 50228',15860,19842);
INSERT INTO "django_geo_db_zipcode" VALUES(22534,50229,-6,'Prole, Iowa 50229',15861,19843);
INSERT INTO "django_geo_db_zipcode" VALUES(22535,50230,-6,'Radcliffe, Iowa 50230',15862,19844);
INSERT INTO "django_geo_db_zipcode" VALUES(22536,50231,-6,'Randall, Iowa 50231',15863,19845);
INSERT INTO "django_geo_db_zipcode" VALUES(22537,50232,-6,'Reasnor, Iowa 50232',15864,19846);
INSERT INTO "django_geo_db_zipcode" VALUES(22538,50233,-6,'Redfield, Iowa 50233',15865,19847);
INSERT INTO "django_geo_db_zipcode" VALUES(22539,50234,-6,'Rhodes, Iowa 50234',15866,19848);
INSERT INTO "django_geo_db_zipcode" VALUES(22540,50235,-6,'Rippey, Iowa 50235',15867,19849);
INSERT INTO "django_geo_db_zipcode" VALUES(22541,50236,-6,'Roland, Iowa 50236',15868,19850);
INSERT INTO "django_geo_db_zipcode" VALUES(22542,50237,-6,'Runnells, Iowa 50237',15869,19851);
INSERT INTO "django_geo_db_zipcode" VALUES(22543,50238,-6,'Russell, Iowa 50238',15870,19852);
INSERT INTO "django_geo_db_zipcode" VALUES(22544,50239,-6,'Saint Anthony, Iowa 50239',15871,19853);
INSERT INTO "django_geo_db_zipcode" VALUES(22545,50240,-6,'Saint Charles, Iowa 50240',15872,19854);
INSERT INTO "django_geo_db_zipcode" VALUES(22546,50241,-6,'Saint Marys, Iowa 50241',15873,19855);
INSERT INTO "django_geo_db_zipcode" VALUES(22547,50242,-6,'Searsboro, Iowa 50242',15874,19856);
INSERT INTO "django_geo_db_zipcode" VALUES(22548,50243,-6,'Sheldahl, Iowa 50243',15875,19857);
INSERT INTO "django_geo_db_zipcode" VALUES(22549,50244,-6,'Slater, Iowa 50244',15876,19858);
INSERT INTO "django_geo_db_zipcode" VALUES(22550,50246,-6,'Stanhope, Iowa 50246',15877,19859);
INSERT INTO "django_geo_db_zipcode" VALUES(22551,50247,-6,'State Center, Iowa 50247',15878,19860);
INSERT INTO "django_geo_db_zipcode" VALUES(22552,50248,-6,'Story City, Iowa 50248',15879,19861);
INSERT INTO "django_geo_db_zipcode" VALUES(22553,50249,-6,'Stratford, Iowa 50249',15880,19862);
INSERT INTO "django_geo_db_zipcode" VALUES(22554,50250,-6,'Stuart, Iowa 50250',15881,19863);
INSERT INTO "django_geo_db_zipcode" VALUES(22555,50251,-6,'Sully, Iowa 50251',15882,19864);
INSERT INTO "django_geo_db_zipcode" VALUES(22556,50252,-6,'Swan, Iowa 50252',15883,19865);
INSERT INTO "django_geo_db_zipcode" VALUES(22557,50254,-6,'Thayer, Iowa 50254',15884,19866);
INSERT INTO "django_geo_db_zipcode" VALUES(22558,50255,-6,'Thornburg, Iowa 50255',15885,19867);
INSERT INTO "django_geo_db_zipcode" VALUES(22559,50256,-6,'Tracy, Iowa 50256',15886,19868);
INSERT INTO "django_geo_db_zipcode" VALUES(22560,50257,-6,'Truro, Iowa 50257',15887,19869);
INSERT INTO "django_geo_db_zipcode" VALUES(22561,50258,-6,'Union, Iowa 50258',15888,19870);
INSERT INTO "django_geo_db_zipcode" VALUES(22562,50259,-6,'Gifford, Iowa 50259',15889,19871);
INSERT INTO "django_geo_db_zipcode" VALUES(22563,50261,-6,'Van Meter, Iowa 50261',15890,19872);
INSERT INTO "django_geo_db_zipcode" VALUES(22564,50262,-6,'Van Wert, Iowa 50262',15891,19873);
INSERT INTO "django_geo_db_zipcode" VALUES(22565,50263,-6,'Waukee, Iowa 50263',15892,19874);
INSERT INTO "django_geo_db_zipcode" VALUES(22566,50264,-6,'Weldon, Iowa 50264',15893,19875);
INSERT INTO "django_geo_db_zipcode" VALUES(22567,50265,-6,'West Des Moines, Iowa 50265',15894,19876);
INSERT INTO "django_geo_db_zipcode" VALUES(22568,50266,-6,'West Des Moines, Iowa 50266',15894,19877);
INSERT INTO "django_geo_db_zipcode" VALUES(22569,50268,-6,'What Cheer, Iowa 50268',15895,19878);
INSERT INTO "django_geo_db_zipcode" VALUES(22570,50269,-6,'Whitten, Iowa 50269',15896,19879);
INSERT INTO "django_geo_db_zipcode" VALUES(22571,50271,-6,'Williams, Iowa 50271',15897,19880);
INSERT INTO "django_geo_db_zipcode" VALUES(22572,50272,-6,'Williamson, Iowa 50272',15898,19881);
INSERT INTO "django_geo_db_zipcode" VALUES(22573,50273,-6,'Winterset, Iowa 50273',15899,19882);
INSERT INTO "django_geo_db_zipcode" VALUES(22574,50274,-6,'Wiota, Iowa 50274',15900,19883);
INSERT INTO "django_geo_db_zipcode" VALUES(22575,50275,-6,'Woodburn, Iowa 50275',15901,19884);
INSERT INTO "django_geo_db_zipcode" VALUES(22576,50276,-6,'Woodward, Iowa 50276',15902,19885);
INSERT INTO "django_geo_db_zipcode" VALUES(22577,50277,-6,'Yale, Iowa 50277',15903,19886);
INSERT INTO "django_geo_db_zipcode" VALUES(22578,50278,-6,'Zearing, Iowa 50278',15904,19887);
INSERT INTO "django_geo_db_zipcode" VALUES(22579,50294,-6,'Stratford, Iowa 50294',15880,19888);
INSERT INTO "django_geo_db_zipcode" VALUES(22580,50301,-6,'Des Moines, Iowa 50301',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22581,50302,-6,'Des Moines, Iowa 50302',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22582,50303,-6,'Des Moines, Iowa 50303',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22583,50304,-6,'Des Moines, Iowa 50304',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22584,50305,-6,'Des Moines, Iowa 50305',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22585,50306,-6,'Des Moines, Iowa 50306',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22586,50307,-6,'Des Moines, Iowa 50307',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22587,50308,-6,'Des Moines, Iowa 50308',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22588,50309,-6,'Des Moines, Iowa 50309',15905,19889);
INSERT INTO "django_geo_db_zipcode" VALUES(22589,50310,-6,'Des Moines, Iowa 50310',15905,19890);
INSERT INTO "django_geo_db_zipcode" VALUES(22590,50311,-6,'Des Moines, Iowa 50311',15905,19891);
INSERT INTO "django_geo_db_zipcode" VALUES(22591,50312,-6,'Des Moines, Iowa 50312',15905,19892);
INSERT INTO "django_geo_db_zipcode" VALUES(22592,50313,-6,'Des Moines, Iowa 50313',15905,19893);
INSERT INTO "django_geo_db_zipcode" VALUES(22593,50314,-6,'Des Moines, Iowa 50314',15905,19894);
INSERT INTO "django_geo_db_zipcode" VALUES(22594,50315,-6,'Des Moines, Iowa 50315',15905,19895);
INSERT INTO "django_geo_db_zipcode" VALUES(22595,50316,-6,'Des Moines, Iowa 50316',15905,19896);
INSERT INTO "django_geo_db_zipcode" VALUES(22596,50317,-6,'Des Moines, Iowa 50317',15905,19897);
INSERT INTO "django_geo_db_zipcode" VALUES(22597,50318,-6,'Des Moines, Iowa 50318',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22598,50319,-6,'Des Moines, Iowa 50319',15905,19898);
INSERT INTO "django_geo_db_zipcode" VALUES(22599,50320,-6,'Des Moines, Iowa 50320',15905,19899);
INSERT INTO "django_geo_db_zipcode" VALUES(22600,50321,-6,'Des Moines, Iowa 50321',15905,19900);
INSERT INTO "django_geo_db_zipcode" VALUES(22601,50322,-6,'Urbandale, Iowa 50322',15906,19901);
INSERT INTO "django_geo_db_zipcode" VALUES(22602,50323,-6,'Urbandale, Iowa 50323',15906,19902);
INSERT INTO "django_geo_db_zipcode" VALUES(22603,50325,-6,'Clive, Iowa 50325',15907,19903);
INSERT INTO "django_geo_db_zipcode" VALUES(22604,50327,-6,'Pleasant Hill, Iowa 50327',15908,19904);
INSERT INTO "django_geo_db_zipcode" VALUES(22605,50328,-6,'Des Moines, Iowa 50328',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22606,50329,-6,'Des Moines, Iowa 50329',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22607,50330,-6,'Des Moines, Iowa 50330',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22608,50331,-6,'Des Moines, Iowa 50331',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22609,50332,-6,'Des Moines, Iowa 50332',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22610,50333,-6,'Des Moines, Iowa 50333',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22611,50334,-6,'Des Moines, Iowa 50334',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22612,50335,-6,'Des Moines, Iowa 50335',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22613,50336,-6,'Des Moines, Iowa 50336',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22614,50338,-6,'Des Moines, Iowa 50338',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22615,50339,-6,'Des Moines, Iowa 50339',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22616,50340,-6,'Des Moines, Iowa 50340',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22617,50347,-6,'Des Moines, Iowa 50347',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22618,50350,-6,'Des Moines, Iowa 50350',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22619,50359,-6,'Des Moines, Iowa 50359',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22620,50360,-6,'Des Moines, Iowa 50360',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22621,50361,-6,'Des Moines, Iowa 50361',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22622,50362,-6,'Des Moines, Iowa 50362',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22623,50363,-6,'Des Moines, Iowa 50363',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22624,50364,-6,'Des Moines, Iowa 50364',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22625,50367,-6,'Des Moines, Iowa 50367',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22626,50368,-6,'Des Moines, Iowa 50368',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22627,50369,-6,'Des Moines, Iowa 50369',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22628,50380,-6,'Des Moines, Iowa 50380',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22629,50381,-6,'Des Moines, Iowa 50381',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22630,50391,-6,'Des Moines, Iowa 50391',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22631,50392,-6,'Des Moines, Iowa 50392',15905,19905);
INSERT INTO "django_geo_db_zipcode" VALUES(22632,50393,-6,'Des Moines, Iowa 50393',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22633,50394,-6,'Des Moines, Iowa 50394',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22634,50395,-6,'Des Moines, Iowa 50395',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22635,50396,-6,'Des Moines, Iowa 50396',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22636,50397,-6,'Des Moines, Iowa 50397',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22637,50398,-6,'West Des Moines, Iowa 50398',15894,19906);
INSERT INTO "django_geo_db_zipcode" VALUES(22638,50401,-6,'Mason City, Iowa 50401',15909,19907);
INSERT INTO "django_geo_db_zipcode" VALUES(22639,50402,-6,'Mason City, Iowa 50402',15909,19908);
INSERT INTO "django_geo_db_zipcode" VALUES(22640,50405,-6,'Lake Mills, Iowa 50405',15910,19909);
INSERT INTO "django_geo_db_zipcode" VALUES(22641,50420,-6,'Alexander, Iowa 50420',15911,19910);
INSERT INTO "django_geo_db_zipcode" VALUES(22642,50421,-6,'Belmond, Iowa 50421',15912,19911);
INSERT INTO "django_geo_db_zipcode" VALUES(22643,50423,-6,'Britt, Iowa 50423',15913,19912);
INSERT INTO "django_geo_db_zipcode" VALUES(22644,50424,-6,'Buffalo Center, Iowa 50424',15914,19913);
INSERT INTO "django_geo_db_zipcode" VALUES(22645,50426,-6,'Carpenter, Iowa 50426',15915,19914);
INSERT INTO "django_geo_db_zipcode" VALUES(22646,50427,-6,'Chapin, Iowa 50427',15916,19915);
INSERT INTO "django_geo_db_zipcode" VALUES(22647,50428,-6,'Clear Lake, Iowa 50428',15917,19916);
INSERT INTO "django_geo_db_zipcode" VALUES(22648,50430,-6,'Corwith, Iowa 50430',15918,19917);
INSERT INTO "django_geo_db_zipcode" VALUES(22649,50431,-6,'Coulter, Iowa 50431',15919,19918);
INSERT INTO "django_geo_db_zipcode" VALUES(22650,50432,-6,'Crystal Lake, Iowa 50432',15920,19919);
INSERT INTO "django_geo_db_zipcode" VALUES(22651,50433,-6,'Dougherty, Iowa 50433',15921,19920);
INSERT INTO "django_geo_db_zipcode" VALUES(22652,50434,-6,'Fertile, Iowa 50434',15922,19921);
INSERT INTO "django_geo_db_zipcode" VALUES(22653,50435,-6,'Floyd, Iowa 50435',15923,19922);
INSERT INTO "django_geo_db_zipcode" VALUES(22654,50436,-6,'Forest City, Iowa 50436',15924,19923);
INSERT INTO "django_geo_db_zipcode" VALUES(22655,50438,-6,'Garner, Iowa 50438',15925,19924);
INSERT INTO "django_geo_db_zipcode" VALUES(22656,50439,-6,'Goodell, Iowa 50439',15926,19925);
INSERT INTO "django_geo_db_zipcode" VALUES(22657,50440,-6,'Grafton, Iowa 50440',15927,19926);
INSERT INTO "django_geo_db_zipcode" VALUES(22658,50441,-6,'Hampton, Iowa 50441',15928,19927);
INSERT INTO "django_geo_db_zipcode" VALUES(22659,50444,-6,'Hanlontown, Iowa 50444',15929,19928);
INSERT INTO "django_geo_db_zipcode" VALUES(22660,50446,-6,'Joice, Iowa 50446',15930,19929);
INSERT INTO "django_geo_db_zipcode" VALUES(22661,50447,-6,'Kanawha, Iowa 50447',15931,19930);
INSERT INTO "django_geo_db_zipcode" VALUES(22662,50448,-6,'Kensett, Iowa 50448',15932,19931);
INSERT INTO "django_geo_db_zipcode" VALUES(22663,50449,-6,'Klemme, Iowa 50449',15933,19932);
INSERT INTO "django_geo_db_zipcode" VALUES(22664,50450,-6,'Lake Mills, Iowa 50450',15910,19933);
INSERT INTO "django_geo_db_zipcode" VALUES(22665,50451,-6,'Lakota, Iowa 50451',15934,19934);
INSERT INTO "django_geo_db_zipcode" VALUES(22666,50452,-6,'Latimer, Iowa 50452',15935,19935);
INSERT INTO "django_geo_db_zipcode" VALUES(22667,50453,-6,'Leland, Iowa 50453',15936,19936);
INSERT INTO "django_geo_db_zipcode" VALUES(22668,50454,-6,'Little Cedar, Iowa 50454',15937,19937);
INSERT INTO "django_geo_db_zipcode" VALUES(22669,50455,-6,'McIntire, Iowa 50455',15938,19938);
INSERT INTO "django_geo_db_zipcode" VALUES(22670,50456,-6,'Manly, Iowa 50456',15939,19939);
INSERT INTO "django_geo_db_zipcode" VALUES(22671,50457,-6,'Meservey, Iowa 50457',15940,19940);
INSERT INTO "django_geo_db_zipcode" VALUES(22672,50458,-6,'Nora Springs, Iowa 50458',15941,19941);
INSERT INTO "django_geo_db_zipcode" VALUES(22673,50459,-6,'Northwood, Iowa 50459',15942,19942);
INSERT INTO "django_geo_db_zipcode" VALUES(22674,50460,-6,'Orchard, Iowa 50460',15943,19943);
INSERT INTO "django_geo_db_zipcode" VALUES(22675,50461,-6,'Osage, Iowa 50461',15944,19944);
INSERT INTO "django_geo_db_zipcode" VALUES(22676,50464,-6,'Plymouth, Iowa 50464',15945,19945);
INSERT INTO "django_geo_db_zipcode" VALUES(22677,50465,-6,'Rake, Iowa 50465',15946,19946);
INSERT INTO "django_geo_db_zipcode" VALUES(22678,50466,-6,'Riceville, Iowa 50466',15947,19947);
INSERT INTO "django_geo_db_zipcode" VALUES(22679,50467,-6,'Rock Falls, Iowa 50467',15948,19948);
INSERT INTO "django_geo_db_zipcode" VALUES(22680,50468,-6,'Rockford, Iowa 50468',15949,19949);
INSERT INTO "django_geo_db_zipcode" VALUES(22681,50469,-6,'Rockwell, Iowa 50469',15950,19950);
INSERT INTO "django_geo_db_zipcode" VALUES(22682,50470,-6,'Rowan, Iowa 50470',15951,19951);
INSERT INTO "django_geo_db_zipcode" VALUES(22683,50471,-6,'Rudd, Iowa 50471',15952,19952);
INSERT INTO "django_geo_db_zipcode" VALUES(22684,50472,-6,'Saint Ansgar, Iowa 50472',15953,19953);
INSERT INTO "django_geo_db_zipcode" VALUES(22685,50473,-6,'Scarville, Iowa 50473',15954,19954);
INSERT INTO "django_geo_db_zipcode" VALUES(22686,50475,-6,'Sheffield, Iowa 50475',15955,19955);
INSERT INTO "django_geo_db_zipcode" VALUES(22687,50476,-6,'Stacyville, Iowa 50476',15956,19956);
INSERT INTO "django_geo_db_zipcode" VALUES(22688,50477,-6,'Swaledale, Iowa 50477',15957,19957);
INSERT INTO "django_geo_db_zipcode" VALUES(22689,50478,-6,'Thompson, Iowa 50478',15958,19958);
INSERT INTO "django_geo_db_zipcode" VALUES(22690,50479,-6,'Thornton, Iowa 50479',15959,19959);
INSERT INTO "django_geo_db_zipcode" VALUES(22691,50480,-6,'Titonka, Iowa 50480',15960,19960);
INSERT INTO "django_geo_db_zipcode" VALUES(22692,50481,-6,'Toeterville, Iowa 50481',15961,19961);
INSERT INTO "django_geo_db_zipcode" VALUES(22693,50482,-6,'Ventura, Iowa 50482',15962,19962);
INSERT INTO "django_geo_db_zipcode" VALUES(22694,50483,-6,'Wesley, Iowa 50483',15963,19963);
INSERT INTO "django_geo_db_zipcode" VALUES(22695,50484,-6,'Woden, Iowa 50484',15964,19964);
INSERT INTO "django_geo_db_zipcode" VALUES(22696,50501,-6,'Fort Dodge, Iowa 50501',15965,19965);
INSERT INTO "django_geo_db_zipcode" VALUES(22697,50510,-6,'Albert City, Iowa 50510',15966,19966);
INSERT INTO "django_geo_db_zipcode" VALUES(22698,50511,-6,'Algona, Iowa 50511',15967,19967);
INSERT INTO "django_geo_db_zipcode" VALUES(22699,50514,-6,'Armstrong, Iowa 50514',15968,19968);
INSERT INTO "django_geo_db_zipcode" VALUES(22700,50515,-6,'Ayrshire, Iowa 50515',15969,19969);
INSERT INTO "django_geo_db_zipcode" VALUES(22701,50516,-6,'Badger, Iowa 50516',15970,19970);
INSERT INTO "django_geo_db_zipcode" VALUES(22702,50517,-6,'Bancroft, Iowa 50517',15971,19971);
INSERT INTO "django_geo_db_zipcode" VALUES(22703,50518,-6,'Barnum, Iowa 50518',15972,19972);
INSERT INTO "django_geo_db_zipcode" VALUES(22704,50519,-6,'Bode, Iowa 50519',15973,19973);
INSERT INTO "django_geo_db_zipcode" VALUES(22705,50520,-6,'Bradgate, Iowa 50520',15974,19974);
INSERT INTO "django_geo_db_zipcode" VALUES(22706,50521,-6,'Burnside, Iowa 50521',15975,19975);
INSERT INTO "django_geo_db_zipcode" VALUES(22707,50522,-6,'Burt, Iowa 50522',15976,19976);
INSERT INTO "django_geo_db_zipcode" VALUES(22708,50523,-6,'Callender, Iowa 50523',15977,19977);
INSERT INTO "django_geo_db_zipcode" VALUES(22709,50524,-6,'Clare, Iowa 50524',15978,19978);
INSERT INTO "django_geo_db_zipcode" VALUES(22710,50525,-6,'Clarion, Iowa 50525',15979,19979);
INSERT INTO "django_geo_db_zipcode" VALUES(22711,50526,-6,'Clarion, Iowa 50526',15979,19980);
INSERT INTO "django_geo_db_zipcode" VALUES(22712,50527,-6,'Curlew, Iowa 50527',15980,19981);
INSERT INTO "django_geo_db_zipcode" VALUES(22713,50528,-6,'Cylinder, Iowa 50528',15981,19982);
INSERT INTO "django_geo_db_zipcode" VALUES(22714,50529,-6,'Dakota City, Iowa 50529',15982,19983);
INSERT INTO "django_geo_db_zipcode" VALUES(22715,50530,-6,'Dayton, Iowa 50530',15983,19984);
INSERT INTO "django_geo_db_zipcode" VALUES(22716,50531,-6,'Dolliver, Iowa 50531',15984,19985);
INSERT INTO "django_geo_db_zipcode" VALUES(22717,50532,-6,'Duncombe, Iowa 50532',15985,19986);
INSERT INTO "django_geo_db_zipcode" VALUES(22718,50533,-6,'Eagle Grove, Iowa 50533',15986,19987);
INSERT INTO "django_geo_db_zipcode" VALUES(22719,50535,-6,'Early, Iowa 50535',15987,19988);
INSERT INTO "django_geo_db_zipcode" VALUES(22720,50536,-6,'Emmetsburg, Iowa 50536',15988,19989);
INSERT INTO "django_geo_db_zipcode" VALUES(22721,50538,-6,'Farnhamville, Iowa 50538',15989,19990);
INSERT INTO "django_geo_db_zipcode" VALUES(22722,50539,-6,'Fenton, Iowa 50539',15990,19991);
INSERT INTO "django_geo_db_zipcode" VALUES(22723,50540,-6,'Fonda, Iowa 50540',15991,19992);
INSERT INTO "django_geo_db_zipcode" VALUES(22724,50541,-6,'Gilmore City, Iowa 50541',15992,19993);
INSERT INTO "django_geo_db_zipcode" VALUES(22725,50542,-6,'Goldfield, Iowa 50542',15993,19994);
INSERT INTO "django_geo_db_zipcode" VALUES(22726,50543,-6,'Gowrie, Iowa 50543',15994,19995);
INSERT INTO "django_geo_db_zipcode" VALUES(22727,50544,-6,'Harcourt, Iowa 50544',15995,19996);
INSERT INTO "django_geo_db_zipcode" VALUES(22728,50545,-6,'Hardy, Iowa 50545',15996,19997);
INSERT INTO "django_geo_db_zipcode" VALUES(22729,50546,-6,'Havelock, Iowa 50546',15997,19998);
INSERT INTO "django_geo_db_zipcode" VALUES(22730,50548,-6,'Humboldt, Iowa 50548',15998,19999);
INSERT INTO "django_geo_db_zipcode" VALUES(22731,50551,-6,'Jolley, Iowa 50551',15999,20000);
INSERT INTO "django_geo_db_zipcode" VALUES(22732,50552,-6,'Knierim, Iowa 50552',16000,20001);
INSERT INTO "django_geo_db_zipcode" VALUES(22733,50554,-6,'Laurens, Iowa 50554',16001,20002);
INSERT INTO "django_geo_db_zipcode" VALUES(22734,50556,-6,'Ledyard, Iowa 50556',16002,20003);
INSERT INTO "django_geo_db_zipcode" VALUES(22735,50557,-6,'Lehigh, Iowa 50557',16003,20004);
INSERT INTO "django_geo_db_zipcode" VALUES(22736,50558,-6,'Livermore, Iowa 50558',16004,20005);
INSERT INTO "django_geo_db_zipcode" VALUES(22737,50559,-6,'Lone Rock, Iowa 50559',16005,20006);
INSERT INTO "django_geo_db_zipcode" VALUES(22738,50560,-6,'Lu Verne, Iowa 50560',16006,20007);
INSERT INTO "django_geo_db_zipcode" VALUES(22739,50561,-6,'Lytton, Iowa 50561',16007,20008);
INSERT INTO "django_geo_db_zipcode" VALUES(22740,50562,-6,'Mallard, Iowa 50562',16008,20009);
INSERT INTO "django_geo_db_zipcode" VALUES(22741,50563,-6,'Manson, Iowa 50563',16009,20010);
INSERT INTO "django_geo_db_zipcode" VALUES(22742,50565,-6,'Marathon, Iowa 50565',16010,20011);
INSERT INTO "django_geo_db_zipcode" VALUES(22743,50566,-6,'Moorland, Iowa 50566',16011,20012);
INSERT INTO "django_geo_db_zipcode" VALUES(22744,50567,-6,'Nemaha, Iowa 50567',16012,20013);
INSERT INTO "django_geo_db_zipcode" VALUES(22745,50568,-6,'Newell, Iowa 50568',16013,20014);
INSERT INTO "django_geo_db_zipcode" VALUES(22746,50569,-6,'Otho, Iowa 50569',16014,20015);
INSERT INTO "django_geo_db_zipcode" VALUES(22747,50570,-6,'Ottosen, Iowa 50570',16015,20016);
INSERT INTO "django_geo_db_zipcode" VALUES(22748,50571,-6,'Palmer, Iowa 50571',16016,20017);
INSERT INTO "django_geo_db_zipcode" VALUES(22749,50573,-6,'Plover, Iowa 50573',16017,20018);
INSERT INTO "django_geo_db_zipcode" VALUES(22750,50574,-6,'Pocahontas, Iowa 50574',16018,20019);
INSERT INTO "django_geo_db_zipcode" VALUES(22751,50575,-6,'Pomeroy, Iowa 50575',16019,20020);
INSERT INTO "django_geo_db_zipcode" VALUES(22752,50576,-6,'Rembrandt, Iowa 50576',16020,20021);
INSERT INTO "django_geo_db_zipcode" VALUES(22753,50577,-6,'Renwick, Iowa 50577',16021,20022);
INSERT INTO "django_geo_db_zipcode" VALUES(22754,50578,-6,'Ringsted, Iowa 50578',16022,20023);
INSERT INTO "django_geo_db_zipcode" VALUES(22755,50579,-6,'Rockwell City, Iowa 50579',16023,20024);
INSERT INTO "django_geo_db_zipcode" VALUES(22756,50581,-6,'Rolfe, Iowa 50581',16024,20025);
INSERT INTO "django_geo_db_zipcode" VALUES(22757,50582,-6,'Rutland, Iowa 50582',16025,20026);
INSERT INTO "django_geo_db_zipcode" VALUES(22758,50583,-6,'Sac City, Iowa 50583',16026,20027);
INSERT INTO "django_geo_db_zipcode" VALUES(22759,50585,-6,'Sioux Rapids, Iowa 50585',16027,20028);
INSERT INTO "django_geo_db_zipcode" VALUES(22760,50586,-6,'Somers, Iowa 50586',16028,20029);
INSERT INTO "django_geo_db_zipcode" VALUES(22761,50587,-6,'Rinard, Iowa 50587',16029,20030);
INSERT INTO "django_geo_db_zipcode" VALUES(22762,50588,-6,'Storm Lake, Iowa 50588',16030,20031);
INSERT INTO "django_geo_db_zipcode" VALUES(22763,50590,-6,'Swea City, Iowa 50590',16031,20032);
INSERT INTO "django_geo_db_zipcode" VALUES(22764,50591,-6,'Thor, Iowa 50591',16032,20033);
INSERT INTO "django_geo_db_zipcode" VALUES(22765,50592,-6,'Truesdale, Iowa 50592',16033,20034);
INSERT INTO "django_geo_db_zipcode" VALUES(22766,50593,-6,'Varina, Iowa 50593',16034,20035);
INSERT INTO "django_geo_db_zipcode" VALUES(22767,50594,-6,'Vincent, Iowa 50594',16035,20036);
INSERT INTO "django_geo_db_zipcode" VALUES(22768,50595,-6,'Webster City, Iowa 50595',16036,20037);
INSERT INTO "django_geo_db_zipcode" VALUES(22769,50597,-6,'West Bend, Iowa 50597',16037,20038);
INSERT INTO "django_geo_db_zipcode" VALUES(22770,50598,-6,'Whittemore, Iowa 50598',16038,20039);
INSERT INTO "django_geo_db_zipcode" VALUES(22771,50599,-6,'Woolstock, Iowa 50599',16039,20040);
INSERT INTO "django_geo_db_zipcode" VALUES(22772,50601,-6,'Ackley, Iowa 50601',16040,20041);
INSERT INTO "django_geo_db_zipcode" VALUES(22773,50602,-6,'Allison, Iowa 50602',16041,20042);
INSERT INTO "django_geo_db_zipcode" VALUES(22774,50603,-6,'Alta Vista, Iowa 50603',16042,20043);
INSERT INTO "django_geo_db_zipcode" VALUES(22775,50604,-6,'Aplington, Iowa 50604',16043,20044);
INSERT INTO "django_geo_db_zipcode" VALUES(22776,50605,-6,'Aredale, Iowa 50605',16044,20045);
INSERT INTO "django_geo_db_zipcode" VALUES(22777,50606,-6,'Arlington, Iowa 50606',16045,20046);
INSERT INTO "django_geo_db_zipcode" VALUES(22778,50607,-6,'Aurora, Iowa 50607',16046,20047);
INSERT INTO "django_geo_db_zipcode" VALUES(22779,50608,-6,'Austinville, Iowa 50608',16047,20048);
INSERT INTO "django_geo_db_zipcode" VALUES(22780,50609,-6,'Beaman, Iowa 50609',16048,20049);
INSERT INTO "django_geo_db_zipcode" VALUES(22781,50611,-6,'Bristow, Iowa 50611',16049,20050);
INSERT INTO "django_geo_db_zipcode" VALUES(22782,50612,-6,'Buckingham, Iowa 50612',16050,20051);
INSERT INTO "django_geo_db_zipcode" VALUES(22783,50613,-6,'Cedar Falls, Iowa 50613',16051,20052);
INSERT INTO "django_geo_db_zipcode" VALUES(22784,50614,-6,'Cedar Falls, Iowa 50614',16051,20053);
INSERT INTO "django_geo_db_zipcode" VALUES(22785,50616,-6,'Charles City, Iowa 50616',16052,20054);
INSERT INTO "django_geo_db_zipcode" VALUES(22786,50619,-6,'Clarksville, Iowa 50619',16053,20055);
INSERT INTO "django_geo_db_zipcode" VALUES(22787,50620,-6,'Colwell, Iowa 50620',16054,20056);
INSERT INTO "django_geo_db_zipcode" VALUES(22788,50621,-6,'Conrad, Iowa 50621',16055,20057);
INSERT INTO "django_geo_db_zipcode" VALUES(22789,50622,-6,'Denver, Iowa 50622',16056,20058);
INSERT INTO "django_geo_db_zipcode" VALUES(22790,50623,-6,'Dewar, Iowa 50623',16057,20059);
INSERT INTO "django_geo_db_zipcode" VALUES(22791,50624,-6,'Dike, Iowa 50624',16058,20060);
INSERT INTO "django_geo_db_zipcode" VALUES(22792,50625,-6,'Dumont, Iowa 50625',16059,20061);
INSERT INTO "django_geo_db_zipcode" VALUES(22793,50626,-6,'Dunkerton, Iowa 50626',16060,20062);
INSERT INTO "django_geo_db_zipcode" VALUES(22794,50627,-6,'Eldora, Iowa 50627',16061,20063);
INSERT INTO "django_geo_db_zipcode" VALUES(22795,50628,-6,'Elma, Iowa 50628',16062,20064);
INSERT INTO "django_geo_db_zipcode" VALUES(22796,50629,-6,'Fairbank, Iowa 50629',16063,20065);
INSERT INTO "django_geo_db_zipcode" VALUES(22797,50630,-6,'Fredericksburg, Iowa 50630',16064,20066);
INSERT INTO "django_geo_db_zipcode" VALUES(22798,50631,-6,'Frederika, Iowa 50631',16065,20067);
INSERT INTO "django_geo_db_zipcode" VALUES(22799,50632,-6,'Garwin, Iowa 50632',16066,20068);
INSERT INTO "django_geo_db_zipcode" VALUES(22800,50633,-6,'Geneva, Iowa 50633',16067,20069);
INSERT INTO "django_geo_db_zipcode" VALUES(22801,50634,-6,'Gilbertville, Iowa 50634',16068,20070);
INSERT INTO "django_geo_db_zipcode" VALUES(22802,50635,-6,'Gladbrook, Iowa 50635',16069,20071);
INSERT INTO "django_geo_db_zipcode" VALUES(22803,50636,-6,'Greene, Iowa 50636',16070,20072);
INSERT INTO "django_geo_db_zipcode" VALUES(22804,50638,-6,'Grundy Center, Iowa 50638',16071,20073);
INSERT INTO "django_geo_db_zipcode" VALUES(22805,50641,-6,'Hazleton, Iowa 50641',16072,20074);
INSERT INTO "django_geo_db_zipcode" VALUES(22806,50642,-6,'Holland, Iowa 50642',16073,20075);
INSERT INTO "django_geo_db_zipcode" VALUES(22807,50643,-6,'Hudson, Iowa 50643',16074,20076);
INSERT INTO "django_geo_db_zipcode" VALUES(22808,50644,-6,'Independence, Iowa 50644',16075,20077);
INSERT INTO "django_geo_db_zipcode" VALUES(22809,50645,-6,'Ionia, Iowa 50645',16076,20078);
INSERT INTO "django_geo_db_zipcode" VALUES(22810,50647,-6,'Janesville, Iowa 50647',16077,20079);
INSERT INTO "django_geo_db_zipcode" VALUES(22811,50648,-6,'Jesup, Iowa 50648',16078,20080);
INSERT INTO "django_geo_db_zipcode" VALUES(22812,50649,-6,'Kesley, Iowa 50649',16079,20081);
INSERT INTO "django_geo_db_zipcode" VALUES(22813,50650,-6,'Lamont, Iowa 50650',16080,20082);
INSERT INTO "django_geo_db_zipcode" VALUES(22814,50651,-6,'La Porte City, Iowa 50651',16081,20083);
INSERT INTO "django_geo_db_zipcode" VALUES(22815,50652,-6,'Lincoln, Iowa 50652',16082,20084);
INSERT INTO "django_geo_db_zipcode" VALUES(22816,50653,-6,'Marble Rock, Iowa 50653',16083,20085);
INSERT INTO "django_geo_db_zipcode" VALUES(22817,50654,-6,'Masonville, Iowa 50654',16084,20086);
INSERT INTO "django_geo_db_zipcode" VALUES(22818,50655,-6,'Maynard, Iowa 50655',16085,20087);
INSERT INTO "django_geo_db_zipcode" VALUES(22819,50657,-6,'Morrison, Iowa 50657',16086,20088);
INSERT INTO "django_geo_db_zipcode" VALUES(22820,50658,-6,'Nashua, Iowa 50658',16087,20089);
INSERT INTO "django_geo_db_zipcode" VALUES(22821,50659,-6,'New Hampton, Iowa 50659',16088,20090);
INSERT INTO "django_geo_db_zipcode" VALUES(22822,50660,-6,'New Hartford, Iowa 50660',16089,20091);
INSERT INTO "django_geo_db_zipcode" VALUES(22823,50661,-6,'North Washington, Iowa 50661',16090,20092);
INSERT INTO "django_geo_db_zipcode" VALUES(22824,50662,-6,'Oelwein, Iowa 50662',16091,20093);
INSERT INTO "django_geo_db_zipcode" VALUES(22825,50664,-6,'Oran, Iowa 50664',16092,20094);
INSERT INTO "django_geo_db_zipcode" VALUES(22826,50665,-6,'Parkersburg, Iowa 50665',16093,20095);
INSERT INTO "django_geo_db_zipcode" VALUES(22827,50666,-6,'Plainfield, Iowa 50666',16094,20096);
INSERT INTO "django_geo_db_zipcode" VALUES(22828,50667,-6,'Raymond, Iowa 50667',16095,20097);
INSERT INTO "django_geo_db_zipcode" VALUES(22829,50668,-6,'Readlyn, Iowa 50668',16096,20098);
INSERT INTO "django_geo_db_zipcode" VALUES(22830,50669,-6,'Reinbeck, Iowa 50669',16097,20099);
INSERT INTO "django_geo_db_zipcode" VALUES(22831,50670,-6,'Shell Rock, Iowa 50670',16098,20100);
INSERT INTO "django_geo_db_zipcode" VALUES(22832,50671,-6,'Stanley, Iowa 50671',16099,20101);
INSERT INTO "django_geo_db_zipcode" VALUES(22833,50672,-6,'Steamboat Rock, Iowa 50672',16100,20102);
INSERT INTO "django_geo_db_zipcode" VALUES(22834,50673,-6,'Stout, Iowa 50673',16101,20103);
INSERT INTO "django_geo_db_zipcode" VALUES(22835,50674,-6,'Sumner, Iowa 50674',16102,20104);
INSERT INTO "django_geo_db_zipcode" VALUES(22836,50675,-6,'Traer, Iowa 50675',16103,20105);
INSERT INTO "django_geo_db_zipcode" VALUES(22837,50676,-6,'Tripoli, Iowa 50676',16104,20106);
INSERT INTO "django_geo_db_zipcode" VALUES(22838,50677,-6,'Waverly, Iowa 50677',16105,20107);
INSERT INTO "django_geo_db_zipcode" VALUES(22839,50680,-6,'Wellsburg, Iowa 50680',16106,20108);
INSERT INTO "django_geo_db_zipcode" VALUES(22840,50681,-6,'Westgate, Iowa 50681',16107,20109);
INSERT INTO "django_geo_db_zipcode" VALUES(22841,50682,-6,'Winthrop, Iowa 50682',16108,20110);
INSERT INTO "django_geo_db_zipcode" VALUES(22842,50701,-6,'Waterloo, Iowa 50701',16109,20111);
INSERT INTO "django_geo_db_zipcode" VALUES(22843,50702,-6,'Waterloo, Iowa 50702',16109,20112);
INSERT INTO "django_geo_db_zipcode" VALUES(22844,50703,-6,'Waterloo, Iowa 50703',16109,20113);
INSERT INTO "django_geo_db_zipcode" VALUES(22845,50704,-6,'Waterloo, Iowa 50704',16109,20053);
INSERT INTO "django_geo_db_zipcode" VALUES(22846,50706,-6,'Waterloo, Iowa 50706',16109,20114);
INSERT INTO "django_geo_db_zipcode" VALUES(22847,50707,-6,'Evansdale, Iowa 50707',16110,20115);
INSERT INTO "django_geo_db_zipcode" VALUES(22848,50799,-6,'Waterloo, Iowa 50799',16109,20053);
INSERT INTO "django_geo_db_zipcode" VALUES(22849,50801,-6,'Creston, Iowa 50801',16111,20116);
INSERT INTO "django_geo_db_zipcode" VALUES(22850,50830,-6,'Afton, Iowa 50830',16112,20117);
INSERT INTO "django_geo_db_zipcode" VALUES(22851,50831,-6,'Arispe, Iowa 50831',16113,20118);
INSERT INTO "django_geo_db_zipcode" VALUES(22852,50833,-6,'Bedford, Iowa 50833',16114,20119);
INSERT INTO "django_geo_db_zipcode" VALUES(22853,50835,-6,'Benton, Iowa 50835',16115,20120);
INSERT INTO "django_geo_db_zipcode" VALUES(22854,50836,-6,'Blockton, Iowa 50836',16116,20121);
INSERT INTO "django_geo_db_zipcode" VALUES(22855,50837,-6,'Bridgewater, Iowa 50837',16117,20122);
INSERT INTO "django_geo_db_zipcode" VALUES(22856,50839,-6,'Carbon, Iowa 50839',16118,20123);
INSERT INTO "django_geo_db_zipcode" VALUES(22857,50840,-6,'Clearfield, Iowa 50840',16119,20124);
INSERT INTO "django_geo_db_zipcode" VALUES(22858,50841,-6,'Corning, Iowa 50841',16120,20125);
INSERT INTO "django_geo_db_zipcode" VALUES(22859,50842,-6,'Cromwell, Iowa 50842',16121,20126);
INSERT INTO "django_geo_db_zipcode" VALUES(22860,50843,-6,'Cumberland, Iowa 50843',16122,20127);
INSERT INTO "django_geo_db_zipcode" VALUES(22861,50845,-6,'Diagonal, Iowa 50845',16123,20128);
INSERT INTO "django_geo_db_zipcode" VALUES(22862,50846,-6,'Fontanelle, Iowa 50846',16124,20129);
INSERT INTO "django_geo_db_zipcode" VALUES(22863,50847,-6,'Grant, Iowa 50847',16125,20130);
INSERT INTO "django_geo_db_zipcode" VALUES(22864,50848,-6,'Gravity, Iowa 50848',16126,20131);
INSERT INTO "django_geo_db_zipcode" VALUES(22865,50849,-6,'Greenfield, Iowa 50849',16127,20132);
INSERT INTO "django_geo_db_zipcode" VALUES(22866,50851,-6,'Lenox, Iowa 50851',16128,20133);
INSERT INTO "django_geo_db_zipcode" VALUES(22867,50853,-6,'Massena, Iowa 50853',16129,20134);
INSERT INTO "django_geo_db_zipcode" VALUES(22868,50854,-6,'Mount Ayr, Iowa 50854',16130,20135);
INSERT INTO "django_geo_db_zipcode" VALUES(22869,50857,-6,'Nodaway, Iowa 50857',16131,20136);
INSERT INTO "django_geo_db_zipcode" VALUES(22870,50858,-6,'Orient, Iowa 50858',16132,20137);
INSERT INTO "django_geo_db_zipcode" VALUES(22871,50859,-6,'Prescott, Iowa 50859',16133,20138);
INSERT INTO "django_geo_db_zipcode" VALUES(22872,50860,-6,'Redding, Iowa 50860',16134,20139);
INSERT INTO "django_geo_db_zipcode" VALUES(22873,50861,-6,'Shannon City, Iowa 50861',16135,20140);
INSERT INTO "django_geo_db_zipcode" VALUES(22874,50862,-6,'Sharpsburg, Iowa 50862',16136,20141);
INSERT INTO "django_geo_db_zipcode" VALUES(22875,50863,-6,'Tingley, Iowa 50863',16137,20142);
INSERT INTO "django_geo_db_zipcode" VALUES(22876,50864,-6,'Villisca, Iowa 50864',16138,20143);
INSERT INTO "django_geo_db_zipcode" VALUES(22877,50936,-6,'Des Moines, Iowa 50936',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22878,50940,-6,'Des Moines, Iowa 50940',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22879,50947,-6,'Des Moines, Iowa 50947',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22880,50950,-6,'Des Moines, Iowa 50950',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22881,50980,-6,'Des Moines, Iowa 50980',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22882,50981,-6,'Des Moines, Iowa 50981',15905,19698);
INSERT INTO "django_geo_db_zipcode" VALUES(22883,51001,-6,'Akron, Iowa 51001',16139,20144);
INSERT INTO "django_geo_db_zipcode" VALUES(22884,51002,-6,'Alta, Iowa 51002',16140,20145);
INSERT INTO "django_geo_db_zipcode" VALUES(22885,51003,-6,'Alton, Iowa 51003',16141,20146);
INSERT INTO "django_geo_db_zipcode" VALUES(22886,51004,-6,'Anthon, Iowa 51004',16142,20147);
INSERT INTO "django_geo_db_zipcode" VALUES(22887,51005,-6,'Aurelia, Iowa 51005',16143,20148);
INSERT INTO "django_geo_db_zipcode" VALUES(22888,51006,-6,'Battle Creek, Iowa 51006',16144,20149);
INSERT INTO "django_geo_db_zipcode" VALUES(22889,51007,-6,'Bronson, Iowa 51007',16145,20150);
INSERT INTO "django_geo_db_zipcode" VALUES(22890,51008,-6,'Brunsville, Iowa 51008',16146,20151);
INSERT INTO "django_geo_db_zipcode" VALUES(22891,51009,-6,'Calumet, Iowa 51009',16147,20152);
INSERT INTO "django_geo_db_zipcode" VALUES(22892,51010,-6,'Castana, Iowa 51010',16148,20153);
INSERT INTO "django_geo_db_zipcode" VALUES(22893,51011,-6,'Chatsworth, Iowa 51011',16149,20154);
INSERT INTO "django_geo_db_zipcode" VALUES(22894,51012,-6,'Cherokee, Iowa 51012',16150,20155);
INSERT INTO "django_geo_db_zipcode" VALUES(22895,51014,-6,'Cleghorn, Iowa 51014',16151,20156);
INSERT INTO "django_geo_db_zipcode" VALUES(22896,51015,-6,'Climbing Hill, Iowa 51015',16152,20157);
INSERT INTO "django_geo_db_zipcode" VALUES(22897,51016,-6,'Correctionville, Iowa 51016',16153,20158);
INSERT INTO "django_geo_db_zipcode" VALUES(22898,51017,-6,'Craig, Iowa 51017',16154,20159);
INSERT INTO "django_geo_db_zipcode" VALUES(22899,51018,-6,'Cushing, Iowa 51018',16155,20160);
INSERT INTO "django_geo_db_zipcode" VALUES(22900,51019,-6,'Danbury, Iowa 51019',16156,20161);
INSERT INTO "django_geo_db_zipcode" VALUES(22901,51020,-6,'Galva, Iowa 51020',16157,20162);
INSERT INTO "django_geo_db_zipcode" VALUES(22902,51022,-6,'Granville, Iowa 51022',16158,20163);
INSERT INTO "django_geo_db_zipcode" VALUES(22903,51023,-6,'Hawarden, Iowa 51023',16159,20164);
INSERT INTO "django_geo_db_zipcode" VALUES(22904,51024,-6,'Hinton, Iowa 51024',16160,20165);
INSERT INTO "django_geo_db_zipcode" VALUES(22905,51025,-6,'Holstein, Iowa 51025',16161,20166);
INSERT INTO "django_geo_db_zipcode" VALUES(22906,51026,-6,'Hornick, Iowa 51026',16162,20167);
INSERT INTO "django_geo_db_zipcode" VALUES(22907,51027,-6,'Ireton, Iowa 51027',16163,20168);
INSERT INTO "django_geo_db_zipcode" VALUES(22908,51028,-6,'Kingsley, Iowa 51028',16164,20169);
INSERT INTO "django_geo_db_zipcode" VALUES(22909,51029,-6,'Larrabee, Iowa 51029',16165,20170);
INSERT INTO "django_geo_db_zipcode" VALUES(22910,51030,-6,'Lawton, Iowa 51030',16166,20171);
INSERT INTO "django_geo_db_zipcode" VALUES(22911,51031,-6,'Le Mars, Iowa 51031',16167,20172);
INSERT INTO "django_geo_db_zipcode" VALUES(22912,51033,-6,'Linn Grove, Iowa 51033',16168,20173);
INSERT INTO "django_geo_db_zipcode" VALUES(22913,51034,-6,'Mapleton, Iowa 51034',16169,20174);
INSERT INTO "django_geo_db_zipcode" VALUES(22914,51035,-6,'Marcus, Iowa 51035',16170,20175);
INSERT INTO "django_geo_db_zipcode" VALUES(22915,51036,-6,'Maurice, Iowa 51036',16171,20176);
INSERT INTO "django_geo_db_zipcode" VALUES(22916,51037,-6,'Meriden, Iowa 51037',16172,20177);
INSERT INTO "django_geo_db_zipcode" VALUES(22917,51038,-6,'Merrill, Iowa 51038',16173,20178);
INSERT INTO "django_geo_db_zipcode" VALUES(22918,51039,-6,'Moville, Iowa 51039',16174,20179);
INSERT INTO "django_geo_db_zipcode" VALUES(22919,51040,-6,'Onawa, Iowa 51040',16175,20180);
INSERT INTO "django_geo_db_zipcode" VALUES(22920,51041,-6,'Orange City, Iowa 51041',16176,20181);
INSERT INTO "django_geo_db_zipcode" VALUES(22921,51044,-6,'Oto, Iowa 51044',16177,20182);
INSERT INTO "django_geo_db_zipcode" VALUES(22922,51045,-6,'Oyens, Iowa 51045',16178,20183);
INSERT INTO "django_geo_db_zipcode" VALUES(22923,51046,-6,'Paullina, Iowa 51046',16179,20184);
INSERT INTO "django_geo_db_zipcode" VALUES(22924,51047,-6,'Peterson, Iowa 51047',16180,20185);
INSERT INTO "django_geo_db_zipcode" VALUES(22925,51048,-6,'Pierson, Iowa 51048',16181,20186);
INSERT INTO "django_geo_db_zipcode" VALUES(22926,51049,-6,'Quimby, Iowa 51049',16182,20187);
INSERT INTO "django_geo_db_zipcode" VALUES(22927,51050,-6,'Remsen, Iowa 51050',16183,20188);
INSERT INTO "django_geo_db_zipcode" VALUES(22928,51051,-6,'Rodney, Iowa 51051',16184,20189);
INSERT INTO "django_geo_db_zipcode" VALUES(22929,51052,-6,'Salix, Iowa 51052',16185,20190);
INSERT INTO "django_geo_db_zipcode" VALUES(22930,51053,-6,'Schaller, Iowa 51053',16186,20191);
INSERT INTO "django_geo_db_zipcode" VALUES(22931,51054,-6,'Sergeant Bluff, Iowa 51054',16187,20192);
INSERT INTO "django_geo_db_zipcode" VALUES(22932,51055,-6,'Sloan, Iowa 51055',16188,20193);
INSERT INTO "django_geo_db_zipcode" VALUES(22933,51056,-6,'Smithland, Iowa 51056',16189,20194);
INSERT INTO "django_geo_db_zipcode" VALUES(22934,51057,-6,'Struble, Iowa 51057',16190,20195);
INSERT INTO "django_geo_db_zipcode" VALUES(22935,51058,-6,'Sutherland, Iowa 51058',16191,20196);
INSERT INTO "django_geo_db_zipcode" VALUES(22936,51059,-6,'Turin, Iowa 51059',16192,20197);
INSERT INTO "django_geo_db_zipcode" VALUES(22937,51060,-6,'Ute, Iowa 51060',16193,20198);
INSERT INTO "django_geo_db_zipcode" VALUES(22938,51061,-6,'Washta, Iowa 51061',16194,20199);
INSERT INTO "django_geo_db_zipcode" VALUES(22939,51062,-6,'Westfield, Iowa 51062',16195,20200);
INSERT INTO "django_geo_db_zipcode" VALUES(22940,51063,-6,'Whiting, Iowa 51063',16196,20201);
INSERT INTO "django_geo_db_zipcode" VALUES(22941,51101,-6,'Sioux City, Iowa 51101',16197,20202);
INSERT INTO "django_geo_db_zipcode" VALUES(22942,51102,-6,'Sioux City, Iowa 51102',16197,20203);
INSERT INTO "django_geo_db_zipcode" VALUES(22943,51103,-6,'Sioux City, Iowa 51103',16197,20204);
INSERT INTO "django_geo_db_zipcode" VALUES(22944,51104,-6,'Sioux City, Iowa 51104',16197,20205);
INSERT INTO "django_geo_db_zipcode" VALUES(22945,51105,-6,'Sioux City, Iowa 51105',16197,20206);
INSERT INTO "django_geo_db_zipcode" VALUES(22946,51106,-6,'Sioux City, Iowa 51106',16197,20207);
INSERT INTO "django_geo_db_zipcode" VALUES(22947,51107,-6,'Bronson, Iowa 51107',16145,20208);
INSERT INTO "django_geo_db_zipcode" VALUES(22948,51108,-6,'Sioux City, Iowa 51108',16197,20209);
INSERT INTO "django_geo_db_zipcode" VALUES(22949,51109,-6,'Sioux City, Iowa 51109',16197,20210);
INSERT INTO "django_geo_db_zipcode" VALUES(22950,51111,-6,'Sioux City, Iowa 51111',16197,20211);
INSERT INTO "django_geo_db_zipcode" VALUES(22951,51201,-6,'Sheldon, Iowa 51201',16198,20212);
INSERT INTO "django_geo_db_zipcode" VALUES(22952,51230,-6,'Alvord, Iowa 51230',16199,20213);
INSERT INTO "django_geo_db_zipcode" VALUES(22953,51231,-6,'Archer, Iowa 51231',16200,20214);
INSERT INTO "django_geo_db_zipcode" VALUES(22954,51232,-6,'Ashton, Iowa 51232',16201,20215);
INSERT INTO "django_geo_db_zipcode" VALUES(22955,51234,-6,'Boyden, Iowa 51234',16202,20216);
INSERT INTO "django_geo_db_zipcode" VALUES(22956,51235,-6,'Doon, Iowa 51235',16203,20217);
INSERT INTO "django_geo_db_zipcode" VALUES(22957,51237,-6,'George, Iowa 51237',16204,20218);
INSERT INTO "django_geo_db_zipcode" VALUES(22958,51238,-6,'Hospers, Iowa 51238',16205,20219);
INSERT INTO "django_geo_db_zipcode" VALUES(22959,51239,-6,'Hull, Iowa 51239',16206,20220);
INSERT INTO "django_geo_db_zipcode" VALUES(22960,51240,-6,'Inwood, Iowa 51240',16207,20221);
INSERT INTO "django_geo_db_zipcode" VALUES(22961,51241,-6,'Larchwood, Iowa 51241',16208,20222);
INSERT INTO "django_geo_db_zipcode" VALUES(22962,51242,-6,'Lester, Iowa 51242',16209,20223);
INSERT INTO "django_geo_db_zipcode" VALUES(22963,51243,-6,'Little Rock, Iowa 51243',16210,20224);
INSERT INTO "django_geo_db_zipcode" VALUES(22964,51244,-6,'Matlock, Iowa 51244',16211,20225);
INSERT INTO "django_geo_db_zipcode" VALUES(22965,51245,-6,'Primghar, Iowa 51245',16212,20226);
INSERT INTO "django_geo_db_zipcode" VALUES(22966,51246,-6,'Rock Rapids, Iowa 51246',16213,20227);
INSERT INTO "django_geo_db_zipcode" VALUES(22967,51247,-6,'Rock Valley, Iowa 51247',16214,20228);
INSERT INTO "django_geo_db_zipcode" VALUES(22968,51248,-6,'Sanborn, Iowa 51248',16215,20229);
INSERT INTO "django_geo_db_zipcode" VALUES(22969,51249,-6,'Sibley, Iowa 51249',16216,20230);
INSERT INTO "django_geo_db_zipcode" VALUES(22970,51250,-6,'Sioux Center, Iowa 51250',16217,20231);
INSERT INTO "django_geo_db_zipcode" VALUES(22971,51301,-6,'Spencer, Iowa 51301',16218,20232);
INSERT INTO "django_geo_db_zipcode" VALUES(22972,51330,-6,'Allendorf, Iowa 51330',16219,20233);
INSERT INTO "django_geo_db_zipcode" VALUES(22973,51331,-6,'Arnolds Park, Iowa 51331',16220,20234);
INSERT INTO "django_geo_db_zipcode" VALUES(22974,51333,-6,'Dickens, Iowa 51333',16221,20235);
INSERT INTO "django_geo_db_zipcode" VALUES(22975,51334,-6,'Estherville, Iowa 51334',16222,20236);
INSERT INTO "django_geo_db_zipcode" VALUES(22976,51338,-6,'Everly, Iowa 51338',16223,20237);
INSERT INTO "django_geo_db_zipcode" VALUES(22977,51340,-6,'Fostoria, Iowa 51340',16224,20238);
INSERT INTO "django_geo_db_zipcode" VALUES(22978,51341,-6,'Gillett Grove, Iowa 51341',16225,20239);
INSERT INTO "django_geo_db_zipcode" VALUES(22979,51342,-6,'Graettinger, Iowa 51342',16226,20240);
INSERT INTO "django_geo_db_zipcode" VALUES(22980,51343,-6,'Greenville, Iowa 51343',16227,20241);
INSERT INTO "django_geo_db_zipcode" VALUES(22981,51344,-6,'Gruver, Iowa 51344',16228,20242);
INSERT INTO "django_geo_db_zipcode" VALUES(22982,51345,-6,'Harris, Iowa 51345',16229,20243);
INSERT INTO "django_geo_db_zipcode" VALUES(22983,51346,-6,'Hartley, Iowa 51346',16230,20244);
INSERT INTO "django_geo_db_zipcode" VALUES(22984,51347,-6,'Lake Park, Iowa 51347',16231,20245);
INSERT INTO "django_geo_db_zipcode" VALUES(22985,51349,-6,'May City, Iowa 51349',16232,20246);
INSERT INTO "django_geo_db_zipcode" VALUES(22986,51350,-6,'Melvin, Iowa 51350',16233,20247);
INSERT INTO "django_geo_db_zipcode" VALUES(22987,51351,-6,'Milford, Iowa 51351',16234,20248);
INSERT INTO "django_geo_db_zipcode" VALUES(22988,51354,-6,'Ocheyedan, Iowa 51354',16235,20249);
INSERT INTO "django_geo_db_zipcode" VALUES(22989,51355,-6,'Okoboji, Iowa 51355',16236,20250);
INSERT INTO "django_geo_db_zipcode" VALUES(22990,51357,-6,'Royal, Iowa 51357',16237,20251);
INSERT INTO "django_geo_db_zipcode" VALUES(22991,51358,-6,'Ruthven, Iowa 51358',16238,20252);
INSERT INTO "django_geo_db_zipcode" VALUES(22992,51360,-6,'Spirit Lake, Iowa 51360',16239,20253);
INSERT INTO "django_geo_db_zipcode" VALUES(22993,51363,-6,'Superior, Iowa 51363',16240,20254);
INSERT INTO "django_geo_db_zipcode" VALUES(22994,51364,-6,'Terril, Iowa 51364',16241,20255);
INSERT INTO "django_geo_db_zipcode" VALUES(22995,51365,-6,'Wallingford, Iowa 51365',16242,20256);
INSERT INTO "django_geo_db_zipcode" VALUES(22996,51366,-6,'Webb, Iowa 51366',16243,20257);
INSERT INTO "django_geo_db_zipcode" VALUES(22997,51401,-6,'Carroll, Iowa 51401',16244,20258);
INSERT INTO "django_geo_db_zipcode" VALUES(22998,51430,-6,'Arcadia, Iowa 51430',16245,20259);
INSERT INTO "django_geo_db_zipcode" VALUES(22999,51431,-6,'Arthur, Iowa 51431',16246,20260);
INSERT INTO "django_geo_db_zipcode" VALUES(23000,51432,-6,'Aspinwall, Iowa 51432',16247,20261);
INSERT INTO "django_geo_db_zipcode" VALUES(23001,51433,-6,'Auburn, Iowa 51433',16248,20262);
INSERT INTO "django_geo_db_zipcode" VALUES(23002,51436,-6,'Breda, Iowa 51436',16249,20263);
INSERT INTO "django_geo_db_zipcode" VALUES(23003,51439,-6,'Charter Oak, Iowa 51439',16250,20264);
INSERT INTO "django_geo_db_zipcode" VALUES(23004,51440,-6,'Dedham, Iowa 51440',16251,20265);
INSERT INTO "django_geo_db_zipcode" VALUES(23005,51441,-6,'Deloit, Iowa 51441',16252,20266);
INSERT INTO "django_geo_db_zipcode" VALUES(23006,51442,-6,'Denison, Iowa 51442',16253,20267);
INSERT INTO "django_geo_db_zipcode" VALUES(23007,51443,-6,'Glidden, Iowa 51443',16254,20268);
INSERT INTO "django_geo_db_zipcode" VALUES(23008,51444,-6,'Halbur, Iowa 51444',16255,20269);
INSERT INTO "django_geo_db_zipcode" VALUES(23009,51445,-6,'Ida Grove, Iowa 51445',16256,20270);
INSERT INTO "django_geo_db_zipcode" VALUES(23010,51446,-6,'Irwin, Iowa 51446',16257,20271);
INSERT INTO "django_geo_db_zipcode" VALUES(23011,51447,-6,'Kirkman, Iowa 51447',16258,20272);
INSERT INTO "django_geo_db_zipcode" VALUES(23012,51448,-6,'Kiron, Iowa 51448',16259,20273);
INSERT INTO "django_geo_db_zipcode" VALUES(23013,51449,-6,'Lake City, Iowa 51449',16260,20274);
INSERT INTO "django_geo_db_zipcode" VALUES(23014,51450,-6,'Lake View, Iowa 51450',16261,20275);
INSERT INTO "django_geo_db_zipcode" VALUES(23015,51451,-6,'Lanesboro, Iowa 51451',16262,20276);
INSERT INTO "django_geo_db_zipcode" VALUES(23016,51452,-6,'Lidderdale, Iowa 51452',16263,20277);
INSERT INTO "django_geo_db_zipcode" VALUES(23017,51453,-6,'Lohrville, Iowa 51453',16264,20278);
INSERT INTO "django_geo_db_zipcode" VALUES(23018,51454,-6,'Manilla, Iowa 51454',16265,20279);
INSERT INTO "django_geo_db_zipcode" VALUES(23019,51455,-6,'Manning, Iowa 51455',16266,20280);
INSERT INTO "django_geo_db_zipcode" VALUES(23020,51458,-6,'Odebolt, Iowa 51458',16267,20281);
INSERT INTO "django_geo_db_zipcode" VALUES(23021,51459,-6,'Ralston, Iowa 51459',16268,20282);
INSERT INTO "django_geo_db_zipcode" VALUES(23022,51460,-6,'Ricketts, Iowa 51460',16269,20283);
INSERT INTO "django_geo_db_zipcode" VALUES(23023,51461,-6,'Schleswig, Iowa 51461',16270,20284);
INSERT INTO "django_geo_db_zipcode" VALUES(23024,51462,-6,'Scranton, Iowa 51462',16271,20285);
INSERT INTO "django_geo_db_zipcode" VALUES(23025,51463,-6,'Templeton, Iowa 51463',16272,20286);
INSERT INTO "django_geo_db_zipcode" VALUES(23026,51465,-6,'Vail, Iowa 51465',16273,20287);
INSERT INTO "django_geo_db_zipcode" VALUES(23027,51466,-6,'Wall Lake, Iowa 51466',16274,20288);
INSERT INTO "django_geo_db_zipcode" VALUES(23028,51467,-6,'Westside, Iowa 51467',16275,20289);
INSERT INTO "django_geo_db_zipcode" VALUES(23029,51496,-6,'Templeton, Iowa 51496',16272,20290);
INSERT INTO "django_geo_db_zipcode" VALUES(23030,51501,-6,'Council Bluffs, Iowa 51501',16276,20291);
INSERT INTO "django_geo_db_zipcode" VALUES(23031,51502,-6,'Council Bluffs, Iowa 51502',16276,20292);
INSERT INTO "django_geo_db_zipcode" VALUES(23032,51503,-6,'Council Bluffs, Iowa 51503',16276,20293);
INSERT INTO "django_geo_db_zipcode" VALUES(23033,51510,-6,'Carter Lake, Iowa 51510',16277,20294);
INSERT INTO "django_geo_db_zipcode" VALUES(23034,51515,-6,'Griswold, Iowa 51515',16278,20295);
INSERT INTO "django_geo_db_zipcode" VALUES(23035,51520,-6,'Arion, Iowa 51520',16279,20296);
INSERT INTO "django_geo_db_zipcode" VALUES(23036,51521,-6,'Avoca, Iowa 51521',16280,20297);
INSERT INTO "django_geo_db_zipcode" VALUES(23037,51523,-6,'Blencoe, Iowa 51523',16281,20298);
INSERT INTO "django_geo_db_zipcode" VALUES(23038,51525,-6,'Carson, Iowa 51525',16282,20299);
INSERT INTO "django_geo_db_zipcode" VALUES(23039,51526,-6,'Crescent, Iowa 51526',16283,20300);
INSERT INTO "django_geo_db_zipcode" VALUES(23040,51527,-6,'Defiance, Iowa 51527',16284,20301);
INSERT INTO "django_geo_db_zipcode" VALUES(23041,51528,-6,'Dow City, Iowa 51528',16285,20302);
INSERT INTO "django_geo_db_zipcode" VALUES(23042,51529,-6,'Dunlap, Iowa 51529',16286,20303);
INSERT INTO "django_geo_db_zipcode" VALUES(23043,51530,-6,'Earling, Iowa 51530',16287,20304);
INSERT INTO "django_geo_db_zipcode" VALUES(23044,51531,-6,'Elk Horn, Iowa 51531',16288,20305);
INSERT INTO "django_geo_db_zipcode" VALUES(23045,51532,-6,'Elliott, Iowa 51532',16289,20306);
INSERT INTO "django_geo_db_zipcode" VALUES(23046,51533,-6,'Emerson, Iowa 51533',16290,20307);
INSERT INTO "django_geo_db_zipcode" VALUES(23047,51534,-6,'Glenwood, Iowa 51534',16291,20308);
INSERT INTO "django_geo_db_zipcode" VALUES(23048,51535,-6,'Griswold, Iowa 51535',16278,20309);
INSERT INTO "django_geo_db_zipcode" VALUES(23049,51536,-6,'Hancock, Iowa 51536',16292,20310);
INSERT INTO "django_geo_db_zipcode" VALUES(23050,51537,-6,'Harlan, Iowa 51537',16293,20311);
INSERT INTO "django_geo_db_zipcode" VALUES(23051,51540,-6,'Hastings, Iowa 51540',16294,20312);
INSERT INTO "django_geo_db_zipcode" VALUES(23052,51541,-6,'Henderson, Iowa 51541',16295,20313);
INSERT INTO "django_geo_db_zipcode" VALUES(23053,51542,-6,'Honey Creek, Iowa 51542',16296,20314);
INSERT INTO "django_geo_db_zipcode" VALUES(23054,51543,-6,'Kimballton, Iowa 51543',16297,20315);
INSERT INTO "django_geo_db_zipcode" VALUES(23055,51544,-6,'Lewis, Iowa 51544',16298,20316);
INSERT INTO "django_geo_db_zipcode" VALUES(23056,51545,-6,'Little Sioux, Iowa 51545',16299,20317);
INSERT INTO "django_geo_db_zipcode" VALUES(23057,51546,-6,'Logan, Iowa 51546',16300,20318);
INSERT INTO "django_geo_db_zipcode" VALUES(23058,51547,-6,'Kirkman, Iowa 51547',16258,20319);
INSERT INTO "django_geo_db_zipcode" VALUES(23059,51548,-6,'McClelland, Iowa 51548',16301,20320);
INSERT INTO "django_geo_db_zipcode" VALUES(23060,51549,-6,'Macedonia, Iowa 51549',16302,20321);
INSERT INTO "django_geo_db_zipcode" VALUES(23061,51550,-6,'Magnolia, Iowa 51550',16303,20322);
INSERT INTO "django_geo_db_zipcode" VALUES(23062,51551,-6,'Malvern, Iowa 51551',16304,20323);
INSERT INTO "django_geo_db_zipcode" VALUES(23063,51552,-6,'Marne, Iowa 51552',16305,20324);
INSERT INTO "django_geo_db_zipcode" VALUES(23064,51553,-6,'Minden, Iowa 51553',16306,20325);
INSERT INTO "django_geo_db_zipcode" VALUES(23065,51554,-6,'Mineola, Iowa 51554',16307,20326);
INSERT INTO "django_geo_db_zipcode" VALUES(23066,51555,-6,'Missouri Valley, Iowa 51555',16308,20327);
INSERT INTO "django_geo_db_zipcode" VALUES(23067,51556,-6,'Modale, Iowa 51556',16309,20328);
INSERT INTO "django_geo_db_zipcode" VALUES(23068,51557,-6,'Mondamin, Iowa 51557',16310,20329);
INSERT INTO "django_geo_db_zipcode" VALUES(23069,51558,-6,'Moorhead, Iowa 51558',16311,20330);
INSERT INTO "django_geo_db_zipcode" VALUES(23070,51559,-6,'Neola, Iowa 51559',16312,20331);
INSERT INTO "django_geo_db_zipcode" VALUES(23071,51560,-6,'Oakland, Iowa 51560',16313,20332);
INSERT INTO "django_geo_db_zipcode" VALUES(23072,51561,-6,'Pacific Junction, Iowa 51561',16314,20333);
INSERT INTO "django_geo_db_zipcode" VALUES(23073,51562,-6,'Panama, Iowa 51562',16315,20334);
INSERT INTO "django_geo_db_zipcode" VALUES(23074,51563,-6,'Persia, Iowa 51563',16316,20335);
INSERT INTO "django_geo_db_zipcode" VALUES(23075,51564,-6,'Pisgah, Iowa 51564',16317,20336);
INSERT INTO "django_geo_db_zipcode" VALUES(23076,51565,-6,'Portsmouth, Iowa 51565',16318,20337);
INSERT INTO "django_geo_db_zipcode" VALUES(23077,51566,-6,'Red Oak, Iowa 51566',16319,20338);
INSERT INTO "django_geo_db_zipcode" VALUES(23078,51570,-6,'Shelby, Iowa 51570',16320,20339);
INSERT INTO "django_geo_db_zipcode" VALUES(23079,51571,-6,'Silver City, Iowa 51571',16321,20340);
INSERT INTO "django_geo_db_zipcode" VALUES(23080,51572,-6,'Soldier, Iowa 51572',16322,20341);
INSERT INTO "django_geo_db_zipcode" VALUES(23081,51573,-6,'Stanton, Iowa 51573',16323,20342);
INSERT INTO "django_geo_db_zipcode" VALUES(23082,51574,-6,'Tennant, Iowa 51574',16324,20343);
INSERT INTO "django_geo_db_zipcode" VALUES(23083,51575,-6,'Treynor, Iowa 51575',16325,20344);
INSERT INTO "django_geo_db_zipcode" VALUES(23084,51576,-6,'Underwood, Iowa 51576',16326,20345);
INSERT INTO "django_geo_db_zipcode" VALUES(23085,51577,-6,'Walnut, Iowa 51577',16327,20346);
INSERT INTO "django_geo_db_zipcode" VALUES(23086,51578,-6,'Westphalia, Iowa 51578',16328,20347);
INSERT INTO "django_geo_db_zipcode" VALUES(23087,51579,-6,'Woodbine, Iowa 51579',16329,20348);
INSERT INTO "django_geo_db_zipcode" VALUES(23088,51591,-6,'Red Oak, Iowa 51591',16319,20349);
INSERT INTO "django_geo_db_zipcode" VALUES(23089,51593,-6,'Harlan, Iowa 51593',16293,20350);
INSERT INTO "django_geo_db_zipcode" VALUES(23090,51601,-6,'Shenandoah, Iowa 51601',16330,20351);
INSERT INTO "django_geo_db_zipcode" VALUES(23091,51602,-6,'Shenandoah, Iowa 51602',16330,20352);
INSERT INTO "django_geo_db_zipcode" VALUES(23092,51603,-6,'Shenandoah, Iowa 51603',16330,20352);
INSERT INTO "django_geo_db_zipcode" VALUES(23093,51630,-6,'Blanchard, Iowa 51630',16331,20353);
INSERT INTO "django_geo_db_zipcode" VALUES(23094,51631,-6,'Braddyville, Iowa 51631',16332,20354);
INSERT INTO "django_geo_db_zipcode" VALUES(23095,51632,-6,'Clarinda, Iowa 51632',16333,20355);
INSERT INTO "django_geo_db_zipcode" VALUES(23096,51636,-6,'Coin, Iowa 51636',16334,20356);
INSERT INTO "django_geo_db_zipcode" VALUES(23097,51637,-6,'College Springs, Iowa 51637',16335,20357);
INSERT INTO "django_geo_db_zipcode" VALUES(23098,51638,-6,'Essex, Iowa 51638',16336,20358);
INSERT INTO "django_geo_db_zipcode" VALUES(23099,51639,-6,'Farragut, Iowa 51639',16337,20359);
INSERT INTO "django_geo_db_zipcode" VALUES(23100,51640,-6,'Hamburg, Iowa 51640',16338,20360);
INSERT INTO "django_geo_db_zipcode" VALUES(23101,51645,-6,'Imogene, Iowa 51645',16339,20361);
INSERT INTO "django_geo_db_zipcode" VALUES(23102,51646,-6,'New Market, Iowa 51646',16340,20362);
INSERT INTO "django_geo_db_zipcode" VALUES(23103,51647,-6,'Northboro, Iowa 51647',16341,20363);
INSERT INTO "django_geo_db_zipcode" VALUES(23104,51648,-6,'Percival, Iowa 51648',16342,20364);
INSERT INTO "django_geo_db_zipcode" VALUES(23105,51649,-6,'Randolph, Iowa 51649',16343,20365);
INSERT INTO "django_geo_db_zipcode" VALUES(23106,51650,-6,'Riverton, Iowa 51650',16344,20366);
INSERT INTO "django_geo_db_zipcode" VALUES(23107,51651,-6,'Shambaugh, Iowa 51651',16345,20367);
INSERT INTO "django_geo_db_zipcode" VALUES(23108,51652,-6,'Sidney, Iowa 51652',16346,20368);
INSERT INTO "django_geo_db_zipcode" VALUES(23109,51653,-6,'Tabor, Iowa 51653',16347,20369);
INSERT INTO "django_geo_db_zipcode" VALUES(23110,51654,-6,'Thurman, Iowa 51654',16348,20370);
INSERT INTO "django_geo_db_zipcode" VALUES(23111,51656,-6,'Yorktown, Iowa 51656',16349,20371);
INSERT INTO "django_geo_db_zipcode" VALUES(23112,52001,-6,'Dubuque, Iowa 52001',16350,20372);
INSERT INTO "django_geo_db_zipcode" VALUES(23113,52002,-6,'Dubuque, Iowa 52002',16350,20373);
INSERT INTO "django_geo_db_zipcode" VALUES(23114,52003,-6,'Dubuque, Iowa 52003',16350,20374);
INSERT INTO "django_geo_db_zipcode" VALUES(23115,52004,-6,'Dubuque, Iowa 52004',16350,20375);
INSERT INTO "django_geo_db_zipcode" VALUES(23116,52030,-6,'Andrew, Iowa 52030',16351,20376);
INSERT INTO "django_geo_db_zipcode" VALUES(23117,52031,-6,'Bellevue, Iowa 52031',16352,20377);
INSERT INTO "django_geo_db_zipcode" VALUES(23118,52032,-6,'Bernard, Iowa 52032',16353,20378);
INSERT INTO "django_geo_db_zipcode" VALUES(23119,52033,-6,'Cascade, Iowa 52033',16354,20379);
INSERT INTO "django_geo_db_zipcode" VALUES(23120,52035,-6,'Colesburg, Iowa 52035',16355,20380);
INSERT INTO "django_geo_db_zipcode" VALUES(23121,52036,-6,'Delaware, Iowa 52036',16356,20381);
INSERT INTO "django_geo_db_zipcode" VALUES(23122,52037,-6,'Delmar, Iowa 52037',16357,20382);
INSERT INTO "django_geo_db_zipcode" VALUES(23123,52038,-6,'Dundee, Iowa 52038',16358,20383);
INSERT INTO "django_geo_db_zipcode" VALUES(23124,52039,-6,'Durango, Iowa 52039',16359,20384);
INSERT INTO "django_geo_db_zipcode" VALUES(23125,52040,-6,'Dyersville, Iowa 52040',16360,20385);
INSERT INTO "django_geo_db_zipcode" VALUES(23126,52041,-6,'Earlville, Iowa 52041',16361,20386);
INSERT INTO "django_geo_db_zipcode" VALUES(23127,52042,-6,'Edgewood, Iowa 52042',16362,20387);
INSERT INTO "django_geo_db_zipcode" VALUES(23128,52043,-6,'Elkader, Iowa 52043',16363,20388);
INSERT INTO "django_geo_db_zipcode" VALUES(23129,52044,-6,'Elkport, Iowa 52044',16364,20389);
INSERT INTO "django_geo_db_zipcode" VALUES(23130,52045,-6,'Epworth, Iowa 52045',16365,20390);
INSERT INTO "django_geo_db_zipcode" VALUES(23131,52046,-6,'Farley, Iowa 52046',16366,20391);
INSERT INTO "django_geo_db_zipcode" VALUES(23132,52047,-6,'Farmersburg, Iowa 52047',16367,20392);
INSERT INTO "django_geo_db_zipcode" VALUES(23133,52048,-6,'Garber, Iowa 52048',16368,20393);
INSERT INTO "django_geo_db_zipcode" VALUES(23134,52049,-6,'Garnavillo, Iowa 52049',16369,20394);
INSERT INTO "django_geo_db_zipcode" VALUES(23135,52050,-6,'Greeley, Iowa 52050',16370,20395);
INSERT INTO "django_geo_db_zipcode" VALUES(23136,52052,-6,'Guttenberg, Iowa 52052',16371,20396);
INSERT INTO "django_geo_db_zipcode" VALUES(23137,52053,-6,'Holy Cross, Iowa 52053',16372,20397);
INSERT INTO "django_geo_db_zipcode" VALUES(23138,52054,-6,'La Motte, Iowa 52054',16373,20398);
INSERT INTO "django_geo_db_zipcode" VALUES(23139,52055,-6,'Littleport, Iowa 52055',16374,20399);
INSERT INTO "django_geo_db_zipcode" VALUES(23140,52056,-6,'Luxemburg, Iowa 52056',16375,20400);
INSERT INTO "django_geo_db_zipcode" VALUES(23141,52057,-6,'Manchester, Iowa 52057',16376,20401);
INSERT INTO "django_geo_db_zipcode" VALUES(23142,52060,-6,'Maquoketa, Iowa 52060',16377,20402);
INSERT INTO "django_geo_db_zipcode" VALUES(23143,52064,-6,'Miles, Iowa 52064',16378,20403);
INSERT INTO "django_geo_db_zipcode" VALUES(23144,52065,-6,'New Vienna, Iowa 52065',16379,20404);
INSERT INTO "django_geo_db_zipcode" VALUES(23145,52066,-6,'North Buena Vista, Iowa 52066',16380,20405);
INSERT INTO "django_geo_db_zipcode" VALUES(23146,52068,-6,'Peosta, Iowa 52068',16381,20406);
INSERT INTO "django_geo_db_zipcode" VALUES(23147,52069,-6,'Preston, Iowa 52069',16382,20407);
INSERT INTO "django_geo_db_zipcode" VALUES(23148,52070,-6,'Sabula, Iowa 52070',16383,20408);
INSERT INTO "django_geo_db_zipcode" VALUES(23149,52071,-6,'Saint Donatus, Iowa 52071',16384,20409);
INSERT INTO "django_geo_db_zipcode" VALUES(23150,52072,-6,'Saint Olaf, Iowa 52072',16385,20410);
INSERT INTO "django_geo_db_zipcode" VALUES(23151,52073,-6,'Sherrill, Iowa 52073',16386,20411);
INSERT INTO "django_geo_db_zipcode" VALUES(23152,52074,-6,'Spragueville, Iowa 52074',16387,20412);
INSERT INTO "django_geo_db_zipcode" VALUES(23153,52075,-6,'Springbrook, Iowa 52075',16388,20413);
INSERT INTO "django_geo_db_zipcode" VALUES(23154,52076,-6,'Strawberry Point, Iowa 52076',16389,20414);
INSERT INTO "django_geo_db_zipcode" VALUES(23155,52077,-6,'Volga, Iowa 52077',16390,20415);
INSERT INTO "django_geo_db_zipcode" VALUES(23156,52078,-6,'Worthington, Iowa 52078',16391,20416);
INSERT INTO "django_geo_db_zipcode" VALUES(23157,52079,-6,'Zwingle, Iowa 52079',16392,20417);
INSERT INTO "django_geo_db_zipcode" VALUES(23158,52099,-6,'Dubuque, Iowa 52099',16350,20375);
INSERT INTO "django_geo_db_zipcode" VALUES(23159,52101,-6,'Decorah, Iowa 52101',16393,20418);
INSERT INTO "django_geo_db_zipcode" VALUES(23160,52131,-6,'Burr Oak, Iowa 52131',16394,20419);
INSERT INTO "django_geo_db_zipcode" VALUES(23161,52132,-6,'Calmar, Iowa 52132',16395,20420);
INSERT INTO "django_geo_db_zipcode" VALUES(23162,52133,-6,'Castalia, Iowa 52133',16396,20421);
INSERT INTO "django_geo_db_zipcode" VALUES(23163,52134,-6,'Chester, Iowa 52134',16397,20422);
INSERT INTO "django_geo_db_zipcode" VALUES(23164,52135,-6,'Clermont, Iowa 52135',16398,20423);
INSERT INTO "django_geo_db_zipcode" VALUES(23165,52136,-6,'Cresco, Iowa 52136',16399,20424);
INSERT INTO "django_geo_db_zipcode" VALUES(23166,52140,-6,'Dorchester, Iowa 52140',16400,20425);
INSERT INTO "django_geo_db_zipcode" VALUES(23167,52141,-6,'Elgin, Iowa 52141',16401,20426);
INSERT INTO "django_geo_db_zipcode" VALUES(23168,52142,-6,'Fayette, Iowa 52142',16402,20427);
INSERT INTO "django_geo_db_zipcode" VALUES(23169,52144,-6,'Fort Atkinson, Iowa 52144',16403,20428);
INSERT INTO "django_geo_db_zipcode" VALUES(23170,52146,-6,'Harpers Ferry, Iowa 52146',16404,20429);
INSERT INTO "django_geo_db_zipcode" VALUES(23171,52147,-6,'Hawkeye, Iowa 52147',16405,20430);
INSERT INTO "django_geo_db_zipcode" VALUES(23172,52149,-6,'Highlandville, Iowa 52149',16406,20431);
INSERT INTO "django_geo_db_zipcode" VALUES(23173,52151,-6,'Lansing, Iowa 52151',16407,20432);
INSERT INTO "django_geo_db_zipcode" VALUES(23174,52154,-6,'Lawler, Iowa 52154',16408,20433);
INSERT INTO "django_geo_db_zipcode" VALUES(23175,52155,-6,'Lime Springs, Iowa 52155',16409,20434);
INSERT INTO "django_geo_db_zipcode" VALUES(23176,52156,-6,'Luana, Iowa 52156',16410,20435);
INSERT INTO "django_geo_db_zipcode" VALUES(23177,52157,-6,'McGregor, Iowa 52157',16411,20436);
INSERT INTO "django_geo_db_zipcode" VALUES(23178,52158,-6,'Marquette, Iowa 52158',16412,20437);
INSERT INTO "django_geo_db_zipcode" VALUES(23179,52159,-6,'Monona, Iowa 52159',16413,20438);
INSERT INTO "django_geo_db_zipcode" VALUES(23180,52160,-6,'New Albin, Iowa 52160',16414,20439);
INSERT INTO "django_geo_db_zipcode" VALUES(23181,52161,-6,'Ossian, Iowa 52161',16415,20440);
INSERT INTO "django_geo_db_zipcode" VALUES(23182,52162,-6,'Postville, Iowa 52162',16416,20441);
INSERT INTO "django_geo_db_zipcode" VALUES(23183,52163,-6,'Protivin, Iowa 52163',16417,20442);
INSERT INTO "django_geo_db_zipcode" VALUES(23184,52164,-6,'Randalia, Iowa 52164',16418,20443);
INSERT INTO "django_geo_db_zipcode" VALUES(23185,52165,-6,'Ridgeway, Iowa 52165',16419,20444);
INSERT INTO "django_geo_db_zipcode" VALUES(23186,52166,-6,'Saint Lucas, Iowa 52166',16420,20445);
INSERT INTO "django_geo_db_zipcode" VALUES(23187,52168,-6,'Spillville, Iowa 52168',16421,20446);
INSERT INTO "django_geo_db_zipcode" VALUES(23188,52169,-6,'Wadena, Iowa 52169',16422,20447);
INSERT INTO "django_geo_db_zipcode" VALUES(23189,52170,-6,'Waterville, Iowa 52170',16423,20448);
INSERT INTO "django_geo_db_zipcode" VALUES(23190,52171,-6,'Waucoma, Iowa 52171',16424,20449);
INSERT INTO "django_geo_db_zipcode" VALUES(23191,52172,-6,'Waukon, Iowa 52172',16425,20450);
INSERT INTO "django_geo_db_zipcode" VALUES(23192,52175,-6,'West Union, Iowa 52175',16426,20451);
INSERT INTO "django_geo_db_zipcode" VALUES(23193,52201,-6,'Ainsworth, Iowa 52201',16427,20452);
INSERT INTO "django_geo_db_zipcode" VALUES(23194,52202,-6,'Alburnett, Iowa 52202',16428,20453);
INSERT INTO "django_geo_db_zipcode" VALUES(23195,52203,-6,'Amana, Iowa 52203',16429,20454);
INSERT INTO "django_geo_db_zipcode" VALUES(23196,52204,-6,'Amana, Iowa 52204',16429,20455);
INSERT INTO "django_geo_db_zipcode" VALUES(23197,52205,-6,'Anamosa, Iowa 52205',16430,20456);
INSERT INTO "django_geo_db_zipcode" VALUES(23198,52206,-6,'Atkins, Iowa 52206',16431,20457);
INSERT INTO "django_geo_db_zipcode" VALUES(23199,52207,-6,'Baldwin, Iowa 52207',16432,20458);
INSERT INTO "django_geo_db_zipcode" VALUES(23200,52208,-6,'Belle Plaine, Iowa 52208',16433,20459);
INSERT INTO "django_geo_db_zipcode" VALUES(23201,52209,-6,'Blairstown, Iowa 52209',16434,20460);
INSERT INTO "django_geo_db_zipcode" VALUES(23202,52210,-6,'Brandon, Iowa 52210',16435,20461);
INSERT INTO "django_geo_db_zipcode" VALUES(23203,52211,-6,'Brooklyn, Iowa 52211',16436,20462);
INSERT INTO "django_geo_db_zipcode" VALUES(23204,52212,-6,'Center Junction, Iowa 52212',16437,20463);
INSERT INTO "django_geo_db_zipcode" VALUES(23205,52213,-6,'Center Point, Iowa 52213',16438,20464);
INSERT INTO "django_geo_db_zipcode" VALUES(23206,52214,-6,'Central City, Iowa 52214',16439,20465);
INSERT INTO "django_geo_db_zipcode" VALUES(23207,52215,-6,'Chelsea, Iowa 52215',16440,20466);
INSERT INTO "django_geo_db_zipcode" VALUES(23208,52216,-6,'Clarence, Iowa 52216',16441,20467);
INSERT INTO "django_geo_db_zipcode" VALUES(23209,52217,-6,'Clutier, Iowa 52217',16442,20468);
INSERT INTO "django_geo_db_zipcode" VALUES(23210,52218,-6,'Coggon, Iowa 52218',16443,20469);
INSERT INTO "django_geo_db_zipcode" VALUES(23211,52219,-6,'Prairieburg, Iowa 52219',16444,20470);
INSERT INTO "django_geo_db_zipcode" VALUES(23212,52220,-6,'Conroy, Iowa 52220',16445,20471);
INSERT INTO "django_geo_db_zipcode" VALUES(23213,52221,-6,'Guernsey, Iowa 52221',16446,20472);
INSERT INTO "django_geo_db_zipcode" VALUES(23214,52222,-6,'Deep River, Iowa 52222',16447,20473);
INSERT INTO "django_geo_db_zipcode" VALUES(23215,52223,-6,'Delhi, Iowa 52223',16448,20474);
INSERT INTO "django_geo_db_zipcode" VALUES(23216,52224,-6,'Dysart, Iowa 52224',16449,20475);
INSERT INTO "django_geo_db_zipcode" VALUES(23217,52225,-6,'Elberon, Iowa 52225',16450,20476);
INSERT INTO "django_geo_db_zipcode" VALUES(23218,52226,-6,'Elwood, Iowa 52226',16451,20477);
INSERT INTO "django_geo_db_zipcode" VALUES(23219,52227,-6,'Ely, Iowa 52227',16452,20478);
INSERT INTO "django_geo_db_zipcode" VALUES(23220,52228,-6,'Fairfax, Iowa 52228',16453,20479);
INSERT INTO "django_geo_db_zipcode" VALUES(23221,52229,-6,'Garrison, Iowa 52229',16454,20480);
INSERT INTO "django_geo_db_zipcode" VALUES(23222,52231,-6,'Harper, Iowa 52231',16455,20481);
INSERT INTO "django_geo_db_zipcode" VALUES(23223,52232,-6,'Hartwick, Iowa 52232',16456,20482);
INSERT INTO "django_geo_db_zipcode" VALUES(23224,52233,-6,'Hiawatha, Iowa 52233',16457,20483);
INSERT INTO "django_geo_db_zipcode" VALUES(23225,52235,-6,'Hills, Iowa 52235',16458,20484);
INSERT INTO "django_geo_db_zipcode" VALUES(23226,52236,-6,'Homestead, Iowa 52236',16459,20485);
INSERT INTO "django_geo_db_zipcode" VALUES(23227,52237,-6,'Hopkinton, Iowa 52237',16460,20486);
INSERT INTO "django_geo_db_zipcode" VALUES(23228,52239,-6,'Tama, Iowa 52239',16461,20487);
INSERT INTO "django_geo_db_zipcode" VALUES(23229,52240,-6,'Iowa City, Iowa 52240',16462,20488);
INSERT INTO "django_geo_db_zipcode" VALUES(23230,52241,-6,'Coralville, Iowa 52241',16463,20489);
INSERT INTO "django_geo_db_zipcode" VALUES(23231,52242,-6,'Iowa City, Iowa 52242',16462,20490);
INSERT INTO "django_geo_db_zipcode" VALUES(23232,52243,-6,'Iowa City, Iowa 52243',16462,20491);
INSERT INTO "django_geo_db_zipcode" VALUES(23233,52244,-6,'Iowa City, Iowa 52244',16462,20492);
INSERT INTO "django_geo_db_zipcode" VALUES(23234,52245,-6,'Iowa City, Iowa 52245',16462,20493);
INSERT INTO "django_geo_db_zipcode" VALUES(23235,52246,-6,'Iowa City, Iowa 52246',16462,20494);
INSERT INTO "django_geo_db_zipcode" VALUES(23236,52247,-6,'Kalona, Iowa 52247',16464,20495);
INSERT INTO "django_geo_db_zipcode" VALUES(23237,52248,-6,'Keota, Iowa 52248',16465,20496);
INSERT INTO "django_geo_db_zipcode" VALUES(23238,52249,-6,'Keystone, Iowa 52249',16466,20497);
INSERT INTO "django_geo_db_zipcode" VALUES(23239,52251,-6,'Ladora, Iowa 52251',16467,20498);
INSERT INTO "django_geo_db_zipcode" VALUES(23240,52252,-6,'Langworthy, Iowa 52252',16468,20499);
INSERT INTO "django_geo_db_zipcode" VALUES(23241,52253,-6,'Lisbon, Iowa 52253',16469,20500);
INSERT INTO "django_geo_db_zipcode" VALUES(23242,52254,-6,'Lost Nation, Iowa 52254',16470,20501);
INSERT INTO "django_geo_db_zipcode" VALUES(23243,52255,-6,'Lowden, Iowa 52255',16471,20502);
INSERT INTO "django_geo_db_zipcode" VALUES(23244,52257,-6,'Luzerne, Iowa 52257',16472,20503);
INSERT INTO "django_geo_db_zipcode" VALUES(23245,52301,-6,'Marengo, Iowa 52301',16473,20504);
INSERT INTO "django_geo_db_zipcode" VALUES(23246,52302,-6,'Marion, Iowa 52302',16474,20505);
INSERT INTO "django_geo_db_zipcode" VALUES(23247,52305,-6,'Martelle, Iowa 52305',16475,20506);
INSERT INTO "django_geo_db_zipcode" VALUES(23248,52306,-6,'Mechanicsville, Iowa 52306',16476,20507);
INSERT INTO "django_geo_db_zipcode" VALUES(23249,52307,-6,'Middle Amana, Iowa 52307',16477,20508);
INSERT INTO "django_geo_db_zipcode" VALUES(23250,52308,-6,'Millersburg, Iowa 52308',16478,20509);
INSERT INTO "django_geo_db_zipcode" VALUES(23251,52309,-6,'Monmouth, Iowa 52309',16479,20510);
INSERT INTO "django_geo_db_zipcode" VALUES(23252,52310,-6,'Monticello, Iowa 52310',16480,20511);
INSERT INTO "django_geo_db_zipcode" VALUES(23253,52312,-6,'Morley, Iowa 52312',16481,20512);
INSERT INTO "django_geo_db_zipcode" VALUES(23254,52313,-6,'Mount Auburn, Iowa 52313',16482,20513);
INSERT INTO "django_geo_db_zipcode" VALUES(23255,52314,-6,'Mount Vernon, Iowa 52314',16483,20514);
INSERT INTO "django_geo_db_zipcode" VALUES(23256,52315,-6,'Newhall, Iowa 52315',16484,20515);
INSERT INTO "django_geo_db_zipcode" VALUES(23257,52316,-6,'North English, Iowa 52316',16485,20516);
INSERT INTO "django_geo_db_zipcode" VALUES(23258,52317,-6,'North Liberty, Iowa 52317',16486,20517);
INSERT INTO "django_geo_db_zipcode" VALUES(23259,52318,-6,'Norway, Iowa 52318',16487,20518);
INSERT INTO "django_geo_db_zipcode" VALUES(23260,52319,-6,'Oakdale, Iowa 52319',16488,20491);
INSERT INTO "django_geo_db_zipcode" VALUES(23261,52320,-6,'Olin, Iowa 52320',16489,20519);
INSERT INTO "django_geo_db_zipcode" VALUES(23262,52321,-6,'Onslow, Iowa 52321',16490,20520);
INSERT INTO "django_geo_db_zipcode" VALUES(23263,52322,-6,'Oxford, Iowa 52322',16491,20521);
INSERT INTO "django_geo_db_zipcode" VALUES(23264,52323,-6,'Oxford Junction, Iowa 52323',16492,20522);
INSERT INTO "django_geo_db_zipcode" VALUES(23265,52324,-6,'Palo, Iowa 52324',16493,20523);
INSERT INTO "django_geo_db_zipcode" VALUES(23266,52325,-6,'Parnell, Iowa 52325',16494,20524);
INSERT INTO "django_geo_db_zipcode" VALUES(23267,52326,-6,'Quasqueton, Iowa 52326',16495,20525);
INSERT INTO "django_geo_db_zipcode" VALUES(23268,52327,-6,'Riverside, Iowa 52327',16496,20526);
INSERT INTO "django_geo_db_zipcode" VALUES(23269,52328,-6,'Robins, Iowa 52328',16497,20527);
INSERT INTO "django_geo_db_zipcode" VALUES(23270,52329,-6,'Rowley, Iowa 52329',16498,20528);
INSERT INTO "django_geo_db_zipcode" VALUES(23271,52330,-6,'Ryan, Iowa 52330',16499,20529);
INSERT INTO "django_geo_db_zipcode" VALUES(23272,52332,-6,'Shellsburg, Iowa 52332',16500,20530);
INSERT INTO "django_geo_db_zipcode" VALUES(23273,52333,-6,'Solon, Iowa 52333',16501,20531);
INSERT INTO "django_geo_db_zipcode" VALUES(23274,52334,-6,'South Amana, Iowa 52334',16502,20532);
INSERT INTO "django_geo_db_zipcode" VALUES(23275,52335,-6,'South English, Iowa 52335',16503,20533);
INSERT INTO "django_geo_db_zipcode" VALUES(23276,52336,-6,'Springville, Iowa 52336',16504,20534);
INSERT INTO "django_geo_db_zipcode" VALUES(23277,52337,-6,'Stanwood, Iowa 52337',16505,20535);
INSERT INTO "django_geo_db_zipcode" VALUES(23278,52338,-6,'Swisher, Iowa 52338',16506,20536);
INSERT INTO "django_geo_db_zipcode" VALUES(23279,52339,-6,'Tama, Iowa 52339',16461,20537);
INSERT INTO "django_geo_db_zipcode" VALUES(23280,52340,-6,'Tiffin, Iowa 52340',16507,20538);
INSERT INTO "django_geo_db_zipcode" VALUES(23281,52341,-6,'Toddville, Iowa 52341',16508,20539);
INSERT INTO "django_geo_db_zipcode" VALUES(23282,52342,-6,'Toledo, Iowa 52342',16509,20540);
INSERT INTO "django_geo_db_zipcode" VALUES(23283,52344,-6,'Troy Mills, Iowa 52344',16510,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23284,52345,-6,'Urbana, Iowa 52345',16511,20542);
INSERT INTO "django_geo_db_zipcode" VALUES(23285,52346,-6,'Van Horne, Iowa 52346',16512,20543);
INSERT INTO "django_geo_db_zipcode" VALUES(23286,52347,-6,'Victor, Iowa 52347',16513,20544);
INSERT INTO "django_geo_db_zipcode" VALUES(23287,52348,-6,'Vining, Iowa 52348',16514,20545);
INSERT INTO "django_geo_db_zipcode" VALUES(23288,52349,-6,'Vinton, Iowa 52349',16515,20546);
INSERT INTO "django_geo_db_zipcode" VALUES(23289,52350,-6,'Viola, Iowa 52350',16516,20547);
INSERT INTO "django_geo_db_zipcode" VALUES(23290,52351,-6,'Walford, Iowa 52351',16517,20548);
INSERT INTO "django_geo_db_zipcode" VALUES(23291,52352,-6,'Walker, Iowa 52352',16518,20549);
INSERT INTO "django_geo_db_zipcode" VALUES(23292,52353,-6,'Washington, Iowa 52353',16519,20550);
INSERT INTO "django_geo_db_zipcode" VALUES(23293,52354,-6,'Watkins, Iowa 52354',16520,20551);
INSERT INTO "django_geo_db_zipcode" VALUES(23294,52355,-6,'Webster, Iowa 52355',16521,20552);
INSERT INTO "django_geo_db_zipcode" VALUES(23295,52356,-6,'Wellman, Iowa 52356',16522,20553);
INSERT INTO "django_geo_db_zipcode" VALUES(23296,52358,-6,'West Branch, Iowa 52358',16523,20554);
INSERT INTO "django_geo_db_zipcode" VALUES(23297,52359,-6,'West Chester, Iowa 52359',16524,20555);
INSERT INTO "django_geo_db_zipcode" VALUES(23298,52361,-6,'Williamsburg, Iowa 52361',16525,20556);
INSERT INTO "django_geo_db_zipcode" VALUES(23299,52362,-6,'Wyoming, Iowa 52362',16526,20557);
INSERT INTO "django_geo_db_zipcode" VALUES(23300,52401,-6,'Cedar Rapids, Iowa 52401',16527,20558);
INSERT INTO "django_geo_db_zipcode" VALUES(23301,52402,-6,'Cedar Rapids, Iowa 52402',16527,20559);
INSERT INTO "django_geo_db_zipcode" VALUES(23302,52403,-6,'Cedar Rapids, Iowa 52403',16527,20560);
INSERT INTO "django_geo_db_zipcode" VALUES(23303,52404,-6,'Cedar Rapids, Iowa 52404',16527,20561);
INSERT INTO "django_geo_db_zipcode" VALUES(23304,52405,-6,'Cedar Rapids, Iowa 52405',16527,20562);
INSERT INTO "django_geo_db_zipcode" VALUES(23305,52406,-6,'Cedar Rapids, Iowa 52406',16527,20563);
INSERT INTO "django_geo_db_zipcode" VALUES(23306,52407,-6,'Cedar Rapids, Iowa 52407',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23307,52408,-6,'Cedar Rapids, Iowa 52408',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23308,52409,-6,'Cedar Rapids, Iowa 52409',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23309,52410,-6,'Cedar Rapids, Iowa 52410',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23310,52411,-6,'Cedar Rapids, Iowa 52411',16527,20564);
INSERT INTO "django_geo_db_zipcode" VALUES(23311,52497,-6,'Cedar Rapids, Iowa 52497',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23312,52498,-6,'Cedar Rapids, Iowa 52498',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23313,52499,-6,'Cedar Rapids, Iowa 52499',16527,20541);
INSERT INTO "django_geo_db_zipcode" VALUES(23314,52501,-6,'Ottumwa, Iowa 52501',16528,20565);
INSERT INTO "django_geo_db_zipcode" VALUES(23315,52530,-6,'Agency, Iowa 52530',16529,20566);
INSERT INTO "django_geo_db_zipcode" VALUES(23316,52531,-6,'Albia, Iowa 52531',16530,20567);
INSERT INTO "django_geo_db_zipcode" VALUES(23317,52533,-6,'Batavia, Iowa 52533',16531,20568);
INSERT INTO "django_geo_db_zipcode" VALUES(23318,52534,-6,'Beacon, Iowa 52534',16532,20569);
INSERT INTO "django_geo_db_zipcode" VALUES(23319,52535,-6,'Birmingham, Iowa 52535',16533,20570);
INSERT INTO "django_geo_db_zipcode" VALUES(23320,52536,-6,'Blakesburg, Iowa 52536',16534,20571);
INSERT INTO "django_geo_db_zipcode" VALUES(23321,52537,-6,'Bloomfield, Iowa 52537',16535,20572);
INSERT INTO "django_geo_db_zipcode" VALUES(23322,52538,-6,'West Grove, Iowa 52538',16536,20573);
INSERT INTO "django_geo_db_zipcode" VALUES(23323,52540,-6,'Brighton, Iowa 52540',16537,20574);
INSERT INTO "django_geo_db_zipcode" VALUES(23324,52542,-6,'Cantril, Iowa 52542',16538,20575);
INSERT INTO "django_geo_db_zipcode" VALUES(23325,52543,-6,'Cedar, Iowa 52543',16539,20576);
INSERT INTO "django_geo_db_zipcode" VALUES(23326,52544,-6,'Centerville, Iowa 52544',16540,20577);
INSERT INTO "django_geo_db_zipcode" VALUES(23327,52548,-6,'Chillicothe, Iowa 52548',16541,20578);
INSERT INTO "django_geo_db_zipcode" VALUES(23328,52549,-6,'Cincinnati, Iowa 52549',16542,20579);
INSERT INTO "django_geo_db_zipcode" VALUES(23329,52550,-6,'Delta, Iowa 52550',16543,20580);
INSERT INTO "django_geo_db_zipcode" VALUES(23330,52551,-6,'Douds, Iowa 52551',16544,20581);
INSERT INTO "django_geo_db_zipcode" VALUES(23331,52552,-6,'Drakesville, Iowa 52552',16545,20582);
INSERT INTO "django_geo_db_zipcode" VALUES(23332,52553,-6,'Eddyville, Iowa 52553',16546,20583);
INSERT INTO "django_geo_db_zipcode" VALUES(23333,52554,-6,'Eldon, Iowa 52554',16547,20584);
INSERT INTO "django_geo_db_zipcode" VALUES(23334,52555,-6,'Exline, Iowa 52555',16548,20585);
INSERT INTO "django_geo_db_zipcode" VALUES(23335,52556,-6,'Fairfield, Iowa 52556',16549,20586);
INSERT INTO "django_geo_db_zipcode" VALUES(23336,52557,-6,'Fairfield, Iowa 52557',16549,20587);
INSERT INTO "django_geo_db_zipcode" VALUES(23337,52560,-6,'Floris, Iowa 52560',16550,20588);
INSERT INTO "django_geo_db_zipcode" VALUES(23338,52561,-6,'Fremont, Iowa 52561',16551,20589);
INSERT INTO "django_geo_db_zipcode" VALUES(23339,52562,-6,'Hayesville, Iowa 52562',16552,20590);
INSERT INTO "django_geo_db_zipcode" VALUES(23340,52563,-6,'Hedrick, Iowa 52563',16553,20591);
INSERT INTO "django_geo_db_zipcode" VALUES(23341,52565,-6,'Keosauqua, Iowa 52565',16554,20592);
INSERT INTO "django_geo_db_zipcode" VALUES(23342,52566,-6,'Kirkville, Iowa 52566',16555,20593);
INSERT INTO "django_geo_db_zipcode" VALUES(23343,52567,-6,'Libertyville, Iowa 52567',16556,20594);
INSERT INTO "django_geo_db_zipcode" VALUES(23344,52568,-6,'Martinsburg, Iowa 52568',16557,20595);
INSERT INTO "django_geo_db_zipcode" VALUES(23345,52569,-6,'Melrose, Iowa 52569',16558,20596);
INSERT INTO "django_geo_db_zipcode" VALUES(23346,52570,-6,'Milton, Iowa 52570',16559,20597);
INSERT INTO "django_geo_db_zipcode" VALUES(23347,52571,-6,'Moravia, Iowa 52571',16560,20598);
INSERT INTO "django_geo_db_zipcode" VALUES(23348,52572,-6,'Moulton, Iowa 52572',16561,20599);
INSERT INTO "django_geo_db_zipcode" VALUES(23349,52573,-6,'Mount Sterling, Iowa 52573',16562,20600);
INSERT INTO "django_geo_db_zipcode" VALUES(23350,52574,-6,'Mystic, Iowa 52574',16563,20601);
INSERT INTO "django_geo_db_zipcode" VALUES(23351,52576,-6,'Ollie, Iowa 52576',16564,20602);
INSERT INTO "django_geo_db_zipcode" VALUES(23352,52577,-6,'Oskaloosa, Iowa 52577',16565,20603);
INSERT INTO "django_geo_db_zipcode" VALUES(23353,52580,-6,'Packwood, Iowa 52580',16566,20604);
INSERT INTO "django_geo_db_zipcode" VALUES(23354,52581,-6,'Plano, Iowa 52581',16567,20605);
INSERT INTO "django_geo_db_zipcode" VALUES(23355,52583,-6,'Promise City, Iowa 52583',16568,20606);
INSERT INTO "django_geo_db_zipcode" VALUES(23356,52584,-6,'Pulaski, Iowa 52584',16569,20607);
INSERT INTO "django_geo_db_zipcode" VALUES(23357,52585,-6,'Richland, Iowa 52585',16570,20608);
INSERT INTO "django_geo_db_zipcode" VALUES(23358,52586,-6,'Rose Hill, Iowa 52586',16571,20609);
INSERT INTO "django_geo_db_zipcode" VALUES(23359,52588,-6,'Selma, Iowa 52588',16572,20610);
INSERT INTO "django_geo_db_zipcode" VALUES(23360,52590,-6,'Seymour, Iowa 52590',16573,20611);
INSERT INTO "django_geo_db_zipcode" VALUES(23361,52591,-6,'Sigourney, Iowa 52591',16574,20612);
INSERT INTO "django_geo_db_zipcode" VALUES(23362,52593,-6,'Udell, Iowa 52593',16575,20613);
INSERT INTO "django_geo_db_zipcode" VALUES(23363,52594,-6,'Unionville, Iowa 52594',16576,20614);
INSERT INTO "django_geo_db_zipcode" VALUES(23364,52595,-6,'University Park, Iowa 52595',16577,20615);
INSERT INTO "django_geo_db_zipcode" VALUES(23365,52601,-6,'Burlington, Iowa 52601',16578,20616);
INSERT INTO "django_geo_db_zipcode" VALUES(23366,52619,-6,'Argyle, Iowa 52619',16579,20617);
INSERT INTO "django_geo_db_zipcode" VALUES(23367,52620,-6,'Bonaparte, Iowa 52620',16580,20618);
INSERT INTO "django_geo_db_zipcode" VALUES(23368,52621,-6,'Crawfordsville, Iowa 52621',16581,20619);
INSERT INTO "django_geo_db_zipcode" VALUES(23369,52623,-6,'Danville, Iowa 52623',16582,20620);
INSERT INTO "django_geo_db_zipcode" VALUES(23370,52624,-6,'Denmark, Iowa 52624',16583,20621);
INSERT INTO "django_geo_db_zipcode" VALUES(23371,52625,-6,'Donnellson, Iowa 52625',16584,20622);
INSERT INTO "django_geo_db_zipcode" VALUES(23372,52626,-6,'Farmington, Iowa 52626',16585,20623);
INSERT INTO "django_geo_db_zipcode" VALUES(23373,52627,-6,'Fort Madison, Iowa 52627',16586,20624);
INSERT INTO "django_geo_db_zipcode" VALUES(23374,52630,-6,'Hillsboro, Iowa 52630',16587,20625);
INSERT INTO "django_geo_db_zipcode" VALUES(23375,52631,-6,'Houghton, Iowa 52631',16588,20626);
INSERT INTO "django_geo_db_zipcode" VALUES(23376,52632,-6,'Keokuk, Iowa 52632',16589,20627);
INSERT INTO "django_geo_db_zipcode" VALUES(23377,52635,-6,'Lockridge, Iowa 52635',16590,20628);
INSERT INTO "django_geo_db_zipcode" VALUES(23378,52637,-6,'Mediapolis, Iowa 52637',16591,20629);
INSERT INTO "django_geo_db_zipcode" VALUES(23379,52638,-6,'Middletown, Iowa 52638',16592,20630);
INSERT INTO "django_geo_db_zipcode" VALUES(23380,52639,-6,'Montrose, Iowa 52639',16593,20631);
INSERT INTO "django_geo_db_zipcode" VALUES(23381,52640,-6,'Morning Sun, Iowa 52640',16594,20632);
INSERT INTO "django_geo_db_zipcode" VALUES(23382,52641,-6,'Mount Pleasant, Iowa 52641',16595,20633);
INSERT INTO "django_geo_db_zipcode" VALUES(23383,52642,-6,'Rome, Iowa 52642',16596,20634);
INSERT INTO "django_geo_db_zipcode" VALUES(23384,52644,-6,'Mount Union, Iowa 52644',16597,20635);
INSERT INTO "django_geo_db_zipcode" VALUES(23385,52645,-6,'New London, Iowa 52645',16598,20636);
INSERT INTO "django_geo_db_zipcode" VALUES(23386,52646,-6,'Oakville, Iowa 52646',16599,20637);
INSERT INTO "django_geo_db_zipcode" VALUES(23387,52647,-6,'Olds, Iowa 52647',16600,20638);
INSERT INTO "django_geo_db_zipcode" VALUES(23388,52648,-6,'Pilot Grove, Iowa 52648',16601,20639);
INSERT INTO "django_geo_db_zipcode" VALUES(23389,52649,-6,'Salem, Iowa 52649',16602,20640);
INSERT INTO "django_geo_db_zipcode" VALUES(23390,52650,-6,'Sperry, Iowa 52650',16603,20641);
INSERT INTO "django_geo_db_zipcode" VALUES(23391,52651,-6,'Stockport, Iowa 52651',16604,20642);
INSERT INTO "django_geo_db_zipcode" VALUES(23392,52652,-6,'Swedesburg, Iowa 52652',16605,20643);
INSERT INTO "django_geo_db_zipcode" VALUES(23393,52653,-6,'Wapello, Iowa 52653',16606,20644);
INSERT INTO "django_geo_db_zipcode" VALUES(23394,52654,-6,'Wayland, Iowa 52654',16607,20645);
INSERT INTO "django_geo_db_zipcode" VALUES(23395,52655,-6,'West Burlington, Iowa 52655',16608,20646);
INSERT INTO "django_geo_db_zipcode" VALUES(23396,52656,-6,'West Point, Iowa 52656',16609,20647);
INSERT INTO "django_geo_db_zipcode" VALUES(23397,52657,-6,'Saint Paul, Iowa 52657',16610,20648);
INSERT INTO "django_geo_db_zipcode" VALUES(23398,52658,-6,'Wever, Iowa 52658',16611,20649);
INSERT INTO "django_geo_db_zipcode" VALUES(23399,52659,-6,'Winfield, Iowa 52659',16612,20650);
INSERT INTO "django_geo_db_zipcode" VALUES(23400,52660,-6,'Yarmouth, Iowa 52660',16613,20651);
INSERT INTO "django_geo_db_zipcode" VALUES(23401,52701,-6,'Andover, Iowa 52701',16614,20652);
INSERT INTO "django_geo_db_zipcode" VALUES(23402,52706,-6,'Blue Grass, Iowa 52706',16615,20653);
INSERT INTO "django_geo_db_zipcode" VALUES(23403,52720,-6,'Atalissa, Iowa 52720',16616,20654);
INSERT INTO "django_geo_db_zipcode" VALUES(23404,52721,-6,'Bennett, Iowa 52721',16617,20655);
INSERT INTO "django_geo_db_zipcode" VALUES(23405,52722,-6,'Bettendorf, Iowa 52722',16618,20656);
INSERT INTO "django_geo_db_zipcode" VALUES(23406,52726,-6,'Blue Grass, Iowa 52726',16615,20657);
INSERT INTO "django_geo_db_zipcode" VALUES(23407,52727,-6,'Bryant, Iowa 52727',16619,20658);
INSERT INTO "django_geo_db_zipcode" VALUES(23408,52728,-6,'Buffalo, Iowa 52728',16620,20659);
INSERT INTO "django_geo_db_zipcode" VALUES(23409,52729,-6,'Calamus, Iowa 52729',16621,20660);
INSERT INTO "django_geo_db_zipcode" VALUES(23410,52730,-6,'Camanche, Iowa 52730',16622,20661);
INSERT INTO "django_geo_db_zipcode" VALUES(23411,52731,-6,'Charlotte, Iowa 52731',16623,20662);
INSERT INTO "django_geo_db_zipcode" VALUES(23412,52732,-6,'Clinton, Iowa 52732',16624,20663);
INSERT INTO "django_geo_db_zipcode" VALUES(23413,52733,-6,'Clinton, Iowa 52733',16624,20664);
INSERT INTO "django_geo_db_zipcode" VALUES(23414,52736,-6,'Clinton, Iowa 52736',16624,20664);
INSERT INTO "django_geo_db_zipcode" VALUES(23415,52737,-6,'Columbus City, Iowa 52737',16625,20665);
INSERT INTO "django_geo_db_zipcode" VALUES(23416,52738,-6,'Columbus Junction, Iowa 52738',16626,20666);
INSERT INTO "django_geo_db_zipcode" VALUES(23417,52739,-6,'Conesville, Iowa 52739',16627,20667);
INSERT INTO "django_geo_db_zipcode" VALUES(23418,52742,-6,'De Witt, Iowa 52742',16628,20668);
INSERT INTO "django_geo_db_zipcode" VALUES(23419,52745,-6,'Dixon, Iowa 52745',16629,20669);
INSERT INTO "django_geo_db_zipcode" VALUES(23420,52746,-6,'Donahue, Iowa 52746',16630,20670);
INSERT INTO "django_geo_db_zipcode" VALUES(23421,52747,-6,'Durant, Iowa 52747',16631,20671);
INSERT INTO "django_geo_db_zipcode" VALUES(23422,52748,-6,'Eldridge, Iowa 52748',16632,20672);
INSERT INTO "django_geo_db_zipcode" VALUES(23423,52749,-6,'Fruitland, Iowa 52749',16633,20673);
INSERT INTO "django_geo_db_zipcode" VALUES(23424,52750,-6,'Goose Lake, Iowa 52750',16634,20674);
INSERT INTO "django_geo_db_zipcode" VALUES(23425,52751,-6,'Grand Mound, Iowa 52751',16635,20675);
INSERT INTO "django_geo_db_zipcode" VALUES(23426,52752,-6,'Grandview, Iowa 52752',16636,20676);
INSERT INTO "django_geo_db_zipcode" VALUES(23427,52753,-6,'Le Claire, Iowa 52753',16637,20677);
INSERT INTO "django_geo_db_zipcode" VALUES(23428,52754,-6,'Letts, Iowa 52754',16638,20678);
INSERT INTO "django_geo_db_zipcode" VALUES(23429,52755,-6,'Lone Tree, Iowa 52755',16639,20679);
INSERT INTO "django_geo_db_zipcode" VALUES(23430,52756,-6,'Long Grove, Iowa 52756',16640,20680);
INSERT INTO "django_geo_db_zipcode" VALUES(23431,52757,-6,'Low Moor, Iowa 52757',16641,20681);
INSERT INTO "django_geo_db_zipcode" VALUES(23432,52758,-6,'McCausland, Iowa 52758',16642,20682);
INSERT INTO "django_geo_db_zipcode" VALUES(23433,52759,-6,'Montpelier, Iowa 52759',16643,20683);
INSERT INTO "django_geo_db_zipcode" VALUES(23434,52760,-6,'Moscow, Iowa 52760',16644,20684);
INSERT INTO "django_geo_db_zipcode" VALUES(23435,52761,-6,'Muscatine, Illinois 52761',16645,20685);
INSERT INTO "django_geo_db_zipcode" VALUES(23436,52765,-6,'New Liberty, Iowa 52765',16646,20686);
INSERT INTO "django_geo_db_zipcode" VALUES(23437,52766,-6,'Nichols, Iowa 52766',16647,20687);
INSERT INTO "django_geo_db_zipcode" VALUES(23438,52767,-6,'Pleasant Valley, Iowa 52767',16648,20688);
INSERT INTO "django_geo_db_zipcode" VALUES(23439,52768,-6,'Princeton, Iowa 52768',16649,20689);
INSERT INTO "django_geo_db_zipcode" VALUES(23440,52769,-6,'Stockton, Iowa 52769',16650,20690);
INSERT INTO "django_geo_db_zipcode" VALUES(23441,52771,-6,'Teeds Grove, Iowa 52771',16651,20691);
INSERT INTO "django_geo_db_zipcode" VALUES(23442,52772,-6,'Tipton, Iowa 52772',16652,20692);
INSERT INTO "django_geo_db_zipcode" VALUES(23443,52773,-6,'Walcott, Iowa 52773',16653,20693);
INSERT INTO "django_geo_db_zipcode" VALUES(23444,52774,-6,'Welton, Iowa 52774',16654,20694);
INSERT INTO "django_geo_db_zipcode" VALUES(23445,52776,-6,'West Liberty, Iowa 52776',16655,20695);
INSERT INTO "django_geo_db_zipcode" VALUES(23446,52777,-6,'Wheatland, Iowa 52777',16656,20696);
INSERT INTO "django_geo_db_zipcode" VALUES(23447,52778,-6,'Wilton, Iowa 52778',16657,20697);
INSERT INTO "django_geo_db_zipcode" VALUES(23448,52801,-6,'Davenport, Iowa 52801',16658,20698);
INSERT INTO "django_geo_db_zipcode" VALUES(23449,52802,-6,'Davenport, Iowa 52802',16658,20699);
INSERT INTO "django_geo_db_zipcode" VALUES(23450,52803,-6,'Davenport, Iowa 52803',16658,20700);
INSERT INTO "django_geo_db_zipcode" VALUES(23451,52804,-6,'Davenport, Iowa 52804',16658,20701);
INSERT INTO "django_geo_db_zipcode" VALUES(23452,52805,-6,'Davenport, Iowa 52805',16658,20702);
INSERT INTO "django_geo_db_zipcode" VALUES(23453,52806,-6,'Davenport, Iowa 52806',16658,20703);
INSERT INTO "django_geo_db_zipcode" VALUES(23454,52807,-6,'Davenport, Iowa 52807',16658,20704);
INSERT INTO "django_geo_db_zipcode" VALUES(23455,52808,-6,'Davenport, Iowa 52808',16658,20702);
INSERT INTO "django_geo_db_zipcode" VALUES(23456,52809,-6,'Davenport, Iowa 52809',16658,20702);
INSERT INTO "django_geo_db_zipcode" VALUES(23457,52820,-6,'Tennyson, Wisconsin 52820',16659,20705);
INSERT INTO "django_geo_db_zipcode" VALUES(23458,53001,-6,'Adell, Wisconsin 53001',16660,20706);
INSERT INTO "django_geo_db_zipcode" VALUES(23459,53002,-6,'Allenton, Wisconsin 53002',16661,20707);
INSERT INTO "django_geo_db_zipcode" VALUES(23460,53003,-6,'Ashippun, Wisconsin 53003',16662,20708);
INSERT INTO "django_geo_db_zipcode" VALUES(23461,53004,-6,'Belgium, Wisconsin 53004',16663,20709);
INSERT INTO "django_geo_db_zipcode" VALUES(23462,53005,-6,'Brookfield, Wisconsin 53005',16664,20710);
INSERT INTO "django_geo_db_zipcode" VALUES(23463,53006,-6,'Brownsville, Wisconsin 53006',16665,20711);
INSERT INTO "django_geo_db_zipcode" VALUES(23464,53007,-6,'Butler, Wisconsin 53007',16666,20712);
INSERT INTO "django_geo_db_zipcode" VALUES(23465,53008,-6,'Brookfield, Wisconsin 53008',16664,20713);
INSERT INTO "django_geo_db_zipcode" VALUES(23466,53009,-6,'Byron, Wisconsin 53009',16667,20714);
INSERT INTO "django_geo_db_zipcode" VALUES(23467,53010,-6,'Campbellsport, Wisconsin 53010',16668,20715);
INSERT INTO "django_geo_db_zipcode" VALUES(23468,53011,-6,'Cascade, Wisconsin 53011',16669,20716);
INSERT INTO "django_geo_db_zipcode" VALUES(23469,53012,-6,'Cedarburg, Wisconsin 53012',16670,20717);
INSERT INTO "django_geo_db_zipcode" VALUES(23470,53013,-6,'Cedar Grove, Wisconsin 53013',16671,20718);
INSERT INTO "django_geo_db_zipcode" VALUES(23471,53014,-6,'Chilton, Wisconsin 53014',16672,20719);
INSERT INTO "django_geo_db_zipcode" VALUES(23472,53015,-6,'Cleveland, Wisconsin 53015',16673,20720);
INSERT INTO "django_geo_db_zipcode" VALUES(23473,53016,-6,'Clyman, Wisconsin 53016',16674,20721);
INSERT INTO "django_geo_db_zipcode" VALUES(23474,53017,-6,'Colgate, Wisconsin 53017',16675,20722);
INSERT INTO "django_geo_db_zipcode" VALUES(23475,53018,-6,'Delafield, Wisconsin 53018',16676,20723);
INSERT INTO "django_geo_db_zipcode" VALUES(23476,53019,-6,'Eden, Wisconsin 53019',16677,20724);
INSERT INTO "django_geo_db_zipcode" VALUES(23477,53020,-6,'Elkhart Lake, Wisconsin 53020',16678,20725);
INSERT INTO "django_geo_db_zipcode" VALUES(23478,53021,-6,'Fredonia, Wisconsin 53021',16679,20726);
INSERT INTO "django_geo_db_zipcode" VALUES(23479,53022,-6,'Germantown, Wisconsin 53022',16680,20727);
INSERT INTO "django_geo_db_zipcode" VALUES(23480,53023,-6,'Glenbeulah, Wisconsin 53023',16681,20728);
INSERT INTO "django_geo_db_zipcode" VALUES(23481,53024,-6,'Grafton, Wisconsin 53024',16682,20729);
INSERT INTO "django_geo_db_zipcode" VALUES(23482,53026,-6,'Greenbush, Wisconsin 53026',16683,20730);
INSERT INTO "django_geo_db_zipcode" VALUES(23483,53027,-6,'Hartford, Wisconsin 53027',16684,20731);
INSERT INTO "django_geo_db_zipcode" VALUES(23484,53029,-6,'Hartland, Wisconsin 53029',16685,20732);
INSERT INTO "django_geo_db_zipcode" VALUES(23485,53031,-6,'Hingham, Wisconsin 53031',16686,20733);
INSERT INTO "django_geo_db_zipcode" VALUES(23486,53032,-6,'Horicon, Wisconsin 53032',16687,20734);
INSERT INTO "django_geo_db_zipcode" VALUES(23487,53033,-6,'Hubertus, Wisconsin 53033',16688,20735);
INSERT INTO "django_geo_db_zipcode" VALUES(23488,53034,-6,'Hustisford, Wisconsin 53034',16689,20736);
INSERT INTO "django_geo_db_zipcode" VALUES(23489,53035,-6,'Iron Ridge, Wisconsin 53035',16690,20737);
INSERT INTO "django_geo_db_zipcode" VALUES(23490,53036,-6,'Ixonia, Wisconsin 53036',16691,20738);
INSERT INTO "django_geo_db_zipcode" VALUES(23491,53037,-6,'Jackson, Wisconsin 53037',16692,20739);
INSERT INTO "django_geo_db_zipcode" VALUES(23492,53038,-6,'Johnson Creek, Wisconsin 53038',16693,20740);
INSERT INTO "django_geo_db_zipcode" VALUES(23493,53039,-6,'Juneau, Wisconsin 53039',16694,20741);
INSERT INTO "django_geo_db_zipcode" VALUES(23494,53040,-6,'Kewaskum, Wisconsin 53040',16695,20742);
INSERT INTO "django_geo_db_zipcode" VALUES(23495,53042,-6,'Kiel, Wisconsin 53042',16696,20743);
INSERT INTO "django_geo_db_zipcode" VALUES(23496,53044,-6,'Kohler, Wisconsin 53044',16697,20744);
INSERT INTO "django_geo_db_zipcode" VALUES(23497,53045,-6,'Brookfield, Wisconsin 53045',16664,20745);
INSERT INTO "django_geo_db_zipcode" VALUES(23498,53046,-6,'Lannon, Wisconsin 53046',16698,20746);
INSERT INTO "django_geo_db_zipcode" VALUES(23499,53047,-6,'Lebanon, Wisconsin 53047',16699,20747);
INSERT INTO "django_geo_db_zipcode" VALUES(23500,53048,-6,'Lomira, Wisconsin 53048',16700,20748);
INSERT INTO "django_geo_db_zipcode" VALUES(23501,53049,-6,'Malone, Wisconsin 53049',16701,20749);
INSERT INTO "django_geo_db_zipcode" VALUES(23502,53050,-6,'Mayville, Wisconsin 53050',16702,20750);
INSERT INTO "django_geo_db_zipcode" VALUES(23503,53051,-6,'Menomonee Falls, Wisconsin 53051',16703,20751);
INSERT INTO "django_geo_db_zipcode" VALUES(23504,53052,-6,'Menomonee Falls, Wisconsin 53052',16703,20713);
INSERT INTO "django_geo_db_zipcode" VALUES(23505,53056,-6,'Merton, Wisconsin 53056',16704,20752);
INSERT INTO "django_geo_db_zipcode" VALUES(23506,53057,-6,'Mount Calvary, Wisconsin 53057',16705,20753);
INSERT INTO "django_geo_db_zipcode" VALUES(23507,53058,-6,'Nashotah, Wisconsin 53058',16706,20754);
INSERT INTO "django_geo_db_zipcode" VALUES(23508,53059,-6,'Neosho, Wisconsin 53059',16707,20755);
INSERT INTO "django_geo_db_zipcode" VALUES(23509,53060,-6,'Newburg, Wisconsin 53060',16708,20756);
INSERT INTO "django_geo_db_zipcode" VALUES(23510,53061,-6,'New Holstein, Wisconsin 53061',16709,20757);
INSERT INTO "django_geo_db_zipcode" VALUES(23511,53062,-6,'New Holstein, Wisconsin 53062',16709,20758);
INSERT INTO "django_geo_db_zipcode" VALUES(23512,53063,-6,'Newton, Wisconsin 53063',16710,20759);
INSERT INTO "django_geo_db_zipcode" VALUES(23513,53064,-6,'North Lake, Wisconsin 53064',16711,20713);
INSERT INTO "django_geo_db_zipcode" VALUES(23514,53065,-6,'Oakfield, Wisconsin 53065',16712,20760);
INSERT INTO "django_geo_db_zipcode" VALUES(23515,53066,-6,'Oconomowoc, Wisconsin 53066',16713,20761);
INSERT INTO "django_geo_db_zipcode" VALUES(23516,53069,-6,'Okauchee, Wisconsin 53069',16714,20762);
INSERT INTO "django_geo_db_zipcode" VALUES(23517,53070,-6,'Oostburg, Wisconsin 53070',16715,20763);
INSERT INTO "django_geo_db_zipcode" VALUES(23518,53072,-6,'Pewaukee, Wisconsin 53072',16716,20764);
INSERT INTO "django_geo_db_zipcode" VALUES(23519,53073,-6,'Plymouth, Wisconsin 53073',16717,20765);
INSERT INTO "django_geo_db_zipcode" VALUES(23520,53074,-6,'Port Washington, Wisconsin 53074',16718,20766);
INSERT INTO "django_geo_db_zipcode" VALUES(23521,53075,-6,'Random Lake, Wisconsin 53075',16719,20767);
INSERT INTO "django_geo_db_zipcode" VALUES(23522,53076,-6,'Richfield, Wisconsin 53076',16720,20768);
INSERT INTO "django_geo_db_zipcode" VALUES(23523,53078,-6,'Rubicon, Wisconsin 53078',16721,20769);
INSERT INTO "django_geo_db_zipcode" VALUES(23524,53079,-6,'Saint Cloud, Wisconsin 53079',16722,20770);
INSERT INTO "django_geo_db_zipcode" VALUES(23525,53080,-6,'Saukville, Wisconsin 53080',16723,20771);
INSERT INTO "django_geo_db_zipcode" VALUES(23526,53081,-6,'Sheboygan, Wisconsin 53081',16724,20772);
INSERT INTO "django_geo_db_zipcode" VALUES(23527,53082,-6,'Sheboygan, Wisconsin 53082',16724,20730);
INSERT INTO "django_geo_db_zipcode" VALUES(23528,53083,-6,'Sheboygan, Wisconsin 53083',16724,20773);
INSERT INTO "django_geo_db_zipcode" VALUES(23529,53085,-6,'Sheboygan Falls, Wisconsin 53085',16725,20774);
INSERT INTO "django_geo_db_zipcode" VALUES(23530,53086,-6,'Slinger, Wisconsin 53086',16726,20775);
INSERT INTO "django_geo_db_zipcode" VALUES(23531,53088,-6,'Stockbridge, Wisconsin 53088',16727,20776);
INSERT INTO "django_geo_db_zipcode" VALUES(23532,53089,-6,'Sussex, Wisconsin 53089',16728,20777);
INSERT INTO "django_geo_db_zipcode" VALUES(23533,53090,-6,'West Bend, Wisconsin 53090',16729,20778);
INSERT INTO "django_geo_db_zipcode" VALUES(23534,53091,-6,'Theresa, Wisconsin 53091',16730,20779);
INSERT INTO "django_geo_db_zipcode" VALUES(23535,53092,-6,'Thiensville, Wisconsin 53092',16731,20780);
INSERT INTO "django_geo_db_zipcode" VALUES(23536,53093,-6,'Waldo, Wisconsin 53093',16732,20781);
INSERT INTO "django_geo_db_zipcode" VALUES(23537,53094,-6,'Watertown, Wisconsin 53094',16733,20782);
INSERT INTO "django_geo_db_zipcode" VALUES(23538,53095,-6,'West Bend, Wisconsin 53095',16729,20783);
INSERT INTO "django_geo_db_zipcode" VALUES(23539,53097,-6,'Mequon, Wisconsin 53097',16734,20784);
INSERT INTO "django_geo_db_zipcode" VALUES(23540,53098,-6,'Watertown, Wisconsin 53098',16733,20785);
INSERT INTO "django_geo_db_zipcode" VALUES(23541,53099,-6,'Woodland, Wisconsin 53099',16735,20786);
INSERT INTO "django_geo_db_zipcode" VALUES(23542,53101,-6,'Bassett, Wisconsin 53101',16736,20787);
INSERT INTO "django_geo_db_zipcode" VALUES(23543,53102,-6,'Benet Lake, Wisconsin 53102',16737,20788);
INSERT INTO "django_geo_db_zipcode" VALUES(23544,53103,-6,'Big Bend, Wisconsin 53103',16738,20789);
INSERT INTO "django_geo_db_zipcode" VALUES(23545,53104,-6,'Bristol, Wisconsin 53104',16739,20790);
INSERT INTO "django_geo_db_zipcode" VALUES(23546,53105,-6,'Burlington, Wisconsin 53105',16740,20791);
INSERT INTO "django_geo_db_zipcode" VALUES(23547,53108,-6,'Caledonia, Wisconsin 53108',16741,20792);
INSERT INTO "django_geo_db_zipcode" VALUES(23548,53109,-6,'Camp Lake, Wisconsin 53109',16742,20793);
INSERT INTO "django_geo_db_zipcode" VALUES(23549,53110,-6,'Cudahy, Wisconsin 53110',16743,20794);
INSERT INTO "django_geo_db_zipcode" VALUES(23550,53114,-6,'Darien, Wisconsin 53114',16744,20795);
INSERT INTO "django_geo_db_zipcode" VALUES(23551,53115,-6,'Delavan, Wisconsin 53115',16745,20796);
INSERT INTO "django_geo_db_zipcode" VALUES(23552,53118,-6,'Dousman, Wisconsin 53118',16746,20797);
INSERT INTO "django_geo_db_zipcode" VALUES(23553,53119,-6,'Eagle, Wisconsin 53119',16747,20798);
INSERT INTO "django_geo_db_zipcode" VALUES(23554,53120,-6,'East Troy, Wisconsin 53120',16748,20799);
INSERT INTO "django_geo_db_zipcode" VALUES(23555,53121,-6,'Elkhorn, Wisconsin 53121',16749,20800);
INSERT INTO "django_geo_db_zipcode" VALUES(23556,53122,-6,'Elm Grove, Wisconsin 53122',16750,20801);
INSERT INTO "django_geo_db_zipcode" VALUES(23557,53125,-6,'Fontana, Wisconsin 53125',16751,20802);
INSERT INTO "django_geo_db_zipcode" VALUES(23558,53126,-6,'Franksville, Wisconsin 53126',16752,20803);
INSERT INTO "django_geo_db_zipcode" VALUES(23559,53127,-6,'Genesee Depot, Wisconsin 53127',16753,20804);
INSERT INTO "django_geo_db_zipcode" VALUES(23560,53128,-6,'Genoa City, Wisconsin 53128',16754,20805);
INSERT INTO "django_geo_db_zipcode" VALUES(23561,53129,-6,'Greendale, Wisconsin 53129',16755,20806);
INSERT INTO "django_geo_db_zipcode" VALUES(23562,53130,-6,'Hales Corners, Wisconsin 53130',16756,20807);
INSERT INTO "django_geo_db_zipcode" VALUES(23563,53132,-6,'Franklin, Wisconsin 53132',16757,20808);
INSERT INTO "django_geo_db_zipcode" VALUES(23564,53134,-6,'Walworth, Wisconsin 53134',16758,20809);
INSERT INTO "django_geo_db_zipcode" VALUES(23565,53137,-6,'Helenville, Wisconsin 53137',16759,20810);
INSERT INTO "django_geo_db_zipcode" VALUES(23566,53138,-6,'Honey Creek, Wisconsin 53138',16760,20811);
INSERT INTO "django_geo_db_zipcode" VALUES(23567,53139,-6,'Kansasville, Wisconsin 53139',16761,20812);
INSERT INTO "django_geo_db_zipcode" VALUES(23568,53140,-6,'Kenosha, Wisconsin 53140',16762,20813);
INSERT INTO "django_geo_db_zipcode" VALUES(23569,53141,-6,'Kenosha, Wisconsin 53141',16762,20787);
INSERT INTO "django_geo_db_zipcode" VALUES(23570,53142,-6,'Kenosha, Wisconsin 53142',16762,20814);
INSERT INTO "django_geo_db_zipcode" VALUES(23571,53143,-6,'Kenosha, Wisconsin 53143',16762,20815);
INSERT INTO "django_geo_db_zipcode" VALUES(23572,53144,-6,'Kenosha, Wisconsin 53144',16762,20816);
INSERT INTO "django_geo_db_zipcode" VALUES(23573,53146,-6,'New Berlin, Wisconsin 53146',16763,20817);
INSERT INTO "django_geo_db_zipcode" VALUES(23574,53147,-6,'Lake Geneva, Wisconsin 53147',16764,20818);
INSERT INTO "django_geo_db_zipcode" VALUES(23575,53148,-6,'Lyons, Wisconsin 53148',16765,20819);
INSERT INTO "django_geo_db_zipcode" VALUES(23576,53149,-6,'Mukwonago, Wisconsin 53149',16766,20820);
INSERT INTO "django_geo_db_zipcode" VALUES(23577,53150,-6,'Muskego, Wisconsin 53150',16767,20821);
INSERT INTO "django_geo_db_zipcode" VALUES(23578,53151,-6,'New Berlin, Wisconsin 53151',16763,20822);
INSERT INTO "django_geo_db_zipcode" VALUES(23579,53152,-6,'New Munster, Wisconsin 53152',16768,20823);
INSERT INTO "django_geo_db_zipcode" VALUES(23580,53153,-6,'North Prairie, Wisconsin 53153',16769,20824);
INSERT INTO "django_geo_db_zipcode" VALUES(23581,53154,-6,'Oak Creek, Wisconsin 53154',16770,20825);
INSERT INTO "django_geo_db_zipcode" VALUES(23582,53156,-6,'Palmyra, Wisconsin 53156',16771,20826);
INSERT INTO "django_geo_db_zipcode" VALUES(23583,53157,-6,'Pell Lake, Wisconsin 53157',16772,20827);
INSERT INTO "django_geo_db_zipcode" VALUES(23584,53158,-6,'Pleasant Prairie, Wisconsin 53158',16773,20828);
INSERT INTO "django_geo_db_zipcode" VALUES(23585,53159,-6,'Powers Lake, Wisconsin 53159',16774,20829);
INSERT INTO "django_geo_db_zipcode" VALUES(23586,53167,-6,'Rochester, Wisconsin 53167',16775,20830);
INSERT INTO "django_geo_db_zipcode" VALUES(23587,53168,-6,'Salem, Wisconsin 53168',16776,20831);
INSERT INTO "django_geo_db_zipcode" VALUES(23588,53170,-6,'Silver Lake, Wisconsin 53170',16777,20832);
INSERT INTO "django_geo_db_zipcode" VALUES(23589,53171,-6,'Somers, Wisconsin 53171',16778,20833);
INSERT INTO "django_geo_db_zipcode" VALUES(23590,53172,-6,'South Milwaukee, Wisconsin 53172',16779,20834);
INSERT INTO "django_geo_db_zipcode" VALUES(23591,53176,-6,'Springfield, Wisconsin 53176',16780,20835);
INSERT INTO "django_geo_db_zipcode" VALUES(23592,53177,-6,'Sturtevant, Wisconsin 53177',16781,20836);
INSERT INTO "django_geo_db_zipcode" VALUES(23593,53178,-6,'Sullivan, Wisconsin 53178',16782,20837);
INSERT INTO "django_geo_db_zipcode" VALUES(23594,53179,-6,'Trevor, Wisconsin 53179',16783,20838);
INSERT INTO "django_geo_db_zipcode" VALUES(23595,53181,-6,'Twin Lakes, Wisconsin 53181',16784,20839);
INSERT INTO "django_geo_db_zipcode" VALUES(23596,53182,-6,'Union Grove, Wisconsin 53182',16785,20840);
INSERT INTO "django_geo_db_zipcode" VALUES(23597,53183,-6,'Wales, Wisconsin 53183',16786,20841);
INSERT INTO "django_geo_db_zipcode" VALUES(23598,53184,-6,'Walworth, Wisconsin 53184',16758,20842);
INSERT INTO "django_geo_db_zipcode" VALUES(23599,53185,-6,'Waterford, Wisconsin 53185',16787,20843);
INSERT INTO "django_geo_db_zipcode" VALUES(23600,53186,-6,'Waukesha, Wisconsin 53186',16788,20844);
INSERT INTO "django_geo_db_zipcode" VALUES(23601,53187,-6,'Waukesha, Wisconsin 53187',16788,20713);
INSERT INTO "django_geo_db_zipcode" VALUES(23602,53188,-6,'Waukesha, Wisconsin 53188',16788,20845);
INSERT INTO "django_geo_db_zipcode" VALUES(23603,53189,-6,'Waukesha, Wisconsin 53189',16788,20846);
INSERT INTO "django_geo_db_zipcode" VALUES(23604,53190,-6,'Whitewater, Wisconsin 53190',16789,20847);
INSERT INTO "django_geo_db_zipcode" VALUES(23605,53191,-6,'Williams Bay, Wisconsin 53191',16790,20848);
INSERT INTO "django_geo_db_zipcode" VALUES(23606,53192,-6,'Wilmot, Wisconsin 53192',16791,20849);
INSERT INTO "django_geo_db_zipcode" VALUES(23607,53194,-6,'Woodworth, Wisconsin 53194',16792,20787);
INSERT INTO "django_geo_db_zipcode" VALUES(23608,53195,-6,'Zenda, Wisconsin 53195',16793,20850);
INSERT INTO "django_geo_db_zipcode" VALUES(23609,53197,-6,'Walworth, Wisconsin 53197',16758,20851);
INSERT INTO "django_geo_db_zipcode" VALUES(23610,53201,-6,'Milwaukee, Wisconsin 53201',16794,20852);
INSERT INTO "django_geo_db_zipcode" VALUES(23611,53202,-6,'Milwaukee, Wisconsin 53202',16794,20853);
INSERT INTO "django_geo_db_zipcode" VALUES(23612,53203,-6,'Milwaukee, Wisconsin 53203',16794,20854);
INSERT INTO "django_geo_db_zipcode" VALUES(23613,53204,-6,'Milwaukee, Wisconsin 53204',16794,20855);
INSERT INTO "django_geo_db_zipcode" VALUES(23614,53205,-6,'Milwaukee, Wisconsin 53205',16794,20856);
INSERT INTO "django_geo_db_zipcode" VALUES(23615,53206,-6,'Milwaukee, Wisconsin 53206',16794,20857);
INSERT INTO "django_geo_db_zipcode" VALUES(23616,53207,-6,'Milwaukee, Wisconsin 53207',16794,20858);
INSERT INTO "django_geo_db_zipcode" VALUES(23617,53208,-6,'Milwaukee, Wisconsin 53208',16794,20859);
INSERT INTO "django_geo_db_zipcode" VALUES(23618,53209,-6,'Milwaukee, Wisconsin 53209',16794,20860);
INSERT INTO "django_geo_db_zipcode" VALUES(23619,53210,-6,'Milwaukee, Wisconsin 53210',16794,20861);
INSERT INTO "django_geo_db_zipcode" VALUES(23620,53211,-6,'Milwaukee, Wisconsin 53211',16794,20862);
INSERT INTO "django_geo_db_zipcode" VALUES(23621,53212,-6,'Milwaukee, Wisconsin 53212',16794,20863);
INSERT INTO "django_geo_db_zipcode" VALUES(23622,53213,-6,'Milwaukee, Wisconsin 53213',16794,20864);
INSERT INTO "django_geo_db_zipcode" VALUES(23623,53214,-6,'Milwaukee, Wisconsin 53214',16794,20865);
INSERT INTO "django_geo_db_zipcode" VALUES(23624,53215,-6,'Milwaukee, Wisconsin 53215',16794,20866);
INSERT INTO "django_geo_db_zipcode" VALUES(23625,53216,-6,'Milwaukee, Wisconsin 53216',16794,20867);
INSERT INTO "django_geo_db_zipcode" VALUES(23626,53217,-6,'Milwaukee, Wisconsin 53217',16794,20868);
INSERT INTO "django_geo_db_zipcode" VALUES(23627,53218,-6,'Milwaukee, Wisconsin 53218',16794,20869);
INSERT INTO "django_geo_db_zipcode" VALUES(23628,53219,-6,'Milwaukee, Wisconsin 53219',16794,20870);
INSERT INTO "django_geo_db_zipcode" VALUES(23629,53220,-6,'Milwaukee, Wisconsin 53220',16794,20871);
INSERT INTO "django_geo_db_zipcode" VALUES(23630,53221,-6,'Milwaukee, Wisconsin 53221',16794,20872);
INSERT INTO "django_geo_db_zipcode" VALUES(23631,53222,-6,'Milwaukee, Wisconsin 53222',16794,20873);
INSERT INTO "django_geo_db_zipcode" VALUES(23632,53223,-6,'Milwaukee, Wisconsin 53223',16794,20874);
INSERT INTO "django_geo_db_zipcode" VALUES(23633,53224,-6,'Milwaukee, Wisconsin 53224',16794,20875);
INSERT INTO "django_geo_db_zipcode" VALUES(23634,53225,-6,'Milwaukee, Wisconsin 53225',16794,20876);
INSERT INTO "django_geo_db_zipcode" VALUES(23635,53226,-6,'Milwaukee, Wisconsin 53226',16794,20877);
INSERT INTO "django_geo_db_zipcode" VALUES(23636,53227,-6,'Milwaukee, Wisconsin 53227',16794,20878);
INSERT INTO "django_geo_db_zipcode" VALUES(23637,53228,-6,'Milwaukee, Wisconsin 53228',16794,20879);
INSERT INTO "django_geo_db_zipcode" VALUES(23638,53233,-6,'Milwaukee, Wisconsin 53233',16794,20880);
INSERT INTO "django_geo_db_zipcode" VALUES(23639,53234,-6,'Milwaukee, Wisconsin 53234',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23640,53235,-6,'Saint Francis, Wisconsin 53235',16795,20882);
INSERT INTO "django_geo_db_zipcode" VALUES(23641,53237,-6,'Milwaukee, Wisconsin 53237',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23642,53245,-6,'Eaton, Wisconsin 53245',16796,20883);
INSERT INTO "django_geo_db_zipcode" VALUES(23643,53259,-6,'Milwaukee, Wisconsin 53259',16794,20884);
INSERT INTO "django_geo_db_zipcode" VALUES(23644,53263,-6,'Milwaukee, Wisconsin 53263',16794,20885);
INSERT INTO "django_geo_db_zipcode" VALUES(23645,53267,-6,'Milwaukee, Wisconsin 53267',16794,20886);
INSERT INTO "django_geo_db_zipcode" VALUES(23646,53268,-6,'Milwaukee, Wisconsin 53268',16794,20887);
INSERT INTO "django_geo_db_zipcode" VALUES(23647,53270,-6,'Milwaukee, Wisconsin 53270',16794,20888);
INSERT INTO "django_geo_db_zipcode" VALUES(23648,53274,-6,'Milwaukee, Wisconsin 53274',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23649,53277,-6,'Milwaukee, Wisconsin 53277',16794,20889);
INSERT INTO "django_geo_db_zipcode" VALUES(23650,53278,-6,'Milwaukee, Wisconsin 53278',16794,20889);
INSERT INTO "django_geo_db_zipcode" VALUES(23651,53280,-6,'Milwaukee, Wisconsin 53280',16794,20890);
INSERT INTO "django_geo_db_zipcode" VALUES(23652,53281,-6,'Milwaukee, Wisconsin 53281',16794,20890);
INSERT INTO "django_geo_db_zipcode" VALUES(23653,53284,-6,'Milwaukee, Wisconsin 53284',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23654,53285,-6,'Milwaukee, Wisconsin 53285',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23655,53288,-6,'Milwaukee, Wisconsin 53288',16794,20891);
INSERT INTO "django_geo_db_zipcode" VALUES(23656,53290,-6,'Milwaukee, Wisconsin 53290',16794,20892);
INSERT INTO "django_geo_db_zipcode" VALUES(23657,53293,-6,'Milwaukee, Wisconsin 53293',16794,20893);
INSERT INTO "django_geo_db_zipcode" VALUES(23658,53295,-6,'Milwaukee, Wisconsin 53295',16794,20881);
INSERT INTO "django_geo_db_zipcode" VALUES(23659,53401,-6,'Racine, Wisconsin 53401',16797,20894);
INSERT INTO "django_geo_db_zipcode" VALUES(23660,53402,-6,'Racine, Wisconsin 53402',16797,20895);
INSERT INTO "django_geo_db_zipcode" VALUES(23661,53403,-6,'Racine, Wisconsin 53403',16797,20896);
INSERT INTO "django_geo_db_zipcode" VALUES(23662,53404,-6,'Racine, Wisconsin 53404',16797,20897);
INSERT INTO "django_geo_db_zipcode" VALUES(23663,53405,-6,'Racine, Wisconsin 53405',16797,20898);
INSERT INTO "django_geo_db_zipcode" VALUES(23664,53406,-6,'Racine, Wisconsin 53406',16797,20899);
INSERT INTO "django_geo_db_zipcode" VALUES(23665,53407,-6,'Racine, Wisconsin 53407',16797,20900);
INSERT INTO "django_geo_db_zipcode" VALUES(23666,53408,-6,'Racine, Wisconsin 53408',16797,20894);
INSERT INTO "django_geo_db_zipcode" VALUES(23667,53449,-6,'Jefferson, Wisconsin 53449',16798,20901);
INSERT INTO "django_geo_db_zipcode" VALUES(23668,53490,-6,'Racine, Wisconsin 53490',16797,20894);
INSERT INTO "django_geo_db_zipcode" VALUES(23669,53501,-6,'Afton, Wisconsin 53501',16799,20902);
INSERT INTO "django_geo_db_zipcode" VALUES(23670,53502,-6,'Albany, Wisconsin 53502',16800,20903);
INSERT INTO "django_geo_db_zipcode" VALUES(23671,53503,-6,'Arena, Wisconsin 53503',16801,20904);
INSERT INTO "django_geo_db_zipcode" VALUES(23672,53504,-6,'Argyle, Wisconsin 53504',16802,20905);
INSERT INTO "django_geo_db_zipcode" VALUES(23673,53505,-6,'Avalon, Wisconsin 53505',16803,20906);
INSERT INTO "django_geo_db_zipcode" VALUES(23674,53506,-6,'Avoca, Wisconsin 53506',16804,20907);
INSERT INTO "django_geo_db_zipcode" VALUES(23675,53507,-6,'Barneveld, Wisconsin 53507',16805,20908);
INSERT INTO "django_geo_db_zipcode" VALUES(23676,53508,-6,'Belleville, Wisconsin 53508',16806,20909);
INSERT INTO "django_geo_db_zipcode" VALUES(23677,53510,-6,'Belmont, Wisconsin 53510',16807,20910);
INSERT INTO "django_geo_db_zipcode" VALUES(23678,53511,-6,'Beloit, Wisconsin 53511',16808,20911);
INSERT INTO "django_geo_db_zipcode" VALUES(23679,53512,-6,'Beloit, Wisconsin 53512',16808,20912);
INSERT INTO "django_geo_db_zipcode" VALUES(23680,53515,-6,'Black Earth, Wisconsin 53515',16809,20913);
INSERT INTO "django_geo_db_zipcode" VALUES(23681,53516,-6,'Blanchardville, Wisconsin 53516',16810,20914);
INSERT INTO "django_geo_db_zipcode" VALUES(23682,53517,-6,'Blue Mounds, Wisconsin 53517',16811,20915);
INSERT INTO "django_geo_db_zipcode" VALUES(23683,53518,-6,'Blue River, Wisconsin 53518',16812,20916);
INSERT INTO "django_geo_db_zipcode" VALUES(23684,53520,-6,'Brodhead, Wisconsin 53520',16813,20917);
INSERT INTO "django_geo_db_zipcode" VALUES(23685,53521,-6,'Brooklyn, Wisconsin 53521',16814,20918);
INSERT INTO "django_geo_db_zipcode" VALUES(23686,53522,-6,'Browntown, Wisconsin 53522',16815,20919);
INSERT INTO "django_geo_db_zipcode" VALUES(23687,53523,-6,'Cambridge, Wisconsin 53523',16816,20920);
INSERT INTO "django_geo_db_zipcode" VALUES(23688,53525,-6,'Clinton, Wisconsin 53525',16817,20921);
INSERT INTO "django_geo_db_zipcode" VALUES(23689,53526,-6,'Cobb, Wisconsin 53526',16818,20922);
INSERT INTO "django_geo_db_zipcode" VALUES(23690,53527,-6,'Cottage Grove, Wisconsin 53527',16819,20923);
INSERT INTO "django_geo_db_zipcode" VALUES(23691,53528,-6,'Cross Plains, Wisconsin 53528',16820,20924);
INSERT INTO "django_geo_db_zipcode" VALUES(23692,53529,-6,'Dane, Wisconsin 53529',16821,20925);
INSERT INTO "django_geo_db_zipcode" VALUES(23693,53530,-6,'Darlington, Wisconsin 53530',16822,20926);
INSERT INTO "django_geo_db_zipcode" VALUES(23694,53531,-6,'Deerfield, Wisconsin 53531',16823,20927);
INSERT INTO "django_geo_db_zipcode" VALUES(23695,53532,-6,'De Forest, Wisconsin 53532',16824,20928);
INSERT INTO "django_geo_db_zipcode" VALUES(23696,53533,-6,'Dodgeville, Wisconsin 53533',16825,20929);
INSERT INTO "django_geo_db_zipcode" VALUES(23697,53534,-6,'Edgerton, Wisconsin 53534',16826,20930);
INSERT INTO "django_geo_db_zipcode" VALUES(23698,53535,-6,'Edmund, Wisconsin 53535',16827,20931);
INSERT INTO "django_geo_db_zipcode" VALUES(23699,53536,-6,'Evansville, Wisconsin 53536',16828,20932);
INSERT INTO "django_geo_db_zipcode" VALUES(23700,53537,-6,'Footville, Wisconsin 53537',16829,20933);
INSERT INTO "django_geo_db_zipcode" VALUES(23701,53538,-6,'Fort Atkinson, Wisconsin 53538',16830,20934);
INSERT INTO "django_geo_db_zipcode" VALUES(23702,53540,-6,'Gotham, Wisconsin 53540',16831,20935);
INSERT INTO "django_geo_db_zipcode" VALUES(23703,53541,-6,'Gratiot, Wisconsin 53541',16832,20936);
INSERT INTO "django_geo_db_zipcode" VALUES(23704,53542,-6,'Hanover, Wisconsin 53542',16833,20937);
INSERT INTO "django_geo_db_zipcode" VALUES(23705,53543,-6,'Highland, Wisconsin 53543',16834,20938);
INSERT INTO "django_geo_db_zipcode" VALUES(23706,53544,-6,'Hollandale, Wisconsin 53544',16835,20939);
INSERT INTO "django_geo_db_zipcode" VALUES(23707,53545,-6,'Janesville, Wisconsin 53545',16836,20940);
INSERT INTO "django_geo_db_zipcode" VALUES(23708,53546,-6,'Janesville, Wisconsin 53546',16836,20941);
INSERT INTO "django_geo_db_zipcode" VALUES(23709,53547,-6,'Janesville, Wisconsin 53547',16836,20942);
INSERT INTO "django_geo_db_zipcode" VALUES(23710,53549,-6,'Jefferson, Wisconsin 53549',16798,20943);
INSERT INTO "django_geo_db_zipcode" VALUES(23711,53550,-6,'Juda, Wisconsin 53550',16837,20944);
INSERT INTO "django_geo_db_zipcode" VALUES(23712,53551,-6,'Lake Mills, Wisconsin 53551',16838,20945);
INSERT INTO "django_geo_db_zipcode" VALUES(23713,53553,-6,'Linden, Wisconsin 53553',16839,20946);
INSERT INTO "django_geo_db_zipcode" VALUES(23714,53554,-6,'Livingston, Wisconsin 53554',16840,20947);
INSERT INTO "django_geo_db_zipcode" VALUES(23715,53555,-6,'Lodi, Wisconsin 53555',16841,20948);
INSERT INTO "django_geo_db_zipcode" VALUES(23716,53556,-6,'Lone Rock, Wisconsin 53556',16842,20949);
INSERT INTO "django_geo_db_zipcode" VALUES(23717,53557,-6,'Lowell, Wisconsin 53557',16843,20950);
INSERT INTO "django_geo_db_zipcode" VALUES(23718,53558,-6,'McFarland, Wisconsin 53558',16844,20951);
INSERT INTO "django_geo_db_zipcode" VALUES(23719,53559,-6,'Marshall, Wisconsin 53559',16845,20952);
INSERT INTO "django_geo_db_zipcode" VALUES(23720,53560,-6,'Mazomanie, Wisconsin 53560',16846,20953);
INSERT INTO "django_geo_db_zipcode" VALUES(23721,53561,-6,'Merrimac, Wisconsin 53561',16847,20954);
INSERT INTO "django_geo_db_zipcode" VALUES(23722,53562,-6,'Middleton, Wisconsin 53562',16848,20955);
INSERT INTO "django_geo_db_zipcode" VALUES(23723,53563,-6,'Milton, Wisconsin 53563',16849,20956);
INSERT INTO "django_geo_db_zipcode" VALUES(23724,53565,-6,'Mineral Point, Wisconsin 53565',16850,20957);
INSERT INTO "django_geo_db_zipcode" VALUES(23725,53566,-6,'Monroe, Wisconsin 53566',16851,20958);
INSERT INTO "django_geo_db_zipcode" VALUES(23726,53569,-6,'Montfort, Wisconsin 53569',16852,20959);
INSERT INTO "django_geo_db_zipcode" VALUES(23727,53570,-6,'Monticello, Wisconsin 53570',16853,20960);
INSERT INTO "django_geo_db_zipcode" VALUES(23728,53571,-6,'Morrisonville, Wisconsin 53571',16854,20961);
INSERT INTO "django_geo_db_zipcode" VALUES(23729,53572,-6,'Mount Horeb, Wisconsin 53572',16855,20962);
INSERT INTO "django_geo_db_zipcode" VALUES(23730,53573,-6,'Muscoda, Wisconsin 53573',16856,20963);
INSERT INTO "django_geo_db_zipcode" VALUES(23731,53574,-6,'New Glarus, Wisconsin 53574',16857,20964);
INSERT INTO "django_geo_db_zipcode" VALUES(23732,53575,-6,'Oregon, Wisconsin 53575',16858,20965);
INSERT INTO "django_geo_db_zipcode" VALUES(23733,53576,-6,'Orfordville, Wisconsin 53576',16859,20966);
INSERT INTO "django_geo_db_zipcode" VALUES(23734,53577,-6,'Plain, Wisconsin 53577',16860,20967);
INSERT INTO "django_geo_db_zipcode" VALUES(23735,53578,-6,'Prairie Du Sac, Wisconsin 53578',16861,20968);
INSERT INTO "django_geo_db_zipcode" VALUES(23736,53579,-6,'Reeseville, Wisconsin 53579',16862,20969);
INSERT INTO "django_geo_db_zipcode" VALUES(23737,53580,-6,'Rewey, Wisconsin 53580',16863,20970);
INSERT INTO "django_geo_db_zipcode" VALUES(23738,53581,-6,'Richland Center, Wisconsin 53581',16864,20971);
INSERT INTO "django_geo_db_zipcode" VALUES(23739,53582,-6,'Ridgeway, Wisconsin 53582',16865,20972);
INSERT INTO "django_geo_db_zipcode" VALUES(23740,53583,-6,'Sauk City, Wisconsin 53583',16866,20973);
INSERT INTO "django_geo_db_zipcode" VALUES(23741,53584,-6,'Sextonville, Wisconsin 53584',16867,20974);
INSERT INTO "django_geo_db_zipcode" VALUES(23742,53585,-6,'Sharon, Wisconsin 53585',16868,20975);
INSERT INTO "django_geo_db_zipcode" VALUES(23743,53586,-6,'Shullsburg, Wisconsin 53586',16869,20976);
INSERT INTO "django_geo_db_zipcode" VALUES(23744,53587,-6,'South Wayne, Wisconsin 53587',16870,20977);
INSERT INTO "django_geo_db_zipcode" VALUES(23745,53588,-6,'Spring Green, Wisconsin 53588',16871,20978);
INSERT INTO "django_geo_db_zipcode" VALUES(23746,53589,-6,'Stoughton, Wisconsin 53589',16872,20979);
INSERT INTO "django_geo_db_zipcode" VALUES(23747,53590,-6,'Sun Prairie, Wisconsin 53590',16873,20980);
INSERT INTO "django_geo_db_zipcode" VALUES(23748,53591,-6,'Sun Prairie, Wisconsin 53591',16873,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23749,53593,-6,'Verona, Wisconsin 53593',16874,20982);
INSERT INTO "django_geo_db_zipcode" VALUES(23750,53594,-6,'Waterloo, Wisconsin 53594',16875,20983);
INSERT INTO "django_geo_db_zipcode" VALUES(23751,53595,-6,'Dodgeville, Wisconsin 53595',16825,20984);
INSERT INTO "django_geo_db_zipcode" VALUES(23752,53596,-6,'Sun Prairie, Wisconsin 53596',16873,20985);
INSERT INTO "django_geo_db_zipcode" VALUES(23753,53597,-6,'Waunakee, Wisconsin 53597',16876,20986);
INSERT INTO "django_geo_db_zipcode" VALUES(23754,53598,-6,'Windsor, Wisconsin 53598',16877,20987);
INSERT INTO "django_geo_db_zipcode" VALUES(23755,53599,-6,'Woodford, Wisconsin 53599',16878,20988);
INSERT INTO "django_geo_db_zipcode" VALUES(23756,53648,-6,'Salem, Wisconsin 53648',16776,20989);
INSERT INTO "django_geo_db_zipcode" VALUES(23757,53698,-6,'Union Center, Wisconsin 53698',16879,20990);
INSERT INTO "django_geo_db_zipcode" VALUES(23758,53701,-6,'Madison, Wisconsin 53701',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23759,53702,-6,'Madison, Wisconsin 53702',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23760,53703,-6,'Madison, Wisconsin 53703',16880,20991);
INSERT INTO "django_geo_db_zipcode" VALUES(23761,53704,-6,'Madison, Wisconsin 53704',16880,20992);
INSERT INTO "django_geo_db_zipcode" VALUES(23762,53705,-6,'Madison, Wisconsin 53705',16880,20993);
INSERT INTO "django_geo_db_zipcode" VALUES(23763,53706,-6,'Madison, Wisconsin 53706',16880,20994);
INSERT INTO "django_geo_db_zipcode" VALUES(23764,53707,-6,'Madison, Wisconsin 53707',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23765,53708,-6,'Madison, Wisconsin 53708',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23766,53709,-6,'Madison, Wisconsin 53709',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23767,53710,-6,'Madison, Wisconsin 53710',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23768,53711,-6,'Madison, Wisconsin 53711',16880,20995);
INSERT INTO "django_geo_db_zipcode" VALUES(23769,53713,-6,'Madison, Wisconsin 53713',16880,20996);
INSERT INTO "django_geo_db_zipcode" VALUES(23770,53714,-6,'Madison, Wisconsin 53714',16880,20997);
INSERT INTO "django_geo_db_zipcode" VALUES(23771,53715,-6,'Madison, Wisconsin 53715',16880,20998);
INSERT INTO "django_geo_db_zipcode" VALUES(23772,53716,-6,'Madison, Wisconsin 53716',16880,20999);
INSERT INTO "django_geo_db_zipcode" VALUES(23773,53717,-6,'Madison, Wisconsin 53717',16880,21000);
INSERT INTO "django_geo_db_zipcode" VALUES(23774,53718,-6,'Madison, Wisconsin 53718',16880,21001);
INSERT INTO "django_geo_db_zipcode" VALUES(23775,53719,-6,'Madison, Wisconsin 53719',16880,21002);
INSERT INTO "django_geo_db_zipcode" VALUES(23776,53725,-6,'Madison, Wisconsin 53725',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23777,53726,-6,'Madison, Wisconsin 53726',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23778,53744,-6,'Madison, Wisconsin 53744',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23779,53777,-6,'Madison, Wisconsin 53777',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23780,53778,-6,'Madison, Wisconsin 53778',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23781,53779,-6,'Madison, Wisconsin 53779',16880,21003);
INSERT INTO "django_geo_db_zipcode" VALUES(23782,53780,-6,'Madison, Wisconsin 53780',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23783,53782,-6,'Madison, Wisconsin 53782',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23784,53783,-6,'Madison, Wisconsin 53783',16880,21004);
INSERT INTO "django_geo_db_zipcode" VALUES(23785,53784,-6,'Madison, Wisconsin 53784',16880,21005);
INSERT INTO "django_geo_db_zipcode" VALUES(23786,53785,-6,'Madison, Wisconsin 53785',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23787,53786,-6,'Madison, Wisconsin 53786',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23788,53787,-6,'Madison, Wisconsin 53787',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23789,53788,-6,'Madison, Wisconsin 53788',16880,21006);
INSERT INTO "django_geo_db_zipcode" VALUES(23790,53789,-6,'Madison, Wisconsin 53789',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23791,53790,-6,'Madison, Wisconsin 53790',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23792,53791,-6,'Madison, Wisconsin 53791',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23793,53792,-6,'Madison, Wisconsin 53792',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23794,53793,-6,'Madison, Wisconsin 53793',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23795,53794,-6,'Madison, Wisconsin 53794',16880,20981);
INSERT INTO "django_geo_db_zipcode" VALUES(23796,53801,-6,'Bagley, Wisconsin 53801',16881,21007);
INSERT INTO "django_geo_db_zipcode" VALUES(23797,53802,-6,'Beetown, Wisconsin 53802',16882,21008);
INSERT INTO "django_geo_db_zipcode" VALUES(23798,53803,-6,'Benton, Wisconsin 53803',16883,21009);
INSERT INTO "django_geo_db_zipcode" VALUES(23799,53804,-6,'Bloomington, Wisconsin 53804',16884,21010);
INSERT INTO "django_geo_db_zipcode" VALUES(23800,53805,-6,'Boscobel, Wisconsin 53805',16885,21011);
INSERT INTO "django_geo_db_zipcode" VALUES(23801,53806,-6,'Cassville, Wisconsin 53806',16886,21012);
INSERT INTO "django_geo_db_zipcode" VALUES(23802,53807,-6,'Cuba City, Wisconsin 53807',16887,21013);
INSERT INTO "django_geo_db_zipcode" VALUES(23803,53808,-6,'Dickeyville, Wisconsin 53808',16888,21014);
INSERT INTO "django_geo_db_zipcode" VALUES(23804,53809,-6,'Fennimore, Wisconsin 53809',16889,21015);
INSERT INTO "django_geo_db_zipcode" VALUES(23805,53810,-6,'Glen Haven, Wisconsin 53810',16890,21016);
INSERT INTO "django_geo_db_zipcode" VALUES(23806,53811,-6,'Hazel Green, Wisconsin 53811',16891,21017);
INSERT INTO "django_geo_db_zipcode" VALUES(23807,53812,-6,'Kieler, Wisconsin 53812',16892,21018);
INSERT INTO "django_geo_db_zipcode" VALUES(23808,53813,-6,'Lancaster, Wisconsin 53813',16893,21019);
INSERT INTO "django_geo_db_zipcode" VALUES(23809,53816,-6,'Mount Hope, Wisconsin 53816',16894,21020);
INSERT INTO "django_geo_db_zipcode" VALUES(23810,53817,-6,'Patch Grove, Wisconsin 53817',16895,21021);
INSERT INTO "django_geo_db_zipcode" VALUES(23811,53818,-6,'Platteville, Wisconsin 53818',16896,21022);
INSERT INTO "django_geo_db_zipcode" VALUES(23812,53820,-6,'Potosi, Wisconsin 53820',16897,21023);
INSERT INTO "django_geo_db_zipcode" VALUES(23813,53821,-6,'Prairie Du Chien, Wisconsin 53821',16898,21024);
INSERT INTO "django_geo_db_zipcode" VALUES(23814,53824,-6,'Sinsinawa, Wisconsin 53824',16899,21018);
INSERT INTO "django_geo_db_zipcode" VALUES(23815,53825,-6,'Stitzer, Wisconsin 53825',16900,21025);
INSERT INTO "django_geo_db_zipcode" VALUES(23816,53826,-6,'Wauzeka, Wisconsin 53826',16901,21026);
INSERT INTO "django_geo_db_zipcode" VALUES(23817,53827,-6,'Woodman, Wisconsin 53827',16902,21027);
INSERT INTO "django_geo_db_zipcode" VALUES(23818,53886,-6,'New Diggings, Wisconsin 53886',16903,21028);
INSERT INTO "django_geo_db_zipcode" VALUES(23819,53901,-6,'Portage, Wisconsin 53901',16904,21029);
INSERT INTO "django_geo_db_zipcode" VALUES(23820,53910,-6,'Adams, Wisconsin 53910',16905,21030);
INSERT INTO "django_geo_db_zipcode" VALUES(23821,53911,-6,'Arlington, Wisconsin 53911',16906,21031);
INSERT INTO "django_geo_db_zipcode" VALUES(23822,53913,-6,'Baraboo, Wisconsin 53913',16907,21032);
INSERT INTO "django_geo_db_zipcode" VALUES(23823,53916,-6,'Beaver Dam, Wisconsin 53916',16908,21033);
INSERT INTO "django_geo_db_zipcode" VALUES(23824,53917,-6,'Beaver Dam, Wisconsin 53917',16908,20786);
INSERT INTO "django_geo_db_zipcode" VALUES(23825,53919,-6,'Brandon, Wisconsin 53919',16909,21034);
INSERT INTO "django_geo_db_zipcode" VALUES(23826,53920,-6,'Briggsville, Wisconsin 53920',16910,21035);
INSERT INTO "django_geo_db_zipcode" VALUES(23827,53922,-6,'Burnett, Wisconsin 53922',16911,21036);
INSERT INTO "django_geo_db_zipcode" VALUES(23828,53923,-6,'Cambria, Wisconsin 53923',16912,21037);
INSERT INTO "django_geo_db_zipcode" VALUES(23829,53924,-6,'Cazenovia, Wisconsin 53924',16913,21038);
INSERT INTO "django_geo_db_zipcode" VALUES(23830,53925,-6,'Columbus, Wisconsin 53925',16914,21039);
INSERT INTO "django_geo_db_zipcode" VALUES(23831,53926,-6,'Dalton, Wisconsin 53926',16915,21040);
INSERT INTO "django_geo_db_zipcode" VALUES(23832,53927,-6,'Dellwood, Wisconsin 53927',16916,21041);
INSERT INTO "django_geo_db_zipcode" VALUES(23833,53928,-6,'Doylestown, Wisconsin 53928',16917,21042);
INSERT INTO "django_geo_db_zipcode" VALUES(23834,53929,-6,'Elroy, Wisconsin 53929',16918,21043);
INSERT INTO "django_geo_db_zipcode" VALUES(23835,53930,-6,'Endeavor, Wisconsin 53930',16919,21044);
INSERT INTO "django_geo_db_zipcode" VALUES(23836,53931,-6,'Fairwater, Wisconsin 53931',16920,21045);
INSERT INTO "django_geo_db_zipcode" VALUES(23837,53932,-6,'Fall River, Wisconsin 53932',16921,21046);
INSERT INTO "django_geo_db_zipcode" VALUES(23838,53933,-6,'Fox Lake, Wisconsin 53933',16922,21047);
INSERT INTO "django_geo_db_zipcode" VALUES(23839,53934,-6,'Friendship, Wisconsin 53934',16923,21048);
INSERT INTO "django_geo_db_zipcode" VALUES(23840,53935,-6,'Friesland, Wisconsin 53935',16924,21049);
INSERT INTO "django_geo_db_zipcode" VALUES(23841,53936,-6,'Grand Marsh, Wisconsin 53936',16925,21050);
INSERT INTO "django_geo_db_zipcode" VALUES(23842,53937,-6,'Hillpoint, Wisconsin 53937',16926,21051);
INSERT INTO "django_geo_db_zipcode" VALUES(23843,53939,-6,'Kingston, Wisconsin 53939',16927,21052);
INSERT INTO "django_geo_db_zipcode" VALUES(23844,53940,-6,'Lake Delton, Wisconsin 53940',16928,21053);
INSERT INTO "django_geo_db_zipcode" VALUES(23845,53941,-6,'La Valle, Wisconsin 53941',16929,21054);
INSERT INTO "django_geo_db_zipcode" VALUES(23846,53942,-6,'Lime Ridge, Wisconsin 53942',16930,21055);
INSERT INTO "django_geo_db_zipcode" VALUES(23847,53943,-6,'Loganville, Wisconsin 53943',16931,21056);
INSERT INTO "django_geo_db_zipcode" VALUES(23848,53944,-6,'Lyndon Station, Wisconsin 53944',16932,21057);
INSERT INTO "django_geo_db_zipcode" VALUES(23849,53946,-6,'Markesan, Wisconsin 53946',16933,21058);
INSERT INTO "django_geo_db_zipcode" VALUES(23850,53947,-6,'Marquette, Wisconsin 53947',16934,21059);
INSERT INTO "django_geo_db_zipcode" VALUES(23851,53948,-6,'Mauston, Wisconsin 53948',16935,21060);
INSERT INTO "django_geo_db_zipcode" VALUES(23852,53949,-6,'Montello, Wisconsin 53949',16936,21061);
INSERT INTO "django_geo_db_zipcode" VALUES(23853,53950,-6,'New Lisbon, Wisconsin 53950',16937,21062);
INSERT INTO "django_geo_db_zipcode" VALUES(23854,53951,-6,'North Freedom, Wisconsin 53951',16938,21063);
INSERT INTO "django_geo_db_zipcode" VALUES(23855,53952,-6,'Oxford, Wisconsin 53952',16939,21064);
INSERT INTO "django_geo_db_zipcode" VALUES(23856,53953,-6,'Packwaukee, Wisconsin 53953',16940,21065);
INSERT INTO "django_geo_db_zipcode" VALUES(23857,53954,-6,'Pardeeville, Wisconsin 53954',16941,21066);
INSERT INTO "django_geo_db_zipcode" VALUES(23858,53955,-6,'Poynette, Wisconsin 53955',16942,21067);
INSERT INTO "django_geo_db_zipcode" VALUES(23859,53956,-6,'Randolph, Wisconsin 53956',16943,21068);
INSERT INTO "django_geo_db_zipcode" VALUES(23860,53957,-6,'Randolph, Wisconsin 53957',16943,21069);
INSERT INTO "django_geo_db_zipcode" VALUES(23861,53958,-6,'Reedsburg, Wisconsin 53958',16944,21070);
INSERT INTO "django_geo_db_zipcode" VALUES(23862,53959,-6,'Reedsburg, Wisconsin 53959',16944,21071);
INSERT INTO "django_geo_db_zipcode" VALUES(23863,53960,-6,'Rio, Wisconsin 53960',16945,21072);
INSERT INTO "django_geo_db_zipcode" VALUES(23864,53961,-6,'Rock Springs, Wisconsin 53961',16946,21073);
INSERT INTO "django_geo_db_zipcode" VALUES(23865,53962,-6,'Union Center, Wisconsin 53962',16879,21074);
INSERT INTO "django_geo_db_zipcode" VALUES(23866,53963,-6,'Waupun, Wisconsin 53963',16947,21075);
INSERT INTO "django_geo_db_zipcode" VALUES(23867,53964,-6,'Westfield, Wisconsin 53964',16948,21076);
INSERT INTO "django_geo_db_zipcode" VALUES(23868,53965,-6,'Wisconsin Dells, Wisconsin 53965',16949,21077);
INSERT INTO "django_geo_db_zipcode" VALUES(23869,53968,-6,'Wonewoc, Wisconsin 53968',16950,21078);
INSERT INTO "django_geo_db_zipcode" VALUES(23870,53969,-6,'Wyocena, Wisconsin 53969',16951,21079);
INSERT INTO "django_geo_db_zipcode" VALUES(23871,53981,-6,'Willow, Wisconsin 53981',16952,21080);
INSERT INTO "django_geo_db_zipcode" VALUES(23872,53995,-6,'Poynette, Wisconsin 53995',16942,21081);
INSERT INTO "django_geo_db_zipcode" VALUES(23873,54001,-6,'Amery, Wisconsin 54001',16953,21082);
INSERT INTO "django_geo_db_zipcode" VALUES(23874,54002,-6,'Baldwin, Wisconsin 54002',16954,21083);
INSERT INTO "django_geo_db_zipcode" VALUES(23875,54003,-6,'Beldenville, Wisconsin 54003',16955,21084);
INSERT INTO "django_geo_db_zipcode" VALUES(23876,54004,-6,'Clayton, Wisconsin 54004',16956,21085);
INSERT INTO "django_geo_db_zipcode" VALUES(23877,54005,-6,'Clear Lake, Wisconsin 54005',16957,21086);
INSERT INTO "django_geo_db_zipcode" VALUES(23878,54006,-6,'Cushing, Wisconsin 54006',16958,21087);
INSERT INTO "django_geo_db_zipcode" VALUES(23879,54007,-6,'Deer Park, Wisconsin 54007',16959,21088);
INSERT INTO "django_geo_db_zipcode" VALUES(23880,54009,-6,'Dresser, Wisconsin 54009',16960,21089);
INSERT INTO "django_geo_db_zipcode" VALUES(23881,54010,-6,'East Ellsworth, Wisconsin 54010',16961,21090);
INSERT INTO "django_geo_db_zipcode" VALUES(23882,54011,-6,'Ellsworth, Wisconsin 54011',16962,21091);
INSERT INTO "django_geo_db_zipcode" VALUES(23883,54012,-6,'Emerald, Wisconsin 54012',16963,21092);
INSERT INTO "django_geo_db_zipcode" VALUES(23884,54013,-6,'Glenwood City, Wisconsin 54013',16964,21093);
INSERT INTO "django_geo_db_zipcode" VALUES(23885,54014,-6,'Hager City, Wisconsin 54014',16965,21094);
INSERT INTO "django_geo_db_zipcode" VALUES(23886,54015,-6,'Hammond, Wisconsin 54015',16966,21095);
INSERT INTO "django_geo_db_zipcode" VALUES(23887,54016,-6,'Hudson, Wisconsin 54016',16967,21096);
INSERT INTO "django_geo_db_zipcode" VALUES(23888,54017,-6,'New Richmond, Wisconsin 54017',16968,21097);
INSERT INTO "django_geo_db_zipcode" VALUES(23889,54020,-6,'Osceola, Wisconsin 54020',16969,21098);
INSERT INTO "django_geo_db_zipcode" VALUES(23890,54021,-6,'Prescott, Wisconsin 54021',16970,21099);
INSERT INTO "django_geo_db_zipcode" VALUES(23891,54022,-6,'River Falls, Wisconsin 54022',16971,21100);
INSERT INTO "django_geo_db_zipcode" VALUES(23892,54023,-6,'Roberts, Wisconsin 54023',16972,21101);
INSERT INTO "django_geo_db_zipcode" VALUES(23893,54024,-6,'Saint Croix Falls, Wisconsin 54024',16973,21102);
INSERT INTO "django_geo_db_zipcode" VALUES(23894,54025,-6,'Somerset, Wisconsin 54025',16974,21103);
INSERT INTO "django_geo_db_zipcode" VALUES(23895,54026,-6,'Star Prairie, Wisconsin 54026',16975,21104);
INSERT INTO "django_geo_db_zipcode" VALUES(23896,54027,-6,'Wilson, Wisconsin 54027',16976,21105);
INSERT INTO "django_geo_db_zipcode" VALUES(23897,54028,-6,'Woodville, Wisconsin 54028',16977,21106);
INSERT INTO "django_geo_db_zipcode" VALUES(23898,54034,-6,'Forest, Wisconsin 54034',16978,21107);
INSERT INTO "django_geo_db_zipcode" VALUES(23899,54035,-6,'Fond du Lac, Wisconsin 54035',16979,21108);
INSERT INTO "django_geo_db_zipcode" VALUES(23900,54052,-6,'Kickapoo, Wisconsin 54052',16980,21109);
INSERT INTO "django_geo_db_zipcode" VALUES(23901,54061,-6,'New London, Wisconsin 54061',16981,21110);
INSERT INTO "django_geo_db_zipcode" VALUES(23902,54082,-6,'Saint Joseph, Wisconsin 54082',16982,21111);
INSERT INTO "django_geo_db_zipcode" VALUES(23903,54101,-6,'Abrams, Wisconsin 54101',16983,21112);
INSERT INTO "django_geo_db_zipcode" VALUES(23904,54102,-6,'Amberg, Wisconsin 54102',16984,21113);
INSERT INTO "django_geo_db_zipcode" VALUES(23905,54103,-6,'Armstrong Creek, Wisconsin 54103',16985,21114);
INSERT INTO "django_geo_db_zipcode" VALUES(23906,54104,-6,'Athelstane, Wisconsin 54104',16986,21115);
INSERT INTO "django_geo_db_zipcode" VALUES(23907,54106,-6,'Black Creek, Wisconsin 54106',16987,21116);
INSERT INTO "django_geo_db_zipcode" VALUES(23908,54107,-6,'Bonduel, Wisconsin 54107',16988,21117);
INSERT INTO "django_geo_db_zipcode" VALUES(23909,54110,-6,'Brillion, Wisconsin 54110',16989,21118);
INSERT INTO "django_geo_db_zipcode" VALUES(23910,54111,-6,'Cecil, Wisconsin 54111',16990,21119);
INSERT INTO "django_geo_db_zipcode" VALUES(23911,54112,-6,'Coleman, Wisconsin 54112',16991,21120);
INSERT INTO "django_geo_db_zipcode" VALUES(23912,54113,-6,'Combined Locks, Wisconsin 54113',16992,21121);
INSERT INTO "django_geo_db_zipcode" VALUES(23913,54114,-6,'Crivitz, Wisconsin 54114',16993,21122);
INSERT INTO "django_geo_db_zipcode" VALUES(23914,54115,-6,'De Pere, Wisconsin 54115',16994,21123);
INSERT INTO "django_geo_db_zipcode" VALUES(23915,54119,-6,'Dunbar, Wisconsin 54119',16995,21124);
INSERT INTO "django_geo_db_zipcode" VALUES(23916,54120,-6,'Fence, Wisconsin 54120',16996,21125);
INSERT INTO "django_geo_db_zipcode" VALUES(23917,54121,-6,'Florence, Wisconsin 54121',16997,21126);
INSERT INTO "django_geo_db_zipcode" VALUES(23918,54123,-6,'Forest Junction, Wisconsin 54123',16998,21127);
INSERT INTO "django_geo_db_zipcode" VALUES(23919,54124,-6,'Gillett, Wisconsin 54124',16999,21128);
INSERT INTO "django_geo_db_zipcode" VALUES(23920,54125,-6,'Goodman, Wisconsin 54125',17000,21129);
INSERT INTO "django_geo_db_zipcode" VALUES(23921,54126,-6,'Greenleaf, Wisconsin 54126',17001,21130);
INSERT INTO "django_geo_db_zipcode" VALUES(23922,54127,-6,'Green Valley, Wisconsin 54127',17002,21131);
INSERT INTO "django_geo_db_zipcode" VALUES(23923,54128,-6,'Gresham, Wisconsin 54128',17003,21132);
INSERT INTO "django_geo_db_zipcode" VALUES(23924,54129,-6,'Hilbert, Wisconsin 54129',17004,21133);
INSERT INTO "django_geo_db_zipcode" VALUES(23925,54130,-6,'Kaukauna, Wisconsin 54130',17005,21134);
INSERT INTO "django_geo_db_zipcode" VALUES(23926,54131,-6,'Freedom, Wisconsin 54131',17006,21135);
INSERT INTO "django_geo_db_zipcode" VALUES(23927,54135,-6,'Keshena, Wisconsin 54135',17007,21136);
INSERT INTO "django_geo_db_zipcode" VALUES(23928,54136,-6,'Kimberly, Wisconsin 54136',17008,21137);
INSERT INTO "django_geo_db_zipcode" VALUES(23929,54137,-6,'Krakow, Wisconsin 54137',17009,21138);
INSERT INTO "django_geo_db_zipcode" VALUES(23930,54138,-6,'Lakewood, Wisconsin 54138',17010,21139);
INSERT INTO "django_geo_db_zipcode" VALUES(23931,54139,-6,'Lena, Wisconsin 54139',17011,21140);
INSERT INTO "django_geo_db_zipcode" VALUES(23932,54140,-6,'Little Chute, Wisconsin 54140',17012,21141);
INSERT INTO "django_geo_db_zipcode" VALUES(23933,54141,-6,'Little Suamico, Wisconsin 54141',17013,21142);
INSERT INTO "django_geo_db_zipcode" VALUES(23934,54143,-6,'Marinette, Wisconsin 54143',17014,21143);
INSERT INTO "django_geo_db_zipcode" VALUES(23935,54149,-6,'Mountain, Wisconsin 54149',17015,21144);
INSERT INTO "django_geo_db_zipcode" VALUES(23936,54150,-6,'Neopit, Wisconsin 54150',17016,21145);
INSERT INTO "django_geo_db_zipcode" VALUES(23937,54151,-6,'Niagara, Wisconsin 54151',17017,21146);
INSERT INTO "django_geo_db_zipcode" VALUES(23938,54152,-6,'Nichols, Wisconsin 54152',17018,21147);
INSERT INTO "django_geo_db_zipcode" VALUES(23939,54153,-6,'Oconto, Wisconsin 54153',17019,21148);
INSERT INTO "django_geo_db_zipcode" VALUES(23940,54154,-6,'Oconto Falls, Wisconsin 54154',17020,21149);
INSERT INTO "django_geo_db_zipcode" VALUES(23941,54155,-6,'Oneida, Wisconsin 54155',17021,21150);
INSERT INTO "django_geo_db_zipcode" VALUES(23942,54156,-6,'Pembine, Wisconsin 54156',17022,21151);
INSERT INTO "django_geo_db_zipcode" VALUES(23943,54157,-6,'Peshtigo, Wisconsin 54157',17023,21152);
INSERT INTO "django_geo_db_zipcode" VALUES(23944,54159,-6,'Porterfield, Wisconsin 54159',17024,21153);
INSERT INTO "django_geo_db_zipcode" VALUES(23945,54160,-6,'Potter, Wisconsin 54160',17025,21154);
INSERT INTO "django_geo_db_zipcode" VALUES(23946,54161,-6,'Pound, Wisconsin 54161',17026,21155);
INSERT INTO "django_geo_db_zipcode" VALUES(23947,54162,-6,'Pulaski, Wisconsin 54162',17027,21156);
INSERT INTO "django_geo_db_zipcode" VALUES(23948,54165,-6,'Seymour, Wisconsin 54165',17028,21157);
INSERT INTO "django_geo_db_zipcode" VALUES(23949,54166,-6,'Shawano, Wisconsin 54166',17029,21158);
INSERT INTO "django_geo_db_zipcode" VALUES(23950,54169,-6,'Sherwood, Wisconsin 54169',17030,21159);
INSERT INTO "django_geo_db_zipcode" VALUES(23951,54170,-6,'Shiocton, Wisconsin 54170',17031,21160);
INSERT INTO "django_geo_db_zipcode" VALUES(23952,54171,-6,'Sobieski, Wisconsin 54171',17032,21161);
INSERT INTO "django_geo_db_zipcode" VALUES(23953,54173,-6,'Suamico, Wisconsin 54173',17033,21162);
INSERT INTO "django_geo_db_zipcode" VALUES(23954,54174,-6,'Suring, Wisconsin 54174',17034,21163);
INSERT INTO "django_geo_db_zipcode" VALUES(23955,54175,-6,'Townsend, Wisconsin 54175',17035,21164);
INSERT INTO "django_geo_db_zipcode" VALUES(23956,54177,-6,'Wausaukee, Wisconsin 54177',17036,21165);
INSERT INTO "django_geo_db_zipcode" VALUES(23957,54180,-6,'Wrightstown, Wisconsin 54180',17037,21166);
INSERT INTO "django_geo_db_zipcode" VALUES(23958,54182,-6,'Zachow, Wisconsin 54182',17038,21167);
INSERT INTO "django_geo_db_zipcode" VALUES(23959,54201,-6,'Algoma, Wisconsin 54201',17039,21168);
INSERT INTO "django_geo_db_zipcode" VALUES(23960,54202,-6,'Baileys Harbor, Wisconsin 54202',17040,21169);
INSERT INTO "django_geo_db_zipcode" VALUES(23961,54203,-6,'Branch, Wisconsin 54203',17041,21170);
INSERT INTO "django_geo_db_zipcode" VALUES(23962,54204,-6,'Brussels, Wisconsin 54204',17042,21171);
INSERT INTO "django_geo_db_zipcode" VALUES(23963,54205,-6,'Casco, Wisconsin 54205',17043,21172);
INSERT INTO "django_geo_db_zipcode" VALUES(23964,54206,-6,'Kossuth, Wisconsin 54206',17044,21173);
INSERT INTO "django_geo_db_zipcode" VALUES(23965,54207,-6,'Collins, Wisconsin 54207',17045,21174);
INSERT INTO "django_geo_db_zipcode" VALUES(23966,54208,-6,'Denmark, Wisconsin 54208',17046,21175);
INSERT INTO "django_geo_db_zipcode" VALUES(23967,54209,-6,'Egg Harbor, Wisconsin 54209',17047,21176);
INSERT INTO "django_geo_db_zipcode" VALUES(23968,54210,-6,'Ellison Bay, Wisconsin 54210',17048,21177);
INSERT INTO "django_geo_db_zipcode" VALUES(23969,54211,-6,'Ephraim, Wisconsin 54211',17049,21178);
INSERT INTO "django_geo_db_zipcode" VALUES(23970,54212,-6,'Fish Creek, Wisconsin 54212',17050,21179);
INSERT INTO "django_geo_db_zipcode" VALUES(23971,54213,-6,'Forestville, Wisconsin 54213',17051,21180);
INSERT INTO "django_geo_db_zipcode" VALUES(23972,54214,-6,'Francis Creek, Wisconsin 54214',17052,21181);
INSERT INTO "django_geo_db_zipcode" VALUES(23973,54215,-6,'Kellnersville, Wisconsin 54215',17053,21182);
INSERT INTO "django_geo_db_zipcode" VALUES(23974,54216,-6,'Kewaunee, Wisconsin 54216',17054,21183);
INSERT INTO "django_geo_db_zipcode" VALUES(23975,54217,-6,'Luxemburg, Wisconsin 54217',17055,21184);
INSERT INTO "django_geo_db_zipcode" VALUES(23976,54220,-6,'Manitowoc, Wisconsin 54220',17056,21185);
INSERT INTO "django_geo_db_zipcode" VALUES(23977,54221,-6,'Manitowoc, Wisconsin 54221',17056,21186);
INSERT INTO "django_geo_db_zipcode" VALUES(23978,54226,-6,'Maplewood, Wisconsin 54226',17057,21187);
INSERT INTO "django_geo_db_zipcode" VALUES(23979,54227,-6,'Maribel, Wisconsin 54227',17058,21188);
INSERT INTO "django_geo_db_zipcode" VALUES(23980,54228,-6,'Mishicot, Wisconsin 54228',17059,21189);
INSERT INTO "django_geo_db_zipcode" VALUES(23981,54229,-6,'New Franken, Wisconsin 54229',17060,21190);
INSERT INTO "django_geo_db_zipcode" VALUES(23982,54230,-6,'Reedsville, Wisconsin 54230',17061,21191);
INSERT INTO "django_geo_db_zipcode" VALUES(23983,54232,-6,'Saint Nazianz, Wisconsin 54232',17062,21192);
INSERT INTO "django_geo_db_zipcode" VALUES(23984,54234,-6,'Sister Bay, Wisconsin 54234',17063,21193);
INSERT INTO "django_geo_db_zipcode" VALUES(23985,54235,-6,'Sturgeon Bay, Wisconsin 54235',17064,21194);
INSERT INTO "django_geo_db_zipcode" VALUES(23986,54240,-6,'Tisch Mills, Wisconsin 54240',17065,21195);
INSERT INTO "django_geo_db_zipcode" VALUES(23987,54241,-6,'Two Rivers, Wisconsin 54241',17066,21196);
INSERT INTO "django_geo_db_zipcode" VALUES(23988,54242,-6,'Ludington, Wisconsin 54242',17067,21197);
INSERT INTO "django_geo_db_zipcode" VALUES(23989,54245,-6,'Valders, Wisconsin 54245',17068,21198);
INSERT INTO "django_geo_db_zipcode" VALUES(23990,54246,-6,'Washington Island, Wisconsin 54246',17069,21199);
INSERT INTO "django_geo_db_zipcode" VALUES(23991,54247,-6,'Whitelaw, Wisconsin 54247',17070,21200);
INSERT INTO "django_geo_db_zipcode" VALUES(23992,54301,-6,'Green Bay, Wisconsin 54301',17071,21201);
INSERT INTO "django_geo_db_zipcode" VALUES(23993,54302,-6,'Green Bay, Wisconsin 54302',17071,21202);
INSERT INTO "django_geo_db_zipcode" VALUES(23994,54303,-6,'Green Bay, Wisconsin 54303',17071,21203);
INSERT INTO "django_geo_db_zipcode" VALUES(23995,54304,-6,'Green Bay, Wisconsin 54304',17071,21204);
INSERT INTO "django_geo_db_zipcode" VALUES(23996,54305,-6,'Green Bay, Wisconsin 54305',17071,21205);
INSERT INTO "django_geo_db_zipcode" VALUES(23997,54306,-6,'Green Bay, Wisconsin 54306',17071,21205);
INSERT INTO "django_geo_db_zipcode" VALUES(23998,54307,-6,'Green Bay, Wisconsin 54307',17071,21205);
INSERT INTO "django_geo_db_zipcode" VALUES(23999,54308,-6,'Green Bay, Wisconsin 54308',17071,21206);
INSERT INTO "django_geo_db_zipcode" VALUES(24000,54310,-6,'Liberty Grove, Wisconsin 54310',17072,21207);
INSERT INTO "django_geo_db_zipcode" VALUES(24001,54311,-6,'Green Bay, Wisconsin 54311',17071,21208);
INSERT INTO "django_geo_db_zipcode" VALUES(24002,54313,-6,'Green Bay, Wisconsin 54313',17071,21209);
INSERT INTO "django_geo_db_zipcode" VALUES(24003,54324,-6,'Green Bay, Wisconsin 54324',17071,21205);
INSERT INTO "django_geo_db_zipcode" VALUES(24004,54337,-6,'Bone Lake, Wisconsin 54337',17073,21210);
INSERT INTO "django_geo_db_zipcode" VALUES(24005,54344,-6,'Green Bay, Wisconsin 54344',17071,21211);
INSERT INTO "django_geo_db_zipcode" VALUES(24006,54353,-6,'Georgetown, Wisconsin 54353',17074,21212);
INSERT INTO "django_geo_db_zipcode" VALUES(24007,54383,-6,'Wascott, Wisconsin 54383',17075,21213);
INSERT INTO "django_geo_db_zipcode" VALUES(24008,54401,-6,'Wausau, Wisconsin 54401',17076,21214);
INSERT INTO "django_geo_db_zipcode" VALUES(24009,54402,-6,'Wausau, Wisconsin 54402',17076,21215);
INSERT INTO "django_geo_db_zipcode" VALUES(24010,54403,-6,'Wausau, Wisconsin 54403',17076,21216);
INSERT INTO "django_geo_db_zipcode" VALUES(24011,54404,-6,'Marshfield, Wisconsin 54404',17077,21217);
INSERT INTO "django_geo_db_zipcode" VALUES(24012,54405,-6,'Abbotsford, Wisconsin 54405',17078,21218);
INSERT INTO "django_geo_db_zipcode" VALUES(24013,54406,-6,'Amherst, Wisconsin 54406',17079,21219);
INSERT INTO "django_geo_db_zipcode" VALUES(24014,54407,-6,'Amherst Junction, Wisconsin 54407',17080,21220);
INSERT INTO "django_geo_db_zipcode" VALUES(24015,54408,-6,'Aniwa, Wisconsin 54408',17081,21221);
INSERT INTO "django_geo_db_zipcode" VALUES(24016,54409,-6,'Antigo, Wisconsin 54409',17082,21222);
INSERT INTO "django_geo_db_zipcode" VALUES(24017,54410,-6,'Arpin, Wisconsin 54410',17083,21223);
INSERT INTO "django_geo_db_zipcode" VALUES(24018,54411,-6,'Athens, Wisconsin 54411',17084,21224);
INSERT INTO "django_geo_db_zipcode" VALUES(24019,54412,-6,'Auburndale, Wisconsin 54412',17085,21225);
INSERT INTO "django_geo_db_zipcode" VALUES(24020,54413,-6,'Babcock, Wisconsin 54413',17086,21226);
INSERT INTO "django_geo_db_zipcode" VALUES(24021,54414,-6,'Birnamwood, Wisconsin 54414',17087,21227);
INSERT INTO "django_geo_db_zipcode" VALUES(24022,54415,-6,'Blenker, Wisconsin 54415',17088,21228);
INSERT INTO "django_geo_db_zipcode" VALUES(24023,54416,-6,'Bowler, Wisconsin 54416',17089,21229);
INSERT INTO "django_geo_db_zipcode" VALUES(24024,54417,-6,'Brokaw, Wisconsin 54417',17090,21230);
INSERT INTO "django_geo_db_zipcode" VALUES(24025,54418,-6,'Bryant, Wisconsin 54418',17091,21231);
INSERT INTO "django_geo_db_zipcode" VALUES(24026,54419,-6,'Chelsea, Wisconsin 54419',17092,21232);
INSERT INTO "django_geo_db_zipcode" VALUES(24027,54420,-6,'Chili, Wisconsin 54420',17093,21233);
INSERT INTO "django_geo_db_zipcode" VALUES(24028,54421,-6,'Colby, Wisconsin 54421',17094,21234);
INSERT INTO "django_geo_db_zipcode" VALUES(24029,54422,-6,'Curtiss, Wisconsin 54422',17095,21235);
INSERT INTO "django_geo_db_zipcode" VALUES(24030,54423,-6,'Custer, Wisconsin 54423',17096,21236);
INSERT INTO "django_geo_db_zipcode" VALUES(24031,54424,-6,'Deerbrook, Wisconsin 54424',17097,21237);
INSERT INTO "django_geo_db_zipcode" VALUES(24032,54425,-6,'Dorchester, Wisconsin 54425',17098,21238);
INSERT INTO "django_geo_db_zipcode" VALUES(24033,54426,-6,'Edgar, Wisconsin 54426',17099,21239);
INSERT INTO "django_geo_db_zipcode" VALUES(24034,54427,-6,'Eland, Wisconsin 54427',17100,21240);
INSERT INTO "django_geo_db_zipcode" VALUES(24035,54428,-6,'Elcho, Wisconsin 54428',17101,21241);
INSERT INTO "django_geo_db_zipcode" VALUES(24036,54429,-6,'Elderon, Wisconsin 54429',17102,21242);
INSERT INTO "django_geo_db_zipcode" VALUES(24037,54430,-6,'Elton, Wisconsin 54430',17103,21243);
INSERT INTO "django_geo_db_zipcode" VALUES(24038,54431,-6,'Little Black, Wisconsin 54431',17104,21244);
INSERT INTO "django_geo_db_zipcode" VALUES(24039,54432,-6,'Galloway, Wisconsin 54432',17105,21215);
INSERT INTO "django_geo_db_zipcode" VALUES(24040,54433,-6,'Gilman, Wisconsin 54433',17106,21245);
INSERT INTO "django_geo_db_zipcode" VALUES(24041,54434,-6,'Jump River, Wisconsin 54434',17107,21246);
INSERT INTO "django_geo_db_zipcode" VALUES(24042,54435,-6,'Gleason, Wisconsin 54435',17108,21247);
INSERT INTO "django_geo_db_zipcode" VALUES(24043,54436,-6,'Granton, Wisconsin 54436',17109,21248);
INSERT INTO "django_geo_db_zipcode" VALUES(24044,54437,-6,'Greenwood, Wisconsin 54437',17110,21249);
INSERT INTO "django_geo_db_zipcode" VALUES(24045,54439,-6,'Hannibal, Wisconsin 54439',17111,21246);
INSERT INTO "django_geo_db_zipcode" VALUES(24046,54440,-6,'Hatley, Wisconsin 54440',17112,21250);
INSERT INTO "django_geo_db_zipcode" VALUES(24047,54441,-6,'Hewitt, Wisconsin 54441',17113,21251);
INSERT INTO "django_geo_db_zipcode" VALUES(24048,54442,-6,'Irma, Wisconsin 54442',17114,21252);
INSERT INTO "django_geo_db_zipcode" VALUES(24049,54443,-6,'Junction City, Wisconsin 54443',17115,21253);
INSERT INTO "django_geo_db_zipcode" VALUES(24050,54444,-6,'Kempster, Wisconsin 54444',17116,21254);
INSERT INTO "django_geo_db_zipcode" VALUES(24051,54446,-6,'Loyal, Wisconsin 54446',17117,21255);
INSERT INTO "django_geo_db_zipcode" VALUES(24052,54447,-6,'Lublin, Wisconsin 54447',17118,21256);
INSERT INTO "django_geo_db_zipcode" VALUES(24053,54448,-6,'Marathon, Wisconsin 54448',17119,21257);
INSERT INTO "django_geo_db_zipcode" VALUES(24054,54449,-6,'Marshfield, Wisconsin 54449',17077,21258);
INSERT INTO "django_geo_db_zipcode" VALUES(24055,54450,-6,'Mattoon, Wisconsin 54450',17120,21259);
INSERT INTO "django_geo_db_zipcode" VALUES(24056,54451,-6,'Medford, Wisconsin 54451',17121,21260);
INSERT INTO "django_geo_db_zipcode" VALUES(24057,54452,-6,'Merrill, Wisconsin 54452',17122,21261);
INSERT INTO "django_geo_db_zipcode" VALUES(24058,54454,-6,'Milladore, Wisconsin 54454',17123,21262);
INSERT INTO "django_geo_db_zipcode" VALUES(24059,54455,-6,'Mosinee, Wisconsin 54455',17124,21263);
INSERT INTO "django_geo_db_zipcode" VALUES(24060,54456,-6,'Neillsville, Wisconsin 54456',17125,21264);
INSERT INTO "django_geo_db_zipcode" VALUES(24061,54457,-6,'Nekoosa, Wisconsin 54457',17126,21265);
INSERT INTO "django_geo_db_zipcode" VALUES(24062,54458,-6,'Nelsonville, Wisconsin 54458',17127,21266);
INSERT INTO "django_geo_db_zipcode" VALUES(24063,54459,-6,'Ogema, Wisconsin 54459',17128,21267);
INSERT INTO "django_geo_db_zipcode" VALUES(24064,54460,-6,'Owen, Wisconsin 54460',17129,21268);
INSERT INTO "django_geo_db_zipcode" VALUES(24065,54462,-6,'Pearson, Wisconsin 54462',17130,21269);
INSERT INTO "django_geo_db_zipcode" VALUES(24066,54463,-6,'Pelican Lake, Wisconsin 54463',17131,21270);
INSERT INTO "django_geo_db_zipcode" VALUES(24067,54464,-6,'Phlox, Wisconsin 54464',17132,21254);
INSERT INTO "django_geo_db_zipcode" VALUES(24068,54465,-6,'Pickerel, Wisconsin 54465',17133,21271);
INSERT INTO "django_geo_db_zipcode" VALUES(24069,54466,-6,'Pittsville, Wisconsin 54466',17134,21272);
INSERT INTO "django_geo_db_zipcode" VALUES(24070,54467,-6,'Plover, Wisconsin 54467',17135,21273);
INSERT INTO "django_geo_db_zipcode" VALUES(24071,54469,-6,'Port Edwards, Wisconsin 54469',17136,21274);
INSERT INTO "django_geo_db_zipcode" VALUES(24072,54470,-6,'Rib Lake, Wisconsin 54470',17137,21275);
INSERT INTO "django_geo_db_zipcode" VALUES(24073,54471,-6,'Ringle, Wisconsin 54471',17138,21276);
INSERT INTO "django_geo_db_zipcode" VALUES(24074,54472,-6,'Marshfield, Wisconsin 54472',17077,21217);
INSERT INTO "django_geo_db_zipcode" VALUES(24075,54473,-6,'Rosholt, Wisconsin 54473',17139,21277);
INSERT INTO "django_geo_db_zipcode" VALUES(24076,54474,-6,'Rothschild, Wisconsin 54474',17140,21278);
INSERT INTO "django_geo_db_zipcode" VALUES(24077,54475,-6,'Rudolph, Wisconsin 54475',17141,21279);
INSERT INTO "django_geo_db_zipcode" VALUES(24078,54476,-6,'Schofield, Wisconsin 54476',17142,21280);
INSERT INTO "django_geo_db_zipcode" VALUES(24079,54479,-6,'Spencer, Wisconsin 54479',17143,21281);
INSERT INTO "django_geo_db_zipcode" VALUES(24080,54480,-6,'Stetsonville, Wisconsin 54480',17144,21282);
INSERT INTO "django_geo_db_zipcode" VALUES(24081,54481,-6,'Stevens Point, Wisconsin 54481',17145,21283);
INSERT INTO "django_geo_db_zipcode" VALUES(24082,54484,-6,'Stratford, Wisconsin 54484',17146,21284);
INSERT INTO "django_geo_db_zipcode" VALUES(24083,54485,-6,'Summit Lake, Wisconsin 54485',17147,21285);
INSERT INTO "django_geo_db_zipcode" VALUES(24084,54486,-6,'Tigerton, Wisconsin 54486',17148,21286);
INSERT INTO "django_geo_db_zipcode" VALUES(24085,54487,-6,'Tomahawk, Wisconsin 54487',17149,21287);
INSERT INTO "django_geo_db_zipcode" VALUES(24086,54488,-6,'Unity, Wisconsin 54488',17150,21288);
INSERT INTO "django_geo_db_zipcode" VALUES(24087,54489,-6,'Vesper, Wisconsin 54489',17151,21289);
INSERT INTO "django_geo_db_zipcode" VALUES(24088,54490,-6,'Westboro, Wisconsin 54490',17152,21290);
INSERT INTO "django_geo_db_zipcode" VALUES(24089,54491,-6,'White Lake, Wisconsin 54491',17153,21291);
INSERT INTO "django_geo_db_zipcode" VALUES(24090,54492,-6,'Stevens Point, Wisconsin 54492',17145,21292);
INSERT INTO "django_geo_db_zipcode" VALUES(24091,54493,-6,'Willard, Wisconsin 54493',17154,21293);
INSERT INTO "django_geo_db_zipcode" VALUES(24092,54494,-6,'Wisconsin Rapids, Wisconsin 54494',17155,21294);
INSERT INTO "django_geo_db_zipcode" VALUES(24093,54495,-6,'Wisconsin Rapids, Wisconsin 54495',17155,21295);
INSERT INTO "django_geo_db_zipcode" VALUES(24094,54498,-6,'Withee, Wisconsin 54498',17156,21296);
INSERT INTO "django_geo_db_zipcode" VALUES(24095,54499,-6,'Wittenberg, Wisconsin 54499',17157,21297);
INSERT INTO "django_geo_db_zipcode" VALUES(24096,54501,-6,'Rhinelander, Wisconsin 54501',17158,21298);
INSERT INTO "django_geo_db_zipcode" VALUES(24097,54511,-6,'Argonne, Wisconsin 54511',17159,21299);
INSERT INTO "django_geo_db_zipcode" VALUES(24098,54512,-6,'Boulder Junction, Wisconsin 54512',17160,21300);
INSERT INTO "django_geo_db_zipcode" VALUES(24099,54513,-6,'Brantwood, Wisconsin 54513',17161,21301);
INSERT INTO "django_geo_db_zipcode" VALUES(24100,54514,-6,'Butternut, Wisconsin 54514',17162,21302);
INSERT INTO "django_geo_db_zipcode" VALUES(24101,54515,-6,'Catawba, Wisconsin 54515',17163,21303);
INSERT INTO "django_geo_db_zipcode" VALUES(24102,54517,-6,'Clam Lake, Wisconsin 54517',17164,21304);
INSERT INTO "django_geo_db_zipcode" VALUES(24103,54519,-6,'Conover, Wisconsin 54519',17165,21305);
INSERT INTO "django_geo_db_zipcode" VALUES(24104,54520,-6,'Crandon, Wisconsin 54520',17166,21306);
INSERT INTO "django_geo_db_zipcode" VALUES(24105,54521,-6,'Eagle River, Wisconsin 54521',17167,21307);
INSERT INTO "django_geo_db_zipcode" VALUES(24106,54524,-6,'Fifield, Wisconsin 54524',17168,21308);
INSERT INTO "django_geo_db_zipcode" VALUES(24107,54525,-6,'Gile, Wisconsin 54525',17169,21309);
INSERT INTO "django_geo_db_zipcode" VALUES(24108,54526,-6,'Glen Flora, Wisconsin 54526',17170,21310);
INSERT INTO "django_geo_db_zipcode" VALUES(24109,54527,-6,'Glidden, Wisconsin 54527',17171,21311);
INSERT INTO "django_geo_db_zipcode" VALUES(24110,54529,-6,'Harshaw, Wisconsin 54529',17172,21312);
INSERT INTO "django_geo_db_zipcode" VALUES(24111,54530,-6,'Hawkins, Wisconsin 54530',17173,21313);
INSERT INTO "django_geo_db_zipcode" VALUES(24112,54531,-6,'Hazelhurst, Wisconsin 54531',17174,21314);
INSERT INTO "django_geo_db_zipcode" VALUES(24113,54532,-6,'Heafford Junction, Wisconsin 54532',17175,21315);
INSERT INTO "django_geo_db_zipcode" VALUES(24114,54534,-6,'Hurley, Wisconsin 54534',17176,21316);
INSERT INTO "django_geo_db_zipcode" VALUES(24115,54536,-6,'Iron Belt, Wisconsin 54536',17177,21317);
INSERT INTO "django_geo_db_zipcode" VALUES(24116,54537,-6,'Kennan, Wisconsin 54537',17178,21318);
INSERT INTO "django_geo_db_zipcode" VALUES(24117,54538,-6,'Lac Du Flambeau, Wisconsin 54538',17179,21319);
INSERT INTO "django_geo_db_zipcode" VALUES(24118,54539,-6,'Lake Tomahawk, Wisconsin 54539',17180,21320);
INSERT INTO "django_geo_db_zipcode" VALUES(24119,54540,-6,'Land O Lakes, Wisconsin 54540',17181,21321);
INSERT INTO "django_geo_db_zipcode" VALUES(24120,54541,-6,'Laona, Wisconsin 54541',17182,21322);
INSERT INTO "django_geo_db_zipcode" VALUES(24121,54542,-6,'Long Lake, Wisconsin 54542',17183,21323);
INSERT INTO "django_geo_db_zipcode" VALUES(24122,54543,-6,'McNaughton, Wisconsin 54543',17184,21324);
INSERT INTO "django_geo_db_zipcode" VALUES(24123,54545,-6,'Manitowish Waters, Wisconsin 54545',17185,21325);
INSERT INTO "django_geo_db_zipcode" VALUES(24124,54546,-6,'Mellen, Wisconsin 54546',17186,21326);
INSERT INTO "django_geo_db_zipcode" VALUES(24125,54547,-6,'Mercer, Wisconsin 54547',17187,21327);
INSERT INTO "django_geo_db_zipcode" VALUES(24126,54548,-6,'Minocqua, Wisconsin 54548',17188,21328);
INSERT INTO "django_geo_db_zipcode" VALUES(24127,54550,-6,'Montreal, Wisconsin 54550',17189,21329);
INSERT INTO "django_geo_db_zipcode" VALUES(24128,54551,-6,'Presque Isle, Wisconsin 54551',17190,21330);
INSERT INTO "django_geo_db_zipcode" VALUES(24129,54552,-6,'Park Falls, Wisconsin 54552',17191,21331);
INSERT INTO "django_geo_db_zipcode" VALUES(24130,54554,-6,'Phelps, Wisconsin 54554',17192,21332);
INSERT INTO "django_geo_db_zipcode" VALUES(24131,54555,-6,'Phillips, Wisconsin 54555',17193,21333);
INSERT INTO "django_geo_db_zipcode" VALUES(24132,54556,-6,'Prentice, Wisconsin 54556',17194,21334);
INSERT INTO "django_geo_db_zipcode" VALUES(24133,54557,-6,'Presque Isle, Wisconsin 54557',17190,21335);
INSERT INTO "django_geo_db_zipcode" VALUES(24134,54558,-6,'Saint Germain, Wisconsin 54558',17195,21336);
INSERT INTO "django_geo_db_zipcode" VALUES(24135,54559,-6,'Saxon, Wisconsin 54559',17196,21337);
INSERT INTO "django_geo_db_zipcode" VALUES(24136,54560,-6,'Sayner, Wisconsin 54560',17197,21338);
INSERT INTO "django_geo_db_zipcode" VALUES(24137,54561,-6,'Star Lake, Wisconsin 54561',17198,21339);
INSERT INTO "django_geo_db_zipcode" VALUES(24138,54562,-6,'Three Lakes, Wisconsin 54562',17199,21340);
INSERT INTO "django_geo_db_zipcode" VALUES(24139,54563,-6,'Tony, Wisconsin 54563',17200,21341);
INSERT INTO "django_geo_db_zipcode" VALUES(24140,54564,-6,'Tripoli, Wisconsin 54564',17201,21342);
INSERT INTO "django_geo_db_zipcode" VALUES(24141,54565,-6,'Upson, Wisconsin 54565',17202,21343);
INSERT INTO "django_geo_db_zipcode" VALUES(24142,54566,-6,'Wabeno, Wisconsin 54566',17203,21344);
INSERT INTO "django_geo_db_zipcode" VALUES(24143,54568,-6,'Woodruff, Wisconsin 54568',17204,21345);
INSERT INTO "django_geo_db_zipcode" VALUES(24144,54601,-6,'La Crosse, Wisconsin 54601',17205,21346);
INSERT INTO "django_geo_db_zipcode" VALUES(24145,54602,-6,'La Crosse, Wisconsin 54602',17205,21347);
INSERT INTO "django_geo_db_zipcode" VALUES(24146,54603,-6,'La Crosse, Wisconsin 54603',17205,21348);
INSERT INTO "django_geo_db_zipcode" VALUES(24147,54610,-6,'Alma, Wisconsin 54610',17206,21349);
INSERT INTO "django_geo_db_zipcode" VALUES(24148,54611,-6,'Alma Center, Wisconsin 54611',17207,21350);
INSERT INTO "django_geo_db_zipcode" VALUES(24149,54612,-6,'Arcadia, Wisconsin 54612',17208,21351);
INSERT INTO "django_geo_db_zipcode" VALUES(24150,54613,-6,'Arkdale, Wisconsin 54613',17209,21352);
INSERT INTO "django_geo_db_zipcode" VALUES(24151,54614,-6,'Bangor, Wisconsin 54614',17210,21353);
INSERT INTO "django_geo_db_zipcode" VALUES(24152,54615,-6,'Black River Falls, Wisconsin 54615',17211,21354);
INSERT INTO "django_geo_db_zipcode" VALUES(24153,54616,-6,'Blair, Wisconsin 54616',17212,21355);
INSERT INTO "django_geo_db_zipcode" VALUES(24154,54618,-6,'Camp Douglas, Wisconsin 54618',17213,21356);
INSERT INTO "django_geo_db_zipcode" VALUES(24155,54619,-6,'Cashton, Wisconsin 54619',17214,21357);
INSERT INTO "django_geo_db_zipcode" VALUES(24156,54620,-6,'Cataract, Wisconsin 54620',17215,21358);
INSERT INTO "django_geo_db_zipcode" VALUES(24157,54621,-6,'Chaseburg, Wisconsin 54621',17216,21359);
INSERT INTO "django_geo_db_zipcode" VALUES(24158,54622,-6,'Cochrane, Wisconsin 54622',17217,21360);
INSERT INTO "django_geo_db_zipcode" VALUES(24159,54623,-6,'Coon Valley, Wisconsin 54623',17218,21361);
INSERT INTO "django_geo_db_zipcode" VALUES(24160,54624,-6,'De Soto, Wisconsin 54624',17219,21362);
INSERT INTO "django_geo_db_zipcode" VALUES(24161,54625,-6,'Dodge, Wisconsin 54625',17220,21363);
INSERT INTO "django_geo_db_zipcode" VALUES(24162,54626,-6,'Eastman, Wisconsin 54626',17221,21364);
INSERT INTO "django_geo_db_zipcode" VALUES(24163,54627,-6,'Ettrick, Wisconsin 54627',17222,21365);
INSERT INTO "django_geo_db_zipcode" VALUES(24164,54628,-6,'Ferryville, Wisconsin 54628',17223,21366);
INSERT INTO "django_geo_db_zipcode" VALUES(24165,54629,-6,'Fountain City, Wisconsin 54629',17224,21367);
INSERT INTO "django_geo_db_zipcode" VALUES(24166,54630,-6,'Galesville, Wisconsin 54630',17225,21368);
INSERT INTO "django_geo_db_zipcode" VALUES(24167,54631,-6,'Gays Mills, Wisconsin 54631',17226,21369);
INSERT INTO "django_geo_db_zipcode" VALUES(24168,54632,-6,'Genoa, Wisconsin 54632',17227,21370);
INSERT INTO "django_geo_db_zipcode" VALUES(24169,54634,-6,'Hillsboro, Wisconsin 54634',17228,21371);
INSERT INTO "django_geo_db_zipcode" VALUES(24170,54635,-6,'Hixton, Wisconsin 54635',17229,21372);
INSERT INTO "django_geo_db_zipcode" VALUES(24171,54636,-6,'Holmen, Wisconsin 54636',17230,21373);
INSERT INTO "django_geo_db_zipcode" VALUES(24172,54637,-6,'Hustler, Wisconsin 54637',17231,21374);
INSERT INTO "django_geo_db_zipcode" VALUES(24173,54638,-6,'Kendall, Wisconsin 54638',17232,21375);
INSERT INTO "django_geo_db_zipcode" VALUES(24174,54639,-6,'La Farge, Wisconsin 54639',17233,21376);
INSERT INTO "django_geo_db_zipcode" VALUES(24175,54640,-6,'Lynxville, Wisconsin 54640',17234,21377);
INSERT INTO "django_geo_db_zipcode" VALUES(24176,54641,-6,'Mather, Wisconsin 54641',17235,21378);
INSERT INTO "django_geo_db_zipcode" VALUES(24177,54642,-6,'Melrose, Wisconsin 54642',17236,21379);
INSERT INTO "django_geo_db_zipcode" VALUES(24178,54643,-6,'Millston, Wisconsin 54643',17237,21380);
INSERT INTO "django_geo_db_zipcode" VALUES(24179,54644,-6,'Mindoro, Wisconsin 54644',17238,21381);
INSERT INTO "django_geo_db_zipcode" VALUES(24180,54645,-6,'Mount Sterling, Wisconsin 54645',17239,21382);
INSERT INTO "django_geo_db_zipcode" VALUES(24181,54646,-6,'Necedah, Wisconsin 54646',17240,21383);
INSERT INTO "django_geo_db_zipcode" VALUES(24182,54648,-6,'Norwalk, Wisconsin 54648',17241,21384);
INSERT INTO "django_geo_db_zipcode" VALUES(24183,54649,-6,'Oakdale, Wisconsin 54649',17242,21385);
INSERT INTO "django_geo_db_zipcode" VALUES(24184,54650,-6,'Onalaska, Wisconsin 54650',17243,21386);
INSERT INTO "django_geo_db_zipcode" VALUES(24185,54651,-6,'Ontario, Wisconsin 54651',17244,21387);
INSERT INTO "django_geo_db_zipcode" VALUES(24186,54652,-6,'Readstown, Wisconsin 54652',17245,21388);
INSERT INTO "django_geo_db_zipcode" VALUES(24187,54653,-6,'Rockland, Wisconsin 54653',17246,21389);
INSERT INTO "django_geo_db_zipcode" VALUES(24188,54654,-6,'Seneca, Wisconsin 54654',17247,21390);
INSERT INTO "django_geo_db_zipcode" VALUES(24189,54655,-6,'Soldiers Grove, Wisconsin 54655',17248,21391);
INSERT INTO "django_geo_db_zipcode" VALUES(24190,54656,-6,'Sparta, Wisconsin 54656',17249,21392);
INSERT INTO "django_geo_db_zipcode" VALUES(24191,54657,-6,'Steuben, Wisconsin 54657',17250,21393);
INSERT INTO "django_geo_db_zipcode" VALUES(24192,54658,-6,'Stoddard, Wisconsin 54658',17251,21394);
INSERT INTO "django_geo_db_zipcode" VALUES(24193,54659,-6,'Taylor, Wisconsin 54659',17252,21395);
INSERT INTO "django_geo_db_zipcode" VALUES(24194,54660,-6,'Tomah, Wisconsin 54660',17253,21396);
INSERT INTO "django_geo_db_zipcode" VALUES(24195,54661,-6,'Trempealeau, Wisconsin 54661',17254,21397);
INSERT INTO "django_geo_db_zipcode" VALUES(24196,54662,-6,'Tunnel City, Wisconsin 54662',17255,21398);
INSERT INTO "django_geo_db_zipcode" VALUES(24197,54664,-6,'Viola, Wisconsin 54664',17256,21399);
INSERT INTO "django_geo_db_zipcode" VALUES(24198,54665,-6,'Viroqua, Wisconsin 54665',17257,21400);
INSERT INTO "django_geo_db_zipcode" VALUES(24199,54666,-6,'Warrens, Wisconsin 54666',17258,21401);
INSERT INTO "django_geo_db_zipcode" VALUES(24200,54667,-6,'Westby, Wisconsin 54667',17259,21402);
INSERT INTO "django_geo_db_zipcode" VALUES(24201,54669,-6,'West Salem, Wisconsin 54669',17260,21403);
INSERT INTO "django_geo_db_zipcode" VALUES(24202,54670,-6,'Wilton, Wisconsin 54670',17261,21404);
INSERT INTO "django_geo_db_zipcode" VALUES(24203,54699,-6,'West Salem, Wisconsin 54699',17260,21405);
INSERT INTO "django_geo_db_zipcode" VALUES(24204,54701,-6,'Eau Claire, Wisconsin 54701',17262,21406);
INSERT INTO "django_geo_db_zipcode" VALUES(24205,54702,-6,'Eau Claire, Wisconsin 54702',17262,21407);
INSERT INTO "django_geo_db_zipcode" VALUES(24206,54703,-6,'Eau Claire, Wisconsin 54703',17262,21408);
INSERT INTO "django_geo_db_zipcode" VALUES(24207,54720,-6,'Altoona, Wisconsin 54720',17263,21409);
INSERT INTO "django_geo_db_zipcode" VALUES(24208,54721,-6,'Arkansaw, Wisconsin 54721',17264,21410);
INSERT INTO "django_geo_db_zipcode" VALUES(24209,54722,-6,'Augusta, Wisconsin 54722',17265,21411);
INSERT INTO "django_geo_db_zipcode" VALUES(24210,54723,-6,'Bay City, Wisconsin 54723',17266,21412);
INSERT INTO "django_geo_db_zipcode" VALUES(24211,54724,-6,'Bloomer, Wisconsin 54724',17267,21413);
INSERT INTO "django_geo_db_zipcode" VALUES(24212,54725,-6,'Boyceville, Wisconsin 54725',17268,21414);
INSERT INTO "django_geo_db_zipcode" VALUES(24213,54726,-6,'Boyd, Wisconsin 54726',17269,21415);
INSERT INTO "django_geo_db_zipcode" VALUES(24214,54727,-6,'Cadott, Wisconsin 54727',17270,21416);
INSERT INTO "django_geo_db_zipcode" VALUES(24215,54728,-6,'Chetek, Wisconsin 54728',17271,21417);
INSERT INTO "django_geo_db_zipcode" VALUES(24216,54729,-6,'Chippewa Falls, Wisconsin 54729',17272,21418);
INSERT INTO "django_geo_db_zipcode" VALUES(24217,54730,-6,'Colfax, Wisconsin 54730',17273,21419);
INSERT INTO "django_geo_db_zipcode" VALUES(24218,54731,-6,'Conrath, Wisconsin 54731',17274,21420);
INSERT INTO "django_geo_db_zipcode" VALUES(24219,54732,-6,'Cornell, Wisconsin 54732',17275,21421);
INSERT INTO "django_geo_db_zipcode" VALUES(24220,54733,-6,'Dallas, Wisconsin 54733',17276,21422);
INSERT INTO "django_geo_db_zipcode" VALUES(24221,54734,-6,'Downing, Wisconsin 54734',17277,21423);
INSERT INTO "django_geo_db_zipcode" VALUES(24222,54735,-6,'Downsville, Wisconsin 54735',17278,21424);
INSERT INTO "django_geo_db_zipcode" VALUES(24223,54736,-6,'Durand, Wisconsin 54736',17279,21425);
INSERT INTO "django_geo_db_zipcode" VALUES(24224,54737,-6,'Eau Galle, Wisconsin 54737',17280,21426);
INSERT INTO "django_geo_db_zipcode" VALUES(24225,54738,-6,'Eleva, Wisconsin 54738',17281,21427);
INSERT INTO "django_geo_db_zipcode" VALUES(24226,54739,-6,'Elk Mound, Wisconsin 54739',17282,21428);
INSERT INTO "django_geo_db_zipcode" VALUES(24227,54740,-6,'Elmwood, Wisconsin 54740',17283,21429);
INSERT INTO "django_geo_db_zipcode" VALUES(24228,54741,-6,'Fairchild, Wisconsin 54741',17284,21430);
INSERT INTO "django_geo_db_zipcode" VALUES(24229,54742,-6,'Fall Creek, Wisconsin 54742',17285,21431);
INSERT INTO "django_geo_db_zipcode" VALUES(24230,54743,-6,'Gilmanton, Wisconsin 54743',17286,21432);
INSERT INTO "django_geo_db_zipcode" VALUES(24231,54744,-6,'Hillsdale, Wisconsin 54744',17287,21433);
INSERT INTO "django_geo_db_zipcode" VALUES(24232,54745,-6,'Holcombe, Wisconsin 54745',17288,21434);
INSERT INTO "django_geo_db_zipcode" VALUES(24233,54746,-6,'Humbird, Wisconsin 54746',17289,21435);
INSERT INTO "django_geo_db_zipcode" VALUES(24234,54747,-6,'Independence, Wisconsin 54747',17290,21436);
INSERT INTO "django_geo_db_zipcode" VALUES(24235,54748,-6,'Jim Falls, Wisconsin 54748',17291,21437);
INSERT INTO "django_geo_db_zipcode" VALUES(24236,54749,-6,'Knapp, Wisconsin 54749',17292,21438);
INSERT INTO "django_geo_db_zipcode" VALUES(24237,54750,-6,'Maiden Rock, Wisconsin 54750',17293,21439);
INSERT INTO "django_geo_db_zipcode" VALUES(24238,54751,-6,'Menomonie, Wisconsin 54751',17294,21440);
INSERT INTO "django_geo_db_zipcode" VALUES(24239,54754,-6,'Merrillan, Wisconsin 54754',17295,21441);
INSERT INTO "django_geo_db_zipcode" VALUES(24240,54755,-6,'Mondovi, Wisconsin 54755',17296,21442);
INSERT INTO "django_geo_db_zipcode" VALUES(24241,54756,-6,'Nelson, Wisconsin 54756',17297,21443);
INSERT INTO "django_geo_db_zipcode" VALUES(24242,54757,-6,'New Auburn, Wisconsin 54757',17298,21444);
INSERT INTO "django_geo_db_zipcode" VALUES(24243,54758,-6,'Osseo, Wisconsin 54758',17299,21445);
INSERT INTO "django_geo_db_zipcode" VALUES(24244,54759,-6,'Pepin, Wisconsin 54759',17300,21446);
INSERT INTO "django_geo_db_zipcode" VALUES(24245,54760,-6,'Pigeon Falls, Wisconsin 54760',17301,21447);
INSERT INTO "django_geo_db_zipcode" VALUES(24246,54761,-6,'Plum City, Wisconsin 54761',17302,21448);
INSERT INTO "django_geo_db_zipcode" VALUES(24247,54762,-6,'Prairie Farm, Wisconsin 54762',17303,21449);
INSERT INTO "django_geo_db_zipcode" VALUES(24248,54763,-6,'Ridgeland, Wisconsin 54763',17304,21450);
INSERT INTO "django_geo_db_zipcode" VALUES(24249,54764,-6,'Rock Falls, Wisconsin 54764',17305,21424);
INSERT INTO "django_geo_db_zipcode" VALUES(24250,54765,-6,'Sand Creek, Wisconsin 54765',17306,21451);
INSERT INTO "django_geo_db_zipcode" VALUES(24251,54766,-6,'Sheldon, Wisconsin 54766',17307,21452);
INSERT INTO "django_geo_db_zipcode" VALUES(24252,54767,-6,'Spring Valley, Wisconsin 54767',17308,21453);
INSERT INTO "django_geo_db_zipcode" VALUES(24253,54768,-6,'Stanley, Wisconsin 54768',17309,21454);
INSERT INTO "django_geo_db_zipcode" VALUES(24254,54769,-6,'Stockholm, Wisconsin 54769',17310,21455);
INSERT INTO "django_geo_db_zipcode" VALUES(24255,54770,-6,'Strum, Wisconsin 54770',17311,21456);
INSERT INTO "django_geo_db_zipcode" VALUES(24256,54771,-6,'Thorp, Wisconsin 54771',17312,21457);
INSERT INTO "django_geo_db_zipcode" VALUES(24257,54772,-6,'Wheeler, Wisconsin 54772',17313,21458);
INSERT INTO "django_geo_db_zipcode" VALUES(24258,54773,-6,'Whitehall, Wisconsin 54773',17314,21459);
INSERT INTO "django_geo_db_zipcode" VALUES(24259,54774,-6,'Chippewa Falls, Wisconsin 54774',17272,21460);
INSERT INTO "django_geo_db_zipcode" VALUES(24260,54801,-6,'Spooner, Wisconsin 54801',17315,21461);
INSERT INTO "django_geo_db_zipcode" VALUES(24261,54805,-6,'Almena, Wisconsin 54805',17316,21462);
INSERT INTO "django_geo_db_zipcode" VALUES(24262,54806,-6,'Ashland, Wisconsin 54806',17317,21463);
INSERT INTO "django_geo_db_zipcode" VALUES(24263,54810,-6,'Balsam Lake, Wisconsin 54810',17318,21464);
INSERT INTO "django_geo_db_zipcode" VALUES(24264,54812,-6,'Barron, Wisconsin 54812',17319,21465);
INSERT INTO "django_geo_db_zipcode" VALUES(24265,54813,-6,'Barronett, Wisconsin 54813',17320,21466);
INSERT INTO "django_geo_db_zipcode" VALUES(24266,54814,-6,'Bayfield, Wisconsin 54814',17321,21467);
INSERT INTO "django_geo_db_zipcode" VALUES(24267,54816,-6,'Benoit, Wisconsin 54816',17322,21468);
INSERT INTO "django_geo_db_zipcode" VALUES(24268,54817,-6,'Birchwood, Wisconsin 54817',17323,21469);
INSERT INTO "django_geo_db_zipcode" VALUES(24269,54818,-6,'Brill, Wisconsin 54818',17324,21470);
INSERT INTO "django_geo_db_zipcode" VALUES(24270,54819,-6,'Bruce, Wisconsin 54819',17325,21471);
INSERT INTO "django_geo_db_zipcode" VALUES(24271,54820,-6,'Brule, Wisconsin 54820',17326,21472);
INSERT INTO "django_geo_db_zipcode" VALUES(24272,54821,-6,'Cable, Wisconsin 54821',17327,21473);
INSERT INTO "django_geo_db_zipcode" VALUES(24273,54822,-6,'Cameron, Wisconsin 54822',17328,21474);
INSERT INTO "django_geo_db_zipcode" VALUES(24274,54824,-6,'Centuria, Wisconsin 54824',17329,21475);
INSERT INTO "django_geo_db_zipcode" VALUES(24275,54826,-6,'Comstock, Wisconsin 54826',17330,21476);
INSERT INTO "django_geo_db_zipcode" VALUES(24276,54827,-6,'Cornucopia, Wisconsin 54827',17331,21477);
INSERT INTO "django_geo_db_zipcode" VALUES(24277,54828,-6,'Couderay, Wisconsin 54828',17332,21478);
INSERT INTO "django_geo_db_zipcode" VALUES(24278,54829,-6,'Cumberland, Wisconsin 54829',17333,21479);
INSERT INTO "django_geo_db_zipcode" VALUES(24279,54830,-6,'Danbury, Wisconsin 54830',17334,21480);
INSERT INTO "django_geo_db_zipcode" VALUES(24280,54832,-6,'Drummond, Wisconsin 54832',17335,21481);
INSERT INTO "django_geo_db_zipcode" VALUES(24281,54834,-6,'Edgewater, Wisconsin 54834',17336,21482);
INSERT INTO "django_geo_db_zipcode" VALUES(24282,54835,-6,'Exeland, Wisconsin 54835',17337,21483);
INSERT INTO "django_geo_db_zipcode" VALUES(24283,54836,-6,'Foxboro, Wisconsin 54836',17338,21484);
INSERT INTO "django_geo_db_zipcode" VALUES(24284,54837,-6,'Frederic, Wisconsin 54837',17339,21485);
INSERT INTO "django_geo_db_zipcode" VALUES(24285,54838,-6,'Gordon, Wisconsin 54838',17340,21486);
INSERT INTO "django_geo_db_zipcode" VALUES(24286,54839,-6,'Grand View, Wisconsin 54839',17341,21487);
INSERT INTO "django_geo_db_zipcode" VALUES(24287,54840,-6,'Grantsburg, Wisconsin 54840',17342,21488);
INSERT INTO "django_geo_db_zipcode" VALUES(24288,54841,-6,'Haugen, Wisconsin 54841',17343,21489);
INSERT INTO "django_geo_db_zipcode" VALUES(24289,54842,-6,'Hawthorne, Wisconsin 54842',17344,21490);
INSERT INTO "django_geo_db_zipcode" VALUES(24290,54843,-6,'Hayward, Wisconsin 54843',17345,21491);
INSERT INTO "django_geo_db_zipcode" VALUES(24291,54844,-6,'Herbster, Wisconsin 54844',17346,21492);
INSERT INTO "django_geo_db_zipcode" VALUES(24292,54845,-6,'Hertel, Wisconsin 54845',17347,21493);
INSERT INTO "django_geo_db_zipcode" VALUES(24293,54846,-6,'High Bridge, Wisconsin 54846',17348,21494);
INSERT INTO "django_geo_db_zipcode" VALUES(24294,54847,-6,'Iron River, Wisconsin 54847',17349,21495);
INSERT INTO "django_geo_db_zipcode" VALUES(24295,54848,-6,'Ladysmith, Wisconsin 54848',17350,21496);
INSERT INTO "django_geo_db_zipcode" VALUES(24296,54849,-6,'Lake Nebagamon, Wisconsin 54849',17351,21497);
INSERT INTO "django_geo_db_zipcode" VALUES(24297,54850,-6,'La Pointe, Wisconsin 54850',17352,21498);
INSERT INTO "django_geo_db_zipcode" VALUES(24298,54851,-6,'Lewis, Wisconsin 54851',17353,21499);
INSERT INTO "django_geo_db_zipcode" VALUES(24299,54853,-6,'Luck, Wisconsin 54853',17354,21500);
INSERT INTO "django_geo_db_zipcode" VALUES(24300,54854,-6,'Maple, Wisconsin 54854',17355,21501);
INSERT INTO "django_geo_db_zipcode" VALUES(24301,54855,-6,'Marengo, Wisconsin 54855',17356,21502);
INSERT INTO "django_geo_db_zipcode" VALUES(24302,54856,-6,'Mason, Wisconsin 54856',17357,21503);
INSERT INTO "django_geo_db_zipcode" VALUES(24303,54857,-6,'Mikana, Wisconsin 54857',17358,21504);
INSERT INTO "django_geo_db_zipcode" VALUES(24304,54858,-6,'Milltown, Wisconsin 54858',17359,21505);
INSERT INTO "django_geo_db_zipcode" VALUES(24305,54859,-6,'Minong, Wisconsin 54859',17360,21506);
INSERT INTO "django_geo_db_zipcode" VALUES(24306,54861,-6,'Odanah, Wisconsin 54861',17361,21507);
INSERT INTO "django_geo_db_zipcode" VALUES(24307,54862,-6,'Ojibwa, Wisconsin 54862',17362,21508);
INSERT INTO "django_geo_db_zipcode" VALUES(24308,54863,-6,'Stanley, Wisconsin 54863',17309,21509);
INSERT INTO "django_geo_db_zipcode" VALUES(24309,54864,-6,'Poplar, Wisconsin 54864',17363,21510);
INSERT INTO "django_geo_db_zipcode" VALUES(24310,54865,-6,'Port Wing, Wisconsin 54865',17364,21511);
INSERT INTO "django_geo_db_zipcode" VALUES(24311,54867,-6,'Radisson, Wisconsin 54867',17365,21512);
INSERT INTO "django_geo_db_zipcode" VALUES(24312,54868,-6,'Rice Lake, Wisconsin 54868',17366,21513);
INSERT INTO "django_geo_db_zipcode" VALUES(24313,54870,-6,'Sarona, Wisconsin 54870',17367,21514);
INSERT INTO "django_geo_db_zipcode" VALUES(24314,54871,-6,'Shell Lake, Wisconsin 54871',17368,21515);
INSERT INTO "django_geo_db_zipcode" VALUES(24315,54872,-6,'Siren, Wisconsin 54872',17369,21516);
INSERT INTO "django_geo_db_zipcode" VALUES(24316,54873,-6,'Solon Springs, Wisconsin 54873',17370,21517);
INSERT INTO "django_geo_db_zipcode" VALUES(24317,54874,-6,'South Range, Wisconsin 54874',17371,21518);
INSERT INTO "django_geo_db_zipcode" VALUES(24318,54875,-6,'Springbrook, Wisconsin 54875',17372,21519);
INSERT INTO "django_geo_db_zipcode" VALUES(24319,54876,-6,'Stone Lake, Wisconsin 54876',17373,21520);
INSERT INTO "django_geo_db_zipcode" VALUES(24320,54880,-6,'Superior, Wisconsin 54880',17374,21521);
INSERT INTO "django_geo_db_zipcode" VALUES(24321,54886,-6,'Winter, Wisconsin 54886',17375,21522);
INSERT INTO "django_geo_db_zipcode" VALUES(24322,54888,-6,'Trego, Wisconsin 54888',17376,21523);
INSERT INTO "django_geo_db_zipcode" VALUES(24323,54889,-6,'Turtle Lake, Wisconsin 54889',17377,21524);
INSERT INTO "django_geo_db_zipcode" VALUES(24324,54890,-6,'Wascott, Wisconsin 54890',17075,21525);
INSERT INTO "django_geo_db_zipcode" VALUES(24325,54891,-6,'Washburn, Wisconsin 54891',17378,21526);
INSERT INTO "django_geo_db_zipcode" VALUES(24326,54893,-6,'Webster, Wisconsin 54893',17379,21527);
INSERT INTO "django_geo_db_zipcode" VALUES(24327,54895,-6,'Weyerhaeuser, Wisconsin 54895',17380,21528);
INSERT INTO "django_geo_db_zipcode" VALUES(24328,54896,-6,'Winter, Wisconsin 54896',17375,21529);
INSERT INTO "django_geo_db_zipcode" VALUES(24329,54901,-6,'Oshkosh, Wisconsin 54901',17381,21530);
INSERT INTO "django_geo_db_zipcode" VALUES(24330,54902,-6,'Oshkosh, Wisconsin 54902',17381,21531);
INSERT INTO "django_geo_db_zipcode" VALUES(24331,54903,-6,'Oshkosh, Wisconsin 54903',17381,21532);
INSERT INTO "django_geo_db_zipcode" VALUES(24332,54904,-6,'Oshkosh, Wisconsin 54904',17381,21533);
INSERT INTO "django_geo_db_zipcode" VALUES(24333,54906,-6,'Oshkosh, Wisconsin 54906',17381,21532);
INSERT INTO "django_geo_db_zipcode" VALUES(24334,54909,-6,'Almond, Wisconsin 54909',17382,21534);
INSERT INTO "django_geo_db_zipcode" VALUES(24335,54911,-6,'Appleton, Wisconsin 54911',17383,21535);
INSERT INTO "django_geo_db_zipcode" VALUES(24336,54912,-6,'Appleton, Wisconsin 54912',17383,21135);
INSERT INTO "django_geo_db_zipcode" VALUES(24337,54913,-6,'Appleton, Wisconsin 54913',17383,21536);
INSERT INTO "django_geo_db_zipcode" VALUES(24338,54914,-6,'Appleton, Wisconsin 54914',17383,21537);
INSERT INTO "django_geo_db_zipcode" VALUES(24339,54915,-6,'Appleton, Wisconsin 54915',17383,21538);
INSERT INTO "django_geo_db_zipcode" VALUES(24340,54919,-6,'Appleton, Wisconsin 54919',17383,21135);
INSERT INTO "django_geo_db_zipcode" VALUES(24341,54921,-6,'Bancroft, Wisconsin 54921',17384,21539);
INSERT INTO "django_geo_db_zipcode" VALUES(24342,54922,-6,'Bear Creek, Wisconsin 54922',17385,21540);
INSERT INTO "django_geo_db_zipcode" VALUES(24343,54923,-6,'Berlin, Wisconsin 54923',17386,21541);
INSERT INTO "django_geo_db_zipcode" VALUES(24344,54926,-6,'Big Falls, Wisconsin 54926',17387,21542);
INSERT INTO "django_geo_db_zipcode" VALUES(24345,54927,-6,'Butte Des Morts, Wisconsin 54927',17388,21543);
INSERT INTO "django_geo_db_zipcode" VALUES(24346,54928,-6,'Caroline, Wisconsin 54928',17389,21544);
INSERT INTO "django_geo_db_zipcode" VALUES(24347,54929,-6,'Clintonville, Wisconsin 54929',17390,21545);
INSERT INTO "django_geo_db_zipcode" VALUES(24348,54930,-6,'Coloma, Wisconsin 54930',17391,21546);
INSERT INTO "django_geo_db_zipcode" VALUES(24349,54931,-6,'Dale, Wisconsin 54931',17392,21135);
INSERT INTO "django_geo_db_zipcode" VALUES(24350,54932,-6,'Eldorado, Wisconsin 54932',17393,21547);
INSERT INTO "django_geo_db_zipcode" VALUES(24351,54933,-6,'Embarrass, Wisconsin 54933',17394,21548);
INSERT INTO "django_geo_db_zipcode" VALUES(24352,54934,-6,'Eureka, Wisconsin 54934',17395,21549);
INSERT INTO "django_geo_db_zipcode" VALUES(24353,54935,-6,'Fond Du Lac, Wisconsin 54935',17396,21550);
INSERT INTO "django_geo_db_zipcode" VALUES(24354,54936,-6,'Fond Du Lac, Wisconsin 54936',17396,21551);
INSERT INTO "django_geo_db_zipcode" VALUES(24355,54937,-6,'Fond Du Lac, Wisconsin 54937',17396,21552);
INSERT INTO "django_geo_db_zipcode" VALUES(24356,54940,-6,'Fremont, Wisconsin 54940',17397,21553);
INSERT INTO "django_geo_db_zipcode" VALUES(24357,54941,-6,'Green Lake, Wisconsin 54941',17398,21554);
INSERT INTO "django_geo_db_zipcode" VALUES(24358,54942,-6,'Greenville, Wisconsin 54942',17399,21555);
INSERT INTO "django_geo_db_zipcode" VALUES(24359,54943,-6,'Hancock, Wisconsin 54943',17400,21556);
INSERT INTO "django_geo_db_zipcode" VALUES(24360,54944,-6,'Hortonville, Wisconsin 54944',17401,21557);
INSERT INTO "django_geo_db_zipcode" VALUES(24361,54945,-6,'Iola, Wisconsin 54945',17402,21558);
INSERT INTO "django_geo_db_zipcode" VALUES(24362,54946,-6,'King, Wisconsin 54946',17403,21559);
INSERT INTO "django_geo_db_zipcode" VALUES(24363,54947,-6,'Larsen, Wisconsin 54947',17404,21560);
INSERT INTO "django_geo_db_zipcode" VALUES(24364,54948,-6,'Leopolis, Wisconsin 54948',17405,21561);
INSERT INTO "django_geo_db_zipcode" VALUES(24365,54949,-6,'Manawa, Wisconsin 54949',17406,21562);
INSERT INTO "django_geo_db_zipcode" VALUES(24366,54950,-6,'Marion, Wisconsin 54950',17407,21563);
INSERT INTO "django_geo_db_zipcode" VALUES(24367,54951,-6,'Medina, Wisconsin 54951',17408,21135);
INSERT INTO "django_geo_db_zipcode" VALUES(24368,54952,-6,'Menasha, Wisconsin 54952',17409,21564);
INSERT INTO "django_geo_db_zipcode" VALUES(24369,54956,-6,'Neenah, Wisconsin 54956',17410,21565);
INSERT INTO "django_geo_db_zipcode" VALUES(24370,54957,-6,'Neenah, Wisconsin 54957',17410,21566);
INSERT INTO "django_geo_db_zipcode" VALUES(24371,54960,-6,'Neshkoro, Wisconsin 54960',17411,21567);
INSERT INTO "django_geo_db_zipcode" VALUES(24372,54961,-6,'New London, Wisconsin 54961',16981,21568);
INSERT INTO "django_geo_db_zipcode" VALUES(24373,54962,-6,'Ogdensburg, Wisconsin 54962',17412,21569);
INSERT INTO "django_geo_db_zipcode" VALUES(24374,54963,-6,'Omro, Wisconsin 54963',17413,21570);
INSERT INTO "django_geo_db_zipcode" VALUES(24375,54964,-6,'Pickett, Wisconsin 54964',17414,21571);
INSERT INTO "django_geo_db_zipcode" VALUES(24376,54965,-6,'Pine River, Wisconsin 54965',17415,21572);
INSERT INTO "django_geo_db_zipcode" VALUES(24377,54966,-6,'Plainfield, Wisconsin 54966',17416,21573);
INSERT INTO "django_geo_db_zipcode" VALUES(24378,54967,-6,'Poy Sippi, Wisconsin 54967',17417,21574);
INSERT INTO "django_geo_db_zipcode" VALUES(24379,54968,-6,'Princeton, Wisconsin 54968',17418,21575);
INSERT INTO "django_geo_db_zipcode" VALUES(24380,54969,-6,'Readfield, Wisconsin 54969',17419,21576);
INSERT INTO "django_geo_db_zipcode" VALUES(24381,54970,-6,'Redgranite, Wisconsin 54970',17420,21577);
INSERT INTO "django_geo_db_zipcode" VALUES(24382,54971,-6,'Ripon, Wisconsin 54971',17421,21578);
INSERT INTO "django_geo_db_zipcode" VALUES(24383,54974,-6,'Rosendale, Wisconsin 54974',17422,21579);
INSERT INTO "django_geo_db_zipcode" VALUES(24384,54975,-6,'Royalton, Wisconsin 54975',17423,21580);
INSERT INTO "django_geo_db_zipcode" VALUES(24385,54976,-6,'Saxeville, Wisconsin 54976',17424,21581);
INSERT INTO "django_geo_db_zipcode" VALUES(24386,54977,-6,'Scandinavia, Wisconsin 54977',17425,21582);
INSERT INTO "django_geo_db_zipcode" VALUES(24387,54978,-6,'Tilleda, Wisconsin 54978',17426,21583);
INSERT INTO "django_geo_db_zipcode" VALUES(24388,54979,-6,'Van Dyne, Wisconsin 54979',17427,21584);
INSERT INTO "django_geo_db_zipcode" VALUES(24389,54980,-6,'Waukau, Wisconsin 54980',17428,21585);
INSERT INTO "django_geo_db_zipcode" VALUES(24390,54981,-6,'Waupaca, Wisconsin 54981',17429,21586);
INSERT INTO "django_geo_db_zipcode" VALUES(24391,54982,-6,'Wautoma, Wisconsin 54982',17430,21587);
INSERT INTO "django_geo_db_zipcode" VALUES(24392,54983,-6,'Weyauwega, Wisconsin 54983',17431,21588);
INSERT INTO "django_geo_db_zipcode" VALUES(24393,54984,-6,'Wild Rose, Wisconsin 54984',17432,21589);
INSERT INTO "django_geo_db_zipcode" VALUES(24394,54985,-6,'Winnebago, Wisconsin 54985',17433,21590);
INSERT INTO "django_geo_db_zipcode" VALUES(24395,54986,-6,'Winneconne, Wisconsin 54986',17434,21591);
INSERT INTO "django_geo_db_zipcode" VALUES(24396,54990,-6,'Iola, Wisconsin 54990',17402,21580);
INSERT INTO "django_geo_db_zipcode" VALUES(24397,55001,-6,'Afton, Minnesota 55001',17435,21592);
INSERT INTO "django_geo_db_zipcode" VALUES(24398,55002,-6,'Almelund, Minnesota 55002',17436,21593);
INSERT INTO "django_geo_db_zipcode" VALUES(24399,55003,-6,'Bayport, Minnesota 55003',17437,21594);
INSERT INTO "django_geo_db_zipcode" VALUES(24400,55005,-6,'Bethel, Minnesota 55005',17438,21595);
INSERT INTO "django_geo_db_zipcode" VALUES(24401,55006,-6,'Braham, Minnesota 55006',17439,21596);
INSERT INTO "django_geo_db_zipcode" VALUES(24402,55007,-6,'Brook Park, Minnesota 55007',17440,21597);
INSERT INTO "django_geo_db_zipcode" VALUES(24403,55008,-6,'Cambridge, Minnesota 55008',17441,21598);
INSERT INTO "django_geo_db_zipcode" VALUES(24404,55009,-6,'Cannon Falls, Minnesota 55009',17442,21599);
INSERT INTO "django_geo_db_zipcode" VALUES(24405,55010,-6,'Castle Rock, Minnesota 55010',17443,21600);
INSERT INTO "django_geo_db_zipcode" VALUES(24406,55011,-6,'Cedar, Minnesota 55011',17444,21601);
INSERT INTO "django_geo_db_zipcode" VALUES(24407,55012,-6,'Center City, Minnesota 55012',17445,21602);
INSERT INTO "django_geo_db_zipcode" VALUES(24408,55013,-6,'Chisago City, Minnesota 55013',17446,21603);
INSERT INTO "django_geo_db_zipcode" VALUES(24409,55014,-6,'Circle Pines, Minnesota 55014',17447,21604);
INSERT INTO "django_geo_db_zipcode" VALUES(24410,55016,-6,'Cottage Grove, Minnesota 55016',17448,21605);
INSERT INTO "django_geo_db_zipcode" VALUES(24411,55017,-6,'Dalbo, Minnesota 55017',17449,21606);
INSERT INTO "django_geo_db_zipcode" VALUES(24412,55018,-6,'Dennison, Minnesota 55018',17450,21607);
INSERT INTO "django_geo_db_zipcode" VALUES(24413,55019,-6,'Dundas, Minnesota 55019',17451,21608);
INSERT INTO "django_geo_db_zipcode" VALUES(24414,55020,-6,'Elko, Minnesota 55020',17452,21609);
INSERT INTO "django_geo_db_zipcode" VALUES(24415,55021,-6,'Faribault, Minnesota 55021',17453,21610);
INSERT INTO "django_geo_db_zipcode" VALUES(24416,55024,-6,'Farmington, Minnesota 55024',17454,21611);
INSERT INTO "django_geo_db_zipcode" VALUES(24417,55025,-6,'Forest Lake, Minnesota 55025',17455,21612);
INSERT INTO "django_geo_db_zipcode" VALUES(24418,55026,-6,'Frontenac, Minnesota 55026',17456,21613);
INSERT INTO "django_geo_db_zipcode" VALUES(24419,55027,-6,'Goodhue, Minnesota 55027',17457,21614);
INSERT INTO "django_geo_db_zipcode" VALUES(24420,55029,-6,'Grandy, Minnesota 55029',17458,21615);
INSERT INTO "django_geo_db_zipcode" VALUES(24421,55030,-6,'Grasston, Minnesota 55030',17459,21616);
INSERT INTO "django_geo_db_zipcode" VALUES(24422,55031,-6,'Hampton, Minnesota 55031',17460,21617);
INSERT INTO "django_geo_db_zipcode" VALUES(24423,55032,-6,'Harris, Minnesota 55032',17461,21618);
INSERT INTO "django_geo_db_zipcode" VALUES(24424,55033,-6,'Hastings, Minnesota 55033',17462,21619);
INSERT INTO "django_geo_db_zipcode" VALUES(24425,55036,-6,'Henriette, Minnesota 55036',17463,21620);
INSERT INTO "django_geo_db_zipcode" VALUES(24426,55037,-6,'Hinckley, Minnesota 55037',17464,21621);
INSERT INTO "django_geo_db_zipcode" VALUES(24427,55038,-6,'Hugo, Minnesota 55038',17465,21622);
INSERT INTO "django_geo_db_zipcode" VALUES(24428,55040,-6,'Isanti, Minnesota 55040',17466,21623);
INSERT INTO "django_geo_db_zipcode" VALUES(24429,55041,-6,'Lake City, Minnesota 55041',17467,21624);
INSERT INTO "django_geo_db_zipcode" VALUES(24430,55042,-6,'Lake Elmo, Minnesota 55042',17468,21625);
INSERT INTO "django_geo_db_zipcode" VALUES(24431,55043,-6,'Lakeland, Minnesota 55043',17469,21626);
INSERT INTO "django_geo_db_zipcode" VALUES(24432,55044,-6,'Lakeville, Minnesota 55044',17470,21627);
INSERT INTO "django_geo_db_zipcode" VALUES(24433,55045,-6,'Lindstrom, Minnesota 55045',17471,21628);
INSERT INTO "django_geo_db_zipcode" VALUES(24434,55046,-6,'Lonsdale, Minnesota 55046',17472,21629);
INSERT INTO "django_geo_db_zipcode" VALUES(24435,55047,-6,'Marine On Saint Croix, Minnesota 55047',17473,21630);
INSERT INTO "django_geo_db_zipcode" VALUES(24436,55049,-6,'Medford, Minnesota 55049',17474,21631);
INSERT INTO "django_geo_db_zipcode" VALUES(24437,55051,-6,'Mora, Minnesota 55051',17475,21632);
INSERT INTO "django_geo_db_zipcode" VALUES(24438,55052,-6,'Morristown, Minnesota 55052',17476,21633);
INSERT INTO "django_geo_db_zipcode" VALUES(24439,55053,-6,'Nerstrand, Minnesota 55053',17477,21634);
INSERT INTO "django_geo_db_zipcode" VALUES(24440,55054,-6,'New Market, Minnesota 55054',17478,21635);
INSERT INTO "django_geo_db_zipcode" VALUES(24441,55055,-6,'Newport, Minnesota 55055',17479,21636);
INSERT INTO "django_geo_db_zipcode" VALUES(24442,55056,-6,'North Branch, Minnesota 55056',17480,21637);
INSERT INTO "django_geo_db_zipcode" VALUES(24443,55057,-6,'Northfield, Minnesota 55057',17481,21638);
INSERT INTO "django_geo_db_zipcode" VALUES(24444,55060,-6,'Owatonna, Minnesota 55060',17482,21639);
INSERT INTO "django_geo_db_zipcode" VALUES(24445,55063,-6,'Pine City, Minnesota 55063',17483,21640);
INSERT INTO "django_geo_db_zipcode" VALUES(24446,55065,-6,'Randolph, Minnesota 55065',17484,21641);
INSERT INTO "django_geo_db_zipcode" VALUES(24447,55066,-6,'Red Wing, Minnesota 55066',17485,21642);
INSERT INTO "django_geo_db_zipcode" VALUES(24448,55067,-6,'Rock Creek, Minnesota 55067',17486,21643);
INSERT INTO "django_geo_db_zipcode" VALUES(24449,55068,-6,'Rosemount, Minnesota 55068',17487,21644);
INSERT INTO "django_geo_db_zipcode" VALUES(24450,55069,-6,'Rush City, Minnesota 55069',17488,21645);
INSERT INTO "django_geo_db_zipcode" VALUES(24451,55070,-6,'Saint Francis, Minnesota 55070',17489,21646);
INSERT INTO "django_geo_db_zipcode" VALUES(24452,55071,-6,'Saint Paul Park, Minnesota 55071',17490,21647);
INSERT INTO "django_geo_db_zipcode" VALUES(24453,55072,-6,'Sandstone, Minnesota 55072',17491,21648);
INSERT INTO "django_geo_db_zipcode" VALUES(24454,55073,-6,'Scandia, Minnesota 55073',17492,21649);
INSERT INTO "django_geo_db_zipcode" VALUES(24455,55074,-6,'Shafer, Minnesota 55074',17493,21650);
INSERT INTO "django_geo_db_zipcode" VALUES(24456,55075,-6,'South Saint Paul, Minnesota 55075',17494,21651);
INSERT INTO "django_geo_db_zipcode" VALUES(24457,55076,-6,'Inver Grove Heights, Minnesota 55076',17495,21652);
INSERT INTO "django_geo_db_zipcode" VALUES(24458,55077,-6,'Inver Grove Heights, Minnesota 55077',17495,21653);
INSERT INTO "django_geo_db_zipcode" VALUES(24459,55078,-6,'Stacy, Minnesota 55078',17496,21593);
INSERT INTO "django_geo_db_zipcode" VALUES(24460,55079,-6,'Stacy, Minnesota 55079',17496,21654);
INSERT INTO "django_geo_db_zipcode" VALUES(24461,55080,-6,'Stanchfield, Minnesota 55080',17497,21655);
INSERT INTO "django_geo_db_zipcode" VALUES(24462,55082,-6,'Stillwater, Minnesota 55082',17498,21656);
INSERT INTO "django_geo_db_zipcode" VALUES(24463,55083,-6,'Stillwater, Minnesota 55083',17498,21657);
INSERT INTO "django_geo_db_zipcode" VALUES(24464,55084,-6,'Taylors Falls, Minnesota 55084',17499,21658);
INSERT INTO "django_geo_db_zipcode" VALUES(24465,55085,-6,'Vermillion, Minnesota 55085',17500,21659);
INSERT INTO "django_geo_db_zipcode" VALUES(24466,55087,-6,'Warsaw, Minnesota 55087',17501,21660);
INSERT INTO "django_geo_db_zipcode" VALUES(24467,55088,-6,'Webster, Minnesota 55088',17502,21661);
INSERT INTO "django_geo_db_zipcode" VALUES(24468,55089,-6,'Welch, Minnesota 55089',17503,21662);
INSERT INTO "django_geo_db_zipcode" VALUES(24469,55090,-6,'Willernie, Minnesota 55090',17504,21663);
INSERT INTO "django_geo_db_zipcode" VALUES(24470,55092,-6,'Wyoming, Minnesota 55092',17505,21664);
INSERT INTO "django_geo_db_zipcode" VALUES(24471,55101,-6,'Saint Paul, Minnesota 55101',17506,21665);
INSERT INTO "django_geo_db_zipcode" VALUES(24472,55102,-6,'Saint Paul, Minnesota 55102',17506,21666);
INSERT INTO "django_geo_db_zipcode" VALUES(24473,55103,-6,'Saint Paul, Minnesota 55103',17506,21667);
INSERT INTO "django_geo_db_zipcode" VALUES(24474,55104,-6,'Saint Paul, Minnesota 55104',17506,21668);
INSERT INTO "django_geo_db_zipcode" VALUES(24475,55105,-6,'Saint Paul, Minnesota 55105',17506,21669);
INSERT INTO "django_geo_db_zipcode" VALUES(24476,55106,-6,'Saint Paul, Minnesota 55106',17506,21670);
INSERT INTO "django_geo_db_zipcode" VALUES(24477,55107,-6,'Saint Paul, Minnesota 55107',17506,21671);
INSERT INTO "django_geo_db_zipcode" VALUES(24478,55108,-6,'Saint Paul, Minnesota 55108',17506,21672);
INSERT INTO "django_geo_db_zipcode" VALUES(24479,55109,-6,'Saint Paul, Minnesota 55109',17506,21673);
INSERT INTO "django_geo_db_zipcode" VALUES(24480,55110,-6,'Saint Paul, Minnesota 55110',17506,21674);
INSERT INTO "django_geo_db_zipcode" VALUES(24481,55111,-6,'Saint Paul, Minnesota 55111',17506,21675);
INSERT INTO "django_geo_db_zipcode" VALUES(24482,55112,-6,'Saint Paul, Minnesota 55112',17506,21676);
INSERT INTO "django_geo_db_zipcode" VALUES(24483,55113,-6,'Saint Paul, Minnesota 55113',17506,21677);
INSERT INTO "django_geo_db_zipcode" VALUES(24484,55114,-6,'Saint Paul, Minnesota 55114',17506,21678);
INSERT INTO "django_geo_db_zipcode" VALUES(24485,55115,-6,'Saint Paul, Minnesota 55115',17506,21679);
INSERT INTO "django_geo_db_zipcode" VALUES(24486,55116,-6,'Saint Paul, Minnesota 55116',17506,21680);
INSERT INTO "django_geo_db_zipcode" VALUES(24487,55117,-6,'Saint Paul, Minnesota 55117',17506,21681);
INSERT INTO "django_geo_db_zipcode" VALUES(24488,55118,-6,'Saint Paul, Minnesota 55118',17506,21682);
INSERT INTO "django_geo_db_zipcode" VALUES(24489,55119,-6,'Saint Paul, Minnesota 55119',17506,21683);
INSERT INTO "django_geo_db_zipcode" VALUES(24490,55120,-6,'Saint Paul, Minnesota 55120',17506,21684);
INSERT INTO "django_geo_db_zipcode" VALUES(24491,55121,-6,'Saint Paul, Minnesota 55121',17506,21685);
INSERT INTO "django_geo_db_zipcode" VALUES(24492,55122,-6,'Saint Paul, Minnesota 55122',17506,21686);
INSERT INTO "django_geo_db_zipcode" VALUES(24493,55123,-6,'Saint Paul, Minnesota 55123',17506,21687);
INSERT INTO "django_geo_db_zipcode" VALUES(24494,55124,-6,'Saint Paul, Minnesota 55124',17506,21688);
INSERT INTO "django_geo_db_zipcode" VALUES(24495,55125,-6,'Saint Paul, Minnesota 55125',17506,21689);
INSERT INTO "django_geo_db_zipcode" VALUES(24496,55126,-6,'Saint Paul, Minnesota 55126',17506,21690);
INSERT INTO "django_geo_db_zipcode" VALUES(24497,55127,-6,'Saint Paul, Minnesota 55127',17506,21691);
INSERT INTO "django_geo_db_zipcode" VALUES(24498,55128,-6,'Saint Paul, Minnesota 55128',17506,21692);
INSERT INTO "django_geo_db_zipcode" VALUES(24499,55129,-6,'Saint Paul, Minnesota 55129',17506,21693);
INSERT INTO "django_geo_db_zipcode" VALUES(24500,55133,-6,'Saint Paul, Minnesota 55133',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24501,55144,-6,'Saint Paul, Minnesota 55144',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24502,55145,-6,'Saint Paul, Minnesota 55145',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24503,55146,-6,'Saint Paul, Minnesota 55146',17506,21695);
INSERT INTO "django_geo_db_zipcode" VALUES(24504,55150,-6,'Mendota, Minnesota 55150',17507,21696);
INSERT INTO "django_geo_db_zipcode" VALUES(24505,55155,-6,'Saint Paul, Minnesota 55155',17506,21697);
INSERT INTO "django_geo_db_zipcode" VALUES(24506,55161,-6,'Saint Paul, Minnesota 55161',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24507,55164,-6,'Saint Paul, Minnesota 55164',17506,21698);
INSERT INTO "django_geo_db_zipcode" VALUES(24508,55165,-6,'Saint Paul, Minnesota 55165',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24509,55166,-6,'Saint Paul, Minnesota 55166',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24510,55168,-6,'Saint Paul, Minnesota 55168',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24511,55169,-6,'Saint Paul, Minnesota 55169',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24512,55170,-6,'Saint Paul, Minnesota 55170',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24513,55171,-6,'Saint Paul, Minnesota 55171',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24514,55172,-6,'Saint Paul, Minnesota 55172',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24515,55175,-6,'Saint Paul, Minnesota 55175',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24516,55177,-6,'Saint Paul, Minnesota 55177',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24517,55182,-6,'Saint Paul, Minnesota 55182',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24518,55184,-6,'Duluth, Minnesota 55184',17508,21699);
INSERT INTO "django_geo_db_zipcode" VALUES(24519,55187,-6,'Saint Paul, Minnesota 55187',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24520,55188,-6,'Saint Paul, Minnesota 55188',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24521,55189,-6,'Saint Paul, Minnesota 55189',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24522,55190,-6,'Saint Paul, Minnesota 55190',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24523,55191,-6,'Saint Paul, Minnesota 55191',17506,21694);
INSERT INTO "django_geo_db_zipcode" VALUES(24524,55272,-6,'Kroschel, Minnesota 55272',17509,21700);
INSERT INTO "django_geo_db_zipcode" VALUES(24525,55301,-6,'Albertville, Minnesota 55301',17510,21701);
INSERT INTO "django_geo_db_zipcode" VALUES(24526,55302,-6,'Annandale, Minnesota 55302',17511,21702);
INSERT INTO "django_geo_db_zipcode" VALUES(24527,55303,-6,'Anoka, Minnesota 55303',17512,21703);
INSERT INTO "django_geo_db_zipcode" VALUES(24528,55304,-6,'Andover, Minnesota 55304',17513,21704);
INSERT INTO "django_geo_db_zipcode" VALUES(24529,55305,-6,'Hopkins, Minnesota 55305',17514,21705);
INSERT INTO "django_geo_db_zipcode" VALUES(24530,55306,-6,'Burnsville, Minnesota 55306',17515,21706);
INSERT INTO "django_geo_db_zipcode" VALUES(24531,55307,-6,'Arlington, Minnesota 55307',17516,21707);
INSERT INTO "django_geo_db_zipcode" VALUES(24532,55308,-6,'Becker, Minnesota 55308',17517,21708);
INSERT INTO "django_geo_db_zipcode" VALUES(24533,55309,-6,'Big Lake, Minnesota 55309',17518,21709);
INSERT INTO "django_geo_db_zipcode" VALUES(24534,55310,-6,'Bird Island, Minnesota 55310',17519,21710);
INSERT INTO "django_geo_db_zipcode" VALUES(24535,55311,-6,'Osseo, Minnesota 55311',17520,21711);
INSERT INTO "django_geo_db_zipcode" VALUES(24536,55312,-6,'Brownton, Minnesota 55312',17521,21712);
INSERT INTO "django_geo_db_zipcode" VALUES(24537,55313,-6,'Buffalo, Minnesota 55313',17522,21713);
INSERT INTO "django_geo_db_zipcode" VALUES(24538,55314,-6,'Buffalo Lake, Minnesota 55314',17523,21714);
INSERT INTO "django_geo_db_zipcode" VALUES(24539,55315,-6,'Carver, Minnesota 55315',17524,21715);
INSERT INTO "django_geo_db_zipcode" VALUES(24540,55316,-6,'Champlin, Minnesota 55316',17525,21716);
INSERT INTO "django_geo_db_zipcode" VALUES(24541,55317,-6,'Chanhassen, Minnesota 55317',17526,21717);
INSERT INTO "django_geo_db_zipcode" VALUES(24542,55318,-6,'Chaska, Minnesota 55318',17527,21718);
INSERT INTO "django_geo_db_zipcode" VALUES(24543,55319,-6,'Clear Lake, Minnesota 55319',17528,21719);
INSERT INTO "django_geo_db_zipcode" VALUES(24544,55320,-6,'Clearwater, Minnesota 55320',17529,21720);
INSERT INTO "django_geo_db_zipcode" VALUES(24545,55321,-6,'Cokato, Minnesota 55321',17530,21721);
INSERT INTO "django_geo_db_zipcode" VALUES(24546,55322,-6,'Cologne, Minnesota 55322',17531,21722);
INSERT INTO "django_geo_db_zipcode" VALUES(24547,55323,-6,'Crystal Bay, Minnesota 55323',17532,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24548,55324,-6,'Darwin, Minnesota 55324',17533,21724);
INSERT INTO "django_geo_db_zipcode" VALUES(24549,55325,-6,'Dassel, Minnesota 55325',17534,21725);
INSERT INTO "django_geo_db_zipcode" VALUES(24550,55327,-6,'Dayton, Minnesota 55327',17535,21726);
INSERT INTO "django_geo_db_zipcode" VALUES(24551,55328,-6,'Delano, Minnesota 55328',17536,21727);
INSERT INTO "django_geo_db_zipcode" VALUES(24552,55329,-6,'Eden Valley, Minnesota 55329',17537,21728);
INSERT INTO "django_geo_db_zipcode" VALUES(24553,55330,-6,'Elk River, Minnesota 55330',17538,21729);
INSERT INTO "django_geo_db_zipcode" VALUES(24554,55331,-6,'Excelsior, Minnesota 55331',17539,21730);
INSERT INTO "django_geo_db_zipcode" VALUES(24555,55332,-6,'Fairfax, Minnesota 55332',17540,21731);
INSERT INTO "django_geo_db_zipcode" VALUES(24556,55333,-6,'Franklin, Minnesota 55333',17541,21732);
INSERT INTO "django_geo_db_zipcode" VALUES(24557,55334,-6,'Gaylord, Minnesota 55334',17542,21733);
INSERT INTO "django_geo_db_zipcode" VALUES(24558,55335,-6,'Gibbon, Minnesota 55335',17543,21734);
INSERT INTO "django_geo_db_zipcode" VALUES(24559,55336,-6,'Glencoe, Minnesota 55336',17544,21735);
INSERT INTO "django_geo_db_zipcode" VALUES(24560,55337,-6,'Burnsville, Minnesota 55337',17515,21736);
INSERT INTO "django_geo_db_zipcode" VALUES(24561,55338,-6,'Green Isle, Minnesota 55338',17545,21737);
INSERT INTO "django_geo_db_zipcode" VALUES(24562,55339,-6,'Hamburg, Minnesota 55339',17546,21738);
INSERT INTO "django_geo_db_zipcode" VALUES(24563,55340,-6,'Hamel, Minnesota 55340',17547,21739);
INSERT INTO "django_geo_db_zipcode" VALUES(24564,55341,-6,'Hanover, Minnesota 55341',17548,21740);
INSERT INTO "django_geo_db_zipcode" VALUES(24565,55342,-6,'Hector, Minnesota 55342',17549,21741);
INSERT INTO "django_geo_db_zipcode" VALUES(24566,55343,-6,'Hopkins, Minnesota 55343',17514,21742);
INSERT INTO "django_geo_db_zipcode" VALUES(24567,55344,-6,'Eden Prairie, Minnesota 55344',17550,21743);
INSERT INTO "django_geo_db_zipcode" VALUES(24568,55345,-6,'Minnetonka, Minnesota 55345',17551,21744);
INSERT INTO "django_geo_db_zipcode" VALUES(24569,55346,-6,'Eden Prairie, Minnesota 55346',17550,21745);
INSERT INTO "django_geo_db_zipcode" VALUES(24570,55347,-6,'Eden Prairie, Minnesota 55347',17550,21746);
INSERT INTO "django_geo_db_zipcode" VALUES(24571,55348,-6,'Maple Plain, Minnesota 55348',17552,21747);
INSERT INTO "django_geo_db_zipcode" VALUES(24572,55349,-6,'Howard Lake, Minnesota 55349',17553,21748);
INSERT INTO "django_geo_db_zipcode" VALUES(24573,55350,-6,'Hutchinson, Minnesota 55350',17554,21749);
INSERT INTO "django_geo_db_zipcode" VALUES(24574,55352,-6,'Jordan, Minnesota 55352',17555,21750);
INSERT INTO "django_geo_db_zipcode" VALUES(24575,55353,-6,'Kimball, Minnesota 55353',17556,21751);
INSERT INTO "django_geo_db_zipcode" VALUES(24576,55354,-6,'Lester Prairie, Minnesota 55354',17557,21752);
INSERT INTO "django_geo_db_zipcode" VALUES(24577,55355,-6,'Litchfield, Minnesota 55355',17558,21753);
INSERT INTO "django_geo_db_zipcode" VALUES(24578,55356,-6,'Long Lake, Minnesota 55356',17559,21754);
INSERT INTO "django_geo_db_zipcode" VALUES(24579,55357,-6,'Loretto, Minnesota 55357',17560,21755);
INSERT INTO "django_geo_db_zipcode" VALUES(24580,55358,-6,'Maple Lake, Minnesota 55358',17561,21756);
INSERT INTO "django_geo_db_zipcode" VALUES(24581,55359,-6,'Maple Plain, Minnesota 55359',17552,21757);
INSERT INTO "django_geo_db_zipcode" VALUES(24582,55360,-6,'Mayer, Minnesota 55360',17562,21758);
INSERT INTO "django_geo_db_zipcode" VALUES(24583,55361,-6,'Minnetonka Beach, Minnesota 55361',17563,21759);
INSERT INTO "django_geo_db_zipcode" VALUES(24584,55362,-6,'Monticello, Minnesota 55362',17564,21760);
INSERT INTO "django_geo_db_zipcode" VALUES(24585,55363,-6,'Montrose, Minnesota 55363',17565,21761);
INSERT INTO "django_geo_db_zipcode" VALUES(24586,55364,-6,'Mound, Minnesota 55364',17566,21762);
INSERT INTO "django_geo_db_zipcode" VALUES(24587,55365,-6,'Monticello, Minnesota 55365',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24588,55366,-6,'New Auburn, Minnesota 55366',17567,21764);
INSERT INTO "django_geo_db_zipcode" VALUES(24589,55367,-6,'New Germany, Minnesota 55367',17568,21765);
INSERT INTO "django_geo_db_zipcode" VALUES(24590,55368,-6,'Norwood, Minnesota 55368',17569,21766);
INSERT INTO "django_geo_db_zipcode" VALUES(24591,55369,-6,'Osseo, Minnesota 55369',17520,21767);
INSERT INTO "django_geo_db_zipcode" VALUES(24592,55370,-6,'Plato, Minnesota 55370',17570,21768);
INSERT INTO "django_geo_db_zipcode" VALUES(24593,55371,-6,'Princeton, Minnesota 55371',17571,21769);
INSERT INTO "django_geo_db_zipcode" VALUES(24594,55372,-6,'Prior Lake, Minnesota 55372',17572,21770);
INSERT INTO "django_geo_db_zipcode" VALUES(24595,55373,-6,'Rockford, Minnesota 55373',17573,21771);
INSERT INTO "django_geo_db_zipcode" VALUES(24596,55374,-6,'Rogers, Minnesota 55374',17574,21772);
INSERT INTO "django_geo_db_zipcode" VALUES(24597,55375,-6,'Saint Bonifacius, Minnesota 55375',17575,21773);
INSERT INTO "django_geo_db_zipcode" VALUES(24598,55376,-6,'Saint Michael, Minnesota 55376',17576,21774);
INSERT INTO "django_geo_db_zipcode" VALUES(24599,55377,-6,'Santiago, Minnesota 55377',17577,21775);
INSERT INTO "django_geo_db_zipcode" VALUES(24600,55378,-6,'Savage, Minnesota 55378',17578,21776);
INSERT INTO "django_geo_db_zipcode" VALUES(24601,55379,-6,'Shakopee, Minnesota 55379',17579,21777);
INSERT INTO "django_geo_db_zipcode" VALUES(24602,55380,-6,'Silver Creek, Minnesota 55380',17580,21778);
INSERT INTO "django_geo_db_zipcode" VALUES(24603,55381,-6,'Silver Lake, Minnesota 55381',17581,21779);
INSERT INTO "django_geo_db_zipcode" VALUES(24604,55382,-6,'South Haven, Minnesota 55382',17582,21780);
INSERT INTO "django_geo_db_zipcode" VALUES(24605,55383,-6,'Norwood, Minnesota 55383',17569,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24606,55384,-6,'Spring Park, Minnesota 55384',17583,21782);
INSERT INTO "django_geo_db_zipcode" VALUES(24607,55385,-6,'Stewart, Minnesota 55385',17584,21783);
INSERT INTO "django_geo_db_zipcode" VALUES(24608,55386,-6,'Victoria, Minnesota 55386',17585,21784);
INSERT INTO "django_geo_db_zipcode" VALUES(24609,55387,-6,'Waconia, Minnesota 55387',17586,21785);
INSERT INTO "django_geo_db_zipcode" VALUES(24610,55388,-6,'Watertown, Minnesota 55388',17587,21786);
INSERT INTO "django_geo_db_zipcode" VALUES(24611,55389,-6,'Watkins, Minnesota 55389',17588,21787);
INSERT INTO "django_geo_db_zipcode" VALUES(24612,55390,-6,'Waverly, Minnesota 55390',17589,21788);
INSERT INTO "django_geo_db_zipcode" VALUES(24613,55391,-6,'Wayzata, Minnesota 55391',17590,21789);
INSERT INTO "django_geo_db_zipcode" VALUES(24614,55392,-6,'Navarre, Minnesota 55392',17591,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24615,55393,-6,'Maple Plain, Minnesota 55393',17552,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24616,55394,-6,'Young America, Minnesota 55394',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24617,55395,-6,'Winsted, Minnesota 55395',17593,21790);
INSERT INTO "django_geo_db_zipcode" VALUES(24618,55396,-6,'Winthrop, Minnesota 55396',17594,21791);
INSERT INTO "django_geo_db_zipcode" VALUES(24619,55397,-6,'Young America, Minnesota 55397',17592,21792);
INSERT INTO "django_geo_db_zipcode" VALUES(24620,55398,-6,'Zimmerman, Minnesota 55398',17595,21793);
INSERT INTO "django_geo_db_zipcode" VALUES(24621,55399,-6,'Young America, Minnesota 55399',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24622,55401,-6,'Minneapolis, Minnesota 55401',17596,21794);
INSERT INTO "django_geo_db_zipcode" VALUES(24623,55402,-6,'Minneapolis, Minnesota 55402',17596,21795);
INSERT INTO "django_geo_db_zipcode" VALUES(24624,55403,-6,'Minneapolis, Minnesota 55403',17596,21796);
INSERT INTO "django_geo_db_zipcode" VALUES(24625,55404,-6,'Minneapolis, Minnesota 55404',17596,21797);
INSERT INTO "django_geo_db_zipcode" VALUES(24626,55405,-6,'Minneapolis, Minnesota 55405',17596,21798);
INSERT INTO "django_geo_db_zipcode" VALUES(24627,55406,-6,'Minneapolis, Minnesota 55406',17596,21799);
INSERT INTO "django_geo_db_zipcode" VALUES(24628,55407,-6,'Minneapolis, Minnesota 55407',17596,21800);
INSERT INTO "django_geo_db_zipcode" VALUES(24629,55408,-6,'Minneapolis, Minnesota 55408',17596,21801);
INSERT INTO "django_geo_db_zipcode" VALUES(24630,55409,-6,'Minneapolis, Minnesota 55409',17596,21802);
INSERT INTO "django_geo_db_zipcode" VALUES(24631,55410,-6,'Minneapolis, Minnesota 55410',17596,21803);
INSERT INTO "django_geo_db_zipcode" VALUES(24632,55411,-6,'Minneapolis, Minnesota 55411',17596,21804);
INSERT INTO "django_geo_db_zipcode" VALUES(24633,55412,-6,'Minneapolis, Minnesota 55412',17596,21805);
INSERT INTO "django_geo_db_zipcode" VALUES(24634,55413,-6,'Minneapolis, Minnesota 55413',17596,21806);
INSERT INTO "django_geo_db_zipcode" VALUES(24635,55414,-6,'Minneapolis, Minnesota 55414',17596,21807);
INSERT INTO "django_geo_db_zipcode" VALUES(24636,55415,-6,'Minneapolis, Minnesota 55415',17596,21808);
INSERT INTO "django_geo_db_zipcode" VALUES(24637,55416,-6,'Minneapolis, Minnesota 55416',17596,21809);
INSERT INTO "django_geo_db_zipcode" VALUES(24638,55417,-6,'Minneapolis, Minnesota 55417',17596,21810);
INSERT INTO "django_geo_db_zipcode" VALUES(24639,55418,-6,'Minneapolis, Minnesota 55418',17596,21811);
INSERT INTO "django_geo_db_zipcode" VALUES(24640,55419,-6,'Minneapolis, Minnesota 55419',17596,21812);
INSERT INTO "django_geo_db_zipcode" VALUES(24641,55420,-6,'Minneapolis, Minnesota 55420',17596,21813);
INSERT INTO "django_geo_db_zipcode" VALUES(24642,55421,-6,'Minneapolis, Minnesota 55421',17596,21814);
INSERT INTO "django_geo_db_zipcode" VALUES(24643,55422,-6,'Minneapolis, Minnesota 55422',17596,21815);
INSERT INTO "django_geo_db_zipcode" VALUES(24644,55423,-6,'Minneapolis, Minnesota 55423',17596,21816);
INSERT INTO "django_geo_db_zipcode" VALUES(24645,55424,-6,'Minneapolis, Minnesota 55424',17596,21817);
INSERT INTO "django_geo_db_zipcode" VALUES(24646,55425,-6,'Minneapolis, Minnesota 55425',17596,21818);
INSERT INTO "django_geo_db_zipcode" VALUES(24647,55426,-6,'Minneapolis, Minnesota 55426',17596,21819);
INSERT INTO "django_geo_db_zipcode" VALUES(24648,55427,-6,'Minneapolis, Minnesota 55427',17596,21820);
INSERT INTO "django_geo_db_zipcode" VALUES(24649,55428,-6,'Minneapolis, Minnesota 55428',17596,21821);
INSERT INTO "django_geo_db_zipcode" VALUES(24650,55429,-6,'Minneapolis, Minnesota 55429',17596,21822);
INSERT INTO "django_geo_db_zipcode" VALUES(24651,55430,-6,'Minneapolis, Minnesota 55430',17596,21823);
INSERT INTO "django_geo_db_zipcode" VALUES(24652,55431,-6,'Minneapolis, Minnesota 55431',17596,21824);
INSERT INTO "django_geo_db_zipcode" VALUES(24653,55432,-6,'Minneapolis, Minnesota 55432',17596,21825);
INSERT INTO "django_geo_db_zipcode" VALUES(24654,55433,-6,'Minneapolis, Minnesota 55433',17596,21826);
INSERT INTO "django_geo_db_zipcode" VALUES(24655,55434,-6,'Minneapolis, Minnesota 55434',17596,21827);
INSERT INTO "django_geo_db_zipcode" VALUES(24656,55435,-6,'Minneapolis, Minnesota 55435',17596,21828);
INSERT INTO "django_geo_db_zipcode" VALUES(24657,55436,-6,'Minneapolis, Minnesota 55436',17596,21829);
INSERT INTO "django_geo_db_zipcode" VALUES(24658,55437,-6,'Minneapolis, Minnesota 55437',17596,21830);
INSERT INTO "django_geo_db_zipcode" VALUES(24659,55438,-6,'Minneapolis, Minnesota 55438',17596,21831);
INSERT INTO "django_geo_db_zipcode" VALUES(24660,55439,-6,'Minneapolis, Minnesota 55439',17596,21832);
INSERT INTO "django_geo_db_zipcode" VALUES(24661,55440,-6,'Minneapolis, Minnesota 55440',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24662,55441,-6,'Minneapolis, Minnesota 55441',17596,21833);
INSERT INTO "django_geo_db_zipcode" VALUES(24663,55442,-6,'Minneapolis, Minnesota 55442',17596,21834);
INSERT INTO "django_geo_db_zipcode" VALUES(24664,55443,-6,'Minneapolis, Minnesota 55443',17596,21835);
INSERT INTO "django_geo_db_zipcode" VALUES(24665,55444,-6,'Minneapolis, Minnesota 55444',17596,21836);
INSERT INTO "django_geo_db_zipcode" VALUES(24666,55445,-6,'Minneapolis, Minnesota 55445',17596,21837);
INSERT INTO "django_geo_db_zipcode" VALUES(24667,55446,-6,'Minneapolis, Minnesota 55446',17596,21838);
INSERT INTO "django_geo_db_zipcode" VALUES(24668,55447,-6,'Minneapolis, Minnesota 55447',17596,21839);
INSERT INTO "django_geo_db_zipcode" VALUES(24669,55448,-6,'Minneapolis, Minnesota 55448',17596,21840);
INSERT INTO "django_geo_db_zipcode" VALUES(24670,55449,-6,'Minneapolis, Minnesota 55449',17596,21841);
INSERT INTO "django_geo_db_zipcode" VALUES(24671,55450,-6,'Minneapolis, Minnesota 55450',17596,21842);
INSERT INTO "django_geo_db_zipcode" VALUES(24672,55454,-6,'Minneapolis, Minnesota 55454',17596,21843);
INSERT INTO "django_geo_db_zipcode" VALUES(24673,55455,-6,'Minneapolis, Minnesota 55455',17596,21844);
INSERT INTO "django_geo_db_zipcode" VALUES(24674,55458,-6,'Minneapolis, Minnesota 55458',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24675,55459,-6,'Minneapolis, Minnesota 55459',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24676,55460,-6,'Minneapolis, Minnesota 55460',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24677,55468,-6,'Minneapolis, Minnesota 55468',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24678,55470,-6,'Minneapolis, Minnesota 55470',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24679,55472,-6,'Minneapolis, Minnesota 55472',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24680,55473,-6,'Minneapolis, Minnesota 55473',17596,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24681,55474,-6,'Minneapolis, Minnesota 55474',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24682,55478,-6,'Minneapolis, Minnesota 55478',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24683,55479,-6,'Minneapolis, Minnesota 55479',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24684,55480,-6,'Minneapolis, Minnesota 55480',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24685,55483,-6,'Minneapolis, Minnesota 55483',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24686,55484,-6,'Minneapolis, Minnesota 55484',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24687,55485,-6,'Minneapolis, Minnesota 55485',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24688,55486,-6,'Minneapolis, Minnesota 55486',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24689,55487,-6,'Minneapolis, Minnesota 55487',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24690,55488,-6,'Minneapolis, Minnesota 55488',17596,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24691,55530,-6,'Elk River, Minnesota 55530',17538,21845);
INSERT INTO "django_geo_db_zipcode" VALUES(24692,55550,-6,'Young America, Minnesota 55550',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24693,55551,-6,'Young America, Minnesota 55551',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24694,55552,-6,'Young America, Minnesota 55552',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24695,55553,-6,'Young America, Minnesota 55553',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24696,55554,-6,'Norwood, Minnesota 55554',17569,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24697,55555,-6,'Young America, Minnesota 55555',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24698,55556,-6,'Young America, Minnesota 55556',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24699,55557,-6,'Young America, Minnesota 55557',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24700,55558,-6,'Young America, Minnesota 55558',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24701,55559,-6,'Young America, Minnesota 55559',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24702,55560,-6,'Young America, Minnesota 55560',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24703,55561,-6,'Monticello, Minnesota 55561',17564,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24704,55562,-6,'Young America, Minnesota 55562',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24705,55563,-6,'Monticello, Minnesota 55563',17564,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24706,55564,-6,'Young America, Minnesota 55564',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24707,55565,-6,'Monticello, Minnesota 55565',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24708,55566,-6,'Young America, Minnesota 55566',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24709,55567,-6,'Young America, Minnesota 55567',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24710,55568,-6,'Young America, Minnesota 55568',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24711,55569,-6,'Osseo, Minnesota 55569',17520,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24712,55570,-6,'Maple Plain, Minnesota 55570',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24713,55571,-6,'Maple Plain, Minnesota 55571',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24714,55572,-6,'Maple Plain, Minnesota 55572',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24715,55573,-6,'Young America, Minnesota 55573',17592,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24716,55574,-6,'Maple Plain, Minnesota 55574',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24717,55575,-6,'Howard Lake, Minnesota 55575',17553,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24718,55576,-6,'Maple Plain, Minnesota 55576',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24719,55577,-6,'Maple Plain, Minnesota 55577',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24720,55578,-6,'Maple Plain, Minnesota 55578',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24721,55579,-6,'Maple Plain, Minnesota 55579',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24722,55580,-6,'Monticello, Minnesota 55580',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24723,55581,-6,'Monticello, Minnesota 55581',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24724,55582,-6,'Monticello, Minnesota 55582',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24725,55583,-6,'Norwood, Minnesota 55583',17569,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24726,55584,-6,'Monticello, Minnesota 55584',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24727,55585,-6,'Monticello, Minnesota 55585',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24728,55586,-6,'Monticello, Minnesota 55586',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24729,55587,-6,'Monticello, Minnesota 55587',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24730,55588,-6,'Monticello, Minnesota 55588',17564,21846);
INSERT INTO "django_geo_db_zipcode" VALUES(24731,55589,-6,'Monticello, Minnesota 55589',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24732,55590,-6,'Monticello, Minnesota 55590',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24733,55591,-6,'Monticello, Minnesota 55591',17564,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24734,55592,-6,'Maple Plain, Minnesota 55592',17552,21763);
INSERT INTO "django_geo_db_zipcode" VALUES(24735,55593,-6,'Maple Plain, Minnesota 55593',17552,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24736,55594,-6,'Young America, Minnesota 55594',17592,21781);
INSERT INTO "django_geo_db_zipcode" VALUES(24737,55595,-6,'Loretto, Minnesota 55595',17560,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24738,55596,-6,'Loretto, Minnesota 55596',17560,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24739,55597,-6,'Loretto, Minnesota 55597',17560,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24740,55598,-6,'Loretto, Minnesota 55598',17560,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24741,55599,-6,'Loretto, Minnesota 55599',17560,21723);
INSERT INTO "django_geo_db_zipcode" VALUES(24742,55601,-6,'Beaver Bay, Minnesota 55601',17597,21847);
INSERT INTO "django_geo_db_zipcode" VALUES(24743,55602,-6,'Brimson, Minnesota 55602',17598,21848);
INSERT INTO "django_geo_db_zipcode" VALUES(24744,55603,-6,'Finland, Minnesota 55603',17599,21849);
INSERT INTO "django_geo_db_zipcode" VALUES(24745,55604,-6,'Grand Marais, Minnesota 55604',17600,21850);
INSERT INTO "django_geo_db_zipcode" VALUES(24746,55605,-6,'Grand Portage, Minnesota 55605',17601,21851);
INSERT INTO "django_geo_db_zipcode" VALUES(24747,55606,-6,'Hovland, Minnesota 55606',17602,21852);
INSERT INTO "django_geo_db_zipcode" VALUES(24748,55607,-6,'Isabella, Minnesota 55607',17603,21853);
INSERT INTO "django_geo_db_zipcode" VALUES(24749,55608,-6,'Rosemount, Minnesota 55608',17487,21854);
INSERT INTO "django_geo_db_zipcode" VALUES(24750,55609,-6,'Knife River, Minnesota 55609',17604,21855);
INSERT INTO "django_geo_db_zipcode" VALUES(24751,55612,-6,'Lutsen, Minnesota 55612',17605,21856);
INSERT INTO "django_geo_db_zipcode" VALUES(24752,55613,-6,'Schroeder, Minnesota 55613',17606,21857);
INSERT INTO "django_geo_db_zipcode" VALUES(24753,55614,-6,'Silver Bay, Minnesota 55614',17607,21858);
INSERT INTO "django_geo_db_zipcode" VALUES(24754,55615,-6,'Tofte, Minnesota 55615',17608,21859);
INSERT INTO "django_geo_db_zipcode" VALUES(24755,55616,-6,'Two Harbors, Minnesota 55616',17609,21860);
INSERT INTO "django_geo_db_zipcode" VALUES(24756,55676,-6,'Barnum, Minnesota 55676',17610,21861);
INSERT INTO "django_geo_db_zipcode" VALUES(24757,55701,-6,'Adolph, Minnesota 55701',17611,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24758,55702,-6,'Alborn, Minnesota 55702',17612,21863);
INSERT INTO "django_geo_db_zipcode" VALUES(24759,55703,-6,'Angora, Minnesota 55703',17613,21864);
INSERT INTO "django_geo_db_zipcode" VALUES(24760,55704,-6,'Askov, Minnesota 55704',17614,21865);
INSERT INTO "django_geo_db_zipcode" VALUES(24761,55705,-6,'Aurora, Minnesota 55705',17615,21866);
INSERT INTO "django_geo_db_zipcode" VALUES(24762,55706,-6,'Babbitt, Minnesota 55706',17616,21867);
INSERT INTO "django_geo_db_zipcode" VALUES(24763,55707,-6,'Barnum, Minnesota 55707',17610,21868);
INSERT INTO "django_geo_db_zipcode" VALUES(24764,55708,-6,'Biwabik, Minnesota 55708',17617,21869);
INSERT INTO "django_geo_db_zipcode" VALUES(24765,55709,-6,'Bovey, Minnesota 55709',17618,21870);
INSERT INTO "django_geo_db_zipcode" VALUES(24766,55710,-6,'Britt, Minnesota 55710',17619,21871);
INSERT INTO "django_geo_db_zipcode" VALUES(24767,55711,-6,'Brookston, Minnesota 55711',17620,21872);
INSERT INTO "django_geo_db_zipcode" VALUES(24768,55712,-6,'Bruno, Minnesota 55712',17621,21873);
INSERT INTO "django_geo_db_zipcode" VALUES(24769,55713,-6,'Buhl, Minnesota 55713',17622,21874);
INSERT INTO "django_geo_db_zipcode" VALUES(24770,55715,-6,'Buhl, Minnesota 55715',17622,21875);
INSERT INTO "django_geo_db_zipcode" VALUES(24771,55716,-6,'Calumet, Minnesota 55716',17623,21876);
INSERT INTO "django_geo_db_zipcode" VALUES(24772,55717,-6,'Canyon, Minnesota 55717',17624,21877);
INSERT INTO "django_geo_db_zipcode" VALUES(24773,55718,-6,'Carlton, Minnesota 55718',17625,21878);
INSERT INTO "django_geo_db_zipcode" VALUES(24774,55719,-6,'Chisholm, Minnesota 55719',17626,21879);
INSERT INTO "django_geo_db_zipcode" VALUES(24775,55720,-6,'Cloquet, Minnesota 55720',17627,21880);
INSERT INTO "django_geo_db_zipcode" VALUES(24776,55721,-6,'Cohasset, Minnesota 55721',17628,21881);
INSERT INTO "django_geo_db_zipcode" VALUES(24777,55722,-6,'Coleraine, Minnesota 55722',17629,21882);
INSERT INTO "django_geo_db_zipcode" VALUES(24778,55723,-6,'Cook, Minnesota 55723',17630,21883);
INSERT INTO "django_geo_db_zipcode" VALUES(24779,55724,-6,'Cotton, Minnesota 55724',17631,21884);
INSERT INTO "django_geo_db_zipcode" VALUES(24780,55725,-6,'Crane Lake, Minnesota 55725',17632,21885);
INSERT INTO "django_geo_db_zipcode" VALUES(24781,55726,-6,'Cromwell, Minnesota 55726',17633,21886);
INSERT INTO "django_geo_db_zipcode" VALUES(24782,55728,-6,'Bigfork, Minnesota 55728',17634,21887);
INSERT INTO "django_geo_db_zipcode" VALUES(24783,55730,-6,'Grand Rapids, Minnesota 55730',17635,21888);
INSERT INTO "django_geo_db_zipcode" VALUES(24784,55731,-6,'Ely, Minnesota 55731',17636,21889);
INSERT INTO "django_geo_db_zipcode" VALUES(24785,55732,-6,'Embarrass, Minnesota 55732',17637,21890);
INSERT INTO "django_geo_db_zipcode" VALUES(24786,55733,-6,'Esko, Minnesota 55733',17638,21891);
INSERT INTO "django_geo_db_zipcode" VALUES(24787,55734,-6,'Eveleth, Minnesota 55734',17639,21892);
INSERT INTO "django_geo_db_zipcode" VALUES(24788,55735,-6,'Finlayson, Minnesota 55735',17640,21893);
INSERT INTO "django_geo_db_zipcode" VALUES(24789,55736,-6,'Floodwood, Minnesota 55736',17641,21894);
INSERT INTO "django_geo_db_zipcode" VALUES(24790,55738,-6,'Forbes, Minnesota 55738',17642,21895);
INSERT INTO "django_geo_db_zipcode" VALUES(24791,55741,-6,'Gilbert, Minnesota 55741',17643,21896);
INSERT INTO "django_geo_db_zipcode" VALUES(24792,55742,-6,'Goodland, Minnesota 55742',17644,21897);
INSERT INTO "django_geo_db_zipcode" VALUES(24793,55744,-6,'Grand Rapids, Minnesota 55744',17635,21898);
INSERT INTO "django_geo_db_zipcode" VALUES(24794,55745,-6,'Grand Rapids, Minnesota 55745',17635,21888);
INSERT INTO "django_geo_db_zipcode" VALUES(24795,55746,-6,'Hibbing, Minnesota 55746',17645,21899);
INSERT INTO "django_geo_db_zipcode" VALUES(24796,55747,-6,'Hibbing, Minnesota 55747',17645,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24797,55748,-6,'Hill City, Minnesota 55748',17646,21900);
INSERT INTO "django_geo_db_zipcode" VALUES(24798,55749,-6,'Holyoke, Minnesota 55749',17647,21901);
INSERT INTO "django_geo_db_zipcode" VALUES(24799,55750,-6,'Hoyt Lakes, Minnesota 55750',17648,21902);
INSERT INTO "django_geo_db_zipcode" VALUES(24800,55751,-6,'Iron, Minnesota 55751',17649,21903);
INSERT INTO "django_geo_db_zipcode" VALUES(24801,55752,-6,'Jacobson, Minnesota 55752',17650,21904);
INSERT INTO "django_geo_db_zipcode" VALUES(24802,55753,-6,'Keewatin, Minnesota 55753',17651,21905);
INSERT INTO "django_geo_db_zipcode" VALUES(24803,55756,-6,'Kerrick, Minnesota 55756',17652,21906);
INSERT INTO "django_geo_db_zipcode" VALUES(24804,55757,-6,'Kettle River, Minnesota 55757',17653,21907);
INSERT INTO "django_geo_db_zipcode" VALUES(24805,55758,-6,'Kinney, Minnesota 55758',17654,21908);
INSERT INTO "django_geo_db_zipcode" VALUES(24806,55760,-6,'Mcgregor, Minnesota 55760',17655,21909);
INSERT INTO "django_geo_db_zipcode" VALUES(24807,55761,-6,'McKinley, Minnesota 55761',17656,21910);
INSERT INTO "django_geo_db_zipcode" VALUES(24808,55763,-6,'Makinen, Minnesota 55763',17657,21911);
INSERT INTO "django_geo_db_zipcode" VALUES(24809,55764,-6,'Marble, Minnesota 55764',17658,21912);
INSERT INTO "django_geo_db_zipcode" VALUES(24810,55765,-6,'Meadowlands, Minnesota 55765',17659,21913);
INSERT INTO "django_geo_db_zipcode" VALUES(24811,55766,-6,'Melrude, Minnesota 55766',17660,21914);
INSERT INTO "django_geo_db_zipcode" VALUES(24812,55767,-6,'Moose Lake, Minnesota 55767',17661,21915);
INSERT INTO "django_geo_db_zipcode" VALUES(24813,55768,-6,'Mountain Iron, Minnesota 55768',17662,21916);
INSERT INTO "django_geo_db_zipcode" VALUES(24814,55769,-6,'Nashwauk, Minnesota 55769',17663,21917);
INSERT INTO "django_geo_db_zipcode" VALUES(24815,55771,-6,'Orr, Minnesota 55771',17664,21918);
INSERT INTO "django_geo_db_zipcode" VALUES(24816,55772,-6,'Nett Lake, Minnesota 55772',17665,21919);
INSERT INTO "django_geo_db_zipcode" VALUES(24817,55775,-6,'Pengilly, Minnesota 55775',17666,21920);
INSERT INTO "django_geo_db_zipcode" VALUES(24818,55777,-6,'Virginia, Minnesota 55777',17667,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24819,55778,-6,'Clark, Minnesota 55778',17668,21921);
INSERT INTO "django_geo_db_zipcode" VALUES(24820,55779,-6,'Saginaw, Minnesota 55779',17669,21922);
INSERT INTO "django_geo_db_zipcode" VALUES(24821,55780,-6,'Sawyer, Minnesota 55780',17670,21923);
INSERT INTO "django_geo_db_zipcode" VALUES(24822,55781,-6,'Side Lake, Minnesota 55781',17671,21924);
INSERT INTO "django_geo_db_zipcode" VALUES(24823,55782,-6,'Soudan, Minnesota 55782',17672,21925);
INSERT INTO "django_geo_db_zipcode" VALUES(24824,55783,-6,'Sturgeon Lake, Minnesota 55783',17673,21926);
INSERT INTO "django_geo_db_zipcode" VALUES(24825,55784,-6,'Swan River, Minnesota 55784',17674,21927);
INSERT INTO "django_geo_db_zipcode" VALUES(24826,55785,-6,'Swatara, Minnesota 55785',17675,21928);
INSERT INTO "django_geo_db_zipcode" VALUES(24827,55786,-6,'Taconite, Minnesota 55786',17676,21929);
INSERT INTO "django_geo_db_zipcode" VALUES(24828,55787,-6,'Tamarack, Minnesota 55787',17677,21930);
INSERT INTO "django_geo_db_zipcode" VALUES(24829,55790,-6,'Tower, Minnesota 55790',17678,21931);
INSERT INTO "django_geo_db_zipcode" VALUES(24830,55791,-6,'Twig, Minnesota 55791',17679,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24831,55792,-6,'Virginia, Minnesota 55792',17667,21932);
INSERT INTO "django_geo_db_zipcode" VALUES(24832,55793,-6,'Warba, Minnesota 55793',17680,21933);
INSERT INTO "django_geo_db_zipcode" VALUES(24833,55795,-6,'Willow River, Minnesota 55795',17681,21934);
INSERT INTO "django_geo_db_zipcode" VALUES(24834,55796,-6,'Winton, Minnesota 55796',17682,21935);
INSERT INTO "django_geo_db_zipcode" VALUES(24835,55797,-6,'Wrenshall, Minnesota 55797',17683,21936);
INSERT INTO "django_geo_db_zipcode" VALUES(24836,55798,-6,'Wright, Minnesota 55798',17684,21937);
INSERT INTO "django_geo_db_zipcode" VALUES(24837,55801,-6,'Duluth, Minnesota 55801',17508,21938);
INSERT INTO "django_geo_db_zipcode" VALUES(24838,55802,-6,'Duluth, Minnesota 55802',17508,21939);
INSERT INTO "django_geo_db_zipcode" VALUES(24839,55803,-6,'Duluth, Minnesota 55803',17508,21940);
INSERT INTO "django_geo_db_zipcode" VALUES(24840,55804,-6,'Duluth, Minnesota 55804',17508,21941);
INSERT INTO "django_geo_db_zipcode" VALUES(24841,55805,-6,'Duluth, Minnesota 55805',17508,21942);
INSERT INTO "django_geo_db_zipcode" VALUES(24842,55806,-6,'Duluth, Minnesota 55806',17508,21943);
INSERT INTO "django_geo_db_zipcode" VALUES(24843,55807,-6,'Duluth, Minnesota 55807',17508,21944);
INSERT INTO "django_geo_db_zipcode" VALUES(24844,55808,-6,'Duluth, Minnesota 55808',17508,21945);
INSERT INTO "django_geo_db_zipcode" VALUES(24845,55810,-6,'Duluth, Minnesota 55810',17508,21946);
INSERT INTO "django_geo_db_zipcode" VALUES(24846,55811,-6,'Duluth, Minnesota 55811',17508,21947);
INSERT INTO "django_geo_db_zipcode" VALUES(24847,55812,-6,'Duluth, Minnesota 55812',17508,21948);
INSERT INTO "django_geo_db_zipcode" VALUES(24848,55814,-6,'Duluth, Minnesota 55814',17508,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24849,55815,-6,'Duluth, Minnesota 55815',17508,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24850,55816,-6,'Duluth, Minnesota 55816',17508,21862);
INSERT INTO "django_geo_db_zipcode" VALUES(24851,55901,-6,'Rochester, Minnesota 55901',17685,21949);
INSERT INTO "django_geo_db_zipcode" VALUES(24852,55902,-6,'Rochester, Minnesota 55902',17685,21950);
INSERT INTO "django_geo_db_zipcode" VALUES(24853,55903,-6,'Rochester, Minnesota 55903',17685,21951);
INSERT INTO "django_geo_db_zipcode" VALUES(24854,55904,-6,'Rochester, Minnesota 55904',17685,21952);
INSERT INTO "django_geo_db_zipcode" VALUES(24855,55905,-6,'Rochester, Minnesota 55905',17685,21953);
INSERT INTO "django_geo_db_zipcode" VALUES(24856,55906,-6,'Rochester, Minnesota 55906',17685,21954);
INSERT INTO "django_geo_db_zipcode" VALUES(24857,55909,-6,'Adams, Minnesota 55909',17686,21955);
INSERT INTO "django_geo_db_zipcode" VALUES(24858,55910,-6,'Altura, Minnesota 55910',17687,21956);
INSERT INTO "django_geo_db_zipcode" VALUES(24859,55912,-6,'Austin, Minnesota 55912',17688,21957);
INSERT INTO "django_geo_db_zipcode" VALUES(24860,55917,-6,'Blooming Prairie, Minnesota 55917',17689,21958);
INSERT INTO "django_geo_db_zipcode" VALUES(24861,55918,-6,'Brownsdale, Minnesota 55918',17690,21959);
INSERT INTO "django_geo_db_zipcode" VALUES(24862,55919,-6,'Brownsville, Minnesota 55919',17691,21960);
INSERT INTO "django_geo_db_zipcode" VALUES(24863,55920,-6,'Byron, Minnesota 55920',17692,21961);
INSERT INTO "django_geo_db_zipcode" VALUES(24864,55921,-6,'Caledonia, Minnesota 55921',17693,21962);
INSERT INTO "django_geo_db_zipcode" VALUES(24865,55922,-6,'Canton, Minnesota 55922',17694,21963);
INSERT INTO "django_geo_db_zipcode" VALUES(24866,55923,-6,'Chatfield, Minnesota 55923',17695,21964);
INSERT INTO "django_geo_db_zipcode" VALUES(24867,55924,-6,'Claremont, Minnesota 55924',17696,21965);
INSERT INTO "django_geo_db_zipcode" VALUES(24868,55925,-6,'Dakota, Minnesota 55925',17697,21966);
INSERT INTO "django_geo_db_zipcode" VALUES(24869,55926,-6,'Dexter, Minnesota 55926',17698,21967);
INSERT INTO "django_geo_db_zipcode" VALUES(24870,55927,-6,'Dodge Center, Minnesota 55927',17699,21968);
INSERT INTO "django_geo_db_zipcode" VALUES(24871,55929,-6,'Dover, Minnesota 55929',17700,21969);
INSERT INTO "django_geo_db_zipcode" VALUES(24872,55931,-6,'Eitzen, Minnesota 55931',17701,21970);
INSERT INTO "django_geo_db_zipcode" VALUES(24873,55932,-6,'Elgin, Minnesota 55932',17702,21971);
INSERT INTO "django_geo_db_zipcode" VALUES(24874,55933,-6,'Elkton, Minnesota 55933',17703,21972);
INSERT INTO "django_geo_db_zipcode" VALUES(24875,55934,-6,'Eyota, Minnesota 55934',17704,21973);
INSERT INTO "django_geo_db_zipcode" VALUES(24876,55935,-6,'Fountain, Minnesota 55935',17705,21974);
INSERT INTO "django_geo_db_zipcode" VALUES(24877,55936,-6,'Grand Meadow, Minnesota 55936',17706,21975);
INSERT INTO "django_geo_db_zipcode" VALUES(24878,55939,-6,'Harmony, Minnesota 55939',17707,21976);
INSERT INTO "django_geo_db_zipcode" VALUES(24879,55940,-6,'Hayfield, Minnesota 55940',17708,21977);
INSERT INTO "django_geo_db_zipcode" VALUES(24880,55941,-6,'Hokah, Minnesota 55941',17709,21978);
INSERT INTO "django_geo_db_zipcode" VALUES(24881,55942,-6,'Homer, Minnesota 55942',17710,21979);
INSERT INTO "django_geo_db_zipcode" VALUES(24882,55943,-6,'Houston, Minnesota 55943',17711,21980);
INSERT INTO "django_geo_db_zipcode" VALUES(24883,55944,-6,'Kasson, Minnesota 55944',17712,21981);
INSERT INTO "django_geo_db_zipcode" VALUES(24884,55945,-6,'Kellogg, Minnesota 55945',17713,21982);
INSERT INTO "django_geo_db_zipcode" VALUES(24885,55946,-6,'Kenyon, Minnesota 55946',17714,21983);
INSERT INTO "django_geo_db_zipcode" VALUES(24886,55947,-6,'La Crescent, Minnesota 55947',17715,21984);
INSERT INTO "django_geo_db_zipcode" VALUES(24887,55949,-6,'Lanesboro, Minnesota 55949',17716,21985);
INSERT INTO "django_geo_db_zipcode" VALUES(24888,55950,-6,'Lansing, Minnesota 55950',17717,21986);
INSERT INTO "django_geo_db_zipcode" VALUES(24889,55951,-6,'Le Roy, Minnesota 55951',17718,21987);
INSERT INTO "django_geo_db_zipcode" VALUES(24890,55952,-6,'Lewiston, Minnesota 55952',17719,21988);
INSERT INTO "django_geo_db_zipcode" VALUES(24891,55953,-6,'Lyle, Minnesota 55953',17720,21989);
INSERT INTO "django_geo_db_zipcode" VALUES(24892,55954,-6,'Mabel, Iowa 55954',17721,21990);
INSERT INTO "django_geo_db_zipcode" VALUES(24893,55955,-6,'Mantorville, Minnesota 55955',17722,21991);
INSERT INTO "django_geo_db_zipcode" VALUES(24894,55956,-6,'Mazeppa, Minnesota 55956',17723,21992);
INSERT INTO "django_geo_db_zipcode" VALUES(24895,55957,-6,'Millville, Minnesota 55957',17724,21993);
INSERT INTO "django_geo_db_zipcode" VALUES(24896,55959,-6,'Minnesota City, Minnesota 55959',17725,21994);
INSERT INTO "django_geo_db_zipcode" VALUES(24897,55960,-6,'Oronoco, Minnesota 55960',17726,21995);
INSERT INTO "django_geo_db_zipcode" VALUES(24898,55961,-6,'Ostrander, Minnesota 55961',17727,21996);
INSERT INTO "django_geo_db_zipcode" VALUES(24899,55962,-6,'Peterson, Minnesota 55962',17728,21997);
INSERT INTO "django_geo_db_zipcode" VALUES(24900,55963,-6,'Pine Island, Minnesota 55963',17729,21998);
INSERT INTO "django_geo_db_zipcode" VALUES(24901,55964,-6,'Plainview, Minnesota 55964',17730,21999);
INSERT INTO "django_geo_db_zipcode" VALUES(24902,55965,-6,'Preston, Minnesota 55965',17731,22000);
INSERT INTO "django_geo_db_zipcode" VALUES(24903,55967,-6,'Racine, Minnesota 55967',17732,22001);
INSERT INTO "django_geo_db_zipcode" VALUES(24904,55968,-6,'Reads Landing, Minnesota 55968',17733,22002);
INSERT INTO "django_geo_db_zipcode" VALUES(24905,55969,-6,'Rollingstone, Minnesota 55969',17734,22003);
INSERT INTO "django_geo_db_zipcode" VALUES(24906,55970,-6,'Rose Creek, Minnesota 55970',17735,22004);
INSERT INTO "django_geo_db_zipcode" VALUES(24907,55971,-6,'Rushford, Minnesota 55971',17736,22005);
INSERT INTO "django_geo_db_zipcode" VALUES(24908,55972,-6,'Saint Charles, Minnesota 55972',17737,22006);
INSERT INTO "django_geo_db_zipcode" VALUES(24909,55973,-6,'Sargeant, Minnesota 55973',17738,22007);
INSERT INTO "django_geo_db_zipcode" VALUES(24910,55974,-6,'Spring Grove, Minnesota 55974',17739,22008);
INSERT INTO "django_geo_db_zipcode" VALUES(24911,55975,-6,'Spring Valley, Minnesota 55975',17740,22009);
INSERT INTO "django_geo_db_zipcode" VALUES(24912,55976,-6,'Stewartville, Minnesota 55976',17741,22010);
INSERT INTO "django_geo_db_zipcode" VALUES(24913,55977,-6,'Taopi, Minnesota 55977',17742,22011);
INSERT INTO "django_geo_db_zipcode" VALUES(24914,55978,-6,'West Albany, Minnesota 55978',17743,22012);
INSERT INTO "django_geo_db_zipcode" VALUES(24915,55979,-6,'Utica, Minnesota 55979',17744,22013);
INSERT INTO "django_geo_db_zipcode" VALUES(24916,55981,-6,'Wabasha, Minnesota 55981',17745,22014);
INSERT INTO "django_geo_db_zipcode" VALUES(24917,55982,-6,'Waltham, Minnesota 55982',17746,22015);
INSERT INTO "django_geo_db_zipcode" VALUES(24918,55983,-6,'Wanamingo, Minnesota 55983',17747,22016);
INSERT INTO "django_geo_db_zipcode" VALUES(24919,55985,-6,'West Concord, Minnesota 55985',17748,22017);
INSERT INTO "django_geo_db_zipcode" VALUES(24920,55987,-6,'Winona, Minnesota 55987',17749,22018);
INSERT INTO "django_geo_db_zipcode" VALUES(24921,55988,-6,'Stockton, Minnesota 55988',17750,22019);
INSERT INTO "django_geo_db_zipcode" VALUES(24922,55990,-6,'Wykoff, Minnesota 55990',17751,22020);
INSERT INTO "django_geo_db_zipcode" VALUES(24923,55991,-6,'Zumbro Falls, Minnesota 55991',17752,22021);
INSERT INTO "django_geo_db_zipcode" VALUES(24924,55992,-6,'Zumbrota, Minnesota 55992',17753,22022);
INSERT INTO "django_geo_db_zipcode" VALUES(24925,56001,-6,'Mankato, Minnesota 56001',17754,22023);
INSERT INTO "django_geo_db_zipcode" VALUES(24926,56002,-6,'Mankato, Minnesota 56002',17754,22024);
INSERT INTO "django_geo_db_zipcode" VALUES(24927,56003,-6,'Mankato, Minnesota 56003',17754,22025);
INSERT INTO "django_geo_db_zipcode" VALUES(24928,56006,-6,'Mankato, Minnesota 56006',17754,22024);
INSERT INTO "django_geo_db_zipcode" VALUES(24929,56007,-6,'Albert Lea, Minnesota 56007',17755,22026);
INSERT INTO "django_geo_db_zipcode" VALUES(24930,56009,-6,'Alden, Minnesota 56009',17756,22027);
INSERT INTO "django_geo_db_zipcode" VALUES(24931,56010,-6,'Amboy, Minnesota 56010',17757,22028);
INSERT INTO "django_geo_db_zipcode" VALUES(24932,56011,-6,'Belle Plaine, Minnesota 56011',17758,22029);
INSERT INTO "django_geo_db_zipcode" VALUES(24933,56013,-6,'Blue Earth, Minnesota 56013',17759,22030);
INSERT INTO "django_geo_db_zipcode" VALUES(24934,56014,-6,'Bricelyn, Minnesota 56014',17760,22031);
INSERT INTO "django_geo_db_zipcode" VALUES(24935,56016,-6,'Clarks Grove, Minnesota 56016',17761,22032);
INSERT INTO "django_geo_db_zipcode" VALUES(24936,56017,-6,'Cleveland, Minnesota 56017',17762,22033);
INSERT INTO "django_geo_db_zipcode" VALUES(24937,56019,-6,'Comfrey, Minnesota 56019',17763,22034);
INSERT INTO "django_geo_db_zipcode" VALUES(24938,56020,-6,'Conger, Minnesota 56020',17764,22035);
INSERT INTO "django_geo_db_zipcode" VALUES(24939,56021,-6,'Courtland, Minnesota 56021',17765,22036);
INSERT INTO "django_geo_db_zipcode" VALUES(24940,56022,-6,'Darfur, Minnesota 56022',17766,22037);
INSERT INTO "django_geo_db_zipcode" VALUES(24941,56023,-6,'Delavan, Minnesota 56023',17767,22038);
INSERT INTO "django_geo_db_zipcode" VALUES(24942,56024,-6,'Eagle Lake, Minnesota 56024',17768,22039);
INSERT INTO "django_geo_db_zipcode" VALUES(24943,56025,-6,'Easton, Minnesota 56025',17769,22040);
INSERT INTO "django_geo_db_zipcode" VALUES(24944,56026,-6,'Ellendale, Minnesota 56026',17770,22041);
INSERT INTO "django_geo_db_zipcode" VALUES(24945,56027,-6,'Elmore, Iowa 56027',17771,22042);
INSERT INTO "django_geo_db_zipcode" VALUES(24946,56028,-6,'Elysian, Minnesota 56028',17772,22043);
INSERT INTO "django_geo_db_zipcode" VALUES(24947,56029,-6,'Emmons, Minnesota 56029',17773,22044);
INSERT INTO "django_geo_db_zipcode" VALUES(24948,56030,-6,'Essig, Minnesota 56030',17774,22045);
INSERT INTO "django_geo_db_zipcode" VALUES(24949,56031,-6,'Fairmont, Minnesota 56031',17775,22046);
INSERT INTO "django_geo_db_zipcode" VALUES(24950,56032,-6,'Freeborn, Minnesota 56032',17776,22047);
INSERT INTO "django_geo_db_zipcode" VALUES(24951,56033,-6,'Frost, Minnesota 56033',17777,22048);
INSERT INTO "django_geo_db_zipcode" VALUES(24952,56034,-6,'Garden City, Minnesota 56034',17778,22049);
INSERT INTO "django_geo_db_zipcode" VALUES(24953,56035,-6,'Geneva, Minnesota 56035',17779,22050);
INSERT INTO "django_geo_db_zipcode" VALUES(24954,56036,-6,'Glenville, Minnesota 56036',17780,22051);
INSERT INTO "django_geo_db_zipcode" VALUES(24955,56037,-6,'Good Thunder, Minnesota 56037',17781,22052);
INSERT INTO "django_geo_db_zipcode" VALUES(24956,56039,-6,'Granada, Minnesota 56039',17782,22053);
INSERT INTO "django_geo_db_zipcode" VALUES(24957,56041,-6,'Hanska, Minnesota 56041',17783,22054);
INSERT INTO "django_geo_db_zipcode" VALUES(24958,56042,-6,'Hartland, Minnesota 56042',17784,22055);
INSERT INTO "django_geo_db_zipcode" VALUES(24959,56043,-6,'Hayward, Minnesota 56043',17785,22056);
INSERT INTO "django_geo_db_zipcode" VALUES(24960,56044,-6,'Henderson, Minnesota 56044',17786,22057);
INSERT INTO "django_geo_db_zipcode" VALUES(24961,56045,-6,'Hollandale, Minnesota 56045',17787,22058);
INSERT INTO "django_geo_db_zipcode" VALUES(24962,56046,-6,'Hope, Minnesota 56046',17788,22059);
INSERT INTO "django_geo_db_zipcode" VALUES(24963,56047,-6,'Huntley, Minnesota 56047',17789,22060);
INSERT INTO "django_geo_db_zipcode" VALUES(24964,56048,-6,'Janesville, Minnesota 56048',17790,22061);
INSERT INTO "django_geo_db_zipcode" VALUES(24965,56050,-6,'Kasota, Minnesota 56050',17791,22062);
INSERT INTO "django_geo_db_zipcode" VALUES(24966,56051,-6,'Kiester, Minnesota 56051',17792,22063);
INSERT INTO "django_geo_db_zipcode" VALUES(24967,56052,-6,'Kilkenny, Minnesota 56052',17793,22064);
INSERT INTO "django_geo_db_zipcode" VALUES(24968,56054,-6,'Lafayette, Minnesota 56054',17794,22065);
INSERT INTO "django_geo_db_zipcode" VALUES(24969,56055,-6,'Lake Crystal, Minnesota 56055',17795,22066);
INSERT INTO "django_geo_db_zipcode" VALUES(24970,56056,-6,'La Salle, Minnesota 56056',17796,22067);
INSERT INTO "django_geo_db_zipcode" VALUES(24971,56057,-6,'Le Center, Minnesota 56057',17797,22068);
INSERT INTO "django_geo_db_zipcode" VALUES(24972,56058,-6,'Le Sueur, Minnesota 56058',17798,22069);
INSERT INTO "django_geo_db_zipcode" VALUES(24973,56060,-6,'Lewisville, Minnesota 56060',17799,22070);
INSERT INTO "django_geo_db_zipcode" VALUES(24974,56062,-6,'Madelia, Minnesota 56062',17800,22071);
INSERT INTO "django_geo_db_zipcode" VALUES(24975,56063,-6,'Madison Lake, Minnesota 56063',17801,22072);
INSERT INTO "django_geo_db_zipcode" VALUES(24976,56064,-6,'Manchester, Minnesota 56064',17802,22073);
INSERT INTO "django_geo_db_zipcode" VALUES(24977,56065,-6,'Mapleton, Minnesota 56065',17803,22074);
INSERT INTO "django_geo_db_zipcode" VALUES(24978,56068,-6,'Minnesota Lake, Minnesota 56068',17804,22075);
INSERT INTO "django_geo_db_zipcode" VALUES(24979,56069,-6,'Montgomery, Minnesota 56069',17805,22076);
INSERT INTO "django_geo_db_zipcode" VALUES(24980,56071,-6,'New Prague, Minnesota 56071',17806,22077);
INSERT INTO "django_geo_db_zipcode" VALUES(24981,56072,-6,'New Richland, Minnesota 56072',17807,22078);
INSERT INTO "django_geo_db_zipcode" VALUES(24982,56073,-6,'New Ulm, Minnesota 56073',17808,22079);
INSERT INTO "django_geo_db_zipcode" VALUES(24983,56074,-6,'Nicollet, Minnesota 56074',17809,22080);
INSERT INTO "django_geo_db_zipcode" VALUES(24984,56075,-6,'Northrop, Minnesota 56075',17810,22081);
INSERT INTO "django_geo_db_zipcode" VALUES(24985,56076,-6,'Oakland, Minnesota 56076',17811,22082);
INSERT INTO "django_geo_db_zipcode" VALUES(24986,56078,-6,'Pemberton, Minnesota 56078',17812,22083);
INSERT INTO "django_geo_db_zipcode" VALUES(24987,56080,-6,'Saint Clair, Minnesota 56080',17813,22084);
INSERT INTO "django_geo_db_zipcode" VALUES(24988,56081,-6,'Saint James, Minnesota 56081',17814,22085);
INSERT INTO "django_geo_db_zipcode" VALUES(24989,56082,-6,'Saint Peter, Minnesota 56082',17815,22086);
INSERT INTO "django_geo_db_zipcode" VALUES(24990,56083,-6,'Sanborn, Minnesota 56083',17816,22087);
INSERT INTO "django_geo_db_zipcode" VALUES(24991,56084,-6,'Searles, Minnesota 56084',17817,22088);
INSERT INTO "django_geo_db_zipcode" VALUES(24992,56085,-6,'Sleepy Eye, Minnesota 56085',17818,22089);
INSERT INTO "django_geo_db_zipcode" VALUES(24993,56087,-6,'Springfield, Minnesota 56087',17819,22090);
INSERT INTO "django_geo_db_zipcode" VALUES(24994,56088,-6,'Truman, Minnesota 56088',17820,22091);
INSERT INTO "django_geo_db_zipcode" VALUES(24995,56089,-6,'Twin Lakes, Minnesota 56089',17821,22092);
INSERT INTO "django_geo_db_zipcode" VALUES(24996,56090,-6,'Vernon Center, Minnesota 56090',17822,22093);
INSERT INTO "django_geo_db_zipcode" VALUES(24997,56091,-6,'Waldorf, Minnesota 56091',17823,22094);
INSERT INTO "django_geo_db_zipcode" VALUES(24998,56093,-6,'Waseca, Minnesota 56093',17824,22095);
INSERT INTO "django_geo_db_zipcode" VALUES(24999,56096,-6,'Waterville, Minnesota 56096',17825,22096);
INSERT INTO "django_geo_db_zipcode" VALUES(25000,56097,-6,'Wells, Minnesota 56097',17826,22097);
INSERT INTO "django_geo_db_zipcode" VALUES(25001,56098,-6,'Winnebago, Minnesota 56098',17827,22098);
INSERT INTO "django_geo_db_zipcode" VALUES(25002,56101,-6,'Windom, Minnesota 56101',17828,22099);
INSERT INTO "django_geo_db_zipcode" VALUES(25003,56110,-6,'Adrian, Minnesota 56110',17829,22100);
INSERT INTO "django_geo_db_zipcode" VALUES(25004,56111,-6,'Alpha, Minnesota 56111',17830,22101);
INSERT INTO "django_geo_db_zipcode" VALUES(25005,56113,-6,'Arco, Minnesota 56113',17831,22102);
INSERT INTO "django_geo_db_zipcode" VALUES(25006,56114,-6,'Avoca, Minnesota 56114',17832,22103);
INSERT INTO "django_geo_db_zipcode" VALUES(25007,56115,-6,'Balaton, Minnesota 56115',17833,22104);
INSERT INTO "django_geo_db_zipcode" VALUES(25008,56116,-6,'Beaver Creek, Minnesota 56116',17834,22105);
INSERT INTO "django_geo_db_zipcode" VALUES(25009,56117,-6,'Bigelow, Minnesota 56117',17835,22106);
INSERT INTO "django_geo_db_zipcode" VALUES(25010,56118,-6,'Bingham Lake, Minnesota 56118',17836,22107);
INSERT INTO "django_geo_db_zipcode" VALUES(25011,56119,-6,'Brewster, Minnesota 56119',17837,22108);
INSERT INTO "django_geo_db_zipcode" VALUES(25012,56120,-6,'Butterfield, Minnesota 56120',17838,22109);
INSERT INTO "django_geo_db_zipcode" VALUES(25013,56121,-6,'Ceylon, Minnesota 56121',17839,22110);
INSERT INTO "django_geo_db_zipcode" VALUES(25014,56122,-6,'Chandler, Minnesota 56122',17840,22111);
INSERT INTO "django_geo_db_zipcode" VALUES(25015,56123,-6,'Currie, Minnesota 56123',17841,22112);
INSERT INTO "django_geo_db_zipcode" VALUES(25016,56125,-6,'Dovray, Minnesota 56125',17842,22113);
INSERT INTO "django_geo_db_zipcode" VALUES(25017,56126,-6,'Graham Lakes, Minnesota 56126',17843,22114);
INSERT INTO "django_geo_db_zipcode" VALUES(25018,56127,-6,'Dunnell, Minnesota 56127',17844,22115);
INSERT INTO "django_geo_db_zipcode" VALUES(25019,56128,-6,'Edgerton, Minnesota 56128',17845,22116);
INSERT INTO "django_geo_db_zipcode" VALUES(25020,56129,-6,'Ellsworth, Iowa 56129',15769,22117);
INSERT INTO "django_geo_db_zipcode" VALUES(25021,56130,-6,'Florence, Minnesota 56130',17846,22118);
INSERT INTO "django_geo_db_zipcode" VALUES(25022,56131,-6,'Fulda, Minnesota 56131',17847,22119);
INSERT INTO "django_geo_db_zipcode" VALUES(25023,56132,-6,'Garvin, Minnesota 56132',17848,22120);
INSERT INTO "django_geo_db_zipcode" VALUES(25024,56134,-6,'Hardwick, Minnesota 56134',17849,22121);
INSERT INTO "django_geo_db_zipcode" VALUES(25025,56135,-6,'Powers, Minnesota 56135',17850,22122);
INSERT INTO "django_geo_db_zipcode" VALUES(25026,56136,-6,'Hendricks, Minnesota 56136',17851,22123);
INSERT INTO "django_geo_db_zipcode" VALUES(25027,56137,-6,'Heron Lake, Minnesota 56137',17852,22124);
INSERT INTO "django_geo_db_zipcode" VALUES(25028,56138,-6,'Hills, Minnesota 56138',17853,22125);
INSERT INTO "django_geo_db_zipcode" VALUES(25029,56139,-6,'Holland, Minnesota 56139',17854,22126);
INSERT INTO "django_geo_db_zipcode" VALUES(25030,56140,-6,'Ihlen, Minnesota 56140',17855,22127);
INSERT INTO "django_geo_db_zipcode" VALUES(25031,56141,-6,'Iona, Minnesota 56141',17856,22128);
INSERT INTO "django_geo_db_zipcode" VALUES(25032,56142,-6,'Ivanhoe, Minnesota 56142',17857,22129);
INSERT INTO "django_geo_db_zipcode" VALUES(25033,56143,-6,'Jackson, Minnesota 56143',17858,22130);
INSERT INTO "django_geo_db_zipcode" VALUES(25034,56144,-6,'Jasper, Minnesota 56144',17859,22131);
INSERT INTO "django_geo_db_zipcode" VALUES(25035,56145,-6,'Jeffers, Minnesota 56145',17860,22132);
INSERT INTO "django_geo_db_zipcode" VALUES(25036,56146,-6,'Kanaranzi, Minnesota 56146',17861,22133);
INSERT INTO "django_geo_db_zipcode" VALUES(25037,56147,-6,'Kenneth, Minnesota 56147',17862,22134);
INSERT INTO "django_geo_db_zipcode" VALUES(25038,56149,-6,'Lake Benton, Minnesota 56149',17863,22135);
INSERT INTO "django_geo_db_zipcode" VALUES(25039,56150,-6,'Lakefield, Minnesota 56150',17864,22136);
INSERT INTO "django_geo_db_zipcode" VALUES(25040,56151,-6,'Lake Wilson, Minnesota 56151',17865,22137);
INSERT INTO "django_geo_db_zipcode" VALUES(25041,56152,-6,'Lamberton, Minnesota 56152',17866,22138);
INSERT INTO "django_geo_db_zipcode" VALUES(25042,56153,-6,'Leota, Minnesota 56153',17867,22139);
INSERT INTO "django_geo_db_zipcode" VALUES(25043,56155,-6,'Lismore, Minnesota 56155',17868,22140);
INSERT INTO "django_geo_db_zipcode" VALUES(25044,56156,-6,'Luverne, Minnesota 56156',17869,22141);
INSERT INTO "django_geo_db_zipcode" VALUES(25045,56157,-6,'Lynd, Minnesota 56157',17870,22142);
INSERT INTO "django_geo_db_zipcode" VALUES(25046,56158,-6,'Magnolia, Minnesota 56158',17871,22143);
INSERT INTO "django_geo_db_zipcode" VALUES(25047,56159,-6,'Mountain Lake, Minnesota 56159',17872,22144);
INSERT INTO "django_geo_db_zipcode" VALUES(25048,56160,-6,'Odin, Minnesota 56160',17873,22145);
INSERT INTO "django_geo_db_zipcode" VALUES(25049,56161,-6,'Okabena, Minnesota 56161',17874,22146);
INSERT INTO "django_geo_db_zipcode" VALUES(25050,56162,-6,'Ormsby, Minnesota 56162',17875,22147);
INSERT INTO "django_geo_db_zipcode" VALUES(25051,56164,-6,'Pipestone, Minnesota 56164',17876,22148);
INSERT INTO "django_geo_db_zipcode" VALUES(25052,56165,-6,'Reading, Minnesota 56165',17877,22149);
INSERT INTO "django_geo_db_zipcode" VALUES(25053,56166,-6,'Revere, Minnesota 56166',17878,22150);
INSERT INTO "django_geo_db_zipcode" VALUES(25054,56167,-6,'Round Lake, Minnesota 56167',17879,22151);
INSERT INTO "django_geo_db_zipcode" VALUES(25055,56168,-6,'Rushmore, Minnesota 56168',17880,22152);
INSERT INTO "django_geo_db_zipcode" VALUES(25056,56169,-6,'Russell, Minnesota 56169',17881,22153);
INSERT INTO "django_geo_db_zipcode" VALUES(25057,56170,-6,'Ruthton, Minnesota 56170',17882,22154);
INSERT INTO "django_geo_db_zipcode" VALUES(25058,56171,-6,'Sherburn, Minnesota 56171',17883,22155);
INSERT INTO "django_geo_db_zipcode" VALUES(25059,56172,-6,'Slayton, Minnesota 56172',17884,22156);
INSERT INTO "django_geo_db_zipcode" VALUES(25060,56173,-6,'Steen, Minnesota 56173',17885,22157);
INSERT INTO "django_geo_db_zipcode" VALUES(25061,56174,-6,'Storden, Minnesota 56174',17886,22158);
INSERT INTO "django_geo_db_zipcode" VALUES(25062,56175,-6,'Tracy, Minnesota 56175',17887,22159);
INSERT INTO "django_geo_db_zipcode" VALUES(25063,56176,-6,'Trimont, Minnesota 56176',17888,22160);
INSERT INTO "django_geo_db_zipcode" VALUES(25064,56177,-6,'Trosky, Minnesota 56177',17889,22161);
INSERT INTO "django_geo_db_zipcode" VALUES(25065,56178,-6,'Tyler, Minnesota 56178',17890,22162);
INSERT INTO "django_geo_db_zipcode" VALUES(25066,56180,-6,'Walnut Grove, Minnesota 56180',17891,22163);
INSERT INTO "django_geo_db_zipcode" VALUES(25067,56181,-6,'Welcome, Minnesota 56181',17892,22164);
INSERT INTO "django_geo_db_zipcode" VALUES(25068,56183,-6,'Westbrook, Minnesota 56183',17893,22165);
INSERT INTO "django_geo_db_zipcode" VALUES(25069,56185,-6,'Wilmont, Minnesota 56185',17894,22166);
INSERT INTO "django_geo_db_zipcode" VALUES(25070,56186,-6,'Woodstock, Minnesota 56186',17895,22167);
INSERT INTO "django_geo_db_zipcode" VALUES(25071,56187,-6,'Worthington, Minnesota 56187',17896,22168);
INSERT INTO "django_geo_db_zipcode" VALUES(25072,56201,-6,'Willmar, Minnesota 56201',17897,22169);
INSERT INTO "django_geo_db_zipcode" VALUES(25073,56207,-6,'Alberta, Minnesota 56207',17898,22170);
INSERT INTO "django_geo_db_zipcode" VALUES(25074,56208,-6,'Appleton, Minnesota 56208',17899,22171);
INSERT INTO "django_geo_db_zipcode" VALUES(25075,56209,-6,'Atwater, Minnesota 56209',17900,22172);
INSERT INTO "django_geo_db_zipcode" VALUES(25076,56210,-6,'Barry, Minnesota 56210',17901,22173);
INSERT INTO "django_geo_db_zipcode" VALUES(25077,56211,-6,'Beardsley, Minnesota 56211',17902,22174);
INSERT INTO "django_geo_db_zipcode" VALUES(25078,56212,-6,'Bellingham, Minnesota 56212',17903,22175);
INSERT INTO "django_geo_db_zipcode" VALUES(25079,56214,-6,'Belview, Minnesota 56214',17904,22176);
INSERT INTO "django_geo_db_zipcode" VALUES(25080,56215,-6,'Benson, Minnesota 56215',17905,22177);
INSERT INTO "django_geo_db_zipcode" VALUES(25081,56216,-6,'Blomkest, Minnesota 56216',17906,22178);
INSERT INTO "django_geo_db_zipcode" VALUES(25082,56218,-6,'Boyd, Minnesota 56218',17907,22179);
INSERT INTO "django_geo_db_zipcode" VALUES(25083,56219,-6,'Browns Valley, Minnesota 56219',17908,22180);
INSERT INTO "django_geo_db_zipcode" VALUES(25084,56220,-6,'Canby, Minnesota 56220',17909,22181);
INSERT INTO "django_geo_db_zipcode" VALUES(25085,56221,-6,'Chokio, Minnesota 56221',17910,22182);
INSERT INTO "django_geo_db_zipcode" VALUES(25086,56222,-6,'Clara City, Minnesota 56222',17911,22183);
INSERT INTO "django_geo_db_zipcode" VALUES(25087,56223,-6,'Clarkfield, Minnesota 56223',17912,22184);
INSERT INTO "django_geo_db_zipcode" VALUES(25088,56224,-6,'Clements, Minnesota 56224',17913,22185);
INSERT INTO "django_geo_db_zipcode" VALUES(25089,56225,-6,'Clinton, Minnesota 56225',17914,22186);
INSERT INTO "django_geo_db_zipcode" VALUES(25090,56226,-6,'Clontarf, Minnesota 56226',17915,22187);
INSERT INTO "django_geo_db_zipcode" VALUES(25091,56227,-6,'Correll, Minnesota 56227',17916,22188);
INSERT INTO "django_geo_db_zipcode" VALUES(25092,56228,-6,'Cosmos, Minnesota 56228',17917,22189);
INSERT INTO "django_geo_db_zipcode" VALUES(25093,56229,-6,'Cottonwood, Minnesota 56229',17918,22190);
INSERT INTO "django_geo_db_zipcode" VALUES(25094,56230,-6,'Danube, Minnesota 56230',17919,22191);
INSERT INTO "django_geo_db_zipcode" VALUES(25095,56231,-6,'Danvers, Minnesota 56231',17920,22192);
INSERT INTO "django_geo_db_zipcode" VALUES(25096,56232,-6,'Dawson, Minnesota 56232',17921,22193);
INSERT INTO "django_geo_db_zipcode" VALUES(25097,56235,-6,'Donnelly, Minnesota 56235',17922,22194);
INSERT INTO "django_geo_db_zipcode" VALUES(25098,56236,-6,'Dumont, Minnesota 56236',17923,22195);
INSERT INTO "django_geo_db_zipcode" VALUES(25099,56237,-6,'Echo, Minnesota 56237',17924,22196);
INSERT INTO "django_geo_db_zipcode" VALUES(25100,56239,-6,'Ghent, Minnesota 56239',17925,22197);
INSERT INTO "django_geo_db_zipcode" VALUES(25101,56240,-6,'Graceville, Minnesota 56240',17926,22198);
INSERT INTO "django_geo_db_zipcode" VALUES(25102,56241,-6,'Granite Falls, Minnesota 56241',17927,22199);
INSERT INTO "django_geo_db_zipcode" VALUES(25103,56243,-6,'Grove City, Minnesota 56243',17928,22200);
INSERT INTO "django_geo_db_zipcode" VALUES(25104,56244,-6,'Hancock, Minnesota 56244',17929,22201);
INSERT INTO "django_geo_db_zipcode" VALUES(25105,56245,-6,'Hanley Falls, Minnesota 56245',17930,22202);
INSERT INTO "django_geo_db_zipcode" VALUES(25106,56246,-6,'Hawick, Minnesota 56246',17931,22203);
INSERT INTO "django_geo_db_zipcode" VALUES(25107,56248,-6,'Herman, Minnesota 56248',17932,22204);
INSERT INTO "django_geo_db_zipcode" VALUES(25108,56249,-6,'Holloway, Minnesota 56249',17933,22205);
INSERT INTO "django_geo_db_zipcode" VALUES(25109,56251,-6,'Kandiyohi, Minnesota 56251',17934,22206);
INSERT INTO "django_geo_db_zipcode" VALUES(25110,56252,-6,'Kerkhoven, Minnesota 56252',17935,22207);
INSERT INTO "django_geo_db_zipcode" VALUES(25111,56253,-6,'Lake Lillian, Minnesota 56253',17936,22208);
INSERT INTO "django_geo_db_zipcode" VALUES(25112,56255,-6,'Lucan, Minnesota 56255',17937,22209);
INSERT INTO "django_geo_db_zipcode" VALUES(25113,56256,-6,'Madison, Minnesota 56256',17938,22210);
INSERT INTO "django_geo_db_zipcode" VALUES(25114,56257,-6,'Marietta, Minnesota 56257',17939,22211);
INSERT INTO "django_geo_db_zipcode" VALUES(25115,56258,-6,'Marshall, Minnesota 56258',17940,22212);
INSERT INTO "django_geo_db_zipcode" VALUES(25116,56260,-6,'Maynard, Minnesota 56260',17941,22213);
INSERT INTO "django_geo_db_zipcode" VALUES(25117,56262,-6,'Milan, Minnesota 56262',17942,22214);
INSERT INTO "django_geo_db_zipcode" VALUES(25118,56263,-6,'Milroy, Minnesota 56263',17943,22215);
INSERT INTO "django_geo_db_zipcode" VALUES(25119,56264,-6,'Minneota, Minnesota 56264',17944,22216);
INSERT INTO "django_geo_db_zipcode" VALUES(25120,56265,-6,'Montevideo, Minnesota 56265',17945,22217);
INSERT INTO "django_geo_db_zipcode" VALUES(25121,56266,-6,'Morgan, Minnesota 56266',17946,22218);
INSERT INTO "django_geo_db_zipcode" VALUES(25122,56267,-6,'Morris, Minnesota 56267',17947,22219);
INSERT INTO "django_geo_db_zipcode" VALUES(25123,56270,-6,'Morton, Minnesota 56270',17948,22220);
INSERT INTO "django_geo_db_zipcode" VALUES(25124,56271,-6,'Murdock, Minnesota 56271',17949,22221);
INSERT INTO "django_geo_db_zipcode" VALUES(25125,56273,-6,'New London, Minnesota 56273',17950,22222);
INSERT INTO "django_geo_db_zipcode" VALUES(25126,56274,-6,'Norcross, Minnesota 56274',17951,22223);
INSERT INTO "django_geo_db_zipcode" VALUES(25127,56276,-6,'Odessa, Minnesota 56276',17952,22224);
INSERT INTO "django_geo_db_zipcode" VALUES(25128,56277,-6,'Olivia, Minnesota 56277',17953,22225);
INSERT INTO "django_geo_db_zipcode" VALUES(25129,56278,-6,'Ortonville, Minnesota 56278',17954,22226);
INSERT INTO "django_geo_db_zipcode" VALUES(25130,56279,-6,'Pennock, Minnesota 56279',17955,22227);
INSERT INTO "django_geo_db_zipcode" VALUES(25131,56280,-6,'Porter, Minnesota 56280',17956,22228);
INSERT INTO "django_geo_db_zipcode" VALUES(25132,56281,-6,'Prinsburg, Minnesota 56281',17957,22229);
INSERT INTO "django_geo_db_zipcode" VALUES(25133,56282,-6,'Raymond, Minnesota 56282',17958,22230);
INSERT INTO "django_geo_db_zipcode" VALUES(25134,56283,-6,'Redwood Falls, Minnesota 56283',17959,22231);
INSERT INTO "django_geo_db_zipcode" VALUES(25135,56284,-6,'Renville, Minnesota 56284',17960,22232);
INSERT INTO "django_geo_db_zipcode" VALUES(25136,56285,-6,'Sacred Heart, Minnesota 56285',17961,22233);
INSERT INTO "django_geo_db_zipcode" VALUES(25137,56286,-6,'St. Leo, Minnesota 56286',17962,22234);
INSERT INTO "django_geo_db_zipcode" VALUES(25138,56287,-6,'Seaforth, Minnesota 56287',17963,22235);
INSERT INTO "django_geo_db_zipcode" VALUES(25139,56288,-6,'Spicer, Minnesota 56288',17964,22236);
INSERT INTO "django_geo_db_zipcode" VALUES(25140,56289,-6,'Sunburg, Minnesota 56289',17965,22237);
INSERT INTO "django_geo_db_zipcode" VALUES(25141,56291,-6,'Taunton, Minnesota 56291',17966,22238);
INSERT INTO "django_geo_db_zipcode" VALUES(25142,56292,-6,'Vesta, Minnesota 56292',17967,22239);
INSERT INTO "django_geo_db_zipcode" VALUES(25143,56293,-6,'Wabasso, Minnesota 56293',17968,22240);
INSERT INTO "django_geo_db_zipcode" VALUES(25144,56294,-6,'Wanda, Minnesota 56294',17969,22241);
INSERT INTO "django_geo_db_zipcode" VALUES(25145,56295,-6,'Watson, Minnesota 56295',17970,22242);
INSERT INTO "django_geo_db_zipcode" VALUES(25146,56296,-6,'Wheaton, Minnesota 56296',17971,22243);
INSERT INTO "django_geo_db_zipcode" VALUES(25147,56297,-6,'Wood Lake, Minnesota 56297',17972,22244);
INSERT INTO "django_geo_db_zipcode" VALUES(25148,56301,-6,'Saint Cloud, Minnesota 56301',17973,22245);
INSERT INTO "django_geo_db_zipcode" VALUES(25149,56302,-6,'Saint Cloud, Minnesota 56302',17973,22246);
INSERT INTO "django_geo_db_zipcode" VALUES(25150,56303,-6,'Saint Cloud, Minnesota 56303',17973,22247);
INSERT INTO "django_geo_db_zipcode" VALUES(25151,56304,-6,'Saint Cloud, Minnesota 56304',17973,22248);
INSERT INTO "django_geo_db_zipcode" VALUES(25152,56307,-6,'Albany, Minnesota 56307',17974,22249);
INSERT INTO "django_geo_db_zipcode" VALUES(25153,56308,-6,'Alexandria, Minnesota 56308',17975,22250);
INSERT INTO "django_geo_db_zipcode" VALUES(25154,56309,-6,'Ashby, Minnesota 56309',17976,22251);
INSERT INTO "django_geo_db_zipcode" VALUES(25155,56310,-6,'Avon, Minnesota 56310',17977,22252);
INSERT INTO "django_geo_db_zipcode" VALUES(25156,56311,-6,'Barrett, Minnesota 56311',17978,22253);
INSERT INTO "django_geo_db_zipcode" VALUES(25157,56312,-6,'Belgrade, Minnesota 56312',17979,22254);
INSERT INTO "django_geo_db_zipcode" VALUES(25158,56313,-6,'Bock, Minnesota 56313',17980,22255);
INSERT INTO "django_geo_db_zipcode" VALUES(25159,56314,-6,'Bowlus, Minnesota 56314',17981,22256);
INSERT INTO "django_geo_db_zipcode" VALUES(25160,56315,-6,'Brandon, Minnesota 56315',17982,22257);
INSERT INTO "django_geo_db_zipcode" VALUES(25161,56316,-6,'Brooten, Minnesota 56316',17983,22258);
INSERT INTO "django_geo_db_zipcode" VALUES(25162,56317,-6,'Buckman, Minnesota 56317',17984,22259);
INSERT INTO "django_geo_db_zipcode" VALUES(25163,56318,-6,'Burtrum, Minnesota 56318',17985,22260);
INSERT INTO "django_geo_db_zipcode" VALUES(25164,56319,-6,'Carlos, Minnesota 56319',17986,22261);
INSERT INTO "django_geo_db_zipcode" VALUES(25165,56320,-6,'Cold Spring, Minnesota 56320',17987,22262);
INSERT INTO "django_geo_db_zipcode" VALUES(25166,56321,-6,'Collegeville, Minnesota 56321',17988,22263);
INSERT INTO "django_geo_db_zipcode" VALUES(25167,56323,-6,'Cyrus, Minnesota 56323',17989,22264);
INSERT INTO "django_geo_db_zipcode" VALUES(25168,56324,-6,'Dalton, Minnesota 56324',17990,22265);
INSERT INTO "django_geo_db_zipcode" VALUES(25169,56325,-6,'Elrosa, Minnesota 56325',17991,22266);
INSERT INTO "django_geo_db_zipcode" VALUES(25170,56326,-6,'Evansville, Minnesota 56326',17992,22267);
INSERT INTO "django_geo_db_zipcode" VALUES(25171,56327,-6,'Farwell, Minnesota 56327',17993,22268);
INSERT INTO "django_geo_db_zipcode" VALUES(25172,56328,-6,'Flensburg, Minnesota 56328',17994,22269);
INSERT INTO "django_geo_db_zipcode" VALUES(25173,56329,-6,'Foley, Minnesota 56329',17995,22270);
INSERT INTO "django_geo_db_zipcode" VALUES(25174,56330,-6,'Foreston, Minnesota 56330',17996,22271);
INSERT INTO "django_geo_db_zipcode" VALUES(25175,56331,-6,'Freeport, Minnesota 56331',17997,22272);
INSERT INTO "django_geo_db_zipcode" VALUES(25176,56332,-6,'Garfield, Minnesota 56332',17998,22273);
INSERT INTO "django_geo_db_zipcode" VALUES(25177,56333,-6,'Gilman, Minnesota 56333',17999,22274);
INSERT INTO "django_geo_db_zipcode" VALUES(25178,56334,-6,'Glenwood, Minnesota 56334',18000,22275);
INSERT INTO "django_geo_db_zipcode" VALUES(25179,56335,-6,'Greenwald, Minnesota 56335',18001,22276);
INSERT INTO "django_geo_db_zipcode" VALUES(25180,56336,-6,'Grey Eagle, Minnesota 56336',18002,22277);
INSERT INTO "django_geo_db_zipcode" VALUES(25181,56338,-6,'Hillman, Minnesota 56338',18003,22278);
INSERT INTO "django_geo_db_zipcode" VALUES(25182,56339,-6,'Hoffman, Minnesota 56339',18004,22279);
INSERT INTO "django_geo_db_zipcode" VALUES(25183,56340,-6,'Holdingford, Minnesota 56340',18005,22280);
INSERT INTO "django_geo_db_zipcode" VALUES(25184,56341,-6,'Holmes City, Minnesota 56341',18006,22281);
INSERT INTO "django_geo_db_zipcode" VALUES(25185,56342,-6,'Isle, Minnesota 56342',18007,22282);
INSERT INTO "django_geo_db_zipcode" VALUES(25186,56343,-6,'Kensington, Minnesota 56343',18008,22283);
INSERT INTO "django_geo_db_zipcode" VALUES(25187,56344,-6,'Lastrup, Minnesota 56344',18009,22259);
INSERT INTO "django_geo_db_zipcode" VALUES(25188,56345,-6,'Little Falls, Minnesota 56345',18010,22284);
INSERT INTO "django_geo_db_zipcode" VALUES(25189,56347,-6,'Long Prairie, Minnesota 56347',18011,22285);
INSERT INTO "django_geo_db_zipcode" VALUES(25190,56349,-6,'Lowry, Minnesota 56349',18012,22286);
INSERT INTO "django_geo_db_zipcode" VALUES(25191,56350,-6,'McGrath, Minnesota 56350',18013,22287);
INSERT INTO "django_geo_db_zipcode" VALUES(25192,56352,-6,'Melrose, Minnesota 56352',18014,22288);
INSERT INTO "django_geo_db_zipcode" VALUES(25193,56353,-6,'Milaca, Minnesota 56353',18015,22289);
INSERT INTO "django_geo_db_zipcode" VALUES(25194,56354,-6,'Miltona, Minnesota 56354',18016,22290);
INSERT INTO "django_geo_db_zipcode" VALUES(25195,56355,-6,'Nelson, Minnesota 56355',18017,22291);
INSERT INTO "django_geo_db_zipcode" VALUES(25196,56356,-6,'New Munich, Minnesota 56356',18018,22292);
INSERT INTO "django_geo_db_zipcode" VALUES(25197,56357,-6,'Oak Park, Minnesota 56357',18019,22293);
INSERT INTO "django_geo_db_zipcode" VALUES(25198,56358,-6,'Ogilvie, Minnesota 56358',18020,22294);
INSERT INTO "django_geo_db_zipcode" VALUES(25199,56359,-6,'Onamia, Minnesota 56359',18021,22295);
INSERT INTO "django_geo_db_zipcode" VALUES(25200,56360,-6,'Osakis, Minnesota 56360',18022,22296);
INSERT INTO "django_geo_db_zipcode" VALUES(25201,56361,-6,'Parkers Prairie, Minnesota 56361',18023,22297);
INSERT INTO "django_geo_db_zipcode" VALUES(25202,56362,-6,'Paynesville, Minnesota 56362',18024,22298);
INSERT INTO "django_geo_db_zipcode" VALUES(25203,56363,-6,'Pease, Minnesota 56363',18025,22299);
INSERT INTO "django_geo_db_zipcode" VALUES(25204,56364,-6,'Pierz, Minnesota 56364',18026,22300);
INSERT INTO "django_geo_db_zipcode" VALUES(25205,56366,-6,'Bowstring, Minnesota 56366',18027,22301);
INSERT INTO "django_geo_db_zipcode" VALUES(25206,56367,-6,'Rice, Minnesota 56367',18028,22302);
INSERT INTO "django_geo_db_zipcode" VALUES(25207,56368,-6,'Richmond, Minnesota 56368',18029,22303);
INSERT INTO "django_geo_db_zipcode" VALUES(25208,56369,-6,'Rockville, Minnesota 56369',18030,22304);
INSERT INTO "django_geo_db_zipcode" VALUES(25209,56371,-6,'Roscoe, Minnesota 56371',18031,22305);
INSERT INTO "django_geo_db_zipcode" VALUES(25210,56372,-6,'Saint Cloud, Minnesota 56372',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25211,56373,-6,'Royalton, Minnesota 56373',18032,22307);
INSERT INTO "django_geo_db_zipcode" VALUES(25212,56374,-6,'Saint Joseph, Minnesota 56374',18033,22308);
INSERT INTO "django_geo_db_zipcode" VALUES(25213,56375,-6,'Saint Stephen, Minnesota 56375',18034,22309);
INSERT INTO "django_geo_db_zipcode" VALUES(25214,56376,-6,'Saint Martin, Minnesota 56376',18035,22310);
INSERT INTO "django_geo_db_zipcode" VALUES(25215,56377,-6,'Sartell, Minnesota 56377',18036,22311);
INSERT INTO "django_geo_db_zipcode" VALUES(25216,56378,-6,'Sauk Centre, Minnesota 56378',18037,22312);
INSERT INTO "django_geo_db_zipcode" VALUES(25217,56379,-6,'Sauk Rapids, Minnesota 56379',18038,22313);
INSERT INTO "django_geo_db_zipcode" VALUES(25218,56381,-6,'Starbuck, Minnesota 56381',18039,22314);
INSERT INTO "django_geo_db_zipcode" VALUES(25219,56382,-6,'Swanville, Minnesota 56382',18040,22315);
INSERT INTO "django_geo_db_zipcode" VALUES(25220,56384,-6,'Upsala, Minnesota 56384',18041,22316);
INSERT INTO "django_geo_db_zipcode" VALUES(25221,56385,-6,'Villard, Minnesota 56385',18042,22317);
INSERT INTO "django_geo_db_zipcode" VALUES(25222,56386,-6,'Wahkon, Minnesota 56386',18043,22318);
INSERT INTO "django_geo_db_zipcode" VALUES(25223,56387,-6,'Waite Park, Minnesota 56387',18044,22319);
INSERT INTO "django_geo_db_zipcode" VALUES(25224,56388,-6,'Mount Morris, Minnesota 56388',18045,22320);
INSERT INTO "django_geo_db_zipcode" VALUES(25225,56389,-6,'West Union, Minnesota 56389',18046,22321);
INSERT INTO "django_geo_db_zipcode" VALUES(25226,56393,-6,'Saint Cloud, Minnesota 56393',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25227,56395,-6,'Saint Cloud, Minnesota 56395',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25228,56396,-6,'Saint Cloud, Minnesota 56396',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25229,56397,-6,'Saint Cloud, Minnesota 56397',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25230,56398,-6,'Saint Cloud, Minnesota 56398',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25231,56399,-6,'Saint Cloud, Minnesota 56399',17973,22306);
INSERT INTO "django_geo_db_zipcode" VALUES(25232,56401,-6,'Brainerd, Minnesota 56401',18047,22322);
INSERT INTO "django_geo_db_zipcode" VALUES(25233,56425,-6,'Baxter, Minnesota 56425',18048,22323);
INSERT INTO "django_geo_db_zipcode" VALUES(25234,56430,-6,'Ah Gwah Ching, Minnesota 56430',18049,22324);
INSERT INTO "django_geo_db_zipcode" VALUES(25235,56431,-6,'Aitkin, Minnesota 56431',18050,22325);
INSERT INTO "django_geo_db_zipcode" VALUES(25236,56432,-6,'Acton, Minnesota 56432',18051,22326);
INSERT INTO "django_geo_db_zipcode" VALUES(25237,56433,-6,'Akeley, Minnesota 56433',18052,22327);
INSERT INTO "django_geo_db_zipcode" VALUES(25238,56434,-6,'Aldrich, Minnesota 56434',18053,22328);
INSERT INTO "django_geo_db_zipcode" VALUES(25239,56435,-6,'Backus, Minnesota 56435',18054,22329);
INSERT INTO "django_geo_db_zipcode" VALUES(25240,56436,-6,'Benedict, Minnesota 56436',18055,22330);
INSERT INTO "django_geo_db_zipcode" VALUES(25241,56437,-6,'Bertha, Minnesota 56437',18056,22331);
INSERT INTO "django_geo_db_zipcode" VALUES(25242,56438,-6,'Browerville, Minnesota 56438',18057,22332);
INSERT INTO "django_geo_db_zipcode" VALUES(25243,56440,-6,'Clarissa, Minnesota 56440',18058,22333);
INSERT INTO "django_geo_db_zipcode" VALUES(25244,56441,-6,'Crosby, Minnesota 56441',18059,22334);
INSERT INTO "django_geo_db_zipcode" VALUES(25245,56442,-6,'Crosslake, Minnesota 56442',18060,22335);
INSERT INTO "django_geo_db_zipcode" VALUES(25246,56443,-6,'Cushing, Minnesota 56443',18061,22336);
INSERT INTO "django_geo_db_zipcode" VALUES(25247,56444,-6,'Deerwood, Minnesota 56444',18062,22337);
INSERT INTO "django_geo_db_zipcode" VALUES(25248,56446,-6,'Eagle Bend, Minnesota 56446',18063,22338);
INSERT INTO "django_geo_db_zipcode" VALUES(25249,56447,-6,'Emily, Minnesota 56447',18064,22339);
INSERT INTO "django_geo_db_zipcode" VALUES(25250,56448,-6,'Fifty Lakes, Minnesota 56448',18065,22340);
INSERT INTO "django_geo_db_zipcode" VALUES(25251,56449,-6,'Fort Ripley, Minnesota 56449',18066,22341);
INSERT INTO "django_geo_db_zipcode" VALUES(25252,56450,-6,'Garrison, Minnesota 56450',18067,22342);
INSERT INTO "django_geo_db_zipcode" VALUES(25253,56452,-6,'Hackensack, Minnesota 56452',18068,22343);
INSERT INTO "django_geo_db_zipcode" VALUES(25254,56453,-6,'Hewitt, Minnesota 56453',18069,22344);
INSERT INTO "django_geo_db_zipcode" VALUES(25255,56455,-6,'Ironton, Minnesota 56455',18070,22345);
INSERT INTO "django_geo_db_zipcode" VALUES(25256,56456,-6,'Jenkins, Minnesota 56456',18071,22346);
INSERT INTO "django_geo_db_zipcode" VALUES(25257,56458,-6,'Lake George, Minnesota 56458',18072,22347);
INSERT INTO "django_geo_db_zipcode" VALUES(25258,56459,-6,'Lake Hubert, Minnesota 56459',18073,22348);
INSERT INTO "django_geo_db_zipcode" VALUES(25259,56460,-6,'Itasca, Minnesota 56460',18074,22349);
INSERT INTO "django_geo_db_zipcode" VALUES(25260,56461,-6,'Laporte, Minnesota 56461',18075,22350);
INSERT INTO "django_geo_db_zipcode" VALUES(25261,56464,-6,'Menahga, Minnesota 56464',18076,22351);
INSERT INTO "django_geo_db_zipcode" VALUES(25262,56465,-6,'Merrifield, Minnesota 56465',18077,22352);
INSERT INTO "django_geo_db_zipcode" VALUES(25263,56466,-6,'Motley, Minnesota 56466',18078,22353);
INSERT INTO "django_geo_db_zipcode" VALUES(25264,56467,-6,'Nevis, Minnesota 56467',18079,22354);
INSERT INTO "django_geo_db_zipcode" VALUES(25265,56468,-6,'Nisswa, Minnesota 56468',18080,22355);
INSERT INTO "django_geo_db_zipcode" VALUES(25266,56469,-6,'Palisade, Minnesota 56469',18081,22356);
INSERT INTO "django_geo_db_zipcode" VALUES(25267,56470,-6,'Park Rapids, Minnesota 56470',18082,22357);
INSERT INTO "django_geo_db_zipcode" VALUES(25268,56472,-6,'Pequot Lakes, Minnesota 56472',18083,22358);
INSERT INTO "django_geo_db_zipcode" VALUES(25269,56473,-6,'Pillager, Minnesota 56473',18084,22359);
INSERT INTO "django_geo_db_zipcode" VALUES(25270,56474,-6,'Pine River, Minnesota 56474',18085,22360);
INSERT INTO "django_geo_db_zipcode" VALUES(25271,56475,-6,'Randall, Minnesota 56475',18086,22361);
INSERT INTO "django_geo_db_zipcode" VALUES(25272,56477,-6,'Sebeka, Minnesota 56477',18087,22362);
INSERT INTO "django_geo_db_zipcode" VALUES(25273,56478,-6,'Nimrod, Minnesota 56478',18088,22363);
INSERT INTO "django_geo_db_zipcode" VALUES(25274,56479,-6,'Staples, Minnesota 56479',18089,22364);
INSERT INTO "django_geo_db_zipcode" VALUES(25275,56481,-6,'Verndale, Minnesota 56481',18090,22365);
INSERT INTO "django_geo_db_zipcode" VALUES(25276,56482,-6,'Wadena, Minnesota 56482',18091,22366);
INSERT INTO "django_geo_db_zipcode" VALUES(25277,56483,-6,'Wadena, Minnesota 56483',18091,22367);
INSERT INTO "django_geo_db_zipcode" VALUES(25278,56484,-6,'Walker, Minnesota 56484',18092,22368);
INSERT INTO "django_geo_db_zipcode" VALUES(25279,56501,-6,'Detroit Lakes, Minnesota 56501',18093,22369);
INSERT INTO "django_geo_db_zipcode" VALUES(25280,56502,-6,'Detroit Lakes, Minnesota 56502',18093,22370);
INSERT INTO "django_geo_db_zipcode" VALUES(25281,56508,-6,'Lake Eunice, Minnesota 56508',18094,22371);
INSERT INTO "django_geo_db_zipcode" VALUES(25282,56510,-6,'Ada, Minnesota 56510',18095,22372);
INSERT INTO "django_geo_db_zipcode" VALUES(25283,56511,-6,'Audubon, Minnesota 56511',18096,22373);
INSERT INTO "django_geo_db_zipcode" VALUES(25284,56513,-6,'Baker, Minnesota 56513',18097,22374);
INSERT INTO "django_geo_db_zipcode" VALUES(25285,56514,-6,'Barnesville, Minnesota 56514',18098,22375);
INSERT INTO "django_geo_db_zipcode" VALUES(25286,56515,-6,'Battle Lake, Minnesota 56515',18099,22376);
INSERT INTO "django_geo_db_zipcode" VALUES(25287,56516,-6,'Bejou, Minnesota 56516',18100,22377);
INSERT INTO "django_geo_db_zipcode" VALUES(25288,56517,-6,'Beltrami, Minnesota 56517',18101,22378);
INSERT INTO "django_geo_db_zipcode" VALUES(25289,56518,-6,'Bluffton, Minnesota 56518',18102,22379);
INSERT INTO "django_geo_db_zipcode" VALUES(25290,56519,-6,'Borup, Minnesota 56519',18103,22380);
INSERT INTO "django_geo_db_zipcode" VALUES(25291,56520,-6,'Breckenridge, Minnesota 56520',18104,22381);
INSERT INTO "django_geo_db_zipcode" VALUES(25292,56521,-6,'Callaway, Minnesota 56521',18105,22382);
INSERT INTO "django_geo_db_zipcode" VALUES(25293,56522,-6,'Campbell, Minnesota 56522',18106,22383);
INSERT INTO "django_geo_db_zipcode" VALUES(25294,56523,-6,'Climax, Minnesota 56523',18107,22384);
INSERT INTO "django_geo_db_zipcode" VALUES(25295,56524,-6,'Clitherall, Minnesota 56524',18108,22385);
INSERT INTO "django_geo_db_zipcode" VALUES(25296,56525,-6,'Comstock, Minnesota 56525',18109,22386);
INSERT INTO "django_geo_db_zipcode" VALUES(25297,56527,-6,'Deer Creek, Minnesota 56527',18110,22387);
INSERT INTO "django_geo_db_zipcode" VALUES(25298,56528,-6,'Dent, Minnesota 56528',18111,22388);
INSERT INTO "django_geo_db_zipcode" VALUES(25299,56529,-6,'Dilworth, Minnesota 56529',18112,22389);
INSERT INTO "django_geo_db_zipcode" VALUES(25300,56531,-6,'Elbow Lake, Minnesota 56531',18113,22390);
INSERT INTO "django_geo_db_zipcode" VALUES(25301,56533,-6,'Elizabeth, Minnesota 56533',18114,22391);
INSERT INTO "django_geo_db_zipcode" VALUES(25302,56534,-6,'Erhard, Minnesota 56534',18115,22392);
INSERT INTO "django_geo_db_zipcode" VALUES(25303,56535,-6,'Erskine, Minnesota 56535',18116,22393);
INSERT INTO "django_geo_db_zipcode" VALUES(25304,56536,-6,'Felton, Minnesota 56536',18117,22394);
INSERT INTO "django_geo_db_zipcode" VALUES(25305,56537,-6,'Fergus Falls, Minnesota 56537',18118,22395);
INSERT INTO "django_geo_db_zipcode" VALUES(25306,56538,-6,'Fergus Falls, Minnesota 56538',18118,22396);
INSERT INTO "django_geo_db_zipcode" VALUES(25307,56540,-6,'Fertile, Minnesota 56540',18119,22397);
INSERT INTO "django_geo_db_zipcode" VALUES(25308,56541,-6,'Flom, Minnesota 56541',18120,22398);
INSERT INTO "django_geo_db_zipcode" VALUES(25309,56542,-6,'Fosston, Minnesota 56542',18121,22399);
INSERT INTO "django_geo_db_zipcode" VALUES(25310,56543,-6,'Foxhome, Minnesota 56543',18122,22400);
INSERT INTO "django_geo_db_zipcode" VALUES(25311,56544,-6,'Frazee, Minnesota 56544',18123,22401);
INSERT INTO "django_geo_db_zipcode" VALUES(25312,56545,-6,'Gary, Minnesota 56545',18124,22402);
INSERT INTO "django_geo_db_zipcode" VALUES(25313,56546,-6,'Georgetown, Minnesota 56546',18125,22403);
INSERT INTO "django_geo_db_zipcode" VALUES(25314,56547,-6,'Glyndon, Minnesota 56547',18126,22404);
INSERT INTO "django_geo_db_zipcode" VALUES(25315,56548,-6,'Halstad, Minnesota 56548',18127,22405);
INSERT INTO "django_geo_db_zipcode" VALUES(25316,56549,-6,'Hawley, Minnesota 56549',18128,22406);
INSERT INTO "django_geo_db_zipcode" VALUES(25317,56550,-6,'Hendrum, Minnesota 56550',18129,22407);
INSERT INTO "django_geo_db_zipcode" VALUES(25318,56551,-6,'Henning, Minnesota 56551',18130,22408);
INSERT INTO "django_geo_db_zipcode" VALUES(25319,56552,-6,'Hitterdal, Minnesota 56552',18131,22409);
INSERT INTO "django_geo_db_zipcode" VALUES(25320,56553,-6,'Kent, Minnesota 56553',18132,22410);
INSERT INTO "django_geo_db_zipcode" VALUES(25321,56554,-6,'Lake Park, Minnesota 56554',18133,22411);
INSERT INTO "django_geo_db_zipcode" VALUES(25322,56556,-6,'Mcintosh, Minnesota 56556',18134,22412);
INSERT INTO "django_geo_db_zipcode" VALUES(25323,56557,-6,'Mahnomen, Minnesota 56557',18135,22413);
INSERT INTO "django_geo_db_zipcode" VALUES(25324,56560,-6,'Moorhead, Minnesota 56560',18136,22414);
INSERT INTO "django_geo_db_zipcode" VALUES(25325,56561,-6,'Moorhead, Minnesota 56561',18136,22415);
INSERT INTO "django_geo_db_zipcode" VALUES(25326,56562,-6,'Moorhead, Minnesota 56562',18136,22415);
INSERT INTO "django_geo_db_zipcode" VALUES(25327,56563,-6,'Moorhead, Minnesota 56563',18136,22415);
INSERT INTO "django_geo_db_zipcode" VALUES(25328,56565,-6,'Nashua, Minnesota 56565',18137,22416);
INSERT INTO "django_geo_db_zipcode" VALUES(25329,56566,-6,'Naytahwaush, Minnesota 56566',18138,22417);
INSERT INTO "django_geo_db_zipcode" VALUES(25330,56567,-6,'New York Mills, Minnesota 56567',18139,22418);
INSERT INTO "django_geo_db_zipcode" VALUES(25331,56568,-6,'Nielsville, Minnesota 56568',18140,22419);
INSERT INTO "django_geo_db_zipcode" VALUES(25332,56569,-6,'Ogema, Minnesota 56569',18141,22420);
INSERT INTO "django_geo_db_zipcode" VALUES(25333,56570,-6,'Osage, Minnesota 56570',18142,22421);
INSERT INTO "django_geo_db_zipcode" VALUES(25334,56571,-6,'Ottertail, Minnesota 56571',18143,22422);
INSERT INTO "django_geo_db_zipcode" VALUES(25335,56572,-6,'Pelican Rapids, Minnesota 56572',18144,22423);
INSERT INTO "django_geo_db_zipcode" VALUES(25336,56573,-6,'Perham, Minnesota 56573',18145,22424);
INSERT INTO "django_geo_db_zipcode" VALUES(25337,56574,-6,'Perley, Minnesota 56574',18146,22425);
INSERT INTO "django_geo_db_zipcode" VALUES(25338,56575,-6,'Ponsford, Minnesota 56575',18147,22426);
INSERT INTO "django_geo_db_zipcode" VALUES(25339,56576,-6,'Richville, Minnesota 56576',18148,22427);
INSERT INTO "django_geo_db_zipcode" VALUES(25340,56577,-6,'Richwood, Minnesota 56577',18149,22370);
INSERT INTO "django_geo_db_zipcode" VALUES(25341,56578,-6,'Rochert, Minnesota 56578',18150,22428);
INSERT INTO "django_geo_db_zipcode" VALUES(25342,56579,-6,'Rothsay, Minnesota 56579',18151,22429);
INSERT INTO "django_geo_db_zipcode" VALUES(25343,56580,-6,'Sabin, Minnesota 56580',18152,22430);
INSERT INTO "django_geo_db_zipcode" VALUES(25344,56581,-6,'Shelly, Minnesota 56581',18153,22431);
INSERT INTO "django_geo_db_zipcode" VALUES(25345,56583,-6,'Tintah, Minnesota 56583',18154,22432);
INSERT INTO "django_geo_db_zipcode" VALUES(25346,56584,-6,'Twin Valley, Minnesota 56584',18155,22433);
INSERT INTO "django_geo_db_zipcode" VALUES(25347,56585,-6,'Ulen, Minnesota 56585',18156,22434);
INSERT INTO "django_geo_db_zipcode" VALUES(25348,56586,-6,'Underwood, Minnesota 56586',18157,22435);
INSERT INTO "django_geo_db_zipcode" VALUES(25349,56587,-6,'Vergas, Minnesota 56587',18158,22436);
INSERT INTO "django_geo_db_zipcode" VALUES(25350,56588,-6,'Vining, Minnesota 56588',18159,22437);
INSERT INTO "django_geo_db_zipcode" VALUES(25351,56589,-6,'Waubun, Minnesota 56589',18160,22438);
INSERT INTO "django_geo_db_zipcode" VALUES(25352,56590,-6,'Wendell, Minnesota 56590',18161,22439);
INSERT INTO "django_geo_db_zipcode" VALUES(25353,56591,-6,'White Earth, Minnesota 56591',18162,22370);
INSERT INTO "django_geo_db_zipcode" VALUES(25354,56592,-6,'Winger, Minnesota 56592',18163,22440);
INSERT INTO "django_geo_db_zipcode" VALUES(25355,56593,-6,'Wolf Lake, Minnesota 56593',18164,22441);
INSERT INTO "django_geo_db_zipcode" VALUES(25356,56594,-6,'Wolverton, Minnesota 56594',18165,22442);
INSERT INTO "django_geo_db_zipcode" VALUES(25357,56601,-6,'Bemidji, Minnesota 56601',18166,22443);
INSERT INTO "django_geo_db_zipcode" VALUES(25358,56619,-6,'Bemidji, Minnesota 56619',18166,22444);
INSERT INTO "django_geo_db_zipcode" VALUES(25359,56621,-6,'Bagley, Minnesota 56621',18167,22445);
INSERT INTO "django_geo_db_zipcode" VALUES(25360,56623,-6,'Baudette, Minnesota 56623',18168,22446);
INSERT INTO "django_geo_db_zipcode" VALUES(25361,56626,-6,'Bena, Minnesota 56626',18169,22447);
INSERT INTO "django_geo_db_zipcode" VALUES(25362,56627,-6,'Big Falls, Minnesota 56627',18170,22448);
INSERT INTO "django_geo_db_zipcode" VALUES(25363,56628,-6,'Bigfork, Minnesota 56628',17634,22449);
INSERT INTO "django_geo_db_zipcode" VALUES(25364,56629,-6,'Birchdale, Minnesota 56629',18171,22450);
INSERT INTO "django_geo_db_zipcode" VALUES(25365,56630,-6,'Blackduck, Minnesota 56630',18172,22451);
INSERT INTO "django_geo_db_zipcode" VALUES(25366,56631,-6,'Bowstring, Minnesota 56631',18027,21888);
INSERT INTO "django_geo_db_zipcode" VALUES(25367,56633,-6,'Cass Lake, Minnesota 56633',18173,22452);
INSERT INTO "django_geo_db_zipcode" VALUES(25368,56634,-6,'Clearbrook, Minnesota 56634',18174,22453);
INSERT INTO "django_geo_db_zipcode" VALUES(25369,56636,-6,'Deer River, Minnesota 56636',18175,22454);
INSERT INTO "django_geo_db_zipcode" VALUES(25370,56637,-6,'Talmoon, Minnesota 56637',18176,22455);
INSERT INTO "django_geo_db_zipcode" VALUES(25371,56639,-6,'Effie, Minnesota 56639',18177,22456);
INSERT INTO "django_geo_db_zipcode" VALUES(25372,56641,-6,'Federal Dam, Minnesota 56641',18178,22457);
INSERT INTO "django_geo_db_zipcode" VALUES(25373,56643,-6,'Fleming, Minnesota 56643',18179,22458);
INSERT INTO "django_geo_db_zipcode" VALUES(25374,56644,-6,'Gonvick, Minnesota 56644',18180,22459);
INSERT INTO "django_geo_db_zipcode" VALUES(25375,56646,-6,'Gully, Minnesota 56646',18181,22460);
INSERT INTO "django_geo_db_zipcode" VALUES(25376,56647,-6,'Hines, Minnesota 56647',18182,22461);
INSERT INTO "django_geo_db_zipcode" VALUES(25377,56649,-6,'International Falls, Minnesota 56649',18183,22462);
INSERT INTO "django_geo_db_zipcode" VALUES(25378,56650,-6,'Kelliher, Minnesota 56650',18184,22463);
INSERT INTO "django_geo_db_zipcode" VALUES(25379,56651,-6,'Lengby, Minnesota 56651',18185,22464);
INSERT INTO "django_geo_db_zipcode" VALUES(25380,56652,-6,'Leonard, Minnesota 56652',18186,22465);
INSERT INTO "django_geo_db_zipcode" VALUES(25381,56653,-6,'Littlefork, Minnesota 56653',18187,22466);
INSERT INTO "django_geo_db_zipcode" VALUES(25382,56654,-6,'Loman, Minnesota 56654',18188,22467);
INSERT INTO "django_geo_db_zipcode" VALUES(25383,56655,-6,'Longville, Minnesota 56655',18189,22468);
INSERT INTO "django_geo_db_zipcode" VALUES(25384,56657,-6,'Marcell, Minnesota 56657',18190,22469);
INSERT INTO "django_geo_db_zipcode" VALUES(25385,56658,-6,'Margie, Minnesota 56658',18191,22470);
INSERT INTO "django_geo_db_zipcode" VALUES(25386,56659,-6,'Max, Minnesota 56659',18192,22471);
INSERT INTO "django_geo_db_zipcode" VALUES(25387,56660,-6,'Mizpah, Minnesota 56660',18193,22472);
INSERT INTO "django_geo_db_zipcode" VALUES(25388,56661,-6,'Northome, Minnesota 56661',18194,22473);
INSERT INTO "django_geo_db_zipcode" VALUES(25389,56662,-6,'Outing, Minnesota 56662',18195,22474);
INSERT INTO "django_geo_db_zipcode" VALUES(25390,56663,-6,'Pennington, Minnesota 56663',18196,22475);
INSERT INTO "django_geo_db_zipcode" VALUES(25391,56666,-6,'Ponemah, Minnesota 56666',18197,22476);
INSERT INTO "django_geo_db_zipcode" VALUES(25392,56667,-6,'Puposky, Minnesota 56667',18198,22477);
INSERT INTO "django_geo_db_zipcode" VALUES(25393,56668,-6,'Ranier, Minnesota 56668',18199,22478);
INSERT INTO "django_geo_db_zipcode" VALUES(25394,56669,-6,'Ray, Minnesota 56669',18200,22479);
INSERT INTO "django_geo_db_zipcode" VALUES(25395,56670,-6,'Redby, Minnesota 56670',18201,22480);
INSERT INTO "django_geo_db_zipcode" VALUES(25396,56671,-6,'Redlake, Minnesota 56671',18202,22481);
INSERT INTO "django_geo_db_zipcode" VALUES(25397,56672,-6,'Remer, Minnesota 56672',18203,22482);
INSERT INTO "django_geo_db_zipcode" VALUES(25398,56673,-6,'Roosevelt, Minnesota 56673',18204,22483);
INSERT INTO "django_geo_db_zipcode" VALUES(25399,56676,-6,'Shevlin, Minnesota 56676',18205,22484);
INSERT INTO "django_geo_db_zipcode" VALUES(25400,56678,-6,'Solway, Minnesota 56678',18206,22485);
INSERT INTO "django_geo_db_zipcode" VALUES(25401,56679,-6,'South International Falls, Minnesota 56679',18207,22470);
INSERT INTO "django_geo_db_zipcode" VALUES(25402,56680,-6,'Spring Lake, Minnesota 56680',18208,22486);
INSERT INTO "django_geo_db_zipcode" VALUES(25403,56681,-6,'Squaw Lake, Minnesota 56681',18209,22487);
INSERT INTO "django_geo_db_zipcode" VALUES(25404,56682,-6,'Swift, Minnesota 56682',18210,22488);
INSERT INTO "django_geo_db_zipcode" VALUES(25405,56683,-6,'Tenstrike, Minnesota 56683',18211,22489);
INSERT INTO "django_geo_db_zipcode" VALUES(25406,56684,-6,'Trail, Minnesota 56684',18212,22490);
INSERT INTO "django_geo_db_zipcode" VALUES(25407,56685,-6,'Waskish, Minnesota 56685',18213,22491);
INSERT INTO "django_geo_db_zipcode" VALUES(25408,56686,-6,'Williams, Minnesota 56686',18214,22492);
INSERT INTO "django_geo_db_zipcode" VALUES(25409,56687,-6,'Wilton, Minnesota 56687',18215,22493);
INSERT INTO "django_geo_db_zipcode" VALUES(25410,56688,-6,'Wirt, Minnesota 56688',18216,22494);
INSERT INTO "django_geo_db_zipcode" VALUES(25411,56701,-6,'Thief River Falls, Minnesota 56701',18217,22495);
INSERT INTO "django_geo_db_zipcode" VALUES(25412,56710,-6,'Alvarado, Minnesota 56710',18218,22496);
INSERT INTO "django_geo_db_zipcode" VALUES(25413,56711,-6,'Angle Inlet, Minnesota 56711',18219,22497);
INSERT INTO "django_geo_db_zipcode" VALUES(25414,56712,-6,'Angus, Minnesota 56712',18220,22498);
INSERT INTO "django_geo_db_zipcode" VALUES(25415,56713,-6,'Argyle, Minnesota 56713',18221,22499);
INSERT INTO "django_geo_db_zipcode" VALUES(25416,56714,-6,'Badger, Minnesota 56714',18222,22500);
INSERT INTO "django_geo_db_zipcode" VALUES(25417,56715,-6,'Brooks, Minnesota 56715',18223,22501);
INSERT INTO "django_geo_db_zipcode" VALUES(25418,56716,-6,'Crookston, Minnesota 56716',18224,22502);
INSERT INTO "django_geo_db_zipcode" VALUES(25419,56720,-6,'Donaldson, Minnesota 56720',18225,22503);
INSERT INTO "django_geo_db_zipcode" VALUES(25420,56721,-6,'East Grand Forks, Minnesota 56721',18226,22504);
INSERT INTO "django_geo_db_zipcode" VALUES(25421,56722,-6,'Euclid, Minnesota 56722',18227,22505);
INSERT INTO "django_geo_db_zipcode" VALUES(25422,56723,-6,'Fisher, Minnesota 56723',18228,22506);
INSERT INTO "django_geo_db_zipcode" VALUES(25423,56724,-6,'Gatzke, Minnesota 56724',18229,22507);
INSERT INTO "django_geo_db_zipcode" VALUES(25424,56725,-6,'Goodridge, Minnesota 56725',18230,22508);
INSERT INTO "django_geo_db_zipcode" VALUES(25425,56726,-6,'Greenbush, Minnesota 56726',18231,22509);
INSERT INTO "django_geo_db_zipcode" VALUES(25426,56727,-6,'Grygla, Minnesota 56727',18232,22510);
INSERT INTO "django_geo_db_zipcode" VALUES(25427,56728,-6,'Hallock, Minnesota 56728',18233,22511);
INSERT INTO "django_geo_db_zipcode" VALUES(25428,56729,-6,'Halma, Minnesota 56729',18234,22512);
INSERT INTO "django_geo_db_zipcode" VALUES(25429,56731,-6,'Humboldt, Minnesota 56731',18235,22513);
INSERT INTO "django_geo_db_zipcode" VALUES(25430,56732,-6,'Karlstad, Minnesota 56732',18236,22514);
INSERT INTO "django_geo_db_zipcode" VALUES(25431,56733,-6,'Kennedy, Minnesota 56733',18237,22515);
INSERT INTO "django_geo_db_zipcode" VALUES(25432,56734,-6,'Lake Bronson, Minnesota 56734',18238,22516);
INSERT INTO "django_geo_db_zipcode" VALUES(25433,56735,-6,'Lancaster, Minnesota 56735',18239,22517);
INSERT INTO "django_geo_db_zipcode" VALUES(25434,56736,-6,'Mentor, Minnesota 56736',18240,22518);
INSERT INTO "django_geo_db_zipcode" VALUES(25435,56737,-6,'Middle River, Minnesota 56737',18241,22519);
INSERT INTO "django_geo_db_zipcode" VALUES(25436,56738,-6,'Newfolden, Minnesota 56738',18242,22520);
INSERT INTO "django_geo_db_zipcode" VALUES(25437,56740,-6,'Noyes, Minnesota 56740',18243,22521);
INSERT INTO "django_geo_db_zipcode" VALUES(25438,56741,-6,'Oak Island, Minnesota 56741',18244,22522);
INSERT INTO "django_geo_db_zipcode" VALUES(25439,56742,-6,'Oklee, Minnesota 56742',18245,22523);
INSERT INTO "django_geo_db_zipcode" VALUES(25440,56744,-6,'Oslo, Minnesota 56744',18246,22524);
INSERT INTO "django_geo_db_zipcode" VALUES(25441,56748,-6,'Plummer, Minnesota 56748',18247,22525);
INSERT INTO "django_geo_db_zipcode" VALUES(25442,56750,-6,'Red Lake Falls, Minnesota 56750',18248,22526);
INSERT INTO "django_geo_db_zipcode" VALUES(25443,56751,-6,'Roseau, Minnesota 56751',18249,22527);
INSERT INTO "django_geo_db_zipcode" VALUES(25444,56754,-6,'Saint Hilaire, Minnesota 56754',18250,22528);
INSERT INTO "django_geo_db_zipcode" VALUES(25445,56755,-6,'Saint Vincent, Minnesota 56755',18251,22529);
INSERT INTO "django_geo_db_zipcode" VALUES(25446,56756,-6,'Salol, Minnesota 56756',18252,22530);
INSERT INTO "django_geo_db_zipcode" VALUES(25447,56757,-6,'Stephen, Minnesota 56757',18253,22531);
INSERT INTO "django_geo_db_zipcode" VALUES(25448,56758,-6,'Strandquist, Minnesota 56758',18254,22532);
INSERT INTO "django_geo_db_zipcode" VALUES(25449,56759,-6,'Strathcona, Minnesota 56759',18255,22533);
INSERT INTO "django_geo_db_zipcode" VALUES(25450,56760,-6,'Viking, Minnesota 56760',18256,22534);
INSERT INTO "django_geo_db_zipcode" VALUES(25451,56761,-6,'Wannaska, Minnesota 56761',18257,22535);
INSERT INTO "django_geo_db_zipcode" VALUES(25452,56762,-6,'Warren, Minnesota 56762',18258,22536);
INSERT INTO "django_geo_db_zipcode" VALUES(25453,56763,-6,'Warroad, Minnesota 56763',18259,22537);
INSERT INTO "django_geo_db_zipcode" VALUES(25454,57001,-6,'Alcester, South Dakota 57001',18260,22538);
INSERT INTO "django_geo_db_zipcode" VALUES(25455,57002,-6,'Aurora, South Dakota 57002',18261,22539);
INSERT INTO "django_geo_db_zipcode" VALUES(25456,57003,-6,'Baltic, South Dakota 57003',18262,22540);
INSERT INTO "django_geo_db_zipcode" VALUES(25457,57004,-6,'Beresford, South Dakota 57004',18263,22541);
INSERT INTO "django_geo_db_zipcode" VALUES(25458,57005,-6,'Brandon, South Dakota 57005',18264,22542);
INSERT INTO "django_geo_db_zipcode" VALUES(25459,57006,-6,'Brookings, South Dakota 57006',18265,22543);
INSERT INTO "django_geo_db_zipcode" VALUES(25460,57007,-6,'Brookings, South Dakota 57007',18265,22544);
INSERT INTO "django_geo_db_zipcode" VALUES(25461,57010,-6,'Burbank, South Dakota 57010',18266,22545);
INSERT INTO "django_geo_db_zipcode" VALUES(25462,57012,-6,'Canistota, South Dakota 57012',18267,22546);
INSERT INTO "django_geo_db_zipcode" VALUES(25463,57013,-6,'Canton, South Dakota 57013',18268,22547);
INSERT INTO "django_geo_db_zipcode" VALUES(25464,57014,-6,'Centerville, South Dakota 57014',18269,22548);
INSERT INTO "django_geo_db_zipcode" VALUES(25465,57015,-6,'Chancellor, South Dakota 57015',18270,22549);
INSERT INTO "django_geo_db_zipcode" VALUES(25466,57016,-6,'Chester, South Dakota 57016',18271,22550);
INSERT INTO "django_geo_db_zipcode" VALUES(25467,57017,-6,'Colman, South Dakota 57017',18272,22551);
INSERT INTO "django_geo_db_zipcode" VALUES(25468,57018,-6,'Colton, South Dakota 57018',18273,22552);
INSERT INTO "django_geo_db_zipcode" VALUES(25469,57020,-6,'Crooks, South Dakota 57020',18274,22553);
INSERT INTO "django_geo_db_zipcode" VALUES(25470,57021,-6,'Davis, South Dakota 57021',18275,22554);
INSERT INTO "django_geo_db_zipcode" VALUES(25471,57022,-6,'Dell Rapids, South Dakota 57022',18276,22555);
INSERT INTO "django_geo_db_zipcode" VALUES(25472,57024,-6,'Egan, South Dakota 57024',18277,22556);
INSERT INTO "django_geo_db_zipcode" VALUES(25473,57025,-6,'Elk Point, South Dakota 57025',18278,22557);
INSERT INTO "django_geo_db_zipcode" VALUES(25474,57026,-6,'Elkton, South Dakota 57026',18279,22558);
INSERT INTO "django_geo_db_zipcode" VALUES(25475,57027,-6,'Fairview, South Dakota 57027',18280,22559);
INSERT INTO "django_geo_db_zipcode" VALUES(25476,57028,-6,'Flandreau, South Dakota 57028',18281,22560);
INSERT INTO "django_geo_db_zipcode" VALUES(25477,57029,-6,'Freeman, South Dakota 57029',18282,22561);
INSERT INTO "django_geo_db_zipcode" VALUES(25478,57030,-6,'Garretson, South Dakota 57030',18283,22562);
INSERT INTO "django_geo_db_zipcode" VALUES(25479,57031,-6,'Gayville, South Dakota 57031',18284,22563);
INSERT INTO "django_geo_db_zipcode" VALUES(25480,57032,-6,'Harrisburg, South Dakota 57032',18285,22564);
INSERT INTO "django_geo_db_zipcode" VALUES(25481,57033,-6,'Hartford, South Dakota 57033',18286,22565);
INSERT INTO "django_geo_db_zipcode" VALUES(25482,57034,-6,'Hudson, South Dakota 57034',18287,22566);
INSERT INTO "django_geo_db_zipcode" VALUES(25483,57035,-6,'Humboldt, South Dakota 57035',18288,22567);
INSERT INTO "django_geo_db_zipcode" VALUES(25484,57036,-6,'Hurley, South Dakota 57036',18289,22568);
INSERT INTO "django_geo_db_zipcode" VALUES(25485,57037,-6,'Irene, South Dakota 57037',18290,22569);
INSERT INTO "django_geo_db_zipcode" VALUES(25486,57038,-6,'Jefferson, South Dakota 57038',18291,22570);
INSERT INTO "django_geo_db_zipcode" VALUES(25487,57039,-6,'Lennox, South Dakota 57039',18292,22571);
INSERT INTO "django_geo_db_zipcode" VALUES(25488,57040,-6,'Lesterville, South Dakota 57040',18293,22572);
INSERT INTO "django_geo_db_zipcode" VALUES(25489,57041,-6,'Lyons, South Dakota 57041',18294,22573);
INSERT INTO "django_geo_db_zipcode" VALUES(25490,57042,-6,'Madison, South Dakota 57042',18295,22574);
INSERT INTO "django_geo_db_zipcode" VALUES(25491,57043,-6,'Marion, South Dakota 57043',18296,22575);
INSERT INTO "django_geo_db_zipcode" VALUES(25492,57044,-6,'Meckling, South Dakota 57044',18297,22576);
INSERT INTO "django_geo_db_zipcode" VALUES(25493,57045,-6,'Menno, South Dakota 57045',18298,22577);
INSERT INTO "django_geo_db_zipcode" VALUES(25494,57046,-6,'Mission Hill, South Dakota 57046',18299,22578);
INSERT INTO "django_geo_db_zipcode" VALUES(25495,57047,-6,'Monroe, South Dakota 57047',18300,22579);
INSERT INTO "django_geo_db_zipcode" VALUES(25496,57048,-6,'Montrose, South Dakota 57048',18301,22580);
INSERT INTO "django_geo_db_zipcode" VALUES(25497,57049,-6,'North Sioux City, South Dakota 57049',18302,22581);
INSERT INTO "django_geo_db_zipcode" VALUES(25498,57050,-6,'Nunda, South Dakota 57050',18303,22582);
INSERT INTO "django_geo_db_zipcode" VALUES(25499,57051,-6,'Oldham, South Dakota 57051',18304,22583);
INSERT INTO "django_geo_db_zipcode" VALUES(25500,57052,-6,'Olivet, South Dakota 57052',18305,22584);
INSERT INTO "django_geo_db_zipcode" VALUES(25501,57053,-6,'Parker, South Dakota 57053',18306,22585);
INSERT INTO "django_geo_db_zipcode" VALUES(25502,57054,-6,'Ramona, South Dakota 57054',18307,22586);
INSERT INTO "django_geo_db_zipcode" VALUES(25503,57055,-6,'Renner, South Dakota 57055',18308,22587);
INSERT INTO "django_geo_db_zipcode" VALUES(25504,57056,-6,'Rowena, South Dakota 57056',18309,22588);
INSERT INTO "django_geo_db_zipcode" VALUES(25505,57057,-6,'Rutland, South Dakota 57057',18310,22589);
INSERT INTO "django_geo_db_zipcode" VALUES(25506,57058,-6,'Salem, South Dakota 57058',18311,22590);
INSERT INTO "django_geo_db_zipcode" VALUES(25507,57059,-6,'Scotland, South Dakota 57059',18312,22591);
INSERT INTO "django_geo_db_zipcode" VALUES(25508,57061,-6,'Sinai, South Dakota 57061',18313,22592);
INSERT INTO "django_geo_db_zipcode" VALUES(25509,57062,-6,'Springfield, South Dakota 57062',18314,22593);
INSERT INTO "django_geo_db_zipcode" VALUES(25510,57063,-6,'Tabor, South Dakota 57063',18315,22594);
INSERT INTO "django_geo_db_zipcode" VALUES(25511,57064,-6,'Tea, South Dakota 57064',18316,22595);
INSERT INTO "django_geo_db_zipcode" VALUES(25512,57065,-6,'Trent, South Dakota 57065',18317,22596);
INSERT INTO "django_geo_db_zipcode" VALUES(25513,57066,-6,'Tyndall, South Dakota 57066',18318,22597);
INSERT INTO "django_geo_db_zipcode" VALUES(25514,57067,-6,'Utica, South Dakota 57067',18319,22598);
INSERT INTO "django_geo_db_zipcode" VALUES(25515,57068,-6,'Valley Springs, South Dakota 57068',18320,22599);
INSERT INTO "django_geo_db_zipcode" VALUES(25516,57069,-6,'Vermillion, South Dakota 57069',18321,22600);
INSERT INTO "django_geo_db_zipcode" VALUES(25517,57070,-6,'Viborg, South Dakota 57070',18322,22601);
INSERT INTO "django_geo_db_zipcode" VALUES(25518,57071,-6,'Volga, South Dakota 57071',18323,22602);
INSERT INTO "django_geo_db_zipcode" VALUES(25519,57072,-6,'Volin, South Dakota 57072',18324,22603);
INSERT INTO "django_geo_db_zipcode" VALUES(25520,57073,-6,'Wakonda, South Dakota 57073',18325,22604);
INSERT INTO "django_geo_db_zipcode" VALUES(25521,57074,-6,'Ward, South Dakota 57074',18326,22605);
INSERT INTO "django_geo_db_zipcode" VALUES(25522,57075,-6,'Wentworth, South Dakota 57075',18327,22606);
INSERT INTO "django_geo_db_zipcode" VALUES(25523,57076,-6,'Winfred, South Dakota 57076',18328,22607);
INSERT INTO "django_geo_db_zipcode" VALUES(25524,57077,-6,'Worthing, South Dakota 57077',18329,22608);
INSERT INTO "django_geo_db_zipcode" VALUES(25525,57078,-6,'Yankton, South Dakota 57078',18330,22609);
INSERT INTO "django_geo_db_zipcode" VALUES(25526,57079,-6,'Yankton, South Dakota 57079',18330,22610);
INSERT INTO "django_geo_db_zipcode" VALUES(25527,57101,-6,'Sioux Falls, South Dakota 57101',18331,22611);
INSERT INTO "django_geo_db_zipcode" VALUES(25528,57103,-6,'Sioux Falls, South Dakota 57103',18331,22612);
INSERT INTO "django_geo_db_zipcode" VALUES(25529,57104,-6,'Sioux Falls, South Dakota 57104',18331,22613);
INSERT INTO "django_geo_db_zipcode" VALUES(25530,57105,-6,'Sioux Falls, South Dakota 57105',18331,22614);
INSERT INTO "django_geo_db_zipcode" VALUES(25531,57106,-6,'Sioux Falls, South Dakota 57106',18331,22615);
INSERT INTO "django_geo_db_zipcode" VALUES(25532,57107,-6,'Sioux Falls, South Dakota 57107',18331,22616);
INSERT INTO "django_geo_db_zipcode" VALUES(25533,57108,-6,'Sioux Falls, South Dakota 57108',18331,22617);
INSERT INTO "django_geo_db_zipcode" VALUES(25534,57109,-6,'Sioux Falls, South Dakota 57109',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25535,57110,-6,'Sioux Falls, South Dakota 57110',18331,22619);
INSERT INTO "django_geo_db_zipcode" VALUES(25536,57115,-6,'Buffalo Ridge, South Dakota 57115',18332,22620);
INSERT INTO "django_geo_db_zipcode" VALUES(25537,57117,-6,'Sioux Falls, South Dakota 57117',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25538,57118,-6,'Sioux Falls, South Dakota 57118',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25539,57188,-6,'Sioux Falls, South Dakota 57188',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25540,57189,-6,'Sioux Falls, South Dakota 57189',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25541,57192,-6,'Sioux Falls, South Dakota 57192',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25542,57193,-6,'Sioux Falls, South Dakota 57193',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25543,57194,-6,'Sioux Falls, South Dakota 57194',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25544,57195,-6,'Sioux Falls, South Dakota 57195',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25545,57196,-6,'Sioux Falls, South Dakota 57196',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25546,57197,-6,'Sioux Falls, South Dakota 57197',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25547,57198,-6,'Sioux Falls, South Dakota 57198',18331,22618);
INSERT INTO "django_geo_db_zipcode" VALUES(25548,57201,-6,'Watertown, South Dakota 57201',18333,22621);
INSERT INTO "django_geo_db_zipcode" VALUES(25549,57202,-6,'Waverly, South Dakota 57202',18334,22622);
INSERT INTO "django_geo_db_zipcode" VALUES(25550,57211,-6,'Cleveland, South Dakota 57211',18335,22623);
INSERT INTO "django_geo_db_zipcode" VALUES(25551,57212,-6,'Arlington, South Dakota 57212',18336,22624);
INSERT INTO "django_geo_db_zipcode" VALUES(25552,57213,-6,'Astoria, South Dakota 57213',18337,22625);
INSERT INTO "django_geo_db_zipcode" VALUES(25553,57214,-6,'Badger, South Dakota 57214',18338,22626);
INSERT INTO "django_geo_db_zipcode" VALUES(25554,57216,-6,'Big Stone City, South Dakota 57216',18339,22627);
INSERT INTO "django_geo_db_zipcode" VALUES(25555,57217,-6,'Bradley, South Dakota 57217',18340,22628);
INSERT INTO "django_geo_db_zipcode" VALUES(25556,57218,-6,'Brandt, South Dakota 57218',18341,22629);
INSERT INTO "django_geo_db_zipcode" VALUES(25557,57219,-6,'Bristol, South Dakota 57219',18342,22630);
INSERT INTO "django_geo_db_zipcode" VALUES(25558,57220,-6,'Bruce, South Dakota 57220',18343,22631);
INSERT INTO "django_geo_db_zipcode" VALUES(25559,57221,-6,'Bryant, South Dakota 57221',18344,22632);
INSERT INTO "django_geo_db_zipcode" VALUES(25560,57223,-6,'Castlewood, South Dakota 57223',18345,22633);
INSERT INTO "django_geo_db_zipcode" VALUES(25561,57224,-6,'Claire City, South Dakota 57224',18346,22634);
INSERT INTO "django_geo_db_zipcode" VALUES(25562,57225,-6,'Clark, South Dakota 57225',18347,22635);
INSERT INTO "django_geo_db_zipcode" VALUES(25563,57226,-6,'Clear Lake, South Dakota 57226',18348,22636);
INSERT INTO "django_geo_db_zipcode" VALUES(25564,57227,-6,'Corona, South Dakota 57227',18349,22637);
INSERT INTO "django_geo_db_zipcode" VALUES(25565,57230,-6,'De Smet, South Dakota 57230',18350,22638);
INSERT INTO "django_geo_db_zipcode" VALUES(25566,57231,-6,'De Smet, South Dakota 57231',18350,22639);
INSERT INTO "django_geo_db_zipcode" VALUES(25567,57232,-6,'Eden, South Dakota 57232',18351,22640);
INSERT INTO "django_geo_db_zipcode" VALUES(25568,57233,-6,'Erwin, South Dakota 57233',18352,22641);
INSERT INTO "django_geo_db_zipcode" VALUES(25569,57234,-6,'Estelline, South Dakota 57234',18353,22642);
INSERT INTO "django_geo_db_zipcode" VALUES(25570,57235,-6,'Florence, South Dakota 57235',18354,22643);
INSERT INTO "django_geo_db_zipcode" VALUES(25571,57236,-6,'Garden City, South Dakota 57236',18355,22644);
INSERT INTO "django_geo_db_zipcode" VALUES(25572,57237,-6,'Gary, South Dakota 57237',18356,22645);
INSERT INTO "django_geo_db_zipcode" VALUES(25573,57238,-6,'Goodwin, South Dakota 57238',18357,22646);
INSERT INTO "django_geo_db_zipcode" VALUES(25574,57239,-6,'Grenville, South Dakota 57239',18358,22647);
INSERT INTO "django_geo_db_zipcode" VALUES(25575,57241,-6,'Hayti, South Dakota 57241',18359,22648);
INSERT INTO "django_geo_db_zipcode" VALUES(25576,57242,-6,'Hazel, South Dakota 57242',18360,22649);
INSERT INTO "django_geo_db_zipcode" VALUES(25577,57243,-6,'Henry, South Dakota 57243',18361,22650);
INSERT INTO "django_geo_db_zipcode" VALUES(25578,57244,-6,'Hetland, South Dakota 57244',18362,22651);
INSERT INTO "django_geo_db_zipcode" VALUES(25579,57245,-6,'Kranzburg, South Dakota 57245',18363,22652);
INSERT INTO "django_geo_db_zipcode" VALUES(25580,57246,-6,'Labolt, South Dakota 57246',18364,22653);
INSERT INTO "django_geo_db_zipcode" VALUES(25581,57247,-6,'Lake City, South Dakota 57247',18365,22654);
INSERT INTO "django_geo_db_zipcode" VALUES(25582,57248,-6,'Lake Norden, South Dakota 57248',18366,22655);
INSERT INTO "django_geo_db_zipcode" VALUES(25583,57249,-6,'Lake Preston, South Dakota 57249',18367,22656);
INSERT INTO "django_geo_db_zipcode" VALUES(25584,57251,-6,'Marvin, South Dakota 57251',18368,22657);
INSERT INTO "django_geo_db_zipcode" VALUES(25585,57252,-6,'Milbank, South Dakota 57252',18369,22658);
INSERT INTO "django_geo_db_zipcode" VALUES(25586,57253,-6,'Milbank, South Dakota 57253',18369,22659);
INSERT INTO "django_geo_db_zipcode" VALUES(25587,57255,-6,'New Effington, South Dakota 57255',18370,22660);
INSERT INTO "django_geo_db_zipcode" VALUES(25588,57256,-6,'Ortley, South Dakota 57256',18371,22661);
INSERT INTO "django_geo_db_zipcode" VALUES(25589,57257,-6,'Peever, South Dakota 57257',18372,22662);
INSERT INTO "django_geo_db_zipcode" VALUES(25590,57258,-6,'Raymond, South Dakota 57258',18373,22663);
INSERT INTO "django_geo_db_zipcode" VALUES(25591,57259,-6,'Revillo, South Dakota 57259',18374,22664);
INSERT INTO "django_geo_db_zipcode" VALUES(25592,57260,-6,'Rosholt, South Dakota 57260',18375,22665);
INSERT INTO "django_geo_db_zipcode" VALUES(25593,57261,-6,'Roslyn, South Dakota 57261',18376,22666);
INSERT INTO "django_geo_db_zipcode" VALUES(25594,57262,-6,'Sisseton, South Dakota 57262',18377,22667);
INSERT INTO "django_geo_db_zipcode" VALUES(25595,57263,-6,'South Shore, South Dakota 57263',18378,22668);
INSERT INTO "django_geo_db_zipcode" VALUES(25596,57264,-6,'Stockholm, South Dakota 57264',18379,22669);
INSERT INTO "django_geo_db_zipcode" VALUES(25597,57265,-6,'Strandburg, South Dakota 57265',18380,22670);
INSERT INTO "django_geo_db_zipcode" VALUES(25598,57266,-6,'Summit, South Dakota 57266',18381,22671);
INSERT INTO "django_geo_db_zipcode" VALUES(25599,57268,-6,'Toronto, South Dakota 57268',18382,22672);
INSERT INTO "django_geo_db_zipcode" VALUES(25600,57269,-6,'Twin Brooks, South Dakota 57269',18383,22673);
INSERT INTO "django_geo_db_zipcode" VALUES(25601,57270,-6,'Veblen, South Dakota 57270',18384,22674);
INSERT INTO "django_geo_db_zipcode" VALUES(25602,57271,-6,'Vienna, South Dakota 57271',18385,22675);
INSERT INTO "django_geo_db_zipcode" VALUES(25603,57272,-6,'Wallace, South Dakota 57272',18386,22676);
INSERT INTO "django_geo_db_zipcode" VALUES(25604,57273,-6,'Waubay, South Dakota 57273',18387,22677);
INSERT INTO "django_geo_db_zipcode" VALUES(25605,57274,-6,'Webster, South Dakota 57274',18388,22678);
INSERT INTO "django_geo_db_zipcode" VALUES(25606,57276,-6,'White, South Dakota 57276',18389,22679);
INSERT INTO "django_geo_db_zipcode" VALUES(25607,57278,-6,'Willow Lake, South Dakota 57278',18390,22680);
INSERT INTO "django_geo_db_zipcode" VALUES(25608,57279,-6,'Wilmot, South Dakota 57279',18391,22681);
INSERT INTO "django_geo_db_zipcode" VALUES(25609,57301,-6,'Mitchell, South Dakota 57301',18392,22682);
INSERT INTO "django_geo_db_zipcode" VALUES(25610,57309,-6,'Perry, South Dakota 57309',18393,22683);
INSERT INTO "django_geo_db_zipcode" VALUES(25611,57311,-6,'Alexandria, South Dakota 57311',18394,22684);
INSERT INTO "django_geo_db_zipcode" VALUES(25612,57312,-6,'Alpena, South Dakota 57312',18395,22685);
INSERT INTO "django_geo_db_zipcode" VALUES(25613,57313,-6,'Armour, South Dakota 57313',18396,22686);
INSERT INTO "django_geo_db_zipcode" VALUES(25614,57314,-6,'Artesian, South Dakota 57314',18397,22687);
INSERT INTO "django_geo_db_zipcode" VALUES(25615,57315,-6,'Avon, South Dakota 57315',18398,22688);
INSERT INTO "django_geo_db_zipcode" VALUES(25616,57317,-6,'Bonesteel, South Dakota 57317',18399,22689);
INSERT INTO "django_geo_db_zipcode" VALUES(25617,57319,-6,'Bridgewater, South Dakota 57319',18400,22690);
INSERT INTO "django_geo_db_zipcode" VALUES(25618,57321,-6,'Canova, South Dakota 57321',18401,22691);
INSERT INTO "django_geo_db_zipcode" VALUES(25619,57322,-6,'Carpenter, South Dakota 57322',18402,22692);
INSERT INTO "django_geo_db_zipcode" VALUES(25620,57323,-6,'Carthage, South Dakota 57323',18403,22693);
INSERT INTO "django_geo_db_zipcode" VALUES(25621,57324,-6,'Cavour, South Dakota 57324',18404,22694);
INSERT INTO "django_geo_db_zipcode" VALUES(25622,57325,-6,'Chamberlain, South Dakota 57325',18405,22695);
INSERT INTO "django_geo_db_zipcode" VALUES(25623,57326,-6,'Chamberlain, South Dakota 57326',18405,22696);
INSERT INTO "django_geo_db_zipcode" VALUES(25624,57328,-6,'Corsica, South Dakota 57328',18406,22697);
INSERT INTO "django_geo_db_zipcode" VALUES(25625,57329,-6,'Dante, South Dakota 57329',18407,22698);
INSERT INTO "django_geo_db_zipcode" VALUES(25626,57330,-6,'Delmont, South Dakota 57330',18408,22699);
INSERT INTO "django_geo_db_zipcode" VALUES(25627,57331,-6,'Dimock, South Dakota 57331',18409,22700);
INSERT INTO "django_geo_db_zipcode" VALUES(25628,57332,-6,'Emery, South Dakota 57332',18410,22701);
INSERT INTO "django_geo_db_zipcode" VALUES(25629,57334,-6,'Ethan, South Dakota 57334',18411,22702);
INSERT INTO "django_geo_db_zipcode" VALUES(25630,57335,-6,'Fairfax, South Dakota 57335',18412,22703);
INSERT INTO "django_geo_db_zipcode" VALUES(25631,57337,-6,'Fedora, South Dakota 57337',18413,22704);
INSERT INTO "django_geo_db_zipcode" VALUES(25632,57339,-6,'Fort Thompson, South Dakota 57339',18414,22705);
INSERT INTO "django_geo_db_zipcode" VALUES(25633,57340,-6,'Fulton, South Dakota 57340',18415,22706);
INSERT INTO "django_geo_db_zipcode" VALUES(25634,57341,-6,'Gann Valley, South Dakota 57341',18416,22707);
INSERT INTO "django_geo_db_zipcode" VALUES(25635,57342,-6,'Geddes, South Dakota 57342',18417,22708);
INSERT INTO "django_geo_db_zipcode" VALUES(25636,57344,-6,'Harrison, South Dakota 57344',18418,22709);
INSERT INTO "django_geo_db_zipcode" VALUES(25637,57345,-6,'Highmore, South Dakota 57345',18419,22710);
INSERT INTO "django_geo_db_zipcode" VALUES(25638,57346,-6,'Stephan, South Dakota 57346',18420,22711);
INSERT INTO "django_geo_db_zipcode" VALUES(25639,57347,-6,'Benton, South Dakota 57347',18421,22712);
INSERT INTO "django_geo_db_zipcode" VALUES(25640,57348,-6,'Hitchcock, South Dakota 57348',18422,22713);
INSERT INTO "django_geo_db_zipcode" VALUES(25641,57349,-6,'Howard, South Dakota 57349',18423,22714);
INSERT INTO "django_geo_db_zipcode" VALUES(25642,57350,-6,'Huron, South Dakota 57350',18424,22715);
INSERT INTO "django_geo_db_zipcode" VALUES(25643,57353,-6,'Iroquois, South Dakota 57353',18425,22716);
INSERT INTO "django_geo_db_zipcode" VALUES(25644,57354,-6,'Kaylor, South Dakota 57354',18426,22717);
INSERT INTO "django_geo_db_zipcode" VALUES(25645,57355,-6,'Kimball, South Dakota 57355',18427,22718);
INSERT INTO "django_geo_db_zipcode" VALUES(25646,57356,-6,'Lake Andes, South Dakota 57356',18428,22719);
INSERT INTO "django_geo_db_zipcode" VALUES(25647,57357,-6,'Ravinia, South Dakota 57357',18429,22720);
INSERT INTO "django_geo_db_zipcode" VALUES(25648,57358,-6,'Lane, South Dakota 57358',18430,22721);
INSERT INTO "django_geo_db_zipcode" VALUES(25649,57359,-6,'Letcher, South Dakota 57359',18431,22722);
INSERT INTO "django_geo_db_zipcode" VALUES(25650,57361,-6,'Marty, South Dakota 57361',18432,22723);
INSERT INTO "django_geo_db_zipcode" VALUES(25651,57362,-6,'Miller, South Dakota 57362',18433,22724);
INSERT INTO "django_geo_db_zipcode" VALUES(25652,57363,-6,'Mount Vernon, South Dakota 57363',18434,22725);
INSERT INTO "django_geo_db_zipcode" VALUES(25653,57364,-6,'New Holland, South Dakota 57364',18435,22726);
INSERT INTO "django_geo_db_zipcode" VALUES(25654,57365,-6,'Oacoma, South Dakota 57365',18436,22727);
INSERT INTO "django_geo_db_zipcode" VALUES(25655,57366,-6,'Parkston, South Dakota 57366',18437,22728);
INSERT INTO "django_geo_db_zipcode" VALUES(25656,57367,-6,'Pickstown, South Dakota 57367',18438,22729);
INSERT INTO "django_geo_db_zipcode" VALUES(25657,57368,-6,'Plankinton, South Dakota 57368',18439,22730);
INSERT INTO "django_geo_db_zipcode" VALUES(25658,57369,-6,'Platte, South Dakota 57369',18440,22731);
INSERT INTO "django_geo_db_zipcode" VALUES(25659,57370,-6,'Pukwana, South Dakota 57370',18441,22732);
INSERT INTO "django_geo_db_zipcode" VALUES(25660,57371,-6,'Ree Heights, South Dakota 57371',18442,22733);
INSERT INTO "django_geo_db_zipcode" VALUES(25661,57373,-6,'Saint Lawrence, South Dakota 57373',18443,22734);
INSERT INTO "django_geo_db_zipcode" VALUES(25662,57374,-6,'Spencer, South Dakota 57374',18444,22735);
INSERT INTO "django_geo_db_zipcode" VALUES(25663,57375,-6,'Stickney, South Dakota 57375',18445,22736);
INSERT INTO "django_geo_db_zipcode" VALUES(25664,57376,-6,'Tripp, South Dakota 57376',18446,22737);
INSERT INTO "django_geo_db_zipcode" VALUES(25665,57379,-6,'Virgil, South Dakota 57379',18447,22738);
INSERT INTO "django_geo_db_zipcode" VALUES(25666,57380,-6,'Wagner, South Dakota 57380',18448,22739);
INSERT INTO "django_geo_db_zipcode" VALUES(25667,57381,-6,'Wessington, South Dakota 57381',18449,22740);
INSERT INTO "django_geo_db_zipcode" VALUES(25668,57382,-6,'Wessington Springs, South Dakota 57382',18450,22741);
INSERT INTO "django_geo_db_zipcode" VALUES(25669,57383,-6,'White Lake, South Dakota 57383',18451,22742);
INSERT INTO "django_geo_db_zipcode" VALUES(25670,57384,-6,'Wolsey, South Dakota 57384',18452,22743);
INSERT INTO "django_geo_db_zipcode" VALUES(25671,57385,-6,'Woonsocket, South Dakota 57385',18453,22744);
INSERT INTO "django_geo_db_zipcode" VALUES(25672,57386,-6,'Yale, South Dakota 57386',18454,22745);
INSERT INTO "django_geo_db_zipcode" VALUES(25673,57399,-6,'Huron, South Dakota 57399',18424,22746);
INSERT INTO "django_geo_db_zipcode" VALUES(25674,57401,-6,'Aberdeen, South Dakota 57401',18455,22747);
INSERT INTO "django_geo_db_zipcode" VALUES(25675,57402,-6,'Aberdeen, South Dakota 57402',18455,22748);
INSERT INTO "django_geo_db_zipcode" VALUES(25676,57411,-6,'Bryant, South Dakota 57411',18344,22749);
INSERT INTO "django_geo_db_zipcode" VALUES(25677,57420,-6,'Akaska, South Dakota 57420',18456,22750);
INSERT INTO "django_geo_db_zipcode" VALUES(25678,57421,-6,'Amherst, South Dakota 57421',18457,22751);
INSERT INTO "django_geo_db_zipcode" VALUES(25679,57422,-6,'Andover, South Dakota 57422',18458,22752);
INSERT INTO "django_geo_db_zipcode" VALUES(25680,57424,-6,'Ashton, South Dakota 57424',18459,22753);
INSERT INTO "django_geo_db_zipcode" VALUES(25681,57426,-6,'Barnard, South Dakota 57426',18460,22754);
INSERT INTO "django_geo_db_zipcode" VALUES(25682,57427,-6,'Bath, South Dakota 57427',18461,22755);
INSERT INTO "django_geo_db_zipcode" VALUES(25683,57428,-6,'Bowdle, South Dakota 57428',18462,22756);
INSERT INTO "django_geo_db_zipcode" VALUES(25684,57429,-6,'Brentford, South Dakota 57429',18463,22757);
INSERT INTO "django_geo_db_zipcode" VALUES(25685,57430,-6,'Britton, South Dakota 57430',18464,22758);
INSERT INTO "django_geo_db_zipcode" VALUES(25686,57432,-6,'Claremont, South Dakota 57432',18465,22759);
INSERT INTO "django_geo_db_zipcode" VALUES(25687,57433,-6,'Columbia, South Dakota 57433',18466,22760);
INSERT INTO "django_geo_db_zipcode" VALUES(25688,57434,-6,'Conde, South Dakota 57434',18467,22761);
INSERT INTO "django_geo_db_zipcode" VALUES(25689,57435,-6,'Cresbard, South Dakota 57435',18468,22762);
INSERT INTO "django_geo_db_zipcode" VALUES(25690,57436,-6,'Doland, South Dakota 57436',18469,22763);
INSERT INTO "django_geo_db_zipcode" VALUES(25691,57437,-6,'Eureka, South Dakota 57437',18470,22764);
INSERT INTO "django_geo_db_zipcode" VALUES(25692,57438,-6,'Faulkton, South Dakota 57438',18471,22765);
INSERT INTO "django_geo_db_zipcode" VALUES(25693,57439,-6,'Ferney, South Dakota 57439',18472,22766);
INSERT INTO "django_geo_db_zipcode" VALUES(25694,57440,-6,'Frankfort, South Dakota 57440',18473,22767);
INSERT INTO "django_geo_db_zipcode" VALUES(25695,57441,-6,'Frederick, South Dakota 57441',18474,22768);
INSERT INTO "django_geo_db_zipcode" VALUES(25696,57442,-6,'Gettysburg, South Dakota 57442',18475,22769);
INSERT INTO "django_geo_db_zipcode" VALUES(25697,57443,-6,'Cambria, South Dakota 57443',18476,22770);
INSERT INTO "django_geo_db_zipcode" VALUES(25698,57445,-6,'Groton, South Dakota 57445',18477,22771);
INSERT INTO "django_geo_db_zipcode" VALUES(25699,57446,-6,'Hecla, South Dakota 57446',18478,22772);
INSERT INTO "django_geo_db_zipcode" VALUES(25700,57448,-6,'Hosmer, South Dakota 57448',18479,22773);
INSERT INTO "django_geo_db_zipcode" VALUES(25701,57449,-6,'Houghton, South Dakota 57449',18480,22774);
INSERT INTO "django_geo_db_zipcode" VALUES(25702,57450,-6,'Hoven, South Dakota 57450',18481,22775);
INSERT INTO "django_geo_db_zipcode" VALUES(25703,57451,-6,'Ipswich, South Dakota 57451',18482,22776);
INSERT INTO "django_geo_db_zipcode" VALUES(25704,57452,-6,'Java, South Dakota 57452',18483,22777);
INSERT INTO "django_geo_db_zipcode" VALUES(25705,57454,-6,'Langford, South Dakota 57454',18484,22778);
INSERT INTO "django_geo_db_zipcode" VALUES(25706,57455,-6,'Lebanon, South Dakota 57455',18485,22779);
INSERT INTO "django_geo_db_zipcode" VALUES(25707,57456,-6,'Leola, South Dakota 57456',18486,22780);
INSERT INTO "django_geo_db_zipcode" VALUES(25708,57457,-6,'Longlake, South Dakota 57457',18487,22781);
INSERT INTO "django_geo_db_zipcode" VALUES(25709,57460,-6,'Mansfield, South Dakota 57460',18488,22782);
INSERT INTO "django_geo_db_zipcode" VALUES(25710,57461,-6,'Mellette, South Dakota 57461',18489,22783);
INSERT INTO "django_geo_db_zipcode" VALUES(25711,57462,-6,'Mina, South Dakota 57462',18490,22784);
INSERT INTO "django_geo_db_zipcode" VALUES(25712,57465,-6,'Northville, South Dakota 57465',18491,22785);
INSERT INTO "django_geo_db_zipcode" VALUES(25713,57466,-6,'Onaka, South Dakota 57466',18492,22786);
INSERT INTO "django_geo_db_zipcode" VALUES(25714,57467,-6,'Orient, South Dakota 57467',18493,22787);
INSERT INTO "django_geo_db_zipcode" VALUES(25715,57468,-6,'Pierpont, South Dakota 57468',18494,22788);
INSERT INTO "django_geo_db_zipcode" VALUES(25716,57469,-6,'Redfield, South Dakota 57469',18495,22789);
INSERT INTO "django_geo_db_zipcode" VALUES(25717,57470,-6,'Rockham, South Dakota 57470',18496,22790);
INSERT INTO "django_geo_db_zipcode" VALUES(25718,57471,-6,'Roscoe, South Dakota 57471',18497,22791);
INSERT INTO "django_geo_db_zipcode" VALUES(25719,57472,-6,'Selby, South Dakota 57472',18498,22792);
INSERT INTO "django_geo_db_zipcode" VALUES(25720,57473,-6,'Seneca, South Dakota 57473',18499,22793);
INSERT INTO "django_geo_db_zipcode" VALUES(25721,57474,-6,'Stratford, South Dakota 57474',18500,22794);
INSERT INTO "django_geo_db_zipcode" VALUES(25722,57475,-6,'Tolstoy, South Dakota 57475',18501,22795);
INSERT INTO "django_geo_db_zipcode" VALUES(25723,57476,-6,'Tulare, South Dakota 57476',18502,22796);
INSERT INTO "django_geo_db_zipcode" VALUES(25724,57477,-6,'Turton, South Dakota 57477',18503,22797);
INSERT INTO "django_geo_db_zipcode" VALUES(25725,57479,-6,'Warner, South Dakota 57479',18504,22798);
INSERT INTO "django_geo_db_zipcode" VALUES(25726,57481,-6,'Westport, South Dakota 57481',18505,22799);
INSERT INTO "django_geo_db_zipcode" VALUES(25727,57501,-6,'Pierre, South Dakota 57501',18506,22800);
INSERT INTO "django_geo_db_zipcode" VALUES(25728,57520,-6,'Agar, South Dakota 57520',18507,22801);
INSERT INTO "django_geo_db_zipcode" VALUES(25729,57521,-7,'Belvidere, South Dakota 57521',18508,22802);
INSERT INTO "django_geo_db_zipcode" VALUES(25730,57522,-6,'Blunt, South Dakota 57522',18509,22803);
INSERT INTO "django_geo_db_zipcode" VALUES(25731,57523,-6,'Burke, South Dakota 57523',18510,22804);
INSERT INTO "django_geo_db_zipcode" VALUES(25732,57526,-6,'Carter, South Dakota 57526',18511,22805);
INSERT INTO "django_geo_db_zipcode" VALUES(25733,57528,-6,'Colome, South Dakota 57528',18512,22806);
INSERT INTO "django_geo_db_zipcode" VALUES(25734,57529,-6,'Dallas, South Dakota 57529',18513,22807);
INSERT INTO "django_geo_db_zipcode" VALUES(25735,57531,-6,'Draper, South Dakota 57531',18514,22808);
INSERT INTO "django_geo_db_zipcode" VALUES(25736,57532,-7,'Fort Pierre, South Dakota 57532',18515,22809);
INSERT INTO "django_geo_db_zipcode" VALUES(25737,57533,-6,'Gregory, South Dakota 57533',18516,22810);
INSERT INTO "django_geo_db_zipcode" VALUES(25738,57534,-6,'Hamill, South Dakota 57534',18517,22811);
INSERT INTO "django_geo_db_zipcode" VALUES(25739,57536,-6,'Harrold, South Dakota 57536',18518,22812);
INSERT INTO "django_geo_db_zipcode" VALUES(25740,57537,-7,'Hayes, South Dakota 57537',18519,22813);
INSERT INTO "django_geo_db_zipcode" VALUES(25741,57538,-6,'Herrick, South Dakota 57538',18520,22814);
INSERT INTO "django_geo_db_zipcode" VALUES(25742,57540,-6,'Holabird, South Dakota 57540',18521,22815);
INSERT INTO "django_geo_db_zipcode" VALUES(25743,57541,-6,'Ideal, South Dakota 57541',18522,22816);
INSERT INTO "django_geo_db_zipcode" VALUES(25744,57542,-6,'Iona, South Dakota 57542',18523,22817);
INSERT INTO "django_geo_db_zipcode" VALUES(25745,57543,-7,'Kadoka, South Dakota 57543',18524,22818);
INSERT INTO "django_geo_db_zipcode" VALUES(25746,57544,-6,'Kennebec, South Dakota 57544',18525,22819);
INSERT INTO "django_geo_db_zipcode" VALUES(25747,57547,-7,'Long Valley, South Dakota 57547',18526,22820);
INSERT INTO "django_geo_db_zipcode" VALUES(25748,57548,-6,'Lower Brule, South Dakota 57548',18527,22821);
INSERT INTO "django_geo_db_zipcode" VALUES(25749,57551,-7,'Martin, South Dakota 57551',18528,22822);
INSERT INTO "django_geo_db_zipcode" VALUES(25750,57552,-7,'Midland, South Dakota 57552',18529,22823);
INSERT INTO "django_geo_db_zipcode" VALUES(25751,57553,-7,'Milesville, South Dakota 57553',18530,22824);
INSERT INTO "django_geo_db_zipcode" VALUES(25752,57555,-6,'Mission, South Dakota 57555',18531,22825);
INSERT INTO "django_geo_db_zipcode" VALUES(25753,57557,-6,'Mission Ridge, South Dakota 57557',18532,22826);
INSERT INTO "django_geo_db_zipcode" VALUES(25754,57559,-6,'Murdo, South Dakota 57559',18533,22827);
INSERT INTO "django_geo_db_zipcode" VALUES(25755,57560,-6,'Norris, South Dakota 57560',18534,22828);
INSERT INTO "django_geo_db_zipcode" VALUES(25756,57562,-6,'Okaton, South Dakota 57562',18535,22829);
INSERT INTO "django_geo_db_zipcode" VALUES(25757,57563,-6,'Okreek, South Dakota 57563',18536,22830);
INSERT INTO "django_geo_db_zipcode" VALUES(25758,57564,-6,'Onida, South Dakota 57564',18537,22831);
INSERT INTO "django_geo_db_zipcode" VALUES(25759,57565,-7,'Timber Lake, South Dakota 57565',18538,22832);
INSERT INTO "django_geo_db_zipcode" VALUES(25760,57566,-6,'Parmelee, South Dakota 57566',18539,22833);
INSERT INTO "django_geo_db_zipcode" VALUES(25761,57567,-7,'Philip, South Dakota 57567',18540,22834);
INSERT INTO "django_geo_db_zipcode" VALUES(25762,57568,-6,'Presho, South Dakota 57568',18541,22835);
INSERT INTO "django_geo_db_zipcode" VALUES(25763,57569,-6,'Reliance, South Dakota 57569',18542,22836);
INSERT INTO "django_geo_db_zipcode" VALUES(25764,57570,-6,'Rosebud, South Dakota 57570',18543,22837);
INSERT INTO "django_geo_db_zipcode" VALUES(25765,57571,-6,'Saint Charles, South Dakota 57571',18544,22838);
INSERT INTO "django_geo_db_zipcode" VALUES(25766,57572,-6,'Saint Francis, South Dakota 57572',18545,22839);
INSERT INTO "django_geo_db_zipcode" VALUES(25767,57574,-7,'Tuthill, South Dakota 57574',18546,22840);
INSERT INTO "django_geo_db_zipcode" VALUES(25768,57576,-6,'Vivian, South Dakota 57576',18547,22841);
INSERT INTO "django_geo_db_zipcode" VALUES(25769,57577,-7,'Wanblee, South Dakota 57577',18548,22842);
INSERT INTO "django_geo_db_zipcode" VALUES(25770,57578,-6,'Wewela, South Dakota 57578',18549,22843);
INSERT INTO "django_geo_db_zipcode" VALUES(25771,57579,-6,'White River, South Dakota 57579',18550,22844);
INSERT INTO "django_geo_db_zipcode" VALUES(25772,57580,-6,'Winner, South Dakota 57580',18551,22845);
INSERT INTO "django_geo_db_zipcode" VALUES(25773,57584,-6,'Witten, South Dakota 57584',18552,22846);
INSERT INTO "django_geo_db_zipcode" VALUES(25774,57585,-6,'Wood, South Dakota 57585',18553,22847);
INSERT INTO "django_geo_db_zipcode" VALUES(25775,57601,-7,'Mobridge, South Dakota 57601',18554,22848);
INSERT INTO "django_geo_db_zipcode" VALUES(25776,57620,-7,'Bison, South Dakota 57620',18555,22849);
INSERT INTO "django_geo_db_zipcode" VALUES(25777,57621,-7,'Bullhead, South Dakota 57621',18556,22850);
INSERT INTO "django_geo_db_zipcode" VALUES(25778,57622,-7,'Cherry Creek, South Dakota 57622',18557,22851);
INSERT INTO "django_geo_db_zipcode" VALUES(25779,57623,-7,'Dupree, South Dakota 57623',18558,22852);
INSERT INTO "django_geo_db_zipcode" VALUES(25780,57625,-7,'Eagle Butte, South Dakota 57625',18559,22853);
INSERT INTO "django_geo_db_zipcode" VALUES(25781,57626,-7,'Faith, South Dakota 57626',18560,22854);
INSERT INTO "django_geo_db_zipcode" VALUES(25782,57628,-7,'Firesteel, South Dakota 57628',18561,22855);
INSERT INTO "django_geo_db_zipcode" VALUES(25783,57629,-7,'Glad Valley, South Dakota 57629',18562,22856);
INSERT INTO "django_geo_db_zipcode" VALUES(25784,57630,-7,'Glencross, South Dakota 57630',18563,22857);
INSERT INTO "django_geo_db_zipcode" VALUES(25785,57631,-6,'Glenham, South Dakota 57631',18564,22858);
INSERT INTO "django_geo_db_zipcode" VALUES(25786,57632,-6,'Herreid, South Dakota 57632',18565,22859);
INSERT INTO "django_geo_db_zipcode" VALUES(25787,57633,-7,'Isabel, South Dakota 57633',18566,22860);
INSERT INTO "django_geo_db_zipcode" VALUES(25788,57634,-7,'Keldron, South Dakota 57634',18567,22861);
INSERT INTO "django_geo_db_zipcode" VALUES(25789,57636,-7,'Lantry, South Dakota 57636',18568,22862);
INSERT INTO "django_geo_db_zipcode" VALUES(25790,57638,-7,'Lemmon, North Dakota 57638',18569,22863);
INSERT INTO "django_geo_db_zipcode" VALUES(25791,57639,-7,'Little Eagle, South Dakota 57639',18570,22864);
INSERT INTO "django_geo_db_zipcode" VALUES(25792,57640,-7,'Lodgepole, South Dakota 57640',18571,22865);
INSERT INTO "django_geo_db_zipcode" VALUES(25793,57641,-7,'McIntosh, South Dakota 57641',18572,22866);
INSERT INTO "django_geo_db_zipcode" VALUES(25794,57642,-7,'McLaughlin, South Dakota 57642',18573,22867);
INSERT INTO "django_geo_db_zipcode" VALUES(25795,57643,-7,'Mahto, South Dakota 57643',18574,22864);
INSERT INTO "django_geo_db_zipcode" VALUES(25796,57644,-7,'Meadow, South Dakota 57644',18575,22868);
INSERT INTO "django_geo_db_zipcode" VALUES(25797,57645,-7,'Morristown, South Dakota 57645',18576,22869);
INSERT INTO "django_geo_db_zipcode" VALUES(25798,57646,-6,'Mound City, South Dakota 57646',18577,22870);
INSERT INTO "django_geo_db_zipcode" VALUES(25799,57647,-7,'Parade, South Dakota 57647',18578,22857);
INSERT INTO "django_geo_db_zipcode" VALUES(25800,57648,-6,'Pollock, South Dakota 57648',18579,22871);
INSERT INTO "django_geo_db_zipcode" VALUES(25801,57649,-7,'Prairie City, South Dakota 57649',18580,22872);
INSERT INTO "django_geo_db_zipcode" VALUES(25802,57650,-7,'Ralph, South Dakota 57650',18581,22873);
INSERT INTO "django_geo_db_zipcode" VALUES(25803,57651,-7,'Reva, South Dakota 57651',18582,22874);
INSERT INTO "django_geo_db_zipcode" VALUES(25804,57652,-7,'Ridgeview, South Dakota 57652',18583,22875);
INSERT INTO "django_geo_db_zipcode" VALUES(25805,57653,-7,'Shadehill, South Dakota 57653',18584,22876);
INSERT INTO "django_geo_db_zipcode" VALUES(25806,57656,-7,'Timber Lake, South Dakota 57656',18538,22877);
INSERT INTO "django_geo_db_zipcode" VALUES(25807,57657,-7,'Trail City, South Dakota 57657',18585,22878);
INSERT INTO "django_geo_db_zipcode" VALUES(25808,57658,-7,'Wakpala, South Dakota 57658',18586,22879);
INSERT INTO "django_geo_db_zipcode" VALUES(25809,57659,-7,'Walker, South Dakota 57659',18587,22864);
INSERT INTO "django_geo_db_zipcode" VALUES(25810,57660,-7,'Watauga, South Dakota 57660',18588,22880);
INSERT INTO "django_geo_db_zipcode" VALUES(25811,57661,-7,'Whitehorse, South Dakota 57661',18589,22881);
INSERT INTO "django_geo_db_zipcode" VALUES(25812,57671,-7,'McIntosh, South Dakota 57671',18572,22882);
INSERT INTO "django_geo_db_zipcode" VALUES(25813,57673,-6,'York, South Dakota 57673',18590,22883);
INSERT INTO "django_geo_db_zipcode" VALUES(25814,57683,-7,'Orange, North Dakota 57683',18591,22884);
INSERT INTO "django_geo_db_zipcode" VALUES(25815,57700,-7,'Rapid City, South Dakota 57700',18592,22885);
INSERT INTO "django_geo_db_zipcode" VALUES(25816,57701,-7,'Rapid City, South Dakota 57701',18592,22886);
INSERT INTO "django_geo_db_zipcode" VALUES(25817,57702,-7,'Rapid City, South Dakota 57702',18592,22887);
INSERT INTO "django_geo_db_zipcode" VALUES(25818,57703,-7,'Rapid City, South Dakota 57703',18592,22888);
INSERT INTO "django_geo_db_zipcode" VALUES(25819,57706,-7,'Ellsworth AFB, South Dakota 57706',18593,22889);
INSERT INTO "django_geo_db_zipcode" VALUES(25820,57708,-7,'Bethlehem, South Dakota 57708',18594,22890);
INSERT INTO "django_geo_db_zipcode" VALUES(25821,57709,-7,'Rapid City, South Dakota 57709',18592,22891);
INSERT INTO "django_geo_db_zipcode" VALUES(25822,57714,-7,'Allen, South Dakota 57714',18595,22892);
INSERT INTO "django_geo_db_zipcode" VALUES(25823,57716,-7,'Batesland, South Dakota 57716',18596,22893);
INSERT INTO "django_geo_db_zipcode" VALUES(25824,57717,-7,'Belle Fourche, South Dakota 57717',18597,22894);
INSERT INTO "django_geo_db_zipcode" VALUES(25825,57718,-7,'Black Hawk, South Dakota 57718',18598,22895);
INSERT INTO "django_geo_db_zipcode" VALUES(25826,57719,-7,'Box Elder, South Dakota 57719',18599,22896);
INSERT INTO "django_geo_db_zipcode" VALUES(25827,57720,-7,'Buffalo, South Dakota 57720',18600,22897);
INSERT INTO "django_geo_db_zipcode" VALUES(25828,57722,-7,'Buffalo Gap, South Dakota 57722',18601,22898);
INSERT INTO "django_geo_db_zipcode" VALUES(25829,57724,-7,'Camp Crook, South Dakota 57724',18602,22899);
INSERT INTO "django_geo_db_zipcode" VALUES(25830,57725,-7,'Caputa, South Dakota 57725',18603,22900);
INSERT INTO "django_geo_db_zipcode" VALUES(25831,57729,-7,'Creighton, South Dakota 57729',18604,22901);
INSERT INTO "django_geo_db_zipcode" VALUES(25832,57730,-7,'Custer, South Dakota 57730',18605,22902);
INSERT INTO "django_geo_db_zipcode" VALUES(25833,57732,-7,'Deadwood, South Dakota 57732',18606,22903);
INSERT INTO "django_geo_db_zipcode" VALUES(25834,57735,-7,'Edgemont, South Dakota 57735',18607,22904);
INSERT INTO "django_geo_db_zipcode" VALUES(25835,57736,-7,'Elm Springs, South Dakota 57736',18608,22905);
INSERT INTO "django_geo_db_zipcode" VALUES(25836,57737,-7,'Enning, South Dakota 57737',18609,22906);
INSERT INTO "django_geo_db_zipcode" VALUES(25837,57738,-7,'Fairburn, South Dakota 57738',18610,22907);
INSERT INTO "django_geo_db_zipcode" VALUES(25838,57741,-7,'Fort Meade, South Dakota 57741',18611,22908);
INSERT INTO "django_geo_db_zipcode" VALUES(25839,57742,-7,'Fruitdale, South Dakota 57742',18612,22909);
INSERT INTO "django_geo_db_zipcode" VALUES(25840,57744,-7,'Hermosa, South Dakota 57744',18613,22910);
INSERT INTO "django_geo_db_zipcode" VALUES(25841,57745,-7,'Hill City, South Dakota 57745',18614,22911);
INSERT INTO "django_geo_db_zipcode" VALUES(25842,57747,-7,'Hot Springs, South Dakota 57747',18615,22912);
INSERT INTO "django_geo_db_zipcode" VALUES(25843,57748,-7,'Howes, South Dakota 57748',18616,22913);
INSERT INTO "django_geo_db_zipcode" VALUES(25844,57750,-7,'Interior, South Dakota 57750',18617,22914);
INSERT INTO "django_geo_db_zipcode" VALUES(25845,57751,-7,'Keystone, South Dakota 57751',18618,22915);
INSERT INTO "django_geo_db_zipcode" VALUES(25846,57752,-7,'Kyle, South Dakota 57752',18619,22916);
INSERT INTO "django_geo_db_zipcode" VALUES(25847,57754,-7,'Lead, South Dakota 57754',18620,22917);
INSERT INTO "django_geo_db_zipcode" VALUES(25848,57755,-7,'Ludlow, South Dakota 57755',18621,22918);
INSERT INTO "django_geo_db_zipcode" VALUES(25849,57756,-7,'Manderson, South Dakota 57756',18622,22919);
INSERT INTO "django_geo_db_zipcode" VALUES(25850,57758,-7,'Mud Butte, South Dakota 57758',18623,22920);
INSERT INTO "django_geo_db_zipcode" VALUES(25851,57759,-7,'Nemo, South Dakota 57759',18624,22921);
INSERT INTO "django_geo_db_zipcode" VALUES(25852,57760,-7,'Newell, South Dakota 57760',18625,22922);
INSERT INTO "django_geo_db_zipcode" VALUES(25853,57761,-7,'New Underwood, South Dakota 57761',18626,22923);
INSERT INTO "django_geo_db_zipcode" VALUES(25854,57762,-7,'Nisland, South Dakota 57762',18627,22924);
INSERT INTO "django_geo_db_zipcode" VALUES(25855,57763,-7,'Oelrichs, South Dakota 57763',18628,22925);
INSERT INTO "django_geo_db_zipcode" VALUES(25856,57764,-7,'Oglala, South Dakota 57764',18629,22926);
INSERT INTO "django_geo_db_zipcode" VALUES(25857,57765,-7,'Opal, South Dakota 57765',18630,22927);
INSERT INTO "django_geo_db_zipcode" VALUES(25858,57766,-7,'Oral, South Dakota 57766',18631,22928);
INSERT INTO "django_geo_db_zipcode" VALUES(25859,57767,-7,'Owanka, South Dakota 57767',18632,22929);
INSERT INTO "django_geo_db_zipcode" VALUES(25860,57769,-7,'Piedmont, South Dakota 57769',18633,22930);
INSERT INTO "django_geo_db_zipcode" VALUES(25861,57770,-7,'Pine Ridge, South Dakota 57770',18634,22931);
INSERT INTO "django_geo_db_zipcode" VALUES(25862,57772,-7,'Porcupine, South Dakota 57772',18635,22932);
INSERT INTO "django_geo_db_zipcode" VALUES(25863,57773,-7,'Pringle, South Dakota 57773',18636,22933);
INSERT INTO "django_geo_db_zipcode" VALUES(25864,57774,-7,'Provo, South Dakota 57774',18637,22934);
INSERT INTO "django_geo_db_zipcode" VALUES(25865,57775,-7,'Quinn, South Dakota 57775',18638,22935);
INSERT INTO "django_geo_db_zipcode" VALUES(25866,57776,-7,'Redig, South Dakota 57776',18639,22936);
INSERT INTO "django_geo_db_zipcode" VALUES(25867,57777,-7,'Red Owl, South Dakota 57777',18640,22937);
INSERT INTO "django_geo_db_zipcode" VALUES(25868,57778,-7,'Rochford, South Dakota 57778',18641,22938);
INSERT INTO "django_geo_db_zipcode" VALUES(25869,57779,-7,'Saint Onge, South Dakota 57779',18642,22939);
INSERT INTO "django_geo_db_zipcode" VALUES(25870,57780,-7,'Scenic, South Dakota 57780',18643,22940);
INSERT INTO "django_geo_db_zipcode" VALUES(25871,57782,-7,'Smithwick, South Dakota 57782',18644,22941);
INSERT INTO "django_geo_db_zipcode" VALUES(25872,57783,-7,'Spearfish, South Dakota 57783',18645,22942);
INSERT INTO "django_geo_db_zipcode" VALUES(25873,57785,-7,'Sturgis, South Dakota 57785',18646,22943);
INSERT INTO "django_geo_db_zipcode" VALUES(25874,57787,-7,'Union Center, South Dakota 57787',18647,22944);
INSERT INTO "django_geo_db_zipcode" VALUES(25875,57788,-7,'Vale, South Dakota 57788',18648,22945);
INSERT INTO "django_geo_db_zipcode" VALUES(25876,57790,-7,'Wall, South Dakota 57790',18649,22946);
INSERT INTO "django_geo_db_zipcode" VALUES(25877,57791,-7,'Wasta, South Dakota 57791',18650,22947);
INSERT INTO "django_geo_db_zipcode" VALUES(25878,57792,-7,'White Owl, South Dakota 57792',18651,22948);
INSERT INTO "django_geo_db_zipcode" VALUES(25879,57793,-7,'Whitewood, South Dakota 57793',18652,22949);
INSERT INTO "django_geo_db_zipcode" VALUES(25880,57794,-7,'Wounded Knee, South Dakota 57794',18653,22950);
INSERT INTO "django_geo_db_zipcode" VALUES(25881,57796,-7,'Wall, South Dakota 57796',18649,22951);
INSERT INTO "django_geo_db_zipcode" VALUES(25882,57799,-7,'Spearfish, South Dakota 57799',18645,22952);
INSERT INTO "django_geo_db_zipcode" VALUES(25883,57840,-6,'Harrison, South Dakota 57840',18418,22953);
INSERT INTO "django_geo_db_zipcode" VALUES(25884,57841,-6,'Carlisle, South Dakota 57841',18654,22954);
INSERT INTO "django_geo_db_zipcode" VALUES(25885,57949,-6,'Big Sioux, South Dakota 57949',18655,22955);
INSERT INTO "django_geo_db_zipcode" VALUES(25886,58000,-6,'Minot, North Dakota 58000',18656,22956);
INSERT INTO "django_geo_db_zipcode" VALUES(25887,58001,-6,'Abercrombie, North Dakota 58001',18657,22957);
INSERT INTO "django_geo_db_zipcode" VALUES(25888,58002,-6,'Absaraka, North Dakota 58002',18658,22958);
INSERT INTO "django_geo_db_zipcode" VALUES(25889,58004,-6,'Amenia, North Dakota 58004',18659,22959);
INSERT INTO "django_geo_db_zipcode" VALUES(25890,58005,-6,'Argusville, North Dakota 58005',18660,22960);
INSERT INTO "django_geo_db_zipcode" VALUES(25891,58006,-6,'Arthur, North Dakota 58006',18661,22961);
INSERT INTO "django_geo_db_zipcode" VALUES(25892,58007,-6,'Ayr, North Dakota 58007',18662,22962);
INSERT INTO "django_geo_db_zipcode" VALUES(25893,58008,-6,'Barney, North Dakota 58008',18663,22963);
INSERT INTO "django_geo_db_zipcode" VALUES(25894,58009,-6,'Blanchard, North Dakota 58009',18664,22964);
INSERT INTO "django_geo_db_zipcode" VALUES(25895,58011,-6,'Buffalo, North Dakota 58011',18665,22965);
INSERT INTO "django_geo_db_zipcode" VALUES(25896,58012,-6,'Casselton, North Dakota 58012',18666,22966);
INSERT INTO "django_geo_db_zipcode" VALUES(25897,58013,-6,'Cayuga, North Dakota 58013',18667,22967);
INSERT INTO "django_geo_db_zipcode" VALUES(25898,58014,-6,'Chaffee, North Dakota 58014',18668,22968);
INSERT INTO "django_geo_db_zipcode" VALUES(25899,58015,-6,'Christine, North Dakota 58015',18669,22969);
INSERT INTO "django_geo_db_zipcode" VALUES(25900,58016,-6,'Clifford, North Dakota 58016',18670,22970);
INSERT INTO "django_geo_db_zipcode" VALUES(25901,58017,-6,'Cogswell, North Dakota 58017',18671,22971);
INSERT INTO "django_geo_db_zipcode" VALUES(25902,58018,-6,'Colfax, North Dakota 58018',18672,22972);
INSERT INTO "django_geo_db_zipcode" VALUES(25903,58021,-6,'Davenport, North Dakota 58021',18673,22973);
INSERT INTO "django_geo_db_zipcode" VALUES(25904,58027,-6,'Enderlin, North Dakota 58027',18674,22974);
INSERT INTO "django_geo_db_zipcode" VALUES(25905,58029,-6,'Erie, North Dakota 58029',18675,22975);
INSERT INTO "django_geo_db_zipcode" VALUES(25906,58030,-6,'Fairmount, North Dakota 58030',18676,22976);
INSERT INTO "django_geo_db_zipcode" VALUES(25907,58031,-6,'Fingal, North Dakota 58031',18677,22977);
INSERT INTO "django_geo_db_zipcode" VALUES(25908,58032,-6,'Forman, North Dakota 58032',18678,22978);
INSERT INTO "django_geo_db_zipcode" VALUES(25909,58033,-6,'Fort Ransom, North Dakota 58033',18679,22979);
INSERT INTO "django_geo_db_zipcode" VALUES(25910,58035,-6,'Galesburg, North Dakota 58035',18680,22980);
INSERT INTO "django_geo_db_zipcode" VALUES(25911,58036,-6,'Gardner, North Dakota 58036',18681,22981);
INSERT INTO "django_geo_db_zipcode" VALUES(25912,58038,-6,'Grandin, North Dakota 58038',18682,22982);
INSERT INTO "django_geo_db_zipcode" VALUES(25913,58039,-6,'Great Bend, North Dakota 58039',18683,22983);
INSERT INTO "django_geo_db_zipcode" VALUES(25914,58040,-6,'Gwinner, North Dakota 58040',18684,22984);
INSERT INTO "django_geo_db_zipcode" VALUES(25915,58041,-6,'Hankinson, North Dakota 58041',18685,22985);
INSERT INTO "django_geo_db_zipcode" VALUES(25916,58042,-6,'Harwood, North Dakota 58042',18686,22986);
INSERT INTO "django_geo_db_zipcode" VALUES(25917,58043,-6,'Havana, North Dakota 58043',18687,22987);
INSERT INTO "django_geo_db_zipcode" VALUES(25918,58045,-6,'Hillsboro, North Dakota 58045',18688,22988);
INSERT INTO "django_geo_db_zipcode" VALUES(25919,58046,-6,'Hope, North Dakota 58046',18689,22989);
INSERT INTO "django_geo_db_zipcode" VALUES(25920,58047,-6,'Horace, North Dakota 58047',18690,22990);
INSERT INTO "django_geo_db_zipcode" VALUES(25921,58048,-6,'Hunter, North Dakota 58048',18691,22991);
INSERT INTO "django_geo_db_zipcode" VALUES(25922,58049,-6,'Kathryn, North Dakota 58049',18692,22992);
INSERT INTO "django_geo_db_zipcode" VALUES(25923,58051,-6,'Kindred, North Dakota 58051',18693,22993);
INSERT INTO "django_geo_db_zipcode" VALUES(25924,58052,-6,'Leonard, North Dakota 58052',18694,22994);
INSERT INTO "django_geo_db_zipcode" VALUES(25925,58053,-6,'Lidgerwood, North Dakota 58053',18695,22995);
INSERT INTO "django_geo_db_zipcode" VALUES(25926,58054,-6,'Lisbon, North Dakota 58054',18696,22996);
INSERT INTO "django_geo_db_zipcode" VALUES(25927,58056,-6,'Luverne, North Dakota 58056',18697,22997);
INSERT INTO "django_geo_db_zipcode" VALUES(25928,58057,-6,'Mcleod, North Dakota 58057',18698,22998);
INSERT INTO "django_geo_db_zipcode" VALUES(25929,58058,-6,'Mantador, North Dakota 58058',18699,22999);
INSERT INTO "django_geo_db_zipcode" VALUES(25930,58059,-6,'Mapleton, North Dakota 58059',18700,23000);
INSERT INTO "django_geo_db_zipcode" VALUES(25931,58060,-6,'Milnor, North Dakota 58060',18701,23001);
INSERT INTO "django_geo_db_zipcode" VALUES(25932,58061,-6,'Mooreton, North Dakota 58061',18702,23002);
INSERT INTO "django_geo_db_zipcode" VALUES(25933,58062,-6,'Nome, North Dakota 58062',18703,23003);
INSERT INTO "django_geo_db_zipcode" VALUES(25934,58063,-6,'Oriska, North Dakota 58063',18704,23004);
INSERT INTO "django_geo_db_zipcode" VALUES(25935,58064,-6,'Page, North Dakota 58064',18705,23005);
INSERT INTO "django_geo_db_zipcode" VALUES(25936,58065,-6,'Pillsbury, North Dakota 58065',18706,23006);
INSERT INTO "django_geo_db_zipcode" VALUES(25937,58067,-6,'Rutland, North Dakota 58067',18707,23007);
INSERT INTO "django_geo_db_zipcode" VALUES(25938,58068,-6,'Sheldon, North Dakota 58068',18708,23008);
INSERT INTO "django_geo_db_zipcode" VALUES(25939,58069,-6,'Stirum, North Dakota 58069',18709,23009);
INSERT INTO "django_geo_db_zipcode" VALUES(25940,58071,-6,'Tower City, North Dakota 58071',18710,23010);
INSERT INTO "django_geo_db_zipcode" VALUES(25941,58072,-6,'Valley City, North Dakota 58072',18711,23011);
INSERT INTO "django_geo_db_zipcode" VALUES(25942,58074,-6,'Wahpeton, North Dakota 58074',18712,23012);
INSERT INTO "django_geo_db_zipcode" VALUES(25943,58075,-6,'Wahpeton, North Dakota 58075',18712,23013);
INSERT INTO "django_geo_db_zipcode" VALUES(25944,58076,-6,'Wahpeton, North Dakota 58076',18712,23014);
INSERT INTO "django_geo_db_zipcode" VALUES(25945,58077,-6,'Walcott, North Dakota 58077',18713,23015);
INSERT INTO "django_geo_db_zipcode" VALUES(25946,58078,-6,'West Fargo, North Dakota 58078',18714,23016);
INSERT INTO "django_geo_db_zipcode" VALUES(25947,58079,-6,'Wheatland, North Dakota 58079',18715,23017);
INSERT INTO "django_geo_db_zipcode" VALUES(25948,58081,-6,'Wyndmere, North Dakota 58081',18716,23018);
INSERT INTO "django_geo_db_zipcode" VALUES(25949,58102,-6,'Fargo, North Dakota 58102',18717,23019);
INSERT INTO "django_geo_db_zipcode" VALUES(25950,58103,-6,'Fargo, North Dakota 58103',18717,23020);
INSERT INTO "django_geo_db_zipcode" VALUES(25951,58104,-6,'Fargo, North Dakota 58104',18717,23021);
INSERT INTO "django_geo_db_zipcode" VALUES(25952,58105,-6,'Fargo, North Dakota 58105',18717,23022);
INSERT INTO "django_geo_db_zipcode" VALUES(25953,58106,-6,'Fargo, North Dakota 58106',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25954,58107,-6,'Fargo, North Dakota 58107',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25955,58108,-6,'Fargo, North Dakota 58108',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25956,58109,-6,'Fargo, North Dakota 58109',18717,23024);
INSERT INTO "django_geo_db_zipcode" VALUES(25957,58121,-6,'Fargo, North Dakota 58121',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25958,58122,-6,'Fargo, North Dakota 58122',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25959,58123,-6,'Fargo, North Dakota 58123',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25960,58124,-6,'Fargo, North Dakota 58124',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25961,58125,-6,'Fargo, North Dakota 58125',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25962,58126,-6,'Fargo, North Dakota 58126',18717,23023);
INSERT INTO "django_geo_db_zipcode" VALUES(25963,58201,-6,'Grand Forks, North Dakota 58201',18718,23025);
INSERT INTO "django_geo_db_zipcode" VALUES(25964,58202,-6,'Grand Forks, North Dakota 58202',18718,23026);
INSERT INTO "django_geo_db_zipcode" VALUES(25965,58203,-6,'Grand Forks, North Dakota 58203',18718,23027);
INSERT INTO "django_geo_db_zipcode" VALUES(25966,58204,-6,'Grand Forks AFB, North Dakota 58204',18719,23028);
INSERT INTO "django_geo_db_zipcode" VALUES(25967,58205,-6,'Grand Forks AFB, North Dakota 58205',18719,23029);
INSERT INTO "django_geo_db_zipcode" VALUES(25968,58206,-6,'Grand Forks, North Dakota 58206',18718,23029);
INSERT INTO "django_geo_db_zipcode" VALUES(25969,58207,-6,'Grand Forks, North Dakota 58207',18718,23029);
INSERT INTO "django_geo_db_zipcode" VALUES(25970,58208,-6,'Grand Forks, North Dakota 58208',18718,23029);
INSERT INTO "django_geo_db_zipcode" VALUES(25971,58210,-6,'Adams, North Dakota 58210',18720,23030);
INSERT INTO "django_geo_db_zipcode" VALUES(25972,58212,-6,'Aneta, North Dakota 58212',18721,23031);
INSERT INTO "django_geo_db_zipcode" VALUES(25973,58213,-6,'Ardoch, North Dakota 58213',18722,23032);
INSERT INTO "django_geo_db_zipcode" VALUES(25974,58214,-6,'Arvilla, North Dakota 58214',18723,23033);
INSERT INTO "django_geo_db_zipcode" VALUES(25975,58216,-6,'Bathgate, North Dakota 58216',18724,23034);
INSERT INTO "django_geo_db_zipcode" VALUES(25976,58218,-6,'Buxton, North Dakota 58218',18725,23035);
INSERT INTO "django_geo_db_zipcode" VALUES(25977,58219,-6,'Caledonia, North Dakota 58219',18726,23036);
INSERT INTO "django_geo_db_zipcode" VALUES(25978,58220,-6,'Cavalier, North Dakota 58220',18727,23037);
INSERT INTO "django_geo_db_zipcode" VALUES(25979,58222,-6,'Crystal, North Dakota 58222',18728,23038);
INSERT INTO "django_geo_db_zipcode" VALUES(25980,58223,-6,'Cummings, North Dakota 58223',18729,23039);
INSERT INTO "django_geo_db_zipcode" VALUES(25981,58224,-6,'Dahlen, North Dakota 58224',18730,23040);
INSERT INTO "django_geo_db_zipcode" VALUES(25982,58225,-6,'Drayton, North Dakota 58225',18731,23041);
INSERT INTO "django_geo_db_zipcode" VALUES(25983,58227,-6,'Edinburg, North Dakota 58227',18732,23042);
INSERT INTO "django_geo_db_zipcode" VALUES(25984,58228,-6,'Emerado, North Dakota 58228',18733,23043);
INSERT INTO "django_geo_db_zipcode" VALUES(25985,58229,-6,'Fairdale, North Dakota 58229',18734,23044);
INSERT INTO "django_geo_db_zipcode" VALUES(25986,58230,-6,'Finley, North Dakota 58230',18735,23045);
INSERT INTO "django_geo_db_zipcode" VALUES(25987,58231,-6,'Fordville, North Dakota 58231',18736,23046);
INSERT INTO "django_geo_db_zipcode" VALUES(25988,58233,-6,'Forest River, North Dakota 58233',18737,23047);
INSERT INTO "django_geo_db_zipcode" VALUES(25989,58234,-6,'Brantford, South Dakota 58234',18738,23048);
INSERT INTO "django_geo_db_zipcode" VALUES(25990,58235,-6,'Gilby, North Dakota 58235',18739,23049);
INSERT INTO "django_geo_db_zipcode" VALUES(25991,58236,-6,'Glasston, North Dakota 58236',18740,23050);
INSERT INTO "django_geo_db_zipcode" VALUES(25992,58237,-6,'Grafton, North Dakota 58237',18741,23051);
INSERT INTO "django_geo_db_zipcode" VALUES(25993,58238,-6,'Hamilton, North Dakota 58238',18742,23052);
INSERT INTO "django_geo_db_zipcode" VALUES(25994,58239,-6,'Hannah, North Dakota 58239',18743,23053);
INSERT INTO "django_geo_db_zipcode" VALUES(25995,58240,-6,'Hatton, North Dakota 58240',18744,23054);
INSERT INTO "django_geo_db_zipcode" VALUES(25996,58241,-6,'Hensel, North Dakota 58241',18745,23055);
INSERT INTO "django_geo_db_zipcode" VALUES(25997,58243,-6,'Hoople, North Dakota 58243',18746,23056);
INSERT INTO "django_geo_db_zipcode" VALUES(25998,58244,-6,'Inkster, North Dakota 58244',18747,23057);
INSERT INTO "django_geo_db_zipcode" VALUES(25999,58249,-6,'Langdon, North Dakota 58249',18748,23058);
INSERT INTO "django_geo_db_zipcode" VALUES(26000,58250,-6,'Lankin, North Dakota 58250',18749,23059);
INSERT INTO "django_geo_db_zipcode" VALUES(26001,58251,-6,'Larimore, North Dakota 58251',18750,23060);
INSERT INTO "django_geo_db_zipcode" VALUES(26002,58254,-6,'Mcville, North Dakota 58254',18751,23061);
INSERT INTO "django_geo_db_zipcode" VALUES(26003,58255,-6,'Maida, North Dakota 58255',18752,23062);
INSERT INTO "django_geo_db_zipcode" VALUES(26004,58256,-6,'Manvel, North Dakota 58256',18753,23063);
INSERT INTO "django_geo_db_zipcode" VALUES(26005,58257,-6,'Mayville, North Dakota 58257',18754,23064);
INSERT INTO "django_geo_db_zipcode" VALUES(26006,58258,-6,'Mekinock, North Dakota 58258',18755,23065);
INSERT INTO "django_geo_db_zipcode" VALUES(26007,58259,-6,'Michigan, North Dakota 58259',18756,23066);
INSERT INTO "django_geo_db_zipcode" VALUES(26008,58260,-6,'Milton, North Dakota 58260',18757,23067);
INSERT INTO "django_geo_db_zipcode" VALUES(26009,58261,-6,'Minto, North Dakota 58261',18758,23068);
INSERT INTO "django_geo_db_zipcode" VALUES(26010,58262,-6,'Mountain, North Dakota 58262',18759,23069);
INSERT INTO "django_geo_db_zipcode" VALUES(26011,58265,-6,'Neche, North Dakota 58265',18760,23070);
INSERT INTO "django_geo_db_zipcode" VALUES(26012,58266,-6,'Niagara, North Dakota 58266',18761,23071);
INSERT INTO "django_geo_db_zipcode" VALUES(26013,58267,-6,'Northwood, North Dakota 58267',18762,23072);
INSERT INTO "django_geo_db_zipcode" VALUES(26014,58269,-6,'Osnabrock, North Dakota 58269',18763,23073);
INSERT INTO "django_geo_db_zipcode" VALUES(26015,58270,-6,'Park River, North Dakota 58270',18764,23074);
INSERT INTO "django_geo_db_zipcode" VALUES(26016,58271,-6,'Pembina, North Dakota 58271',18765,23075);
INSERT INTO "django_geo_db_zipcode" VALUES(26017,58272,-6,'Petersburg, North Dakota 58272',18766,23076);
INSERT INTO "django_geo_db_zipcode" VALUES(26018,58273,-6,'Pisek, North Dakota 58273',18767,23077);
INSERT INTO "django_geo_db_zipcode" VALUES(26019,58274,-6,'Portland, North Dakota 58274',18768,23078);
INSERT INTO "django_geo_db_zipcode" VALUES(26020,58275,-6,'Reynolds, North Dakota 58275',18769,23079);
INSERT INTO "django_geo_db_zipcode" VALUES(26021,58276,-6,'Saint Thomas, North Dakota 58276',18770,23080);
INSERT INTO "django_geo_db_zipcode" VALUES(26022,58277,-6,'Sharon, North Dakota 58277',18771,23081);
INSERT INTO "django_geo_db_zipcode" VALUES(26023,58278,-6,'Thompson, North Dakota 58278',18772,23082);
INSERT INTO "django_geo_db_zipcode" VALUES(26024,58281,-6,'Wales, North Dakota 58281',18773,23083);
INSERT INTO "django_geo_db_zipcode" VALUES(26025,58282,-6,'Walhalla, North Dakota 58282',18774,23084);
INSERT INTO "django_geo_db_zipcode" VALUES(26026,58293,-6,'Farmington, North Dakota 58293',18775,23085);
INSERT INTO "django_geo_db_zipcode" VALUES(26027,58300,-6,'Poplar Grove, North Dakota 58300',18776,23086);
INSERT INTO "django_geo_db_zipcode" VALUES(26028,58301,-6,'Devils Lake, North Dakota 58301',18777,23087);
INSERT INTO "django_geo_db_zipcode" VALUES(26029,58310,-6,'Agate, North Dakota 58310',18778,23088);
INSERT INTO "django_geo_db_zipcode" VALUES(26030,58311,-6,'Alsen, North Dakota 58311',18779,23089);
INSERT INTO "django_geo_db_zipcode" VALUES(26031,58313,-6,'Balta, North Dakota 58313',18780,23090);
INSERT INTO "django_geo_db_zipcode" VALUES(26032,58316,-6,'Belcourt, North Dakota 58316',18781,23091);
INSERT INTO "django_geo_db_zipcode" VALUES(26033,58317,-6,'Bisbee, North Dakota 58317',18782,23092);
INSERT INTO "django_geo_db_zipcode" VALUES(26034,58318,-6,'Bottineau, North Dakota 58318',18783,23093);
INSERT INTO "django_geo_db_zipcode" VALUES(26035,58319,-6,'Bremen, North Dakota 58319',18784,23094);
INSERT INTO "django_geo_db_zipcode" VALUES(26036,58320,-6,'Brinsmade, North Dakota 58320',18785,23095);
INSERT INTO "django_geo_db_zipcode" VALUES(26037,58321,-6,'Brocket, North Dakota 58321',18786,23096);
INSERT INTO "django_geo_db_zipcode" VALUES(26038,58323,-6,'Calvin, North Dakota 58323',18787,23097);
INSERT INTO "django_geo_db_zipcode" VALUES(26039,58324,-6,'Cando, North Dakota 58324',18788,23098);
INSERT INTO "django_geo_db_zipcode" VALUES(26040,58325,-6,'Churchs Ferry, North Dakota 58325',18789,23099);
INSERT INTO "django_geo_db_zipcode" VALUES(26041,58327,-6,'Crary, North Dakota 58327',18790,23100);
INSERT INTO "django_geo_db_zipcode" VALUES(26042,58329,-6,'Dunseith, North Dakota 58329',18791,23101);
INSERT INTO "django_geo_db_zipcode" VALUES(26043,58330,-6,'Edmore, North Dakota 58330',18792,23102);
INSERT INTO "django_geo_db_zipcode" VALUES(26044,58331,-6,'Egeland, North Dakota 58331',18793,23103);
INSERT INTO "django_geo_db_zipcode" VALUES(26045,58332,-6,'Esmond, North Dakota 58332',18794,23104);
INSERT INTO "django_geo_db_zipcode" VALUES(26046,58333,-6,'Sykeston, North Dakota 58333',18795,23105);
INSERT INTO "django_geo_db_zipcode" VALUES(26047,58335,-6,'Fort Totten, North Dakota 58335',18796,23106);
INSERT INTO "django_geo_db_zipcode" VALUES(26048,58337,-6,'Hamberg, North Dakota 58337',18797,23107);
INSERT INTO "django_geo_db_zipcode" VALUES(26049,58338,-6,'Hampden, North Dakota 58338',18798,23108);
INSERT INTO "django_geo_db_zipcode" VALUES(26050,58339,-6,'Hansboro, North Dakota 58339',18799,23109);
INSERT INTO "django_geo_db_zipcode" VALUES(26051,58341,-6,'Harvey, North Dakota 58341',18800,23110);
INSERT INTO "django_geo_db_zipcode" VALUES(26052,58343,-6,'Knox, North Dakota 58343',18801,23111);
INSERT INTO "django_geo_db_zipcode" VALUES(26053,58344,-6,'Lakota, North Dakota 58344',18802,23112);
INSERT INTO "django_geo_db_zipcode" VALUES(26054,58345,-6,'Lawton, North Dakota 58345',18803,23113);
INSERT INTO "django_geo_db_zipcode" VALUES(26055,58346,-6,'Leeds, North Dakota 58346',18804,23114);
INSERT INTO "django_geo_db_zipcode" VALUES(26056,58348,-6,'Maddock, North Dakota 58348',18805,23115);
INSERT INTO "django_geo_db_zipcode" VALUES(26057,58351,-6,'Minnewaukan, North Dakota 58351',18806,23116);
INSERT INTO "django_geo_db_zipcode" VALUES(26058,58352,-6,'Munich, North Dakota 58352',18807,23117);
INSERT INTO "django_geo_db_zipcode" VALUES(26059,58353,-6,'Mylo, North Dakota 58353',18808,23118);
INSERT INTO "django_geo_db_zipcode" VALUES(26060,58355,-6,'Nekoma, North Dakota 58355',18809,23119);
INSERT INTO "django_geo_db_zipcode" VALUES(26061,58356,-6,'New Rockford, North Dakota 58356',18810,23120);
INSERT INTO "django_geo_db_zipcode" VALUES(26062,58357,-6,'Oberon, North Dakota 58357',18811,23121);
INSERT INTO "django_geo_db_zipcode" VALUES(26063,58358,-6,'Fort Yates, North Dakota 58358',18812,23122);
INSERT INTO "django_geo_db_zipcode" VALUES(26064,58359,-6,'Orrin, North Dakota 58359',18813,23123);
INSERT INTO "django_geo_db_zipcode" VALUES(26065,58361,-6,'Pekin, North Dakota 58361',18814,23124);
INSERT INTO "django_geo_db_zipcode" VALUES(26066,58362,-6,'Penn, North Dakota 58362',18815,23125);
INSERT INTO "django_geo_db_zipcode" VALUES(26067,58363,-6,'Perth, North Dakota 58363',18816,23126);
INSERT INTO "django_geo_db_zipcode" VALUES(26068,58365,-6,'Rocklake, North Dakota 58365',18817,23127);
INSERT INTO "django_geo_db_zipcode" VALUES(26069,58366,-6,'Rolette, North Dakota 58366',18818,23128);
INSERT INTO "django_geo_db_zipcode" VALUES(26070,58367,-6,'Rolla, North Dakota 58367',18819,23129);
INSERT INTO "django_geo_db_zipcode" VALUES(26071,58368,-6,'Rugby, North Dakota 58368',18820,23130);
INSERT INTO "django_geo_db_zipcode" VALUES(26072,58369,-6,'Saint John, North Dakota 58369',18821,23131);
INSERT INTO "django_geo_db_zipcode" VALUES(26073,58370,-6,'Saint Michael, North Dakota 58370',18822,23132);
INSERT INTO "django_geo_db_zipcode" VALUES(26074,58371,-6,'Grandfield, North Dakota 58371',18823,23133);
INSERT INTO "django_geo_db_zipcode" VALUES(26075,58372,-6,'Sarles, North Dakota 58372',18824,23134);
INSERT INTO "django_geo_db_zipcode" VALUES(26076,58374,-6,'Sheyenne, North Dakota 58374',18825,23135);
INSERT INTO "django_geo_db_zipcode" VALUES(26077,58377,-6,'Starkweather, North Dakota 58377',18826,23136);
INSERT INTO "django_geo_db_zipcode" VALUES(26078,58379,-6,'Tokio, North Dakota 58379',18827,23137);
INSERT INTO "django_geo_db_zipcode" VALUES(26079,58380,-6,'Tolna, North Dakota 58380',18828,23138);
INSERT INTO "django_geo_db_zipcode" VALUES(26080,58381,-6,'Warwick, North Dakota 58381',18829,23139);
INSERT INTO "django_geo_db_zipcode" VALUES(26081,58382,-6,'Webster, North Dakota 58382',18830,23140);
INSERT INTO "django_geo_db_zipcode" VALUES(26082,58384,-6,'Willow City, North Dakota 58384',18831,23141);
INSERT INTO "django_geo_db_zipcode" VALUES(26083,58385,-6,'Wolford, North Dakota 58385',18832,23142);
INSERT INTO "django_geo_db_zipcode" VALUES(26084,58386,-6,'York, North Dakota 58386',18833,23143);
INSERT INTO "django_geo_db_zipcode" VALUES(26085,58401,-6,'Jamestown, North Dakota 58401',18834,23144);
INSERT INTO "django_geo_db_zipcode" VALUES(26086,58402,-6,'Jamestown, North Dakota 58402',18834,23145);
INSERT INTO "django_geo_db_zipcode" VALUES(26087,58405,-6,'Jamestown, North Dakota 58405',18834,23146);
INSERT INTO "django_geo_db_zipcode" VALUES(26088,58413,-6,'Ashley, North Dakota 58413',18835,23147);
INSERT INTO "django_geo_db_zipcode" VALUES(26089,58415,-6,'Berlin, North Dakota 58415',18836,23148);
INSERT INTO "django_geo_db_zipcode" VALUES(26090,58416,-6,'Binford, North Dakota 58416',18837,23149);
INSERT INTO "django_geo_db_zipcode" VALUES(26091,58418,-6,'Bowdon, North Dakota 58418',18838,23150);
INSERT INTO "django_geo_db_zipcode" VALUES(26092,58420,-6,'Buchanan, North Dakota 58420',18839,23151);
INSERT INTO "django_geo_db_zipcode" VALUES(26093,58421,-6,'Carrington, North Dakota 58421',18840,23152);
INSERT INTO "django_geo_db_zipcode" VALUES(26094,58422,-6,'Cathay, North Dakota 58422',18841,23153);
INSERT INTO "django_geo_db_zipcode" VALUES(26095,58423,-6,'Chaseley, North Dakota 58423',18842,23154);
INSERT INTO "django_geo_db_zipcode" VALUES(26096,58424,-6,'Cleveland, North Dakota 58424',18843,23155);
INSERT INTO "django_geo_db_zipcode" VALUES(26097,58425,-6,'Cooperstown, North Dakota 58425',18844,23156);
INSERT INTO "django_geo_db_zipcode" VALUES(26098,58426,-6,'Courtenay, North Dakota 58426',18845,23157);
INSERT INTO "django_geo_db_zipcode" VALUES(26099,58428,-6,'Dawson, North Dakota 58428',18846,23158);
INSERT INTO "django_geo_db_zipcode" VALUES(26100,58429,-6,'Dazey, North Dakota 58429',18847,23159);
INSERT INTO "django_geo_db_zipcode" VALUES(26101,58430,-6,'Denhoff, North Dakota 58430',18848,23160);
INSERT INTO "django_geo_db_zipcode" VALUES(26102,58431,-6,'Dickey, North Dakota 58431',18849,23161);
INSERT INTO "django_geo_db_zipcode" VALUES(26103,58432,-6,'Eckelson, North Dakota 58432',18850,23162);
INSERT INTO "django_geo_db_zipcode" VALUES(26104,58433,-6,'Edgeley, North Dakota 58433',18851,23163);
INSERT INTO "django_geo_db_zipcode" VALUES(26105,58436,-6,'Ellendale, North Dakota 58436',18852,23164);
INSERT INTO "django_geo_db_zipcode" VALUES(26106,58438,-6,'Fessenden, North Dakota 58438',18853,23165);
INSERT INTO "django_geo_db_zipcode" VALUES(26107,58439,-6,'Forbes, North Dakota 58439',18854,23166);
INSERT INTO "django_geo_db_zipcode" VALUES(26108,58440,-6,'Fredonia, North Dakota 58440',18855,23167);
INSERT INTO "django_geo_db_zipcode" VALUES(26109,58441,-6,'Fullerton, North Dakota 58441',18856,23168);
INSERT INTO "django_geo_db_zipcode" VALUES(26110,58442,-6,'Gackle, North Dakota 58442',18857,23169);
INSERT INTO "django_geo_db_zipcode" VALUES(26111,58443,-6,'Glenfield, North Dakota 58443',18858,23170);
INSERT INTO "django_geo_db_zipcode" VALUES(26112,58444,-6,'Goodrich, North Dakota 58444',18859,23171);
INSERT INTO "django_geo_db_zipcode" VALUES(26113,58445,-6,'Grace City, North Dakota 58445',18860,23172);
INSERT INTO "django_geo_db_zipcode" VALUES(26114,58448,-6,'Hannaford, North Dakota 58448',18861,23173);
INSERT INTO "django_geo_db_zipcode" VALUES(26115,58451,-6,'Hurdsfield, North Dakota 58451',18862,23174);
INSERT INTO "django_geo_db_zipcode" VALUES(26116,58452,-6,'Jessie, North Dakota 58452',18863,23175);
INSERT INTO "django_geo_db_zipcode" VALUES(26117,58454,-6,'Jud, North Dakota 58454',18864,23176);
INSERT INTO "django_geo_db_zipcode" VALUES(26118,58455,-6,'Kensal, North Dakota 58455',18865,23177);
INSERT INTO "django_geo_db_zipcode" VALUES(26119,58456,-6,'Kulm, North Dakota 58456',18866,23178);
INSERT INTO "django_geo_db_zipcode" VALUES(26120,58458,-6,'Lamoure, North Dakota 58458',18867,23179);
INSERT INTO "django_geo_db_zipcode" VALUES(26121,58460,-6,'Lehr, North Dakota 58460',18868,23180);
INSERT INTO "django_geo_db_zipcode" VALUES(26122,58461,-6,'Litchville, North Dakota 58461',18869,23181);
INSERT INTO "django_geo_db_zipcode" VALUES(26123,58463,-6,'Mcclusky, North Dakota 58463',18870,23182);
INSERT INTO "django_geo_db_zipcode" VALUES(26124,58464,-6,'Mchenry, North Dakota 58464',18871,23183);
INSERT INTO "django_geo_db_zipcode" VALUES(26125,58466,-6,'Marion, North Dakota 58466',18872,23184);
INSERT INTO "django_geo_db_zipcode" VALUES(26126,58467,-6,'Medina, North Dakota 58467',18873,23185);
INSERT INTO "django_geo_db_zipcode" VALUES(26127,58472,-6,'Montpelier, North Dakota 58472',18874,23186);
INSERT INTO "django_geo_db_zipcode" VALUES(26128,58474,-6,'Oakes, North Dakota 58474',18875,23187);
INSERT INTO "django_geo_db_zipcode" VALUES(26129,58475,-6,'Pettibone, North Dakota 58475',18876,23188);
INSERT INTO "django_geo_db_zipcode" VALUES(26130,58476,-6,'Pingree, North Dakota 58476',18877,23189);
INSERT INTO "django_geo_db_zipcode" VALUES(26131,58477,-6,'Regan, North Dakota 58477',18878,23190);
INSERT INTO "django_geo_db_zipcode" VALUES(26132,58478,-6,'Robinson, North Dakota 58478',18879,23191);
INSERT INTO "django_geo_db_zipcode" VALUES(26133,58479,-6,'Rogers, North Dakota 58479',18880,23192);
INSERT INTO "django_geo_db_zipcode" VALUES(26134,58480,-6,'Sanborn, North Dakota 58480',18881,23193);
INSERT INTO "django_geo_db_zipcode" VALUES(26135,58481,-6,'Spiritwood, North Dakota 58481',18882,23194);
INSERT INTO "django_geo_db_zipcode" VALUES(26136,58482,-6,'Steele, North Dakota 58482',18883,23195);
INSERT INTO "django_geo_db_zipcode" VALUES(26137,58483,-6,'Streeter, North Dakota 58483',18884,23196);
INSERT INTO "django_geo_db_zipcode" VALUES(26138,58484,-6,'Sutton, North Dakota 58484',18885,23197);
INSERT INTO "django_geo_db_zipcode" VALUES(26139,58486,-6,'Sykeston, North Dakota 58486',18795,23198);
INSERT INTO "django_geo_db_zipcode" VALUES(26140,58487,-6,'Tappen, North Dakota 58487',18886,23199);
INSERT INTO "django_geo_db_zipcode" VALUES(26141,58488,-6,'Tuttle, North Dakota 58488',18887,23200);
INSERT INTO "django_geo_db_zipcode" VALUES(26142,58489,-6,'Venturia, North Dakota 58489',18888,23201);
INSERT INTO "django_geo_db_zipcode" VALUES(26143,58490,-6,'Verona, North Dakota 58490',18889,23202);
INSERT INTO "django_geo_db_zipcode" VALUES(26144,58492,-6,'Wimbledon, North Dakota 58492',18890,23203);
INSERT INTO "django_geo_db_zipcode" VALUES(26145,58494,-6,'Wing, North Dakota 58494',18891,23204);
INSERT INTO "django_geo_db_zipcode" VALUES(26146,58495,-6,'Wishek, North Dakota 58495',18892,23205);
INSERT INTO "django_geo_db_zipcode" VALUES(26147,58496,-6,'Woodworth, North Dakota 58496',18893,23206);
INSERT INTO "django_geo_db_zipcode" VALUES(26148,58497,-6,'Ypsilanti, North Dakota 58497',18894,23207);
INSERT INTO "django_geo_db_zipcode" VALUES(26149,58501,-6,'Bismarck, North Dakota 58501',18895,23208);
INSERT INTO "django_geo_db_zipcode" VALUES(26150,58502,-6,'Bismarck, North Dakota 58502',18895,23209);
INSERT INTO "django_geo_db_zipcode" VALUES(26151,58503,-6,'Bismarck, North Dakota 58503',18895,23210);
INSERT INTO "django_geo_db_zipcode" VALUES(26152,58504,-6,'Bismarck, North Dakota 58504',18895,23211);
INSERT INTO "django_geo_db_zipcode" VALUES(26153,58505,-6,'Bismarck, North Dakota 58505',18895,23212);
INSERT INTO "django_geo_db_zipcode" VALUES(26154,58506,-6,'Bismarck, North Dakota 58506',18895,23213);
INSERT INTO "django_geo_db_zipcode" VALUES(26155,58507,-6,'Bismarck, North Dakota 58507',18895,23213);
INSERT INTO "django_geo_db_zipcode" VALUES(26156,58520,-6,'Almont, North Dakota 58520',18896,23214);
INSERT INTO "django_geo_db_zipcode" VALUES(26157,58521,-6,'Baldwin, North Dakota 58521',18897,23215);
INSERT INTO "django_geo_db_zipcode" VALUES(26158,58523,-6,'Beulah, North Dakota 58523',18898,23216);
INSERT INTO "django_geo_db_zipcode" VALUES(26159,58524,-6,'Braddock, North Dakota 58524',18899,23217);
INSERT INTO "django_geo_db_zipcode" VALUES(26160,58528,-6,'Cannon Ball, North Dakota 58528',18900,23218);
INSERT INTO "django_geo_db_zipcode" VALUES(26161,58529,-7,'Carson, North Dakota 58529',18901,23219);
INSERT INTO "django_geo_db_zipcode" VALUES(26162,58530,-6,'Center, North Dakota 58530',18902,23220);
INSERT INTO "django_geo_db_zipcode" VALUES(26163,58531,-6,'Coleharbor, North Dakota 58531',18903,23221);
INSERT INTO "django_geo_db_zipcode" VALUES(26164,58532,-6,'Driscoll, North Dakota 58532',18904,23222);
INSERT INTO "django_geo_db_zipcode" VALUES(26165,58533,-7,'Elgin, North Dakota 58533',18905,23223);
INSERT INTO "django_geo_db_zipcode" VALUES(26166,58535,-6,'Flasher, North Dakota 58535',18906,23224);
INSERT INTO "django_geo_db_zipcode" VALUES(26167,58538,-6,'Fort Yates, North Dakota 58538',18812,23225);
INSERT INTO "django_geo_db_zipcode" VALUES(26168,58540,-6,'Garrison, North Dakota 58540',18907,23226);
INSERT INTO "django_geo_db_zipcode" VALUES(26169,58541,-7,'Golden Valley, North Dakota 58541',18908,23227);
INSERT INTO "django_geo_db_zipcode" VALUES(26170,58542,-6,'Hague, North Dakota 58542',18909,23228);
INSERT INTO "django_geo_db_zipcode" VALUES(26171,58544,-6,'Hazelton, North Dakota 58544',18910,23229);
INSERT INTO "django_geo_db_zipcode" VALUES(26172,58545,-7,'Hazen, North Dakota 58545',18911,23230);
INSERT INTO "django_geo_db_zipcode" VALUES(26173,58549,-6,'Kintyre, North Dakota 58549',18912,23231);
INSERT INTO "django_geo_db_zipcode" VALUES(26174,58552,-6,'Linton, North Dakota 58552',18913,23232);
INSERT INTO "django_geo_db_zipcode" VALUES(26175,58553,-6,'Mckenzie, North Dakota 58553',18914,23233);
INSERT INTO "django_geo_db_zipcode" VALUES(26176,58554,-6,'Mandan, North Dakota 58554',18915,23234);
INSERT INTO "django_geo_db_zipcode" VALUES(26177,58558,-6,'Menoken, North Dakota 58558',18916,23235);
INSERT INTO "django_geo_db_zipcode" VALUES(26178,58559,-6,'Mercer, North Dakota 58559',18917,23236);
INSERT INTO "django_geo_db_zipcode" VALUES(26179,58560,-6,'Moffit, North Dakota 58560',18918,23237);
INSERT INTO "django_geo_db_zipcode" VALUES(26180,58561,-6,'Napoleon, North Dakota 58561',18919,23238);
INSERT INTO "django_geo_db_zipcode" VALUES(26181,58562,-7,'New Leipzig, North Dakota 58562',18920,23239);
INSERT INTO "django_geo_db_zipcode" VALUES(26182,58563,-6,'New Salem, North Dakota 58563',18921,23240);
INSERT INTO "django_geo_db_zipcode" VALUES(26183,58564,-7,'Raleigh, North Dakota 58564',18922,23241);
INSERT INTO "django_geo_db_zipcode" VALUES(26184,58565,-6,'Riverdale, North Dakota 58565',18923,23242);
INSERT INTO "django_geo_db_zipcode" VALUES(26185,58566,-6,'Saint Anthony, North Dakota 58566',18924,23243);
INSERT INTO "django_geo_db_zipcode" VALUES(26186,58568,-6,'Selfridge, North Dakota 58568',18925,23244);
INSERT INTO "django_geo_db_zipcode" VALUES(26187,58569,-7,'Shields, North Dakota 58569',18926,23245);
INSERT INTO "django_geo_db_zipcode" VALUES(26188,58570,-6,'Solen, North Dakota 58570',18927,23246);
INSERT INTO "django_geo_db_zipcode" VALUES(26189,58571,-7,'Stanton, North Dakota 58571',18928,23247);
INSERT INTO "django_geo_db_zipcode" VALUES(26190,58572,-6,'Sterling, North Dakota 58572',18929,23248);
INSERT INTO "django_geo_db_zipcode" VALUES(26191,58573,-6,'Strasburg, North Dakota 58573',18930,23249);
INSERT INTO "django_geo_db_zipcode" VALUES(26192,58575,-6,'Turtle Lake, North Dakota 58575',18931,23250);
INSERT INTO "django_geo_db_zipcode" VALUES(26193,58576,-6,'Underwood, North Dakota 58576',18932,23251);
INSERT INTO "django_geo_db_zipcode" VALUES(26194,58577,-6,'Washburn, North Dakota 58577',18933,23252);
INSERT INTO "django_geo_db_zipcode" VALUES(26195,58579,-6,'Wilton, North Dakota 58579',18934,23253);
INSERT INTO "django_geo_db_zipcode" VALUES(26196,58580,-7,'Zap, North Dakota 58580',18935,23254);
INSERT INTO "django_geo_db_zipcode" VALUES(26197,58581,-6,'Zeeland, North Dakota 58581',18936,23255);
INSERT INTO "django_geo_db_zipcode" VALUES(26198,58601,-7,'Dickinson, North Dakota 58601',18937,23256);
INSERT INTO "django_geo_db_zipcode" VALUES(26199,58602,-7,'Dickinson, North Dakota 58602',18937,23257);
INSERT INTO "django_geo_db_zipcode" VALUES(26200,58620,-7,'Amidon, North Dakota 58620',18938,23258);
INSERT INTO "django_geo_db_zipcode" VALUES(26201,58621,-7,'Beach, North Dakota 58621',18939,23259);
INSERT INTO "django_geo_db_zipcode" VALUES(26202,58622,-7,'Belfield, North Dakota 58622',18940,23260);
INSERT INTO "django_geo_db_zipcode" VALUES(26203,58623,-7,'Bowman, North Dakota 58623',18941,23261);
INSERT INTO "django_geo_db_zipcode" VALUES(26204,58625,-7,'Dodge, North Dakota 58625',18942,23262);
INSERT INTO "django_geo_db_zipcode" VALUES(26205,58626,-7,'Dunn Center, North Dakota 58626',18943,23263);
INSERT INTO "django_geo_db_zipcode" VALUES(26206,58627,-7,'Fairfield, North Dakota 58627',18944,23264);
INSERT INTO "django_geo_db_zipcode" VALUES(26207,58630,-7,'Gladstone, North Dakota 58630',18945,23265);
INSERT INTO "django_geo_db_zipcode" VALUES(26208,58631,-6,'Glen Ullin, North Dakota 58631',18946,23266);
INSERT INTO "django_geo_db_zipcode" VALUES(26209,58632,-7,'Golva, North Dakota 58632',18947,23267);
INSERT INTO "django_geo_db_zipcode" VALUES(26210,58634,-7,'Grassy Butte, North Dakota 58634',18948,23268);
INSERT INTO "django_geo_db_zipcode" VALUES(26211,58636,-7,'Halliday, North Dakota 58636',18949,23269);
INSERT INTO "django_geo_db_zipcode" VALUES(26212,58638,-6,'Hebron, North Dakota 58638',18950,23270);
INSERT INTO "django_geo_db_zipcode" VALUES(26213,58639,-7,'Hettinger, North Dakota 58639',18951,23271);
INSERT INTO "django_geo_db_zipcode" VALUES(26214,58640,-7,'Killdeer, North Dakota 58640',18952,23272);
INSERT INTO "django_geo_db_zipcode" VALUES(26215,58641,-7,'Lefor, North Dakota 58641',18953,23273);
INSERT INTO "django_geo_db_zipcode" VALUES(26216,58642,-7,'Manning, North Dakota 58642',18954,23274);
INSERT INTO "django_geo_db_zipcode" VALUES(26217,58643,-7,'Marmarth, North Dakota 58643',18955,23275);
INSERT INTO "django_geo_db_zipcode" VALUES(26218,58644,-7,'Marshall, North Dakota 58644',18956,23276);
INSERT INTO "django_geo_db_zipcode" VALUES(26219,58645,-7,'Medora, North Dakota 58645',18957,23277);
INSERT INTO "django_geo_db_zipcode" VALUES(26220,58646,-7,'Mott, North Dakota 58646',18958,23278);
INSERT INTO "django_geo_db_zipcode" VALUES(26221,58647,-7,'New England, North Dakota 58647',18959,23279);
INSERT INTO "django_geo_db_zipcode" VALUES(26222,58649,-7,'Reeder, North Dakota 58649',18960,23280);
INSERT INTO "django_geo_db_zipcode" VALUES(26223,58650,-7,'Regent, North Dakota 58650',18961,23281);
INSERT INTO "django_geo_db_zipcode" VALUES(26224,58651,-7,'Rhame, North Dakota 58651',18962,23282);
INSERT INTO "django_geo_db_zipcode" VALUES(26225,58652,-7,'Richardton, North Dakota 58652',18963,23283);
INSERT INTO "django_geo_db_zipcode" VALUES(26226,58653,-7,'Scranton, North Dakota 58653',18964,23284);
INSERT INTO "django_geo_db_zipcode" VALUES(26227,58654,-7,'Sentinel Butte, North Dakota 58654',18965,23285);
INSERT INTO "django_geo_db_zipcode" VALUES(26228,58655,-7,'South Heart, North Dakota 58655',18966,23286);
INSERT INTO "django_geo_db_zipcode" VALUES(26229,58656,-7,'Taylor, North Dakota 58656',18967,23287);
INSERT INTO "django_geo_db_zipcode" VALUES(26230,58673,-7,'Dodge, North Dakota 58673',18942,23288);
INSERT INTO "django_geo_db_zipcode" VALUES(26231,58701,-6,'Minot, North Dakota 58701',18656,23289);
INSERT INTO "django_geo_db_zipcode" VALUES(26232,58702,-6,'Minot, North Dakota 58702',18656,23290);
INSERT INTO "django_geo_db_zipcode" VALUES(26233,58703,-6,'Minot, North Dakota 58703',18656,23291);
INSERT INTO "django_geo_db_zipcode" VALUES(26234,58704,-6,'Minot AFB, North Dakota 58704',18968,23292);
INSERT INTO "django_geo_db_zipcode" VALUES(26235,58705,-6,'Minot AFB, North Dakota 58705',18968,23293);
INSERT INTO "django_geo_db_zipcode" VALUES(26236,58707,-6,'Minot, North Dakota 58707',18656,23294);
INSERT INTO "django_geo_db_zipcode" VALUES(26237,58710,-6,'Anamoose, North Dakota 58710',18969,23295);
INSERT INTO "django_geo_db_zipcode" VALUES(26238,58711,-6,'Antler, North Dakota 58711',18970,23296);
INSERT INTO "django_geo_db_zipcode" VALUES(26239,58712,-6,'Balfour, North Dakota 58712',18971,23297);
INSERT INTO "django_geo_db_zipcode" VALUES(26240,58713,-6,'Bantry, North Dakota 58713',18972,23298);
INSERT INTO "django_geo_db_zipcode" VALUES(26241,58716,-6,'Benedict, North Dakota 58716',18973,23299);
INSERT INTO "django_geo_db_zipcode" VALUES(26242,58718,-6,'Berthold, North Dakota 58718',18974,23300);
INSERT INTO "django_geo_db_zipcode" VALUES(26243,58721,-6,'Bowbells, North Dakota 58721',18975,23301);
INSERT INTO "django_geo_db_zipcode" VALUES(26244,58722,-6,'Burlington, North Dakota 58722',18976,23302);
INSERT INTO "django_geo_db_zipcode" VALUES(26245,58723,-6,'Butte, North Dakota 58723',18977,23303);
INSERT INTO "django_geo_db_zipcode" VALUES(26246,58725,-6,'Carpio, North Dakota 58725',18978,23304);
INSERT INTO "django_geo_db_zipcode" VALUES(26247,58727,-6,'Columbus, North Dakota 58727',18979,23305);
INSERT INTO "django_geo_db_zipcode" VALUES(26248,58730,-6,'Crosby, North Dakota 58730',18980,23306);
INSERT INTO "django_geo_db_zipcode" VALUES(26249,58731,-6,'Deering, North Dakota 58731',18981,23307);
INSERT INTO "django_geo_db_zipcode" VALUES(26250,58733,-6,'Des Lacs, North Dakota 58733',18982,23308);
INSERT INTO "django_geo_db_zipcode" VALUES(26251,58734,-6,'Donnybrook, North Dakota 58734',18983,23309);
INSERT INTO "django_geo_db_zipcode" VALUES(26252,58735,-6,'Douglas, North Dakota 58735',18984,23310);
INSERT INTO "django_geo_db_zipcode" VALUES(26253,58736,-6,'Drake, North Dakota 58736',18985,23311);
INSERT INTO "django_geo_db_zipcode" VALUES(26254,58737,-6,'Flaxton, North Dakota 58737',18986,23312);
INSERT INTO "django_geo_db_zipcode" VALUES(26255,58740,-6,'Glenburn, North Dakota 58740',18987,23313);
INSERT INTO "django_geo_db_zipcode" VALUES(26256,58741,-6,'Granville, North Dakota 58741',18988,23314);
INSERT INTO "django_geo_db_zipcode" VALUES(26257,58744,-6,'Karlsruhe, North Dakota 58744',18989,23315);
INSERT INTO "django_geo_db_zipcode" VALUES(26258,58746,-6,'Kenmare, North Dakota 58746',18990,23316);
INSERT INTO "django_geo_db_zipcode" VALUES(26259,58747,-6,'Kief, North Dakota 58747',18991,23317);
INSERT INTO "django_geo_db_zipcode" VALUES(26260,58748,-6,'Kramer, North Dakota 58748',18992,23318);
INSERT INTO "django_geo_db_zipcode" VALUES(26261,58750,-6,'Lansford, North Dakota 58750',18993,23319);
INSERT INTO "django_geo_db_zipcode" VALUES(26262,58752,-6,'Lignite, North Dakota 58752',18994,23320);
INSERT INTO "django_geo_db_zipcode" VALUES(26263,58755,-6,'Mcgregor, North Dakota 58755',18995,23321);
INSERT INTO "django_geo_db_zipcode" VALUES(26264,58756,-6,'Makoti, North Dakota 58756',18996,23322);
INSERT INTO "django_geo_db_zipcode" VALUES(26265,58757,-6,'Mandaree, North Dakota 58757',18997,23323);
INSERT INTO "django_geo_db_zipcode" VALUES(26266,58758,-6,'Martin, North Dakota 58758',18998,23324);
INSERT INTO "django_geo_db_zipcode" VALUES(26267,58759,-6,'Max, North Dakota 58759',18999,23325);
INSERT INTO "django_geo_db_zipcode" VALUES(26268,58760,-6,'Maxbass, North Dakota 58760',19000,23326);
INSERT INTO "django_geo_db_zipcode" VALUES(26269,58761,-6,'Mohall, North Dakota 58761',19001,23327);
INSERT INTO "django_geo_db_zipcode" VALUES(26270,58762,-6,'Newburg, North Dakota 58762',19002,23328);
INSERT INTO "django_geo_db_zipcode" VALUES(26271,58763,-6,'New Town, North Dakota 58763',19003,23329);
INSERT INTO "django_geo_db_zipcode" VALUES(26272,58764,-6,'Clay, North Dakota 58764',19004,23330);
INSERT INTO "django_geo_db_zipcode" VALUES(26273,58765,-6,'Noonan, North Dakota 58765',19005,23331);
INSERT INTO "django_geo_db_zipcode" VALUES(26274,58768,-6,'Norwich, North Dakota 58768',19006,23332);
INSERT INTO "django_geo_db_zipcode" VALUES(26275,58769,-6,'Palermo, North Dakota 58769',19007,23333);
INSERT INTO "django_geo_db_zipcode" VALUES(26276,58770,-6,'Parshall, North Dakota 58770',19008,23334);
INSERT INTO "django_geo_db_zipcode" VALUES(26277,58771,-6,'Plaza, North Dakota 58771',19009,23335);
INSERT INTO "django_geo_db_zipcode" VALUES(26278,58772,-6,'Portal, North Dakota 58772',19010,23336);
INSERT INTO "django_geo_db_zipcode" VALUES(26279,58773,-6,'Powers Lake, North Dakota 58773',19011,23337);
INSERT INTO "django_geo_db_zipcode" VALUES(26280,58775,-6,'Roseglen, North Dakota 58775',19012,23338);
INSERT INTO "django_geo_db_zipcode" VALUES(26281,58776,-6,'Ross, North Dakota 58776',19013,23339);
INSERT INTO "django_geo_db_zipcode" VALUES(26282,58778,-6,'Ruso, North Dakota 58778',19014,23340);
INSERT INTO "django_geo_db_zipcode" VALUES(26283,58779,-6,'Ryder, North Dakota 58779',19015,23341);
INSERT INTO "django_geo_db_zipcode" VALUES(26284,58781,-6,'Sawyer, North Dakota 58781',19016,23342);
INSERT INTO "django_geo_db_zipcode" VALUES(26285,58782,-6,'Sherwood, North Dakota 58782',19017,23343);
INSERT INTO "django_geo_db_zipcode" VALUES(26286,58783,-6,'Souris, North Dakota 58783',19018,23344);
INSERT INTO "django_geo_db_zipcode" VALUES(26287,58784,-6,'Stanley, North Dakota 58784',19019,23345);
INSERT INTO "django_geo_db_zipcode" VALUES(26288,58785,-6,'Surrey, North Dakota 58785',19020,23346);
INSERT INTO "django_geo_db_zipcode" VALUES(26289,58787,-6,'Tolley, North Dakota 58787',19021,23347);
INSERT INTO "django_geo_db_zipcode" VALUES(26290,58788,-6,'Towner, North Dakota 58788',19022,23348);
INSERT INTO "django_geo_db_zipcode" VALUES(26291,58789,-6,'Upham, North Dakota 58789',19023,23349);
INSERT INTO "django_geo_db_zipcode" VALUES(26292,58790,-6,'Velva, North Dakota 58790',19024,23350);
INSERT INTO "django_geo_db_zipcode" VALUES(26293,58792,-6,'Voltaire, North Dakota 58792',19025,23351);
INSERT INTO "django_geo_db_zipcode" VALUES(26294,58793,-6,'Westhope, North Dakota 58793',19026,23352);
INSERT INTO "django_geo_db_zipcode" VALUES(26295,58794,-6,'White Earth, North Dakota 58794',19027,23353);
INSERT INTO "django_geo_db_zipcode" VALUES(26296,58795,-6,'Wildrose, North Dakota 58795',19028,23354);
INSERT INTO "django_geo_db_zipcode" VALUES(26297,58801,-6,'Williston, North Dakota 58801',19029,23355);
INSERT INTO "django_geo_db_zipcode" VALUES(26298,58802,-6,'Williston, North Dakota 58802',19029,23356);
INSERT INTO "django_geo_db_zipcode" VALUES(26299,58830,-6,'Alamo, North Dakota 58830',19030,23357);
INSERT INTO "django_geo_db_zipcode" VALUES(26300,58831,-6,'Alexander, North Dakota 58831',19031,23358);
INSERT INTO "django_geo_db_zipcode" VALUES(26301,58832,-6,'Westby, North Dakota 58832',19032,23359);
INSERT INTO "django_geo_db_zipcode" VALUES(26302,58833,-6,'Ambrose, North Dakota 58833',19033,23360);
INSERT INTO "django_geo_db_zipcode" VALUES(26303,58835,-6,'Arnegard, North Dakota 58835',19034,23361);
INSERT INTO "django_geo_db_zipcode" VALUES(26304,58838,-7,'Cartwright, North Dakota 58838',19035,23362);
INSERT INTO "django_geo_db_zipcode" VALUES(26305,58843,-6,'Epping, North Dakota 58843',19036,23363);
INSERT INTO "django_geo_db_zipcode" VALUES(26306,58844,-6,'Fortuna, North Dakota 58844',19037,23364);
INSERT INTO "django_geo_db_zipcode" VALUES(26307,58845,-6,'Grenora, North Dakota 58845',19038,23365);
INSERT INTO "django_geo_db_zipcode" VALUES(26308,58847,-6,'Keene, North Dakota 58847',19039,23366);
INSERT INTO "django_geo_db_zipcode" VALUES(26309,58849,-6,'Ray, North Dakota 58849',19040,23367);
INSERT INTO "django_geo_db_zipcode" VALUES(26310,58852,-6,'Tioga, North Dakota 58852',19041,23368);
INSERT INTO "django_geo_db_zipcode" VALUES(26311,58853,-6,'Trenton, North Dakota 58853',19042,23369);
INSERT INTO "django_geo_db_zipcode" VALUES(26312,58854,-6,'Watford City, North Dakota 58854',19043,23370);
INSERT INTO "django_geo_db_zipcode" VALUES(26313,58856,-6,'Zahl, North Dakota 58856',19044,23371);
INSERT INTO "django_geo_db_zipcode" VALUES(26314,58888,-6,'Garrison, North Dakota 58888',18907,23372);
INSERT INTO "django_geo_db_zipcode" VALUES(26315,58982,-6,'Colquhoun, North Dakota 58982',19045,23373);
INSERT INTO "django_geo_db_zipcode" VALUES(26316,59000,-7,'Roundup, Montana 59000',19046,23374);
INSERT INTO "django_geo_db_zipcode" VALUES(26317,59001,-7,'Absarokee, Montana 59001',19047,23375);
INSERT INTO "django_geo_db_zipcode" VALUES(26318,59002,-7,'Acton, Montana 59002',19048,23376);
INSERT INTO "django_geo_db_zipcode" VALUES(26319,59003,-7,'Ashland, Montana 59003',19049,23377);
INSERT INTO "django_geo_db_zipcode" VALUES(26320,59004,-7,'Ashland, Montana 59004',19049,23378);
INSERT INTO "django_geo_db_zipcode" VALUES(26321,59006,-7,'Ballantine, Montana 59006',19050,23379);
INSERT INTO "django_geo_db_zipcode" VALUES(26322,59007,-7,'Bearcreek, Montana 59007',19051,23380);
INSERT INTO "django_geo_db_zipcode" VALUES(26323,59008,-7,'Belfry, Montana 59008',19052,23381);
INSERT INTO "django_geo_db_zipcode" VALUES(26324,59010,-7,'Bighorn, Montana 59010',19053,23382);
INSERT INTO "django_geo_db_zipcode" VALUES(26325,59011,-7,'Big Timber, Montana 59011',19054,23383);
INSERT INTO "django_geo_db_zipcode" VALUES(26326,59012,-7,'Birney, Montana 59012',19055,23384);
INSERT INTO "django_geo_db_zipcode" VALUES(26327,59013,-7,'Boyd, Montana 59013',19056,23385);
INSERT INTO "django_geo_db_zipcode" VALUES(26328,59014,-7,'Bridger, Montana 59014',19057,23386);
INSERT INTO "django_geo_db_zipcode" VALUES(26329,59015,-7,'Broadview, Montana 59015',19058,23387);
INSERT INTO "django_geo_db_zipcode" VALUES(26330,59016,-7,'Busby, Montana 59016',19059,23388);
INSERT INTO "django_geo_db_zipcode" VALUES(26331,59018,-7,'Clyde Park, Montana 59018',19060,23389);
INSERT INTO "django_geo_db_zipcode" VALUES(26332,59019,-7,'Columbus, Montana 59019',19061,23390);
INSERT INTO "django_geo_db_zipcode" VALUES(26333,59020,-7,'Cooke City, Montana 59020',19062,23391);
INSERT INTO "django_geo_db_zipcode" VALUES(26334,59022,-7,'Crow Agency, Montana 59022',19063,23392);
INSERT INTO "django_geo_db_zipcode" VALUES(26335,59024,-7,'Custer, Montana 59024',19064,23393);
INSERT INTO "django_geo_db_zipcode" VALUES(26336,59025,-7,'Decker, Montana 59025',19065,23394);
INSERT INTO "django_geo_db_zipcode" VALUES(26337,59026,-7,'Edgar, Montana 59026',19066,23395);
INSERT INTO "django_geo_db_zipcode" VALUES(26338,59027,-7,'Emigrant, Montana 59027',19067,23396);
INSERT INTO "django_geo_db_zipcode" VALUES(26339,59028,-7,'Fishtail, Montana 59028',19068,23397);
INSERT INTO "django_geo_db_zipcode" VALUES(26340,59029,-7,'Fromberg, Montana 59029',19069,23398);
INSERT INTO "django_geo_db_zipcode" VALUES(26341,59030,-7,'Gardiner, Montana 59030',19070,23399);
INSERT INTO "django_geo_db_zipcode" VALUES(26342,59031,-7,'Garryowen, Montana 59031',19071,23400);
INSERT INTO "django_geo_db_zipcode" VALUES(26343,59032,-7,'Grass Range, Montana 59032',19072,23401);
INSERT INTO "django_geo_db_zipcode" VALUES(26344,59033,-7,'Greycliff, Montana 59033',19073,23402);
INSERT INTO "django_geo_db_zipcode" VALUES(26345,59034,-7,'Hardin, Montana 59034',19074,23403);
INSERT INTO "django_geo_db_zipcode" VALUES(26346,59035,-7,'Yellowtail, Montana 59035',19075,23404);
INSERT INTO "django_geo_db_zipcode" VALUES(26347,59036,-7,'Harlowton, Montana 59036',19076,23405);
INSERT INTO "django_geo_db_zipcode" VALUES(26348,59037,-7,'Huntley, Montana 59037',19077,23406);
INSERT INTO "django_geo_db_zipcode" VALUES(26349,59038,-7,'Hysham, Montana 59038',19078,23407);
INSERT INTO "django_geo_db_zipcode" VALUES(26350,59039,-7,'Ingomar, Montana 59039',19079,23408);
INSERT INTO "django_geo_db_zipcode" VALUES(26351,59041,-7,'Joliet, Montana 59041',19080,23409);
INSERT INTO "django_geo_db_zipcode" VALUES(26352,59043,-7,'Lame Deer, Montana 59043',19081,23410);
INSERT INTO "django_geo_db_zipcode" VALUES(26353,59044,-7,'Laurel, Montana 59044',19082,23411);
INSERT INTO "django_geo_db_zipcode" VALUES(26354,59046,-7,'Lavina, Montana 59046',19083,23412);
INSERT INTO "django_geo_db_zipcode" VALUES(26355,59047,-7,'Livingston, Montana 59047',19084,23413);
INSERT INTO "django_geo_db_zipcode" VALUES(26356,59050,-7,'Lodge Grass, Montana 59050',19085,23414);
INSERT INTO "django_geo_db_zipcode" VALUES(26357,59052,-7,'McLeod, Montana 59052',19086,23415);
INSERT INTO "django_geo_db_zipcode" VALUES(26358,59053,-7,'Martinsdale, Montana 59053',19087,23416);
INSERT INTO "django_geo_db_zipcode" VALUES(26359,59054,-7,'Melstone, Montana 59054',19088,23417);
INSERT INTO "django_geo_db_zipcode" VALUES(26360,59055,-7,'Melville, Montana 59055',19089,23418);
INSERT INTO "django_geo_db_zipcode" VALUES(26361,59057,-7,'Molt, Montana 59057',19090,23419);
INSERT INTO "django_geo_db_zipcode" VALUES(26362,59058,-7,'Mosby, Montana 59058',19091,23420);
INSERT INTO "django_geo_db_zipcode" VALUES(26363,59059,-7,'Musselshell, Montana 59059',19092,23421);
INSERT INTO "django_geo_db_zipcode" VALUES(26364,59061,-7,'Nye, Montana 59061',19093,23422);
INSERT INTO "django_geo_db_zipcode" VALUES(26365,59062,-7,'Otter, Montana 59062',19094,23423);
INSERT INTO "django_geo_db_zipcode" VALUES(26366,59063,-7,'Park City, Montana 59063',19095,23424);
INSERT INTO "django_geo_db_zipcode" VALUES(26367,59064,-7,'Pompeys Pillar, Montana 59064',19096,23425);
INSERT INTO "django_geo_db_zipcode" VALUES(26368,59065,-7,'Pray, Montana 59065',19097,23426);
INSERT INTO "django_geo_db_zipcode" VALUES(26369,59066,-7,'Pryor, Montana 59066',19098,23427);
INSERT INTO "django_geo_db_zipcode" VALUES(26370,59067,-7,'Rapelje, Montana 59067',19099,23428);
INSERT INTO "django_geo_db_zipcode" VALUES(26371,59068,-7,'Red Lodge, Montana 59068',19100,23429);
INSERT INTO "django_geo_db_zipcode" VALUES(26372,59069,-7,'Reed Point, Montana 59069',19101,23430);
INSERT INTO "django_geo_db_zipcode" VALUES(26373,59070,-7,'Roberts, Montana 59070',19102,23431);
INSERT INTO "django_geo_db_zipcode" VALUES(26374,59071,-7,'Roscoe, Montana 59071',19103,23432);
INSERT INTO "django_geo_db_zipcode" VALUES(26375,59072,-7,'Roundup, Montana 59072',19046,23433);
INSERT INTO "django_geo_db_zipcode" VALUES(26376,59073,-7,'Roundup, Montana 59073',19046,23434);
INSERT INTO "django_geo_db_zipcode" VALUES(26377,59074,-7,'Ryegate, Montana 59074',19104,23435);
INSERT INTO "django_geo_db_zipcode" VALUES(26378,59075,-7,'Saint Xavier, Montana 59075',19105,23436);
INSERT INTO "django_geo_db_zipcode" VALUES(26379,59076,-7,'Sanders, Montana 59076',19106,23437);
INSERT INTO "django_geo_db_zipcode" VALUES(26380,59077,-7,'Sand Springs, Montana 59077',19107,23438);
INSERT INTO "django_geo_db_zipcode" VALUES(26381,59078,-7,'Shawmut, Montana 59078',19108,23439);
INSERT INTO "django_geo_db_zipcode" VALUES(26382,59079,-7,'Shepherd, Montana 59079',19109,23440);
INSERT INTO "django_geo_db_zipcode" VALUES(26383,59081,-7,'Silver Gate, Montana 59081',19110,23441);
INSERT INTO "django_geo_db_zipcode" VALUES(26384,59082,-7,'Springdale, Montana 59082',19111,23442);
INSERT INTO "django_geo_db_zipcode" VALUES(26385,59083,-7,'Sumatra, Montana 59083',19112,23378);
INSERT INTO "django_geo_db_zipcode" VALUES(26386,59084,-7,'Teigen, Montana 59084',19113,23443);
INSERT INTO "django_geo_db_zipcode" VALUES(26387,59085,-7,'Two Dot, Montana 59085',19114,23444);
INSERT INTO "django_geo_db_zipcode" VALUES(26388,59086,-7,'Wilsall, Montana 59086',19115,23445);
INSERT INTO "django_geo_db_zipcode" VALUES(26389,59087,-7,'Winnett, Montana 59087',19116,23446);
INSERT INTO "django_geo_db_zipcode" VALUES(26390,59088,-7,'Worden, Montana 59088',19117,23447);
INSERT INTO "django_geo_db_zipcode" VALUES(26391,59089,-7,'Wyola, Montana 59089',19118,23448);
INSERT INTO "django_geo_db_zipcode" VALUES(26392,59101,-7,'Billings, Montana 59101',19119,23449);
INSERT INTO "django_geo_db_zipcode" VALUES(26393,59102,-7,'Billings, Montana 59102',19119,23450);
INSERT INTO "django_geo_db_zipcode" VALUES(26394,59103,-7,'Billings, Montana 59103',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26395,59104,-7,'Billings, Montana 59104',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26396,59105,-7,'Billings, Montana 59105',19119,23452);
INSERT INTO "django_geo_db_zipcode" VALUES(26397,59106,-7,'Billings, Montana 59106',19119,23453);
INSERT INTO "django_geo_db_zipcode" VALUES(26398,59107,-7,'Billings, Montana 59107',19119,23454);
INSERT INTO "django_geo_db_zipcode" VALUES(26399,59108,-7,'Billings, Montana 59108',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26400,59111,-7,'Billings, Montana 59111',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26401,59112,-7,'Billings, Montana 59112',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26402,59114,-7,'Billings, Montana 59114',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26403,59115,-7,'Billings, Montana 59115',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26404,59116,-7,'Billings, Montana 59116',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26405,59117,-7,'Billings, Montana 59117',19119,23451);
INSERT INTO "django_geo_db_zipcode" VALUES(26406,59201,-7,'Wolf Point, Montana 59201',19120,23455);
INSERT INTO "django_geo_db_zipcode" VALUES(26407,59211,-7,'Antelope, Montana 59211',19121,23456);
INSERT INTO "django_geo_db_zipcode" VALUES(26408,59212,-7,'Bainville, Montana 59212',19122,23457);
INSERT INTO "django_geo_db_zipcode" VALUES(26409,59213,-7,'Brockton, Montana 59213',19123,23458);
INSERT INTO "django_geo_db_zipcode" VALUES(26410,59214,-7,'Brockway, Montana 59214',19124,23459);
INSERT INTO "django_geo_db_zipcode" VALUES(26411,59215,-7,'Circle, Montana 59215',19125,23460);
INSERT INTO "django_geo_db_zipcode" VALUES(26412,59217,-7,'Crane, Montana 59217',19126,23461);
INSERT INTO "django_geo_db_zipcode" VALUES(26413,59218,-7,'Culbertson, Montana 59218',19127,23462);
INSERT INTO "django_geo_db_zipcode" VALUES(26414,59219,-7,'Dagmar, Montana 59219',19128,23463);
INSERT INTO "django_geo_db_zipcode" VALUES(26415,59221,-7,'Fairview, Montana 59221',19129,23464);
INSERT INTO "django_geo_db_zipcode" VALUES(26416,59222,-7,'Flaxville, Montana 59222',19130,23465);
INSERT INTO "django_geo_db_zipcode" VALUES(26417,59223,-7,'Fort Peck, Montana 59223',19131,23466);
INSERT INTO "django_geo_db_zipcode" VALUES(26418,59225,-7,'Frazer, Montana 59225',19132,23467);
INSERT INTO "django_geo_db_zipcode" VALUES(26419,59226,-7,'Froid, Montana 59226',19133,23468);
INSERT INTO "django_geo_db_zipcode" VALUES(26420,59230,-7,'Glasgow, Montana 59230',19134,23469);
INSERT INTO "django_geo_db_zipcode" VALUES(26421,59231,-7,'Saint Marie, Montana 59231',19135,23470);
INSERT INTO "django_geo_db_zipcode" VALUES(26422,59240,-7,'Glentana, Montana 59240',19136,23471);
INSERT INTO "django_geo_db_zipcode" VALUES(26423,59241,-7,'Hinsdale, Montana 59241',19137,23472);
INSERT INTO "django_geo_db_zipcode" VALUES(26424,59242,-7,'Homestead, Montana 59242',19138,23473);
INSERT INTO "django_geo_db_zipcode" VALUES(26425,59243,-7,'Lambert, Montana 59243',19139,23474);
INSERT INTO "django_geo_db_zipcode" VALUES(26426,59244,-7,'Larslan, Montana 59244',19140,23475);
INSERT INTO "django_geo_db_zipcode" VALUES(26427,59245,-7,'McCabe, Montana 59245',19141,23476);
INSERT INTO "django_geo_db_zipcode" VALUES(26428,59247,-7,'Medicine Lake, Montana 59247',19142,23477);
INSERT INTO "django_geo_db_zipcode" VALUES(26429,59248,-7,'Nashua, Montana 59248',19143,23478);
INSERT INTO "django_geo_db_zipcode" VALUES(26430,59250,-7,'Opheim, Montana 59250',19144,23479);
INSERT INTO "django_geo_db_zipcode" VALUES(26431,59252,-7,'Outlook, Montana 59252',19145,23480);
INSERT INTO "django_geo_db_zipcode" VALUES(26432,59253,-7,'Peerless, Montana 59253',19146,23481);
INSERT INTO "django_geo_db_zipcode" VALUES(26433,59254,-7,'Plentywood, Montana 59254',19147,23482);
INSERT INTO "django_geo_db_zipcode" VALUES(26434,59255,-7,'Poplar, Montana 59255',19148,23483);
INSERT INTO "django_geo_db_zipcode" VALUES(26435,59256,-7,'Raymond, Montana 59256',19149,23484);
INSERT INTO "django_geo_db_zipcode" VALUES(26436,59257,-7,'Redstone, Montana 59257',19150,23485);
INSERT INTO "django_geo_db_zipcode" VALUES(26437,59258,-7,'Reserve, Montana 59258',19151,23486);
INSERT INTO "django_geo_db_zipcode" VALUES(26438,59259,-7,'Richey, Montana 59259',19152,23487);
INSERT INTO "django_geo_db_zipcode" VALUES(26439,59260,-7,'Richland, Montana 59260',19153,23488);
INSERT INTO "django_geo_db_zipcode" VALUES(26440,59261,-7,'Saco, Montana 59261',19154,23489);
INSERT INTO "django_geo_db_zipcode" VALUES(26441,59262,-7,'Savage, Montana 59262',19155,23490);
INSERT INTO "django_geo_db_zipcode" VALUES(26442,59263,-7,'Scobey, Montana 59263',19156,23491);
INSERT INTO "django_geo_db_zipcode" VALUES(26443,59270,-7,'Sidney, Montana 59270',19157,23492);
INSERT INTO "django_geo_db_zipcode" VALUES(26444,59273,-7,'Vandalia, Montana 59273',19158,23471);
INSERT INTO "django_geo_db_zipcode" VALUES(26445,59274,-7,'Vida, Montana 59274',19159,23493);
INSERT INTO "django_geo_db_zipcode" VALUES(26446,59275,-7,'Westby, Montana 59275',19160,23494);
INSERT INTO "django_geo_db_zipcode" VALUES(26447,59276,-7,'Whitetail, Montana 59276',19161,23495);
INSERT INTO "django_geo_db_zipcode" VALUES(26448,59301,-7,'Miles City, Montana 59301',19162,23496);
INSERT INTO "django_geo_db_zipcode" VALUES(26449,59311,-7,'Alzada, Montana 59311',19163,23497);
INSERT INTO "django_geo_db_zipcode" VALUES(26450,59312,-7,'Angela, Montana 59312',19164,23378);
INSERT INTO "django_geo_db_zipcode" VALUES(26451,59313,-7,'Baker, Montana 59313',19165,23498);
INSERT INTO "django_geo_db_zipcode" VALUES(26452,59314,-7,'Biddle, Montana 59314',19166,23499);
INSERT INTO "django_geo_db_zipcode" VALUES(26453,59315,-7,'Bloomfield, Montana 59315',19167,23500);
INSERT INTO "django_geo_db_zipcode" VALUES(26454,59316,-7,'Boyes, Montana 59316',19168,23501);
INSERT INTO "django_geo_db_zipcode" VALUES(26455,59317,-7,'Broadus, Montana 59317',19169,23502);
INSERT INTO "django_geo_db_zipcode" VALUES(26456,59318,-7,'Brusett, Montana 59318',19170,23503);
INSERT INTO "django_geo_db_zipcode" VALUES(26457,59319,-7,'Capitol, Montana 59319',19171,23501);
INSERT INTO "django_geo_db_zipcode" VALUES(26458,59322,-7,'Cohagen, Montana 59322',19172,23504);
INSERT INTO "django_geo_db_zipcode" VALUES(26459,59323,-7,'Colstrip, Montana 59323',19173,23505);
INSERT INTO "django_geo_db_zipcode" VALUES(26460,59324,-7,'Ekalaka, Montana 59324',19174,23506);
INSERT INTO "django_geo_db_zipcode" VALUES(26461,59326,-7,'Fallon, Montana 59326',19175,23507);
INSERT INTO "django_geo_db_zipcode" VALUES(26462,59327,-7,'Forsyth, Montana 59327',19176,23508);
INSERT INTO "django_geo_db_zipcode" VALUES(26463,59330,-7,'Glendive, Montana 59330',19177,23509);
INSERT INTO "django_geo_db_zipcode" VALUES(26464,59332,-7,'Hammond, Montana 59332',19178,23510);
INSERT INTO "django_geo_db_zipcode" VALUES(26465,59333,-7,'Hathaway, Montana 59333',19179,23511);
INSERT INTO "django_geo_db_zipcode" VALUES(26466,59336,-7,'Ismay, Montana 59336',19180,23512);
INSERT INTO "django_geo_db_zipcode" VALUES(26467,59337,-7,'Jordan, Montana 59337',19181,23513);
INSERT INTO "django_geo_db_zipcode" VALUES(26468,59338,-7,'Kinsey, Montana 59338',19182,23514);
INSERT INTO "django_geo_db_zipcode" VALUES(26469,59339,-7,'Lindsay, Montana 59339',19183,23515);
INSERT INTO "django_geo_db_zipcode" VALUES(26470,59341,-7,'Mildred, Montana 59341',19184,23516);
INSERT INTO "django_geo_db_zipcode" VALUES(26471,59343,-7,'Olive, Montana 59343',19185,23517);
INSERT INTO "django_geo_db_zipcode" VALUES(26472,59344,-7,'Plevna, Montana 59344',19186,23518);
INSERT INTO "django_geo_db_zipcode" VALUES(26473,59345,-7,'Powderville, Montana 59345',19187,23519);
INSERT INTO "django_geo_db_zipcode" VALUES(26474,59347,-7,'Rosebud, Montana 59347',19188,23520);
INSERT INTO "django_geo_db_zipcode" VALUES(26475,59348,-7,'Sonnette, Montana 59348',19189,23521);
INSERT INTO "django_geo_db_zipcode" VALUES(26476,59349,-7,'Terry, Montana 59349',19190,23522);
INSERT INTO "django_geo_db_zipcode" VALUES(26477,59351,-7,'Volborg, Montana 59351',19191,23523);
INSERT INTO "django_geo_db_zipcode" VALUES(26478,59353,-7,'Wibaux, Montana 59353',19192,23524);
INSERT INTO "django_geo_db_zipcode" VALUES(26479,59354,-7,'Willard, Montana 59354',19193,23525);
INSERT INTO "django_geo_db_zipcode" VALUES(26480,59400,-7,'Shelby, Montana 59400',19194,23526);
INSERT INTO "django_geo_db_zipcode" VALUES(26481,59401,-7,'Great Falls, Montana 59401',19195,23527);
INSERT INTO "django_geo_db_zipcode" VALUES(26482,59402,-7,'Malmstrom A F B, Montana 59402',19196,23528);
INSERT INTO "django_geo_db_zipcode" VALUES(26483,59403,-7,'Great Falls, Montana 59403',19195,23529);
INSERT INTO "django_geo_db_zipcode" VALUES(26484,59404,-7,'Great Falls, Montana 59404',19195,23530);
INSERT INTO "django_geo_db_zipcode" VALUES(26485,59405,-7,'Great Falls, Montana 59405',19195,23531);
INSERT INTO "django_geo_db_zipcode" VALUES(26486,59406,-7,'Great Falls, Montana 59406',19195,23532);
INSERT INTO "django_geo_db_zipcode" VALUES(26487,59410,-7,'Augusta, Montana 59410',19197,23533);
INSERT INTO "django_geo_db_zipcode" VALUES(26488,59411,-7,'Babb, Montana 59411',19198,23534);
INSERT INTO "django_geo_db_zipcode" VALUES(26489,59412,-7,'Belt, Montana 59412',19199,23535);
INSERT INTO "django_geo_db_zipcode" VALUES(26490,59414,-7,'Black Eagle, Montana 59414',19200,23536);
INSERT INTO "django_geo_db_zipcode" VALUES(26491,59416,-7,'Brady, Montana 59416',19201,23537);
INSERT INTO "django_geo_db_zipcode" VALUES(26492,59417,-7,'Browning, Montana 59417',19202,23538);
INSERT INTO "django_geo_db_zipcode" VALUES(26493,59418,-7,'Buffalo, Montana 59418',19203,23539);
INSERT INTO "django_geo_db_zipcode" VALUES(26494,59419,-7,'Bynum, Montana 59419',19204,23540);
INSERT INTO "django_geo_db_zipcode" VALUES(26495,59420,-7,'Carter, Montana 59420',19205,23541);
INSERT INTO "django_geo_db_zipcode" VALUES(26496,59421,-7,'Cascade, Montana 59421',19206,23542);
INSERT INTO "django_geo_db_zipcode" VALUES(26497,59422,-7,'Choteau, Montana 59422',19207,23543);
INSERT INTO "django_geo_db_zipcode" VALUES(26498,59424,-7,'Coffee Creek, Montana 59424',19208,23544);
INSERT INTO "django_geo_db_zipcode" VALUES(26499,59425,-7,'Conrad, Montana 59425',19209,23545);
INSERT INTO "django_geo_db_zipcode" VALUES(26500,59427,-7,'Cut Bank, Montana 59427',19210,23546);
INSERT INTO "django_geo_db_zipcode" VALUES(26501,59430,-7,'Denton, Montana 59430',19211,23547);
INSERT INTO "django_geo_db_zipcode" VALUES(26502,59432,-7,'Dupuyer, Montana 59432',19212,23548);
INSERT INTO "django_geo_db_zipcode" VALUES(26503,59433,-7,'Dutton, Montana 59433',19213,23549);
INSERT INTO "django_geo_db_zipcode" VALUES(26504,59434,-7,'East Glacier Park, Montana 59434',19214,23550);
INSERT INTO "django_geo_db_zipcode" VALUES(26505,59435,-7,'Ethridge, Montana 59435',19215,23551);
INSERT INTO "django_geo_db_zipcode" VALUES(26506,59436,-7,'Fairfield, Montana 59436',19216,23552);
INSERT INTO "django_geo_db_zipcode" VALUES(26507,59440,-7,'Floweree, Montana 59440',19217,23553);
INSERT INTO "django_geo_db_zipcode" VALUES(26508,59441,-7,'Forestgrove, Montana 59441',19218,23554);
INSERT INTO "django_geo_db_zipcode" VALUES(26509,59442,-7,'Fort Benton, Montana 59442',19219,23555);
INSERT INTO "django_geo_db_zipcode" VALUES(26510,59443,-7,'Fort Shaw, Montana 59443',19220,23556);
INSERT INTO "django_geo_db_zipcode" VALUES(26511,59444,-7,'Galata, Montana 59444',19221,23557);
INSERT INTO "django_geo_db_zipcode" VALUES(26512,59445,-7,'Garneill, Montana 59445',19222,23558);
INSERT INTO "django_geo_db_zipcode" VALUES(26513,59446,-7,'Geraldine, Montana 59446',19223,23559);
INSERT INTO "django_geo_db_zipcode" VALUES(26514,59447,-7,'Geyser, Montana 59447',19224,23560);
INSERT INTO "django_geo_db_zipcode" VALUES(26515,59448,-7,'Heart Butte, Montana 59448',19225,23561);
INSERT INTO "django_geo_db_zipcode" VALUES(26516,59450,-7,'Highwood, Montana 59450',19226,23562);
INSERT INTO "django_geo_db_zipcode" VALUES(26517,59451,-7,'Hilger, Montana 59451',19227,23563);
INSERT INTO "django_geo_db_zipcode" VALUES(26518,59452,-7,'Hobson, Montana 59452',19228,23564);
INSERT INTO "django_geo_db_zipcode" VALUES(26519,59453,-7,'Judith Gap, Montana 59453',19229,23565);
INSERT INTO "django_geo_db_zipcode" VALUES(26520,59454,-7,'Kevin, Montana 59454',19230,23566);
INSERT INTO "django_geo_db_zipcode" VALUES(26521,59456,-7,'Ledger, Montana 59456',19231,23567);
INSERT INTO "django_geo_db_zipcode" VALUES(26522,59457,-7,'Lewistown, Montana 59457',19232,23568);
INSERT INTO "django_geo_db_zipcode" VALUES(26523,59460,-7,'Loma, Montana 59460',19233,23569);
INSERT INTO "django_geo_db_zipcode" VALUES(26524,59461,-7,'Lothair, Montana 59461',19234,23551);
INSERT INTO "django_geo_db_zipcode" VALUES(26525,59462,-7,'Moccasin, Montana 59462',19235,23570);
INSERT INTO "django_geo_db_zipcode" VALUES(26526,59463,-7,'Monarch, Montana 59463',19236,23571);
INSERT INTO "django_geo_db_zipcode" VALUES(26527,59464,-7,'Moore, Montana 59464',19237,23572);
INSERT INTO "django_geo_db_zipcode" VALUES(26528,59465,-7,'Neihart, Montana 59465',19238,23573);
INSERT INTO "django_geo_db_zipcode" VALUES(26529,59466,-7,'Oilmont, Montana 59466',19239,23574);
INSERT INTO "django_geo_db_zipcode" VALUES(26530,59467,-7,'Pendroy, Montana 59467',19240,23575);
INSERT INTO "django_geo_db_zipcode" VALUES(26531,59468,-7,'Power, Montana 59468',19241,23576);
INSERT INTO "django_geo_db_zipcode" VALUES(26532,59469,-7,'Raynesford, Montana 59469',19242,23577);
INSERT INTO "django_geo_db_zipcode" VALUES(26533,59471,-7,'Roy, Montana 59471',19243,23578);
INSERT INTO "django_geo_db_zipcode" VALUES(26534,59472,-7,'Sand Coulee, Montana 59472',19244,23579);
INSERT INTO "django_geo_db_zipcode" VALUES(26535,59473,-7,'Santa Rita, Montana 59473',19245,23580);
INSERT INTO "django_geo_db_zipcode" VALUES(26536,59474,-7,'Shelby, Montana 59474',19194,23581);
INSERT INTO "django_geo_db_zipcode" VALUES(26537,59477,-7,'Simms, Montana 59477',19246,23582);
INSERT INTO "django_geo_db_zipcode" VALUES(26538,59479,-7,'Stanford, Montana 59479',19247,23583);
INSERT INTO "django_geo_db_zipcode" VALUES(26539,59480,-7,'Stockett, Montana 59480',19248,23584);
INSERT INTO "django_geo_db_zipcode" VALUES(26540,59482,-7,'Sunburst, Montana 59482',19249,23585);
INSERT INTO "django_geo_db_zipcode" VALUES(26541,59483,-7,'Sun River, Montana 59483',19250,23586);
INSERT INTO "django_geo_db_zipcode" VALUES(26542,59484,-7,'Sweet Grass, Montana 59484',19251,23587);
INSERT INTO "django_geo_db_zipcode" VALUES(26543,59485,-7,'Ulm, Montana 59485',19252,23588);
INSERT INTO "django_geo_db_zipcode" VALUES(26544,59486,-7,'Valier, Montana 59486',19253,23589);
INSERT INTO "django_geo_db_zipcode" VALUES(26545,59487,-7,'Vaughn, Montana 59487',19254,23590);
INSERT INTO "django_geo_db_zipcode" VALUES(26546,59489,-7,'Winifred, Montana 59489',19255,23591);
INSERT INTO "django_geo_db_zipcode" VALUES(26547,59500,-7,'Havre, Montana 59500',19256,23592);
INSERT INTO "django_geo_db_zipcode" VALUES(26548,59501,-7,'Havre, Montana 59501',19256,23593);
INSERT INTO "django_geo_db_zipcode" VALUES(26549,59520,-7,'Big Sandy, Montana 59520',19257,23594);
INSERT INTO "django_geo_db_zipcode" VALUES(26550,59521,-7,'Box Elder, Montana 59521',19258,23595);
INSERT INTO "django_geo_db_zipcode" VALUES(26551,59522,-7,'Chester, Montana 59522',19259,23596);
INSERT INTO "django_geo_db_zipcode" VALUES(26552,59523,-7,'Chinook, Montana 59523',19260,23597);
INSERT INTO "django_geo_db_zipcode" VALUES(26553,59524,-7,'Dodson, Montana 59524',19261,23598);
INSERT INTO "django_geo_db_zipcode" VALUES(26554,59525,-7,'Gildford, Montana 59525',19262,23599);
INSERT INTO "django_geo_db_zipcode" VALUES(26555,59526,-7,'Harlem, Montana 59526',19263,23600);
INSERT INTO "django_geo_db_zipcode" VALUES(26556,59527,-7,'Hays, Montana 59527',19264,23601);
INSERT INTO "django_geo_db_zipcode" VALUES(26557,59528,-7,'Hingham, Montana 59528',19265,23602);
INSERT INTO "django_geo_db_zipcode" VALUES(26558,59529,-7,'Hogeland, Montana 59529',19266,23603);
INSERT INTO "django_geo_db_zipcode" VALUES(26559,59530,-7,'Inverness, Montana 59530',19267,23604);
INSERT INTO "django_geo_db_zipcode" VALUES(26560,59531,-7,'Joplin, Montana 59531',19268,23605);
INSERT INTO "django_geo_db_zipcode" VALUES(26561,59532,-7,'Kremlin, Montana 59532',19269,23606);
INSERT INTO "django_geo_db_zipcode" VALUES(26562,59535,-7,'Lloyd, Montana 59535',19270,23607);
INSERT INTO "django_geo_db_zipcode" VALUES(26563,59537,-7,'Loring, Montana 59537',19271,23608);
INSERT INTO "django_geo_db_zipcode" VALUES(26564,59538,-7,'Malta, Montana 59538',19272,23609);
INSERT INTO "django_geo_db_zipcode" VALUES(26565,59540,-7,'Rudyard, Montana 59540',19273,23610);
INSERT INTO "django_geo_db_zipcode" VALUES(26566,59542,-7,'Turner, Montana 59542',19274,23611);
INSERT INTO "django_geo_db_zipcode" VALUES(26567,59544,-7,'Whitewater, Montana 59544',19275,23612);
INSERT INTO "django_geo_db_zipcode" VALUES(26568,59545,-7,'Whitlash, Montana 59545',19276,23613);
INSERT INTO "django_geo_db_zipcode" VALUES(26569,59546,-7,'Zortman, Montana 59546',19277,23614);
INSERT INTO "django_geo_db_zipcode" VALUES(26570,59547,-7,'Zurich, Montana 59547',19278,23615);
INSERT INTO "django_geo_db_zipcode" VALUES(26571,59601,-7,'Helena, Montana 59601',19279,23616);
INSERT INTO "django_geo_db_zipcode" VALUES(26572,59602,-7,'Helena, Montana 59602',19279,23617);
INSERT INTO "django_geo_db_zipcode" VALUES(26573,59604,-7,'Helena, Montana 59604',19279,23618);
INSERT INTO "django_geo_db_zipcode" VALUES(26574,59620,-7,'Helena, Montana 59620',19279,23619);
INSERT INTO "django_geo_db_zipcode" VALUES(26575,59623,-7,'Helena, Montana 59623',19279,23620);
INSERT INTO "django_geo_db_zipcode" VALUES(26576,59624,-7,'Helena, Montana 59624',19279,23621);
INSERT INTO "django_geo_db_zipcode" VALUES(26577,59625,-7,'Helena, Montana 59625',19279,23622);
INSERT INTO "django_geo_db_zipcode" VALUES(26578,59626,-7,'Helena, Montana 59626',19279,23619);
INSERT INTO "django_geo_db_zipcode" VALUES(26579,59631,-7,'Basin, Montana 59631',19280,23623);
INSERT INTO "django_geo_db_zipcode" VALUES(26580,59632,-7,'Boulder, Montana 59632',19281,23624);
INSERT INTO "django_geo_db_zipcode" VALUES(26581,59633,-7,'Canyon Creek, Montana 59633',19282,23625);
INSERT INTO "django_geo_db_zipcode" VALUES(26582,59634,-7,'Clancy, Montana 59634',19283,23626);
INSERT INTO "django_geo_db_zipcode" VALUES(26583,59635,-7,'East Helena, Montana 59635',19284,23627);
INSERT INTO "django_geo_db_zipcode" VALUES(26584,59636,-7,'Fort Harrison, Montana 59636',19285,23628);
INSERT INTO "django_geo_db_zipcode" VALUES(26585,59638,-7,'Jefferson City, Montana 59638',19286,23629);
INSERT INTO "django_geo_db_zipcode" VALUES(26586,59639,-7,'Lincoln, Montana 59639',19287,23630);
INSERT INTO "django_geo_db_zipcode" VALUES(26587,59640,-7,'Marysville, Montana 59640',19288,23631);
INSERT INTO "django_geo_db_zipcode" VALUES(26588,59641,-7,'Radersburg, Montana 59641',19289,23632);
INSERT INTO "django_geo_db_zipcode" VALUES(26589,59642,-7,'Ringling, Montana 59642',19290,23633);
INSERT INTO "django_geo_db_zipcode" VALUES(26590,59643,-7,'Toston, Montana 59643',19291,23634);
INSERT INTO "django_geo_db_zipcode" VALUES(26591,59644,-7,'Townsend, Montana 59644',19292,23635);
INSERT INTO "django_geo_db_zipcode" VALUES(26592,59645,-7,'White Sulphur Springs, Montana 59645',19293,23636);
INSERT INTO "django_geo_db_zipcode" VALUES(26593,59647,-7,'Winston, Montana 59647',19294,23637);
INSERT INTO "django_geo_db_zipcode" VALUES(26594,59648,-7,'Wolf Creek, Montana 59648',19295,23638);
INSERT INTO "django_geo_db_zipcode" VALUES(26595,59701,-7,'Butte, Montana 59701',19296,23639);
INSERT INTO "django_geo_db_zipcode" VALUES(26596,59702,-7,'Butte, Montana 59702',19296,23640);
INSERT INTO "django_geo_db_zipcode" VALUES(26597,59703,-7,'Butte, Montana 59703',19296,23640);
INSERT INTO "django_geo_db_zipcode" VALUES(26598,59707,-7,'Butte, Montana 59707',19296,23640);
INSERT INTO "django_geo_db_zipcode" VALUES(26599,59710,-7,'Alder, Montana 59710',19297,23641);
INSERT INTO "django_geo_db_zipcode" VALUES(26600,59711,-7,'Anaconda, Montana 59711',19298,23642);
INSERT INTO "django_geo_db_zipcode" VALUES(26601,59713,-7,'Avon, Montana 59713',19299,23643);
INSERT INTO "django_geo_db_zipcode" VALUES(26602,59714,-7,'Belgrade, Montana 59714',19300,23644);
INSERT INTO "django_geo_db_zipcode" VALUES(26603,59715,-7,'Bozeman, Montana 59715',19301,23645);
INSERT INTO "django_geo_db_zipcode" VALUES(26604,59716,-7,'Big Sky, Montana 59716',19302,23646);
INSERT INTO "django_geo_db_zipcode" VALUES(26605,59717,-7,'Bozeman, Montana 59717',19301,23647);
INSERT INTO "django_geo_db_zipcode" VALUES(26606,59718,-7,'Bozeman, Montana 59718',19301,23648);
INSERT INTO "django_geo_db_zipcode" VALUES(26607,59719,-7,'Bozeman, Montana 59719',19301,23647);
INSERT INTO "django_geo_db_zipcode" VALUES(26608,59720,-7,'Cameron, Montana 59720',19303,23649);
INSERT INTO "django_geo_db_zipcode" VALUES(26609,59721,-7,'Cardwell, Montana 59721',19304,23650);
INSERT INTO "django_geo_db_zipcode" VALUES(26610,59722,-7,'Deer Lodge, Montana 59722',19305,23651);
INSERT INTO "django_geo_db_zipcode" VALUES(26611,59724,-7,'Dell, Montana 59724',19306,23652);
INSERT INTO "django_geo_db_zipcode" VALUES(26612,59725,-7,'Dillon, Montana 59725',19307,23653);
INSERT INTO "django_geo_db_zipcode" VALUES(26613,59727,-7,'Divide, Montana 59727',19308,23654);
INSERT INTO "django_geo_db_zipcode" VALUES(26614,59728,-7,'Elliston, Montana 59728',19309,23655);
INSERT INTO "django_geo_db_zipcode" VALUES(26615,59729,-7,'Ennis, Montana 59729',19310,23656);
INSERT INTO "django_geo_db_zipcode" VALUES(26616,59730,-7,'Gallatin Gateway, Montana 59730',19311,23657);
INSERT INTO "django_geo_db_zipcode" VALUES(26617,59731,-7,'Garrison, Montana 59731',19312,23658);
INSERT INTO "django_geo_db_zipcode" VALUES(26618,59732,-7,'Glen, Montana 59732',19313,23652);
INSERT INTO "django_geo_db_zipcode" VALUES(26619,59733,-7,'Gold Creek, Montana 59733',19314,23659);
INSERT INTO "django_geo_db_zipcode" VALUES(26620,59735,-7,'Harrison, Montana 59735',19315,23660);
INSERT INTO "django_geo_db_zipcode" VALUES(26621,59736,-7,'Jackson, Montana 59736',19316,23661);
INSERT INTO "django_geo_db_zipcode" VALUES(26622,59739,-7,'Lima, Montana 59739',19317,23662);
INSERT INTO "django_geo_db_zipcode" VALUES(26623,59740,-7,'McAllister, Montana 59740',19318,23663);
INSERT INTO "django_geo_db_zipcode" VALUES(26624,59741,-7,'Manhattan, Montana 59741',19319,23664);
INSERT INTO "django_geo_db_zipcode" VALUES(26625,59743,-7,'Melrose, Montana 59743',19320,23665);
INSERT INTO "django_geo_db_zipcode" VALUES(26626,59745,-7,'Norris, Montana 59745',19321,23666);
INSERT INTO "django_geo_db_zipcode" VALUES(26627,59746,-7,'Polaris, Montana 59746',19322,23667);
INSERT INTO "django_geo_db_zipcode" VALUES(26628,59747,-7,'Pony, Montana 59747',19323,23668);
INSERT INTO "django_geo_db_zipcode" VALUES(26629,59748,-7,'Ramsay, Montana 59748',19324,23669);
INSERT INTO "django_geo_db_zipcode" VALUES(26630,59749,-7,'Sheridan, Montana 59749',19325,23670);
INSERT INTO "django_geo_db_zipcode" VALUES(26631,59750,-7,'Butte, Montana 59750',19296,23671);
INSERT INTO "django_geo_db_zipcode" VALUES(26632,59751,-7,'Silver Star, Montana 59751',19326,23672);
INSERT INTO "django_geo_db_zipcode" VALUES(26633,59752,-7,'Three Forks, Montana 59752',19327,23673);
INSERT INTO "django_geo_db_zipcode" VALUES(26634,59754,-7,'Twin Bridges, Montana 59754',19328,23674);
INSERT INTO "django_geo_db_zipcode" VALUES(26635,59755,-7,'Virginia City, Montana 59755',19329,23675);
INSERT INTO "django_geo_db_zipcode" VALUES(26636,59756,-7,'Warm Springs, Montana 59756',19330,23676);
INSERT INTO "django_geo_db_zipcode" VALUES(26637,59758,-7,'West Yellowstone, Montana 59758',19331,23677);
INSERT INTO "django_geo_db_zipcode" VALUES(26638,59759,-7,'Whitehall, Montana 59759',19332,23678);
INSERT INTO "django_geo_db_zipcode" VALUES(26639,59760,-7,'Willow Creek, Montana 59760',19333,23679);
INSERT INTO "django_geo_db_zipcode" VALUES(26640,59761,-7,'Wisdom, Montana 59761',19334,23680);
INSERT INTO "django_geo_db_zipcode" VALUES(26641,59762,-7,'Wise River, Montana 59762',19335,23681);
INSERT INTO "django_geo_db_zipcode" VALUES(26642,59771,-7,'Bozeman, Montana 59771',19301,23682);
INSERT INTO "django_geo_db_zipcode" VALUES(26643,59772,-7,'Bozeman, Montana 59772',19301,23683);
INSERT INTO "django_geo_db_zipcode" VALUES(26644,59773,-7,'Bozeman, Montana 59773',19301,23647);
INSERT INTO "django_geo_db_zipcode" VALUES(26645,59795,-7,'Ennis, Montana 59795',19310,23684);
INSERT INTO "django_geo_db_zipcode" VALUES(26646,59798,-7,'West Yellowstone, Montana 59798',19331,23685);
INSERT INTO "django_geo_db_zipcode" VALUES(26647,59801,-7,'Missoula, Montana 59801',19336,23686);
INSERT INTO "django_geo_db_zipcode" VALUES(26648,59802,-7,'Missoula, Montana 59802',19336,23687);
INSERT INTO "django_geo_db_zipcode" VALUES(26649,59803,-7,'Missoula, Montana 59803',19336,23688);
INSERT INTO "django_geo_db_zipcode" VALUES(26650,59804,-7,'Missoula, Montana 59804',19336,23689);
INSERT INTO "django_geo_db_zipcode" VALUES(26651,59806,-7,'Missoula, Montana 59806',19336,23690);
INSERT INTO "django_geo_db_zipcode" VALUES(26652,59807,-7,'Missoula, Montana 59807',19336,23691);
INSERT INTO "django_geo_db_zipcode" VALUES(26653,59808,-7,'Missoula, Montana 59808',19336,23692);
INSERT INTO "django_geo_db_zipcode" VALUES(26654,59812,-7,'Missoula, Montana 59812',19336,23690);
INSERT INTO "django_geo_db_zipcode" VALUES(26655,59817,-7,'Four Corners, Montana 59817',19337,23693);
INSERT INTO "django_geo_db_zipcode" VALUES(26656,59820,-7,'Alberton, Montana 59820',19338,23694);
INSERT INTO "django_geo_db_zipcode" VALUES(26657,59821,-7,'Arlee, Montana 59821',19339,23695);
INSERT INTO "django_geo_db_zipcode" VALUES(26658,59823,-7,'Bonner, Montana 59823',19340,23696);
INSERT INTO "django_geo_db_zipcode" VALUES(26659,59824,-7,'Charlo, Montana 59824',19341,23697);
INSERT INTO "django_geo_db_zipcode" VALUES(26660,59825,-7,'Clinton, Montana 59825',19342,23698);
INSERT INTO "django_geo_db_zipcode" VALUES(26661,59826,-7,'Condon, Montana 59826',19343,23699);
INSERT INTO "django_geo_db_zipcode" VALUES(26662,59827,-7,'Conner, Montana 59827',19344,23700);
INSERT INTO "django_geo_db_zipcode" VALUES(26663,59828,-7,'Corvallis, Montana 59828',19345,23701);
INSERT INTO "django_geo_db_zipcode" VALUES(26664,59829,-7,'Darby, Montana 59829',19346,23702);
INSERT INTO "django_geo_db_zipcode" VALUES(26665,59830,-7,'De Borgia, Montana 59830',19347,23703);
INSERT INTO "django_geo_db_zipcode" VALUES(26666,59831,-7,'Dixon, Montana 59831',19348,23704);
INSERT INTO "django_geo_db_zipcode" VALUES(26667,59832,-7,'Drummond, Montana 59832',19349,23705);
INSERT INTO "django_geo_db_zipcode" VALUES(26668,59833,-7,'Florence, Montana 59833',19350,23706);
INSERT INTO "django_geo_db_zipcode" VALUES(26669,59834,-7,'Frenchtown, Montana 59834',19351,23707);
INSERT INTO "django_geo_db_zipcode" VALUES(26670,59835,-7,'Grantsdale, Montana 59835',19352,23708);
INSERT INTO "django_geo_db_zipcode" VALUES(26671,59836,-7,'Greenough, Montana 59836',19353,23709);
INSERT INTO "django_geo_db_zipcode" VALUES(26672,59837,-7,'Hall, Montana 59837',19354,23710);
INSERT INTO "django_geo_db_zipcode" VALUES(26673,59840,-7,'Hamilton, Montana 59840',19355,23711);
INSERT INTO "django_geo_db_zipcode" VALUES(26674,59841,-7,'Pinesdale, Montana 59841',19356,23712);
INSERT INTO "django_geo_db_zipcode" VALUES(26675,59842,-7,'Haugan, Montana 59842',19357,23713);
INSERT INTO "django_geo_db_zipcode" VALUES(26676,59843,-7,'Helmville, Montana 59843',19358,23714);
INSERT INTO "django_geo_db_zipcode" VALUES(26677,59844,-7,'Heron, Montana 59844',19359,23715);
INSERT INTO "django_geo_db_zipcode" VALUES(26678,59845,-7,'Hot Springs, Montana 59845',19360,23716);
INSERT INTO "django_geo_db_zipcode" VALUES(26679,59846,-7,'Huson, Montana 59846',19361,23717);
INSERT INTO "django_geo_db_zipcode" VALUES(26680,59847,-7,'Lolo, Montana 59847',19362,23718);
INSERT INTO "django_geo_db_zipcode" VALUES(26681,59848,-7,'Lonepine, Montana 59848',19363,23719);
INSERT INTO "django_geo_db_zipcode" VALUES(26682,59851,-7,'Milltown, Montana 59851',19364,23720);
INSERT INTO "django_geo_db_zipcode" VALUES(26683,59853,-7,'Noxon, Montana 59853',19365,23721);
INSERT INTO "django_geo_db_zipcode" VALUES(26684,59854,-7,'Ovando, Montana 59854',19366,23722);
INSERT INTO "django_geo_db_zipcode" VALUES(26685,59855,-7,'Pablo, Montana 59855',19367,23723);
INSERT INTO "django_geo_db_zipcode" VALUES(26686,59856,-7,'Paradise, Montana 59856',19368,23724);
INSERT INTO "django_geo_db_zipcode" VALUES(26687,59858,-7,'Philipsburg, Montana 59858',19369,23725);
INSERT INTO "django_geo_db_zipcode" VALUES(26688,59859,-7,'Plains, Montana 59859',19370,23726);
INSERT INTO "django_geo_db_zipcode" VALUES(26689,59860,-7,'Polson, Montana 59860',19371,23727);
INSERT INTO "django_geo_db_zipcode" VALUES(26690,59863,-7,'Ravalli, Montana 59863',19372,23728);
INSERT INTO "django_geo_db_zipcode" VALUES(26691,59864,-7,'Ronan, Montana 59864',19373,23729);
INSERT INTO "django_geo_db_zipcode" VALUES(26692,59865,-7,'Saint Ignatius, Montana 59865',19374,23730);
INSERT INTO "django_geo_db_zipcode" VALUES(26693,59866,-7,'Saint Regis, Montana 59866',19375,23731);
INSERT INTO "django_geo_db_zipcode" VALUES(26694,59867,-7,'Saltese, Montana 59867',19376,23732);
INSERT INTO "django_geo_db_zipcode" VALUES(26695,59868,-7,'Seeley Lake, Montana 59868',19377,23733);
INSERT INTO "django_geo_db_zipcode" VALUES(26696,59870,-7,'Stevensville, Montana 59870',19378,23734);
INSERT INTO "django_geo_db_zipcode" VALUES(26697,59871,-7,'Sula, Montana 59871',19379,23735);
INSERT INTO "django_geo_db_zipcode" VALUES(26698,59872,-7,'Superior, Montana 59872',19380,23736);
INSERT INTO "django_geo_db_zipcode" VALUES(26699,59873,-7,'Thompson Falls, Montana 59873',19381,23737);
INSERT INTO "django_geo_db_zipcode" VALUES(26700,59874,-7,'Trout Creek, Montana 59874',19382,23738);
INSERT INTO "django_geo_db_zipcode" VALUES(26701,59875,-7,'Victor, Montana 59875',19383,23739);
INSERT INTO "django_geo_db_zipcode" VALUES(26702,59901,-7,'Kalispell, Montana 59901',19384,23740);
INSERT INTO "django_geo_db_zipcode" VALUES(26703,59902,-7,'Kalispell, Montana 59902',19384,23741);
INSERT INTO "django_geo_db_zipcode" VALUES(26704,59903,-7,'Kalispell, Montana 59903',19384,23742);
INSERT INTO "django_geo_db_zipcode" VALUES(26705,59904,-7,'Kalispell, Montana 59904',19384,23743);
INSERT INTO "django_geo_db_zipcode" VALUES(26706,59910,-7,'Big Arm, Montana 59910',19385,23744);
INSERT INTO "django_geo_db_zipcode" VALUES(26707,59911,-7,'Bigfork, Montana 59911',19386,23745);
INSERT INTO "django_geo_db_zipcode" VALUES(26708,59912,-7,'Columbia Falls, Montana 59912',19387,23746);
INSERT INTO "django_geo_db_zipcode" VALUES(26709,59913,-7,'Coram, Montana 59913',19388,23747);
INSERT INTO "django_geo_db_zipcode" VALUES(26710,59914,-7,'Dayton, Montana 59914',19389,23748);
INSERT INTO "django_geo_db_zipcode" VALUES(26711,59915,-7,'Elmo, Montana 59915',19390,23749);
INSERT INTO "django_geo_db_zipcode" VALUES(26712,59916,-7,'Essex, Montana 59916',19391,23750);
INSERT INTO "django_geo_db_zipcode" VALUES(26713,59917,-7,'Eureka, Montana 59917',19392,23751);
INSERT INTO "django_geo_db_zipcode" VALUES(26714,59918,-7,'Fortine, Montana 59918',19393,23752);
INSERT INTO "django_geo_db_zipcode" VALUES(26715,59919,-7,'Hungry Horse, Montana 59919',19394,23753);
INSERT INTO "django_geo_db_zipcode" VALUES(26716,59920,-7,'Kila, Montana 59920',19395,23754);
INSERT INTO "django_geo_db_zipcode" VALUES(26717,59921,-7,'Lake McDonald, Montana 59921',19396,23755);
INSERT INTO "django_geo_db_zipcode" VALUES(26718,59922,-7,'Lakeside, Montana 59922',19397,23756);
INSERT INTO "django_geo_db_zipcode" VALUES(26719,59923,-7,'Libby, Montana 59923',19398,23757);
INSERT INTO "django_geo_db_zipcode" VALUES(26720,59925,-7,'Marion, Montana 59925',19399,23758);
INSERT INTO "django_geo_db_zipcode" VALUES(26721,59926,-7,'Martin City, Montana 59926',19400,23759);
INSERT INTO "django_geo_db_zipcode" VALUES(26722,59927,-7,'Olney, Montana 59927',19401,23760);
INSERT INTO "django_geo_db_zipcode" VALUES(26723,59928,-7,'Polebridge, Montana 59928',19402,23761);
INSERT INTO "django_geo_db_zipcode" VALUES(26724,59929,-7,'Proctor, Montana 59929',19403,23762);
INSERT INTO "django_geo_db_zipcode" VALUES(26725,59930,-7,'Rexford, Montana 59930',19404,23763);
INSERT INTO "django_geo_db_zipcode" VALUES(26726,59931,-7,'Rollins, Montana 59931',19405,23764);
INSERT INTO "django_geo_db_zipcode" VALUES(26727,59932,-7,'Somers, Montana 59932',19406,23765);
INSERT INTO "django_geo_db_zipcode" VALUES(26728,59933,-7,'Stryker, Montana 59933',19407,23766);
INSERT INTO "django_geo_db_zipcode" VALUES(26729,59934,-7,'Trego, Montana 59934',19408,23767);
INSERT INTO "django_geo_db_zipcode" VALUES(26730,59935,-7,'Troy, Montana 59935',19409,23768);
INSERT INTO "django_geo_db_zipcode" VALUES(26731,59936,-7,'West Glacier, Montana 59936',19410,23769);
INSERT INTO "django_geo_db_zipcode" VALUES(26732,59937,-7,'Whitefish, Montana 59937',19411,23770);
INSERT INTO "django_geo_db_zipcode" VALUES(26733,60001,-6,'Alden, Illinois 60001',19412,23771);
INSERT INTO "django_geo_db_zipcode" VALUES(26734,60002,-6,'Antioch, Illinois 60002',19413,23772);
INSERT INTO "django_geo_db_zipcode" VALUES(26735,60004,-6,'Arlington Heights, Illinois 60004',19414,23773);
INSERT INTO "django_geo_db_zipcode" VALUES(26736,60005,-6,'Arlington Heights, Illinois 60005',19414,23774);
INSERT INTO "django_geo_db_zipcode" VALUES(26737,60006,-6,'Arlington Heights, Illinois 60006',19414,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26738,60007,-6,'Elk Grove Village, Illinois 60007',19415,23776);
INSERT INTO "django_geo_db_zipcode" VALUES(26739,60008,-6,'Rolling Meadows, Illinois 60008',19416,23777);
INSERT INTO "django_geo_db_zipcode" VALUES(26740,60009,-6,'Elk Grove Village, Illinois 60009',19415,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26741,60010,-6,'Barrington, Illinois 60010',19417,23778);
INSERT INTO "django_geo_db_zipcode" VALUES(26742,60011,-6,'Barrington, Illinois 60011',19417,23779);
INSERT INTO "django_geo_db_zipcode" VALUES(26743,60012,-6,'Crystal Lake, Illinois 60012',19418,23780);
INSERT INTO "django_geo_db_zipcode" VALUES(26744,60013,-6,'Cary, Illinois 60013',19419,23781);
INSERT INTO "django_geo_db_zipcode" VALUES(26745,60014,-6,'Crystal Lake, Illinois 60014',19418,23782);
INSERT INTO "django_geo_db_zipcode" VALUES(26746,60015,-6,'Deerfield, Illinois 60015',19420,23783);
INSERT INTO "django_geo_db_zipcode" VALUES(26747,60016,-6,'Des Plaines, Illinois 60016',19421,23784);
INSERT INTO "django_geo_db_zipcode" VALUES(26748,60017,-6,'Des Plaines, Illinois 60017',19421,23785);
INSERT INTO "django_geo_db_zipcode" VALUES(26749,60018,-6,'Des Plaines, Illinois 60018',19421,23786);
INSERT INTO "django_geo_db_zipcode" VALUES(26750,60019,-6,'Des Plaines, Illinois 60019',19421,23787);
INSERT INTO "django_geo_db_zipcode" VALUES(26751,60020,-6,'Fox Lake, Illinois 60020',19422,23788);
INSERT INTO "django_geo_db_zipcode" VALUES(26752,60021,-6,'Fox River Grove, Illinois 60021',19423,23789);
INSERT INTO "django_geo_db_zipcode" VALUES(26753,60022,-6,'Glencoe, Illinois 60022',19424,23790);
INSERT INTO "django_geo_db_zipcode" VALUES(26754,60025,-6,'Glenview, Illinois 60025',19425,23791);
INSERT INTO "django_geo_db_zipcode" VALUES(26755,60026,-6,'Glenview Nas, Illinois 60026',19426,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26756,60029,-6,'Golf, Illinois 60029',19427,23792);
INSERT INTO "django_geo_db_zipcode" VALUES(26757,60030,-6,'Grayslake, Illinois 60030',19428,23793);
INSERT INTO "django_geo_db_zipcode" VALUES(26758,60031,-6,'Gurnee, Illinois 60031',19429,23794);
INSERT INTO "django_geo_db_zipcode" VALUES(26759,60033,-6,'Harvard, Illinois 60033',19430,23795);
INSERT INTO "django_geo_db_zipcode" VALUES(26760,60034,-6,'Hebron, Illinois 60034',19431,23796);
INSERT INTO "django_geo_db_zipcode" VALUES(26761,60035,-6,'Highland Park, Illinois 60035',19432,23797);
INSERT INTO "django_geo_db_zipcode" VALUES(26762,60037,-6,'Fort Sheridan, Illinois 60037',19433,23798);
INSERT INTO "django_geo_db_zipcode" VALUES(26763,60038,-6,'Palatine, Illinois 60038',19434,23799);
INSERT INTO "django_geo_db_zipcode" VALUES(26764,60039,-6,'Crystal Lake, Illinois 60039',19418,23771);
INSERT INTO "django_geo_db_zipcode" VALUES(26765,60040,-6,'Highwood, Illinois 60040',19435,23800);
INSERT INTO "django_geo_db_zipcode" VALUES(26766,60041,-6,'Ingleside, Illinois 60041',19436,23801);
INSERT INTO "django_geo_db_zipcode" VALUES(26767,60042,-6,'Island Lake, Illinois 60042',19437,23802);
INSERT INTO "django_geo_db_zipcode" VALUES(26768,60043,-6,'Kenilworth, Illinois 60043',19438,23803);
INSERT INTO "django_geo_db_zipcode" VALUES(26769,60044,-6,'Lake Bluff, Illinois 60044',19439,23804);
INSERT INTO "django_geo_db_zipcode" VALUES(26770,60045,-6,'Lake Forest, Illinois 60045',19440,23805);
INSERT INTO "django_geo_db_zipcode" VALUES(26771,60046,-6,'Lake Villa, Illinois 60046',19441,23806);
INSERT INTO "django_geo_db_zipcode" VALUES(26772,60047,-6,'Lake Zurich, Illinois 60047',19442,23807);
INSERT INTO "django_geo_db_zipcode" VALUES(26773,60048,-6,'Libertyville, Illinois 60048',19443,23808);
INSERT INTO "django_geo_db_zipcode" VALUES(26774,60049,-6,'Long Grove, Illinois 60049',19444,23809);
INSERT INTO "django_geo_db_zipcode" VALUES(26775,60050,-6,'Mchenry, Illinois 60050',19445,23810);
INSERT INTO "django_geo_db_zipcode" VALUES(26776,60051,-6,'Mchenry, Illinois 60051',19445,23771);
INSERT INTO "django_geo_db_zipcode" VALUES(26777,60053,-6,'Morton Grove, Illinois 60053',19446,23811);
INSERT INTO "django_geo_db_zipcode" VALUES(26778,60054,-6,'McHenry, Illinois 60054',19447,23812);
INSERT INTO "django_geo_db_zipcode" VALUES(26779,60055,-6,'Palatine, Illinois 60055',19434,23799);
INSERT INTO "django_geo_db_zipcode" VALUES(26780,60056,-6,'Mount Prospect, Illinois 60056',19448,23813);
INSERT INTO "django_geo_db_zipcode" VALUES(26781,60060,-6,'Mundelein, Illinois 60060',19449,23814);
INSERT INTO "django_geo_db_zipcode" VALUES(26782,60061,-6,'Vernon Hills, Illinois 60061',19450,23815);
INSERT INTO "django_geo_db_zipcode" VALUES(26783,60062,-6,'Northbrook, Illinois 60062',19451,23816);
INSERT INTO "django_geo_db_zipcode" VALUES(26784,60064,-6,'North Chicago, Illinois 60064',19452,23817);
INSERT INTO "django_geo_db_zipcode" VALUES(26785,60065,-6,'Northbrook, Illinois 60065',19451,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26786,60067,-6,'Palatine, Illinois 60067',19434,23818);
INSERT INTO "django_geo_db_zipcode" VALUES(26787,60068,-6,'Park Ridge, Illinois 60068',19453,23819);
INSERT INTO "django_geo_db_zipcode" VALUES(26788,60069,-6,'Lincolnshire, Illinois 60069',19454,23820);
INSERT INTO "django_geo_db_zipcode" VALUES(26789,60070,-6,'Prospect Heights, Illinois 60070',19455,23821);
INSERT INTO "django_geo_db_zipcode" VALUES(26790,60071,-6,'Richmond, Illinois 60071',19456,23822);
INSERT INTO "django_geo_db_zipcode" VALUES(26791,60072,-6,'Ringwood, Illinois 60072',19457,23823);
INSERT INTO "django_geo_db_zipcode" VALUES(26792,60073,-6,'Round Lake, Illinois 60073',19458,23824);
INSERT INTO "django_geo_db_zipcode" VALUES(26793,60074,-6,'Palatine, Illinois 60074',19434,23825);
INSERT INTO "django_geo_db_zipcode" VALUES(26794,60075,-6,'Russell, Illinois 60075',19459,23779);
INSERT INTO "django_geo_db_zipcode" VALUES(26795,60076,-6,'Skokie, Illinois 60076',19460,23826);
INSERT INTO "django_geo_db_zipcode" VALUES(26796,60077,-6,'Skokie, Illinois 60077',19460,23827);
INSERT INTO "django_geo_db_zipcode" VALUES(26797,60078,-6,'Palatine, Illinois 60078',19434,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26798,60079,-6,'Waukegan, Illinois 60079',19461,23779);
INSERT INTO "django_geo_db_zipcode" VALUES(26799,60080,-6,'Solon Mills, Illinois 60080',19462,23828);
INSERT INTO "django_geo_db_zipcode" VALUES(26800,60081,-6,'Spring Grove, Illinois 60081',19463,23829);
INSERT INTO "django_geo_db_zipcode" VALUES(26801,60082,-6,'Techny, Illinois 60082',19464,23830);
INSERT INTO "django_geo_db_zipcode" VALUES(26802,60083,-6,'Wadsworth, Illinois 60083',19465,23831);
INSERT INTO "django_geo_db_zipcode" VALUES(26803,60084,-6,'Wauconda, Illinois 60084',19466,23832);
INSERT INTO "django_geo_db_zipcode" VALUES(26804,60085,-6,'Waukegan, Illinois 60085',19461,23833);
INSERT INTO "django_geo_db_zipcode" VALUES(26805,60086,-6,'North Chicago, Illinois 60086',19452,23834);
INSERT INTO "django_geo_db_zipcode" VALUES(26806,60087,-6,'Waukegan, Illinois 60087',19461,23835);
INSERT INTO "django_geo_db_zipcode" VALUES(26807,60088,-6,'Great Lakes, Illinois 60088',19467,23836);
INSERT INTO "django_geo_db_zipcode" VALUES(26808,60089,-6,'Buffalo Grove, Illinois 60089',19468,23837);
INSERT INTO "django_geo_db_zipcode" VALUES(26809,60090,-6,'Wheeling, Illinois 60090',19469,23838);
INSERT INTO "django_geo_db_zipcode" VALUES(26810,60091,-6,'Wilmette, Illinois 60091',19470,23839);
INSERT INTO "django_geo_db_zipcode" VALUES(26811,60092,-6,'Libertyville, Illinois 60092',19443,23779);
INSERT INTO "django_geo_db_zipcode" VALUES(26812,60093,-6,'Winnetka, Illinois 60093',19471,23840);
INSERT INTO "django_geo_db_zipcode" VALUES(26813,60094,-6,'Palatine, Illinois 60094',19434,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26814,60095,-6,'Palatine, Illinois 60095',19434,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26815,60096,-6,'Winthrop Harbor, Illinois 60096',19472,23841);
INSERT INTO "django_geo_db_zipcode" VALUES(26816,60097,-6,'Wonder Lake, Illinois 60097',19473,23842);
INSERT INTO "django_geo_db_zipcode" VALUES(26817,60098,-6,'Woodstock, Illinois 60098',19474,23843);
INSERT INTO "django_geo_db_zipcode" VALUES(26818,60099,-6,'Zion, Illinois 60099',19475,23844);
INSERT INTO "django_geo_db_zipcode" VALUES(26819,60101,-6,'Addison, Illinois 60101',19476,23845);
INSERT INTO "django_geo_db_zipcode" VALUES(26820,60102,-6,'Algonquin, Illinois 60102',19477,23846);
INSERT INTO "django_geo_db_zipcode" VALUES(26821,60103,-6,'Bartlett, Illinois 60103',19478,23847);
INSERT INTO "django_geo_db_zipcode" VALUES(26822,60104,-6,'Bellwood, Illinois 60104',19479,23848);
INSERT INTO "django_geo_db_zipcode" VALUES(26823,60105,-6,'Bensenville, Illinois 60105',19480,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26824,60106,-6,'Bensenville, Illinois 60106',19480,23850);
INSERT INTO "django_geo_db_zipcode" VALUES(26825,60107,-6,'Streamwood, Illinois 60107',19481,23851);
INSERT INTO "django_geo_db_zipcode" VALUES(26826,60108,-6,'Bloomingdale, Illinois 60108',19482,23852);
INSERT INTO "django_geo_db_zipcode" VALUES(26827,60109,-6,'Burlington, Illinois 60109',19483,23853);
INSERT INTO "django_geo_db_zipcode" VALUES(26828,60110,-6,'Carpentersville, Illinois 60110',19484,23854);
INSERT INTO "django_geo_db_zipcode" VALUES(26829,60111,-6,'Clare, Illinois 60111',19485,23855);
INSERT INTO "django_geo_db_zipcode" VALUES(26830,60112,-6,'Cortland, Illinois 60112',19486,23856);
INSERT INTO "django_geo_db_zipcode" VALUES(26831,60113,-6,'Creston, Illinois 60113',19487,23857);
INSERT INTO "django_geo_db_zipcode" VALUES(26832,60114,-6,'Addison, Illinois 60114',19476,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26833,60115,-6,'Dekalb, Illinois 60115',19488,23858);
INSERT INTO "django_geo_db_zipcode" VALUES(26834,60116,-6,'Carol Stream, Illinois 60116',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26835,60117,-6,'Bloomingdale, Illinois 60117',19482,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26836,60118,-6,'Dundee, Illinois 60118',19490,23859);
INSERT INTO "django_geo_db_zipcode" VALUES(26837,60119,-6,'Elburn, Illinois 60119',19491,23860);
INSERT INTO "django_geo_db_zipcode" VALUES(26838,60120,-6,'Elgin, Illinois 60120',19492,23861);
INSERT INTO "django_geo_db_zipcode" VALUES(26839,60121,-6,'Elgin, Illinois 60121',19492,23862);
INSERT INTO "django_geo_db_zipcode" VALUES(26840,60122,-6,'Elgin, Illinois 60122',19492,23863);
INSERT INTO "django_geo_db_zipcode" VALUES(26841,60123,-6,'Elgin, Illinois 60123',19492,23864);
INSERT INTO "django_geo_db_zipcode" VALUES(26842,60125,-6,'Carol Stream, Illinois 60125',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26843,60126,-6,'Elmhurst, Illinois 60126',19493,23865);
INSERT INTO "django_geo_db_zipcode" VALUES(26844,60127,-6,'Milton, Illinois 60127',19494,23866);
INSERT INTO "django_geo_db_zipcode" VALUES(26845,60128,-6,'Carol Stream, Illinois 60128',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26846,60129,-6,'Esmond, Illinois 60129',19495,23867);
INSERT INTO "django_geo_db_zipcode" VALUES(26847,60130,-6,'Forest Park, Illinois 60130',19496,23868);
INSERT INTO "django_geo_db_zipcode" VALUES(26848,60131,-6,'Franklin Park, Illinois 60131',19497,23869);
INSERT INTO "django_geo_db_zipcode" VALUES(26849,60132,-6,'Carol Stream, Illinois 60132',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26850,60133,-6,'Hanover Park, Illinois 60133',19498,23870);
INSERT INTO "django_geo_db_zipcode" VALUES(26851,60134,-6,'Geneva, Illinois 60134',19499,23871);
INSERT INTO "django_geo_db_zipcode" VALUES(26852,60135,-6,'Genoa, Illinois 60135',19500,23872);
INSERT INTO "django_geo_db_zipcode" VALUES(26853,60136,-6,'Gilberts, Illinois 60136',19501,23873);
INSERT INTO "django_geo_db_zipcode" VALUES(26854,60137,-6,'Glen Ellyn, Illinois 60137',19502,23874);
INSERT INTO "django_geo_db_zipcode" VALUES(26855,60138,-6,'Glen Ellyn, Illinois 60138',19502,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26856,60139,-6,'Glendale Heights, Illinois 60139',19503,23875);
INSERT INTO "django_geo_db_zipcode" VALUES(26857,60140,-6,'Hampshire, Illinois 60140',19504,23876);
INSERT INTO "django_geo_db_zipcode" VALUES(26858,60141,-6,'Hines, Illinois 60141',19505,23877);
INSERT INTO "django_geo_db_zipcode" VALUES(26859,60142,-6,'Huntley, Illinois 60142',19506,23878);
INSERT INTO "django_geo_db_zipcode" VALUES(26860,60143,-6,'Itasca, Illinois 60143',19507,23879);
INSERT INTO "django_geo_db_zipcode" VALUES(26861,60144,-6,'Kaneville, Illinois 60144',19508,23880);
INSERT INTO "django_geo_db_zipcode" VALUES(26862,60145,-6,'Kingston, Illinois 60145',19509,23881);
INSERT INTO "django_geo_db_zipcode" VALUES(26863,60146,-6,'Kirkland, Illinois 60146',19510,23882);
INSERT INTO "django_geo_db_zipcode" VALUES(26864,60147,-6,'Lafox, Illinois 60147',19511,23880);
INSERT INTO "django_geo_db_zipcode" VALUES(26865,60148,-6,'Lombard, Illinois 60148',19512,23883);
INSERT INTO "django_geo_db_zipcode" VALUES(26866,60149,-6,'Dement, Illinois 60149',19513,23884);
INSERT INTO "django_geo_db_zipcode" VALUES(26867,60150,-6,'Malta, Illinois 60150',19514,23885);
INSERT INTO "django_geo_db_zipcode" VALUES(26868,60151,-6,'Maple Park, Illinois 60151',19515,23886);
INSERT INTO "django_geo_db_zipcode" VALUES(26869,60152,-6,'Marengo, Illinois 60152',19516,23887);
INSERT INTO "django_geo_db_zipcode" VALUES(26870,60153,-6,'Maywood, Illinois 60153',19517,23888);
INSERT INTO "django_geo_db_zipcode" VALUES(26871,60154,-6,'Westchester, Illinois 60154',19518,23889);
INSERT INTO "django_geo_db_zipcode" VALUES(26872,60155,-6,'Broadview, Illinois 60155',19519,23890);
INSERT INTO "django_geo_db_zipcode" VALUES(26873,60156,-6,'Lake in the Hills, Illinois 60156',19520,23891);
INSERT INTO "django_geo_db_zipcode" VALUES(26874,60157,-6,'Medinah, Illinois 60157',19521,23892);
INSERT INTO "django_geo_db_zipcode" VALUES(26875,60159,-6,'Schaumburg, Illinois 60159',19522,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26876,60160,-6,'Melrose Park, Illinois 60160',19523,23893);
INSERT INTO "django_geo_db_zipcode" VALUES(26877,60161,-6,'Melrose Park, Illinois 60161',19523,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26878,60162,-6,'Hillside, Illinois 60162',19524,23894);
INSERT INTO "django_geo_db_zipcode" VALUES(26879,60163,-6,'Berkeley, Illinois 60163',19525,23895);
INSERT INTO "django_geo_db_zipcode" VALUES(26880,60164,-6,'Melrose Park, Illinois 60164',19523,23896);
INSERT INTO "django_geo_db_zipcode" VALUES(26881,60165,-6,'Stone Park, Illinois 60165',19526,23897);
INSERT INTO "django_geo_db_zipcode" VALUES(26882,60168,-6,'Schaumburg, Illinois 60168',19522,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26883,60170,-6,'Plato Center, Illinois 60170',19527,23898);
INSERT INTO "django_geo_db_zipcode" VALUES(26884,60171,-6,'River Grove, Illinois 60171',19528,23899);
INSERT INTO "django_geo_db_zipcode" VALUES(26885,60172,-6,'Roselle, Illinois 60172',19529,23900);
INSERT INTO "django_geo_db_zipcode" VALUES(26886,60173,-6,'Schaumburg, Illinois 60173',19522,23901);
INSERT INTO "django_geo_db_zipcode" VALUES(26887,60174,-6,'Saint Charles, Illinois 60174',19530,23902);
INSERT INTO "django_geo_db_zipcode" VALUES(26888,60175,-6,'Saint Charles, Illinois 60175',19530,23903);
INSERT INTO "django_geo_db_zipcode" VALUES(26889,60176,-6,'Schiller Park, Illinois 60176',19531,23904);
INSERT INTO "django_geo_db_zipcode" VALUES(26890,60177,-6,'South Elgin, Illinois 60177',19532,23905);
INSERT INTO "django_geo_db_zipcode" VALUES(26891,60178,-6,'Sycamore, Illinois 60178',19533,23906);
INSERT INTO "django_geo_db_zipcode" VALUES(26892,60179,-6,'Hoffman Estates, Illinois 60179',19534,23907);
INSERT INTO "django_geo_db_zipcode" VALUES(26893,60180,-6,'Union, Illinois 60180',19535,23908);
INSERT INTO "django_geo_db_zipcode" VALUES(26894,60181,-6,'Villa Park, Illinois 60181',19536,23909);
INSERT INTO "django_geo_db_zipcode" VALUES(26895,60182,-6,'Virgil, Illinois 60182',19537,23910);
INSERT INTO "django_geo_db_zipcode" VALUES(26896,60183,-6,'Wasco, Illinois 60183',19538,23880);
INSERT INTO "django_geo_db_zipcode" VALUES(26897,60184,-6,'Wayne, Illinois 60184',19539,23911);
INSERT INTO "django_geo_db_zipcode" VALUES(26898,60185,-6,'West Chicago, Illinois 60185',19540,23912);
INSERT INTO "django_geo_db_zipcode" VALUES(26899,60186,-6,'West Chicago, Illinois 60186',19540,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26900,60187,-6,'Wheaton, Illinois 60187',19541,23913);
INSERT INTO "django_geo_db_zipcode" VALUES(26901,60188,-6,'Carol Stream, Illinois 60188',19489,23914);
INSERT INTO "django_geo_db_zipcode" VALUES(26902,60189,-6,'Wheaton, Illinois 60189',19541,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26903,60190,-6,'Winfield, Illinois 60190',19542,23915);
INSERT INTO "django_geo_db_zipcode" VALUES(26904,60191,-6,'Wood Dale, Illinois 60191',19543,23916);
INSERT INTO "django_geo_db_zipcode" VALUES(26905,60192,-6,'Schaumburg, Illinois 60192',19522,23917);
INSERT INTO "django_geo_db_zipcode" VALUES(26906,60193,-6,'Schaumburg, Illinois 60193',19522,23918);
INSERT INTO "django_geo_db_zipcode" VALUES(26907,60194,-6,'Schaumburg, Illinois 60194',19522,23919);
INSERT INTO "django_geo_db_zipcode" VALUES(26908,60195,-6,'Schaumburg, Illinois 60195',19522,23920);
INSERT INTO "django_geo_db_zipcode" VALUES(26909,60196,-6,'Schaumburg, Illinois 60196',19522,23921);
INSERT INTO "django_geo_db_zipcode" VALUES(26910,60197,-6,'Carol Stream, Illinois 60197',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26911,60198,-6,'Carol Stream, Illinois 60198',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26912,60199,-6,'Carol Stream, Illinois 60199',19489,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(26913,60201,-6,'Evanston, Illinois 60201',19544,23922);
INSERT INTO "django_geo_db_zipcode" VALUES(26914,60202,-6,'Evanston, Illinois 60202',19544,23923);
INSERT INTO "django_geo_db_zipcode" VALUES(26915,60203,-6,'Evanston, Illinois 60203',19544,23924);
INSERT INTO "django_geo_db_zipcode" VALUES(26916,60204,-6,'Evanston, Illinois 60204',19544,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26917,60208,-6,'Evanston, Illinois 60208',19544,23925);
INSERT INTO "django_geo_db_zipcode" VALUES(26918,60209,-6,'Evanston, Illinois 60209',19544,23926);
INSERT INTO "django_geo_db_zipcode" VALUES(26919,60301,-6,'Oak Park, Illinois 60301',19545,23927);
INSERT INTO "django_geo_db_zipcode" VALUES(26920,60302,-6,'Oak Park, Illinois 60302',19545,23928);
INSERT INTO "django_geo_db_zipcode" VALUES(26921,60303,-6,'Oak Park, Illinois 60303',19545,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26922,60304,-6,'Oak Park, Illinois 60304',19545,23929);
INSERT INTO "django_geo_db_zipcode" VALUES(26923,60305,-6,'River Forest, Illinois 60305',19546,23930);
INSERT INTO "django_geo_db_zipcode" VALUES(26924,60330,-6,'River Forest, Illinois 60330',19546,23931);
INSERT INTO "django_geo_db_zipcode" VALUES(26925,60401,-6,'Beecher, Illinois 60401',19547,23932);
INSERT INTO "django_geo_db_zipcode" VALUES(26926,60402,-6,'Berwyn, Illinois 60402',19548,23933);
INSERT INTO "django_geo_db_zipcode" VALUES(26927,60406,-6,'Blue Island, Illinois 60406',19549,23934);
INSERT INTO "django_geo_db_zipcode" VALUES(26928,60407,-6,'Braceville, Illinois 60407',19550,23935);
INSERT INTO "django_geo_db_zipcode" VALUES(26929,60408,-6,'Braidwood, Illinois 60408',19551,23936);
INSERT INTO "django_geo_db_zipcode" VALUES(26930,60409,-6,'Calumet City, Illinois 60409',19552,23937);
INSERT INTO "django_geo_db_zipcode" VALUES(26931,60410,-6,'Channahon, Illinois 60410',19553,23938);
INSERT INTO "django_geo_db_zipcode" VALUES(26932,60411,-6,'Chicago Heights, Illinois 60411',19554,23939);
INSERT INTO "django_geo_db_zipcode" VALUES(26933,60412,-6,'Chicago Heights, Illinois 60412',19554,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26934,60415,-6,'Chicago Ridge, Illinois 60415',19555,23940);
INSERT INTO "django_geo_db_zipcode" VALUES(26935,60416,-6,'Coal City, Illinois 60416',19556,23941);
INSERT INTO "django_geo_db_zipcode" VALUES(26936,60417,-6,'Crete, Illinois 60417',19557,23942);
INSERT INTO "django_geo_db_zipcode" VALUES(26937,60419,-6,'Dolton, Illinois 60419',19558,23943);
INSERT INTO "django_geo_db_zipcode" VALUES(26938,60420,-6,'Dwight, Illinois 60420',19559,23944);
INSERT INTO "django_geo_db_zipcode" VALUES(26939,60421,-6,'Elwood, Illinois 60421',19560,23945);
INSERT INTO "django_geo_db_zipcode" VALUES(26940,60422,-6,'Flossmoor, Illinois 60422',19561,23946);
INSERT INTO "django_geo_db_zipcode" VALUES(26941,60423,-6,'Frankfort, Illinois 60423',19562,23947);
INSERT INTO "django_geo_db_zipcode" VALUES(26942,60424,-6,'Gardner, Illinois 60424',19563,23948);
INSERT INTO "django_geo_db_zipcode" VALUES(26943,60425,-6,'Glenwood, Illinois 60425',19564,23949);
INSERT INTO "django_geo_db_zipcode" VALUES(26944,60426,-6,'Harvey, Illinois 60426',19565,23950);
INSERT INTO "django_geo_db_zipcode" VALUES(26945,60429,-6,'Hazel Crest, Illinois 60429',19566,23951);
INSERT INTO "django_geo_db_zipcode" VALUES(26946,60430,-6,'Homewood, Illinois 60430',19567,23952);
INSERT INTO "django_geo_db_zipcode" VALUES(26947,60431,-6,'Joliet, Illinois 60431',19568,23953);
INSERT INTO "django_geo_db_zipcode" VALUES(26948,60432,-6,'Joliet, Illinois 60432',19568,23954);
INSERT INTO "django_geo_db_zipcode" VALUES(26949,60433,-6,'Joliet, Illinois 60433',19568,23955);
INSERT INTO "django_geo_db_zipcode" VALUES(26950,60434,-6,'Joliet, Illinois 60434',19568,23956);
INSERT INTO "django_geo_db_zipcode" VALUES(26951,60435,-6,'Joliet, Illinois 60435',19568,23957);
INSERT INTO "django_geo_db_zipcode" VALUES(26952,60436,-6,'Joliet, Illinois 60436',19568,23958);
INSERT INTO "django_geo_db_zipcode" VALUES(26953,60437,-6,'Kinsman, Illinois 60437',19569,23959);
INSERT INTO "django_geo_db_zipcode" VALUES(26954,60438,-6,'Lansing, Illinois 60438',19570,23960);
INSERT INTO "django_geo_db_zipcode" VALUES(26955,60439,-6,'Lemont, Illinois 60439',19571,23961);
INSERT INTO "django_geo_db_zipcode" VALUES(26956,60440,-6,'Bolingbrook, Illinois 60440',19572,23962);
INSERT INTO "django_geo_db_zipcode" VALUES(26957,60441,-6,'Lockport, Illinois 60441',19573,23963);
INSERT INTO "django_geo_db_zipcode" VALUES(26958,60442,-6,'Manhattan, Illinois 60442',19574,23964);
INSERT INTO "django_geo_db_zipcode" VALUES(26959,60443,-6,'Matteson, Illinois 60443',19575,23965);
INSERT INTO "django_geo_db_zipcode" VALUES(26960,60444,-6,'Mazon, Illinois 60444',19576,23966);
INSERT INTO "django_geo_db_zipcode" VALUES(26961,60445,-6,'Midlothian, Illinois 60445',19577,23967);
INSERT INTO "django_geo_db_zipcode" VALUES(26962,60446,-6,'Romeoville, Illinois 60446',19578,23968);
INSERT INTO "django_geo_db_zipcode" VALUES(26963,60447,-6,'Minooka, Illinois 60447',19579,23969);
INSERT INTO "django_geo_db_zipcode" VALUES(26964,60448,-6,'Mokena, Illinois 60448',19580,23970);
INSERT INTO "django_geo_db_zipcode" VALUES(26965,60449,-6,'Monee, Illinois 60449',19581,23971);
INSERT INTO "django_geo_db_zipcode" VALUES(26966,60450,-6,'Morris, Illinois 60450',19582,23972);
INSERT INTO "django_geo_db_zipcode" VALUES(26967,60451,-6,'New Lenox, Illinois 60451',19583,23973);
INSERT INTO "django_geo_db_zipcode" VALUES(26968,60452,-6,'Oak Forest, Illinois 60452',19584,23974);
INSERT INTO "django_geo_db_zipcode" VALUES(26969,60453,-6,'Oak Lawn, Illinois 60453',19585,23975);
INSERT INTO "django_geo_db_zipcode" VALUES(26970,60454,-6,'Oak Lawn, Illinois 60454',19585,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(26971,60455,-6,'Bridgeview, Illinois 60455',19586,23976);
INSERT INTO "django_geo_db_zipcode" VALUES(26972,60456,-6,'Hometown, Illinois 60456',19587,23977);
INSERT INTO "django_geo_db_zipcode" VALUES(26973,60457,-6,'Hickory Hills, Illinois 60457',19588,23978);
INSERT INTO "django_geo_db_zipcode" VALUES(26974,60458,-6,'Justice, Illinois 60458',19589,23979);
INSERT INTO "django_geo_db_zipcode" VALUES(26975,60459,-6,'Burbank, Illinois 60459',19590,23980);
INSERT INTO "django_geo_db_zipcode" VALUES(26976,60460,-6,'Odell, Illinois 60460',19591,23981);
INSERT INTO "django_geo_db_zipcode" VALUES(26977,60461,-6,'Olympia Fields, Illinois 60461',19592,23982);
INSERT INTO "django_geo_db_zipcode" VALUES(26978,60462,-6,'Orland Park, Illinois 60462',19593,23983);
INSERT INTO "django_geo_db_zipcode" VALUES(26979,60463,-6,'Palos Heights, Illinois 60463',19594,23984);
INSERT INTO "django_geo_db_zipcode" VALUES(26980,60464,-6,'Palos Park, Illinois 60464',19595,23985);
INSERT INTO "django_geo_db_zipcode" VALUES(26981,60465,-6,'Palos Hills, Illinois 60465',19596,23986);
INSERT INTO "django_geo_db_zipcode" VALUES(26982,60466,-6,'Park Forest, Illinois 60466',19597,23987);
INSERT INTO "django_geo_db_zipcode" VALUES(26983,60467,-6,'Orland Park, Illinois 60467',19593,23988);
INSERT INTO "django_geo_db_zipcode" VALUES(26984,60468,-6,'Peotone, Illinois 60468',19598,23989);
INSERT INTO "django_geo_db_zipcode" VALUES(26985,60469,-6,'Posen, Illinois 60469',19599,23990);
INSERT INTO "django_geo_db_zipcode" VALUES(26986,60470,-6,'Ransom, Illinois 60470',19600,23991);
INSERT INTO "django_geo_db_zipcode" VALUES(26987,60471,-6,'Richton Park, Illinois 60471',19601,23992);
INSERT INTO "django_geo_db_zipcode" VALUES(26988,60472,-6,'Robbins, Illinois 60472',19602,23993);
INSERT INTO "django_geo_db_zipcode" VALUES(26989,60473,-6,'South Holland, Illinois 60473',19603,23994);
INSERT INTO "django_geo_db_zipcode" VALUES(26990,60474,-6,'South Wilmington, Illinois 60474',19604,23995);
INSERT INTO "django_geo_db_zipcode" VALUES(26991,60475,-6,'Steger, Illinois 60475',19605,23996);
INSERT INTO "django_geo_db_zipcode" VALUES(26992,60476,-6,'Thornton, Illinois 60476',19606,23997);
INSERT INTO "django_geo_db_zipcode" VALUES(26993,60477,-6,'Tinley Park, Illinois 60477',19607,23998);
INSERT INTO "django_geo_db_zipcode" VALUES(26994,60478,-6,'Country Club Hills, Illinois 60478',19608,23999);
INSERT INTO "django_geo_db_zipcode" VALUES(26995,60479,-6,'Verona, Illinois 60479',19609,24000);
INSERT INTO "django_geo_db_zipcode" VALUES(26996,60480,-6,'Willow Springs, Illinois 60480',19610,24001);
INSERT INTO "django_geo_db_zipcode" VALUES(26997,60481,-6,'Wilmington, Illinois 60481',19611,24002);
INSERT INTO "django_geo_db_zipcode" VALUES(26998,60482,-6,'Worth, Illinois 60482',19612,24003);
INSERT INTO "django_geo_db_zipcode" VALUES(26999,60490,-6,'Bolingbrook, Illinois 60490',19572,24004);
INSERT INTO "django_geo_db_zipcode" VALUES(27000,60499,-6,'Bedford Park, Illinois 60499',19613,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27001,60501,-6,'Summit Argo, Illinois 60501',19614,24005);
INSERT INTO "django_geo_db_zipcode" VALUES(27002,60504,-6,'Aurora, Illinois 60504',19615,24006);
INSERT INTO "django_geo_db_zipcode" VALUES(27003,60505,-6,'Aurora, Illinois 60505',19615,24007);
INSERT INTO "django_geo_db_zipcode" VALUES(27004,60506,-6,'Aurora, Illinois 60506',19615,24008);
INSERT INTO "django_geo_db_zipcode" VALUES(27005,60507,-6,'Aurora, Illinois 60507',19615,23880);
INSERT INTO "django_geo_db_zipcode" VALUES(27006,60510,-6,'Batavia, Illinois 60510',19616,24009);
INSERT INTO "django_geo_db_zipcode" VALUES(27007,60511,-6,'Big Rock, Illinois 60511',19617,24010);
INSERT INTO "django_geo_db_zipcode" VALUES(27008,60512,-6,'Bristol, Illinois 60512',19618,24011);
INSERT INTO "django_geo_db_zipcode" VALUES(27009,60513,-6,'Brookfield, Illinois 60513',19619,24012);
INSERT INTO "django_geo_db_zipcode" VALUES(27010,60514,-6,'Clarendon Hills, Illinois 60514',19620,24013);
INSERT INTO "django_geo_db_zipcode" VALUES(27011,60515,-6,'Downers Grove, Illinois 60515',19621,24014);
INSERT INTO "django_geo_db_zipcode" VALUES(27012,60516,-6,'Downers Grove, Illinois 60516',19621,24015);
INSERT INTO "django_geo_db_zipcode" VALUES(27013,60517,-6,'Woodridge, Illinois 60517',19622,24016);
INSERT INTO "django_geo_db_zipcode" VALUES(27014,60518,-6,'Earlville, Illinois 60518',19623,24017);
INSERT INTO "django_geo_db_zipcode" VALUES(27015,60519,-6,'Eola, Illinois 60519',19624,24018);
INSERT INTO "django_geo_db_zipcode" VALUES(27016,60520,-6,'Hinckley, Illinois 60520',19625,24019);
INSERT INTO "django_geo_db_zipcode" VALUES(27017,60521,-6,'Hinsdale, Illinois 60521',19626,24020);
INSERT INTO "django_geo_db_zipcode" VALUES(27018,60522,-6,'Hinsdale, Illinois 60522',19626,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27019,60523,-6,'Oak Brook, Illinois 60523',19627,24021);
INSERT INTO "django_geo_db_zipcode" VALUES(27020,60525,-6,'La Grange, Illinois 60525',19628,24022);
INSERT INTO "django_geo_db_zipcode" VALUES(27021,60526,-6,'La Grange Park, Illinois 60526',19629,24023);
INSERT INTO "django_geo_db_zipcode" VALUES(27022,60527,-6,'Hinsdale, Illinois 60527',19626,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27023,60530,-6,'Lee, Illinois 60530',19630,24024);
INSERT INTO "django_geo_db_zipcode" VALUES(27024,60531,-6,'Leland, Illinois 60531',19631,24025);
INSERT INTO "django_geo_db_zipcode" VALUES(27025,60532,-6,'Lisle, Illinois 60532',19632,24026);
INSERT INTO "django_geo_db_zipcode" VALUES(27026,60534,-6,'Lyons, Illinois 60534',19633,24027);
INSERT INTO "django_geo_db_zipcode" VALUES(27027,60536,-6,'Millbrook, Illinois 60536',19634,24028);
INSERT INTO "django_geo_db_zipcode" VALUES(27028,60537,-6,'Millington, Illinois 60537',19635,24029);
INSERT INTO "django_geo_db_zipcode" VALUES(27029,60538,-6,'Montgomery, Illinois 60538',19636,24030);
INSERT INTO "django_geo_db_zipcode" VALUES(27030,60539,-6,'Mooseheart, Illinois 60539',19637,24031);
INSERT INTO "django_geo_db_zipcode" VALUES(27031,60540,-6,'Naperville, Illinois 60540',19638,24032);
INSERT INTO "django_geo_db_zipcode" VALUES(27032,60541,-6,'Newark, Illinois 60541',19639,24033);
INSERT INTO "django_geo_db_zipcode" VALUES(27033,60542,-6,'North Aurora, Illinois 60542',19640,24034);
INSERT INTO "django_geo_db_zipcode" VALUES(27034,60543,-6,'Oswego, Illinois 60543',19641,24035);
INSERT INTO "django_geo_db_zipcode" VALUES(27035,60544,-6,'Plainfield, Illinois 60544',19642,24036);
INSERT INTO "django_geo_db_zipcode" VALUES(27036,60545,-6,'Plano, Illinois 60545',19643,24037);
INSERT INTO "django_geo_db_zipcode" VALUES(27037,60546,-6,'Riverside, Illinois 60546',19644,24038);
INSERT INTO "django_geo_db_zipcode" VALUES(27038,60548,-6,'Sandwich, Illinois 60548',19645,24039);
INSERT INTO "django_geo_db_zipcode" VALUES(27039,60549,-6,'Serena, Illinois 60549',19646,24040);
INSERT INTO "django_geo_db_zipcode" VALUES(27040,60550,-6,'Shabbona, Illinois 60550',19647,24041);
INSERT INTO "django_geo_db_zipcode" VALUES(27041,60551,-6,'Sheridan, Illinois 60551',19648,24042);
INSERT INTO "django_geo_db_zipcode" VALUES(27042,60552,-6,'Somonauk, Illinois 60552',19649,24043);
INSERT INTO "django_geo_db_zipcode" VALUES(27043,60553,-6,'Steward, Illinois 60553',19650,24044);
INSERT INTO "django_geo_db_zipcode" VALUES(27044,60554,-6,'Sugar Grove, Illinois 60554',19651,24045);
INSERT INTO "django_geo_db_zipcode" VALUES(27045,60555,-6,'Warrenville, Illinois 60555',19652,24046);
INSERT INTO "django_geo_db_zipcode" VALUES(27046,60556,-6,'Waterman, Illinois 60556',19653,24047);
INSERT INTO "django_geo_db_zipcode" VALUES(27047,60557,-6,'Wedron, Illinois 60557',19654,24048);
INSERT INTO "django_geo_db_zipcode" VALUES(27048,60558,-6,'Western Springs, Illinois 60558',19655,24049);
INSERT INTO "django_geo_db_zipcode" VALUES(27049,60559,-6,'Westmont, Illinois 60559',19656,24050);
INSERT INTO "django_geo_db_zipcode" VALUES(27050,60560,-6,'Yorkville, Illinois 60560',19657,24051);
INSERT INTO "django_geo_db_zipcode" VALUES(27051,60561,-6,'Darien, Illinois 60561',19658,24052);
INSERT INTO "django_geo_db_zipcode" VALUES(27052,60563,-6,'Naperville, Illinois 60563',19638,24053);
INSERT INTO "django_geo_db_zipcode" VALUES(27053,60564,-6,'Naperville, Illinois 60564',19638,24054);
INSERT INTO "django_geo_db_zipcode" VALUES(27054,60565,-6,'Naperville, Illinois 60565',19638,24055);
INSERT INTO "django_geo_db_zipcode" VALUES(27055,60566,-6,'Naperville, Illinois 60566',19638,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27056,60567,-6,'Naperville, Illinois 60567',19638,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27057,60568,-6,'Aurora, Illinois 60568',19615,24056);
INSERT INTO "django_geo_db_zipcode" VALUES(27058,60570,-6,'Hinsdale, Illinois 60570',19626,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27059,60572,-6,'Aurora, Illinois 60572',19615,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27060,60597,-6,'Fox Valley, Illinois 60597',19659,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27061,60598,-6,'Aurora, Illinois 60598',19615,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27062,60599,-6,'Fox Valley, Illinois 60599',19659,23849);
INSERT INTO "django_geo_db_zipcode" VALUES(27063,60601,-6,'Chicago, Illinois 60601',19660,24057);
INSERT INTO "django_geo_db_zipcode" VALUES(27064,60602,-6,'Chicago, Illinois 60602',19660,24058);
INSERT INTO "django_geo_db_zipcode" VALUES(27065,60603,-6,'Chicago, Illinois 60603',19660,24059);
INSERT INTO "django_geo_db_zipcode" VALUES(27066,60604,-6,'Chicago, Illinois 60604',19660,24060);
INSERT INTO "django_geo_db_zipcode" VALUES(27067,60605,-6,'Chicago, Illinois 60605',19660,24061);
INSERT INTO "django_geo_db_zipcode" VALUES(27068,60606,-6,'Chicago, Illinois 60606',19660,24062);
INSERT INTO "django_geo_db_zipcode" VALUES(27069,60607,-6,'Chicago, Illinois 60607',19660,24063);
INSERT INTO "django_geo_db_zipcode" VALUES(27070,60608,-6,'Chicago, Illinois 60608',19660,24064);
INSERT INTO "django_geo_db_zipcode" VALUES(27071,60609,-6,'Chicago, Illinois 60609',19660,24065);
INSERT INTO "django_geo_db_zipcode" VALUES(27072,60610,-6,'Chicago, Illinois 60610',19660,24066);
INSERT INTO "django_geo_db_zipcode" VALUES(27073,60611,-6,'Chicago, Illinois 60611',19660,24067);
INSERT INTO "django_geo_db_zipcode" VALUES(27074,60612,-6,'Chicago, Illinois 60612',19660,24068);
INSERT INTO "django_geo_db_zipcode" VALUES(27075,60613,-6,'Chicago, Illinois 60613',19660,24069);
INSERT INTO "django_geo_db_zipcode" VALUES(27076,60614,-6,'Chicago, Illinois 60614',19660,24070);
INSERT INTO "django_geo_db_zipcode" VALUES(27077,60615,-6,'Chicago, Illinois 60615',19660,24071);
INSERT INTO "django_geo_db_zipcode" VALUES(27078,60616,-6,'Chicago, Illinois 60616',19660,24072);
INSERT INTO "django_geo_db_zipcode" VALUES(27079,60617,-6,'Chicago, Illinois 60617',19660,24073);
INSERT INTO "django_geo_db_zipcode" VALUES(27080,60618,-6,'Chicago, Illinois 60618',19660,24074);
INSERT INTO "django_geo_db_zipcode" VALUES(27081,60619,-6,'Chicago, Illinois 60619',19660,24075);
INSERT INTO "django_geo_db_zipcode" VALUES(27082,60620,-6,'Chicago, Illinois 60620',19660,24076);
INSERT INTO "django_geo_db_zipcode" VALUES(27083,60621,-6,'Chicago, Illinois 60621',19660,24077);
INSERT INTO "django_geo_db_zipcode" VALUES(27084,60622,-6,'Chicago, Illinois 60622',19660,24078);
INSERT INTO "django_geo_db_zipcode" VALUES(27085,60623,-6,'Chicago, Illinois 60623',19660,24079);
INSERT INTO "django_geo_db_zipcode" VALUES(27086,60624,-6,'Chicago, Illinois 60624',19660,24080);
INSERT INTO "django_geo_db_zipcode" VALUES(27087,60625,-6,'Chicago, Illinois 60625',19660,24081);
INSERT INTO "django_geo_db_zipcode" VALUES(27088,60626,-6,'Chicago, Illinois 60626',19660,24082);
INSERT INTO "django_geo_db_zipcode" VALUES(27089,60628,-6,'Chicago, Illinois 60628',19660,24083);
INSERT INTO "django_geo_db_zipcode" VALUES(27090,60629,-6,'Chicago, Illinois 60629',19660,24084);
INSERT INTO "django_geo_db_zipcode" VALUES(27091,60630,-6,'Chicago, Illinois 60630',19660,24085);
INSERT INTO "django_geo_db_zipcode" VALUES(27092,60631,-6,'Chicago, Illinois 60631',19660,24086);
INSERT INTO "django_geo_db_zipcode" VALUES(27093,60632,-6,'Chicago, Illinois 60632',19660,24087);
INSERT INTO "django_geo_db_zipcode" VALUES(27094,60633,-6,'Chicago, Illinois 60633',19660,24088);
INSERT INTO "django_geo_db_zipcode" VALUES(27095,60634,-6,'Chicago, Illinois 60634',19660,24089);
INSERT INTO "django_geo_db_zipcode" VALUES(27096,60636,-6,'Chicago, Illinois 60636',19660,24090);
INSERT INTO "django_geo_db_zipcode" VALUES(27097,60637,-6,'Chicago, Illinois 60637',19660,24091);
INSERT INTO "django_geo_db_zipcode" VALUES(27098,60638,-6,'Chicago, Illinois 60638',19660,24092);
INSERT INTO "django_geo_db_zipcode" VALUES(27099,60639,-6,'Chicago, Illinois 60639',19660,24093);
INSERT INTO "django_geo_db_zipcode" VALUES(27100,60640,-6,'Chicago, Illinois 60640',19660,24094);
INSERT INTO "django_geo_db_zipcode" VALUES(27101,60641,-6,'Chicago, Illinois 60641',19660,24095);
INSERT INTO "django_geo_db_zipcode" VALUES(27102,60643,-6,'Chicago, Illinois 60643',19660,24096);
INSERT INTO "django_geo_db_zipcode" VALUES(27103,60644,-6,'Chicago, Illinois 60644',19660,24097);
INSERT INTO "django_geo_db_zipcode" VALUES(27104,60645,-6,'Chicago, Illinois 60645',19660,24098);
INSERT INTO "django_geo_db_zipcode" VALUES(27105,60646,-6,'Chicago, Illinois 60646',19660,24099);
INSERT INTO "django_geo_db_zipcode" VALUES(27106,60647,-6,'Chicago, Illinois 60647',19660,24100);
INSERT INTO "django_geo_db_zipcode" VALUES(27107,60648,-6,'Peotone, Illinois 60648',19598,24101);
INSERT INTO "django_geo_db_zipcode" VALUES(27108,60649,-6,'Chicago, Illinois 60649',19660,24102);
INSERT INTO "django_geo_db_zipcode" VALUES(27109,60650,-6,'Chicago, Illinois 60650',19660,24103);
INSERT INTO "django_geo_db_zipcode" VALUES(27110,60651,-6,'Chicago, Illinois 60651',19660,24104);
INSERT INTO "django_geo_db_zipcode" VALUES(27111,60652,-6,'Chicago, Illinois 60652',19660,24105);
INSERT INTO "django_geo_db_zipcode" VALUES(27112,60653,-6,'Chicago, Illinois 60653',19660,24106);
INSERT INTO "django_geo_db_zipcode" VALUES(27113,60654,-6,'Chicago, Illinois 60654',19660,24107);
INSERT INTO "django_geo_db_zipcode" VALUES(27114,60655,-6,'Chicago, Illinois 60655',19660,24108);
INSERT INTO "django_geo_db_zipcode" VALUES(27115,60656,-6,'Chicago, Illinois 60656',19660,24109);
INSERT INTO "django_geo_db_zipcode" VALUES(27116,60657,-6,'Chicago, Illinois 60657',19660,24110);
INSERT INTO "django_geo_db_zipcode" VALUES(27117,60659,-6,'Chicago, Illinois 60659',19660,24111);
INSERT INTO "django_geo_db_zipcode" VALUES(27118,60660,-6,'Chicago, Illinois 60660',19660,24112);
INSERT INTO "django_geo_db_zipcode" VALUES(27119,60661,-6,'Chicago, Illinois 60661',19660,24113);
INSERT INTO "django_geo_db_zipcode" VALUES(27120,60663,-6,'Chicago, Illinois 60663',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27121,60664,-6,'Chicago, Illinois 60664',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27122,60665,-6,'Chicago, Illinois 60665',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27123,60666,-6,'Amf Ohare, Illinois 60666',19661,24114);
INSERT INTO "django_geo_db_zipcode" VALUES(27124,60667,-6,'Chicago, Illinois 60667',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27125,60668,-6,'Chicago, Illinois 60668',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27126,60669,-6,'Chicago, Illinois 60669',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27127,60670,-6,'Chicago, Illinois 60670',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27128,60671,-6,'Chicago, Illinois 60671',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27129,60672,-6,'Chicago, Illinois 60672',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27130,60673,-6,'Chicago, Illinois 60673',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27131,60674,-6,'Chicago, Illinois 60674',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27132,60675,-6,'Chicago, Illinois 60675',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27133,60677,-6,'Chicago, Illinois 60677',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27134,60678,-6,'Chicago, Illinois 60678',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27135,60679,-6,'Chicago, Illinois 60679',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27136,60680,-6,'Chicago, Illinois 60680',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27137,60681,-6,'Chicago, Illinois 60681',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27138,60683,-6,'Chicago, Illinois 60683',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27139,60684,-6,'Chicago, Illinois 60684',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27140,60685,-6,'Chicago, Illinois 60685',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27141,60687,-6,'Chicago, Illinois 60687',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27142,60690,-6,'Chicago, Illinois 60690',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27143,60691,-6,'Chicago, Illinois 60691',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27144,60692,-6,'Chicago, Illinois 60692',19660,24115);
INSERT INTO "django_geo_db_zipcode" VALUES(27145,60693,-6,'Chicago, Illinois 60693',19660,24116);
INSERT INTO "django_geo_db_zipcode" VALUES(27146,60694,-6,'Chicago, Illinois 60694',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27147,60697,-6,'Chicago, Illinois 60697',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27148,60699,-6,'Chicago, Illinois 60699',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27149,60701,-6,'Chicago, Illinois 60701',19660,23775);
INSERT INTO "django_geo_db_zipcode" VALUES(27150,60706,-6,'Harwood Heights, Illinois 60706',19662,24117);
INSERT INTO "django_geo_db_zipcode" VALUES(27151,60707,-6,'Elmwood Park, Illinois 60707',19663,24118);
INSERT INTO "django_geo_db_zipcode" VALUES(27152,60712,-6,'Lincolnwood, Illinois 60712',19664,24119);
INSERT INTO "django_geo_db_zipcode" VALUES(27153,60714,-6,'Niles, Illinois 60714',19665,24120);
INSERT INTO "django_geo_db_zipcode" VALUES(27154,60803,-6,'Alsip, Illinois 60803',19666,24121);
INSERT INTO "django_geo_db_zipcode" VALUES(27155,60804,-6,'Cicero, Illinois 60804',19667,24122);
INSERT INTO "django_geo_db_zipcode" VALUES(27156,60805,-6,'Evergreen Park, Illinois 60805',19668,24123);
INSERT INTO "django_geo_db_zipcode" VALUES(27157,60827,-6,'Riverdale, Illinois 60827',19669,24124);
INSERT INTO "django_geo_db_zipcode" VALUES(27158,60901,-6,'Kankakee, Illinois 60901',19670,24125);
INSERT INTO "django_geo_db_zipcode" VALUES(27159,60902,-6,'Kankakee, Illinois 60902',19670,24126);
INSERT INTO "django_geo_db_zipcode" VALUES(27160,60910,-6,'Aroma Park, Illinois 60910',19671,24127);
INSERT INTO "django_geo_db_zipcode" VALUES(27161,60911,-6,'Ashkum, Illinois 60911',19672,24128);
INSERT INTO "django_geo_db_zipcode" VALUES(27162,60912,-6,'Beaverville, Illinois 60912',19673,24129);
INSERT INTO "django_geo_db_zipcode" VALUES(27163,60913,-6,'Bonfield, Illinois 60913',19674,24130);
INSERT INTO "django_geo_db_zipcode" VALUES(27164,60914,-6,'Bourbonnais, Illinois 60914',19675,24131);
INSERT INTO "django_geo_db_zipcode" VALUES(27165,60915,-6,'Bradley, Illinois 60915',19676,24132);
INSERT INTO "django_geo_db_zipcode" VALUES(27166,60917,-6,'Buckingham, Illinois 60917',19677,24133);
INSERT INTO "django_geo_db_zipcode" VALUES(27167,60918,-6,'Buckley, Illinois 60918',19678,24134);
INSERT INTO "django_geo_db_zipcode" VALUES(27168,60919,-6,'Cabery, Illinois 60919',19679,24135);
INSERT INTO "django_geo_db_zipcode" VALUES(27169,60920,-6,'Campus, Illinois 60920',19680,24136);
INSERT INTO "django_geo_db_zipcode" VALUES(27170,60921,-6,'Chatsworth, Illinois 60921',19681,24137);
INSERT INTO "django_geo_db_zipcode" VALUES(27171,60922,-6,'Chebanse, Illinois 60922',19682,24138);
INSERT INTO "django_geo_db_zipcode" VALUES(27172,60924,-6,'Cissna Park, Illinois 60924',19683,24139);
INSERT INTO "django_geo_db_zipcode" VALUES(27173,60926,-6,'Claytonville, Illinois 60926',19684,24140);
INSERT INTO "django_geo_db_zipcode" VALUES(27174,60927,-6,'Clifton, Illinois 60927',19685,24141);
INSERT INTO "django_geo_db_zipcode" VALUES(27175,60928,-6,'Crescent City, Illinois 60928',19686,24142);
INSERT INTO "django_geo_db_zipcode" VALUES(27176,60929,-6,'Cullom, Illinois 60929',19687,24143);
INSERT INTO "django_geo_db_zipcode" VALUES(27177,60930,-6,'Danforth, Illinois 60930',19688,24144);
INSERT INTO "django_geo_db_zipcode" VALUES(27178,60931,-6,'Donovan, Illinois 60931',19689,24145);
INSERT INTO "django_geo_db_zipcode" VALUES(27179,60932,-6,'East Lynn, Illinois 60932',19690,24146);
INSERT INTO "django_geo_db_zipcode" VALUES(27180,60933,-6,'Elliott, Illinois 60933',19691,24147);
INSERT INTO "django_geo_db_zipcode" VALUES(27181,60934,-6,'Emington, Illinois 60934',19692,24148);
INSERT INTO "django_geo_db_zipcode" VALUES(27182,60935,-6,'Essex, Illinois 60935',19693,24149);
INSERT INTO "django_geo_db_zipcode" VALUES(27183,60936,-6,'Gibson City, Illinois 60936',19694,24150);
INSERT INTO "django_geo_db_zipcode" VALUES(27184,60938,-6,'Gilman, Illinois 60938',19695,24151);
INSERT INTO "django_geo_db_zipcode" VALUES(27185,60939,-6,'Goodwine, Illinois 60939',19696,24152);
INSERT INTO "django_geo_db_zipcode" VALUES(27186,60940,-6,'Grant Park, Illinois 60940',19697,24153);
INSERT INTO "django_geo_db_zipcode" VALUES(27187,60941,-6,'Herscher, Illinois 60941',19698,24154);
INSERT INTO "django_geo_db_zipcode" VALUES(27188,60942,-6,'Hoopeston, Illinois 60942',19699,24155);
INSERT INTO "django_geo_db_zipcode" VALUES(27189,60944,-6,'Hopkins Park, Illinois 60944',19700,24126);
INSERT INTO "django_geo_db_zipcode" VALUES(27190,60945,-6,'Iroquois, Illinois 60945',19701,24156);
INSERT INTO "django_geo_db_zipcode" VALUES(27191,60946,-6,'Kempton, Illinois 60946',19702,24157);
INSERT INTO "django_geo_db_zipcode" VALUES(27192,60948,-6,'Loda, Illinois 60948',19703,24158);
INSERT INTO "django_geo_db_zipcode" VALUES(27193,60949,-6,'Ludlow, Illinois 60949',19704,24159);
INSERT INTO "django_geo_db_zipcode" VALUES(27194,60950,-6,'Manteno, Illinois 60950',19705,24160);
INSERT INTO "django_geo_db_zipcode" VALUES(27195,60951,-6,'Martinton, Illinois 60951',19706,24161);
INSERT INTO "django_geo_db_zipcode" VALUES(27196,60952,-6,'Melvin, Illinois 60952',19707,24162);
INSERT INTO "django_geo_db_zipcode" VALUES(27197,60953,-6,'Milford, Illinois 60953',19708,24163);
INSERT INTO "django_geo_db_zipcode" VALUES(27198,60954,-6,'Momence, Illinois 60954',19709,24164);
INSERT INTO "django_geo_db_zipcode" VALUES(27199,60955,-6,'Onarga, Illinois 60955',19710,24165);
INSERT INTO "django_geo_db_zipcode" VALUES(27200,60956,-6,'Papineau, Illinois 60956',19711,24166);
INSERT INTO "django_geo_db_zipcode" VALUES(27201,60957,-6,'Paxton, Illinois 60957',19712,24167);
INSERT INTO "django_geo_db_zipcode" VALUES(27202,60959,-6,'Piper City, Illinois 60959',19713,24168);
INSERT INTO "django_geo_db_zipcode" VALUES(27203,60960,-6,'Rankin, Illinois 60960',19714,24169);
INSERT INTO "django_geo_db_zipcode" VALUES(27204,60961,-6,'Reddick, Illinois 60961',19715,24170);
INSERT INTO "django_geo_db_zipcode" VALUES(27205,60962,-6,'Roberts, Illinois 60962',19716,24171);
INSERT INTO "django_geo_db_zipcode" VALUES(27206,60963,-6,'Rossville, Illinois 60963',19717,24172);
INSERT INTO "django_geo_db_zipcode" VALUES(27207,60964,-6,'Saint Anne, Illinois 60964',19718,24173);
INSERT INTO "django_geo_db_zipcode" VALUES(27208,60966,-6,'Sheldon, Illinois 60966',19719,24174);
INSERT INTO "django_geo_db_zipcode" VALUES(27209,60967,-6,'Stockland, Illinois 60967',19720,24175);
INSERT INTO "django_geo_db_zipcode" VALUES(27210,60968,-6,'Thawville, Illinois 60968',19721,24176);
INSERT INTO "django_geo_db_zipcode" VALUES(27211,60969,-6,'Union Hill, Illinois 60969',19722,24177);
INSERT INTO "django_geo_db_zipcode" VALUES(27212,60970,-6,'Watseka, Illinois 60970',19723,24178);
INSERT INTO "django_geo_db_zipcode" VALUES(27213,60973,-6,'Wellington, Illinois 60973',19724,24179);
INSERT INTO "django_geo_db_zipcode" VALUES(27214,60974,-6,'Woodland, Illinois 60974',19725,24180);
INSERT INTO "django_geo_db_zipcode" VALUES(27215,61001,-6,'Apple River, Illinois 61001',19726,24181);
INSERT INTO "django_geo_db_zipcode" VALUES(27216,61006,-6,'Ashton, Illinois 61006',19727,24182);
INSERT INTO "django_geo_db_zipcode" VALUES(27217,61007,-6,'Baileyville, Illinois 61007',19728,24183);
INSERT INTO "django_geo_db_zipcode" VALUES(27218,61008,-6,'Belvidere, Illinois 61008',19729,24184);
INSERT INTO "django_geo_db_zipcode" VALUES(27219,61010,-6,'Byron, Illinois 61010',19730,24185);
INSERT INTO "django_geo_db_zipcode" VALUES(27220,61011,-6,'Caledonia, Illinois 61011',19731,24186);
INSERT INTO "django_geo_db_zipcode" VALUES(27221,61012,-6,'Capron, Illinois 61012',19732,24187);
INSERT INTO "django_geo_db_zipcode" VALUES(27222,61013,-6,'Cedarville, Illinois 61013',19733,24188);
INSERT INTO "django_geo_db_zipcode" VALUES(27223,61014,-6,'Chadwick, Illinois 61014',19734,24189);
INSERT INTO "django_geo_db_zipcode" VALUES(27224,61015,-6,'Chana, Illinois 61015',19735,24190);
INSERT INTO "django_geo_db_zipcode" VALUES(27225,61016,-6,'Cherry Valley, Illinois 61016',19736,24191);
INSERT INTO "django_geo_db_zipcode" VALUES(27226,61017,-6,'Coleta, Illinois 61017',19737,24192);
INSERT INTO "django_geo_db_zipcode" VALUES(27227,61018,-6,'Dakota, Illinois 61018',19738,24193);
INSERT INTO "django_geo_db_zipcode" VALUES(27228,61019,-6,'Davis, Illinois 61019',19739,24194);
INSERT INTO "django_geo_db_zipcode" VALUES(27229,61020,-6,'Davis Junction, Illinois 61020',19740,24195);
INSERT INTO "django_geo_db_zipcode" VALUES(27230,61021,-6,'Dixon, Illinois 61021',19741,24196);
INSERT INTO "django_geo_db_zipcode" VALUES(27231,61024,-6,'Durand, Illinois 61024',19742,24197);
INSERT INTO "django_geo_db_zipcode" VALUES(27232,61025,-6,'East Dubuque, Illinois 61025',19743,24198);
INSERT INTO "django_geo_db_zipcode" VALUES(27233,61027,-6,'Eleroy, Illinois 61027',19744,24199);
INSERT INTO "django_geo_db_zipcode" VALUES(27234,61028,-6,'Elizabeth, Illinois 61028',19745,24200);
INSERT INTO "django_geo_db_zipcode" VALUES(27235,61030,-6,'Forreston, Illinois 61030',19746,24201);
INSERT INTO "django_geo_db_zipcode" VALUES(27236,61031,-6,'Franklin Grove, Illinois 61031',19747,24202);
INSERT INTO "django_geo_db_zipcode" VALUES(27237,61032,-6,'Freeport, Illinois 61032',19748,24203);
INSERT INTO "django_geo_db_zipcode" VALUES(27238,61036,-6,'Galena, Illinois 61036',19749,24204);
INSERT INTO "django_geo_db_zipcode" VALUES(27239,61037,-6,'Galt, Illinois 61037',19750,24205);
INSERT INTO "django_geo_db_zipcode" VALUES(27240,61038,-6,'Garden Prairie, Illinois 61038',19751,24206);
INSERT INTO "django_geo_db_zipcode" VALUES(27241,61039,-6,'German Valley, Illinois 61039',19752,24207);
INSERT INTO "django_geo_db_zipcode" VALUES(27242,61041,-6,'Hanover, Illinois 61041',19753,24208);
INSERT INTO "django_geo_db_zipcode" VALUES(27243,61042,-6,'Harmon, Illinois 61042',19754,24209);
INSERT INTO "django_geo_db_zipcode" VALUES(27244,61043,-6,'Holcomb, Illinois 61043',19755,24210);
INSERT INTO "django_geo_db_zipcode" VALUES(27245,61044,-6,'Kent, Illinois 61044',19756,24211);
INSERT INTO "django_geo_db_zipcode" VALUES(27246,61046,-6,'Lanark, Illinois 61046',19757,24212);
INSERT INTO "django_geo_db_zipcode" VALUES(27247,61047,-6,'Leaf River, Illinois 61047',19758,24213);
INSERT INTO "django_geo_db_zipcode" VALUES(27248,61048,-6,'Lena, Illinois 61048',19759,24214);
INSERT INTO "django_geo_db_zipcode" VALUES(27249,61049,-6,'Lindenwood, Illinois 61049',19760,24215);
INSERT INTO "django_geo_db_zipcode" VALUES(27250,61050,-6,'McConnell, Illinois 61050',19761,24216);
INSERT INTO "django_geo_db_zipcode" VALUES(27251,61051,-6,'Milledgeville, Illinois 61051',19762,24217);
INSERT INTO "django_geo_db_zipcode" VALUES(27252,61052,-6,'Monroe Center, Illinois 61052',19763,24218);
INSERT INTO "django_geo_db_zipcode" VALUES(27253,61053,-6,'Mount Carroll, Illinois 61053',19764,24219);
INSERT INTO "django_geo_db_zipcode" VALUES(27254,61054,-6,'Mount Morris, Illinois 61054',19765,24220);
INSERT INTO "django_geo_db_zipcode" VALUES(27255,61057,-6,'Nachusa, Illinois 61057',19766,24221);
INSERT INTO "django_geo_db_zipcode" VALUES(27256,61058,-6,'Nelson, Illinois 61058',19767,24222);
INSERT INTO "django_geo_db_zipcode" VALUES(27257,61059,-6,'Nora, Illinois 61059',19768,24223);
INSERT INTO "django_geo_db_zipcode" VALUES(27258,61060,-6,'Orangeville, Illinois 61060',19769,24224);
INSERT INTO "django_geo_db_zipcode" VALUES(27259,61061,-6,'Oregon, Illinois 61061',19770,24225);
INSERT INTO "django_geo_db_zipcode" VALUES(27260,61062,-6,'Pearl City, Illinois 61062',19771,24226);
INSERT INTO "django_geo_db_zipcode" VALUES(27261,61063,-6,'Pecatonica, Illinois 61063',19772,24227);
INSERT INTO "django_geo_db_zipcode" VALUES(27262,61064,-6,'Polo, Illinois 61064',19773,24228);
INSERT INTO "django_geo_db_zipcode" VALUES(27263,61065,-6,'Poplar Grove, Illinois 61065',19774,24229);
INSERT INTO "django_geo_db_zipcode" VALUES(27264,61067,-6,'Ridott, Illinois 61067',19775,24230);
INSERT INTO "django_geo_db_zipcode" VALUES(27265,61068,-6,'Rochelle, Illinois 61068',19776,24231);
INSERT INTO "django_geo_db_zipcode" VALUES(27266,61070,-6,'Rock City, Illinois 61070',19777,24232);
INSERT INTO "django_geo_db_zipcode" VALUES(27267,61071,-6,'Rock Falls, Illinois 61071',19778,24233);
INSERT INTO "django_geo_db_zipcode" VALUES(27268,61072,-6,'Rockton, Illinois 61072',19779,24234);
INSERT INTO "django_geo_db_zipcode" VALUES(27269,61073,-6,'Roscoe, Illinois 61073',19780,24235);
INSERT INTO "django_geo_db_zipcode" VALUES(27270,61074,-6,'Savanna, Illinois 61074',19781,24236);
INSERT INTO "django_geo_db_zipcode" VALUES(27271,61075,-6,'Scales Mound, Illinois 61075',19782,24237);
INSERT INTO "django_geo_db_zipcode" VALUES(27272,61076,-6,'Scioto Mills, Illinois 61076',19783,24238);
INSERT INTO "django_geo_db_zipcode" VALUES(27273,61077,-6,'Seward, Illinois 61077',19784,24239);
INSERT INTO "django_geo_db_zipcode" VALUES(27274,61078,-6,'Shannon, Illinois 61078',19785,24240);
INSERT INTO "django_geo_db_zipcode" VALUES(27275,61079,-6,'Shirland, Illinois 61079',19786,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27276,61080,-6,'South Beloit, Illinois 61080',19787,24242);
INSERT INTO "django_geo_db_zipcode" VALUES(27277,61081,-6,'Sterling, Illinois 61081',19788,24243);
INSERT INTO "django_geo_db_zipcode" VALUES(27278,61084,-6,'Stillman Valley, Illinois 61084',19789,24244);
INSERT INTO "django_geo_db_zipcode" VALUES(27279,61085,-6,'Stockton, Illinois 61085',19790,24245);
INSERT INTO "django_geo_db_zipcode" VALUES(27280,61087,-6,'Warren, Illinois 61087',19791,24246);
INSERT INTO "django_geo_db_zipcode" VALUES(27281,61088,-6,'Winnebago, Illinois 61088',19792,24247);
INSERT INTO "django_geo_db_zipcode" VALUES(27282,61089,-6,'Winslow, Illinois 61089',19793,24248);
INSERT INTO "django_geo_db_zipcode" VALUES(27283,61091,-6,'Woosung, Illinois 61091',19794,24249);
INSERT INTO "django_geo_db_zipcode" VALUES(27284,61101,-6,'Rockford, Illinois 61101',19795,24250);
INSERT INTO "django_geo_db_zipcode" VALUES(27285,61102,-6,'Rockford, Illinois 61102',19795,24251);
INSERT INTO "django_geo_db_zipcode" VALUES(27286,61103,-6,'Rockford, Illinois 61103',19795,24252);
INSERT INTO "django_geo_db_zipcode" VALUES(27287,61104,-6,'Rockford, Illinois 61104',19795,24253);
INSERT INTO "django_geo_db_zipcode" VALUES(27288,61105,-6,'Rockford, Illinois 61105',19795,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27289,61106,-6,'Rockford, Illinois 61106',19795,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27290,61107,-6,'Rockford, Illinois 61107',19795,24254);
INSERT INTO "django_geo_db_zipcode" VALUES(27291,61108,-6,'Rockford, Illinois 61108',19795,24255);
INSERT INTO "django_geo_db_zipcode" VALUES(27292,61109,-6,'Rockford, Illinois 61109',19795,24256);
INSERT INTO "django_geo_db_zipcode" VALUES(27293,61110,-6,'Rockford, Illinois 61110',19795,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27294,61111,-6,'Loves Park, Illinois 61111',19796,24257);
INSERT INTO "django_geo_db_zipcode" VALUES(27295,61112,-6,'Rockford, Illinois 61112',19795,24258);
INSERT INTO "django_geo_db_zipcode" VALUES(27296,61114,-6,'Rockford, Illinois 61114',19795,24259);
INSERT INTO "django_geo_db_zipcode" VALUES(27297,61115,-6,'Machesney Park, Illinois 61115',19797,24260);
INSERT INTO "django_geo_db_zipcode" VALUES(27298,61125,-6,'Rockford, Illinois 61125',19795,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27299,61126,-6,'Rockford, Illinois 61126',19795,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27300,61130,-6,'Loves Park, Illinois 61130',19796,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27301,61131,-6,'Loves Park, Illinois 61131',19796,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27302,61132,-6,'Loves Park, Illinois 61132',19796,24241);
INSERT INTO "django_geo_db_zipcode" VALUES(27303,61201,-6,'Rock Island, Illinois 61201',19798,24261);
INSERT INTO "django_geo_db_zipcode" VALUES(27304,61202,-6,'Rock Island, Illinois 61202',19798,24262);
INSERT INTO "django_geo_db_zipcode" VALUES(27305,61204,-6,'Rock Island, Illinois 61204',19798,24263);
INSERT INTO "django_geo_db_zipcode" VALUES(27306,61206,-6,'Rock Island, Illinois 61206',19798,24263);
INSERT INTO "django_geo_db_zipcode" VALUES(27307,61230,-6,'Albany, Illinois 61230',19799,24264);
INSERT INTO "django_geo_db_zipcode" VALUES(27308,61231,-6,'Aledo, Illinois 61231',19800,24265);
INSERT INTO "django_geo_db_zipcode" VALUES(27309,61232,-6,'Andalusia, Illinois 61232',19801,24266);
INSERT INTO "django_geo_db_zipcode" VALUES(27310,61233,-6,'Andover, Illinois 61233',19802,24267);
INSERT INTO "django_geo_db_zipcode" VALUES(27311,61234,-6,'Annawan, Illinois 61234',19803,24268);
INSERT INTO "django_geo_db_zipcode" VALUES(27312,61235,-6,'Atkinson, Illinois 61235',19804,24269);
INSERT INTO "django_geo_db_zipcode" VALUES(27313,61236,-6,'Barstow, Illinois 61236',19805,24270);
INSERT INTO "django_geo_db_zipcode" VALUES(27314,61237,-6,'Buffalo Prairie, Illinois 61237',19806,24271);
INSERT INTO "django_geo_db_zipcode" VALUES(27315,61238,-6,'Cambridge, Illinois 61238',19807,24272);
INSERT INTO "django_geo_db_zipcode" VALUES(27316,61239,-6,'Carbon Cliff, Illinois 61239',19808,24273);
INSERT INTO "django_geo_db_zipcode" VALUES(27317,61240,-6,'Coal Valley, Illinois 61240',19809,24274);
INSERT INTO "django_geo_db_zipcode" VALUES(27318,61241,-6,'Colona, Illinois 61241',19810,24275);
INSERT INTO "django_geo_db_zipcode" VALUES(27319,61242,-6,'Cordova, Illinois 61242',19811,24276);
INSERT INTO "django_geo_db_zipcode" VALUES(27320,61243,-6,'Deer Grove, Illinois 61243',19812,24277);
INSERT INTO "django_geo_db_zipcode" VALUES(27321,61244,-6,'East Moline, Illinois 61244',19813,24278);
INSERT INTO "django_geo_db_zipcode" VALUES(27322,61250,-6,'Erie, Illinois 61250',19814,24279);
INSERT INTO "django_geo_db_zipcode" VALUES(27323,61251,-6,'Fenton, Illinois 61251',19815,24280);
INSERT INTO "django_geo_db_zipcode" VALUES(27324,61252,-6,'Fulton, Illinois 61252',19816,24281);
INSERT INTO "django_geo_db_zipcode" VALUES(27325,61254,-6,'Geneseo, Illinois 61254',19817,24282);
INSERT INTO "django_geo_db_zipcode" VALUES(27326,61256,-6,'Hampton, Illinois 61256',19818,24283);
INSERT INTO "django_geo_db_zipcode" VALUES(27327,61257,-6,'Hillsdale, Illinois 61257',19819,24284);
INSERT INTO "django_geo_db_zipcode" VALUES(27328,61258,-6,'Hooppole, Illinois 61258',19820,24285);
INSERT INTO "django_geo_db_zipcode" VALUES(27329,61259,-6,'Illinois City, Illinois 61259',19821,24286);
INSERT INTO "django_geo_db_zipcode" VALUES(27330,61260,-6,'Joy, Illinois 61260',19822,24287);
INSERT INTO "django_geo_db_zipcode" VALUES(27331,61261,-6,'Lyndon, Illinois 61261',19823,24288);
INSERT INTO "django_geo_db_zipcode" VALUES(27332,61262,-6,'Lynn Center, Illinois 61262',19824,24289);
INSERT INTO "django_geo_db_zipcode" VALUES(27333,61263,-6,'Matherville, Illinois 61263',19825,24290);
INSERT INTO "django_geo_db_zipcode" VALUES(27334,61264,-6,'Milan, Illinois 61264',19826,24291);
INSERT INTO "django_geo_db_zipcode" VALUES(27335,61265,-6,'Moline, Illinois 61265',19827,24292);
INSERT INTO "django_geo_db_zipcode" VALUES(27336,61266,-6,'Moline, Illinois 61266',19827,24263);
INSERT INTO "django_geo_db_zipcode" VALUES(27337,61270,-6,'Morrison, Illinois 61270',19828,24293);
INSERT INTO "django_geo_db_zipcode" VALUES(27338,61272,-6,'New Boston, Illinois 61272',19829,24294);
INSERT INTO "django_geo_db_zipcode" VALUES(27339,61273,-6,'Orion, Illinois 61273',19830,24295);
INSERT INTO "django_geo_db_zipcode" VALUES(27340,61274,-6,'Osco, Illinois 61274',19831,24296);
INSERT INTO "django_geo_db_zipcode" VALUES(27341,61275,-6,'Port Byron, Illinois 61275',19832,24297);
INSERT INTO "django_geo_db_zipcode" VALUES(27342,61276,-6,'Preemption, Illinois 61276',19833,24298);
INSERT INTO "django_geo_db_zipcode" VALUES(27343,61277,-6,'Prophetstown, Illinois 61277',19834,24299);
INSERT INTO "django_geo_db_zipcode" VALUES(27344,61278,-6,'Rapids City, Illinois 61278',19835,24300);
INSERT INTO "django_geo_db_zipcode" VALUES(27345,61279,-6,'Reynolds, Illinois 61279',19836,24301);
INSERT INTO "django_geo_db_zipcode" VALUES(27346,61281,-6,'Sherrard, Illinois 61281',19837,24302);
INSERT INTO "django_geo_db_zipcode" VALUES(27347,61282,-6,'Silvis, Illinois 61282',19838,24303);
INSERT INTO "django_geo_db_zipcode" VALUES(27348,61283,-6,'Tampico, Illinois 61283',19839,24304);
INSERT INTO "django_geo_db_zipcode" VALUES(27349,61284,-6,'Taylor Ridge, Illinois 61284',19840,24305);
INSERT INTO "django_geo_db_zipcode" VALUES(27350,61285,-6,'Thomson, Illinois 61285',19841,24306);
INSERT INTO "django_geo_db_zipcode" VALUES(27351,61299,-6,'Rock Island, Illinois 61299',19798,24307);
INSERT INTO "django_geo_db_zipcode" VALUES(27352,61301,-6,'La Salle, Illinois 61301',19842,24308);
INSERT INTO "django_geo_db_zipcode" VALUES(27353,61310,-6,'Amboy, Illinois 61310',19843,24309);
INSERT INTO "django_geo_db_zipcode" VALUES(27354,61311,-6,'Ancona, Illinois 61311',19844,24310);
INSERT INTO "django_geo_db_zipcode" VALUES(27355,61312,-6,'Arlington, Illinois 61312',19845,24311);
INSERT INTO "django_geo_db_zipcode" VALUES(27356,61313,-6,'Blackstone, Illinois 61313',19846,24312);
INSERT INTO "django_geo_db_zipcode" VALUES(27357,61314,-6,'Buda, Illinois 61314',19847,24313);
INSERT INTO "django_geo_db_zipcode" VALUES(27358,61315,-6,'Bureau, Illinois 61315',19848,24314);
INSERT INTO "django_geo_db_zipcode" VALUES(27359,61316,-6,'Cedar Point, Illinois 61316',19849,24315);
INSERT INTO "django_geo_db_zipcode" VALUES(27360,61317,-6,'Cherry, Illinois 61317',19850,24316);
INSERT INTO "django_geo_db_zipcode" VALUES(27361,61318,-6,'Compton, Illinois 61318',19851,24317);
INSERT INTO "django_geo_db_zipcode" VALUES(27362,61319,-6,'Cornell, Illinois 61319',19852,24318);
INSERT INTO "django_geo_db_zipcode" VALUES(27363,61320,-6,'Dalzell, Illinois 61320',19853,24319);
INSERT INTO "django_geo_db_zipcode" VALUES(27364,61321,-6,'Dana, Illinois 61321',19854,24320);
INSERT INTO "django_geo_db_zipcode" VALUES(27365,61322,-6,'Depue, Illinois 61322',19855,24321);
INSERT INTO "django_geo_db_zipcode" VALUES(27366,61323,-6,'Dover, Illinois 61323',19856,24322);
INSERT INTO "django_geo_db_zipcode" VALUES(27367,61324,-6,'Eldena, Illinois 61324',19857,24323);
INSERT INTO "django_geo_db_zipcode" VALUES(27368,61325,-6,'Grand Ridge, Illinois 61325',19858,24324);
INSERT INTO "django_geo_db_zipcode" VALUES(27369,61326,-6,'Granville, Illinois 61326',19859,24325);
INSERT INTO "django_geo_db_zipcode" VALUES(27370,61327,-6,'Hennepin, Illinois 61327',19860,24326);
INSERT INTO "django_geo_db_zipcode" VALUES(27371,61328,-6,'Kasbeer, Illinois 61328',19861,24327);
INSERT INTO "django_geo_db_zipcode" VALUES(27372,61329,-6,'Ladd, Illinois 61329',19862,24328);
INSERT INTO "django_geo_db_zipcode" VALUES(27373,61330,-6,'La Moille, Illinois 61330',19863,24329);
INSERT INTO "django_geo_db_zipcode" VALUES(27374,61331,-6,'Lee Center, Illinois 61331',19864,24330);
INSERT INTO "django_geo_db_zipcode" VALUES(27375,61332,-6,'Leonore, Illinois 61332',19865,24331);
INSERT INTO "django_geo_db_zipcode" VALUES(27376,61333,-6,'Long Point, Illinois 61333',19866,24332);
INSERT INTO "django_geo_db_zipcode" VALUES(27377,61334,-6,'Lostant, Illinois 61334',19867,24333);
INSERT INTO "django_geo_db_zipcode" VALUES(27378,61335,-6,'McNabb, Illinois 61335',19868,24334);
INSERT INTO "django_geo_db_zipcode" VALUES(27379,61336,-6,'Magnolia, Illinois 61336',19869,24335);
INSERT INTO "django_geo_db_zipcode" VALUES(27380,61337,-6,'Malden, Illinois 61337',19870,24336);
INSERT INTO "django_geo_db_zipcode" VALUES(27381,61338,-6,'Manlius, Illinois 61338',19871,24337);
INSERT INTO "django_geo_db_zipcode" VALUES(27382,61340,-6,'Mark, Illinois 61340',19872,24338);
INSERT INTO "django_geo_db_zipcode" VALUES(27383,61341,-6,'Marseilles, Illinois 61341',19873,24339);
INSERT INTO "django_geo_db_zipcode" VALUES(27384,61342,-6,'Mendota, Illinois 61342',19874,24340);
INSERT INTO "django_geo_db_zipcode" VALUES(27385,61344,-6,'Mineral, Illinois 61344',19875,24341);
INSERT INTO "django_geo_db_zipcode" VALUES(27386,61345,-6,'Neponset, Illinois 61345',19876,24342);
INSERT INTO "django_geo_db_zipcode" VALUES(27387,61346,-6,'New Bedford, Illinois 61346',19877,24343);
INSERT INTO "django_geo_db_zipcode" VALUES(27388,61348,-6,'Oglesby, Illinois 61348',19878,24344);
INSERT INTO "django_geo_db_zipcode" VALUES(27389,61349,-6,'Ohio, Illinois 61349',19879,24345);
INSERT INTO "django_geo_db_zipcode" VALUES(27390,61350,-6,'Ottawa, Illinois 61350',19880,24346);
INSERT INTO "django_geo_db_zipcode" VALUES(27391,61353,-6,'Paw Paw, Illinois 61353',19881,24347);
INSERT INTO "django_geo_db_zipcode" VALUES(27392,61354,-6,'Peru, Illinois 61354',19882,24348);
INSERT INTO "django_geo_db_zipcode" VALUES(27393,61356,-6,'Princeton, Illinois 61356',19883,24349);
INSERT INTO "django_geo_db_zipcode" VALUES(27394,61358,-6,'Rutland, Illinois 61358',19884,24350);
INSERT INTO "django_geo_db_zipcode" VALUES(27395,61359,-6,'Seatonville, Illinois 61359',19885,24351);
INSERT INTO "django_geo_db_zipcode" VALUES(27396,61360,-6,'Seneca, Illinois 61360',19886,24352);
INSERT INTO "django_geo_db_zipcode" VALUES(27397,61361,-6,'Sheffield, Illinois 61361',19887,24353);
INSERT INTO "django_geo_db_zipcode" VALUES(27398,61362,-6,'Spring Valley, Illinois 61362',19888,24354);
INSERT INTO "django_geo_db_zipcode" VALUES(27399,61363,-6,'Standard, Illinois 61363',19889,24355);
INSERT INTO "django_geo_db_zipcode" VALUES(27400,61364,-6,'Streator, Illinois 61364',19890,24356);
INSERT INTO "django_geo_db_zipcode" VALUES(27401,61367,-6,'Sublette, Illinois 61367',19891,24357);
INSERT INTO "django_geo_db_zipcode" VALUES(27402,61368,-6,'Tiskilwa, Illinois 61368',19892,24358);
INSERT INTO "django_geo_db_zipcode" VALUES(27403,61369,-6,'Toluca, Illinois 61369',19893,24359);
INSERT INTO "django_geo_db_zipcode" VALUES(27404,61370,-6,'Tonica, Illinois 61370',19894,24360);
INSERT INTO "django_geo_db_zipcode" VALUES(27405,61371,-6,'Triumph, Illinois 61371',19895,24361);
INSERT INTO "django_geo_db_zipcode" VALUES(27406,61372,-6,'Troy Grove, Illinois 61372',19896,24362);
INSERT INTO "django_geo_db_zipcode" VALUES(27407,61373,-6,'Utica, Illinois 61373',19897,24363);
INSERT INTO "django_geo_db_zipcode" VALUES(27408,61374,-6,'Van Orin, Illinois 61374',19898,24364);
INSERT INTO "django_geo_db_zipcode" VALUES(27409,61375,-6,'Varna, Illinois 61375',19899,24365);
INSERT INTO "django_geo_db_zipcode" VALUES(27410,61376,-6,'Walnut, Illinois 61376',19900,24366);
INSERT INTO "django_geo_db_zipcode" VALUES(27411,61377,-6,'Wenona, Illinois 61377',19901,24367);
INSERT INTO "django_geo_db_zipcode" VALUES(27412,61378,-6,'West Brooklyn, Illinois 61378',19902,24368);
INSERT INTO "django_geo_db_zipcode" VALUES(27413,61379,-6,'Wyanet, Illinois 61379',19903,24369);
INSERT INTO "django_geo_db_zipcode" VALUES(27414,61401,-6,'Galesburg, Illinois 61401',19904,24370);
INSERT INTO "django_geo_db_zipcode" VALUES(27415,61402,-6,'Galesburg, Illinois 61402',19904,24371);
INSERT INTO "django_geo_db_zipcode" VALUES(27416,61410,-6,'Abingdon, Illinois 61410',19905,24372);
INSERT INTO "django_geo_db_zipcode" VALUES(27417,61411,-6,'Adair, Illinois 61411',19906,24373);
INSERT INTO "django_geo_db_zipcode" VALUES(27418,61412,-6,'Alexis, Illinois 61412',19907,24374);
INSERT INTO "django_geo_db_zipcode" VALUES(27419,61413,-6,'Alpha, Illinois 61413',19908,24375);
INSERT INTO "django_geo_db_zipcode" VALUES(27420,61414,-6,'Altona, Illinois 61414',19909,24376);
INSERT INTO "django_geo_db_zipcode" VALUES(27421,61415,-6,'Avon, Illinois 61415',19910,24377);
INSERT INTO "django_geo_db_zipcode" VALUES(27422,61416,-6,'Bardolph, Illinois 61416',19911,24378);
INSERT INTO "django_geo_db_zipcode" VALUES(27423,61417,-6,'Berwick, Illinois 61417',19912,24379);
INSERT INTO "django_geo_db_zipcode" VALUES(27424,61418,-6,'Biggsville, Illinois 61418',19913,24380);
INSERT INTO "django_geo_db_zipcode" VALUES(27425,61419,-6,'Bishop Hill, Illinois 61419',19914,24381);
INSERT INTO "django_geo_db_zipcode" VALUES(27426,61420,-6,'Blandinsville, Illinois 61420',19915,24382);
INSERT INTO "django_geo_db_zipcode" VALUES(27427,61421,-6,'Bradford, Illinois 61421',19916,24383);
INSERT INTO "django_geo_db_zipcode" VALUES(27428,61422,-6,'Bushnell, Illinois 61422',19917,24384);
INSERT INTO "django_geo_db_zipcode" VALUES(27429,61423,-6,'Cameron, Illinois 61423',19918,24385);
INSERT INTO "django_geo_db_zipcode" VALUES(27430,61424,-6,'Camp Grove, Illinois 61424',19919,24386);
INSERT INTO "django_geo_db_zipcode" VALUES(27431,61425,-6,'Carman, Illinois 61425',19920,24387);
INSERT INTO "django_geo_db_zipcode" VALUES(27432,61426,-6,'Castleton, Illinois 61426',19921,24388);
INSERT INTO "django_geo_db_zipcode" VALUES(27433,61427,-6,'Cuba, Illinois 61427',19922,24389);
INSERT INTO "django_geo_db_zipcode" VALUES(27434,61428,-6,'Dahinda, Illinois 61428',19923,24390);
INSERT INTO "django_geo_db_zipcode" VALUES(27435,61430,-6,'East Galesburg, Illinois 61430',19924,24391);
INSERT INTO "django_geo_db_zipcode" VALUES(27436,61431,-6,'Ellisville, Illinois 61431',19925,24392);
INSERT INTO "django_geo_db_zipcode" VALUES(27437,61432,-6,'Fairview, Illinois 61432',19926,24393);
INSERT INTO "django_geo_db_zipcode" VALUES(27438,61433,-6,'Fiatt, Illinois 61433',19927,24394);
INSERT INTO "django_geo_db_zipcode" VALUES(27439,61434,-6,'Galva, Illinois 61434',19928,24395);
INSERT INTO "django_geo_db_zipcode" VALUES(27440,61435,-6,'Gerlaw, Illinois 61435',19929,24396);
INSERT INTO "django_geo_db_zipcode" VALUES(27441,61436,-6,'Gilson, Illinois 61436',19930,24397);
INSERT INTO "django_geo_db_zipcode" VALUES(27442,61437,-6,'Gladstone, Illinois 61437',19931,24398);
INSERT INTO "django_geo_db_zipcode" VALUES(27443,61438,-6,'Good Hope, Illinois 61438',19932,24399);
INSERT INTO "django_geo_db_zipcode" VALUES(27444,61439,-6,'Henderson, Illinois 61439',19933,24400);
INSERT INTO "django_geo_db_zipcode" VALUES(27445,61440,-6,'Industry, Illinois 61440',19934,24401);
INSERT INTO "django_geo_db_zipcode" VALUES(27446,61441,-6,'Ipava, Illinois 61441',19935,24402);
INSERT INTO "django_geo_db_zipcode" VALUES(27447,61442,-6,'Keithsburg, Illinois 61442',19936,24403);
INSERT INTO "django_geo_db_zipcode" VALUES(27448,61443,-6,'Kewanee, Illinois 61443',19937,24404);
INSERT INTO "django_geo_db_zipcode" VALUES(27449,61447,-6,'Kirkwood, Illinois 61447',19938,24405);
INSERT INTO "django_geo_db_zipcode" VALUES(27450,61448,-6,'Knoxville, Illinois 61448',19939,24406);
INSERT INTO "django_geo_db_zipcode" VALUES(27451,61449,-6,'La Fayette, Illinois 61449',19940,24407);
INSERT INTO "django_geo_db_zipcode" VALUES(27452,61450,-6,'La Harpe, Illinois 61450',19941,24408);
INSERT INTO "django_geo_db_zipcode" VALUES(27453,61451,-6,'Laura, Illinois 61451',19942,24409);
INSERT INTO "django_geo_db_zipcode" VALUES(27454,61452,-6,'Littleton, Illinois 61452',19943,24410);
INSERT INTO "django_geo_db_zipcode" VALUES(27455,61453,-6,'Little York, Illinois 61453',19944,24411);
INSERT INTO "django_geo_db_zipcode" VALUES(27456,61454,-6,'Lomax, Illinois 61454',19945,24412);
INSERT INTO "django_geo_db_zipcode" VALUES(27457,61455,-6,'Macomb, Illinois 61455',19946,24413);
INSERT INTO "django_geo_db_zipcode" VALUES(27458,61457,-6,'Lee, Illinois 61457',19630,24414);
INSERT INTO "django_geo_db_zipcode" VALUES(27459,61458,-6,'Maquon, Illinois 61458',19947,24415);
INSERT INTO "django_geo_db_zipcode" VALUES(27460,61459,-6,'Marietta, Illinois 61459',19948,24416);
INSERT INTO "django_geo_db_zipcode" VALUES(27461,61460,-6,'Media, Illinois 61460',19949,24417);
INSERT INTO "django_geo_db_zipcode" VALUES(27462,61462,-6,'Monmouth, Illinois 61462',19950,24418);
INSERT INTO "django_geo_db_zipcode" VALUES(27463,61465,-6,'New Windsor, Illinois 61465',19951,24419);
INSERT INTO "django_geo_db_zipcode" VALUES(27464,61466,-6,'North Henderson, Illinois 61466',19952,24420);
INSERT INTO "django_geo_db_zipcode" VALUES(27465,61467,-6,'Oneida, Illinois 61467',19953,24421);
INSERT INTO "django_geo_db_zipcode" VALUES(27466,61468,-6,'Opheim, Illinois 61468',19954,24422);
INSERT INTO "django_geo_db_zipcode" VALUES(27467,61469,-6,'Oquawka, Illinois 61469',19955,24423);
INSERT INTO "django_geo_db_zipcode" VALUES(27468,61470,-6,'Prairie City, Illinois 61470',19956,24424);
INSERT INTO "django_geo_db_zipcode" VALUES(27469,61471,-6,'Raritan, Illinois 61471',19957,24425);
INSERT INTO "django_geo_db_zipcode" VALUES(27470,61472,-6,'Rio, Illinois 61472',19958,24426);
INSERT INTO "django_geo_db_zipcode" VALUES(27471,61473,-6,'Roseville, Illinois 61473',19959,24427);
INSERT INTO "django_geo_db_zipcode" VALUES(27472,61474,-6,'Saint Augustine, Illinois 61474',19960,24428);
INSERT INTO "django_geo_db_zipcode" VALUES(27473,61475,-6,'Sciota, Illinois 61475',19961,24429);
INSERT INTO "django_geo_db_zipcode" VALUES(27474,61476,-6,'Seaton, Illinois 61476',19962,24430);
INSERT INTO "django_geo_db_zipcode" VALUES(27475,61477,-6,'Smithfield, Illinois 61477',19963,24431);
INSERT INTO "django_geo_db_zipcode" VALUES(27476,61478,-6,'Smithshire, Illinois 61478',19964,24432);
INSERT INTO "django_geo_db_zipcode" VALUES(27477,61479,-6,'Speer, Illinois 61479',19965,24433);
INSERT INTO "django_geo_db_zipcode" VALUES(27478,61480,-6,'Stronghurst, Illinois 61480',19966,24434);
INSERT INTO "django_geo_db_zipcode" VALUES(27479,61482,-6,'Table Grove, Illinois 61482',19967,24435);
INSERT INTO "django_geo_db_zipcode" VALUES(27480,61483,-6,'Toulon, Illinois 61483',19968,24436);
INSERT INTO "django_geo_db_zipcode" VALUES(27481,61484,-6,'Vermont, Illinois 61484',19969,24437);
INSERT INTO "django_geo_db_zipcode" VALUES(27482,61485,-6,'Victoria, Illinois 61485',19970,24438);
INSERT INTO "django_geo_db_zipcode" VALUES(27483,61486,-6,'Viola, Illinois 61486',19971,24439);
INSERT INTO "django_geo_db_zipcode" VALUES(27484,61488,-6,'Wataga, Illinois 61488',19972,24440);
INSERT INTO "django_geo_db_zipcode" VALUES(27485,61489,-6,'Williamsfield, Illinois 61489',19973,24441);
INSERT INTO "django_geo_db_zipcode" VALUES(27486,61490,-6,'Woodhull, Illinois 61490',19974,24442);
INSERT INTO "django_geo_db_zipcode" VALUES(27487,61491,-6,'Wyoming, Illinois 61491',19975,24443);
INSERT INTO "django_geo_db_zipcode" VALUES(27488,61501,-6,'Astoria, Illinois 61501',19976,24444);
INSERT INTO "django_geo_db_zipcode" VALUES(27489,61516,-6,'Benson, Illinois 61516',19977,24445);
INSERT INTO "django_geo_db_zipcode" VALUES(27490,61517,-6,'Brimfield, Illinois 61517',19978,24446);
INSERT INTO "django_geo_db_zipcode" VALUES(27491,61518,-6,'Brimfield, Illinois 61518',19978,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27492,61519,-6,'Bryant, Illinois 61519',19979,24448);
INSERT INTO "django_geo_db_zipcode" VALUES(27493,61520,-6,'Canton, Illinois 61520',19980,24449);
INSERT INTO "django_geo_db_zipcode" VALUES(27494,61523,-6,'Chillicothe, Illinois 61523',19981,24450);
INSERT INTO "django_geo_db_zipcode" VALUES(27495,61524,-6,'Dunfermline, Illinois 61524',19982,24451);
INSERT INTO "django_geo_db_zipcode" VALUES(27496,61525,-6,'Dunlap, Illinois 61525',19983,24452);
INSERT INTO "django_geo_db_zipcode" VALUES(27497,61526,-6,'Edelstein, Illinois 61526',19984,24453);
INSERT INTO "django_geo_db_zipcode" VALUES(27498,61528,-6,'Edwards, Illinois 61528',19985,24454);
INSERT INTO "django_geo_db_zipcode" VALUES(27499,61529,-6,'Elmwood, Illinois 61529',19986,24455);
INSERT INTO "django_geo_db_zipcode" VALUES(27500,61530,-6,'Eureka, Illinois 61530',19987,24456);
INSERT INTO "django_geo_db_zipcode" VALUES(27501,61531,-6,'Farmington, Illinois 61531',19988,24457);
INSERT INTO "django_geo_db_zipcode" VALUES(27502,61532,-6,'Forest City, Illinois 61532',19989,24458);
INSERT INTO "django_geo_db_zipcode" VALUES(27503,61533,-6,'Glasford, Illinois 61533',19990,24459);
INSERT INTO "django_geo_db_zipcode" VALUES(27504,61534,-6,'Green Valley, Illinois 61534',19991,24460);
INSERT INTO "django_geo_db_zipcode" VALUES(27505,61535,-6,'Groveland, Illinois 61535',19992,24461);
INSERT INTO "django_geo_db_zipcode" VALUES(27506,61536,-6,'Hanna City, Illinois 61536',19993,24462);
INSERT INTO "django_geo_db_zipcode" VALUES(27507,61537,-6,'Henry, Illinois 61537',19994,24463);
INSERT INTO "django_geo_db_zipcode" VALUES(27508,61539,-6,'Kingston Mines, Illinois 61539',19995,24464);
INSERT INTO "django_geo_db_zipcode" VALUES(27509,61540,-6,'Lacon, Illinois 61540',19996,24465);
INSERT INTO "django_geo_db_zipcode" VALUES(27510,61541,-6,'La Rose, Illinois 61541',19997,24466);
INSERT INTO "django_geo_db_zipcode" VALUES(27511,61542,-6,'Lewistown, Illinois 61542',19998,24467);
INSERT INTO "django_geo_db_zipcode" VALUES(27512,61543,-6,'Liverpool, Illinois 61543',19999,24468);
INSERT INTO "django_geo_db_zipcode" VALUES(27513,61544,-6,'London Mills, Illinois 61544',20000,24469);
INSERT INTO "django_geo_db_zipcode" VALUES(27514,61545,-6,'Lowpoint, Illinois 61545',20001,24470);
INSERT INTO "django_geo_db_zipcode" VALUES(27515,61546,-6,'Manito, Illinois 61546',20002,24471);
INSERT INTO "django_geo_db_zipcode" VALUES(27516,61547,-6,'Mapleton, Illinois 61547',20003,24472);
INSERT INTO "django_geo_db_zipcode" VALUES(27517,61548,-6,'Metamora, Illinois 61548',20004,24473);
INSERT INTO "django_geo_db_zipcode" VALUES(27518,61550,-6,'Morton, Illinois 61550',20005,24474);
INSERT INTO "django_geo_db_zipcode" VALUES(27519,61552,-6,'Mossville, Illinois 61552',20006,24475);
INSERT INTO "django_geo_db_zipcode" VALUES(27520,61553,-6,'Norris, Illinois 61553',20007,24394);
INSERT INTO "django_geo_db_zipcode" VALUES(27521,61554,-6,'Pekin, Illinois 61554',20008,24476);
INSERT INTO "django_geo_db_zipcode" VALUES(27522,61555,-6,'Pekin, Illinois 61555',20008,24477);
INSERT INTO "django_geo_db_zipcode" VALUES(27523,61558,-6,'Pekin, Illinois 61558',20008,24478);
INSERT INTO "django_geo_db_zipcode" VALUES(27524,61559,-6,'Princeville, Illinois 61559',20009,24479);
INSERT INTO "django_geo_db_zipcode" VALUES(27525,61560,-6,'Putnam, Illinois 61560',20010,24480);
INSERT INTO "django_geo_db_zipcode" VALUES(27526,61561,-6,'Roanoke, Illinois 61561',20011,24481);
INSERT INTO "django_geo_db_zipcode" VALUES(27527,61562,-6,'Rome, Illinois 61562',20012,24482);
INSERT INTO "django_geo_db_zipcode" VALUES(27528,61563,-6,'Saint David, Illinois 61563',20013,24483);
INSERT INTO "django_geo_db_zipcode" VALUES(27529,61564,-6,'South Pekin, Illinois 61564',20014,24484);
INSERT INTO "django_geo_db_zipcode" VALUES(27530,61565,-6,'Sparland, Illinois 61565',20015,24485);
INSERT INTO "django_geo_db_zipcode" VALUES(27531,61567,-6,'Topeka, Illinois 61567',20016,24486);
INSERT INTO "django_geo_db_zipcode" VALUES(27532,61568,-6,'Tremont, Illinois 61568',20017,24487);
INSERT INTO "django_geo_db_zipcode" VALUES(27533,61569,-6,'Trivoli, Illinois 61569',20018,24488);
INSERT INTO "django_geo_db_zipcode" VALUES(27534,61570,-6,'Washburn, Illinois 61570',20019,24489);
INSERT INTO "django_geo_db_zipcode" VALUES(27535,61571,-6,'Washington, Illinois 61571',20020,24490);
INSERT INTO "django_geo_db_zipcode" VALUES(27536,61572,-6,'Yates City, Illinois 61572',20021,24491);
INSERT INTO "django_geo_db_zipcode" VALUES(27537,61576,-6,'Richland, Illinois 61576',20022,24492);
INSERT INTO "django_geo_db_zipcode" VALUES(27538,61584,-6,'Vermont, Illinois 61584',19969,24493);
INSERT INTO "django_geo_db_zipcode" VALUES(27539,61593,-6,'Garrett, Illinois 61593',20023,24494);
INSERT INTO "django_geo_db_zipcode" VALUES(27540,61601,-6,'Peoria, Illinois 61601',20024,24495);
INSERT INTO "django_geo_db_zipcode" VALUES(27541,61602,-6,'Peoria, Illinois 61602',20024,24496);
INSERT INTO "django_geo_db_zipcode" VALUES(27542,61603,-6,'Peoria, Illinois 61603',20024,24497);
INSERT INTO "django_geo_db_zipcode" VALUES(27543,61604,-6,'Peoria, Illinois 61604',20024,24498);
INSERT INTO "django_geo_db_zipcode" VALUES(27544,61605,-6,'Peoria, Illinois 61605',20024,24499);
INSERT INTO "django_geo_db_zipcode" VALUES(27545,61606,-6,'Peoria, Illinois 61606',20024,24500);
INSERT INTO "django_geo_db_zipcode" VALUES(27546,61607,-6,'Peoria, Illinois 61607',20024,24501);
INSERT INTO "django_geo_db_zipcode" VALUES(27547,61610,-6,'Creve Coeur, Illinois 61610',20025,24502);
INSERT INTO "django_geo_db_zipcode" VALUES(27548,61611,-6,'East Peoria, Illinois 61611',20026,24503);
INSERT INTO "django_geo_db_zipcode" VALUES(27549,61612,-6,'Peoria, Illinois 61612',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27550,61613,-6,'Peoria, Illinois 61613',20024,24504);
INSERT INTO "django_geo_db_zipcode" VALUES(27551,61614,-6,'Peoria, Illinois 61614',20024,24505);
INSERT INTO "django_geo_db_zipcode" VALUES(27552,61615,-6,'Peoria, Illinois 61615',20024,24506);
INSERT INTO "django_geo_db_zipcode" VALUES(27553,61616,-6,'Peoria, Illinois 61616',20024,24507);
INSERT INTO "django_geo_db_zipcode" VALUES(27554,61625,-6,'Peoria, Illinois 61625',20024,24508);
INSERT INTO "django_geo_db_zipcode" VALUES(27555,61628,-6,'Peoria, Illinois 61628',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27556,61629,-6,'Peoria, Illinois 61629',20024,24509);
INSERT INTO "django_geo_db_zipcode" VALUES(27557,61630,-6,'Peoria, Illinois 61630',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27558,61632,-6,'Peoria, Illinois 61632',20024,24510);
INSERT INTO "django_geo_db_zipcode" VALUES(27559,61633,-6,'Peoria, Illinois 61633',20024,24511);
INSERT INTO "django_geo_db_zipcode" VALUES(27560,61634,-6,'Peoria, Illinois 61634',20024,24512);
INSERT INTO "django_geo_db_zipcode" VALUES(27561,61635,-6,'Peoria, Illinois 61635',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27562,61636,-6,'Peoria, Illinois 61636',20024,24513);
INSERT INTO "django_geo_db_zipcode" VALUES(27563,61637,-6,'Peoria, Illinois 61637',20024,24514);
INSERT INTO "django_geo_db_zipcode" VALUES(27564,61638,-6,'Peoria, Illinois 61638',20024,24515);
INSERT INTO "django_geo_db_zipcode" VALUES(27565,61639,-6,'Peoria, Illinois 61639',20024,24516);
INSERT INTO "django_geo_db_zipcode" VALUES(27566,61640,-6,'Peoria, Illinois 61640',20024,24517);
INSERT INTO "django_geo_db_zipcode" VALUES(27567,61641,-6,'Peoria, Illinois 61641',20024,24518);
INSERT INTO "django_geo_db_zipcode" VALUES(27568,61643,-6,'Peoria, Illinois 61643',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27569,61644,-6,'Peoria, Illinois 61644',20024,24510);
INSERT INTO "django_geo_db_zipcode" VALUES(27570,61650,-6,'Peoria, Illinois 61650',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27571,61651,-6,'Peoria, Illinois 61651',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27572,61652,-6,'Peoria, Illinois 61652',20024,24519);
INSERT INTO "django_geo_db_zipcode" VALUES(27573,61653,-6,'Peoria, Illinois 61653',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27574,61654,-6,'Peoria, Illinois 61654',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27575,61655,-6,'Peoria, Illinois 61655',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27576,61656,-6,'Peoria, Illinois 61656',20024,24447);
INSERT INTO "django_geo_db_zipcode" VALUES(27577,61675,-6,'Carlock, Illinois 61675',20027,24520);
INSERT INTO "django_geo_db_zipcode" VALUES(27578,61701,-6,'Bloomington, Illinois 61701',20028,24521);
INSERT INTO "django_geo_db_zipcode" VALUES(27579,61702,-6,'Bloomington, Illinois 61702',20028,24522);
INSERT INTO "django_geo_db_zipcode" VALUES(27580,61704,-6,'Bloomington, Illinois 61704',20028,24523);
INSERT INTO "django_geo_db_zipcode" VALUES(27581,61709,-6,'Bloomington, Illinois 61709',20028,24524);
INSERT INTO "django_geo_db_zipcode" VALUES(27582,61710,-6,'Bloomington, Illinois 61710',20028,24525);
INSERT INTO "django_geo_db_zipcode" VALUES(27583,61720,-6,'Anchor, Illinois 61720',20029,24526);
INSERT INTO "django_geo_db_zipcode" VALUES(27584,61721,-6,'Armington, Illinois 61721',20030,24527);
INSERT INTO "django_geo_db_zipcode" VALUES(27585,61722,-6,'Arrowsmith, Illinois 61722',20031,24528);
INSERT INTO "django_geo_db_zipcode" VALUES(27586,61723,-6,'Atlanta, Illinois 61723',20032,24529);
INSERT INTO "django_geo_db_zipcode" VALUES(27587,61724,-6,'Bellflower, Illinois 61724',20033,24530);
INSERT INTO "django_geo_db_zipcode" VALUES(27588,61725,-6,'Carlock, Illinois 61725',20027,24531);
INSERT INTO "django_geo_db_zipcode" VALUES(27589,61726,-6,'Chenoa, Illinois 61726',20034,24532);
INSERT INTO "django_geo_db_zipcode" VALUES(27590,61727,-6,'Clinton, Illinois 61727',20035,24533);
INSERT INTO "django_geo_db_zipcode" VALUES(27591,61728,-6,'Colfax, Illinois 61728',20036,24534);
INSERT INTO "django_geo_db_zipcode" VALUES(27592,61729,-6,'Congerville, Illinois 61729',20037,24535);
INSERT INTO "django_geo_db_zipcode" VALUES(27593,61730,-6,'Cooksville, Illinois 61730',20038,24536);
INSERT INTO "django_geo_db_zipcode" VALUES(27594,61731,-6,'Cropsey, Illinois 61731',20039,24537);
INSERT INTO "django_geo_db_zipcode" VALUES(27595,61732,-6,'Danvers, Illinois 61732',20040,24538);
INSERT INTO "django_geo_db_zipcode" VALUES(27596,61733,-6,'Deer Creek, Illinois 61733',20041,24539);
INSERT INTO "django_geo_db_zipcode" VALUES(27597,61734,-6,'Delavan, Illinois 61734',20042,24540);
INSERT INTO "django_geo_db_zipcode" VALUES(27598,61735,-6,'Dewitt, Illinois 61735',20043,24541);
INSERT INTO "django_geo_db_zipcode" VALUES(27599,61736,-6,'Downs, Illinois 61736',20044,24542);
INSERT INTO "django_geo_db_zipcode" VALUES(27600,61737,-6,'Ellsworth, Illinois 61737',20045,24543);
INSERT INTO "django_geo_db_zipcode" VALUES(27601,61738,-6,'El Paso, Illinois 61738',20046,24544);
INSERT INTO "django_geo_db_zipcode" VALUES(27602,61739,-6,'Fairbury, Illinois 61739',20047,24545);
INSERT INTO "django_geo_db_zipcode" VALUES(27603,61740,-6,'Flanagan, Illinois 61740',20048,24546);
INSERT INTO "django_geo_db_zipcode" VALUES(27604,61741,-6,'Forrest, Illinois 61741',20049,24547);
INSERT INTO "django_geo_db_zipcode" VALUES(27605,61742,-6,'Goodfield, Illinois 61742',20050,24548);
INSERT INTO "django_geo_db_zipcode" VALUES(27606,61743,-6,'Graymont, Illinois 61743',20051,24549);
INSERT INTO "django_geo_db_zipcode" VALUES(27607,61744,-6,'Gridley, Illinois 61744',20052,24550);
INSERT INTO "django_geo_db_zipcode" VALUES(27608,61745,-6,'Heyworth, Illinois 61745',20053,24551);
INSERT INTO "django_geo_db_zipcode" VALUES(27609,61747,-6,'Hopedale, Illinois 61747',20054,24552);
INSERT INTO "django_geo_db_zipcode" VALUES(27610,61748,-6,'Hudson, Illinois 61748',20055,24553);
INSERT INTO "django_geo_db_zipcode" VALUES(27611,61749,-6,'Kenney, Illinois 61749',20056,24554);
INSERT INTO "django_geo_db_zipcode" VALUES(27612,61750,-6,'Lane, Illinois 61750',20057,24555);
INSERT INTO "django_geo_db_zipcode" VALUES(27613,61751,-6,'Lawndale, Illinois 61751',20058,24556);
INSERT INTO "django_geo_db_zipcode" VALUES(27614,61752,-6,'Le Roy, Illinois 61752',20059,24557);
INSERT INTO "django_geo_db_zipcode" VALUES(27615,61753,-6,'Lexington, Illinois 61753',20060,24558);
INSERT INTO "django_geo_db_zipcode" VALUES(27616,61754,-6,'McLean, Illinois 61754',20061,24559);
INSERT INTO "django_geo_db_zipcode" VALUES(27617,61755,-6,'Mackinaw, Illinois 61755',20062,24560);
INSERT INTO "django_geo_db_zipcode" VALUES(27618,61756,-6,'Maroa, Illinois 61756',20063,24561);
INSERT INTO "django_geo_db_zipcode" VALUES(27619,61758,-6,'Merna, Illinois 61758',20064,24562);
INSERT INTO "django_geo_db_zipcode" VALUES(27620,61759,-6,'Minier, Illinois 61759',20065,24563);
INSERT INTO "django_geo_db_zipcode" VALUES(27621,61760,-6,'Minonk, Illinois 61760',20066,24564);
INSERT INTO "django_geo_db_zipcode" VALUES(27622,61761,-6,'Normal, Illinois 61761',20067,24565);
INSERT INTO "django_geo_db_zipcode" VALUES(27623,61764,-6,'Pontiac, Illinois 61764',20068,24566);
INSERT INTO "django_geo_db_zipcode" VALUES(27624,61766,-6,'Towanda, Illinois 61766',20069,24567);
INSERT INTO "django_geo_db_zipcode" VALUES(27625,61769,-6,'Saunemin, Illinois 61769',20070,24568);
INSERT INTO "django_geo_db_zipcode" VALUES(27626,61770,-6,'Saybrook, Illinois 61770',20071,24569);
INSERT INTO "django_geo_db_zipcode" VALUES(27627,61771,-6,'Secor, Illinois 61771',20072,24570);
INSERT INTO "django_geo_db_zipcode" VALUES(27628,61772,-6,'Shirley, Illinois 61772',20073,24571);
INSERT INTO "django_geo_db_zipcode" VALUES(27629,61773,-6,'Sibley, Illinois 61773',20074,24572);
INSERT INTO "django_geo_db_zipcode" VALUES(27630,61774,-6,'Stanford, Illinois 61774',20075,24573);
INSERT INTO "django_geo_db_zipcode" VALUES(27631,61775,-6,'Strawn, Illinois 61775',20076,24574);
INSERT INTO "django_geo_db_zipcode" VALUES(27632,61776,-6,'Towanda, Illinois 61776',20069,24575);
INSERT INTO "django_geo_db_zipcode" VALUES(27633,61777,-6,'Wapella, Illinois 61777',20077,24576);
INSERT INTO "django_geo_db_zipcode" VALUES(27634,61778,-6,'Waynesville, Illinois 61778',20078,24577);
INSERT INTO "django_geo_db_zipcode" VALUES(27635,61790,-6,'Normal, Illinois 61790',20067,24578);
INSERT INTO "django_geo_db_zipcode" VALUES(27636,61791,-6,'Bloomington, Illinois 61791',20028,24522);
INSERT INTO "django_geo_db_zipcode" VALUES(27637,61799,-6,'Bloomington, Illinois 61799',20028,24579);
INSERT INTO "django_geo_db_zipcode" VALUES(27638,61801,-6,'Urbana, Illinois 61801',20079,24580);
INSERT INTO "django_geo_db_zipcode" VALUES(27639,61802,-6,'Urbana, Illinois 61802',20079,24581);
INSERT INTO "django_geo_db_zipcode" VALUES(27640,61803,-6,'Urbana, Illinois 61803',20079,24582);
INSERT INTO "django_geo_db_zipcode" VALUES(27641,61810,-6,'Allerton, Illinois 61810',20080,24583);
INSERT INTO "django_geo_db_zipcode" VALUES(27642,61811,-6,'Alvin, Illinois 61811',20081,24584);
INSERT INTO "django_geo_db_zipcode" VALUES(27643,61812,-6,'Armstrong, Illinois 61812',20082,24585);
INSERT INTO "django_geo_db_zipcode" VALUES(27644,61813,-6,'Bement, Illinois 61813',20083,24586);
INSERT INTO "django_geo_db_zipcode" VALUES(27645,61814,-6,'Bismarck, Illinois 61814',20084,24587);
INSERT INTO "django_geo_db_zipcode" VALUES(27646,61815,-6,'Bondville, Illinois 61815',20085,24588);
INSERT INTO "django_geo_db_zipcode" VALUES(27647,61816,-6,'Broadlands, Illinois 61816',20086,24589);
INSERT INTO "django_geo_db_zipcode" VALUES(27648,61817,-6,'Catlin, Illinois 61817',20087,24590);
INSERT INTO "django_geo_db_zipcode" VALUES(27649,61818,-6,'Cerro Gordo, Illinois 61818',20088,24591);
INSERT INTO "django_geo_db_zipcode" VALUES(27650,61819,-6,'Bryant, Illinois 61819',19979,24592);
INSERT INTO "django_geo_db_zipcode" VALUES(27651,61820,-6,'Champaign, Illinois 61820',20089,24593);
INSERT INTO "django_geo_db_zipcode" VALUES(27652,61821,-6,'Champaign, Illinois 61821',20089,24594);
INSERT INTO "django_geo_db_zipcode" VALUES(27653,61822,-6,'Champaign, Illinois 61822',20089,24595);
INSERT INTO "django_geo_db_zipcode" VALUES(27654,61824,-6,'Champaign, Illinois 61824',20089,24596);
INSERT INTO "django_geo_db_zipcode" VALUES(27655,61825,-6,'Champaign, Illinois 61825',20089,24596);
INSERT INTO "django_geo_db_zipcode" VALUES(27656,61826,-6,'Champaign, Illinois 61826',20089,24597);
INSERT INTO "django_geo_db_zipcode" VALUES(27657,61830,-6,'Cisco, Illinois 61830',20090,24598);
INSERT INTO "django_geo_db_zipcode" VALUES(27658,61831,-6,'Collison, Illinois 61831',20091,24599);
INSERT INTO "django_geo_db_zipcode" VALUES(27659,61832,-6,'Danville, Illinois 61832',20092,24600);
INSERT INTO "django_geo_db_zipcode" VALUES(27660,61833,-6,'Tilton, Illinois 61833',20093,24601);
INSERT INTO "django_geo_db_zipcode" VALUES(27661,61834,-6,'Danville, Illinois 61834',20092,24602);
INSERT INTO "django_geo_db_zipcode" VALUES(27662,61839,-6,'De Land, Illinois 61839',20094,24603);
INSERT INTO "django_geo_db_zipcode" VALUES(27663,61840,-6,'Dewey, Illinois 61840',20095,24604);
INSERT INTO "django_geo_db_zipcode" VALUES(27664,61841,-6,'Fairmount, Illinois 61841',20096,24605);
INSERT INTO "django_geo_db_zipcode" VALUES(27665,61842,-6,'Farmer City, Illinois 61842',20097,24606);
INSERT INTO "django_geo_db_zipcode" VALUES(27666,61843,-6,'Fisher, Illinois 61843',20098,24607);
INSERT INTO "django_geo_db_zipcode" VALUES(27667,61844,-6,'Fithian, Illinois 61844',20099,24608);
INSERT INTO "django_geo_db_zipcode" VALUES(27668,61845,-6,'Foosland, Illinois 61845',20100,24609);
INSERT INTO "django_geo_db_zipcode" VALUES(27669,61846,-6,'Georgetown, Illinois 61846',20101,24610);
INSERT INTO "django_geo_db_zipcode" VALUES(27670,61847,-6,'Gifford, Illinois 61847',20102,24611);
INSERT INTO "django_geo_db_zipcode" VALUES(27671,61848,-6,'Henning, Illinois 61848',20103,24612);
INSERT INTO "django_geo_db_zipcode" VALUES(27672,61849,-6,'Homer, Illinois 61849',20104,24613);
INSERT INTO "django_geo_db_zipcode" VALUES(27673,61850,-6,'Indianola, Illinois 61850',20105,24614);
INSERT INTO "django_geo_db_zipcode" VALUES(27674,61851,-6,'Ivesdale, Illinois 61851',20106,24615);
INSERT INTO "django_geo_db_zipcode" VALUES(27675,61852,-6,'Longview, Illinois 61852',20107,24616);
INSERT INTO "django_geo_db_zipcode" VALUES(27676,61853,-6,'Mahomet, Illinois 61853',20108,24617);
INSERT INTO "django_geo_db_zipcode" VALUES(27677,61854,-6,'Mansfield, Illinois 61854',20109,24618);
INSERT INTO "django_geo_db_zipcode" VALUES(27678,61855,-6,'Milmine, Illinois 61855',20110,24619);
INSERT INTO "django_geo_db_zipcode" VALUES(27679,61856,-6,'Monticello, Illinois 61856',20111,24620);
INSERT INTO "django_geo_db_zipcode" VALUES(27680,61857,-6,'Muncie, Illinois 61857',20112,24621);
INSERT INTO "django_geo_db_zipcode" VALUES(27681,61858,-6,'Oakwood, Illinois 61858',20113,24622);
INSERT INTO "django_geo_db_zipcode" VALUES(27682,61859,-6,'Ogden, Illinois 61859',20114,24623);
INSERT INTO "django_geo_db_zipcode" VALUES(27683,61862,-6,'Penfield, Illinois 61862',20115,24624);
INSERT INTO "django_geo_db_zipcode" VALUES(27684,61863,-6,'Pesotum, Illinois 61863',20116,24625);
INSERT INTO "django_geo_db_zipcode" VALUES(27685,61864,-6,'Philo, Illinois 61864',20117,24626);
INSERT INTO "django_geo_db_zipcode" VALUES(27686,61865,-6,'Potomac, Illinois 61865',20118,24627);
INSERT INTO "django_geo_db_zipcode" VALUES(27687,61866,-6,'Rantoul, Illinois 61866',20119,24628);
INSERT INTO "django_geo_db_zipcode" VALUES(27688,61870,-6,'Ridge Farm, Illinois 61870',20120,24629);
INSERT INTO "django_geo_db_zipcode" VALUES(27689,61871,-6,'Royal, Illinois 61871',20121,24630);
INSERT INTO "django_geo_db_zipcode" VALUES(27690,61872,-6,'Sadorus, Illinois 61872',20122,24631);
INSERT INTO "django_geo_db_zipcode" VALUES(27691,61873,-6,'Saint Joseph, Illinois 61873',20123,24632);
INSERT INTO "django_geo_db_zipcode" VALUES(27692,61874,-6,'Savoy, Illinois 61874',20124,24633);
INSERT INTO "django_geo_db_zipcode" VALUES(27693,61875,-6,'Seymour, Illinois 61875',20125,24634);
INSERT INTO "django_geo_db_zipcode" VALUES(27694,61876,-6,'Sidell, Illinois 61876',20126,24635);
INSERT INTO "django_geo_db_zipcode" VALUES(27695,61877,-6,'Sidney, Illinois 61877',20127,24636);
INSERT INTO "django_geo_db_zipcode" VALUES(27696,61878,-6,'Thomasboro, Illinois 61878',20128,24637);
INSERT INTO "django_geo_db_zipcode" VALUES(27697,61880,-6,'Tolono, Illinois 61880',20129,24638);
INSERT INTO "django_geo_db_zipcode" VALUES(27698,61882,-6,'Weldon, Illinois 61882',20130,24639);
INSERT INTO "django_geo_db_zipcode" VALUES(27699,61883,-6,'Westville, Illinois 61883',20131,24640);
INSERT INTO "django_geo_db_zipcode" VALUES(27700,61884,-6,'White Heath, Illinois 61884',20132,24641);
INSERT INTO "django_geo_db_zipcode" VALUES(27701,61901,-6,'Bloomington, Illinois 61901',20028,24642);
INSERT INTO "django_geo_db_zipcode" VALUES(27702,61910,-6,'Arcola, Illinois 61910',20133,24643);
INSERT INTO "django_geo_db_zipcode" VALUES(27703,61911,-6,'Arthur, Illinois 61911',20134,24644);
INSERT INTO "django_geo_db_zipcode" VALUES(27704,61912,-6,'Ashmore, Illinois 61912',20135,24645);
INSERT INTO "django_geo_db_zipcode" VALUES(27705,61913,-6,'Atwood, Illinois 61913',20136,24646);
INSERT INTO "django_geo_db_zipcode" VALUES(27706,61914,-6,'Bethany, Illinois 61914',20137,24647);
INSERT INTO "django_geo_db_zipcode" VALUES(27707,61917,-6,'Brocton, Illinois 61917',20138,24648);
INSERT INTO "django_geo_db_zipcode" VALUES(27708,61919,-6,'Camargo, Illinois 61919',20139,24649);
INSERT INTO "django_geo_db_zipcode" VALUES(27709,61920,-6,'Charleston, Illinois 61920',20140,24650);
INSERT INTO "django_geo_db_zipcode" VALUES(27710,61924,-6,'Chrisman, Illinois 61924',20141,24651);
INSERT INTO "django_geo_db_zipcode" VALUES(27711,61925,-6,'Dalton City, Illinois 61925',20142,24652);
INSERT INTO "django_geo_db_zipcode" VALUES(27712,61928,-6,'Gays, Illinois 61928',20143,24653);
INSERT INTO "django_geo_db_zipcode" VALUES(27713,61929,-6,'Hammond, Illinois 61929',20144,24654);
INSERT INTO "django_geo_db_zipcode" VALUES(27714,61930,-6,'Hindsboro, Illinois 61930',20145,24655);
INSERT INTO "django_geo_db_zipcode" VALUES(27715,61931,-6,'Humboldt, Illinois 61931',20146,24656);
INSERT INTO "django_geo_db_zipcode" VALUES(27716,61932,-6,'Hume, Illinois 61932',20147,24657);
INSERT INTO "django_geo_db_zipcode" VALUES(27717,61933,-6,'Kansas, Illinois 61933',20148,24658);
INSERT INTO "django_geo_db_zipcode" VALUES(27718,61936,-6,'La Place, Illinois 61936',20149,24659);
INSERT INTO "django_geo_db_zipcode" VALUES(27719,61937,-6,'Lovington, Illinois 61937',20150,24660);
INSERT INTO "django_geo_db_zipcode" VALUES(27720,61938,-6,'Mattoon, Illinois 61938',20151,24661);
INSERT INTO "django_geo_db_zipcode" VALUES(27721,61940,-6,'Metcalf, Illinois 61940',20152,24662);
INSERT INTO "django_geo_db_zipcode" VALUES(27722,61941,-6,'Murdock, Illinois 61941',20153,24663);
INSERT INTO "django_geo_db_zipcode" VALUES(27723,61942,-6,'Newman, Illinois 61942',20154,24664);
INSERT INTO "django_geo_db_zipcode" VALUES(27724,61943,-6,'Oakland, Illinois 61943',20155,24665);
INSERT INTO "django_geo_db_zipcode" VALUES(27725,61944,-6,'Paris, Illinois 61944',20156,24666);
INSERT INTO "django_geo_db_zipcode" VALUES(27726,61949,-6,'Redmon, Illinois 61949',20157,24667);
INSERT INTO "django_geo_db_zipcode" VALUES(27727,61951,-6,'Sullivan, Illinois 61951',20158,24668);
INSERT INTO "django_geo_db_zipcode" VALUES(27728,61953,-6,'Tuscola, Illinois 61953',20159,24669);
INSERT INTO "django_geo_db_zipcode" VALUES(27729,61955,-6,'Vermilion, Illinois 61955',20160,24670);
INSERT INTO "django_geo_db_zipcode" VALUES(27730,61956,-6,'Villa Grove, Illinois 61956',20161,24671);
INSERT INTO "django_geo_db_zipcode" VALUES(27731,61957,-6,'Windsor, Illinois 61957',20162,24672);
INSERT INTO "django_geo_db_zipcode" VALUES(27732,62001,-6,'Alhambra, Illinois 62001',20163,24673);
INSERT INTO "django_geo_db_zipcode" VALUES(27733,62002,-6,'Alton, Illinois 62002',20164,24674);
INSERT INTO "django_geo_db_zipcode" VALUES(27734,62003,-6,'Medora, Illinois 62003',20165,24675);
INSERT INTO "django_geo_db_zipcode" VALUES(27735,62006,-6,'Batchtown, Illinois 62006',20166,24676);
INSERT INTO "django_geo_db_zipcode" VALUES(27736,62009,-6,'Benld, Illinois 62009',20167,24677);
INSERT INTO "django_geo_db_zipcode" VALUES(27737,62010,-6,'Bethalto, Illinois 62010',20168,24678);
INSERT INTO "django_geo_db_zipcode" VALUES(27738,62011,-6,'Bingham, Illinois 62011',20169,24679);
INSERT INTO "django_geo_db_zipcode" VALUES(27739,62012,-6,'Brighton, Illinois 62012',20170,24680);
INSERT INTO "django_geo_db_zipcode" VALUES(27740,62013,-6,'Brussels, Illinois 62013',20171,24681);
INSERT INTO "django_geo_db_zipcode" VALUES(27741,62014,-6,'Bunker Hill, Illinois 62014',20172,24682);
INSERT INTO "django_geo_db_zipcode" VALUES(27742,62015,-6,'Butler, Illinois 62015',20173,24683);
INSERT INTO "django_geo_db_zipcode" VALUES(27743,62016,-6,'Carrollton, Illinois 62016',20174,24684);
INSERT INTO "django_geo_db_zipcode" VALUES(27744,62017,-6,'Coffeen, Illinois 62017',20175,24685);
INSERT INTO "django_geo_db_zipcode" VALUES(27745,62018,-6,'Cottage Hills, Illinois 62018',20176,24686);
INSERT INTO "django_geo_db_zipcode" VALUES(27746,62019,-6,'Donnellson, Illinois 62019',20177,24687);
INSERT INTO "django_geo_db_zipcode" VALUES(27747,62021,-6,'Dorsey, Illinois 62021',20178,24688);
INSERT INTO "django_geo_db_zipcode" VALUES(27748,62022,-6,'Dow, Illinois 62022',20179,24689);
INSERT INTO "django_geo_db_zipcode" VALUES(27749,62023,-6,'Eagarville, Illinois 62023',20180,24690);
INSERT INTO "django_geo_db_zipcode" VALUES(27750,62024,-6,'East Alton, Illinois 62024',20181,24691);
INSERT INTO "django_geo_db_zipcode" VALUES(27751,62025,-6,'Edwardsville, Illinois 62025',20182,24692);
INSERT INTO "django_geo_db_zipcode" VALUES(27752,62026,-6,'Edwardsville, Illinois 62026',20182,24693);
INSERT INTO "django_geo_db_zipcode" VALUES(27753,62027,-6,'Eldred, Illinois 62027',20183,24694);
INSERT INTO "django_geo_db_zipcode" VALUES(27754,62028,-6,'Elsah, Illinois 62028',20184,24695);
INSERT INTO "django_geo_db_zipcode" VALUES(27755,62030,-6,'Fidelity, Illinois 62030',20185,24696);
INSERT INTO "django_geo_db_zipcode" VALUES(27756,62031,-6,'Fieldon, Illinois 62031',20186,24697);
INSERT INTO "django_geo_db_zipcode" VALUES(27757,62032,-6,'Fillmore, Illinois 62032',20187,24698);
INSERT INTO "django_geo_db_zipcode" VALUES(27758,62033,-6,'Gillespie, Illinois 62033',20188,24699);
INSERT INTO "django_geo_db_zipcode" VALUES(27759,62034,-6,'Glen Carbon, Illinois 62034',20189,24700);
INSERT INTO "django_geo_db_zipcode" VALUES(27760,62035,-6,'Godfrey, Illinois 62035',20190,24701);
INSERT INTO "django_geo_db_zipcode" VALUES(27761,62036,-6,'Golden Eagle, Illinois 62036',20191,24702);
INSERT INTO "django_geo_db_zipcode" VALUES(27762,62037,-6,'Grafton, Illinois 62037',20192,24703);
INSERT INTO "django_geo_db_zipcode" VALUES(27763,62040,-6,'Granite City, Illinois 62040',20193,24704);
INSERT INTO "django_geo_db_zipcode" VALUES(27764,62043,-6,'Brushy Mound, Illinois 62043',20194,24705);
INSERT INTO "django_geo_db_zipcode" VALUES(27765,62044,-6,'Greenfield, Illinois 62044',20195,24706);
INSERT INTO "django_geo_db_zipcode" VALUES(27766,62045,-6,'Hamburg, Illinois 62045',20196,24707);
INSERT INTO "django_geo_db_zipcode" VALUES(27767,62046,-6,'Hamel, Illinois 62046',20197,24708);
INSERT INTO "django_geo_db_zipcode" VALUES(27768,62047,-6,'Hardin, Illinois 62047',20198,24709);
INSERT INTO "django_geo_db_zipcode" VALUES(27769,62048,-6,'Hartford, Illinois 62048',20199,24710);
INSERT INTO "django_geo_db_zipcode" VALUES(27770,62049,-6,'Hillsboro, Illinois 62049',20200,24711);
INSERT INTO "django_geo_db_zipcode" VALUES(27771,62050,-6,'Hillview, Illinois 62050',20201,24712);
INSERT INTO "django_geo_db_zipcode" VALUES(27772,62051,-6,'Irving, Illinois 62051',20202,24713);
INSERT INTO "django_geo_db_zipcode" VALUES(27773,62052,-6,'Jerseyville, Illinois 62052',20203,24714);
INSERT INTO "django_geo_db_zipcode" VALUES(27774,62053,-6,'Kampsville, Illinois 62053',20204,24715);
INSERT INTO "django_geo_db_zipcode" VALUES(27775,62054,-6,'Kane, Illinois 62054',20205,24716);
INSERT INTO "django_geo_db_zipcode" VALUES(27776,62056,-6,'Litchfield, Illinois 62056',20206,24717);
INSERT INTO "django_geo_db_zipcode" VALUES(27777,62058,-6,'Livingston, Illinois 62058',20207,24718);
INSERT INTO "django_geo_db_zipcode" VALUES(27778,62059,-6,'Lovejoy, Illinois 62059',20208,24719);
INSERT INTO "django_geo_db_zipcode" VALUES(27779,62060,-6,'Madison, Illinois 62060',20209,24720);
INSERT INTO "django_geo_db_zipcode" VALUES(27780,62061,-6,'Marine, Illinois 62061',20210,24721);
INSERT INTO "django_geo_db_zipcode" VALUES(27781,62062,-6,'Maryville, Illinois 62062',20211,24722);
INSERT INTO "django_geo_db_zipcode" VALUES(27782,62063,-6,'Medora, Illinois 62063',20165,24723);
INSERT INTO "django_geo_db_zipcode" VALUES(27783,62065,-6,'Michael, Illinois 62065',20212,24724);
INSERT INTO "django_geo_db_zipcode" VALUES(27784,62067,-6,'Moro, Illinois 62067',20213,24725);
INSERT INTO "django_geo_db_zipcode" VALUES(27785,62069,-6,'Mount Olive, Illinois 62069',20214,24726);
INSERT INTO "django_geo_db_zipcode" VALUES(27786,62070,-6,'Mozier, Illinois 62070',20215,24727);
INSERT INTO "django_geo_db_zipcode" VALUES(27787,62071,-6,'National Stock Yards, Illinois 62071',20216,24728);
INSERT INTO "django_geo_db_zipcode" VALUES(27788,62074,-6,'New Douglas, Illinois 62074',20217,24729);
INSERT INTO "django_geo_db_zipcode" VALUES(27789,62075,-6,'Nokomis, Illinois 62075',20218,24730);
INSERT INTO "django_geo_db_zipcode" VALUES(27790,62076,-6,'Ohlman, Illinois 62076',20219,24731);
INSERT INTO "django_geo_db_zipcode" VALUES(27791,62077,-6,'Panama, Illinois 62077',20220,24732);
INSERT INTO "django_geo_db_zipcode" VALUES(27792,62078,-6,'Patterson, Illinois 62078',20221,24733);
INSERT INTO "django_geo_db_zipcode" VALUES(27793,62079,-6,'Piasa, Illinois 62079',20222,24734);
INSERT INTO "django_geo_db_zipcode" VALUES(27794,62080,-6,'Ramsey, Illinois 62080',20223,24735);
INSERT INTO "django_geo_db_zipcode" VALUES(27795,62081,-6,'Rockbridge, Illinois 62081',20224,24736);
INSERT INTO "django_geo_db_zipcode" VALUES(27796,62082,-6,'Roodhouse, Illinois 62082',20225,24737);
INSERT INTO "django_geo_db_zipcode" VALUES(27797,62083,-6,'Rosamond, Illinois 62083',20226,24738);
INSERT INTO "django_geo_db_zipcode" VALUES(27798,62084,-6,'Roxana, Illinois 62084',20227,24739);
INSERT INTO "django_geo_db_zipcode" VALUES(27799,62085,-6,'Sawyerville, Illinois 62085',20228,24740);
INSERT INTO "django_geo_db_zipcode" VALUES(27800,62086,-6,'Sorento, Illinois 62086',20229,24741);
INSERT INTO "django_geo_db_zipcode" VALUES(27801,62087,-6,'South Roxana, Illinois 62087',20230,24742);
INSERT INTO "django_geo_db_zipcode" VALUES(27802,62088,-6,'Staunton, Illinois 62088',20231,24743);
INSERT INTO "django_geo_db_zipcode" VALUES(27803,62089,-6,'Taylor Springs, Illinois 62089',20232,24744);
INSERT INTO "django_geo_db_zipcode" VALUES(27804,62090,-6,'Venice, Illinois 62090',20233,24745);
INSERT INTO "django_geo_db_zipcode" VALUES(27805,62091,-6,'Walshville, Illinois 62091',20234,24746);
INSERT INTO "django_geo_db_zipcode" VALUES(27806,62092,-6,'White Hall, Illinois 62092',20235,24747);
INSERT INTO "django_geo_db_zipcode" VALUES(27807,62093,-6,'Wilsonville, Illinois 62093',20236,24748);
INSERT INTO "django_geo_db_zipcode" VALUES(27808,62094,-6,'Witt, Illinois 62094',20237,24749);
INSERT INTO "django_geo_db_zipcode" VALUES(27809,62095,-6,'Wood River, Illinois 62095',20238,24750);
INSERT INTO "django_geo_db_zipcode" VALUES(27810,62097,-6,'Worden, Illinois 62097',20239,24751);
INSERT INTO "django_geo_db_zipcode" VALUES(27811,62098,-6,'Wrights, Illinois 62098',20240,24752);
INSERT INTO "django_geo_db_zipcode" VALUES(27812,62201,-6,'East Saint Louis, Illinois 62201',20241,24753);
INSERT INTO "django_geo_db_zipcode" VALUES(27813,62202,-6,'East Saint Louis, Illinois 62202',20241,24754);
INSERT INTO "django_geo_db_zipcode" VALUES(27814,62203,-6,'East Saint Louis, Illinois 62203',20241,24755);
INSERT INTO "django_geo_db_zipcode" VALUES(27815,62204,-6,'East Saint Louis, Illinois 62204',20241,24756);
INSERT INTO "django_geo_db_zipcode" VALUES(27816,62205,-6,'East Saint Louis, Illinois 62205',20241,24757);
INSERT INTO "django_geo_db_zipcode" VALUES(27817,62206,-6,'East Saint Louis, Illinois 62206',20241,24758);
INSERT INTO "django_geo_db_zipcode" VALUES(27818,62207,-6,'East Saint Louis, Illinois 62207',20241,24759);
INSERT INTO "django_geo_db_zipcode" VALUES(27819,62208,-6,'Fairview Heights, Illinois 62208',20242,24760);
INSERT INTO "django_geo_db_zipcode" VALUES(27820,62214,-6,'Addieville, Illinois 62214',20243,24761);
INSERT INTO "django_geo_db_zipcode" VALUES(27821,62215,-6,'Albers, Illinois 62215',20244,24762);
INSERT INTO "django_geo_db_zipcode" VALUES(27822,62216,-6,'Aviston, Illinois 62216',20245,24763);
INSERT INTO "django_geo_db_zipcode" VALUES(27823,62217,-6,'Baldwin, Illinois 62217',20246,24764);
INSERT INTO "django_geo_db_zipcode" VALUES(27824,62218,-6,'Bartelso, Illinois 62218',20247,24765);
INSERT INTO "django_geo_db_zipcode" VALUES(27825,62219,-6,'Beckemeyer, Illinois 62219',20248,24766);
INSERT INTO "django_geo_db_zipcode" VALUES(27826,62220,-6,'Belleville, Illinois 62220',20249,24767);
INSERT INTO "django_geo_db_zipcode" VALUES(27827,62221,-6,'Belleville, Illinois 62221',20249,24768);
INSERT INTO "django_geo_db_zipcode" VALUES(27828,62222,-6,'Belleville, Illinois 62222',20249,24769);
INSERT INTO "django_geo_db_zipcode" VALUES(27829,62223,-6,'Belleville, Illinois 62223',20249,24770);
INSERT INTO "django_geo_db_zipcode" VALUES(27830,62224,-6,'Mascoutah, Illinois 62224',20250,24769);
INSERT INTO "django_geo_db_zipcode" VALUES(27831,62225,-6,'Scott Air Force Base, Illinois 62225',20251,24771);
INSERT INTO "django_geo_db_zipcode" VALUES(27832,62226,-6,'Belleville, Illinois 62226',20249,24772);
INSERT INTO "django_geo_db_zipcode" VALUES(27833,62230,-6,'Breese, Illinois 62230',20252,24773);
INSERT INTO "django_geo_db_zipcode" VALUES(27834,62231,-6,'Carlyle, Illinois 62231',20253,24774);
INSERT INTO "django_geo_db_zipcode" VALUES(27835,62232,-6,'Caseyville, Illinois 62232',20254,24775);
INSERT INTO "django_geo_db_zipcode" VALUES(27836,62233,-6,'Chester, Illinois 62233',20255,24776);
INSERT INTO "django_geo_db_zipcode" VALUES(27837,62234,-6,'Collinsville, Illinois 62234',20256,24777);
INSERT INTO "django_geo_db_zipcode" VALUES(27838,62236,-6,'Columbia, Illinois 62236',20257,24778);
INSERT INTO "django_geo_db_zipcode" VALUES(27839,62237,-6,'Coulterville, Illinois 62237',20258,24779);
INSERT INTO "django_geo_db_zipcode" VALUES(27840,62238,-6,'Cutler, Illinois 62238',20259,24780);
INSERT INTO "django_geo_db_zipcode" VALUES(27841,62239,-6,'Dupo, Illinois 62239',20260,24781);
INSERT INTO "django_geo_db_zipcode" VALUES(27842,62240,-6,'East Carondelet, Illinois 62240',20261,24782);
INSERT INTO "django_geo_db_zipcode" VALUES(27843,62241,-6,'Ellis Grove, Illinois 62241',20262,24783);
INSERT INTO "django_geo_db_zipcode" VALUES(27844,62242,-6,'Evansville, Illinois 62242',20263,24784);
INSERT INTO "django_geo_db_zipcode" VALUES(27845,62243,-6,'Freeburg, Illinois 62243',20264,24785);
INSERT INTO "django_geo_db_zipcode" VALUES(27846,62244,-6,'Fults, Illinois 62244',20265,24786);
INSERT INTO "django_geo_db_zipcode" VALUES(27847,62245,-6,'Germantown, Illinois 62245',20266,24787);
INSERT INTO "django_geo_db_zipcode" VALUES(27848,62246,-6,'Greenville, Illinois 62246',20267,24788);
INSERT INTO "django_geo_db_zipcode" VALUES(27849,62247,-6,'Hagarstown, Illinois 62247',20268,24789);
INSERT INTO "django_geo_db_zipcode" VALUES(27850,62248,-6,'Hecker, Illinois 62248',20269,24790);
INSERT INTO "django_geo_db_zipcode" VALUES(27851,62249,-6,'Highland, Illinois 62249',20270,24791);
INSERT INTO "django_geo_db_zipcode" VALUES(27852,62250,-6,'Hoffman, Illinois 62250',20271,24792);
INSERT INTO "django_geo_db_zipcode" VALUES(27853,62252,-6,'Huey, Illinois 62252',20272,24793);
INSERT INTO "django_geo_db_zipcode" VALUES(27854,62253,-6,'Keyesport, Illinois 62253',20273,24794);
INSERT INTO "django_geo_db_zipcode" VALUES(27855,62254,-6,'Lebanon, Illinois 62254',20274,24795);
INSERT INTO "django_geo_db_zipcode" VALUES(27856,62255,-6,'Lenzburg, Illinois 62255',20275,24796);
INSERT INTO "django_geo_db_zipcode" VALUES(27857,62256,-6,'Maeystown, Illinois 62256',20276,24797);
INSERT INTO "django_geo_db_zipcode" VALUES(27858,62257,-6,'Marissa, Illinois 62257',20277,24798);
INSERT INTO "django_geo_db_zipcode" VALUES(27859,62258,-6,'Mascoutah, Illinois 62258',20250,24799);
INSERT INTO "django_geo_db_zipcode" VALUES(27860,62259,-6,'Menard, Illinois 62259',20278,24800);
INSERT INTO "django_geo_db_zipcode" VALUES(27861,62260,-6,'Millstadt, Illinois 62260',20279,24801);
INSERT INTO "django_geo_db_zipcode" VALUES(27862,62261,-6,'Modoc, Illinois 62261',20280,24802);
INSERT INTO "django_geo_db_zipcode" VALUES(27863,62262,-6,'Mulberry Grove, Illinois 62262',20281,24803);
INSERT INTO "django_geo_db_zipcode" VALUES(27864,62263,-6,'Nashville, Illinois 62263',20282,24804);
INSERT INTO "django_geo_db_zipcode" VALUES(27865,62264,-6,'New Athens, Illinois 62264',20283,24805);
INSERT INTO "django_geo_db_zipcode" VALUES(27866,62265,-6,'New Baden, Illinois 62265',20284,24806);
INSERT INTO "django_geo_db_zipcode" VALUES(27867,62266,-6,'New Memphis, Illinois 62266',20285,24807);
INSERT INTO "django_geo_db_zipcode" VALUES(27868,62268,-6,'Oakdale, Illinois 62268',20286,24808);
INSERT INTO "django_geo_db_zipcode" VALUES(27869,62269,-6,'O Fallon, Illinois 62269',20287,24809);
INSERT INTO "django_geo_db_zipcode" VALUES(27870,62270,-6,'Dupo, Illinois 62270',20260,24810);
INSERT INTO "django_geo_db_zipcode" VALUES(27871,62271,-6,'Okawville, Illinois 62271',20288,24811);
INSERT INTO "django_geo_db_zipcode" VALUES(27872,62272,-6,'Percy, Illinois 62272',20289,24812);
INSERT INTO "django_geo_db_zipcode" VALUES(27873,62273,-6,'Pierron, Illinois 62273',20290,24813);
INSERT INTO "django_geo_db_zipcode" VALUES(27874,62274,-6,'Pinckneyville, Illinois 62274',20291,24814);
INSERT INTO "django_geo_db_zipcode" VALUES(27875,62275,-6,'Pocahontas, Illinois 62275',20292,24815);
INSERT INTO "django_geo_db_zipcode" VALUES(27876,62277,-6,'Prairie Du Rocher, Illinois 62277',20293,24816);
INSERT INTO "django_geo_db_zipcode" VALUES(27877,62278,-6,'Red Bud, Illinois 62278',20294,24817);
INSERT INTO "django_geo_db_zipcode" VALUES(27878,62279,-6,'Renault, Illinois 62279',20295,24818);
INSERT INTO "django_geo_db_zipcode" VALUES(27879,62280,-6,'Rockwood, Illinois 62280',20296,24819);
INSERT INTO "django_geo_db_zipcode" VALUES(27880,62281,-6,'Saint Jacob, Illinois 62281',20297,24820);
INSERT INTO "django_geo_db_zipcode" VALUES(27881,62282,-6,'Saint Libory, Illinois 62282',20298,24821);
INSERT INTO "django_geo_db_zipcode" VALUES(27882,62283,-6,'Shattuc, Illinois 62283',20299,24822);
INSERT INTO "django_geo_db_zipcode" VALUES(27883,62284,-6,'Smithboro, Illinois 62284',20300,24823);
INSERT INTO "django_geo_db_zipcode" VALUES(27884,62285,-6,'Smithton, Illinois 62285',20301,24824);
INSERT INTO "django_geo_db_zipcode" VALUES(27885,62286,-6,'Sparta, Illinois 62286',20302,24825);
INSERT INTO "django_geo_db_zipcode" VALUES(27886,62288,-6,'Steeleville, Illinois 62288',20303,24826);
INSERT INTO "django_geo_db_zipcode" VALUES(27887,62289,-6,'Summerfield, Illinois 62289',20304,24827);
INSERT INTO "django_geo_db_zipcode" VALUES(27888,62292,-6,'Tilden, Illinois 62292',20305,24828);
INSERT INTO "django_geo_db_zipcode" VALUES(27889,62293,-6,'Trenton, Illinois 62293',20306,24829);
INSERT INTO "django_geo_db_zipcode" VALUES(27890,62294,-6,'Troy, Illinois 62294',20307,24830);
INSERT INTO "django_geo_db_zipcode" VALUES(27891,62295,-6,'Valmeyer, Illinois 62295',20308,24831);
INSERT INTO "django_geo_db_zipcode" VALUES(27892,62297,-6,'Walsh, Illinois 62297',20309,24832);
INSERT INTO "django_geo_db_zipcode" VALUES(27893,62298,-6,'Waterloo, Illinois 62298',20310,24833);
INSERT INTO "django_geo_db_zipcode" VALUES(27894,62301,-6,'Quincy, Illinois 62301',20311,24834);
INSERT INTO "django_geo_db_zipcode" VALUES(27895,62305,-6,'Quincy, Illinois 62305',20311,24835);
INSERT INTO "django_geo_db_zipcode" VALUES(27896,62306,-6,'Quincy, Illinois 62306',20311,24836);
INSERT INTO "django_geo_db_zipcode" VALUES(27897,62310,-6,'Adrian, Illinois 62310',20312,24837);
INSERT INTO "django_geo_db_zipcode" VALUES(27898,62311,-6,'Augusta, Illinois 62311',20313,24838);
INSERT INTO "django_geo_db_zipcode" VALUES(27899,62312,-6,'Barry, Illinois 62312',20314,24839);
INSERT INTO "django_geo_db_zipcode" VALUES(27900,62313,-6,'Basco, Illinois 62313',20315,24840);
INSERT INTO "django_geo_db_zipcode" VALUES(27901,62314,-6,'Baylis, Illinois 62314',20316,24841);
INSERT INTO "django_geo_db_zipcode" VALUES(27902,62316,-6,'Bowen, Illinois 62316',20317,24842);
INSERT INTO "django_geo_db_zipcode" VALUES(27903,62318,-6,'Burnside, Illinois 62318',20318,24843);
INSERT INTO "django_geo_db_zipcode" VALUES(27904,62319,-6,'Camden, Illinois 62319',20319,24844);
INSERT INTO "django_geo_db_zipcode" VALUES(27905,62320,-6,'Camp Point, Illinois 62320',20320,24845);
INSERT INTO "django_geo_db_zipcode" VALUES(27906,62321,-6,'Carthage, Illinois 62321',20321,24846);
INSERT INTO "django_geo_db_zipcode" VALUES(27907,62323,-6,'Chambersburg, Illinois 62323',20322,24847);
INSERT INTO "django_geo_db_zipcode" VALUES(27908,62324,-6,'Clayton, Illinois 62324',20323,24848);
INSERT INTO "django_geo_db_zipcode" VALUES(27909,62325,-6,'Coatsburg, Illinois 62325',20324,24849);
INSERT INTO "django_geo_db_zipcode" VALUES(27910,62326,-6,'Colchester, Illinois 62326',20325,24850);
INSERT INTO "django_geo_db_zipcode" VALUES(27911,62329,-6,'Colusa, Illinois 62329',20326,24851);
INSERT INTO "django_geo_db_zipcode" VALUES(27912,62330,-6,'Dallas City, Illinois 62330',20327,24852);
INSERT INTO "django_geo_db_zipcode" VALUES(27913,62334,-6,'Elvaston, Illinois 62334',20328,24853);
INSERT INTO "django_geo_db_zipcode" VALUES(27914,62336,-6,'Ferris, Illinois 62336',20329,24854);
INSERT INTO "django_geo_db_zipcode" VALUES(27915,62338,-6,'Fowler, Illinois 62338',20330,24855);
INSERT INTO "django_geo_db_zipcode" VALUES(27916,62339,-6,'Golden, Illinois 62339',20331,24856);
INSERT INTO "django_geo_db_zipcode" VALUES(27917,62340,-6,'Griggsville, Illinois 62340',20332,24857);
INSERT INTO "django_geo_db_zipcode" VALUES(27918,62341,-6,'Hamilton, Illinois 62341',20333,24858);
INSERT INTO "django_geo_db_zipcode" VALUES(27919,62343,-6,'Hull, Illinois 62343',20334,24859);
INSERT INTO "django_geo_db_zipcode" VALUES(27920,62344,-6,'Huntsville, Illinois 62344',20335,24860);
INSERT INTO "django_geo_db_zipcode" VALUES(27921,62345,-6,'Kinderhook, Illinois 62345',20336,24861);
INSERT INTO "django_geo_db_zipcode" VALUES(27922,62346,-6,'La Prairie, Illinois 62346',20337,24862);
INSERT INTO "django_geo_db_zipcode" VALUES(27923,62347,-6,'Liberty, Illinois 62347',20338,24863);
INSERT INTO "django_geo_db_zipcode" VALUES(27924,62348,-6,'Lima, Illinois 62348',20339,24864);
INSERT INTO "django_geo_db_zipcode" VALUES(27925,62349,-6,'Loraine, Illinois 62349',20340,24865);
INSERT INTO "django_geo_db_zipcode" VALUES(27926,62351,-6,'Mendon, Illinois 62351',20341,24866);
INSERT INTO "django_geo_db_zipcode" VALUES(27927,62352,-6,'Milton, Illinois 62352',19494,24867);
INSERT INTO "django_geo_db_zipcode" VALUES(27928,62353,-6,'Mount Sterling, Illinois 62353',20342,24868);
INSERT INTO "django_geo_db_zipcode" VALUES(27929,62354,-6,'Nauvoo, Illinois 62354',20343,24869);
INSERT INTO "django_geo_db_zipcode" VALUES(27930,62355,-6,'Nebo, Illinois 62355',20344,24870);
INSERT INTO "django_geo_db_zipcode" VALUES(27931,62356,-6,'New Canton, Illinois 62356',20345,24871);
INSERT INTO "django_geo_db_zipcode" VALUES(27932,62357,-6,'New Salem, Illinois 62357',20346,24872);
INSERT INTO "django_geo_db_zipcode" VALUES(27933,62358,-6,'Niota, Illinois 62358',20347,24873);
INSERT INTO "django_geo_db_zipcode" VALUES(27934,62359,-6,'Paloma, Illinois 62359',20348,24874);
INSERT INTO "django_geo_db_zipcode" VALUES(27935,62360,-6,'Payson, Illinois 62360',20349,24875);
INSERT INTO "django_geo_db_zipcode" VALUES(27936,62361,-6,'Pearl, Illinois 62361',20350,24876);
INSERT INTO "django_geo_db_zipcode" VALUES(27937,62362,-6,'Perry, Illinois 62362',20351,24877);
INSERT INTO "django_geo_db_zipcode" VALUES(27938,62363,-6,'Pittsfield, Illinois 62363',20352,24878);
INSERT INTO "django_geo_db_zipcode" VALUES(27939,62365,-6,'Plainville, Illinois 62365',20353,24879);
INSERT INTO "django_geo_db_zipcode" VALUES(27940,62366,-6,'Pleasant Hill, Illinois 62366',20354,24880);
INSERT INTO "django_geo_db_zipcode" VALUES(27941,62367,-6,'Plymouth, Illinois 62367',20355,24881);
INSERT INTO "django_geo_db_zipcode" VALUES(27942,62370,-6,'Rockport, Illinois 62370',20356,24882);
INSERT INTO "django_geo_db_zipcode" VALUES(27943,62373,-6,'Sutter, Illinois 62373',20357,24883);
INSERT INTO "django_geo_db_zipcode" VALUES(27944,62374,-6,'Tennessee, Illinois 62374',20358,24884);
INSERT INTO "django_geo_db_zipcode" VALUES(27945,62375,-6,'Timewell, Illinois 62375',20359,24885);
INSERT INTO "django_geo_db_zipcode" VALUES(27946,62376,-6,'Ursa, Illinois 62376',20360,24886);
INSERT INTO "django_geo_db_zipcode" VALUES(27947,62378,-6,'Versailles, Illinois 62378',20361,24887);
INSERT INTO "django_geo_db_zipcode" VALUES(27948,62379,-6,'Warsaw, Illinois 62379',20362,24888);
INSERT INTO "django_geo_db_zipcode" VALUES(27949,62380,-6,'West Point, Illinois 62380',20363,24889);
INSERT INTO "django_geo_db_zipcode" VALUES(27950,62394,-6,'Equality, Illinois 62394',20364,24890);
INSERT INTO "django_geo_db_zipcode" VALUES(27951,62401,-6,'Effingham, Illinois 62401',20365,24891);
INSERT INTO "django_geo_db_zipcode" VALUES(27952,62407,-6,'Summit, Illinois 62407',20366,24892);
INSERT INTO "django_geo_db_zipcode" VALUES(27953,62410,-6,'Allendale, Illinois 62410',20367,24893);
INSERT INTO "django_geo_db_zipcode" VALUES(27954,62411,-6,'Altamont, Illinois 62411',20368,24894);
INSERT INTO "django_geo_db_zipcode" VALUES(27955,62413,-6,'Annapolis, Illinois 62413',20369,24895);
INSERT INTO "django_geo_db_zipcode" VALUES(27956,62414,-6,'Beecher City, Illinois 62414',20370,24896);
INSERT INTO "django_geo_db_zipcode" VALUES(27957,62415,-6,'Birds, Illinois 62415',20371,24897);
INSERT INTO "django_geo_db_zipcode" VALUES(27958,62417,-6,'Bridgeport, Illinois 62417',20372,24898);
INSERT INTO "django_geo_db_zipcode" VALUES(27959,62418,-6,'Brownstown, Illinois 62418',20373,24899);
INSERT INTO "django_geo_db_zipcode" VALUES(27960,62419,-6,'Calhoun, Illinois 62419',20374,24900);
INSERT INTO "django_geo_db_zipcode" VALUES(27961,62420,-6,'Casey, Illinois 62420',20375,24901);
INSERT INTO "django_geo_db_zipcode" VALUES(27962,62421,-6,'Claremont, Illinois 62421',20376,24902);
INSERT INTO "django_geo_db_zipcode" VALUES(27963,62422,-6,'Cowden, Illinois 62422',20377,24903);
INSERT INTO "django_geo_db_zipcode" VALUES(27964,62423,-6,'Dennison, Illinois 62423',20378,24904);
INSERT INTO "django_geo_db_zipcode" VALUES(27965,62424,-6,'Dieterich, Illinois 62424',20379,24905);
INSERT INTO "django_geo_db_zipcode" VALUES(27966,62425,-6,'Dundas, Illinois 62425',20380,24906);
INSERT INTO "django_geo_db_zipcode" VALUES(27967,62426,-6,'Edgewood, Illinois 62426',20381,24907);
INSERT INTO "django_geo_db_zipcode" VALUES(27968,62427,-6,'Flat Rock, Illinois 62427',20382,24908);
INSERT INTO "django_geo_db_zipcode" VALUES(27969,62428,-6,'Greenup, Illinois 62428',20383,24909);
INSERT INTO "django_geo_db_zipcode" VALUES(27970,62431,-6,'Herrick, Illinois 62431',20384,24910);
INSERT INTO "django_geo_db_zipcode" VALUES(27971,62432,-6,'Hidalgo, Illinois 62432',20385,24911);
INSERT INTO "django_geo_db_zipcode" VALUES(27972,62433,-6,'Hutsonville, Illinois 62433',20386,24912);
INSERT INTO "django_geo_db_zipcode" VALUES(27973,62434,-6,'Ingraham, Illinois 62434',20387,24913);
INSERT INTO "django_geo_db_zipcode" VALUES(27974,62435,-6,'Janesville, Illinois 62435',20388,24914);
INSERT INTO "django_geo_db_zipcode" VALUES(27975,62436,-6,'Jewett, Illinois 62436',20389,24915);
INSERT INTO "django_geo_db_zipcode" VALUES(27976,62438,-6,'Lakewood, Illinois 62438',20390,24916);
INSERT INTO "django_geo_db_zipcode" VALUES(27977,62439,-6,'Lawrenceville, Illinois 62439',20391,24917);
INSERT INTO "django_geo_db_zipcode" VALUES(27978,62440,-6,'Lerna, Illinois 62440',20392,24918);
INSERT INTO "django_geo_db_zipcode" VALUES(27979,62441,-6,'Marshall, Illinois 62441',20393,24919);
INSERT INTO "django_geo_db_zipcode" VALUES(27980,62442,-6,'Martinsville, Illinois 62442',20394,24920);
INSERT INTO "django_geo_db_zipcode" VALUES(27981,62443,-6,'Mason, Illinois 62443',20395,24921);
INSERT INTO "django_geo_db_zipcode" VALUES(27982,62444,-6,'Mode, Illinois 62444',20396,24922);
INSERT INTO "django_geo_db_zipcode" VALUES(27983,62445,-6,'Montrose, Illinois 62445',20397,24923);
INSERT INTO "django_geo_db_zipcode" VALUES(27984,62446,-6,'Mount Erie, Illinois 62446',20398,24924);
INSERT INTO "django_geo_db_zipcode" VALUES(27985,62447,-6,'Neoga, Illinois 62447',20399,24925);
INSERT INTO "django_geo_db_zipcode" VALUES(27986,62448,-6,'Newton, Illinois 62448',20400,24926);
INSERT INTO "django_geo_db_zipcode" VALUES(27987,62449,-6,'Oblong, Illinois 62449',20401,24927);
INSERT INTO "django_geo_db_zipcode" VALUES(27988,62450,-6,'Olney, Illinois 62450',20402,24928);
INSERT INTO "django_geo_db_zipcode" VALUES(27989,62451,-6,'Palestine, Illinois 62451',20403,24929);
INSERT INTO "django_geo_db_zipcode" VALUES(27990,62452,-6,'Parkersburg, Illinois 62452',20404,24930);
INSERT INTO "django_geo_db_zipcode" VALUES(27991,62454,-6,'Robinson, Illinois 62454',20405,24931);
INSERT INTO "django_geo_db_zipcode" VALUES(27992,62458,-6,'Saint Elmo, Illinois 62458',20406,24932);
INSERT INTO "django_geo_db_zipcode" VALUES(27993,62459,-6,'Sainte Marie, Illinois 62459',20407,24933);
INSERT INTO "django_geo_db_zipcode" VALUES(27994,62460,-6,'Saint Francisville, Illinois 62460',20408,24934);
INSERT INTO "django_geo_db_zipcode" VALUES(27995,62461,-6,'Shumway, Illinois 62461',20409,24935);
INSERT INTO "django_geo_db_zipcode" VALUES(27996,62462,-6,'Sigel, Illinois 62462',20410,24936);
INSERT INTO "django_geo_db_zipcode" VALUES(27997,62463,-6,'Stewardson, Illinois 62463',20411,24937);
INSERT INTO "django_geo_db_zipcode" VALUES(27998,62464,-6,'Stoy, Illinois 62464',20412,24938);
INSERT INTO "django_geo_db_zipcode" VALUES(27999,62465,-6,'Strasburg, Illinois 62465',20413,24939);
INSERT INTO "django_geo_db_zipcode" VALUES(28000,62466,-6,'Sumner, Illinois 62466',20414,24940);
INSERT INTO "django_geo_db_zipcode" VALUES(28001,62467,-6,'Teutopolis, Illinois 62467',20415,24941);
INSERT INTO "django_geo_db_zipcode" VALUES(28002,62468,-6,'Toledo, Illinois 62468',20416,24942);
INSERT INTO "django_geo_db_zipcode" VALUES(28003,62469,-6,'Trilla, Illinois 62469',20417,24943);
INSERT INTO "django_geo_db_zipcode" VALUES(28004,62471,-6,'Vandalia, Illinois 62471',20418,24944);
INSERT INTO "django_geo_db_zipcode" VALUES(28005,62473,-6,'Watson, Illinois 62473',20419,24945);
INSERT INTO "django_geo_db_zipcode" VALUES(28006,62474,-6,'Westfield, Illinois 62474',20420,24946);
INSERT INTO "django_geo_db_zipcode" VALUES(28007,62475,-6,'West Liberty, Illinois 62475',20421,24947);
INSERT INTO "django_geo_db_zipcode" VALUES(28008,62476,-6,'West Salem, Illinois 62476',20422,24948);
INSERT INTO "django_geo_db_zipcode" VALUES(28009,62477,-6,'West Union, Illinois 62477',20423,24949);
INSERT INTO "django_geo_db_zipcode" VALUES(28010,62478,-6,'West York, Illinois 62478',20424,24950);
INSERT INTO "django_geo_db_zipcode" VALUES(28011,62479,-6,'Wheeler, Illinois 62479',20425,24951);
INSERT INTO "django_geo_db_zipcode" VALUES(28012,62480,-6,'Willow Hill, Illinois 62480',20426,24952);
INSERT INTO "django_geo_db_zipcode" VALUES(28013,62481,-6,'Yale, Illinois 62481',20427,24953);
INSERT INTO "django_geo_db_zipcode" VALUES(28014,62501,-6,'Argenta, Illinois 62501',20428,24954);
INSERT INTO "django_geo_db_zipcode" VALUES(28015,62510,-6,'Assumption, Illinois 62510',20429,24955);
INSERT INTO "django_geo_db_zipcode" VALUES(28016,62511,-6,'Atwater, Illinois 62511',20430,24956);
INSERT INTO "django_geo_db_zipcode" VALUES(28017,62512,-6,'Beason, Illinois 62512',20431,24957);
INSERT INTO "django_geo_db_zipcode" VALUES(28018,62513,-6,'Blue Mound, Illinois 62513',20432,24958);
INSERT INTO "django_geo_db_zipcode" VALUES(28019,62514,-6,'Boody, Illinois 62514',20433,24959);
INSERT INTO "django_geo_db_zipcode" VALUES(28020,62515,-6,'Buffalo, Illinois 62515',20434,24960);
INSERT INTO "django_geo_db_zipcode" VALUES(28021,62517,-6,'Bulpitt, Illinois 62517',20435,24961);
INSERT INTO "django_geo_db_zipcode" VALUES(28022,62518,-6,'Chestnut, Illinois 62518',20436,24962);
INSERT INTO "django_geo_db_zipcode" VALUES(28023,62519,-6,'Cornland, Illinois 62519',20437,24963);
INSERT INTO "django_geo_db_zipcode" VALUES(28024,62520,-6,'Dawson, Illinois 62520',20438,24964);
INSERT INTO "django_geo_db_zipcode" VALUES(28025,62521,-6,'Decatur, Illinois 62521',20439,24965);
INSERT INTO "django_geo_db_zipcode" VALUES(28026,62522,-6,'Decatur, Illinois 62522',20439,24966);
INSERT INTO "django_geo_db_zipcode" VALUES(28027,62523,-6,'Decatur, Illinois 62523',20439,24967);
INSERT INTO "django_geo_db_zipcode" VALUES(28028,62524,-6,'Decatur, Illinois 62524',20439,24968);
INSERT INTO "django_geo_db_zipcode" VALUES(28029,62525,-6,'Decatur, Illinois 62525',20439,24968);
INSERT INTO "django_geo_db_zipcode" VALUES(28030,62526,-6,'Decatur, Illinois 62526',20439,24969);
INSERT INTO "django_geo_db_zipcode" VALUES(28031,62527,-6,'Decatur, Illinois 62527',20439,24968);
INSERT INTO "django_geo_db_zipcode" VALUES(28032,62530,-6,'Divernon, Illinois 62530',20440,24970);
INSERT INTO "django_geo_db_zipcode" VALUES(28033,62531,-6,'Edinburg, Illinois 62531',20441,24971);
INSERT INTO "django_geo_db_zipcode" VALUES(28034,62532,-6,'Elwin, Illinois 62532',20442,24972);
INSERT INTO "django_geo_db_zipcode" VALUES(28035,62533,-6,'Farmersville, Illinois 62533',20443,24973);
INSERT INTO "django_geo_db_zipcode" VALUES(28036,62534,-6,'Findlay, Illinois 62534',20444,24974);
INSERT INTO "django_geo_db_zipcode" VALUES(28037,62535,-6,'Forsyth, Illinois 62535',20445,24975);
INSERT INTO "django_geo_db_zipcode" VALUES(28038,62536,-6,'Glenarm, Illinois 62536',20446,24976);
INSERT INTO "django_geo_db_zipcode" VALUES(28039,62537,-6,'Harristown, Illinois 62537',20447,24977);
INSERT INTO "django_geo_db_zipcode" VALUES(28040,62538,-6,'Harvel, Illinois 62538',20448,24978);
INSERT INTO "django_geo_db_zipcode" VALUES(28041,62539,-6,'Illiopolis, Illinois 62539',20449,24979);
INSERT INTO "django_geo_db_zipcode" VALUES(28042,62540,-6,'Kincaid, Illinois 62540',20450,24980);
INSERT INTO "django_geo_db_zipcode" VALUES(28043,62541,-6,'Lake Fork, Illinois 62541',20451,24981);
INSERT INTO "django_geo_db_zipcode" VALUES(28044,62543,-6,'Latham, Illinois 62543',20452,24982);
INSERT INTO "django_geo_db_zipcode" VALUES(28045,62544,-6,'Macon, Illinois 62544',20453,24983);
INSERT INTO "django_geo_db_zipcode" VALUES(28046,62545,-6,'Mechanicsburg, Illinois 62545',20454,24984);
INSERT INTO "django_geo_db_zipcode" VALUES(28047,62546,-6,'Morrisonville, Illinois 62546',20455,24985);
INSERT INTO "django_geo_db_zipcode" VALUES(28048,62547,-6,'Mount Auburn, Illinois 62547',20456,24986);
INSERT INTO "django_geo_db_zipcode" VALUES(28049,62548,-6,'Mount Pulaski, Illinois 62548',20457,24987);
INSERT INTO "django_geo_db_zipcode" VALUES(28050,62549,-6,'Mt Zion, Illinois 62549',20458,24988);
INSERT INTO "django_geo_db_zipcode" VALUES(28051,62550,-6,'Moweaqua, Illinois 62550',20459,24989);
INSERT INTO "django_geo_db_zipcode" VALUES(28052,62551,-6,'Niantic, Illinois 62551',20460,24990);
INSERT INTO "django_geo_db_zipcode" VALUES(28053,62552,-6,'Oakley, Illinois 62552',20461,24991);
INSERT INTO "django_geo_db_zipcode" VALUES(28054,62553,-6,'Oconee, Illinois 62553',20462,24992);
INSERT INTO "django_geo_db_zipcode" VALUES(28055,62554,-6,'Oreana, Illinois 62554',20463,24993);
INSERT INTO "django_geo_db_zipcode" VALUES(28056,62555,-6,'Owaneco, Illinois 62555',20464,24994);
INSERT INTO "django_geo_db_zipcode" VALUES(28057,62556,-6,'Palmer, Illinois 62556',20465,24995);
INSERT INTO "django_geo_db_zipcode" VALUES(28058,62557,-6,'Pana, Illinois 62557',20466,24996);
INSERT INTO "django_geo_db_zipcode" VALUES(28059,62558,-6,'Pawnee, Illinois 62558',20467,24997);
INSERT INTO "django_geo_db_zipcode" VALUES(28060,62560,-6,'Raymond, Illinois 62560',20468,24998);
INSERT INTO "django_geo_db_zipcode" VALUES(28061,62561,-6,'Riverton, Illinois 62561',20469,24999);
INSERT INTO "django_geo_db_zipcode" VALUES(28062,62563,-6,'Rochester, Illinois 62563',20470,25000);
INSERT INTO "django_geo_db_zipcode" VALUES(28063,62565,-6,'Shelbyville, Illinois 62565',20471,25001);
INSERT INTO "django_geo_db_zipcode" VALUES(28064,62567,-6,'Stonington, Illinois 62567',20472,25002);
INSERT INTO "django_geo_db_zipcode" VALUES(28065,62568,-6,'Taylorville, Illinois 62568',20473,25003);
INSERT INTO "django_geo_db_zipcode" VALUES(28066,62570,-6,'Tovey, Illinois 62570',20474,25004);
INSERT INTO "django_geo_db_zipcode" VALUES(28067,62571,-6,'Tower Hill, Illinois 62571',20475,25005);
INSERT INTO "django_geo_db_zipcode" VALUES(28068,62572,-6,'Waggoner, Illinois 62572',20476,25006);
INSERT INTO "django_geo_db_zipcode" VALUES(28069,62573,-6,'Warrensburg, Illinois 62573',20477,25007);
INSERT INTO "django_geo_db_zipcode" VALUES(28070,62601,-6,'Alexander, Illinois 62601',20478,25008);
INSERT INTO "django_geo_db_zipcode" VALUES(28071,62605,-6,'Emden, Illinois 62605',20479,25009);
INSERT INTO "django_geo_db_zipcode" VALUES(28072,62610,-6,'Alsey, Illinois 62610',20480,25010);
INSERT INTO "django_geo_db_zipcode" VALUES(28073,62611,-6,'Arenzville, Illinois 62611',20481,25011);
INSERT INTO "django_geo_db_zipcode" VALUES(28074,62612,-6,'Ashland, Illinois 62612',20482,25012);
INSERT INTO "django_geo_db_zipcode" VALUES(28075,62613,-6,'Athens, Illinois 62613',20483,25013);
INSERT INTO "django_geo_db_zipcode" VALUES(28076,62615,-6,'Auburn, Illinois 62615',20484,25014);
INSERT INTO "django_geo_db_zipcode" VALUES(28077,62616,-6,'Philadelphia, Illinois 62616',20485,25015);
INSERT INTO "django_geo_db_zipcode" VALUES(28078,62617,-6,'Bath, Illinois 62617',20486,25016);
INSERT INTO "django_geo_db_zipcode" VALUES(28079,62618,-6,'Beardstown, Illinois 62618',20487,25017);
INSERT INTO "django_geo_db_zipcode" VALUES(28080,62621,-6,'Bluffs, Illinois 62621',20488,25018);
INSERT INTO "django_geo_db_zipcode" VALUES(28081,62622,-6,'Bluff Springs, Illinois 62622',20489,25019);
INSERT INTO "django_geo_db_zipcode" VALUES(28082,62623,-6,'Oakford, Illinois 62623',20490,25020);
INSERT INTO "django_geo_db_zipcode" VALUES(28083,62624,-6,'Browning, Illinois 62624',20491,25021);
INSERT INTO "django_geo_db_zipcode" VALUES(28084,62625,-6,'Cantrall, Illinois 62625',20492,25022);
INSERT INTO "django_geo_db_zipcode" VALUES(28085,62626,-6,'Carlinville, Illinois 62626',20493,25023);
INSERT INTO "django_geo_db_zipcode" VALUES(28086,62627,-6,'Chandlerville, Illinois 62627',20494,25024);
INSERT INTO "django_geo_db_zipcode" VALUES(28087,62628,-6,'Chapin, Illinois 62628',20495,25025);
INSERT INTO "django_geo_db_zipcode" VALUES(28088,62629,-6,'Chatham, Illinois 62629',20496,25026);
INSERT INTO "django_geo_db_zipcode" VALUES(28089,62630,-6,'Chesterfield, Illinois 62630',20497,25027);
INSERT INTO "django_geo_db_zipcode" VALUES(28090,62631,-6,'Concord, Illinois 62631',20498,25028);
INSERT INTO "django_geo_db_zipcode" VALUES(28091,62633,-6,'Easton, Illinois 62633',20499,25029);
INSERT INTO "django_geo_db_zipcode" VALUES(28092,62634,-6,'Elkhart, Illinois 62634',20500,25030);
INSERT INTO "django_geo_db_zipcode" VALUES(28093,62635,-6,'Emden, Illinois 62635',20479,25031);
INSERT INTO "django_geo_db_zipcode" VALUES(28094,62638,-6,'Franklin, Illinois 62638',20501,25032);
INSERT INTO "django_geo_db_zipcode" VALUES(28095,62639,-6,'Frederick, Illinois 62639',20502,25033);
INSERT INTO "django_geo_db_zipcode" VALUES(28096,62640,-6,'Girard, Illinois 62640',20503,25034);
INSERT INTO "django_geo_db_zipcode" VALUES(28097,62642,-6,'Greenview, Illinois 62642',20504,25035);
INSERT INTO "django_geo_db_zipcode" VALUES(28098,62643,-6,'Hartsburg, Illinois 62643',20505,25036);
INSERT INTO "django_geo_db_zipcode" VALUES(28099,62644,-6,'Havana, Illinois 62644',20506,25037);
INSERT INTO "django_geo_db_zipcode" VALUES(28100,62648,-6,'Herrin, Illinois 62648',20507,25038);
INSERT INTO "django_geo_db_zipcode" VALUES(28101,62649,-6,'Hettick, Illinois 62649',20508,25039);
INSERT INTO "django_geo_db_zipcode" VALUES(28102,62650,-6,'Jacksonville, Illinois 62650',20509,25040);
INSERT INTO "django_geo_db_zipcode" VALUES(28103,62651,-6,'Jacksonville, Illinois 62651',20509,25041);
INSERT INTO "django_geo_db_zipcode" VALUES(28104,62652,-6,'Milton, Illinois 62652',19494,25042);
INSERT INTO "django_geo_db_zipcode" VALUES(28105,62655,-6,'Kilbourne, Illinois 62655',20510,25043);
INSERT INTO "django_geo_db_zipcode" VALUES(28106,62656,-6,'Lincoln, Illinois 62656',20511,25044);
INSERT INTO "django_geo_db_zipcode" VALUES(28107,62659,-6,'Lincoln''S New Salem, Illinois 62659',20512,25045);
INSERT INTO "django_geo_db_zipcode" VALUES(28108,62660,-6,'Literberry, Illinois 62660',20513,25046);
INSERT INTO "django_geo_db_zipcode" VALUES(28109,62661,-6,'Loami, Illinois 62661',20514,25047);
INSERT INTO "django_geo_db_zipcode" VALUES(28110,62662,-6,'Lowder, Illinois 62662',20515,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28111,62663,-6,'Manchester, Illinois 62663',20516,25049);
INSERT INTO "django_geo_db_zipcode" VALUES(28112,62664,-6,'Mason City, Illinois 62664',20517,25050);
INSERT INTO "django_geo_db_zipcode" VALUES(28113,62665,-6,'Meredosia, Illinois 62665',20518,25051);
INSERT INTO "django_geo_db_zipcode" VALUES(28114,62666,-6,'Middletown, Illinois 62666',20519,25052);
INSERT INTO "django_geo_db_zipcode" VALUES(28115,62667,-6,'Modesto, Illinois 62667',20520,25053);
INSERT INTO "django_geo_db_zipcode" VALUES(28116,62668,-6,'Murrayville, Illinois 62668',20521,25054);
INSERT INTO "django_geo_db_zipcode" VALUES(28117,62670,-6,'New Berlin, Illinois 62670',20522,25055);
INSERT INTO "django_geo_db_zipcode" VALUES(28118,62671,-6,'New Holland, Illinois 62671',20523,25056);
INSERT INTO "django_geo_db_zipcode" VALUES(28119,62672,-6,'Nilwood, Illinois 62672',20524,25057);
INSERT INTO "django_geo_db_zipcode" VALUES(28120,62673,-6,'Oakford, Illinois 62673',20490,25058);
INSERT INTO "django_geo_db_zipcode" VALUES(28121,62674,-6,'Palmyra, Illinois 62674',20525,25059);
INSERT INTO "django_geo_db_zipcode" VALUES(28122,62675,-6,'Petersburg, Illinois 62675',20526,25060);
INSERT INTO "django_geo_db_zipcode" VALUES(28123,62676,-6,'Hillyard, Illinois 62676',20527,25061);
INSERT INTO "django_geo_db_zipcode" VALUES(28124,62677,-6,'Pleasant Plains, Illinois 62677',20528,25062);
INSERT INTO "django_geo_db_zipcode" VALUES(28125,62681,-6,'Rushville, Illinois 62681',20529,25063);
INSERT INTO "django_geo_db_zipcode" VALUES(28126,62682,-6,'San Jose, Illinois 62682',20530,25064);
INSERT INTO "django_geo_db_zipcode" VALUES(28127,62683,-6,'Scottville, Illinois 62683',20531,25065);
INSERT INTO "django_geo_db_zipcode" VALUES(28128,62684,-6,'Sherman, Illinois 62684',20532,25066);
INSERT INTO "django_geo_db_zipcode" VALUES(28129,62685,-6,'Shipman, Illinois 62685',20533,25067);
INSERT INTO "django_geo_db_zipcode" VALUES(28130,62686,-6,'Standard City, Illinois 62686',20534,25068);
INSERT INTO "django_geo_db_zipcode" VALUES(28131,62688,-6,'Tallula, Illinois 62688',20535,25069);
INSERT INTO "django_geo_db_zipcode" VALUES(28132,62689,-6,'Thayer, Illinois 62689',20536,25070);
INSERT INTO "django_geo_db_zipcode" VALUES(28133,62690,-6,'Virden, Illinois 62690',20537,25071);
INSERT INTO "django_geo_db_zipcode" VALUES(28134,62691,-6,'Virginia, Illinois 62691',20538,25072);
INSERT INTO "django_geo_db_zipcode" VALUES(28135,62692,-6,'Waverly, Illinois 62692',20539,25073);
INSERT INTO "django_geo_db_zipcode" VALUES(28136,62693,-6,'Williamsville, Illinois 62693',20540,25074);
INSERT INTO "django_geo_db_zipcode" VALUES(28137,62694,-6,'Winchester, Illinois 62694',20541,25075);
INSERT INTO "django_geo_db_zipcode" VALUES(28138,62695,-6,'Woodson, Illinois 62695',20542,25076);
INSERT INTO "django_geo_db_zipcode" VALUES(28139,62701,-6,'Springfield, Illinois 62701',20543,25077);
INSERT INTO "django_geo_db_zipcode" VALUES(28140,62702,-6,'Springfield, Illinois 62702',20543,25078);
INSERT INTO "django_geo_db_zipcode" VALUES(28141,62703,-6,'Springfield, Illinois 62703',20543,25079);
INSERT INTO "django_geo_db_zipcode" VALUES(28142,62704,-6,'Springfield, Illinois 62704',20543,25080);
INSERT INTO "django_geo_db_zipcode" VALUES(28143,62705,-6,'Springfield, Illinois 62705',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28144,62706,-6,'Springfield, Illinois 62706',20543,25081);
INSERT INTO "django_geo_db_zipcode" VALUES(28145,62707,-6,'Springfield, Illinois 62707',20543,25082);
INSERT INTO "django_geo_db_zipcode" VALUES(28146,62708,-6,'Springfield, Illinois 62708',20543,25083);
INSERT INTO "django_geo_db_zipcode" VALUES(28147,62709,-6,'Springfield, Illinois 62709',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28148,62713,-6,'Springfield, Illinois 62713',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28149,62715,-6,'Springfield, Illinois 62715',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28150,62716,-6,'Springfield, Illinois 62716',20543,25084);
INSERT INTO "django_geo_db_zipcode" VALUES(28151,62718,-6,'Springfield, Illinois 62718',20543,25085);
INSERT INTO "django_geo_db_zipcode" VALUES(28152,62719,-6,'Springfield, Illinois 62719',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28153,62720,-6,'Springfield, Illinois 62720',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28154,62721,-6,'Springfield, Illinois 62721',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28155,62722,-6,'Springfield, Illinois 62722',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28156,62723,-6,'Springfield, Illinois 62723',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28157,62726,-6,'Springfield, Illinois 62726',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28158,62736,-6,'Springfield, Illinois 62736',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28159,62739,-6,'Springfield, Illinois 62739',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28160,62746,-6,'Springfield, Illinois 62746',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28161,62756,-6,'Springfield, Illinois 62756',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28162,62757,-6,'Springfield, Illinois 62757',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28163,62761,-6,'Springfield, Illinois 62761',20543,25086);
INSERT INTO "django_geo_db_zipcode" VALUES(28164,62762,-6,'Springfield, Illinois 62762',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28165,62763,-6,'Springfield, Illinois 62763',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28166,62764,-6,'Springfield, Illinois 62764',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28167,62765,-6,'Springfield, Illinois 62765',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28168,62766,-6,'Springfield, Illinois 62766',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28169,62767,-6,'Springfield, Illinois 62767',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28170,62769,-6,'Springfield, Illinois 62769',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28171,62776,-6,'Springfield, Illinois 62776',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28172,62777,-6,'Springfield, Illinois 62777',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28173,62781,-6,'Springfield, Illinois 62781',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28174,62786,-6,'Springfield, Illinois 62786',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28175,62791,-6,'Springfield, Illinois 62791',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28176,62792,-6,'Ullin, Illinois 62792',20544,25087);
INSERT INTO "django_geo_db_zipcode" VALUES(28177,62794,-6,'Springfield, Illinois 62794',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28178,62796,-6,'Springfield, Illinois 62796',20543,25048);
INSERT INTO "django_geo_db_zipcode" VALUES(28179,62801,-6,'Centralia, Illinois 62801',20545,25088);
INSERT INTO "django_geo_db_zipcode" VALUES(28180,62803,-6,'Hoyleton, Illinois 62803',20546,25089);
INSERT INTO "django_geo_db_zipcode" VALUES(28181,62805,-6,'Akin, Illinois 62805',20547,25090);
INSERT INTO "django_geo_db_zipcode" VALUES(28182,62806,-6,'Albion, Illinois 62806',20548,25091);
INSERT INTO "django_geo_db_zipcode" VALUES(28183,62807,-6,'Alma, Illinois 62807',20549,25092);
INSERT INTO "django_geo_db_zipcode" VALUES(28184,62808,-6,'Ashley, Illinois 62808',20550,25093);
INSERT INTO "django_geo_db_zipcode" VALUES(28185,62809,-6,'Barnhill, Illinois 62809',20551,25094);
INSERT INTO "django_geo_db_zipcode" VALUES(28186,62810,-6,'Belle Rive, Illinois 62810',20552,25095);
INSERT INTO "django_geo_db_zipcode" VALUES(28187,62811,-6,'Bellmont, Illinois 62811',20553,25096);
INSERT INTO "django_geo_db_zipcode" VALUES(28188,62812,-6,'Benton, Illinois 62812',20554,25097);
INSERT INTO "django_geo_db_zipcode" VALUES(28189,62814,-6,'Bluford, Illinois 62814',20555,25098);
INSERT INTO "django_geo_db_zipcode" VALUES(28190,62815,-6,'Bone Gap, Illinois 62815',20556,25099);
INSERT INTO "django_geo_db_zipcode" VALUES(28191,62816,-6,'Bonnie, Illinois 62816',20557,25100);
INSERT INTO "django_geo_db_zipcode" VALUES(28192,62817,-6,'Broughton, Illinois 62817',20558,25101);
INSERT INTO "django_geo_db_zipcode" VALUES(28193,62818,-6,'Browns, Illinois 62818',20559,25102);
INSERT INTO "django_geo_db_zipcode" VALUES(28194,62819,-6,'Buckner, Illinois 62819',20560,25103);
INSERT INTO "django_geo_db_zipcode" VALUES(28195,62820,-6,'Burnt Prairie, Illinois 62820',20561,25104);
INSERT INTO "django_geo_db_zipcode" VALUES(28196,62821,-6,'Carmi, Illinois 62821',20562,25105);
INSERT INTO "django_geo_db_zipcode" VALUES(28197,62822,-6,'Christopher, Illinois 62822',20563,25106);
INSERT INTO "django_geo_db_zipcode" VALUES(28198,62823,-6,'Cisne, Illinois 62823',20564,25107);
INSERT INTO "django_geo_db_zipcode" VALUES(28199,62824,-6,'Clay City, Illinois 62824',20565,25108);
INSERT INTO "django_geo_db_zipcode" VALUES(28200,62825,-6,'Coello, Illinois 62825',20566,25109);
INSERT INTO "django_geo_db_zipcode" VALUES(28201,62827,-6,'Crossville, Illinois 62827',20567,25110);
INSERT INTO "django_geo_db_zipcode" VALUES(28202,62828,-6,'Dahlgren, Illinois 62828',20568,25111);
INSERT INTO "django_geo_db_zipcode" VALUES(28203,62829,-6,'Dale, Illinois 62829',20569,25112);
INSERT INTO "django_geo_db_zipcode" VALUES(28204,62830,-6,'Dix, Illinois 62830',20570,25113);
INSERT INTO "django_geo_db_zipcode" VALUES(28205,62831,-6,'Du Bois, Illinois 62831',20571,25114);
INSERT INTO "django_geo_db_zipcode" VALUES(28206,62832,-6,'Du Quoin, Illinois 62832',20572,25115);
INSERT INTO "django_geo_db_zipcode" VALUES(28207,62833,-6,'Ellery, Illinois 62833',20573,25116);
INSERT INTO "django_geo_db_zipcode" VALUES(28208,62834,-6,'Emma, Illinois 62834',20574,25117);
INSERT INTO "django_geo_db_zipcode" VALUES(28209,62835,-6,'Enfield, Illinois 62835',20575,25118);
INSERT INTO "django_geo_db_zipcode" VALUES(28210,62836,-6,'Ewing, Illinois 62836',20576,25119);
INSERT INTO "django_geo_db_zipcode" VALUES(28211,62837,-6,'Fairfield, Illinois 62837',20577,25120);
INSERT INTO "django_geo_db_zipcode" VALUES(28212,62838,-6,'Farina, Illinois 62838',20578,25121);
INSERT INTO "django_geo_db_zipcode" VALUES(28213,62839,-6,'Flora, Illinois 62839',20579,25122);
INSERT INTO "django_geo_db_zipcode" VALUES(28214,62840,-6,'Frankfort Heights, Illinois 62840',20580,25090);
INSERT INTO "django_geo_db_zipcode" VALUES(28215,62841,-6,'Freeman Spur, Illinois 62841',20581,25123);
INSERT INTO "django_geo_db_zipcode" VALUES(28216,62842,-6,'Geff, Illinois 62842',20582,25124);
INSERT INTO "django_geo_db_zipcode" VALUES(28217,62843,-6,'Golden Gate, Illinois 62843',20583,25125);
INSERT INTO "django_geo_db_zipcode" VALUES(28218,62844,-6,'Grayville, Illinois 62844',20584,25126);
INSERT INTO "django_geo_db_zipcode" VALUES(28219,62845,-6,'Herald, Illinois 62845',20585,25127);
INSERT INTO "django_geo_db_zipcode" VALUES(28220,62846,-6,'Ina, Illinois 62846',20586,25128);
INSERT INTO "django_geo_db_zipcode" VALUES(28221,62847,-6,'Iola, Illinois 62847',20587,25129);
INSERT INTO "django_geo_db_zipcode" VALUES(28222,62848,-6,'Irvington, Illinois 62848',20588,25130);
INSERT INTO "django_geo_db_zipcode" VALUES(28223,62849,-6,'Iuka, Illinois 62849',20589,25131);
INSERT INTO "django_geo_db_zipcode" VALUES(28224,62850,-6,'Johnsonville, Illinois 62850',20590,25132);
INSERT INTO "django_geo_db_zipcode" VALUES(28225,62851,-6,'Keenes, Illinois 62851',20591,25133);
INSERT INTO "django_geo_db_zipcode" VALUES(28226,62852,-6,'Keensburg, Illinois 62852',20592,25134);
INSERT INTO "django_geo_db_zipcode" VALUES(28227,62853,-6,'Kell, Illinois 62853',20593,25135);
INSERT INTO "django_geo_db_zipcode" VALUES(28228,62854,-6,'Kinmundy, Illinois 62854',20594,25136);
INSERT INTO "django_geo_db_zipcode" VALUES(28229,62855,-6,'Lancaster, Illinois 62855',20595,25137);
INSERT INTO "django_geo_db_zipcode" VALUES(28230,62856,-6,'Logan, Illinois 62856',20596,25090);
INSERT INTO "django_geo_db_zipcode" VALUES(28231,62857,-6,'Loogootee, Illinois 62857',20597,25138);
INSERT INTO "django_geo_db_zipcode" VALUES(28232,62858,-6,'Louisville, Illinois 62858',20598,25139);
INSERT INTO "django_geo_db_zipcode" VALUES(28233,62859,-6,'McLeansboro, Illinois 62859',20599,25140);
INSERT INTO "django_geo_db_zipcode" VALUES(28234,62860,-6,'Macedonia, Illinois 62860',20600,25141);
INSERT INTO "django_geo_db_zipcode" VALUES(28235,62861,-6,'Maunie, Illinois 62861',20601,25142);
INSERT INTO "django_geo_db_zipcode" VALUES(28236,62862,-6,'Mill Shoals, Illinois 62862',20602,25143);
INSERT INTO "django_geo_db_zipcode" VALUES(28237,62863,-6,'Mount Carmel, Illinois 62863',20603,25144);
INSERT INTO "django_geo_db_zipcode" VALUES(28238,62864,-6,'Mount Vernon, Illinois 62864',20604,25145);
INSERT INTO "django_geo_db_zipcode" VALUES(28239,62865,-6,'Mulkeytown, Illinois 62865',20605,25146);
INSERT INTO "django_geo_db_zipcode" VALUES(28240,62866,-6,'Nason, Illinois 62866',20606,25147);
INSERT INTO "django_geo_db_zipcode" VALUES(28241,62867,-6,'New Haven, Illinois 62867',20607,25148);
INSERT INTO "django_geo_db_zipcode" VALUES(28242,62868,-6,'Noble, Illinois 62868',20608,25149);
INSERT INTO "django_geo_db_zipcode" VALUES(28243,62869,-6,'Norris City, Illinois 62869',20609,25150);
INSERT INTO "django_geo_db_zipcode" VALUES(28244,62870,-6,'Odin, Illinois 62870',20610,25151);
INSERT INTO "django_geo_db_zipcode" VALUES(28245,62871,-6,'Omaha, Illinois 62871',20611,25152);
INSERT INTO "django_geo_db_zipcode" VALUES(28246,62872,-6,'Opdyke, Illinois 62872',20612,25153);
INSERT INTO "django_geo_db_zipcode" VALUES(28247,62874,-6,'Orient, Illinois 62874',20613,25154);
INSERT INTO "django_geo_db_zipcode" VALUES(28248,62875,-6,'Patoka, Illinois 62875',20614,25155);
INSERT INTO "django_geo_db_zipcode" VALUES(28249,62876,-6,'Radom, Illinois 62876',20615,25156);
INSERT INTO "django_geo_db_zipcode" VALUES(28250,62877,-6,'Richview, Illinois 62877',20616,25157);
INSERT INTO "django_geo_db_zipcode" VALUES(28251,62878,-6,'Rinard, Illinois 62878',20617,25158);
INSERT INTO "django_geo_db_zipcode" VALUES(28252,62879,-6,'Sailor Springs, Illinois 62879',20618,25159);
INSERT INTO "django_geo_db_zipcode" VALUES(28253,62880,-6,'Saint Peter, Illinois 62880',20619,25160);
INSERT INTO "django_geo_db_zipcode" VALUES(28254,62881,-6,'Salem, Illinois 62881',20620,25161);
INSERT INTO "django_geo_db_zipcode" VALUES(28255,62882,-6,'Sandoval, Illinois 62882',20621,25162);
INSERT INTO "django_geo_db_zipcode" VALUES(28256,62883,-6,'Scheller, Illinois 62883',20622,25163);
INSERT INTO "django_geo_db_zipcode" VALUES(28257,62884,-6,'Sesser, Illinois 62884',20623,25164);
INSERT INTO "django_geo_db_zipcode" VALUES(28258,62885,-6,'Shobonier, Illinois 62885',20624,25165);
INSERT INTO "django_geo_db_zipcode" VALUES(28259,62886,-6,'Sims, Illinois 62886',20625,25166);
INSERT INTO "django_geo_db_zipcode" VALUES(28260,62887,-6,'Springerton, Illinois 62887',20626,25167);
INSERT INTO "django_geo_db_zipcode" VALUES(28261,62888,-6,'Tamaroa, Illinois 62888',20627,25168);
INSERT INTO "django_geo_db_zipcode" VALUES(28262,62889,-6,'Texico, Illinois 62889',20628,25169);
INSERT INTO "django_geo_db_zipcode" VALUES(28263,62890,-6,'Thompsonville, Illinois 62890',20629,25170);
INSERT INTO "django_geo_db_zipcode" VALUES(28264,62891,-6,'Valier, Illinois 62891',20630,25171);
INSERT INTO "django_geo_db_zipcode" VALUES(28265,62892,-6,'Vernon, Illinois 62892',20631,25172);
INSERT INTO "django_geo_db_zipcode" VALUES(28266,62893,-6,'Walnut Hill, Illinois 62893',20632,25173);
INSERT INTO "django_geo_db_zipcode" VALUES(28267,62894,-6,'Waltonville, Illinois 62894',20633,25174);
INSERT INTO "django_geo_db_zipcode" VALUES(28268,62895,-6,'Wayne City, Illinois 62895',20634,25175);
INSERT INTO "django_geo_db_zipcode" VALUES(28269,62896,-6,'West Frankfort, Illinois 62896',20635,25176);
INSERT INTO "django_geo_db_zipcode" VALUES(28270,62897,-6,'Whittington, Illinois 62897',20636,25177);
INSERT INTO "django_geo_db_zipcode" VALUES(28271,62898,-6,'Woodlawn, Illinois 62898',20637,25178);
INSERT INTO "django_geo_db_zipcode" VALUES(28272,62899,-6,'Xenia, Illinois 62899',20638,25179);
INSERT INTO "django_geo_db_zipcode" VALUES(28273,62901,-6,'Carbondale, Illinois 62901',20639,25180);
INSERT INTO "django_geo_db_zipcode" VALUES(28274,62902,-6,'Carbondale, Illinois 62902',20639,25181);
INSERT INTO "django_geo_db_zipcode" VALUES(28275,62903,-6,'Carbondale, Illinois 62903',20639,25181);
INSERT INTO "django_geo_db_zipcode" VALUES(28276,62905,-6,'Alto Pass, Illinois 62905',20640,25182);
INSERT INTO "django_geo_db_zipcode" VALUES(28277,62906,-6,'Anna, Illinois 62906',20641,25183);
INSERT INTO "django_geo_db_zipcode" VALUES(28278,62907,-6,'Ava, Illinois 62907',20642,25184);
INSERT INTO "django_geo_db_zipcode" VALUES(28279,62908,-6,'Belknap, Illinois 62908',20643,25185);
INSERT INTO "django_geo_db_zipcode" VALUES(28280,62909,-6,'Boles, Illinois 62909',20644,25186);
INSERT INTO "django_geo_db_zipcode" VALUES(28281,62910,-6,'Brookport, Illinois 62910',20645,25187);
INSERT INTO "django_geo_db_zipcode" VALUES(28282,62912,-6,'Buncombe, Illinois 62912',20646,25188);
INSERT INTO "django_geo_db_zipcode" VALUES(28283,62913,-6,'Cache, Illinois 62913',20647,25189);
INSERT INTO "django_geo_db_zipcode" VALUES(28284,62914,-6,'Cairo, Illinois 62914',20648,25190);
INSERT INTO "django_geo_db_zipcode" VALUES(28285,62915,-6,'Cambria, Illinois 62915',20649,25191);
INSERT INTO "django_geo_db_zipcode" VALUES(28286,62916,-6,'Campbell Hill, Illinois 62916',20650,25192);
INSERT INTO "django_geo_db_zipcode" VALUES(28287,62917,-6,'Carrier Mills, Illinois 62917',20651,25193);
INSERT INTO "django_geo_db_zipcode" VALUES(28288,62918,-6,'Carterville, Illinois 62918',20652,25194);
INSERT INTO "django_geo_db_zipcode" VALUES(28289,62919,-6,'Cave In Rock, Illinois 62919',20653,25195);
INSERT INTO "django_geo_db_zipcode" VALUES(28290,62920,-6,'Cobden, Illinois 62920',20654,25196);
INSERT INTO "django_geo_db_zipcode" VALUES(28291,62921,-6,'Colp, Illinois 62921',20655,25197);
INSERT INTO "django_geo_db_zipcode" VALUES(28292,62922,-6,'Creal Springs, Illinois 62922',20656,25198);
INSERT INTO "django_geo_db_zipcode" VALUES(28293,62923,-6,'Cypress, Illinois 62923',20657,25199);
INSERT INTO "django_geo_db_zipcode" VALUES(28294,62924,-6,'De Soto, Illinois 62924',20658,25200);
INSERT INTO "django_geo_db_zipcode" VALUES(28295,62926,-6,'Dongola, Illinois 62926',20659,25201);
INSERT INTO "django_geo_db_zipcode" VALUES(28296,62927,-6,'Dowell, Illinois 62927',20660,25202);
INSERT INTO "django_geo_db_zipcode" VALUES(28297,62928,-6,'Eddyville, Illinois 62928',20661,25203);
INSERT INTO "django_geo_db_zipcode" VALUES(28298,62930,-6,'Eldorado, Illinois 62930',20662,25204);
INSERT INTO "django_geo_db_zipcode" VALUES(28299,62931,-6,'Elizabethtown, Illinois 62931',20663,25205);
INSERT INTO "django_geo_db_zipcode" VALUES(28300,62932,-6,'Elkville, Illinois 62932',20664,25206);
INSERT INTO "django_geo_db_zipcode" VALUES(28301,62933,-6,'Energy, Illinois 62933',20665,25207);
INSERT INTO "django_geo_db_zipcode" VALUES(28302,62934,-6,'Equality, Illinois 62934',20364,25208);
INSERT INTO "django_geo_db_zipcode" VALUES(28303,62935,-6,'Galatia, Illinois 62935',20666,25209);
INSERT INTO "django_geo_db_zipcode" VALUES(28304,62938,-6,'Golconda, Illinois 62938',20667,25210);
INSERT INTO "django_geo_db_zipcode" VALUES(28305,62939,-6,'Goreville, Illinois 62939',20668,25211);
INSERT INTO "django_geo_db_zipcode" VALUES(28306,62940,-6,'Gorham, Illinois 62940',20669,25212);
INSERT INTO "django_geo_db_zipcode" VALUES(28307,62941,-6,'Grand Chain, Illinois 62941',20670,25213);
INSERT INTO "django_geo_db_zipcode" VALUES(28308,62942,-6,'Grand Tower, Illinois 62942',20671,25214);
INSERT INTO "django_geo_db_zipcode" VALUES(28309,62943,-6,'Grantsburg, Illinois 62943',20672,25215);
INSERT INTO "django_geo_db_zipcode" VALUES(28310,62944,-6,'Hamletsburg, Illinois 62944',20673,25216);
INSERT INTO "django_geo_db_zipcode" VALUES(28311,62946,-6,'Harrisburg, Illinois 62946',20674,25217);
INSERT INTO "django_geo_db_zipcode" VALUES(28312,62947,-6,'Herod, Illinois 62947',20675,25218);
INSERT INTO "django_geo_db_zipcode" VALUES(28313,62948,-6,'Herrin, Illinois 62948',20507,25219);
INSERT INTO "django_geo_db_zipcode" VALUES(28314,62949,-6,'Hurst, Illinois 62949',20676,25220);
INSERT INTO "django_geo_db_zipcode" VALUES(28315,62950,-6,'Jacob, Illinois 62950',20677,25221);
INSERT INTO "django_geo_db_zipcode" VALUES(28316,62951,-6,'Johnston City, Illinois 62951',20678,25222);
INSERT INTO "django_geo_db_zipcode" VALUES(28317,62952,-6,'Jonesboro, Illinois 62952',20679,25223);
INSERT INTO "django_geo_db_zipcode" VALUES(28318,62953,-6,'Joppa, Illinois 62953',20680,25224);
INSERT INTO "django_geo_db_zipcode" VALUES(28319,62954,-6,'Junction, Illinois 62954',20681,25225);
INSERT INTO "django_geo_db_zipcode" VALUES(28320,62955,-6,'Karbers Ridge, Illinois 62955',20682,25226);
INSERT INTO "django_geo_db_zipcode" VALUES(28321,62956,-6,'Karnak, Illinois 62956',20683,25227);
INSERT INTO "django_geo_db_zipcode" VALUES(28322,62957,-6,'McClure, Illinois 62957',20684,25228);
INSERT INTO "django_geo_db_zipcode" VALUES(28323,62958,-6,'Makanda, Illinois 62958',20685,25229);
INSERT INTO "django_geo_db_zipcode" VALUES(28324,62959,-6,'Marion, Illinois 62959',20686,25230);
INSERT INTO "django_geo_db_zipcode" VALUES(28325,62960,-6,'Metropolis, Illinois 62960',20687,25231);
INSERT INTO "django_geo_db_zipcode" VALUES(28326,62961,-6,'Millcreek, Illinois 62961',20688,25232);
INSERT INTO "django_geo_db_zipcode" VALUES(28327,62962,-6,'Miller City, Illinois 62962',20689,25233);
INSERT INTO "django_geo_db_zipcode" VALUES(28328,62963,-6,'Mound City, Illinois 62963',20690,25234);
INSERT INTO "django_geo_db_zipcode" VALUES(28329,62964,-6,'Mounds, Illinois 62964',20691,25235);
INSERT INTO "django_geo_db_zipcode" VALUES(28330,62965,-6,'Muddy, Illinois 62965',20692,25236);
INSERT INTO "django_geo_db_zipcode" VALUES(28331,62966,-6,'Murphysboro, Illinois 62966',20693,25237);
INSERT INTO "django_geo_db_zipcode" VALUES(28332,62967,-6,'New Burnside, Illinois 62967',20694,25238);
INSERT INTO "django_geo_db_zipcode" VALUES(28333,62969,-6,'Olive Branch, Illinois 62969',20695,25239);
INSERT INTO "django_geo_db_zipcode" VALUES(28334,62970,-6,'Olmsted, Illinois 62970',20696,25240);
INSERT INTO "django_geo_db_zipcode" VALUES(28335,62971,-6,'Oraville, Illinois 62971',20697,25181);
INSERT INTO "django_geo_db_zipcode" VALUES(28336,62972,-6,'Ozark, Illinois 62972',20698,25241);
INSERT INTO "django_geo_db_zipcode" VALUES(28337,62973,-6,'Perks, Illinois 62973',20699,25242);
INSERT INTO "django_geo_db_zipcode" VALUES(28338,62974,-6,'Pittsburg, Illinois 62974',20700,25243);
INSERT INTO "django_geo_db_zipcode" VALUES(28339,62975,-6,'Pomona, Illinois 62975',20701,25244);
INSERT INTO "django_geo_db_zipcode" VALUES(28340,62976,-6,'Pulaski, Illinois 62976',20702,25245);
INSERT INTO "django_geo_db_zipcode" VALUES(28341,62977,-6,'Raleigh, Illinois 62977',20703,25246);
INSERT INTO "django_geo_db_zipcode" VALUES(28342,62979,-6,'Ridgway, Illinois 62979',20704,25247);
INSERT INTO "django_geo_db_zipcode" VALUES(28343,62982,-6,'Rosiclare, Illinois 62982',20705,25248);
INSERT INTO "django_geo_db_zipcode" VALUES(28344,62983,-6,'Royalton, Illinois 62983',20706,25249);
INSERT INTO "django_geo_db_zipcode" VALUES(28345,62984,-6,'Shawneetown, Illinois 62984',20707,25250);
INSERT INTO "django_geo_db_zipcode" VALUES(28346,62985,-6,'Simpson, Illinois 62985',20708,25251);
INSERT INTO "django_geo_db_zipcode" VALUES(28347,62987,-6,'Stonefort, Illinois 62987',20709,25252);
INSERT INTO "django_geo_db_zipcode" VALUES(28348,62988,-6,'Tamms, Illinois 62988',20710,25253);
INSERT INTO "django_geo_db_zipcode" VALUES(28349,62990,-6,'Thebes, Illinois 62990',20711,25254);
INSERT INTO "django_geo_db_zipcode" VALUES(28350,62991,-6,'Tunnel Hill, Illinois 62991',20712,25255);
INSERT INTO "django_geo_db_zipcode" VALUES(28351,62992,-6,'Ullin, Illinois 62992',20544,25256);
INSERT INTO "django_geo_db_zipcode" VALUES(28352,62993,-6,'Unity, Illinois 62993',20713,25257);
INSERT INTO "django_geo_db_zipcode" VALUES(28353,62994,-6,'Vergennes, Illinois 62994',20714,25258);
INSERT INTO "django_geo_db_zipcode" VALUES(28354,62995,-6,'Vienna, Illinois 62995',20715,25259);
INSERT INTO "django_geo_db_zipcode" VALUES(28355,62996,-6,'Villa Ridge, Illinois 62996',20716,25260);
INSERT INTO "django_geo_db_zipcode" VALUES(28356,62997,-6,'Willisville, Illinois 62997',20717,25261);
INSERT INTO "django_geo_db_zipcode" VALUES(28357,62998,-6,'Wolf Lake, Illinois 62998',20718,25262);
INSERT INTO "django_geo_db_zipcode" VALUES(28358,62999,-6,'Zeigler, Illinois 62999',20719,25263);
INSERT INTO "django_geo_db_zipcode" VALUES(28359,63001,-6,'Allenton, Missouri 63001',20720,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28360,63005,-6,'Chesterfield, Missouri 63005',20721,25265);
INSERT INTO "django_geo_db_zipcode" VALUES(28361,63006,-6,'Chesterfield, Missouri 63006',20721,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28362,63010,-6,'Arnold, Missouri 63010',20722,25266);
INSERT INTO "django_geo_db_zipcode" VALUES(28363,63011,-6,'Ballwin, Missouri 63011',20723,25267);
INSERT INTO "django_geo_db_zipcode" VALUES(28364,63012,-6,'Barnhart, Missouri 63012',20724,25268);
INSERT INTO "django_geo_db_zipcode" VALUES(28365,63013,-6,'Beaufort, Missouri 63013',20725,25269);
INSERT INTO "django_geo_db_zipcode" VALUES(28366,63014,-6,'Berger, Missouri 63014',20726,25270);
INSERT INTO "django_geo_db_zipcode" VALUES(28367,63015,-6,'Catawissa, Missouri 63015',20727,25271);
INSERT INTO "django_geo_db_zipcode" VALUES(28368,63016,-6,'Cedar Hill, Missouri 63016',20728,25272);
INSERT INTO "django_geo_db_zipcode" VALUES(28369,63017,-6,'Chesterfield, Missouri 63017',20721,25273);
INSERT INTO "django_geo_db_zipcode" VALUES(28370,63019,-6,'Crystal City, Missouri 63019',20729,25274);
INSERT INTO "django_geo_db_zipcode" VALUES(28371,63020,-6,'De Soto, Missouri 63020',20730,25275);
INSERT INTO "django_geo_db_zipcode" VALUES(28372,63021,-6,'Ballwin, Missouri 63021',20723,25276);
INSERT INTO "django_geo_db_zipcode" VALUES(28373,63022,-6,'Ballwin, Missouri 63022',20723,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28374,63023,-6,'Dittmer, Missouri 63023',20731,25277);
INSERT INTO "django_geo_db_zipcode" VALUES(28375,63024,-6,'Ballwin, Missouri 63024',20723,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28376,63025,-6,'Eureka, Missouri 63025',20732,25278);
INSERT INTO "django_geo_db_zipcode" VALUES(28377,63026,-6,'Fenton, Missouri 63026',20733,25279);
INSERT INTO "django_geo_db_zipcode" VALUES(28378,63028,-6,'Festus, Missouri 63028',20734,25280);
INSERT INTO "django_geo_db_zipcode" VALUES(28379,63030,-6,'Fletcher, Missouri 63030',20735,25281);
INSERT INTO "django_geo_db_zipcode" VALUES(28380,63031,-6,'Florissant, Missouri 63031',20736,25282);
INSERT INTO "django_geo_db_zipcode" VALUES(28381,63032,-6,'Florissant, Missouri 63032',20736,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28382,63033,-6,'Florissant, Missouri 63033',20736,25283);
INSERT INTO "django_geo_db_zipcode" VALUES(28383,63034,-6,'Florissant, Missouri 63034',20736,25284);
INSERT INTO "django_geo_db_zipcode" VALUES(28384,63036,-6,'French Village, Missouri 63036',20737,25285);
INSERT INTO "django_geo_db_zipcode" VALUES(28385,63037,-6,'Gerald, Missouri 63037',20738,25286);
INSERT INTO "django_geo_db_zipcode" VALUES(28386,63038,-6,'Glencoe, Missouri 63038',20739,25287);
INSERT INTO "django_geo_db_zipcode" VALUES(28387,63039,-6,'Gray Summit, Missouri 63039',20740,25288);
INSERT INTO "django_geo_db_zipcode" VALUES(28388,63040,-6,'Grover, Missouri 63040',20741,25289);
INSERT INTO "django_geo_db_zipcode" VALUES(28389,63041,-6,'Grubville, Missouri 63041',20742,25290);
INSERT INTO "django_geo_db_zipcode" VALUES(28390,63042,-6,'Hazelwood, Missouri 63042',20743,25291);
INSERT INTO "django_geo_db_zipcode" VALUES(28391,63043,-6,'Maryland Heights, Missouri 63043',20744,25292);
INSERT INTO "django_geo_db_zipcode" VALUES(28392,63044,-6,'Bridgeton, Missouri 63044',20745,25293);
INSERT INTO "django_geo_db_zipcode" VALUES(28393,63045,-6,'Earth City, Missouri 63045',20746,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28394,63047,-6,'Hematite, Missouri 63047',20747,25294);
INSERT INTO "django_geo_db_zipcode" VALUES(28395,63048,-6,'Herculaneum, Missouri 63048',20748,25295);
INSERT INTO "django_geo_db_zipcode" VALUES(28396,63049,-6,'High Ridge, Missouri 63049',20749,25296);
INSERT INTO "django_geo_db_zipcode" VALUES(28397,63050,-6,'Hillsboro, Missouri 63050',20750,25297);
INSERT INTO "django_geo_db_zipcode" VALUES(28398,63051,-6,'House Springs, Missouri 63051',20751,25298);
INSERT INTO "django_geo_db_zipcode" VALUES(28399,63052,-6,'Imperial, Missouri 63052',20752,25299);
INSERT INTO "django_geo_db_zipcode" VALUES(28400,63053,-6,'Kimmswick, Missouri 63053',20753,25300);
INSERT INTO "django_geo_db_zipcode" VALUES(28401,63055,-6,'Labadie, Missouri 63055',20754,25301);
INSERT INTO "django_geo_db_zipcode" VALUES(28402,63056,-6,'Leslie, Missouri 63056',20755,25302);
INSERT INTO "django_geo_db_zipcode" VALUES(28403,63057,-6,'Liguori, Missouri 63057',20756,25303);
INSERT INTO "django_geo_db_zipcode" VALUES(28404,63060,-6,'Lonedell, Missouri 63060',20757,25304);
INSERT INTO "django_geo_db_zipcode" VALUES(28405,63061,-6,'Luebbering, Missouri 63061',20758,25305);
INSERT INTO "django_geo_db_zipcode" VALUES(28406,63065,-6,'Mapaville, Missouri 63065',20759,25300);
INSERT INTO "django_geo_db_zipcode" VALUES(28407,63066,-6,'Morse Mill, Missouri 63066',20760,25306);
INSERT INTO "django_geo_db_zipcode" VALUES(28408,63068,-6,'New Haven, Missouri 63068',20761,25307);
INSERT INTO "django_geo_db_zipcode" VALUES(28409,63069,-6,'Pacific, Missouri 63069',20762,25308);
INSERT INTO "django_geo_db_zipcode" VALUES(28410,63070,-6,'Pevely, Missouri 63070',20763,25309);
INSERT INTO "django_geo_db_zipcode" VALUES(28411,63071,-6,'Richwoods, Missouri 63071',20764,25310);
INSERT INTO "django_geo_db_zipcode" VALUES(28412,63072,-6,'Robertsville, Missouri 63072',20765,25311);
INSERT INTO "django_geo_db_zipcode" VALUES(28413,63073,-6,'Saint Albans, Missouri 63073',20766,25312);
INSERT INTO "django_geo_db_zipcode" VALUES(28414,63074,-6,'Saint Ann, Missouri 63074',20767,25313);
INSERT INTO "django_geo_db_zipcode" VALUES(28415,63077,-6,'Saint Clair, Missouri 63077',20768,25314);
INSERT INTO "django_geo_db_zipcode" VALUES(28416,63079,-6,'Stanton, Missouri 63079',20769,25315);
INSERT INTO "django_geo_db_zipcode" VALUES(28417,63080,-6,'Sullivan, Missouri 63080',20770,25316);
INSERT INTO "django_geo_db_zipcode" VALUES(28418,63084,-6,'Union, Missouri 63084',20771,25317);
INSERT INTO "django_geo_db_zipcode" VALUES(28419,63087,-6,'Valles Mines, Missouri 63087',20772,25318);
INSERT INTO "django_geo_db_zipcode" VALUES(28420,63088,-6,'Valley Park, Missouri 63088',20773,25319);
INSERT INTO "django_geo_db_zipcode" VALUES(28421,63089,-6,'Villa Ridge, Missouri 63089',20774,25320);
INSERT INTO "django_geo_db_zipcode" VALUES(28422,63090,-6,'Washington, Missouri 63090',20775,25321);
INSERT INTO "django_geo_db_zipcode" VALUES(28423,63091,-6,'Rosebud, Missouri 63091',20776,25322);
INSERT INTO "django_geo_db_zipcode" VALUES(28424,63099,-6,'Fenton, Missouri 63099',20733,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28425,63101,-6,'Saint Louis, Missouri 63101',20777,25323);
INSERT INTO "django_geo_db_zipcode" VALUES(28426,63102,-6,'Saint Louis, Missouri 63102',20777,25324);
INSERT INTO "django_geo_db_zipcode" VALUES(28427,63103,-6,'Saint Louis, Missouri 63103',20777,25325);
INSERT INTO "django_geo_db_zipcode" VALUES(28428,63104,-6,'Saint Louis, Missouri 63104',20777,25326);
INSERT INTO "django_geo_db_zipcode" VALUES(28429,63105,-6,'Saint Louis, Missouri 63105',20777,25327);
INSERT INTO "django_geo_db_zipcode" VALUES(28430,63106,-6,'Saint Louis, Missouri 63106',20777,25328);
INSERT INTO "django_geo_db_zipcode" VALUES(28431,63107,-6,'Saint Louis, Missouri 63107',20777,25329);
INSERT INTO "django_geo_db_zipcode" VALUES(28432,63108,-6,'Saint Louis, Missouri 63108',20777,25330);
INSERT INTO "django_geo_db_zipcode" VALUES(28433,63109,-6,'Saint Louis, Missouri 63109',20777,25331);
INSERT INTO "django_geo_db_zipcode" VALUES(28434,63110,-6,'Saint Louis, Missouri 63110',20777,25332);
INSERT INTO "django_geo_db_zipcode" VALUES(28435,63111,-6,'Saint Louis, Missouri 63111',20777,25333);
INSERT INTO "django_geo_db_zipcode" VALUES(28436,63112,-6,'Saint Louis, Missouri 63112',20777,25334);
INSERT INTO "django_geo_db_zipcode" VALUES(28437,63113,-6,'Saint Louis, Missouri 63113',20777,25335);
INSERT INTO "django_geo_db_zipcode" VALUES(28438,63114,-6,'Saint Louis, Missouri 63114',20777,25336);
INSERT INTO "django_geo_db_zipcode" VALUES(28439,63115,-6,'Saint Louis, Missouri 63115',20777,25337);
INSERT INTO "django_geo_db_zipcode" VALUES(28440,63116,-6,'Saint Louis, Missouri 63116',20777,25338);
INSERT INTO "django_geo_db_zipcode" VALUES(28441,63117,-6,'Saint Louis, Missouri 63117',20777,25339);
INSERT INTO "django_geo_db_zipcode" VALUES(28442,63118,-6,'Saint Louis, Missouri 63118',20777,25340);
INSERT INTO "django_geo_db_zipcode" VALUES(28443,63119,-6,'Saint Louis, Missouri 63119',20777,25341);
INSERT INTO "django_geo_db_zipcode" VALUES(28444,63120,-6,'Saint Louis, Missouri 63120',20777,25342);
INSERT INTO "django_geo_db_zipcode" VALUES(28445,63121,-6,'Saint Louis, Missouri 63121',20777,25343);
INSERT INTO "django_geo_db_zipcode" VALUES(28446,63122,-6,'Saint Louis, Missouri 63122',20777,25344);
INSERT INTO "django_geo_db_zipcode" VALUES(28447,63123,-6,'Saint Louis, Missouri 63123',20777,25345);
INSERT INTO "django_geo_db_zipcode" VALUES(28448,63124,-6,'Saint Louis, Missouri 63124',20777,25346);
INSERT INTO "django_geo_db_zipcode" VALUES(28449,63125,-6,'Saint Louis, Missouri 63125',20777,25347);
INSERT INTO "django_geo_db_zipcode" VALUES(28450,63126,-6,'Saint Louis, Missouri 63126',20777,25348);
INSERT INTO "django_geo_db_zipcode" VALUES(28451,63127,-6,'Saint Louis, Missouri 63127',20777,25349);
INSERT INTO "django_geo_db_zipcode" VALUES(28452,63128,-6,'Saint Louis, Missouri 63128',20777,25350);
INSERT INTO "django_geo_db_zipcode" VALUES(28453,63129,-6,'Saint Louis, Missouri 63129',20777,25351);
INSERT INTO "django_geo_db_zipcode" VALUES(28454,63130,-6,'Saint Louis, Missouri 63130',20777,25352);
INSERT INTO "django_geo_db_zipcode" VALUES(28455,63131,-6,'Saint Louis, Missouri 63131',20777,25353);
INSERT INTO "django_geo_db_zipcode" VALUES(28456,63132,-6,'Saint Louis, Missouri 63132',20777,25354);
INSERT INTO "django_geo_db_zipcode" VALUES(28457,63133,-6,'Saint Louis, Missouri 63133',20777,25355);
INSERT INTO "django_geo_db_zipcode" VALUES(28458,63134,-6,'Saint Louis, Missouri 63134',20777,25356);
INSERT INTO "django_geo_db_zipcode" VALUES(28459,63135,-6,'Saint Louis, Missouri 63135',20777,25357);
INSERT INTO "django_geo_db_zipcode" VALUES(28460,63136,-6,'Saint Louis, Missouri 63136',20777,25358);
INSERT INTO "django_geo_db_zipcode" VALUES(28461,63137,-6,'Saint Louis, Missouri 63137',20777,25359);
INSERT INTO "django_geo_db_zipcode" VALUES(28462,63138,-6,'Saint Louis, Missouri 63138',20777,25360);
INSERT INTO "django_geo_db_zipcode" VALUES(28463,63139,-6,'Saint Louis, Missouri 63139',20777,25361);
INSERT INTO "django_geo_db_zipcode" VALUES(28464,63140,-6,'Saint Louis, Missouri 63140',20777,25362);
INSERT INTO "django_geo_db_zipcode" VALUES(28465,63141,-6,'Saint Louis, Missouri 63141',20777,25363);
INSERT INTO "django_geo_db_zipcode" VALUES(28466,63143,-6,'Saint Louis, Missouri 63143',20777,25364);
INSERT INTO "django_geo_db_zipcode" VALUES(28467,63144,-6,'Saint Louis, Missouri 63144',20777,25365);
INSERT INTO "django_geo_db_zipcode" VALUES(28468,63145,-6,'Saint Louis, Missouri 63145',20777,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28469,63146,-6,'Saint Louis, Missouri 63146',20777,25366);
INSERT INTO "django_geo_db_zipcode" VALUES(28470,63147,-6,'Saint Louis, Missouri 63147',20777,25367);
INSERT INTO "django_geo_db_zipcode" VALUES(28471,63150,-6,'Saint Louis, Missouri 63150',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28472,63151,-6,'Saint Louis, Missouri 63151',20777,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28473,63153,-6,'Saint Louis, Missouri 63153',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28474,63155,-6,'Saint Louis, Missouri 63155',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28475,63156,-6,'Saint Louis, Missouri 63156',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28476,63157,-6,'Saint Louis, Missouri 63157',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28477,63158,-6,'Saint Louis, Missouri 63158',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28478,63160,-6,'Saint Louis, Missouri 63160',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28479,63163,-6,'Saint Louis, Missouri 63163',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28480,63164,-6,'Saint Louis, Missouri 63164',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28481,63166,-6,'Saint Louis, Missouri 63166',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28482,63167,-6,'Saint Louis, Missouri 63167',20777,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28483,63169,-6,'Saint Louis, Missouri 63169',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28484,63171,-6,'Saint Louis, Missouri 63171',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28485,63177,-6,'Saint Louis, Missouri 63177',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28486,63178,-6,'Saint Louis, Missouri 63178',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28487,63179,-6,'Saint Louis, Missouri 63179',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28488,63180,-6,'Saint Louis, Missouri 63180',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28489,63182,-6,'Saint Louis, Missouri 63182',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28490,63188,-6,'Saint Louis, Missouri 63188',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28491,63195,-6,'Saint Louis, Missouri 63195',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28492,63196,-6,'Saint Louis, Missouri 63196',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28493,63197,-6,'Saint Louis, Missouri 63197',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28494,63198,-6,'Saint Louis, Missouri 63198',20777,25264);
INSERT INTO "django_geo_db_zipcode" VALUES(28495,63199,-6,'Saint Louis, Missouri 63199',20777,25368);
INSERT INTO "django_geo_db_zipcode" VALUES(28496,63301,-6,'Saint Charles, Missouri 63301',20778,25369);
INSERT INTO "django_geo_db_zipcode" VALUES(28497,63302,-6,'Saint Charles, Missouri 63302',20778,25370);
INSERT INTO "django_geo_db_zipcode" VALUES(28498,63303,-6,'Saint Charles, Missouri 63303',20778,25371);
INSERT INTO "django_geo_db_zipcode" VALUES(28499,63304,-6,'Saint Charles, Missouri 63304',20778,25372);
INSERT INTO "django_geo_db_zipcode" VALUES(28500,63330,-6,'Annada, Missouri 63330',20779,25373);
INSERT INTO "django_geo_db_zipcode" VALUES(28501,63332,-6,'Augusta, Missouri 63332',20780,25374);
INSERT INTO "django_geo_db_zipcode" VALUES(28502,63333,-6,'Bellflower, Missouri 63333',20781,25375);
INSERT INTO "django_geo_db_zipcode" VALUES(28503,63334,-6,'Bowling Green, Missouri 63334',20782,25376);
INSERT INTO "django_geo_db_zipcode" VALUES(28504,63336,-6,'Clarksville, Missouri 63336',20783,25377);
INSERT INTO "django_geo_db_zipcode" VALUES(28505,63338,-6,'Cottleville, Missouri 63338',20784,25378);
INSERT INTO "django_geo_db_zipcode" VALUES(28506,63339,-6,'Curryville, Missouri 63339',20785,25379);
INSERT INTO "django_geo_db_zipcode" VALUES(28507,63341,-6,'Defiance, Missouri 63341',20786,25380);
INSERT INTO "django_geo_db_zipcode" VALUES(28508,63342,-6,'Dutzow, Missouri 63342',20787,25381);
INSERT INTO "django_geo_db_zipcode" VALUES(28509,63343,-6,'Elsberry, Missouri 63343',20788,25382);
INSERT INTO "django_geo_db_zipcode" VALUES(28510,63344,-6,'Eolia, Missouri 63344',20789,25383);
INSERT INTO "django_geo_db_zipcode" VALUES(28511,63345,-6,'Farber, Missouri 63345',20790,25384);
INSERT INTO "django_geo_db_zipcode" VALUES(28512,63346,-6,'Flinthill, Missouri 63346',20791,25378);
INSERT INTO "django_geo_db_zipcode" VALUES(28513,63347,-6,'Foley, Missouri 63347',20792,25385);
INSERT INTO "django_geo_db_zipcode" VALUES(28514,63348,-6,'Foristell, Missouri 63348',20793,25386);
INSERT INTO "django_geo_db_zipcode" VALUES(28515,63349,-6,'Hawk Point, Missouri 63349',20794,25387);
INSERT INTO "django_geo_db_zipcode" VALUES(28516,63350,-6,'High Hill, Missouri 63350',20795,25388);
INSERT INTO "django_geo_db_zipcode" VALUES(28517,63351,-6,'Jonesburg, Missouri 63351',20796,25389);
INSERT INTO "django_geo_db_zipcode" VALUES(28518,63352,-6,'Laddonia, Missouri 63352',20797,25390);
INSERT INTO "django_geo_db_zipcode" VALUES(28519,63353,-6,'Louisiana, Missouri 63353',20798,25391);
INSERT INTO "django_geo_db_zipcode" VALUES(28520,63357,-6,'Marthasville, Missouri 63357',20799,25392);
INSERT INTO "django_geo_db_zipcode" VALUES(28521,63359,-6,'Middletown, Missouri 63359',20800,25393);
INSERT INTO "django_geo_db_zipcode" VALUES(28522,63361,-6,'Montgomery City, Missouri 63361',20801,25394);
INSERT INTO "django_geo_db_zipcode" VALUES(28523,63362,-6,'Moscow Mills, Missouri 63362',20802,25395);
INSERT INTO "django_geo_db_zipcode" VALUES(28524,63363,-6,'New Florence, Missouri 63363',20803,25396);
INSERT INTO "django_geo_db_zipcode" VALUES(28525,63365,-6,'New Melle, Missouri 63365',20804,25397);
INSERT INTO "django_geo_db_zipcode" VALUES(28526,63366,-6,'O Fallon, Missouri 63366',20805,25398);
INSERT INTO "django_geo_db_zipcode" VALUES(28527,63367,-6,'Lake Saint Louis, Missouri 63367',20806,25399);
INSERT INTO "django_geo_db_zipcode" VALUES(28528,63369,-6,'Old Monroe, Missouri 63369',20807,25400);
INSERT INTO "django_geo_db_zipcode" VALUES(28529,63370,-6,'Olney, Missouri 63370',20808,25401);
INSERT INTO "django_geo_db_zipcode" VALUES(28530,63371,-6,'Paynesville, Missouri 63371',20809,25402);
INSERT INTO "django_geo_db_zipcode" VALUES(28531,63373,-6,'Portage Des Sioux, Missouri 63373',20810,25403);
INSERT INTO "django_geo_db_zipcode" VALUES(28532,63375,-6,'Perryville, Missouri 63375',20811,25404);
INSERT INTO "django_geo_db_zipcode" VALUES(28533,63376,-6,'Saint Peters, Missouri 63376',20812,25405);
INSERT INTO "django_geo_db_zipcode" VALUES(28534,63377,-6,'Silex, Missouri 63377',20813,25406);
INSERT INTO "django_geo_db_zipcode" VALUES(28535,63378,-6,'Treloar, Missouri 63378',20814,25407);
INSERT INTO "django_geo_db_zipcode" VALUES(28536,63379,-6,'Troy, Missouri 63379',20815,25408);
INSERT INTO "django_geo_db_zipcode" VALUES(28537,63381,-6,'Truxton, Missouri 63381',20816,25409);
INSERT INTO "django_geo_db_zipcode" VALUES(28538,63382,-6,'Vandalia, Missouri 63382',20817,25410);
INSERT INTO "django_geo_db_zipcode" VALUES(28539,63383,-6,'Warrenton, Missouri 63383',20818,25411);
INSERT INTO "django_geo_db_zipcode" VALUES(28540,63384,-6,'Wellsville, Missouri 63384',20819,25412);
INSERT INTO "django_geo_db_zipcode" VALUES(28541,63385,-6,'Wentzville, Missouri 63385',20820,25413);
INSERT INTO "django_geo_db_zipcode" VALUES(28542,63386,-6,'West Alton, Missouri 63386',20821,25414);
INSERT INTO "django_geo_db_zipcode" VALUES(28543,63387,-6,'Whiteside, Missouri 63387',20822,25415);
INSERT INTO "django_geo_db_zipcode" VALUES(28544,63388,-6,'Williamsburg, Missouri 63388',20823,25416);
INSERT INTO "django_geo_db_zipcode" VALUES(28545,63389,-6,'Winfield, Missouri 63389',20824,25417);
INSERT INTO "django_geo_db_zipcode" VALUES(28546,63390,-6,'Wright City, Missouri 63390',20825,25418);
INSERT INTO "django_geo_db_zipcode" VALUES(28547,63401,-6,'Hannibal, Missouri 63401',20826,25419);
INSERT INTO "django_geo_db_zipcode" VALUES(28548,63430,-6,'Alexandria, Missouri 63430',20827,25420);
INSERT INTO "django_geo_db_zipcode" VALUES(28549,63431,-6,'Anabel, Missouri 63431',20828,25421);
INSERT INTO "django_geo_db_zipcode" VALUES(28550,63432,-6,'Arbela, Missouri 63432',20829,25422);
INSERT INTO "django_geo_db_zipcode" VALUES(28551,63433,-6,'Ashburn, Missouri 63433',20830,25423);
INSERT INTO "django_geo_db_zipcode" VALUES(28552,63434,-6,'Bethel, Missouri 63434',20831,25424);
INSERT INTO "django_geo_db_zipcode" VALUES(28553,63435,-6,'Canton, Missouri 63435',20832,25425);
INSERT INTO "django_geo_db_zipcode" VALUES(28554,63436,-6,'Center, Missouri 63436',20833,25426);
INSERT INTO "django_geo_db_zipcode" VALUES(28555,63437,-6,'Clarence, Missouri 63437',20834,25427);
INSERT INTO "django_geo_db_zipcode" VALUES(28556,63438,-6,'Durham, Missouri 63438',20835,25428);
INSERT INTO "django_geo_db_zipcode" VALUES(28557,63439,-6,'Emden, Missouri 63439',20836,25429);
INSERT INTO "django_geo_db_zipcode" VALUES(28558,63440,-6,'Ewing, Missouri 63440',20837,25430);
INSERT INTO "django_geo_db_zipcode" VALUES(28559,63441,-6,'Frankford, Missouri 63441',20838,25431);
INSERT INTO "django_geo_db_zipcode" VALUES(28560,63442,-6,'Granger, Missouri 63442',20839,25432);
INSERT INTO "django_geo_db_zipcode" VALUES(28561,63443,-6,'Hunnewell, Missouri 63443',20840,25433);
INSERT INTO "django_geo_db_zipcode" VALUES(28562,63445,-6,'Kahoka, Missouri 63445',20841,25434);
INSERT INTO "django_geo_db_zipcode" VALUES(28563,63446,-6,'Knox City, Missouri 63446',20842,25435);
INSERT INTO "django_geo_db_zipcode" VALUES(28564,63447,-6,'La Belle, Missouri 63447',20843,25436);
INSERT INTO "django_geo_db_zipcode" VALUES(28565,63448,-6,'La Grange, Missouri 63448',20844,25437);
INSERT INTO "django_geo_db_zipcode" VALUES(28566,63450,-6,'Lentner, Missouri 63450',20845,25438);
INSERT INTO "django_geo_db_zipcode" VALUES(28567,63451,-6,'Leonard, Missouri 63451',20846,25439);
INSERT INTO "django_geo_db_zipcode" VALUES(28568,63452,-6,'Lewistown, Missouri 63452',20847,25440);
INSERT INTO "django_geo_db_zipcode" VALUES(28569,63453,-6,'Luray, Missouri 63453',20848,25441);
INSERT INTO "django_geo_db_zipcode" VALUES(28570,63454,-6,'Maywood, Missouri 63454',20849,25442);
INSERT INTO "django_geo_db_zipcode" VALUES(28571,63456,-6,'Monroe City, Missouri 63456',20850,25443);
INSERT INTO "django_geo_db_zipcode" VALUES(28572,63457,-6,'Monticello, Missouri 63457',20851,25444);
INSERT INTO "django_geo_db_zipcode" VALUES(28573,63458,-6,'Newark, Missouri 63458',20852,25445);
INSERT INTO "django_geo_db_zipcode" VALUES(28574,63459,-6,'New London, Missouri 63459',20853,25446);
INSERT INTO "django_geo_db_zipcode" VALUES(28575,63460,-6,'Novelty, Missouri 63460',20854,25447);
INSERT INTO "django_geo_db_zipcode" VALUES(28576,63461,-6,'Palmyra, Missouri 63461',20855,25448);
INSERT INTO "django_geo_db_zipcode" VALUES(28577,63462,-6,'Perry, Missouri 63462',20856,25449);
INSERT INTO "django_geo_db_zipcode" VALUES(28578,63463,-6,'Philadelphia, Missouri 63463',20857,25450);
INSERT INTO "django_geo_db_zipcode" VALUES(28579,63464,-6,'Plevna, Missouri 63464',20858,25451);
INSERT INTO "django_geo_db_zipcode" VALUES(28580,63465,-6,'Revere, Missouri 63465',20859,25452);
INSERT INTO "django_geo_db_zipcode" VALUES(28581,63466,-6,'Saint Patrick, Missouri 63466',20860,25453);
INSERT INTO "django_geo_db_zipcode" VALUES(28582,63467,-6,'Saverton, Missouri 63467',20861,25454);
INSERT INTO "django_geo_db_zipcode" VALUES(28583,63468,-6,'Shelbina, Missouri 63468',20862,25455);
INSERT INTO "django_geo_db_zipcode" VALUES(28584,63469,-6,'Shelbyville, Missouri 63469',20863,25456);
INSERT INTO "django_geo_db_zipcode" VALUES(28585,63471,-6,'Taylor, Missouri 63471',20864,25457);
INSERT INTO "django_geo_db_zipcode" VALUES(28586,63472,-6,'Wayland, Missouri 63472',20865,25458);
INSERT INTO "django_geo_db_zipcode" VALUES(28587,63473,-6,'Williamstown, Missouri 63473',20866,25459);
INSERT INTO "django_geo_db_zipcode" VALUES(28588,63474,-6,'Wyaconda, Missouri 63474',20867,25460);
INSERT INTO "django_geo_db_zipcode" VALUES(28589,63477,-6,'La Belle, Missouri 63477',20843,25461);
INSERT INTO "django_geo_db_zipcode" VALUES(28590,63501,-6,'Kirksville, Missouri 63501',20868,25462);
INSERT INTO "django_geo_db_zipcode" VALUES(28591,63530,-6,'Atlanta, Missouri 63530',20869,25463);
INSERT INTO "django_geo_db_zipcode" VALUES(28592,63531,-6,'Baring, Missouri 63531',20870,25464);
INSERT INTO "django_geo_db_zipcode" VALUES(28593,63532,-6,'Bevier, Missouri 63532',20871,25465);
INSERT INTO "django_geo_db_zipcode" VALUES(28594,63533,-6,'Brashear, Missouri 63533',20872,25466);
INSERT INTO "django_geo_db_zipcode" VALUES(28595,63534,-6,'Callao, Missouri 63534',20873,25467);
INSERT INTO "django_geo_db_zipcode" VALUES(28596,63535,-6,'Coatsville, Missouri 63535',20874,25468);
INSERT INTO "django_geo_db_zipcode" VALUES(28597,63536,-6,'Downing, Missouri 63536',20875,25469);
INSERT INTO "django_geo_db_zipcode" VALUES(28598,63537,-6,'Edina, Missouri 63537',20876,25470);
INSERT INTO "django_geo_db_zipcode" VALUES(28599,63538,-6,'Elmer, Missouri 63538',20877,25471);
INSERT INTO "django_geo_db_zipcode" VALUES(28600,63539,-6,'Ethel, Missouri 63539',20878,25472);
INSERT INTO "django_geo_db_zipcode" VALUES(28601,63540,-6,'Gibbs, Missouri 63540',20879,25473);
INSERT INTO "django_geo_db_zipcode" VALUES(28602,63541,-6,'Glenwood, Missouri 63541',20880,25474);
INSERT INTO "django_geo_db_zipcode" VALUES(28603,63543,-6,'Gorin, Missouri 63543',20881,25475);
INSERT INTO "django_geo_db_zipcode" VALUES(28604,63544,-6,'Green Castle, Missouri 63544',20882,25476);
INSERT INTO "django_geo_db_zipcode" VALUES(28605,63545,-6,'Green City, Missouri 63545',20883,25477);
INSERT INTO "django_geo_db_zipcode" VALUES(28606,63546,-6,'Greentop, Missouri 63546',20884,25478);
INSERT INTO "django_geo_db_zipcode" VALUES(28607,63547,-6,'Hurdland, Missouri 63547',20885,25479);
INSERT INTO "django_geo_db_zipcode" VALUES(28608,63548,-6,'Lancaster, Missouri 63548',20886,25480);
INSERT INTO "django_geo_db_zipcode" VALUES(28609,63549,-6,'La Plata, Missouri 63549',20887,25481);
INSERT INTO "django_geo_db_zipcode" VALUES(28610,63551,-6,'Livonia, Missouri 63551',20888,25482);
INSERT INTO "django_geo_db_zipcode" VALUES(28611,63552,-6,'Macon, Missouri 63552',20889,25483);
INSERT INTO "django_geo_db_zipcode" VALUES(28612,63555,-6,'Memphis, Missouri 63555',20890,25484);
INSERT INTO "django_geo_db_zipcode" VALUES(28613,63556,-6,'Milan, Missouri 63556',20891,25485);
INSERT INTO "django_geo_db_zipcode" VALUES(28614,63557,-6,'New Boston, Missouri 63557',20892,25486);
INSERT INTO "django_geo_db_zipcode" VALUES(28615,63558,-6,'New Cambria, Missouri 63558',20893,25487);
INSERT INTO "django_geo_db_zipcode" VALUES(28616,63559,-6,'Novinger, Missouri 63559',20894,25488);
INSERT INTO "django_geo_db_zipcode" VALUES(28617,63560,-6,'Pollock, Missouri 63560',20895,25489);
INSERT INTO "django_geo_db_zipcode" VALUES(28618,63561,-6,'Queen City, Missouri 63561',20896,25490);
INSERT INTO "django_geo_db_zipcode" VALUES(28619,63563,-6,'Rutledge, Missouri 63563',20897,25491);
INSERT INTO "django_geo_db_zipcode" VALUES(28620,63565,-6,'Unionville, Missouri 63565',20898,25492);
INSERT INTO "django_geo_db_zipcode" VALUES(28621,63566,-6,'Winigan, Missouri 63566',20899,25493);
INSERT INTO "django_geo_db_zipcode" VALUES(28622,63567,-6,'Worthington, Missouri 63567',20900,25494);
INSERT INTO "django_geo_db_zipcode" VALUES(28623,63588,-6,'Clay, Missouri 63588',20901,25495);
INSERT INTO "django_geo_db_zipcode" VALUES(28624,63601,-6,'Park Hills, Missouri 63601',20902,25496);
INSERT INTO "django_geo_db_zipcode" VALUES(28625,63620,-6,'Annapolis, Missouri 63620',20903,25497);
INSERT INTO "django_geo_db_zipcode" VALUES(28626,63621,-6,'Arcadia, Missouri 63621',20904,25498);
INSERT INTO "django_geo_db_zipcode" VALUES(28627,63622,-6,'Belgrade, Missouri 63622',20905,25499);
INSERT INTO "django_geo_db_zipcode" VALUES(28628,63623,-6,'Belleview, Missouri 63623',20906,25500);
INSERT INTO "django_geo_db_zipcode" VALUES(28629,63624,-6,'Bismarck, Missouri 63624',20907,25501);
INSERT INTO "django_geo_db_zipcode" VALUES(28630,63625,-6,'Black, Missouri 63625',20908,25502);
INSERT INTO "django_geo_db_zipcode" VALUES(28631,63626,-6,'Blackwell, Missouri 63626',20909,25503);
INSERT INTO "django_geo_db_zipcode" VALUES(28632,63627,-6,'Bloomsdale, Missouri 63627',20910,25504);
INSERT INTO "django_geo_db_zipcode" VALUES(28633,63628,-6,'Bonne Terre, Missouri 63628',20911,25505);
INSERT INTO "django_geo_db_zipcode" VALUES(28634,63629,-6,'Bunker, Missouri 63629',20912,25506);
INSERT INTO "django_geo_db_zipcode" VALUES(28635,63630,-6,'Cadet, Missouri 63630',20913,25507);
INSERT INTO "django_geo_db_zipcode" VALUES(28636,63631,-6,'Caledonia, Missouri 63631',20914,25508);
INSERT INTO "django_geo_db_zipcode" VALUES(28637,63632,-6,'Cascade, Missouri 63632',20915,25509);
INSERT INTO "django_geo_db_zipcode" VALUES(28638,63633,-6,'Centerville, Missouri 63633',20916,25510);
INSERT INTO "django_geo_db_zipcode" VALUES(28639,63636,-6,'Des Arc, Missouri 63636',20917,25511);
INSERT INTO "django_geo_db_zipcode" VALUES(28640,63637,-6,'Doe Run, Missouri 63637',20918,25512);
INSERT INTO "django_geo_db_zipcode" VALUES(28641,63638,-6,'Ellington, Missouri 63638',20919,25513);
INSERT INTO "django_geo_db_zipcode" VALUES(28642,63640,-6,'Farmington, Missouri 63640',20920,25514);
INSERT INTO "django_geo_db_zipcode" VALUES(28643,63645,-6,'Fredericktown, Missouri 63645',20921,25515);
INSERT INTO "django_geo_db_zipcode" VALUES(28644,63646,-6,'Glover, Missouri 63646',20922,25516);
INSERT INTO "django_geo_db_zipcode" VALUES(28645,63648,-6,'Irondale, Missouri 63648',20923,25517);
INSERT INTO "django_geo_db_zipcode" VALUES(28646,63650,-6,'Ironton, Missouri 63650',20924,25518);
INSERT INTO "django_geo_db_zipcode" VALUES(28647,63651,-6,'Knob Lick, Missouri 63651',20925,25519);
INSERT INTO "django_geo_db_zipcode" VALUES(28648,63653,-6,'Leadwood, Missouri 63653',20926,25520);
INSERT INTO "django_geo_db_zipcode" VALUES(28649,63654,-6,'Lesterville, Missouri 63654',20927,25521);
INSERT INTO "django_geo_db_zipcode" VALUES(28650,63655,-6,'Marquand, Missouri 63655',20928,25522);
INSERT INTO "django_geo_db_zipcode" VALUES(28651,63656,-6,'Middle Brook, Missouri 63656',20929,25523);
INSERT INTO "django_geo_db_zipcode" VALUES(28652,63660,-6,'Mineral Point, Missouri 63660',20930,25524);
INSERT INTO "django_geo_db_zipcode" VALUES(28653,63661,-6,'New Offenburg, Missouri 63661',20931,25525);
INSERT INTO "django_geo_db_zipcode" VALUES(28654,63662,-6,'Patton, Missouri 63662',20932,25526);
INSERT INTO "django_geo_db_zipcode" VALUES(28655,63663,-6,'Pilot Knob, Missouri 63663',20933,25527);
INSERT INTO "django_geo_db_zipcode" VALUES(28656,63664,-6,'Potosi, Missouri 63664',20934,25528);
INSERT INTO "django_geo_db_zipcode" VALUES(28657,63665,-6,'Redford, Missouri 63665',20935,25529);
INSERT INTO "django_geo_db_zipcode" VALUES(28658,63666,-6,'Reynolds, Missouri 63666',20936,25530);
INSERT INTO "django_geo_db_zipcode" VALUES(28659,63670,-6,'Sainte Genevieve, Missouri 63670',20937,25531);
INSERT INTO "django_geo_db_zipcode" VALUES(28660,63673,-6,'Saint Mary, Missouri 63673',20938,25532);
INSERT INTO "django_geo_db_zipcode" VALUES(28661,63674,-6,'Tiff, Missouri 63674',20939,25533);
INSERT INTO "django_geo_db_zipcode" VALUES(28662,63675,-6,'Vulcan, Missouri 63675',20940,25534);
INSERT INTO "django_geo_db_zipcode" VALUES(28663,63701,-6,'Cape Girardeau, Missouri 63701',20941,25535);
INSERT INTO "django_geo_db_zipcode" VALUES(28664,63702,-6,'Cape Girardeau, Missouri 63702',20941,25536);
INSERT INTO "django_geo_db_zipcode" VALUES(28665,63703,-6,'Cape Girardeau, Missouri 63703',20941,25537);
INSERT INTO "django_geo_db_zipcode" VALUES(28666,63705,-6,'Cape Girardeau, Missouri 63705',20941,25538);
INSERT INTO "django_geo_db_zipcode" VALUES(28667,63730,-6,'Advance, Missouri 63730',20942,25539);
INSERT INTO "django_geo_db_zipcode" VALUES(28668,63732,-6,'Altenburg, Missouri 63732',20943,25540);
INSERT INTO "django_geo_db_zipcode" VALUES(28669,63735,-6,'Bell City, Missouri 63735',20944,25541);
INSERT INTO "django_geo_db_zipcode" VALUES(28670,63736,-6,'Benton, Missouri 63736',20945,25542);
INSERT INTO "django_geo_db_zipcode" VALUES(28671,63737,-6,'Brazeau, Missouri 63737',20946,25543);
INSERT INTO "django_geo_db_zipcode" VALUES(28672,63738,-6,'Brownwood, Missouri 63738',20947,25544);
INSERT INTO "django_geo_db_zipcode" VALUES(28673,63739,-6,'Burfordville, Missouri 63739',20948,25545);
INSERT INTO "django_geo_db_zipcode" VALUES(28674,63740,-6,'Chaffee, Missouri 63740',20949,25546);
INSERT INTO "django_geo_db_zipcode" VALUES(28675,63742,-6,'Commerce, Missouri 63742',20950,25547);
INSERT INTO "django_geo_db_zipcode" VALUES(28676,63743,-6,'Daisy, Missouri 63743',20951,25548);
INSERT INTO "django_geo_db_zipcode" VALUES(28677,63744,-6,'Delta, Missouri 63744',20952,25549);
INSERT INTO "django_geo_db_zipcode" VALUES(28678,63745,-6,'Dutchtown, Missouri 63745',20953,25550);
INSERT INTO "django_geo_db_zipcode" VALUES(28679,63746,-6,'Farrar, Missouri 63746',20954,25551);
INSERT INTO "django_geo_db_zipcode" VALUES(28680,63747,-6,'Friedheim, Missouri 63747',20955,25552);
INSERT INTO "django_geo_db_zipcode" VALUES(28681,63748,-6,'Frohna, Missouri 63748',20956,25553);
INSERT INTO "django_geo_db_zipcode" VALUES(28682,63750,-6,'Gipsy, Missouri 63750',20957,25554);
INSERT INTO "django_geo_db_zipcode" VALUES(28683,63751,-6,'Glenallen, Missouri 63751',20958,25555);
INSERT INTO "django_geo_db_zipcode" VALUES(28684,63752,-6,'Gordonville, Missouri 63752',20959,25556);
INSERT INTO "django_geo_db_zipcode" VALUES(28685,63753,-6,'Grassy, Missouri 63753',20960,25557);
INSERT INTO "django_geo_db_zipcode" VALUES(28686,63755,-6,'Jackson, Missouri 63755',20961,25558);
INSERT INTO "django_geo_db_zipcode" VALUES(28687,63758,-6,'Kelso, Missouri 63758',20962,25559);
INSERT INTO "django_geo_db_zipcode" VALUES(28688,63760,-6,'Leopold, Missouri 63760',20963,25560);
INSERT INTO "django_geo_db_zipcode" VALUES(28689,63763,-6,'McGee, Missouri 63763',20964,25561);
INSERT INTO "django_geo_db_zipcode" VALUES(28690,63764,-6,'Marble Hill, Missouri 63764',20965,25562);
INSERT INTO "django_geo_db_zipcode" VALUES(28691,63766,-6,'Millersville, Missouri 63766',20966,25563);
INSERT INTO "django_geo_db_zipcode" VALUES(28692,63767,-6,'Morley, Missouri 63767',20967,25564);
INSERT INTO "django_geo_db_zipcode" VALUES(28693,63769,-6,'Oak Ridge, Missouri 63769',20968,25565);
INSERT INTO "django_geo_db_zipcode" VALUES(28694,63770,-6,'Old Appleton, Missouri 63770',20969,25566);
INSERT INTO "django_geo_db_zipcode" VALUES(28695,63771,-6,'Oran, Missouri 63771',20970,25567);
INSERT INTO "django_geo_db_zipcode" VALUES(28696,63772,-6,'Painton, Missouri 63772',20971,25568);
INSERT INTO "django_geo_db_zipcode" VALUES(28697,63774,-6,'Perkins, Missouri 63774',20972,25569);
INSERT INTO "django_geo_db_zipcode" VALUES(28698,63775,-6,'Perryville, Missouri 63775',20811,25570);
INSERT INTO "django_geo_db_zipcode" VALUES(28699,63776,-6,'McBride, Missouri 63776',20973,25551);
INSERT INTO "django_geo_db_zipcode" VALUES(28700,63779,-6,'Pocahontas, Missouri 63779',20974,25571);
INSERT INTO "django_geo_db_zipcode" VALUES(28701,63780,-6,'Scott City, Missouri 63780',20975,25572);
INSERT INTO "django_geo_db_zipcode" VALUES(28702,63781,-6,'Sedgewickville, Missouri 63781',20976,25573);
INSERT INTO "django_geo_db_zipcode" VALUES(28703,63782,-6,'Sturdivant, Missouri 63782',20977,25574);
INSERT INTO "django_geo_db_zipcode" VALUES(28704,63783,-6,'Uniontown, Missouri 63783',20978,25575);
INSERT INTO "django_geo_db_zipcode" VALUES(28705,63784,-6,'Vanduser, Missouri 63784',20979,25576);
INSERT INTO "django_geo_db_zipcode" VALUES(28706,63785,-6,'Whitewater, Missouri 63785',20980,25577);
INSERT INTO "django_geo_db_zipcode" VALUES(28707,63787,-6,'Zalma, Missouri 63787',20981,25578);
INSERT INTO "django_geo_db_zipcode" VALUES(28708,63801,-6,'Sikeston, Missouri 63801',20982,25579);
INSERT INTO "django_geo_db_zipcode" VALUES(28709,63804,-6,'Blodgett, Missouri 63804',20983,25580);
INSERT INTO "django_geo_db_zipcode" VALUES(28710,63820,-6,'Anniston, Missouri 63820',20984,25581);
INSERT INTO "django_geo_db_zipcode" VALUES(28711,63821,-6,'Arbyrd, Missouri 63821',20985,25582);
INSERT INTO "django_geo_db_zipcode" VALUES(28712,63822,-6,'Bernie, Missouri 63822',20986,25583);
INSERT INTO "django_geo_db_zipcode" VALUES(28713,63823,-6,'Bertrand, Missouri 63823',20987,25584);
INSERT INTO "django_geo_db_zipcode" VALUES(28714,63824,-6,'Blodgett, Missouri 63824',20983,25585);
INSERT INTO "django_geo_db_zipcode" VALUES(28715,63825,-6,'Bloomfield, Missouri 63825',20988,25586);
INSERT INTO "django_geo_db_zipcode" VALUES(28716,63826,-6,'Braggadocio, Missouri 63826',20989,25587);
INSERT INTO "django_geo_db_zipcode" VALUES(28717,63827,-6,'Bragg City, Missouri 63827',20990,25588);
INSERT INTO "django_geo_db_zipcode" VALUES(28718,63828,-6,'Canalou, Missouri 63828',20991,25589);
INSERT INTO "django_geo_db_zipcode" VALUES(28719,63829,-6,'Cardwell, Missouri 63829',20992,25590);
INSERT INTO "django_geo_db_zipcode" VALUES(28720,63830,-6,'Caruthersville, Missouri 63830',20993,25591);
INSERT INTO "django_geo_db_zipcode" VALUES(28721,63832,-6,'Wyatt, Missouri 63832',20994,25592);
INSERT INTO "django_geo_db_zipcode" VALUES(28722,63833,-6,'Catron, Missouri 63833',20995,25593);
INSERT INTO "django_geo_db_zipcode" VALUES(28723,63834,-6,'Charleston, Missouri 63834',20996,25594);
INSERT INTO "django_geo_db_zipcode" VALUES(28724,63837,-6,'Clarkton, Missouri 63837',20997,25595);
INSERT INTO "django_geo_db_zipcode" VALUES(28725,63838,-6,'Conran, Missouri 63838',20998,25596);
INSERT INTO "django_geo_db_zipcode" VALUES(28726,63839,-6,'Cooter, Missouri 63839',20999,25597);
INSERT INTO "django_geo_db_zipcode" VALUES(28727,63840,-6,'Deering, Missouri 63840',21000,25598);
INSERT INTO "django_geo_db_zipcode" VALUES(28728,63841,-6,'Dexter, Missouri 63841',21001,25599);
INSERT INTO "django_geo_db_zipcode" VALUES(28729,63845,-6,'East Prairie, Missouri 63845',21002,25600);
INSERT INTO "django_geo_db_zipcode" VALUES(28730,63846,-6,'Essex, Missouri 63846',21003,25601);
INSERT INTO "django_geo_db_zipcode" VALUES(28731,63847,-6,'Gibson, Missouri 63847',21004,25602);
INSERT INTO "django_geo_db_zipcode" VALUES(28732,63848,-6,'Gideon, Missouri 63848',21005,25603);
INSERT INTO "django_geo_db_zipcode" VALUES(28733,63849,-6,'Gobler, Missouri 63849',21006,25604);
INSERT INTO "django_geo_db_zipcode" VALUES(28734,63850,-6,'Grayridge, Missouri 63850',21007,25605);
INSERT INTO "django_geo_db_zipcode" VALUES(28735,63851,-6,'Hayti, Missouri 63851',21008,25606);
INSERT INTO "django_geo_db_zipcode" VALUES(28736,63852,-6,'Holcomb, Missouri 63852',21009,25607);
INSERT INTO "django_geo_db_zipcode" VALUES(28737,63853,-6,'Holland, Missouri 63853',21010,25608);
INSERT INTO "django_geo_db_zipcode" VALUES(28738,63855,-6,'Hornersville, Missouri 63855',21011,25609);
INSERT INTO "django_geo_db_zipcode" VALUES(28739,63857,-6,'Kennett, Missouri 63857',21012,25610);
INSERT INTO "django_geo_db_zipcode" VALUES(28740,63859,-6,'Independence, Missouri 63859',21013,25611);
INSERT INTO "django_geo_db_zipcode" VALUES(28741,63860,-6,'Kewanee, Missouri 63860',21014,25612);
INSERT INTO "django_geo_db_zipcode" VALUES(28742,63862,-6,'Lilbourn, Missouri 63862',21015,25613);
INSERT INTO "django_geo_db_zipcode" VALUES(28743,63863,-6,'Malden, Missouri 63863',21016,25614);
INSERT INTO "django_geo_db_zipcode" VALUES(28744,63866,-6,'Marston, Missouri 63866',21017,25615);
INSERT INTO "django_geo_db_zipcode" VALUES(28745,63867,-6,'Matthews, Missouri 63867',21018,25616);
INSERT INTO "django_geo_db_zipcode" VALUES(28746,63868,-6,'Morehouse, Missouri 63868',21019,25617);
INSERT INTO "django_geo_db_zipcode" VALUES(28747,63869,-6,'New Madrid, Missouri 63869',21020,25618);
INSERT INTO "django_geo_db_zipcode" VALUES(28748,63870,-6,'Parma, Missouri 63870',21021,25619);
INSERT INTO "django_geo_db_zipcode" VALUES(28749,63871,-6,'Pascola, Missouri 63871',21022,25620);
INSERT INTO "django_geo_db_zipcode" VALUES(28750,63872,-6,'Clay, Missouri 63872',20901,25621);
INSERT INTO "django_geo_db_zipcode" VALUES(28751,63873,-6,'Portageville, Missouri 63873',21023,25622);
INSERT INTO "django_geo_db_zipcode" VALUES(28752,63874,-6,'Risco, Missouri 63874',21024,25623);
INSERT INTO "django_geo_db_zipcode" VALUES(28753,63875,-6,'Rives, Missouri 63875',21025,25624);
INSERT INTO "django_geo_db_zipcode" VALUES(28754,63876,-6,'Senath, Missouri 63876',21026,25625);
INSERT INTO "django_geo_db_zipcode" VALUES(28755,63877,-6,'Steele, Missouri 63877',21027,25626);
INSERT INTO "django_geo_db_zipcode" VALUES(28756,63878,-6,'Tallapoosa, Missouri 63878',21028,25627);
INSERT INTO "django_geo_db_zipcode" VALUES(28757,63879,-6,'Wardell, Missouri 63879',21029,25628);
INSERT INTO "django_geo_db_zipcode" VALUES(28758,63880,-6,'Whiteoak, Missouri 63880',21030,25629);
INSERT INTO "django_geo_db_zipcode" VALUES(28759,63881,-6,'Wolf Island, Missouri 63881',21031,25630);
INSERT INTO "django_geo_db_zipcode" VALUES(28760,63882,-6,'Wyatt, Missouri 63882',20994,25631);
INSERT INTO "django_geo_db_zipcode" VALUES(28761,63901,-6,'Poplar Bluff, Missouri 63901',21032,25632);
INSERT INTO "django_geo_db_zipcode" VALUES(28762,63902,-6,'Poplar Bluff, Missouri 63902',21032,25633);
INSERT INTO "django_geo_db_zipcode" VALUES(28763,63931,-6,'Briar, Missouri 63931',21033,25634);
INSERT INTO "django_geo_db_zipcode" VALUES(28764,63932,-6,'Broseley, Missouri 63932',21034,25635);
INSERT INTO "django_geo_db_zipcode" VALUES(28765,63933,-6,'Campbell, Missouri 63933',21035,25636);
INSERT INTO "django_geo_db_zipcode" VALUES(28766,63934,-6,'Clubb, Missouri 63934',21036,25637);
INSERT INTO "django_geo_db_zipcode" VALUES(28767,63935,-6,'Doniphan, Missouri 63935',21037,25638);
INSERT INTO "django_geo_db_zipcode" VALUES(28768,63936,-6,'Dudley, Missouri 63936',21038,25639);
INSERT INTO "django_geo_db_zipcode" VALUES(28769,63937,-6,'Ellsinore, Missouri 63937',21039,25640);
INSERT INTO "django_geo_db_zipcode" VALUES(28770,63938,-6,'Fagus, Missouri 63938',21040,25641);
INSERT INTO "django_geo_db_zipcode" VALUES(28771,63939,-6,'Fairdealing, Missouri 63939',21041,25642);
INSERT INTO "django_geo_db_zipcode" VALUES(28772,63940,-6,'Fisk, Missouri 63940',21042,25643);
INSERT INTO "django_geo_db_zipcode" VALUES(28773,63941,-6,'Fremont, Missouri 63941',21043,25644);
INSERT INTO "django_geo_db_zipcode" VALUES(28774,63942,-6,'Gatewood, Missouri 63942',21044,25645);
INSERT INTO "django_geo_db_zipcode" VALUES(28775,63943,-6,'Grandin, Missouri 63943',21045,25646);
INSERT INTO "django_geo_db_zipcode" VALUES(28776,63944,-6,'Greenville, Missouri 63944',21046,25647);
INSERT INTO "django_geo_db_zipcode" VALUES(28777,63945,-6,'Harviell, Missouri 63945',21047,25648);
INSERT INTO "django_geo_db_zipcode" VALUES(28778,63947,-6,'Hiram, Missouri 63947',21048,25649);
INSERT INTO "django_geo_db_zipcode" VALUES(28779,63950,-6,'Lodi, Missouri 63950',21049,25509);
INSERT INTO "django_geo_db_zipcode" VALUES(28780,63951,-6,'Lowndes, Missouri 63951',21050,25650);
INSERT INTO "django_geo_db_zipcode" VALUES(28781,63952,-6,'Mill Spring, Missouri 63952',21051,25651);
INSERT INTO "django_geo_db_zipcode" VALUES(28782,63953,-6,'Naylor, Missouri 63953',21052,25652);
INSERT INTO "django_geo_db_zipcode" VALUES(28783,63954,-6,'Neelyville, Missouri 63954',21053,25653);
INSERT INTO "django_geo_db_zipcode" VALUES(28784,63955,-6,'Oxly, Missouri 63955',21054,25654);
INSERT INTO "django_geo_db_zipcode" VALUES(28785,63956,-6,'Patterson, Missouri 63956',21055,25655);
INSERT INTO "django_geo_db_zipcode" VALUES(28786,63957,-6,'Piedmont, Missouri 63957',21056,25656);
INSERT INTO "django_geo_db_zipcode" VALUES(28787,63960,-6,'Puxico, Missouri 63960',21057,25657);
INSERT INTO "django_geo_db_zipcode" VALUES(28788,63961,-6,'Qulin, Missouri 63961',21058,25658);
INSERT INTO "django_geo_db_zipcode" VALUES(28789,63962,-6,'Rombauer, Missouri 63962',21059,25633);
INSERT INTO "django_geo_db_zipcode" VALUES(28790,63963,-6,'Shook, Missouri 63963',21060,25659);
INSERT INTO "django_geo_db_zipcode" VALUES(28791,63964,-6,'Silva, Missouri 63964',21061,25660);
INSERT INTO "django_geo_db_zipcode" VALUES(28792,63965,-6,'Van Buren, Missouri 63965',21062,25661);
INSERT INTO "django_geo_db_zipcode" VALUES(28793,63966,-6,'Wappapello, Missouri 63966',21063,25662);
INSERT INTO "django_geo_db_zipcode" VALUES(28794,63967,-6,'Williamsville, Missouri 63967',21064,25663);
INSERT INTO "django_geo_db_zipcode" VALUES(28795,64001,-6,'Alma, Missouri 64001',21065,25664);
INSERT INTO "django_geo_db_zipcode" VALUES(28796,64011,-6,'Bates City, Missouri 64011',21066,25665);
INSERT INTO "django_geo_db_zipcode" VALUES(28797,64012,-6,'Belton, Missouri 64012',21067,25666);
INSERT INTO "django_geo_db_zipcode" VALUES(28798,64013,-6,'Blue Springs, Missouri 64013',21068,25667);
INSERT INTO "django_geo_db_zipcode" VALUES(28799,64014,-6,'Blue Springs, Missouri 64014',21068,25668);
INSERT INTO "django_geo_db_zipcode" VALUES(28800,64015,-6,'Blue Springs, Missouri 64015',21068,25669);
INSERT INTO "django_geo_db_zipcode" VALUES(28801,64016,-6,'Buckner, Missouri 64016',21069,25670);
INSERT INTO "django_geo_db_zipcode" VALUES(28802,64017,-6,'Camden, Missouri 64017',21070,25671);
INSERT INTO "django_geo_db_zipcode" VALUES(28803,64018,-6,'Camden Point, Missouri 64018',21071,25672);
INSERT INTO "django_geo_db_zipcode" VALUES(28804,64019,-6,'Centerview, Missouri 64019',21072,25673);
INSERT INTO "django_geo_db_zipcode" VALUES(28805,64020,-6,'Concordia, Missouri 64020',21073,25674);
INSERT INTO "django_geo_db_zipcode" VALUES(28806,64021,-6,'Corder, Missouri 64021',21074,25675);
INSERT INTO "django_geo_db_zipcode" VALUES(28807,64022,-6,'Dover, Missouri 64022',21075,25676);
INSERT INTO "django_geo_db_zipcode" VALUES(28808,64024,-6,'Excelsior Springs, Missouri 64024',21076,25677);
INSERT INTO "django_geo_db_zipcode" VALUES(28809,64028,-6,'Farley, Missouri 64028',21077,25678);
INSERT INTO "django_geo_db_zipcode" VALUES(28810,64029,-6,'Grain Valley, Missouri 64029',21078,25679);
INSERT INTO "django_geo_db_zipcode" VALUES(28811,64030,-6,'Grandview, Missouri 64030',21079,25680);
INSERT INTO "django_geo_db_zipcode" VALUES(28812,64034,-6,'Greenwood, Missouri 64034',21080,25681);
INSERT INTO "django_geo_db_zipcode" VALUES(28813,64035,-6,'Hardin, Missouri 64035',21081,25682);
INSERT INTO "django_geo_db_zipcode" VALUES(28814,64036,-6,'Henrietta, Missouri 64036',21082,25683);
INSERT INTO "django_geo_db_zipcode" VALUES(28815,64037,-6,'Higginsville, Missouri 64037',21083,25684);
INSERT INTO "django_geo_db_zipcode" VALUES(28816,64040,-6,'Holden, Missouri 64040',21084,25685);
INSERT INTO "django_geo_db_zipcode" VALUES(28817,64048,-6,'Holt, Missouri 64048',21085,25686);
INSERT INTO "django_geo_db_zipcode" VALUES(28818,64050,-6,'Independence, Missouri 64050',21013,25687);
INSERT INTO "django_geo_db_zipcode" VALUES(28819,64051,-6,'Independence, Missouri 64051',21013,25688);
INSERT INTO "django_geo_db_zipcode" VALUES(28820,64052,-6,'Independence, Missouri 64052',21013,25689);
INSERT INTO "django_geo_db_zipcode" VALUES(28821,64053,-6,'Independence, Missouri 64053',21013,25690);
INSERT INTO "django_geo_db_zipcode" VALUES(28822,64054,-6,'Independence, Missouri 64054',21013,25691);
INSERT INTO "django_geo_db_zipcode" VALUES(28823,64055,-6,'Independence, Missouri 64055',21013,25692);
INSERT INTO "django_geo_db_zipcode" VALUES(28824,64056,-6,'Independence, Missouri 64056',21013,25693);
INSERT INTO "django_geo_db_zipcode" VALUES(28825,64057,-6,'Independence, Missouri 64057',21013,25694);
INSERT INTO "django_geo_db_zipcode" VALUES(28826,64058,-6,'Independence, Missouri 64058',21013,25695);
INSERT INTO "django_geo_db_zipcode" VALUES(28827,64060,-6,'Kearney, Missouri 64060',21086,25696);
INSERT INTO "django_geo_db_zipcode" VALUES(28828,64061,-6,'Kingsville, Missouri 64061',21087,25697);
INSERT INTO "django_geo_db_zipcode" VALUES(28829,64062,-6,'Lawson, Missouri 64062',21088,25698);
INSERT INTO "django_geo_db_zipcode" VALUES(28830,64063,-6,'Lees Summit, Missouri 64063',21089,25699);
INSERT INTO "django_geo_db_zipcode" VALUES(28831,64064,-6,'Lees Summit, Missouri 64064',21089,25700);
INSERT INTO "django_geo_db_zipcode" VALUES(28832,64065,-6,'Lees Summit, Missouri 64065',21089,25701);
INSERT INTO "django_geo_db_zipcode" VALUES(28833,64066,-6,'Levasy, Missouri 64066',21090,25702);
INSERT INTO "django_geo_db_zipcode" VALUES(28834,64067,-6,'Lexington, Missouri 64067',21091,25703);
INSERT INTO "django_geo_db_zipcode" VALUES(28835,64068,-6,'Liberty, Missouri 64068',21092,25704);
INSERT INTO "django_geo_db_zipcode" VALUES(28836,64069,-6,'Liberty, Missouri 64069',21092,25705);
INSERT INTO "django_geo_db_zipcode" VALUES(28837,64070,-6,'Lone Jack, Missouri 64070',21093,25706);
INSERT INTO "django_geo_db_zipcode" VALUES(28838,64071,-6,'Mayview, Missouri 64071',21094,25707);
INSERT INTO "django_geo_db_zipcode" VALUES(28839,64072,-6,'Missouri City, Missouri 64072',21095,25708);
INSERT INTO "django_geo_db_zipcode" VALUES(28840,64073,-6,'Mosby, Missouri 64073',21096,25709);
INSERT INTO "django_geo_db_zipcode" VALUES(28841,64074,-6,'Napoleon, Missouri 64074',21097,25710);
INSERT INTO "django_geo_db_zipcode" VALUES(28842,64075,-6,'Oak Grove, Missouri 64075',21098,25711);
INSERT INTO "django_geo_db_zipcode" VALUES(28843,64076,-6,'Odessa, Missouri 64076',21099,25712);
INSERT INTO "django_geo_db_zipcode" VALUES(28844,64077,-6,'Orrick, Missouri 64077',21100,25713);
INSERT INTO "django_geo_db_zipcode" VALUES(28845,64078,-6,'Peculiar, Missouri 64078',21101,25714);
INSERT INTO "django_geo_db_zipcode" VALUES(28846,64079,-6,'Platte City, Missouri 64079',21102,25715);
INSERT INTO "django_geo_db_zipcode" VALUES(28847,64080,-6,'Pleasant Hill, Missouri 64080',21103,25716);
INSERT INTO "django_geo_db_zipcode" VALUES(28848,64081,-6,'Lees Summit, Missouri 64081',21089,25717);
INSERT INTO "django_geo_db_zipcode" VALUES(28849,64082,-6,'Lees Summit, Missouri 64082',21089,25718);
INSERT INTO "django_geo_db_zipcode" VALUES(28850,64083,-6,'Raymore, Missouri 64083',21104,25719);
INSERT INTO "django_geo_db_zipcode" VALUES(28851,64084,-6,'Rayville, Missouri 64084',21105,25720);
INSERT INTO "django_geo_db_zipcode" VALUES(28852,64085,-6,'Richmond, Missouri 64085',21106,25721);
INSERT INTO "django_geo_db_zipcode" VALUES(28853,64086,-6,'Lees Summit, Missouri 64086',21089,25722);
INSERT INTO "django_geo_db_zipcode" VALUES(28854,64087,-6,'Liberty, Missouri 64087',21092,25705);
INSERT INTO "django_geo_db_zipcode" VALUES(28855,64088,-6,'Sibley, Missouri 64088',21107,25723);
INSERT INTO "django_geo_db_zipcode" VALUES(28856,64089,-6,'Smithville, Missouri 64089',21108,25724);
INSERT INTO "django_geo_db_zipcode" VALUES(28857,64090,-6,'Strasburg, Missouri 64090',21109,25725);
INSERT INTO "django_geo_db_zipcode" VALUES(28858,64092,-6,'Waldron, Missouri 64092',21110,25726);
INSERT INTO "django_geo_db_zipcode" VALUES(28859,64093,-6,'Warrensburg, Missouri 64093',21111,25727);
INSERT INTO "django_geo_db_zipcode" VALUES(28860,64096,-6,'Waverly, Missouri 64096',21112,25728);
INSERT INTO "django_geo_db_zipcode" VALUES(28861,64097,-6,'Wellington, Missouri 64097',21113,25729);
INSERT INTO "django_geo_db_zipcode" VALUES(28862,64098,-6,'Weston, Missouri 64098',21114,25730);
INSERT INTO "django_geo_db_zipcode" VALUES(28863,64101,-6,'Kansas City, Missouri 64101',21115,25731);
INSERT INTO "django_geo_db_zipcode" VALUES(28864,64102,-6,'Kansas City, Missouri 64102',21115,25732);
INSERT INTO "django_geo_db_zipcode" VALUES(28865,64105,-6,'Kansas City, Missouri 64105',21115,25733);
INSERT INTO "django_geo_db_zipcode" VALUES(28866,64106,-6,'Kansas City, Missouri 64106',21115,25734);
INSERT INTO "django_geo_db_zipcode" VALUES(28867,64108,-6,'Kansas City, Missouri 64108',21115,25735);
INSERT INTO "django_geo_db_zipcode" VALUES(28868,64109,-6,'Kansas City, Missouri 64109',21115,25736);
INSERT INTO "django_geo_db_zipcode" VALUES(28869,64110,-6,'Kansas City, Missouri 64110',21115,25737);
INSERT INTO "django_geo_db_zipcode" VALUES(28870,64111,-6,'Kansas City, Missouri 64111',21115,25738);
INSERT INTO "django_geo_db_zipcode" VALUES(28871,64112,-6,'Kansas City, Missouri 64112',21115,25739);
INSERT INTO "django_geo_db_zipcode" VALUES(28872,64113,-6,'Kansas City, Missouri 64113',21115,25740);
INSERT INTO "django_geo_db_zipcode" VALUES(28873,64114,-6,'Kansas City, Missouri 64114',21115,25741);
INSERT INTO "django_geo_db_zipcode" VALUES(28874,64116,-6,'Kansas City, Missouri 64116',21115,25742);
INSERT INTO "django_geo_db_zipcode" VALUES(28875,64117,-6,'Kansas City, Missouri 64117',21115,25743);
INSERT INTO "django_geo_db_zipcode" VALUES(28876,64118,-6,'Kansas City, Missouri 64118',21115,25744);
INSERT INTO "django_geo_db_zipcode" VALUES(28877,64119,-6,'Kansas City, Missouri 64119',21115,25745);
INSERT INTO "django_geo_db_zipcode" VALUES(28878,64120,-6,'Kansas City, Missouri 64120',21115,25746);
INSERT INTO "django_geo_db_zipcode" VALUES(28879,64121,-6,'Kansas City, Missouri 64121',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28880,64123,-6,'Kansas City, Missouri 64123',21115,25748);
INSERT INTO "django_geo_db_zipcode" VALUES(28881,64124,-6,'Kansas City, Missouri 64124',21115,25749);
INSERT INTO "django_geo_db_zipcode" VALUES(28882,64125,-6,'Kansas City, Missouri 64125',21115,25750);
INSERT INTO "django_geo_db_zipcode" VALUES(28883,64126,-6,'Kansas City, Missouri 64126',21115,25751);
INSERT INTO "django_geo_db_zipcode" VALUES(28884,64127,-6,'Kansas City, Missouri 64127',21115,25752);
INSERT INTO "django_geo_db_zipcode" VALUES(28885,64128,-6,'Kansas City, Missouri 64128',21115,25753);
INSERT INTO "django_geo_db_zipcode" VALUES(28886,64129,-6,'Kansas City, Missouri 64129',21115,25754);
INSERT INTO "django_geo_db_zipcode" VALUES(28887,64130,-6,'Kansas City, Missouri 64130',21115,25755);
INSERT INTO "django_geo_db_zipcode" VALUES(28888,64131,-6,'Kansas City, Missouri 64131',21115,25756);
INSERT INTO "django_geo_db_zipcode" VALUES(28889,64132,-6,'Kansas City, Missouri 64132',21115,25757);
INSERT INTO "django_geo_db_zipcode" VALUES(28890,64133,-6,'Kansas City, Missouri 64133',21115,25758);
INSERT INTO "django_geo_db_zipcode" VALUES(28891,64134,-6,'Kansas City, Missouri 64134',21115,25759);
INSERT INTO "django_geo_db_zipcode" VALUES(28892,64136,-6,'Kansas City, Missouri 64136',21115,25760);
INSERT INTO "django_geo_db_zipcode" VALUES(28893,64137,-6,'Kansas City, Missouri 64137',21115,25761);
INSERT INTO "django_geo_db_zipcode" VALUES(28894,64138,-6,'Kansas City, Missouri 64138',21115,25762);
INSERT INTO "django_geo_db_zipcode" VALUES(28895,64139,-6,'Kansas City, Missouri 64139',21115,25763);
INSERT INTO "django_geo_db_zipcode" VALUES(28896,64141,-6,'Kansas City, Missouri 64141',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28897,64142,-6,'Kansas City, Missouri 64142',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28898,64144,-6,'Kansas City, Missouri 64144',21115,25705);
INSERT INTO "django_geo_db_zipcode" VALUES(28899,64145,-6,'Kansas City, Missouri 64145',21115,25764);
INSERT INTO "django_geo_db_zipcode" VALUES(28900,64146,-6,'Kansas City, Missouri 64146',21115,25765);
INSERT INTO "django_geo_db_zipcode" VALUES(28901,64147,-6,'Kansas City, Missouri 64147',21115,25766);
INSERT INTO "django_geo_db_zipcode" VALUES(28902,64148,-6,'Kansas City, Missouri 64148',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28903,64149,-6,'Kansas City, Missouri 64149',21115,25767);
INSERT INTO "django_geo_db_zipcode" VALUES(28904,64150,-6,'Riverside, Missouri 64150',21116,25768);
INSERT INTO "django_geo_db_zipcode" VALUES(28905,64151,-6,'Kansas City, Missouri 64151',21115,25769);
INSERT INTO "django_geo_db_zipcode" VALUES(28906,64152,-6,'Kansas City, Missouri 64152',21115,25770);
INSERT INTO "django_geo_db_zipcode" VALUES(28907,64153,-6,'Kansas City, Missouri 64153',21115,25771);
INSERT INTO "django_geo_db_zipcode" VALUES(28908,64154,-6,'Kansas City, Missouri 64154',21115,25772);
INSERT INTO "django_geo_db_zipcode" VALUES(28909,64155,-6,'Kansas City, Missouri 64155',21115,25773);
INSERT INTO "django_geo_db_zipcode" VALUES(28910,64156,-6,'Kansas City, Missouri 64156',21115,25774);
INSERT INTO "django_geo_db_zipcode" VALUES(28911,64157,-6,'Kansas City, Missouri 64157',21115,25775);
INSERT INTO "django_geo_db_zipcode" VALUES(28912,64158,-6,'Kansas City, Missouri 64158',21115,25776);
INSERT INTO "django_geo_db_zipcode" VALUES(28913,64160,-6,'Kansas City, Missouri 64160',21115,25705);
INSERT INTO "django_geo_db_zipcode" VALUES(28914,64161,-6,'Kansas City, Missouri 64161',21115,25777);
INSERT INTO "django_geo_db_zipcode" VALUES(28915,64163,-6,'Kansas City, Missouri 64163',21115,25778);
INSERT INTO "django_geo_db_zipcode" VALUES(28916,64164,-6,'Kansas City, Missouri 64164',21115,25779);
INSERT INTO "django_geo_db_zipcode" VALUES(28917,64165,-6,'Kansas City, Missouri 64165',21115,25780);
INSERT INTO "django_geo_db_zipcode" VALUES(28918,64166,-6,'Kansas City, Missouri 64166',21115,25781);
INSERT INTO "django_geo_db_zipcode" VALUES(28919,64167,-6,'Kansas City, Missouri 64167',21115,25782);
INSERT INTO "django_geo_db_zipcode" VALUES(28920,64168,-6,'Kansas City, Missouri 64168',21115,25783);
INSERT INTO "django_geo_db_zipcode" VALUES(28921,64170,-6,'Kansas City, Missouri 64170',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28922,64171,-6,'Kansas City, Missouri 64171',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28923,64172,-6,'Kansas City, Missouri 64172',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28924,64173,-6,'Kansas City, Missouri 64173',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28925,64179,-6,'Kansas City, Missouri 64179',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28926,64180,-6,'Kansas City, Missouri 64180',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28927,64183,-6,'Kansas City, Missouri 64183',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28928,64184,-6,'Kansas City, Missouri 64184',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28929,64185,-6,'Kansas City, Missouri 64185',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28930,64187,-6,'Kansas City, Missouri 64187',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28931,64188,-6,'Kansas City, Missouri 64188',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28932,64189,-6,'Kansas City, Missouri 64189',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28933,64190,-6,'Kansas City, Missouri 64190',21115,25783);
INSERT INTO "django_geo_db_zipcode" VALUES(28934,64191,-6,'Kansas City, Missouri 64191',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28935,64192,-6,'Kansas City, Missouri 64192',21115,25784);
INSERT INTO "django_geo_db_zipcode" VALUES(28936,64193,-6,'Kansas City, Missouri 64193',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28937,64194,-6,'Kansas City, Missouri 64194',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28938,64195,-6,'Kansas City, Missouri 64195',21115,25783);
INSERT INTO "django_geo_db_zipcode" VALUES(28939,64196,-6,'Kansas City, Missouri 64196',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28940,64197,-6,'Kansas City, Missouri 64197',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28941,64198,-6,'Kansas City, Missouri 64198',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28942,64199,-6,'Kansas City, Missouri 64199',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(28943,64401,-6,'Agency, Missouri 64401',21117,25785);
INSERT INTO "django_geo_db_zipcode" VALUES(28944,64402,-6,'Albany, Missouri 64402',21118,25786);
INSERT INTO "django_geo_db_zipcode" VALUES(28945,64420,-6,'Allendale, Missouri 64420',21119,25787);
INSERT INTO "django_geo_db_zipcode" VALUES(28946,64421,-6,'Amazonia, Missouri 64421',21120,25788);
INSERT INTO "django_geo_db_zipcode" VALUES(28947,64422,-6,'Amity, Missouri 64422',21121,25789);
INSERT INTO "django_geo_db_zipcode" VALUES(28948,64423,-6,'Barnard, Missouri 64423',21122,25790);
INSERT INTO "django_geo_db_zipcode" VALUES(28949,64424,-6,'Bethany, Missouri 64424',21123,25791);
INSERT INTO "django_geo_db_zipcode" VALUES(28950,64426,-6,'Blythedale, Missouri 64426',21124,25792);
INSERT INTO "django_geo_db_zipcode" VALUES(28951,64427,-6,'Bolckow, Missouri 64427',21125,25793);
INSERT INTO "django_geo_db_zipcode" VALUES(28952,64428,-6,'Burlington Junction, Missouri 64428',21126,25794);
INSERT INTO "django_geo_db_zipcode" VALUES(28953,64429,-6,'Cameron, Missouri 64429',21127,25795);
INSERT INTO "django_geo_db_zipcode" VALUES(28954,64430,-6,'Clarksdale, Missouri 64430',21128,25796);
INSERT INTO "django_geo_db_zipcode" VALUES(28955,64431,-6,'Clearmont, Missouri 64431',21129,25797);
INSERT INTO "django_geo_db_zipcode" VALUES(28956,64432,-6,'Clyde, Missouri 64432',21130,25798);
INSERT INTO "django_geo_db_zipcode" VALUES(28957,64433,-6,'Conception, Missouri 64433',21131,25799);
INSERT INTO "django_geo_db_zipcode" VALUES(28958,64434,-6,'Conception Junction, Missouri 64434',21132,25800);
INSERT INTO "django_geo_db_zipcode" VALUES(28959,64436,-6,'Cosby, Missouri 64436',21133,25801);
INSERT INTO "django_geo_db_zipcode" VALUES(28960,64437,-6,'Craig, Missouri 64437',21134,25802);
INSERT INTO "django_geo_db_zipcode" VALUES(28961,64438,-6,'Darlington, Missouri 64438',21135,25803);
INSERT INTO "django_geo_db_zipcode" VALUES(28962,64439,-6,'Dearborn, Missouri 64439',21136,25804);
INSERT INTO "django_geo_db_zipcode" VALUES(28963,64440,-6,'De Kalb, Missouri 64440',21137,25805);
INSERT INTO "django_geo_db_zipcode" VALUES(28964,64441,-6,'Denver, Missouri 64441',21138,25806);
INSERT INTO "django_geo_db_zipcode" VALUES(28965,64442,-6,'Eagleville, Missouri 64442',21139,25807);
INSERT INTO "django_geo_db_zipcode" VALUES(28966,64443,-6,'Easton, Missouri 64443',21140,25808);
INSERT INTO "django_geo_db_zipcode" VALUES(28967,64444,-6,'Edgerton, Missouri 64444',21141,25809);
INSERT INTO "django_geo_db_zipcode" VALUES(28968,64445,-6,'Elmo, Missouri 64445',21142,25810);
INSERT INTO "django_geo_db_zipcode" VALUES(28969,64446,-6,'Fairfax, Missouri 64446',21143,25811);
INSERT INTO "django_geo_db_zipcode" VALUES(28970,64447,-6,'Fairport, Missouri 64447',21144,25812);
INSERT INTO "django_geo_db_zipcode" VALUES(28971,64448,-6,'Faucett, Missouri 64448',21145,25813);
INSERT INTO "django_geo_db_zipcode" VALUES(28972,64449,-6,'Fillmore, Missouri 64449',21146,25814);
INSERT INTO "django_geo_db_zipcode" VALUES(28973,64451,-6,'Forest City, Missouri 64451',21147,25815);
INSERT INTO "django_geo_db_zipcode" VALUES(28974,64453,-6,'Gentry, Missouri 64453',21148,25816);
INSERT INTO "django_geo_db_zipcode" VALUES(28975,64454,-6,'Gower, Missouri 64454',21149,25817);
INSERT INTO "django_geo_db_zipcode" VALUES(28976,64455,-6,'Graham, Missouri 64455',21150,25818);
INSERT INTO "django_geo_db_zipcode" VALUES(28977,64456,-6,'Grant City, Missouri 64456',21151,25819);
INSERT INTO "django_geo_db_zipcode" VALUES(28978,64457,-6,'Guilford, Missouri 64457',21152,25820);
INSERT INTO "django_geo_db_zipcode" VALUES(28979,64458,-6,'Hatfield, Missouri 64458',21153,25821);
INSERT INTO "django_geo_db_zipcode" VALUES(28980,64459,-6,'Helena, Missouri 64459',21154,25822);
INSERT INTO "django_geo_db_zipcode" VALUES(28981,64461,-6,'Hopkins, Missouri 64461',21155,25823);
INSERT INTO "django_geo_db_zipcode" VALUES(28982,64463,-6,'King City, Missouri 64463',21156,25824);
INSERT INTO "django_geo_db_zipcode" VALUES(28983,64464,-6,'Polk, Missouri 64464',21157,25825);
INSERT INTO "django_geo_db_zipcode" VALUES(28984,64465,-6,'Lathrop, Missouri 64465',21158,25826);
INSERT INTO "django_geo_db_zipcode" VALUES(28985,64466,-6,'Maitland, Missouri 64466',21159,25827);
INSERT INTO "django_geo_db_zipcode" VALUES(28986,64467,-6,'Martinsville, Missouri 64467',21160,25828);
INSERT INTO "django_geo_db_zipcode" VALUES(28987,64468,-6,'Maryville, Missouri 64468',21161,25829);
INSERT INTO "django_geo_db_zipcode" VALUES(28988,64469,-6,'Maysville, Missouri 64469',21162,25830);
INSERT INTO "django_geo_db_zipcode" VALUES(28989,64470,-6,'Mound City, Missouri 64470',21163,25831);
INSERT INTO "django_geo_db_zipcode" VALUES(28990,64471,-6,'New Hampton, Missouri 64471',21164,25832);
INSERT INTO "django_geo_db_zipcode" VALUES(28991,64473,-6,'Oregon, Missouri 64473',21165,25833);
INSERT INTO "django_geo_db_zipcode" VALUES(28992,64474,-6,'Osborn, Missouri 64474',21166,25834);
INSERT INTO "django_geo_db_zipcode" VALUES(28993,64475,-6,'Parnell, Missouri 64475',21167,25835);
INSERT INTO "django_geo_db_zipcode" VALUES(28994,64476,-6,'Pickering, Missouri 64476',21168,25836);
INSERT INTO "django_geo_db_zipcode" VALUES(28995,64477,-6,'Plattsburg, Missouri 64477',21169,25837);
INSERT INTO "django_geo_db_zipcode" VALUES(28996,64478,-6,'Quitman, Missouri 64478',21170,25838);
INSERT INTO "django_geo_db_zipcode" VALUES(28997,64479,-6,'Ravenwood, Missouri 64479',21171,25839);
INSERT INTO "django_geo_db_zipcode" VALUES(28998,64480,-6,'Rea, Missouri 64480',21172,25840);
INSERT INTO "django_geo_db_zipcode" VALUES(28999,64481,-6,'Ridgeway, Missouri 64481',21173,25841);
INSERT INTO "django_geo_db_zipcode" VALUES(29000,64482,-6,'Rock Port, Missouri 64482',21174,25842);
INSERT INTO "django_geo_db_zipcode" VALUES(29001,64483,-6,'Rosendale, Missouri 64483',21175,25843);
INSERT INTO "django_geo_db_zipcode" VALUES(29002,64484,-6,'Rushville, Missouri 64484',21176,25844);
INSERT INTO "django_geo_db_zipcode" VALUES(29003,64485,-6,'Savannah, Missouri 64485',21177,25845);
INSERT INTO "django_geo_db_zipcode" VALUES(29004,64486,-6,'Sheridan, Missouri 64486',21178,25846);
INSERT INTO "django_geo_db_zipcode" VALUES(29005,64487,-6,'Skidmore, Missouri 64487',21179,25847);
INSERT INTO "django_geo_db_zipcode" VALUES(29006,64489,-6,'Stanberry, Missouri 64489',21180,25848);
INSERT INTO "django_geo_db_zipcode" VALUES(29007,64490,-6,'Stewartsville, Missouri 64490',21181,25849);
INSERT INTO "django_geo_db_zipcode" VALUES(29008,64491,-6,'Tarkio, Missouri 64491',21182,25850);
INSERT INTO "django_geo_db_zipcode" VALUES(29009,64492,-6,'Trimble, Missouri 64492',21183,25851);
INSERT INTO "django_geo_db_zipcode" VALUES(29010,64493,-6,'Turney, Missouri 64493',21184,25852);
INSERT INTO "django_geo_db_zipcode" VALUES(29011,64494,-6,'Union Star, Missouri 64494',21185,25853);
INSERT INTO "django_geo_db_zipcode" VALUES(29012,64496,-6,'Watson, Missouri 64496',21186,25854);
INSERT INTO "django_geo_db_zipcode" VALUES(29013,64497,-6,'Weatherby, Missouri 64497',21187,25855);
INSERT INTO "django_geo_db_zipcode" VALUES(29014,64498,-6,'Westboro, Missouri 64498',21188,25856);
INSERT INTO "django_geo_db_zipcode" VALUES(29015,64499,-6,'Worth, Missouri 64499',21189,25857);
INSERT INTO "django_geo_db_zipcode" VALUES(29016,64501,-6,'Saint Joseph, Missouri 64501',21190,25858);
INSERT INTO "django_geo_db_zipcode" VALUES(29017,64502,-6,'Saint Joseph, Missouri 64502',21190,25859);
INSERT INTO "django_geo_db_zipcode" VALUES(29018,64503,-6,'Saint Joseph, Missouri 64503',21190,25860);
INSERT INTO "django_geo_db_zipcode" VALUES(29019,64504,-6,'Saint Joseph, Missouri 64504',21190,25861);
INSERT INTO "django_geo_db_zipcode" VALUES(29020,64505,-6,'Saint Joseph, Missouri 64505',21190,25862);
INSERT INTO "django_geo_db_zipcode" VALUES(29021,64506,-6,'Saint Joseph, Missouri 64506',21190,25863);
INSERT INTO "django_geo_db_zipcode" VALUES(29022,64507,-6,'Saint Joseph, Missouri 64507',21190,25864);
INSERT INTO "django_geo_db_zipcode" VALUES(29023,64508,-6,'Saint Joseph, Missouri 64508',21190,25859);
INSERT INTO "django_geo_db_zipcode" VALUES(29024,64600,-6,'Blue Mound, Missouri 64600',21191,25865);
INSERT INTO "django_geo_db_zipcode" VALUES(29025,64601,-6,'Chillicothe, Missouri 64601',21192,25866);
INSERT INTO "django_geo_db_zipcode" VALUES(29026,64620,-6,'Altamont, Missouri 64620',21193,25867);
INSERT INTO "django_geo_db_zipcode" VALUES(29027,64621,-6,'Fairview, Missouri 64621',21194,25868);
INSERT INTO "django_geo_db_zipcode" VALUES(29028,64622,-6,'Bogard, Missouri 64622',21195,25869);
INSERT INTO "django_geo_db_zipcode" VALUES(29029,64623,-6,'Bosworth, Missouri 64623',21196,25870);
INSERT INTO "django_geo_db_zipcode" VALUES(29030,64624,-6,'Braymer, Missouri 64624',21197,25871);
INSERT INTO "django_geo_db_zipcode" VALUES(29031,64625,-6,'Breckenridge, Missouri 64625',21198,25872);
INSERT INTO "django_geo_db_zipcode" VALUES(29032,64628,-6,'Brookfield, Missouri 64628',21199,25873);
INSERT INTO "django_geo_db_zipcode" VALUES(29033,64629,-6,'Braymer, Missouri 64629',21197,25874);
INSERT INTO "django_geo_db_zipcode" VALUES(29034,64630,-6,'Browning, Missouri 64630',21200,25875);
INSERT INTO "django_geo_db_zipcode" VALUES(29035,64631,-6,'Bucklin, Missouri 64631',21201,25876);
INSERT INTO "django_geo_db_zipcode" VALUES(29036,64632,-6,'Cainsville, Missouri 64632',21202,25877);
INSERT INTO "django_geo_db_zipcode" VALUES(29037,64633,-6,'Carrollton, Missouri 64633',21203,25878);
INSERT INTO "django_geo_db_zipcode" VALUES(29038,64635,-6,'Chula, Missouri 64635',21204,25879);
INSERT INTO "django_geo_db_zipcode" VALUES(29039,64636,-6,'Coffey, Missouri 64636',21205,25880);
INSERT INTO "django_geo_db_zipcode" VALUES(29040,64637,-6,'Cowgill, Missouri 64637',21206,25881);
INSERT INTO "django_geo_db_zipcode" VALUES(29041,64638,-6,'Dawn, Missouri 64638',21207,25882);
INSERT INTO "django_geo_db_zipcode" VALUES(29042,64639,-6,'De Witt, Missouri 64639',21208,25883);
INSERT INTO "django_geo_db_zipcode" VALUES(29043,64640,-6,'Gallatin, Missouri 64640',21209,25884);
INSERT INTO "django_geo_db_zipcode" VALUES(29044,64641,-6,'Galt, Missouri 64641',21210,25885);
INSERT INTO "django_geo_db_zipcode" VALUES(29045,64642,-6,'Gilman City, Missouri 64642',21211,25886);
INSERT INTO "django_geo_db_zipcode" VALUES(29046,64643,-6,'Hale, Missouri 64643',21212,25887);
INSERT INTO "django_geo_db_zipcode" VALUES(29047,64644,-6,'Hamilton, Missouri 64644',21213,25888);
INSERT INTO "django_geo_db_zipcode" VALUES(29048,64645,-6,'Harris, Missouri 64645',21214,25889);
INSERT INTO "django_geo_db_zipcode" VALUES(29049,64646,-6,'Humphreys, Missouri 64646',21215,25890);
INSERT INTO "django_geo_db_zipcode" VALUES(29050,64647,-6,'Jameson, Missouri 64647',21216,25891);
INSERT INTO "django_geo_db_zipcode" VALUES(29051,64648,-6,'Jamesport, Missouri 64648',21217,25892);
INSERT INTO "django_geo_db_zipcode" VALUES(29052,64649,-6,'Kidder, Missouri 64649',21218,25893);
INSERT INTO "django_geo_db_zipcode" VALUES(29053,64650,-6,'Kingston, Missouri 64650',21219,25894);
INSERT INTO "django_geo_db_zipcode" VALUES(29054,64651,-6,'Laclede, Missouri 64651',21220,25895);
INSERT INTO "django_geo_db_zipcode" VALUES(29055,64652,-6,'Laredo, Missouri 64652',21221,25896);
INSERT INTO "django_geo_db_zipcode" VALUES(29056,64653,-6,'Linneus, Missouri 64653',21222,25897);
INSERT INTO "django_geo_db_zipcode" VALUES(29057,64654,-6,'Lock Springs, Missouri 64654',21223,25898);
INSERT INTO "django_geo_db_zipcode" VALUES(29058,64655,-6,'Lucerne, Missouri 64655',21224,25899);
INSERT INTO "django_geo_db_zipcode" VALUES(29059,64656,-6,'Ludlow, Missouri 64656',21225,25900);
INSERT INTO "django_geo_db_zipcode" VALUES(29060,64657,-6,'McFall, Missouri 64657',21226,25901);
INSERT INTO "django_geo_db_zipcode" VALUES(29061,64658,-6,'Marceline, Missouri 64658',21227,25902);
INSERT INTO "django_geo_db_zipcode" VALUES(29062,64659,-6,'Meadville, Missouri 64659',21228,25903);
INSERT INTO "django_geo_db_zipcode" VALUES(29063,64660,-6,'Mendon, Missouri 64660',21229,25904);
INSERT INTO "django_geo_db_zipcode" VALUES(29064,64661,-6,'Mercer, Missouri 64661',21230,25905);
INSERT INTO "django_geo_db_zipcode" VALUES(29065,64664,-6,'Mooresville, Missouri 64664',21231,25906);
INSERT INTO "django_geo_db_zipcode" VALUES(29066,64665,-6,'Mount Moriah, Missouri 64665',21232,25907);
INSERT INTO "django_geo_db_zipcode" VALUES(29067,64667,-6,'Newtown, Missouri 64667',21233,25908);
INSERT INTO "django_geo_db_zipcode" VALUES(29068,64668,-6,'Norborne, Missouri 64668',21234,25909);
INSERT INTO "django_geo_db_zipcode" VALUES(29069,64670,-6,'Pattonsburg, Missouri 64670',21235,25910);
INSERT INTO "django_geo_db_zipcode" VALUES(29070,64671,-6,'Polo, Missouri 64671',21236,25911);
INSERT INTO "django_geo_db_zipcode" VALUES(29071,64672,-6,'Powersville, Missouri 64672',21237,25912);
INSERT INTO "django_geo_db_zipcode" VALUES(29072,64673,-6,'Princeton, Missouri 64673',21238,25913);
INSERT INTO "django_geo_db_zipcode" VALUES(29073,64674,-6,'Purdin, Missouri 64674',21239,25914);
INSERT INTO "django_geo_db_zipcode" VALUES(29074,64676,-6,'Rothville, Missouri 64676',21240,25915);
INSERT INTO "django_geo_db_zipcode" VALUES(29075,64677,-6,'Purdin, Missouri 64677',21239,25916);
INSERT INTO "django_geo_db_zipcode" VALUES(29076,64679,-6,'Spickard, Missouri 64679',21241,25917);
INSERT INTO "django_geo_db_zipcode" VALUES(29077,64680,-6,'Stet, Missouri 64680',21242,25918);
INSERT INTO "django_geo_db_zipcode" VALUES(29078,64681,-6,'Sumner, Missouri 64681',21243,25919);
INSERT INTO "django_geo_db_zipcode" VALUES(29079,64682,-6,'Tina, Missouri 64682',21244,25920);
INSERT INTO "django_geo_db_zipcode" VALUES(29080,64683,-6,'Trenton, Missouri 64683',21245,25921);
INSERT INTO "django_geo_db_zipcode" VALUES(29081,64686,-6,'Utica, Missouri 64686',21246,25922);
INSERT INTO "django_geo_db_zipcode" VALUES(29082,64687,-6,'Wakenda, Missouri 64687',21247,25923);
INSERT INTO "django_geo_db_zipcode" VALUES(29083,64688,-6,'Wheeling, Missouri 64688',21248,25924);
INSERT INTO "django_geo_db_zipcode" VALUES(29084,64689,-6,'Winston, Missouri 64689',21249,25925);
INSERT INTO "django_geo_db_zipcode" VALUES(29085,64701,-6,'Harrisonville, Missouri 64701',21250,25926);
INSERT INTO "django_geo_db_zipcode" VALUES(29086,64720,-6,'Adrian, Missouri 64720',21251,25927);
INSERT INTO "django_geo_db_zipcode" VALUES(29087,64722,-6,'Amoret, Missouri 64722',21252,25928);
INSERT INTO "django_geo_db_zipcode" VALUES(29088,64723,-6,'Amsterdam, Missouri 64723',21253,25929);
INSERT INTO "django_geo_db_zipcode" VALUES(29089,64724,-6,'Appleton City, Missouri 64724',21254,25930);
INSERT INTO "django_geo_db_zipcode" VALUES(29090,64725,-6,'Archie, Missouri 64725',21255,25931);
INSERT INTO "django_geo_db_zipcode" VALUES(29091,64726,-6,'Blairstown, Missouri 64726',21256,25932);
INSERT INTO "django_geo_db_zipcode" VALUES(29092,64728,-6,'Bronaugh, Missouri 64728',21257,25933);
INSERT INTO "django_geo_db_zipcode" VALUES(29093,64730,-6,'Butler, Missouri 64730',21258,25934);
INSERT INTO "django_geo_db_zipcode" VALUES(29094,64733,-6,'Chilhowee, Missouri 64733',21259,25935);
INSERT INTO "django_geo_db_zipcode" VALUES(29095,64734,-6,'Cleveland, Missouri 64734',21260,25936);
INSERT INTO "django_geo_db_zipcode" VALUES(29096,64735,-6,'Clinton, Missouri 64735',21261,25937);
INSERT INTO "django_geo_db_zipcode" VALUES(29097,64738,-6,'Collins, Missouri 64738',21262,25938);
INSERT INTO "django_geo_db_zipcode" VALUES(29098,64739,-6,'Creighton, Missouri 64739',21263,25939);
INSERT INTO "django_geo_db_zipcode" VALUES(29099,64740,-6,'Deepwater, Missouri 64740',21264,25940);
INSERT INTO "django_geo_db_zipcode" VALUES(29100,64741,-6,'Deerfield, Missouri 64741',21265,25941);
INSERT INTO "django_geo_db_zipcode" VALUES(29101,64742,-6,'Drexel, Missouri 64742',21266,25942);
INSERT INTO "django_geo_db_zipcode" VALUES(29102,64743,-6,'East Lynne, Missouri 64743',21267,25943);
INSERT INTO "django_geo_db_zipcode" VALUES(29103,64744,-6,'El Dorado Springs, Missouri 64744',21268,25944);
INSERT INTO "django_geo_db_zipcode" VALUES(29104,64745,-6,'Foster, Missouri 64745',21269,25945);
INSERT INTO "django_geo_db_zipcode" VALUES(29105,64746,-6,'Freeman, Missouri 64746',21270,25946);
INSERT INTO "django_geo_db_zipcode" VALUES(29106,64747,-6,'Garden City, Missouri 64747',21271,25947);
INSERT INTO "django_geo_db_zipcode" VALUES(29107,64748,-6,'Golden City, Missouri 64748',21272,25948);
INSERT INTO "django_geo_db_zipcode" VALUES(29108,64750,-6,'Harwood, Missouri 64750',21273,25949);
INSERT INTO "django_geo_db_zipcode" VALUES(29109,64751,-6,'Horton, Missouri 64751',21274,25950);
INSERT INTO "django_geo_db_zipcode" VALUES(29110,64752,-6,'Hume, Missouri 64752',21275,25951);
INSERT INTO "django_geo_db_zipcode" VALUES(29111,64755,-6,'Jasper, Missouri 64755',21276,25952);
INSERT INTO "django_geo_db_zipcode" VALUES(29112,64756,-6,'Jerico Springs, Missouri 64756',21277,25953);
INSERT INTO "django_geo_db_zipcode" VALUES(29113,64759,-6,'Lamar, Missouri 64759',21278,25954);
INSERT INTO "django_geo_db_zipcode" VALUES(29114,64761,-6,'Leeton, Missouri 64761',21279,25955);
INSERT INTO "django_geo_db_zipcode" VALUES(29115,64762,-6,'Liberal, Missouri 64762',21280,25956);
INSERT INTO "django_geo_db_zipcode" VALUES(29116,64763,-6,'Lowry City, Missouri 64763',21281,25957);
INSERT INTO "django_geo_db_zipcode" VALUES(29117,64765,-6,'Metz, Missouri 64765',21282,25958);
INSERT INTO "django_geo_db_zipcode" VALUES(29118,64766,-6,'Milford, Missouri 64766',21283,25959);
INSERT INTO "django_geo_db_zipcode" VALUES(29119,64767,-6,'Milo, Missouri 64767',21284,25960);
INSERT INTO "django_geo_db_zipcode" VALUES(29120,64769,-6,'Mindenmines, Missouri 64769',21285,25961);
INSERT INTO "django_geo_db_zipcode" VALUES(29121,64770,-6,'Montrose, Missouri 64770',21286,25962);
INSERT INTO "django_geo_db_zipcode" VALUES(29122,64771,-6,'Moundville, Missouri 64771',21287,25963);
INSERT INTO "django_geo_db_zipcode" VALUES(29123,64772,-6,'Nevada, Missouri 64772',21288,25964);
INSERT INTO "django_geo_db_zipcode" VALUES(29124,64776,-6,'Osceola, Missouri 64776',21289,25965);
INSERT INTO "django_geo_db_zipcode" VALUES(29125,64777,-6,'Passaic, Missouri 64777',21290,25966);
INSERT INTO "django_geo_db_zipcode" VALUES(29126,64778,-6,'Richards, Missouri 64778',21291,25967);
INSERT INTO "django_geo_db_zipcode" VALUES(29127,64779,-6,'Rich Hill, Missouri 64779',21292,25968);
INSERT INTO "django_geo_db_zipcode" VALUES(29128,64780,-6,'Rockville, Missouri 64780',21293,25969);
INSERT INTO "django_geo_db_zipcode" VALUES(29129,64781,-6,'Roscoe, Missouri 64781',21294,25970);
INSERT INTO "django_geo_db_zipcode" VALUES(29130,64783,-6,'Schell City, Missouri 64783',21295,25971);
INSERT INTO "django_geo_db_zipcode" VALUES(29131,64784,-6,'Sheldon, Missouri 64784',21296,25972);
INSERT INTO "django_geo_db_zipcode" VALUES(29132,64788,-6,'Urich, Missouri 64788',21297,25973);
INSERT INTO "django_geo_db_zipcode" VALUES(29133,64789,-6,'Vista, Missouri 64789',21298,25974);
INSERT INTO "django_geo_db_zipcode" VALUES(29134,64790,-6,'Walker, Missouri 64790',21299,25975);
INSERT INTO "django_geo_db_zipcode" VALUES(29135,64801,-6,'Joplin, Missouri 64801',21300,25976);
INSERT INTO "django_geo_db_zipcode" VALUES(29136,64802,-6,'Joplin, Missouri 64802',21300,25977);
INSERT INTO "django_geo_db_zipcode" VALUES(29137,64803,-6,'Joplin, Missouri 64803',21300,25977);
INSERT INTO "django_geo_db_zipcode" VALUES(29138,64804,-6,'Joplin, Missouri 64804',21300,25978);
INSERT INTO "django_geo_db_zipcode" VALUES(29139,64810,-6,'Goodman, Missouri 64810',21301,25979);
INSERT INTO "django_geo_db_zipcode" VALUES(29140,64830,-6,'Alba, Missouri 64830',21302,25980);
INSERT INTO "django_geo_db_zipcode" VALUES(29141,64831,-6,'Anderson, Missouri 64831',21303,25981);
INSERT INTO "django_geo_db_zipcode" VALUES(29142,64832,-6,'Asbury, Missouri 64832',21304,25982);
INSERT INTO "django_geo_db_zipcode" VALUES(29143,64833,-6,'Avilla, Missouri 64833',21305,25983);
INSERT INTO "django_geo_db_zipcode" VALUES(29144,64834,-6,'Carl Junction, Missouri 64834',21306,25984);
INSERT INTO "django_geo_db_zipcode" VALUES(29145,64835,-6,'Carterville, Missouri 64835',21307,25985);
INSERT INTO "django_geo_db_zipcode" VALUES(29146,64836,-6,'Carthage, Missouri 64836',21308,25986);
INSERT INTO "django_geo_db_zipcode" VALUES(29147,64840,-6,'Diamond, Missouri 64840',21309,25987);
INSERT INTO "django_geo_db_zipcode" VALUES(29148,64841,-6,'Duenweg, Missouri 64841',21310,25988);
INSERT INTO "django_geo_db_zipcode" VALUES(29149,64842,-6,'Fairview, Missouri 64842',21194,25989);
INSERT INTO "django_geo_db_zipcode" VALUES(29150,64843,-6,'Goodman, Missouri 64843',21301,25990);
INSERT INTO "django_geo_db_zipcode" VALUES(29151,64844,-6,'Granby, Missouri 64844',21311,25991);
INSERT INTO "django_geo_db_zipcode" VALUES(29152,64847,-6,'Lanagan, Missouri 64847',21312,25992);
INSERT INTO "django_geo_db_zipcode" VALUES(29153,64848,-6,'La Russell, Missouri 64848',21313,25993);
INSERT INTO "django_geo_db_zipcode" VALUES(29154,64849,-6,'Neck City, Missouri 64849',21314,25994);
INSERT INTO "django_geo_db_zipcode" VALUES(29155,64850,-6,'Neosho, Missouri 64850',21315,25995);
INSERT INTO "django_geo_db_zipcode" VALUES(29156,64853,-6,'Newtonia, Missouri 64853',21316,25996);
INSERT INTO "django_geo_db_zipcode" VALUES(29157,64854,-6,'Noel, Missouri 64854',21317,25997);
INSERT INTO "django_geo_db_zipcode" VALUES(29158,64855,-6,'Oronogo, Missouri 64855',21318,25998);
INSERT INTO "django_geo_db_zipcode" VALUES(29159,64856,-6,'Pineville, Missouri 64856',21319,25999);
INSERT INTO "django_geo_db_zipcode" VALUES(29160,64857,-6,'Purcell, Missouri 64857',21320,26000);
INSERT INTO "django_geo_db_zipcode" VALUES(29161,64858,-6,'Racine, Missouri 64858',21321,26001);
INSERT INTO "django_geo_db_zipcode" VALUES(29162,64859,-6,'Reeds, Missouri 64859',21322,26002);
INSERT INTO "django_geo_db_zipcode" VALUES(29163,64861,-6,'Rocky Comfort, Missouri 64861',21323,26003);
INSERT INTO "django_geo_db_zipcode" VALUES(29164,64862,-6,'Sarcoxie, Missouri 64862',21324,26004);
INSERT INTO "django_geo_db_zipcode" VALUES(29165,64863,-6,'South West City, Missouri 64863',21325,26005);
INSERT INTO "django_geo_db_zipcode" VALUES(29166,64864,-6,'Saginaw, Missouri 64864',21326,26006);
INSERT INTO "django_geo_db_zipcode" VALUES(29167,64865,-6,'Seneca, Missouri 64865',21327,26007);
INSERT INTO "django_geo_db_zipcode" VALUES(29168,64866,-6,'Stark City, Missouri 64866',21328,26008);
INSERT INTO "django_geo_db_zipcode" VALUES(29169,64867,-6,'Stella, Missouri 64867',21329,26009);
INSERT INTO "django_geo_db_zipcode" VALUES(29170,64868,-6,'Tiff City, Missouri 64868',21330,26010);
INSERT INTO "django_geo_db_zipcode" VALUES(29171,64869,-6,'Waco, Missouri 64869',21331,25977);
INSERT INTO "django_geo_db_zipcode" VALUES(29172,64870,-6,'Webb City, Missouri 64870',21332,26011);
INSERT INTO "django_geo_db_zipcode" VALUES(29173,64873,-6,'Wentworth, Missouri 64873',21333,26012);
INSERT INTO "django_geo_db_zipcode" VALUES(29174,64874,-6,'Wheaton, Missouri 64874',21334,26013);
INSERT INTO "django_geo_db_zipcode" VALUES(29175,64930,-6,'Washington, Missouri 64930',20775,26014);
INSERT INTO "django_geo_db_zipcode" VALUES(29176,64944,-6,'Kansas City, Missouri 64944',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(29177,64999,-6,'Kansas City, Missouri 64999',21115,25747);
INSERT INTO "django_geo_db_zipcode" VALUES(29178,65001,-6,'Argyle, Missouri 65001',21335,26015);
INSERT INTO "django_geo_db_zipcode" VALUES(29179,65010,-6,'Ashland, Missouri 65010',21336,26016);
INSERT INTO "django_geo_db_zipcode" VALUES(29180,65011,-6,'Barnett, Missouri 65011',21337,26017);
INSERT INTO "django_geo_db_zipcode" VALUES(29181,65013,-6,'Belle, Missouri 65013',21338,26018);
INSERT INTO "django_geo_db_zipcode" VALUES(29182,65014,-6,'Bland, Missouri 65014',21339,26019);
INSERT INTO "django_geo_db_zipcode" VALUES(29183,65016,-6,'Bonnots Mill, Missouri 65016',21340,26020);
INSERT INTO "django_geo_db_zipcode" VALUES(29184,65017,-6,'Brumley, Missouri 65017',21341,26021);
INSERT INTO "django_geo_db_zipcode" VALUES(29185,65018,-6,'California, Missouri 65018',21342,26022);
INSERT INTO "django_geo_db_zipcode" VALUES(29186,65020,-6,'Camdenton, Missouri 65020',21343,26023);
INSERT INTO "django_geo_db_zipcode" VALUES(29187,65022,-6,'Cedar City, Missouri 65022',21344,26024);
INSERT INTO "django_geo_db_zipcode" VALUES(29188,65023,-6,'Centertown, Missouri 65023',21345,26025);
INSERT INTO "django_geo_db_zipcode" VALUES(29189,65024,-6,'Chamois, Missouri 65024',21346,26026);
INSERT INTO "django_geo_db_zipcode" VALUES(29190,65025,-6,'Clarksburg, Missouri 65025',21347,26027);
INSERT INTO "django_geo_db_zipcode" VALUES(29191,65026,-6,'Eldon, Missouri 65026',21348,26028);
INSERT INTO "django_geo_db_zipcode" VALUES(29192,65031,-6,'Etterville, Missouri 65031',21349,26029);
INSERT INTO "django_geo_db_zipcode" VALUES(29193,65032,-6,'Eugene, Missouri 65032',21350,26030);
INSERT INTO "django_geo_db_zipcode" VALUES(29194,65034,-6,'Fortuna, Missouri 65034',21351,26031);
INSERT INTO "django_geo_db_zipcode" VALUES(29195,65035,-6,'Freeburg, Missouri 65035',21352,26032);
INSERT INTO "django_geo_db_zipcode" VALUES(29196,65036,-6,'Gasconade, Missouri 65036',21353,26033);
INSERT INTO "django_geo_db_zipcode" VALUES(29197,65037,-6,'Gravois Mills, Missouri 65037',21354,26034);
INSERT INTO "django_geo_db_zipcode" VALUES(29198,65038,-6,'Laurie, Missouri 65038',21355,26035);
INSERT INTO "django_geo_db_zipcode" VALUES(29199,65039,-6,'Hartsburg, Missouri 65039',21356,26036);
INSERT INTO "django_geo_db_zipcode" VALUES(29200,65040,-6,'Henley, Missouri 65040',21357,26037);
INSERT INTO "django_geo_db_zipcode" VALUES(29201,65041,-6,'Hermann, Missouri 65041',21358,26038);
INSERT INTO "django_geo_db_zipcode" VALUES(29202,65042,-6,'High Point, Missouri 65042',21359,26039);
INSERT INTO "django_geo_db_zipcode" VALUES(29203,65043,-6,'Holts Summit, Missouri 65043',21360,26040);
INSERT INTO "django_geo_db_zipcode" VALUES(29204,65046,-6,'Jamestown, Missouri 65046',21361,26041);
INSERT INTO "django_geo_db_zipcode" VALUES(29205,65047,-6,'Kaiser, Missouri 65047',21362,26042);
INSERT INTO "django_geo_db_zipcode" VALUES(29206,65048,-6,'Koeltztown, Missouri 65048',21363,26043);
INSERT INTO "django_geo_db_zipcode" VALUES(29207,65049,-6,'Lake Ozark, Missouri 65049',21364,26044);
INSERT INTO "django_geo_db_zipcode" VALUES(29208,65050,-6,'Latham, Missouri 65050',21365,26045);
INSERT INTO "django_geo_db_zipcode" VALUES(29209,65051,-6,'Linn, Missouri 65051',21366,26046);
INSERT INTO "django_geo_db_zipcode" VALUES(29210,65052,-6,'Linn Creek, Missouri 65052',21367,26047);
INSERT INTO "django_geo_db_zipcode" VALUES(29211,65053,-6,'Lohman, Missouri 65053',21368,26048);
INSERT INTO "django_geo_db_zipcode" VALUES(29212,65054,-6,'Loose Creek, Missouri 65054',21369,26049);
INSERT INTO "django_geo_db_zipcode" VALUES(29213,65055,-6,'McGirk, Missouri 65055',21370,26039);
INSERT INTO "django_geo_db_zipcode" VALUES(29214,65058,-6,'Meta, Missouri 65058',21371,26050);
INSERT INTO "django_geo_db_zipcode" VALUES(29215,65059,-6,'Mokane, Missouri 65059',21372,26051);
INSERT INTO "django_geo_db_zipcode" VALUES(29216,65061,-6,'Morrison, Missouri 65061',21373,26052);
INSERT INTO "django_geo_db_zipcode" VALUES(29217,65062,-6,'Mount Sterling, Missouri 65062',21374,26053);
INSERT INTO "django_geo_db_zipcode" VALUES(29218,65063,-6,'New Bloomfield, Missouri 65063',21375,26054);
INSERT INTO "django_geo_db_zipcode" VALUES(29219,65064,-6,'Olean, Missouri 65064',21376,26055);
INSERT INTO "django_geo_db_zipcode" VALUES(29220,65065,-6,'Osage Beach, Missouri 65065',21377,26056);
INSERT INTO "django_geo_db_zipcode" VALUES(29221,65066,-6,'Owensville, Missouri 65066',21378,26057);
INSERT INTO "django_geo_db_zipcode" VALUES(29222,65067,-6,'Portland, Missouri 65067',21379,26058);
INSERT INTO "django_geo_db_zipcode" VALUES(29223,65068,-6,'Prairie Home, Missouri 65068',21380,26059);
INSERT INTO "django_geo_db_zipcode" VALUES(29224,65069,-6,'Rhineland, Missouri 65069',21381,26060);
INSERT INTO "django_geo_db_zipcode" VALUES(29225,65072,-6,'Rocky Mount, Missouri 65072',21382,26061);
INSERT INTO "django_geo_db_zipcode" VALUES(29226,65074,-6,'Russellville, Missouri 65074',21383,26062);
INSERT INTO "django_geo_db_zipcode" VALUES(29227,65075,-6,'Saint Elizabeth, Missouri 65075',21384,26063);
INSERT INTO "django_geo_db_zipcode" VALUES(29228,65076,-6,'Saint Thomas, Missouri 65076',21385,26064);
INSERT INTO "django_geo_db_zipcode" VALUES(29229,65077,-6,'Steedman, Missouri 65077',21386,26065);
INSERT INTO "django_geo_db_zipcode" VALUES(29230,65078,-6,'Stover, Missouri 65078',21387,26066);
INSERT INTO "django_geo_db_zipcode" VALUES(29231,65079,-6,'Sunrise Beach, Missouri 65079',21388,26067);
INSERT INTO "django_geo_db_zipcode" VALUES(29232,65080,-6,'Tebbetts, Missouri 65080',21389,26068);
INSERT INTO "django_geo_db_zipcode" VALUES(29233,65081,-6,'Tipton, Missouri 65081',21390,26069);
INSERT INTO "django_geo_db_zipcode" VALUES(29234,65082,-6,'Tuscumbia, Missouri 65082',21391,26070);
INSERT INTO "django_geo_db_zipcode" VALUES(29235,65083,-6,'Ulman, Missouri 65083',21392,26071);
INSERT INTO "django_geo_db_zipcode" VALUES(29236,65084,-6,'Versailles, Missouri 65084',21393,26072);
INSERT INTO "django_geo_db_zipcode" VALUES(29237,65085,-6,'Westphalia, Missouri 65085',21394,26073);
INSERT INTO "django_geo_db_zipcode" VALUES(29238,65101,-6,'Jefferson City, Missouri 65101',21395,26074);
INSERT INTO "django_geo_db_zipcode" VALUES(29239,65102,-6,'Jefferson City, Missouri 65102',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29240,65103,-6,'Jefferson City, Missouri 65103',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29241,65104,-6,'Jefferson City, Missouri 65104',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29242,65105,-6,'Jefferson City, Missouri 65105',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29243,65106,-6,'Jefferson City, Missouri 65106',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29244,65107,-6,'Jefferson City, Missouri 65107',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29245,65108,-6,'Jefferson City, Missouri 65108',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29246,65109,-6,'Jefferson City, Missouri 65109',21395,26076);
INSERT INTO "django_geo_db_zipcode" VALUES(29247,65110,-6,'Jefferson City, Missouri 65110',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29248,65111,-6,'Jefferson City, Missouri 65111',21395,26075);
INSERT INTO "django_geo_db_zipcode" VALUES(29249,65201,-6,'Columbia, Missouri 65201',21396,26077);
INSERT INTO "django_geo_db_zipcode" VALUES(29250,65202,-6,'Columbia, Missouri 65202',21396,26078);
INSERT INTO "django_geo_db_zipcode" VALUES(29251,65203,-6,'Columbia, Missouri 65203',21396,26079);
INSERT INTO "django_geo_db_zipcode" VALUES(29252,65205,-6,'Columbia, Missouri 65205',21396,26080);
INSERT INTO "django_geo_db_zipcode" VALUES(29253,65211,-6,'Columbia, Missouri 65211',21396,26081);
INSERT INTO "django_geo_db_zipcode" VALUES(29254,65212,-6,'Columbia, Missouri 65212',21396,26082);
INSERT INTO "django_geo_db_zipcode" VALUES(29255,65215,-6,'Columbia, Missouri 65215',21396,26083);
INSERT INTO "django_geo_db_zipcode" VALUES(29256,65216,-6,'Columbia, Missouri 65216',21396,26081);
INSERT INTO "django_geo_db_zipcode" VALUES(29257,65217,-6,'Columbia, Missouri 65217',21396,26081);
INSERT INTO "django_geo_db_zipcode" VALUES(29258,65218,-6,'Columbia, Missouri 65218',21396,26081);
INSERT INTO "django_geo_db_zipcode" VALUES(29259,65230,-6,'Armstrong, Missouri 65230',21397,26084);
INSERT INTO "django_geo_db_zipcode" VALUES(29260,65231,-6,'Auxvasse, Missouri 65231',21398,26085);
INSERT INTO "django_geo_db_zipcode" VALUES(29261,65232,-6,'Benton City, Missouri 65232',21399,26086);
INSERT INTO "django_geo_db_zipcode" VALUES(29262,65233,-6,'Boonville, Missouri 65233',21400,26087);
INSERT INTO "django_geo_db_zipcode" VALUES(29263,65236,-6,'Brunswick, Missouri 65236',21401,26088);
INSERT INTO "django_geo_db_zipcode" VALUES(29264,65237,-6,'Bunceton, Missouri 65237',21402,26089);
INSERT INTO "django_geo_db_zipcode" VALUES(29265,65239,-6,'Cairo, Missouri 65239',21403,26090);
INSERT INTO "django_geo_db_zipcode" VALUES(29266,65240,-6,'Centralia, Missouri 65240',21404,26091);
INSERT INTO "django_geo_db_zipcode" VALUES(29267,65243,-6,'Clark, Missouri 65243',21405,26092);
INSERT INTO "django_geo_db_zipcode" VALUES(29268,65244,-6,'Clifton Hill, Missouri 65244',21406,26093);
INSERT INTO "django_geo_db_zipcode" VALUES(29269,65246,-6,'Dalton, Missouri 65246',21407,26094);
INSERT INTO "django_geo_db_zipcode" VALUES(29270,65247,-6,'Excello, Missouri 65247',21408,26095);
INSERT INTO "django_geo_db_zipcode" VALUES(29271,65248,-6,'Fayette, Missouri 65248',21409,26096);
INSERT INTO "django_geo_db_zipcode" VALUES(29272,65250,-6,'Franklin, Missouri 65250',21410,26097);
INSERT INTO "django_geo_db_zipcode" VALUES(29273,65251,-6,'Fulton, Missouri 65251',21411,26098);
INSERT INTO "django_geo_db_zipcode" VALUES(29274,65254,-6,'Glasgow, Missouri 65254',21412,26099);
INSERT INTO "django_geo_db_zipcode" VALUES(29275,65255,-6,'Hallsville, Missouri 65255',21413,26100);
INSERT INTO "django_geo_db_zipcode" VALUES(29276,65256,-6,'Harrisburg, Missouri 65256',21414,26101);
INSERT INTO "django_geo_db_zipcode" VALUES(29277,65257,-6,'Higbee, Missouri 65257',21415,26102);
INSERT INTO "django_geo_db_zipcode" VALUES(29278,65258,-6,'Holliday, Missouri 65258',21416,26103);
INSERT INTO "django_geo_db_zipcode" VALUES(29279,65259,-6,'Huntsville, Missouri 65259',21417,26104);
INSERT INTO "django_geo_db_zipcode" VALUES(29280,65260,-6,'Jacksonville, Missouri 65260',21418,26105);
INSERT INTO "django_geo_db_zipcode" VALUES(29281,65261,-6,'Keytesville, Missouri 65261',21419,26106);
INSERT INTO "django_geo_db_zipcode" VALUES(29282,65262,-6,'Kingdom City, Missouri 65262',21420,26107);
INSERT INTO "django_geo_db_zipcode" VALUES(29283,65263,-6,'Madison, Missouri 65263',21421,26108);
INSERT INTO "django_geo_db_zipcode" VALUES(29284,65264,-6,'Martinsburg, Missouri 65264',21422,26109);
INSERT INTO "django_geo_db_zipcode" VALUES(29285,65265,-6,'Mexico, Missouri 65265',21423,26110);
INSERT INTO "django_geo_db_zipcode" VALUES(29286,65270,-6,'Moberly, Missouri 65270',21424,26111);
INSERT INTO "django_geo_db_zipcode" VALUES(29287,65274,-6,'New Franklin, Missouri 65274',21425,26112);
INSERT INTO "django_geo_db_zipcode" VALUES(29288,65275,-6,'Paris, Missouri 65275',21426,26113);
INSERT INTO "django_geo_db_zipcode" VALUES(29289,65276,-6,'Pilot Grove, Missouri 65276',21427,26114);
INSERT INTO "django_geo_db_zipcode" VALUES(29290,65278,-6,'Renick, Missouri 65278',21428,26115);
INSERT INTO "django_geo_db_zipcode" VALUES(29291,65279,-6,'Rocheport, Missouri 65279',21429,26116);
INSERT INTO "django_geo_db_zipcode" VALUES(29292,65280,-6,'Rush Hill, Missouri 65280',21430,26117);
INSERT INTO "django_geo_db_zipcode" VALUES(29293,65281,-6,'Salisbury, Missouri 65281',21431,26118);
INSERT INTO "django_geo_db_zipcode" VALUES(29294,65282,-6,'Santa Fe, Missouri 65282',21432,26119);
INSERT INTO "django_geo_db_zipcode" VALUES(29295,65283,-6,'Stoutsville, Missouri 65283',21433,26120);
INSERT INTO "django_geo_db_zipcode" VALUES(29296,65284,-6,'Sturgeon, Missouri 65284',21434,26121);
INSERT INTO "django_geo_db_zipcode" VALUES(29297,65285,-6,'Thompson, Missouri 65285',21435,26122);
INSERT INTO "django_geo_db_zipcode" VALUES(29298,65286,-6,'Triplett, Missouri 65286',21436,26123);
INSERT INTO "django_geo_db_zipcode" VALUES(29299,65287,-6,'Wooldridge, Missouri 65287',21437,26124);
INSERT INTO "django_geo_db_zipcode" VALUES(29300,65299,-6,'Mid Missouri, Missouri 65299',21438,26081);
INSERT INTO "django_geo_db_zipcode" VALUES(29301,65301,-6,'Sedalia, Missouri 65301',21439,26125);
INSERT INTO "django_geo_db_zipcode" VALUES(29302,65302,-6,'Sedalia, Missouri 65302',21439,26126);
INSERT INTO "django_geo_db_zipcode" VALUES(29303,65305,-6,'Whiteman Air Force Base, Missouri 65305',21440,26127);
INSERT INTO "django_geo_db_zipcode" VALUES(29304,65320,-6,'Arrow Rock, Missouri 65320',21441,26128);
INSERT INTO "django_geo_db_zipcode" VALUES(29305,65321,-6,'Blackburn, Missouri 65321',21442,26129);
INSERT INTO "django_geo_db_zipcode" VALUES(29306,65322,-6,'Blackwater, Missouri 65322',21443,26130);
INSERT INTO "django_geo_db_zipcode" VALUES(29307,65323,-6,'Calhoun, Missouri 65323',21444,26131);
INSERT INTO "django_geo_db_zipcode" VALUES(29308,65324,-6,'Climax Springs, Missouri 65324',21445,26132);
INSERT INTO "django_geo_db_zipcode" VALUES(29309,65325,-6,'Cole Camp, Missouri 65325',21446,26133);
INSERT INTO "django_geo_db_zipcode" VALUES(29310,65326,-6,'Edwards, Missouri 65326',21447,26134);
INSERT INTO "django_geo_db_zipcode" VALUES(29311,65327,-6,'Emma, Missouri 65327',21448,26135);
INSERT INTO "django_geo_db_zipcode" VALUES(29312,65329,-6,'Florence, Missouri 65329',21449,26136);
INSERT INTO "django_geo_db_zipcode" VALUES(29313,65330,-6,'Gilliam, Missouri 65330',21450,26137);
INSERT INTO "django_geo_db_zipcode" VALUES(29314,65332,-6,'Green Ridge, Missouri 65332',21451,26138);
INSERT INTO "django_geo_db_zipcode" VALUES(29315,65333,-6,'Houstonia, Missouri 65333',21452,26139);
INSERT INTO "django_geo_db_zipcode" VALUES(29316,65334,-6,'Hughesville, Missouri 65334',21453,26140);
INSERT INTO "django_geo_db_zipcode" VALUES(29317,65335,-6,'Ionia, Missouri 65335',21454,26141);
INSERT INTO "django_geo_db_zipcode" VALUES(29318,65336,-6,'Knob Noster, Missouri 65336',21455,26142);
INSERT INTO "django_geo_db_zipcode" VALUES(29319,65337,-6,'La Monte, Missouri 65337',21456,26143);
INSERT INTO "django_geo_db_zipcode" VALUES(29320,65338,-6,'Lincoln, Missouri 65338',21457,26144);
INSERT INTO "django_geo_db_zipcode" VALUES(29321,65339,-6,'Malta Bend, Missouri 65339',21458,26145);
INSERT INTO "django_geo_db_zipcode" VALUES(29322,65340,-6,'Marshall, Missouri 65340',21459,26146);
INSERT INTO "django_geo_db_zipcode" VALUES(29323,65344,-6,'Miami, Missouri 65344',21460,26147);
INSERT INTO "django_geo_db_zipcode" VALUES(29324,65345,-6,'Mora, Missouri 65345',21461,26148);
INSERT INTO "django_geo_db_zipcode" VALUES(29325,65347,-6,'Nelson, Missouri 65347',21462,26149);
INSERT INTO "django_geo_db_zipcode" VALUES(29326,65348,-6,'Otterville, Missouri 65348',21463,26150);
INSERT INTO "django_geo_db_zipcode" VALUES(29327,65349,-6,'Slater, Missouri 65349',21464,26151);
INSERT INTO "django_geo_db_zipcode" VALUES(29328,65350,-6,'Smithton, Missouri 65350',21465,26152);
INSERT INTO "django_geo_db_zipcode" VALUES(29329,65351,-6,'Sweet Springs, Missouri 65351',21466,26153);
INSERT INTO "django_geo_db_zipcode" VALUES(29330,65354,-6,'Syracuse, Missouri 65354',21467,26154);
INSERT INTO "django_geo_db_zipcode" VALUES(29331,65355,-6,'Warsaw, Missouri 65355',21468,26155);
INSERT INTO "django_geo_db_zipcode" VALUES(29332,65360,-6,'Windsor, Missouri 65360',21469,26156);
INSERT INTO "django_geo_db_zipcode" VALUES(29333,65401,-6,'Rolla, Missouri 65401',21470,26157);
INSERT INTO "django_geo_db_zipcode" VALUES(29334,65402,-6,'Rolla, Missouri 65402',21470,26158);
INSERT INTO "django_geo_db_zipcode" VALUES(29335,65409,-6,'Rolla, Missouri 65409',21470,26159);
INSERT INTO "django_geo_db_zipcode" VALUES(29336,65432,-6,'Cuba, Missouri 65432',21471,26160);
INSERT INTO "django_geo_db_zipcode" VALUES(29337,65433,-6,'Bendavis, Missouri 65433',21472,26161);
INSERT INTO "django_geo_db_zipcode" VALUES(29338,65436,-6,'Beulah, Missouri 65436',21473,26162);
INSERT INTO "django_geo_db_zipcode" VALUES(29339,65438,-6,'Birch Tree, Missouri 65438',21474,26163);
INSERT INTO "django_geo_db_zipcode" VALUES(29340,65439,-6,'Bixby, Missouri 65439',21475,26164);
INSERT INTO "django_geo_db_zipcode" VALUES(29341,65440,-6,'Boss, Missouri 65440',21476,26165);
INSERT INTO "django_geo_db_zipcode" VALUES(29342,65441,-6,'Bourbon, Missouri 65441',21477,26166);
INSERT INTO "django_geo_db_zipcode" VALUES(29343,65443,-6,'Brinktown, Missouri 65443',21478,26167);
INSERT INTO "django_geo_db_zipcode" VALUES(29344,65444,-6,'Bucyrus, Missouri 65444',21479,26168);
INSERT INTO "django_geo_db_zipcode" VALUES(29345,65446,-6,'Cherryville, Missouri 65446',21480,26169);
INSERT INTO "django_geo_db_zipcode" VALUES(29346,65449,-6,'Cook Station, Missouri 65449',21481,26170);
INSERT INTO "django_geo_db_zipcode" VALUES(29347,65452,-6,'Crocker, Missouri 65452',21482,26171);
INSERT INTO "django_geo_db_zipcode" VALUES(29348,65453,-6,'Cuba, Missouri 65453',21471,26172);
INSERT INTO "django_geo_db_zipcode" VALUES(29349,65456,-6,'Davisville, Missouri 65456',21483,26173);
INSERT INTO "django_geo_db_zipcode" VALUES(29350,65457,-6,'Devils Elbow, Missouri 65457',21484,26174);
INSERT INTO "django_geo_db_zipcode" VALUES(29351,65459,-6,'Dixon, Missouri 65459',21485,26175);
INSERT INTO "django_geo_db_zipcode" VALUES(29352,65461,-6,'Duke, Missouri 65461',21486,26176);
INSERT INTO "django_geo_db_zipcode" VALUES(29353,65462,-6,'Edgar Springs, Missouri 65462',21487,26177);
INSERT INTO "django_geo_db_zipcode" VALUES(29354,65463,-6,'Eldridge, Missouri 65463',21488,26178);
INSERT INTO "django_geo_db_zipcode" VALUES(29355,65464,-6,'Elk Creek, Missouri 65464',21489,26179);
INSERT INTO "django_geo_db_zipcode" VALUES(29356,65466,-6,'Eminence, Missouri 65466',21490,26180);
INSERT INTO "django_geo_db_zipcode" VALUES(29357,65468,-6,'Eunice, Missouri 65468',21491,26181);
INSERT INTO "django_geo_db_zipcode" VALUES(29358,65470,-6,'Falcon, Missouri 65470',21492,26182);
INSERT INTO "django_geo_db_zipcode" VALUES(29359,65473,-6,'Fort Leonard Wood, Missouri 65473',21493,26183);
INSERT INTO "django_geo_db_zipcode" VALUES(29360,65479,-6,'Hartshorn, Missouri 65479',21494,26184);
INSERT INTO "django_geo_db_zipcode" VALUES(29361,65483,-6,'Houston, Missouri 65483',21495,26185);
INSERT INTO "django_geo_db_zipcode" VALUES(29362,65484,-6,'Huggins, Missouri 65484',21496,26186);
INSERT INTO "django_geo_db_zipcode" VALUES(29363,65486,-6,'Iberia, Missouri 65486',21497,26187);
INSERT INTO "django_geo_db_zipcode" VALUES(29364,65495,-6,'Dixon, Missouri 65495',21485,26188);
INSERT INTO "django_geo_db_zipcode" VALUES(29365,65501,-6,'Jadwin, Missouri 65501',21498,26189);
INSERT INTO "django_geo_db_zipcode" VALUES(29366,65529,-6,'Jerome, Missouri 65529',21499,26190);
INSERT INTO "django_geo_db_zipcode" VALUES(29367,65530,-6,'Gilliam, Missouri 65530',21450,26191);
INSERT INTO "django_geo_db_zipcode" VALUES(29368,65532,-6,'Lake Spring, Missouri 65532',21500,26192);
INSERT INTO "django_geo_db_zipcode" VALUES(29369,65534,-6,'Laquey, Missouri 65534',21501,26193);
INSERT INTO "django_geo_db_zipcode" VALUES(29370,65535,-6,'Leasburg, Missouri 65535',21502,26194);
INSERT INTO "django_geo_db_zipcode" VALUES(29371,65536,-6,'Lebanon, Missouri 65536',21503,26195);
INSERT INTO "django_geo_db_zipcode" VALUES(29372,65540,-6,'Lecoma, Missouri 65540',21504,26196);
INSERT INTO "django_geo_db_zipcode" VALUES(29373,65541,-6,'Lenox, Missouri 65541',21505,26197);
INSERT INTO "django_geo_db_zipcode" VALUES(29374,65542,-6,'Licking, Missouri 65542',21506,26198);
INSERT INTO "django_geo_db_zipcode" VALUES(29375,65543,-6,'Lynchburg, Missouri 65543',21507,26199);
INSERT INTO "django_geo_db_zipcode" VALUES(29376,65546,-6,'Montier, Missouri 65546',21508,26200);
INSERT INTO "django_geo_db_zipcode" VALUES(29377,65548,-6,'Mountain View, Missouri 65548',21509,26201);
INSERT INTO "django_geo_db_zipcode" VALUES(29378,65550,-6,'Newburg, Missouri 65550',21510,26202);
INSERT INTO "django_geo_db_zipcode" VALUES(29379,65552,-6,'Plato, Missouri 65552',21511,26203);
INSERT INTO "django_geo_db_zipcode" VALUES(29380,65555,-6,'Raymondville, Missouri 65555',21512,26204);
INSERT INTO "django_geo_db_zipcode" VALUES(29381,65556,-6,'Richland, Missouri 65556',21513,26205);
INSERT INTO "django_geo_db_zipcode" VALUES(29382,65557,-6,'Roby, Missouri 65557',21514,26206);
INSERT INTO "django_geo_db_zipcode" VALUES(29383,65559,-6,'Saint James, Missouri 65559',21515,26207);
INSERT INTO "django_geo_db_zipcode" VALUES(29384,65560,-6,'Salem, Missouri 65560',21516,26208);
INSERT INTO "django_geo_db_zipcode" VALUES(29385,65564,-6,'Solo, Missouri 65564',21517,26209);
INSERT INTO "django_geo_db_zipcode" VALUES(29386,65565,-6,'Steelville, Missouri 65565',21518,26210);
INSERT INTO "django_geo_db_zipcode" VALUES(29387,65566,-6,'Viburnum, Missouri 65566',21519,26211);
INSERT INTO "django_geo_db_zipcode" VALUES(29388,65567,-6,'Stoutland, Missouri 65567',21520,26212);
INSERT INTO "django_geo_db_zipcode" VALUES(29389,65570,-6,'Success, Missouri 65570',21521,26213);
INSERT INTO "django_geo_db_zipcode" VALUES(29390,65571,-6,'Summersville, Missouri 65571',21522,26214);
INSERT INTO "django_geo_db_zipcode" VALUES(29391,65572,-6,'Swedeborg, Missouri 65572',21523,26215);
INSERT INTO "django_geo_db_zipcode" VALUES(29392,65573,-6,'Teresita, Missouri 65573',21524,26200);
INSERT INTO "django_geo_db_zipcode" VALUES(29393,65575,-6,'West Plains, Missouri 65575',21525,26216);
INSERT INTO "django_geo_db_zipcode" VALUES(29394,65580,-6,'Vichy, Missouri 65580',21526,26217);
INSERT INTO "django_geo_db_zipcode" VALUES(29395,65582,-6,'Vienna, Missouri 65582',21527,26218);
INSERT INTO "django_geo_db_zipcode" VALUES(29396,65583,-6,'Waynesville, Missouri 65583',21528,26219);
INSERT INTO "django_geo_db_zipcode" VALUES(29397,65584,-6,'St. Robert, Missouri 65584',21529,26220);
INSERT INTO "django_geo_db_zipcode" VALUES(29398,65586,-6,'Wesco, Missouri 65586',21530,26221);
INSERT INTO "django_geo_db_zipcode" VALUES(29399,65587,-6,'Waynesville, Missouri 65587',21528,26222);
INSERT INTO "django_geo_db_zipcode" VALUES(29400,65588,-6,'Winona, Missouri 65588',21531,26223);
INSERT INTO "django_geo_db_zipcode" VALUES(29401,65589,-6,'Yukon, Missouri 65589',21532,26224);
INSERT INTO "django_geo_db_zipcode" VALUES(29402,65590,-6,'Long Lane, Missouri 65590',21533,26225);
INSERT INTO "django_geo_db_zipcode" VALUES(29403,65591,-6,'Montreal, Missouri 65591',21534,26226);
INSERT INTO "django_geo_db_zipcode" VALUES(29404,65601,-6,'Aldrich, Missouri 65601',21535,26227);
INSERT INTO "django_geo_db_zipcode" VALUES(29405,65602,-6,'Springfield, Missouri 65602',21536,26228);
INSERT INTO "django_geo_db_zipcode" VALUES(29406,65603,-6,'Arcola, Missouri 65603',21537,26229);
INSERT INTO "django_geo_db_zipcode" VALUES(29407,65604,-6,'Ash Grove, Missouri 65604',21538,26230);
INSERT INTO "django_geo_db_zipcode" VALUES(29408,65605,-6,'Aurora, Missouri 65605',21539,26231);
INSERT INTO "django_geo_db_zipcode" VALUES(29409,65606,-6,'Alton, Missouri 65606',21540,26232);
INSERT INTO "django_geo_db_zipcode" VALUES(29410,65607,-6,'Caplinger Mills, Missouri 65607',21541,26233);
INSERT INTO "django_geo_db_zipcode" VALUES(29411,65608,-6,'Ava, Missouri 65608',21542,26234);
INSERT INTO "django_geo_db_zipcode" VALUES(29412,65609,-6,'Bakersfield, Missouri 65609',21543,26235);
INSERT INTO "django_geo_db_zipcode" VALUES(29413,65610,-6,'Billings, Missouri 65610',21544,26236);
INSERT INTO "django_geo_db_zipcode" VALUES(29414,65611,-6,'Blue Eye, Missouri 65611',21545,26237);
INSERT INTO "django_geo_db_zipcode" VALUES(29415,65612,-6,'Bois D Arc, Missouri 65612',21546,26238);
INSERT INTO "django_geo_db_zipcode" VALUES(29416,65613,-6,'Bolivar, Missouri 65613',21547,26239);
INSERT INTO "django_geo_db_zipcode" VALUES(29417,65614,-6,'Bradleyville, Missouri 65614',21548,26240);
INSERT INTO "django_geo_db_zipcode" VALUES(29418,65615,-6,'Branson, Missouri 65615',21549,26241);
INSERT INTO "django_geo_db_zipcode" VALUES(29419,65616,-6,'Branson, Missouri 65616',21549,26242);
INSERT INTO "django_geo_db_zipcode" VALUES(29420,65617,-6,'Brighton, Missouri 65617',21550,26243);
INSERT INTO "django_geo_db_zipcode" VALUES(29421,65618,-6,'Brixey, Missouri 65618',21551,26244);
INSERT INTO "django_geo_db_zipcode" VALUES(29422,65619,-6,'Brookline Station, Missouri 65619',21552,26245);
INSERT INTO "django_geo_db_zipcode" VALUES(29423,65620,-6,'Bruner, Missouri 65620',21553,26246);
INSERT INTO "django_geo_db_zipcode" VALUES(29424,65622,-6,'Buffalo, Missouri 65622',21554,26247);
INSERT INTO "django_geo_db_zipcode" VALUES(29425,65623,-6,'Butterfield, Missouri 65623',21555,26248);
INSERT INTO "django_geo_db_zipcode" VALUES(29426,65624,-6,'Cape Fair, Missouri 65624',21556,26249);
INSERT INTO "django_geo_db_zipcode" VALUES(29427,65625,-6,'Cassville, Missouri 65625',21557,26250);
INSERT INTO "django_geo_db_zipcode" VALUES(29428,65626,-6,'Caulfield, Missouri 65626',21558,26251);
INSERT INTO "django_geo_db_zipcode" VALUES(29429,65627,-6,'Cedarcreek, Missouri 65627',21559,26252);
INSERT INTO "django_geo_db_zipcode" VALUES(29430,65629,-6,'Chadwick, Missouri 65629',21560,26253);
INSERT INTO "django_geo_db_zipcode" VALUES(29431,65630,-6,'Chestnutridge, Missouri 65630',21561,26254);
INSERT INTO "django_geo_db_zipcode" VALUES(29432,65631,-6,'Clever, Missouri 65631',21562,26255);
INSERT INTO "django_geo_db_zipcode" VALUES(29433,65632,-6,'Conway, Missouri 65632',21563,26256);
INSERT INTO "django_geo_db_zipcode" VALUES(29434,65633,-6,'Crane, Missouri 65633',21564,26257);
INSERT INTO "django_geo_db_zipcode" VALUES(29435,65634,-6,'Cross Timbers, Missouri 65634',21565,26258);
INSERT INTO "django_geo_db_zipcode" VALUES(29436,65635,-6,'Dadeville, Missouri 65635',21566,26259);
INSERT INTO "django_geo_db_zipcode" VALUES(29437,65636,-6,'Diggins, Missouri 65636',21567,26260);
INSERT INTO "django_geo_db_zipcode" VALUES(29438,65637,-6,'Dora, Missouri 65637',21568,26261);
INSERT INTO "django_geo_db_zipcode" VALUES(29439,65638,-6,'Drury, Missouri 65638',21569,26262);
INSERT INTO "django_geo_db_zipcode" VALUES(29440,65640,-6,'Dunnegan, Missouri 65640',21570,26263);
INSERT INTO "django_geo_db_zipcode" VALUES(29441,65641,-6,'Eagle Rock, Missouri 65641',21571,26264);
INSERT INTO "django_geo_db_zipcode" VALUES(29442,65644,-6,'Elkland, Missouri 65644',21572,26265);
INSERT INTO "django_geo_db_zipcode" VALUES(29443,65645,-6,'Eudora, Missouri 65645',21573,26266);
INSERT INTO "django_geo_db_zipcode" VALUES(29444,65646,-6,'Everton, Missouri 65646',21574,26267);
INSERT INTO "django_geo_db_zipcode" VALUES(29445,65647,-6,'Exeter, Missouri 65647',21575,26268);
INSERT INTO "django_geo_db_zipcode" VALUES(29446,65648,-6,'Fair Grove, Missouri 65648',21576,26269);
INSERT INTO "django_geo_db_zipcode" VALUES(29447,65649,-6,'Fair Play, Missouri 65649',21577,26270);
INSERT INTO "django_geo_db_zipcode" VALUES(29448,65650,-6,'Flemington, Missouri 65650',21578,26271);
INSERT INTO "django_geo_db_zipcode" VALUES(29449,65652,-6,'Fordland, Missouri 65652',21579,26272);
INSERT INTO "django_geo_db_zipcode" VALUES(29450,65653,-6,'Forsyth, Missouri 65653',21580,26273);
INSERT INTO "django_geo_db_zipcode" VALUES(29451,65654,-6,'Freistatt, Missouri 65654',21581,26274);
INSERT INTO "django_geo_db_zipcode" VALUES(29452,65655,-6,'Gainesville, Missouri 65655',21582,26275);
INSERT INTO "django_geo_db_zipcode" VALUES(29453,65656,-6,'Galena, Missouri 65656',21583,26276);
INSERT INTO "django_geo_db_zipcode" VALUES(29454,65657,-6,'Garrison, Missouri 65657',21584,26277);
INSERT INTO "django_geo_db_zipcode" VALUES(29455,65658,-6,'Golden, Missouri 65658',21585,26278);
INSERT INTO "django_geo_db_zipcode" VALUES(29456,65659,-6,'Goodson, Missouri 65659',21586,26279);
INSERT INTO "django_geo_db_zipcode" VALUES(29457,65660,-6,'Graff, Missouri 65660',21587,26280);
INSERT INTO "django_geo_db_zipcode" VALUES(29458,65661,-6,'Greenfield, Missouri 65661',21588,26281);
INSERT INTO "django_geo_db_zipcode" VALUES(29459,65662,-6,'Grovespring, Missouri 65662',21589,26282);
INSERT INTO "django_geo_db_zipcode" VALUES(29460,65663,-6,'Half Way, Missouri 65663',21590,26283);
INSERT INTO "django_geo_db_zipcode" VALUES(29461,65664,-6,'Halltown, Missouri 65664',21591,26284);
INSERT INTO "django_geo_db_zipcode" VALUES(29462,65666,-6,'Hardenville, Missouri 65666',21592,26285);
INSERT INTO "django_geo_db_zipcode" VALUES(29463,65667,-6,'Hartville, Missouri 65667',21593,26286);
INSERT INTO "django_geo_db_zipcode" VALUES(29464,65668,-6,'Hermitage, Missouri 65668',21594,26287);
INSERT INTO "django_geo_db_zipcode" VALUES(29465,65669,-6,'Highlandville, Missouri 65669',21595,26288);
INSERT INTO "django_geo_db_zipcode" VALUES(29466,65672,-6,'Hollister, Missouri 65672',21596,26289);
INSERT INTO "django_geo_db_zipcode" VALUES(29467,65673,-6,'Hollister, Missouri 65673',21596,26290);
INSERT INTO "django_geo_db_zipcode" VALUES(29468,65674,-6,'Humansville, Missouri 65674',21597,26291);
INSERT INTO "django_geo_db_zipcode" VALUES(29469,65675,-6,'Hurley, Missouri 65675',21598,26292);
INSERT INTO "django_geo_db_zipcode" VALUES(29470,65676,-6,'Isabella, Missouri 65676',21599,26293);
INSERT INTO "django_geo_db_zipcode" VALUES(29471,65679,-6,'Kirbyville, Missouri 65679',21600,26294);
INSERT INTO "django_geo_db_zipcode" VALUES(29472,65680,-6,'Kissee Mills, Missouri 65680',21601,26295);
INSERT INTO "django_geo_db_zipcode" VALUES(29473,65681,-6,'Lampe, Missouri 65681',21602,26296);
INSERT INTO "django_geo_db_zipcode" VALUES(29474,65682,-6,'Lockwood, Missouri 65682',21603,26297);
INSERT INTO "django_geo_db_zipcode" VALUES(29475,65684,-6,'Morris, Missouri 65684',21604,26298);
INSERT INTO "django_geo_db_zipcode" VALUES(29476,65685,-6,'Louisburg, Missouri 65685',21605,26299);
INSERT INTO "django_geo_db_zipcode" VALUES(29477,65686,-6,'Kimberling City, Missouri 65686',21606,26300);
INSERT INTO "django_geo_db_zipcode" VALUES(29478,65688,-6,'Brandsville, Missouri 65688',21607,26301);
INSERT INTO "django_geo_db_zipcode" VALUES(29479,65689,-6,'Cabool, Missouri 65689',21608,26302);
INSERT INTO "django_geo_db_zipcode" VALUES(29480,65690,-6,'Couch, Missouri 65690',21609,26303);
INSERT INTO "django_geo_db_zipcode" VALUES(29481,65692,-6,'Koshkonong, Missouri 65692',21610,26304);
INSERT INTO "django_geo_db_zipcode" VALUES(29482,65701,-6,'McClurg, Missouri 65701',21611,26305);
INSERT INTO "django_geo_db_zipcode" VALUES(29483,65702,-6,'Macomb, Missouri 65702',21612,26306);
INSERT INTO "django_geo_db_zipcode" VALUES(29484,65704,-6,'Mansfield, Missouri 65704',21613,26307);
INSERT INTO "django_geo_db_zipcode" VALUES(29485,65705,-6,'Marionville, Missouri 65705',21614,26308);
INSERT INTO "django_geo_db_zipcode" VALUES(29486,65706,-6,'Marshfield, Missouri 65706',21615,26309);
INSERT INTO "django_geo_db_zipcode" VALUES(29487,65707,-6,'Miller, Missouri 65707',21616,26310);
INSERT INTO "django_geo_db_zipcode" VALUES(29488,65708,-6,'Monett, Missouri 65708',21617,26311);
INSERT INTO "django_geo_db_zipcode" VALUES(29489,65710,-6,'Morrisville, Missouri 65710',21618,26312);
INSERT INTO "django_geo_db_zipcode" VALUES(29490,65711,-6,'Mountain Grove, Missouri 65711',21619,26313);
INSERT INTO "django_geo_db_zipcode" VALUES(29491,65712,-6,'Mount Vernon, Missouri 65712',21620,26314);
INSERT INTO "django_geo_db_zipcode" VALUES(29492,65713,-6,'Niangua, Missouri 65713',21621,26315);
INSERT INTO "django_geo_db_zipcode" VALUES(29493,65714,-6,'Nixa, Missouri 65714',21622,26316);
INSERT INTO "django_geo_db_zipcode" VALUES(29494,65715,-6,'Noble, Missouri 65715',21623,26317);
INSERT INTO "django_geo_db_zipcode" VALUES(29495,65717,-6,'Norwood, Missouri 65717',21624,26318);
INSERT INTO "django_geo_db_zipcode" VALUES(29496,65720,-6,'Oldfield, Missouri 65720',21625,26319);
INSERT INTO "django_geo_db_zipcode" VALUES(29497,65721,-6,'Ozark, Missouri 65721',21626,26320);
INSERT INTO "django_geo_db_zipcode" VALUES(29498,65722,-6,'Phillipsburg, Missouri 65722',21627,26321);
INSERT INTO "django_geo_db_zipcode" VALUES(29499,65723,-6,'Pierce City, Missouri 65723',21628,26322);
INSERT INTO "django_geo_db_zipcode" VALUES(29500,65724,-6,'Pittsburg, Missouri 65724',21629,26323);
INSERT INTO "django_geo_db_zipcode" VALUES(29501,65725,-6,'Pleasant Hope, Missouri 65725',21630,26324);
INSERT INTO "django_geo_db_zipcode" VALUES(29502,65726,-6,'Point Lookout, Missouri 65726',21631,26325);
INSERT INTO "django_geo_db_zipcode" VALUES(29503,65727,-6,'Polk, Missouri 65727',21157,26326);
INSERT INTO "django_geo_db_zipcode" VALUES(29504,65728,-6,'Ponce De Leon, Missouri 65728',21632,26327);
INSERT INTO "django_geo_db_zipcode" VALUES(29505,65729,-6,'Pontiac, Missouri 65729',21633,26328);
INSERT INTO "django_geo_db_zipcode" VALUES(29506,65730,-6,'Powell, Missouri 65730',21634,26329);
INSERT INTO "django_geo_db_zipcode" VALUES(29507,65731,-6,'Powersite, Missouri 65731',21635,26330);
INSERT INTO "django_geo_db_zipcode" VALUES(29508,65732,-6,'Preston, Missouri 65732',21636,26331);
INSERT INTO "django_geo_db_zipcode" VALUES(29509,65733,-6,'Protem, Arkansas 65733',21637,26332);
INSERT INTO "django_geo_db_zipcode" VALUES(29510,65734,-6,'Purdy, Missouri 65734',21638,26333);
INSERT INTO "django_geo_db_zipcode" VALUES(29511,65735,-6,'Quincy, Missouri 65735',21639,26334);
INSERT INTO "django_geo_db_zipcode" VALUES(29512,65737,-6,'Reeds Spring, Missouri 65737',21640,26335);
INSERT INTO "django_geo_db_zipcode" VALUES(29513,65738,-6,'Republic, Missouri 65738',21641,26336);
INSERT INTO "django_geo_db_zipcode" VALUES(29514,65739,-6,'Ridgedale, Missouri 65739',21642,26337);
INSERT INTO "django_geo_db_zipcode" VALUES(29515,65740,-6,'Rockaway Beach, Missouri 65740',21643,26338);
INSERT INTO "django_geo_db_zipcode" VALUES(29516,65741,-6,'Rockbridge, Missouri 65741',21644,26285);
INSERT INTO "django_geo_db_zipcode" VALUES(29517,65742,-6,'Rogersville, Missouri 65742',21645,26339);
INSERT INTO "django_geo_db_zipcode" VALUES(29518,65744,-6,'Rueter, Missouri 65744',21646,26340);
INSERT INTO "django_geo_db_zipcode" VALUES(29519,65745,-6,'Seligman, Missouri 65745',21647,26341);
INSERT INTO "django_geo_db_zipcode" VALUES(29520,65746,-6,'Seymour, Missouri 65746',21648,26342);
INSERT INTO "django_geo_db_zipcode" VALUES(29521,65747,-6,'Shell Knob, Missouri 65747',21649,26343);
INSERT INTO "django_geo_db_zipcode" VALUES(29522,65752,-6,'South Greenfield, Missouri 65752',21650,26344);
INSERT INTO "django_geo_db_zipcode" VALUES(29523,65753,-6,'Sparta, Missouri 65753',21651,26345);
INSERT INTO "django_geo_db_zipcode" VALUES(29524,65754,-6,'Spokane, Missouri 65754',21652,26346);
INSERT INTO "django_geo_db_zipcode" VALUES(29525,65755,-6,'Squires, Missouri 65755',21653,26347);
INSERT INTO "django_geo_db_zipcode" VALUES(29526,65756,-6,'Stotts City, Missouri 65756',21654,26348);
INSERT INTO "django_geo_db_zipcode" VALUES(29527,65757,-6,'Strafford, Missouri 65757',21655,26349);
INSERT INTO "django_geo_db_zipcode" VALUES(29528,65759,-6,'Taneyville, Missouri 65759',21656,26350);
INSERT INTO "django_geo_db_zipcode" VALUES(29529,65760,-6,'Tecumseh, Missouri 65760',21657,26351);
INSERT INTO "django_geo_db_zipcode" VALUES(29530,65761,-6,'Theodosia, Arkansas 65761',21658,26352);
INSERT INTO "django_geo_db_zipcode" VALUES(29531,65762,-6,'Thornfield, Missouri 65762',21659,26353);
INSERT INTO "django_geo_db_zipcode" VALUES(29532,65764,-6,'Tunas, Missouri 65764',21660,26354);
INSERT INTO "django_geo_db_zipcode" VALUES(29533,65765,-6,'Turners, Missouri 65765',21661,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29534,65766,-6,'Udall, Missouri 65766',21662,26356);
INSERT INTO "django_geo_db_zipcode" VALUES(29535,65767,-6,'Urbana, Missouri 65767',21663,26357);
INSERT INTO "django_geo_db_zipcode" VALUES(29536,65768,-6,'Vanzant, Missouri 65768',21664,26358);
INSERT INTO "django_geo_db_zipcode" VALUES(29537,65769,-6,'Verona, Missouri 65769',21665,26359);
INSERT INTO "django_geo_db_zipcode" VALUES(29538,65770,-6,'Walnut Grove, Missouri 65770',21666,26360);
INSERT INTO "django_geo_db_zipcode" VALUES(29539,65771,-6,'Walnut Shade, Missouri 65771',21667,26361);
INSERT INTO "django_geo_db_zipcode" VALUES(29540,65772,-6,'Washburn, Missouri 65772',21668,26362);
INSERT INTO "django_geo_db_zipcode" VALUES(29541,65773,-6,'Wasola, Missouri 65773',21669,26363);
INSERT INTO "django_geo_db_zipcode" VALUES(29542,65774,-6,'Weaubleau, Missouri 65774',21670,26364);
INSERT INTO "django_geo_db_zipcode" VALUES(29543,65775,-6,'West Plains, Missouri 65775',21525,26365);
INSERT INTO "django_geo_db_zipcode" VALUES(29544,65776,-6,'South Fork, Missouri 65776',21671,26366);
INSERT INTO "django_geo_db_zipcode" VALUES(29545,65777,-6,'Moody, Missouri 65777',21672,26367);
INSERT INTO "django_geo_db_zipcode" VALUES(29546,65778,-6,'Myrtle, Missouri 65778',21673,26368);
INSERT INTO "django_geo_db_zipcode" VALUES(29547,65779,-6,'Wheatland, Missouri 65779',21674,26369);
INSERT INTO "django_geo_db_zipcode" VALUES(29548,65781,-6,'Willard, Missouri 65781',21675,26370);
INSERT INTO "django_geo_db_zipcode" VALUES(29549,65783,-6,'Windyville, Missouri 65783',21676,26371);
INSERT INTO "django_geo_db_zipcode" VALUES(29550,65784,-6,'Zanoni, Missouri 65784',21677,26372);
INSERT INTO "django_geo_db_zipcode" VALUES(29551,65785,-6,'Stockton, Missouri 65785',21678,26373);
INSERT INTO "django_geo_db_zipcode" VALUES(29552,65786,-6,'Macks Creek, Missouri 65786',21679,26374);
INSERT INTO "django_geo_db_zipcode" VALUES(29553,65787,-6,'Roach, Missouri 65787',21680,26375);
INSERT INTO "django_geo_db_zipcode" VALUES(29554,65788,-6,'Peace Valley, Missouri 65788',21681,26376);
INSERT INTO "django_geo_db_zipcode" VALUES(29555,65789,-6,'Pomona, Missouri 65789',21682,26377);
INSERT INTO "django_geo_db_zipcode" VALUES(29556,65790,-6,'Pottersville, Missouri 65790',21683,26378);
INSERT INTO "django_geo_db_zipcode" VALUES(29557,65791,-6,'Thayer, Missouri 65791',21684,26379);
INSERT INTO "django_geo_db_zipcode" VALUES(29558,65793,-6,'Willow Springs, Missouri 65793',21685,26380);
INSERT INTO "django_geo_db_zipcode" VALUES(29559,65801,-6,'Springfield, Missouri 65801',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29560,65802,-6,'Springfield, Missouri 65802',21536,26381);
INSERT INTO "django_geo_db_zipcode" VALUES(29561,65803,-6,'Springfield, Missouri 65803',21536,26382);
INSERT INTO "django_geo_db_zipcode" VALUES(29562,65804,-6,'Springfield, Missouri 65804',21536,26383);
INSERT INTO "django_geo_db_zipcode" VALUES(29563,65805,-6,'Springfield, Missouri 65805',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29564,65806,-6,'Springfield, Missouri 65806',21536,26384);
INSERT INTO "django_geo_db_zipcode" VALUES(29565,65807,-6,'Springfield, Missouri 65807',21536,26385);
INSERT INTO "django_geo_db_zipcode" VALUES(29566,65808,-6,'Springfield, Missouri 65808',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29567,65809,-6,'Springfield, Missouri 65809',21536,26386);
INSERT INTO "django_geo_db_zipcode" VALUES(29568,65810,-6,'Springfield, Missouri 65810',21536,26387);
INSERT INTO "django_geo_db_zipcode" VALUES(29569,65814,-6,'Springfield, Missouri 65814',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29570,65817,-6,'Springfield, Missouri 65817',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29571,65890,-6,'Springfield, Missouri 65890',21536,26355);
INSERT INTO "django_geo_db_zipcode" VALUES(29572,65898,-6,'Springfield, Missouri 65898',21536,26388);
INSERT INTO "django_geo_db_zipcode" VALUES(29573,65899,-6,'Springfield, Missouri 65899',21536,26389);
INSERT INTO "django_geo_db_zipcode" VALUES(29574,66002,-6,'Atchison, Kansas 66002',21686,26390);
INSERT INTO "django_geo_db_zipcode" VALUES(29575,66006,-6,'Baldwin City, Kansas 66006',21687,26391);
INSERT INTO "django_geo_db_zipcode" VALUES(29576,66007,-6,'Basehor, Kansas 66007',21688,26392);
INSERT INTO "django_geo_db_zipcode" VALUES(29577,66008,-6,'Bendena, Kansas 66008',21689,26393);
INSERT INTO "django_geo_db_zipcode" VALUES(29578,66010,-6,'Blue Mound, Kansas 66010',21690,26394);
INSERT INTO "django_geo_db_zipcode" VALUES(29579,66012,-6,'Bonner Springs, Kansas 66012',21691,26395);
INSERT INTO "django_geo_db_zipcode" VALUES(29580,66013,-6,'Bucyrus, Kansas 66013',21692,26396);
INSERT INTO "django_geo_db_zipcode" VALUES(29581,66014,-6,'Centerville, Kansas 66014',21693,26397);
INSERT INTO "django_geo_db_zipcode" VALUES(29582,66015,-6,'Colony, Kansas 66015',21694,26398);
INSERT INTO "django_geo_db_zipcode" VALUES(29583,66016,-6,'Cummings, Kansas 66016',21695,26399);
INSERT INTO "django_geo_db_zipcode" VALUES(29584,66017,-6,'Denton, Kansas 66017',21696,26400);
INSERT INTO "django_geo_db_zipcode" VALUES(29585,66018,-6,'De Soto, Kansas 66018',21697,26401);
INSERT INTO "django_geo_db_zipcode" VALUES(29586,66019,-6,'Clearview City, Kansas 66019',21698,26402);
INSERT INTO "django_geo_db_zipcode" VALUES(29587,66020,-6,'Easton, Kansas 66020',21699,26403);
INSERT INTO "django_geo_db_zipcode" VALUES(29588,66021,-6,'Edgerton, Kansas 66021',21700,26404);
INSERT INTO "django_geo_db_zipcode" VALUES(29589,66023,-6,'Effingham, Kansas 66023',21701,26405);
INSERT INTO "django_geo_db_zipcode" VALUES(29590,66024,-6,'Elwood, Kansas 66024',21702,26406);
INSERT INTO "django_geo_db_zipcode" VALUES(29591,66025,-6,'Eudora, Kansas 66025',21703,26407);
INSERT INTO "django_geo_db_zipcode" VALUES(29592,66026,-6,'Fontana, Kansas 66026',21704,26408);
INSERT INTO "django_geo_db_zipcode" VALUES(29593,66027,-6,'Fort Leavenworth, Kansas 66027',21705,26409);
INSERT INTO "django_geo_db_zipcode" VALUES(29594,66030,-6,'Gardner, Kansas 66030',21706,26410);
INSERT INTO "django_geo_db_zipcode" VALUES(29595,66031,-6,'New Century, Kansas 66031',21707,26411);
INSERT INTO "django_geo_db_zipcode" VALUES(29596,66032,-6,'Garnett, Kansas 66032',21708,26412);
INSERT INTO "django_geo_db_zipcode" VALUES(29597,66033,-6,'Greeley, Kansas 66033',21709,26413);
INSERT INTO "django_geo_db_zipcode" VALUES(29598,66035,-6,'Highland, Kansas 66035',21710,26414);
INSERT INTO "django_geo_db_zipcode" VALUES(29599,66036,-6,'Hillsdale, Kansas 66036',21711,26415);
INSERT INTO "django_geo_db_zipcode" VALUES(29600,66039,-6,'Kincaid, Kansas 66039',21712,26416);
INSERT INTO "django_geo_db_zipcode" VALUES(29601,66040,-6,'La Cygne, Kansas 66040',21713,26417);
INSERT INTO "django_geo_db_zipcode" VALUES(29602,66041,-6,'Lancaster, Kansas 66041',21714,26418);
INSERT INTO "django_geo_db_zipcode" VALUES(29603,66042,-6,'Lane, Kansas 66042',21715,26419);
INSERT INTO "django_geo_db_zipcode" VALUES(29604,66043,-6,'Lansing, Kansas 66043',21716,26420);
INSERT INTO "django_geo_db_zipcode" VALUES(29605,66044,-6,'Lawrence, Kansas 66044',21717,26421);
INSERT INTO "django_geo_db_zipcode" VALUES(29606,66045,-6,'Lawrence, Kansas 66045',21717,26422);
INSERT INTO "django_geo_db_zipcode" VALUES(29607,66046,-6,'Lawrence, Kansas 66046',21717,26423);
INSERT INTO "django_geo_db_zipcode" VALUES(29608,66047,-6,'Lawrence, Kansas 66047',21717,26424);
INSERT INTO "django_geo_db_zipcode" VALUES(29609,66048,-6,'Leavenworth, Kansas 66048',21718,26425);
INSERT INTO "django_geo_db_zipcode" VALUES(29610,66049,-6,'Lawrence, Kansas 66049',21717,26426);
INSERT INTO "django_geo_db_zipcode" VALUES(29611,66050,-6,'Lecompton, Kansas 66050',21719,26427);
INSERT INTO "django_geo_db_zipcode" VALUES(29612,66051,-6,'Olathe, Kansas 66051',21720,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29613,66052,-6,'Linwood, Kansas 66052',21721,26429);
INSERT INTO "django_geo_db_zipcode" VALUES(29614,66053,-6,'Louisburg, Kansas 66053',21722,26430);
INSERT INTO "django_geo_db_zipcode" VALUES(29615,66054,-6,'McLouth, Kansas 66054',21723,26431);
INSERT INTO "django_geo_db_zipcode" VALUES(29616,66056,-6,'Mound City, Kansas 66056',21724,26432);
INSERT INTO "django_geo_db_zipcode" VALUES(29617,66058,-6,'Muscotah, Kansas 66058',21725,26433);
INSERT INTO "django_geo_db_zipcode" VALUES(29618,66060,-6,'Nortonville, Kansas 66060',21726,26434);
INSERT INTO "django_geo_db_zipcode" VALUES(29619,66061,-6,'Olathe, Kansas 66061',21720,26435);
INSERT INTO "django_geo_db_zipcode" VALUES(29620,66062,-6,'Olathe, Kansas 66062',21720,26436);
INSERT INTO "django_geo_db_zipcode" VALUES(29621,66063,-6,'Olathe, Kansas 66063',21720,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29622,66064,-6,'Osawatomie, Kansas 66064',21727,26437);
INSERT INTO "django_geo_db_zipcode" VALUES(29623,66066,-6,'Oskaloosa, Kansas 66066',21728,26438);
INSERT INTO "django_geo_db_zipcode" VALUES(29624,66067,-6,'Ottawa, Kansas 66067',21729,26439);
INSERT INTO "django_geo_db_zipcode" VALUES(29625,66070,-6,'Ozawkie, Kansas 66070',21730,26440);
INSERT INTO "django_geo_db_zipcode" VALUES(29626,66071,-6,'Paola, Kansas 66071',21731,26441);
INSERT INTO "django_geo_db_zipcode" VALUES(29627,66072,-6,'Parker, Kansas 66072',21732,26442);
INSERT INTO "django_geo_db_zipcode" VALUES(29628,66073,-6,'Perry, Kansas 66073',21733,26443);
INSERT INTO "django_geo_db_zipcode" VALUES(29629,66075,-6,'Pleasanton, Kansas 66075',21734,26444);
INSERT INTO "django_geo_db_zipcode" VALUES(29630,66076,-6,'Pomona, Kansas 66076',21735,26445);
INSERT INTO "django_geo_db_zipcode" VALUES(29631,66077,-6,'Potter, Kansas 66077',21736,26446);
INSERT INTO "django_geo_db_zipcode" VALUES(29632,66078,-6,'Princeton, Kansas 66078',21737,26447);
INSERT INTO "django_geo_db_zipcode" VALUES(29633,66079,-6,'Rantoul, Kansas 66079',21738,26448);
INSERT INTO "django_geo_db_zipcode" VALUES(29634,66080,-6,'Richmond, Kansas 66080',21739,26449);
INSERT INTO "django_geo_db_zipcode" VALUES(29635,66081,-6,'Wolf River, Kansas 66081',21740,26450);
INSERT INTO "django_geo_db_zipcode" VALUES(29636,66083,-6,'Spring Hill, Kansas 66083',21741,26451);
INSERT INTO "django_geo_db_zipcode" VALUES(29637,66085,-6,'Stilwell, Kansas 66085',21742,26452);
INSERT INTO "django_geo_db_zipcode" VALUES(29638,66086,-6,'Tonganoxie, Kansas 66086',21743,26453);
INSERT INTO "django_geo_db_zipcode" VALUES(29639,66087,-6,'Troy, Kansas 66087',21744,26454);
INSERT INTO "django_geo_db_zipcode" VALUES(29640,66088,-6,'Valley Falls, Kansas 66088',21745,26455);
INSERT INTO "django_geo_db_zipcode" VALUES(29641,66090,-6,'Wathena, Kansas 66090',21746,26456);
INSERT INTO "django_geo_db_zipcode" VALUES(29642,66091,-6,'Welda, Kansas 66091',21747,26457);
INSERT INTO "django_geo_db_zipcode" VALUES(29643,66092,-6,'Wellsville, Kansas 66092',21748,26458);
INSERT INTO "django_geo_db_zipcode" VALUES(29644,66093,-6,'Westphalia, Kansas 66093',21749,26459);
INSERT INTO "django_geo_db_zipcode" VALUES(29645,66094,-6,'White Cloud, Kansas 66094',21750,26460);
INSERT INTO "django_geo_db_zipcode" VALUES(29646,66095,-6,'Williamsburg, Kansas 66095',21751,26461);
INSERT INTO "django_geo_db_zipcode" VALUES(29647,66097,-6,'Winchester, Kansas 66097',21752,26462);
INSERT INTO "django_geo_db_zipcode" VALUES(29648,66101,-6,'Kansas City, Kansas 66101',21753,26463);
INSERT INTO "django_geo_db_zipcode" VALUES(29649,66102,-6,'Kansas City, Kansas 66102',21753,26464);
INSERT INTO "django_geo_db_zipcode" VALUES(29650,66103,-6,'Kansas City, Kansas 66103',21753,26465);
INSERT INTO "django_geo_db_zipcode" VALUES(29651,66104,-6,'Kansas City, Kansas 66104',21753,26466);
INSERT INTO "django_geo_db_zipcode" VALUES(29652,66105,-6,'Kansas City, Kansas 66105',21753,26467);
INSERT INTO "django_geo_db_zipcode" VALUES(29653,66106,-6,'Kansas City, Kansas 66106',21753,26468);
INSERT INTO "django_geo_db_zipcode" VALUES(29654,66109,-6,'Kansas City, Kansas 66109',21753,26469);
INSERT INTO "django_geo_db_zipcode" VALUES(29655,66110,-6,'Kansas City, Kansas 66110',21753,26470);
INSERT INTO "django_geo_db_zipcode" VALUES(29656,66111,-6,'Kansas City, Kansas 66111',21753,26471);
INSERT INTO "django_geo_db_zipcode" VALUES(29657,66112,-6,'Kansas City, Kansas 66112',21753,26472);
INSERT INTO "django_geo_db_zipcode" VALUES(29658,66113,-6,'Edwardsville, Kansas 66113',21754,26473);
INSERT INTO "django_geo_db_zipcode" VALUES(29659,66115,-6,'Kansas City, Kansas 66115',21753,26474);
INSERT INTO "django_geo_db_zipcode" VALUES(29660,66117,-6,'Kansas City, Kansas 66117',21753,26470);
INSERT INTO "django_geo_db_zipcode" VALUES(29661,66118,-6,'Kansas City, Kansas 66118',21753,26475);
INSERT INTO "django_geo_db_zipcode" VALUES(29662,66119,-6,'Kansas City, Kansas 66119',21753,26470);
INSERT INTO "django_geo_db_zipcode" VALUES(29663,66145,-6,'Centralia, Kansas 66145',21755,26476);
INSERT INTO "django_geo_db_zipcode" VALUES(29664,66151,-6,'Morrill, Kansas 66151',21756,26477);
INSERT INTO "django_geo_db_zipcode" VALUES(29665,66160,-6,'Kansas City, Kansas 66160',21753,26470);
INSERT INTO "django_geo_db_zipcode" VALUES(29666,66201,-6,'Shawnee Mission, Kansas 66201',21757,26478);
INSERT INTO "django_geo_db_zipcode" VALUES(29667,66202,-6,'Shawnee Mission, Kansas 66202',21757,26479);
INSERT INTO "django_geo_db_zipcode" VALUES(29668,66203,-6,'Shawnee Mission, Kansas 66203',21757,26480);
INSERT INTO "django_geo_db_zipcode" VALUES(29669,66204,-6,'Shawnee Mission, Kansas 66204',21757,26481);
INSERT INTO "django_geo_db_zipcode" VALUES(29670,66205,-6,'Shawnee Mission, Kansas 66205',21757,26482);
INSERT INTO "django_geo_db_zipcode" VALUES(29671,66206,-6,'Shawnee Mission, Kansas 66206',21757,26483);
INSERT INTO "django_geo_db_zipcode" VALUES(29672,66207,-6,'Shawnee Mission, Kansas 66207',21757,26484);
INSERT INTO "django_geo_db_zipcode" VALUES(29673,66208,-6,'Shawnee Mission, Kansas 66208',21757,26485);
INSERT INTO "django_geo_db_zipcode" VALUES(29674,66209,-6,'Shawnee Mission, Kansas 66209',21757,26486);
INSERT INTO "django_geo_db_zipcode" VALUES(29675,66210,-6,'Shawnee Mission, Kansas 66210',21757,26487);
INSERT INTO "django_geo_db_zipcode" VALUES(29676,66211,-6,'Shawnee Mission, Kansas 66211',21757,26488);
INSERT INTO "django_geo_db_zipcode" VALUES(29677,66212,-6,'Shawnee Mission, Kansas 66212',21757,26489);
INSERT INTO "django_geo_db_zipcode" VALUES(29678,66213,-6,'Shawnee Mission, Kansas 66213',21757,26490);
INSERT INTO "django_geo_db_zipcode" VALUES(29679,66214,-6,'Shawnee Mission, Kansas 66214',21757,26491);
INSERT INTO "django_geo_db_zipcode" VALUES(29680,66215,-6,'Shawnee Mission, Kansas 66215',21757,26492);
INSERT INTO "django_geo_db_zipcode" VALUES(29681,66216,-6,'Shawnee Mission, Kansas 66216',21757,26493);
INSERT INTO "django_geo_db_zipcode" VALUES(29682,66217,-6,'Shawnee Mission, Kansas 66217',21757,26494);
INSERT INTO "django_geo_db_zipcode" VALUES(29683,66218,-6,'Shawnee Mission, Kansas 66218',21757,26495);
INSERT INTO "django_geo_db_zipcode" VALUES(29684,66219,-6,'Shawnee Mission, Kansas 66219',21757,26496);
INSERT INTO "django_geo_db_zipcode" VALUES(29685,66220,-6,'Shawnee Mission, Kansas 66220',21757,26497);
INSERT INTO "django_geo_db_zipcode" VALUES(29686,66221,-6,'Shawnee Mission, Kansas 66221',21757,26498);
INSERT INTO "django_geo_db_zipcode" VALUES(29687,66222,-6,'Shawnee Mission, Kansas 66222',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29688,66223,-6,'Shawnee Mission, Kansas 66223',21757,26499);
INSERT INTO "django_geo_db_zipcode" VALUES(29689,66224,-6,'Shawnee Mission, Kansas 66224',21757,26500);
INSERT INTO "django_geo_db_zipcode" VALUES(29690,66225,-6,'Shawnee Mission, Kansas 66225',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29691,66226,-6,'Shawnee Mission, Kansas 66226',21757,26501);
INSERT INTO "django_geo_db_zipcode" VALUES(29692,66227,-6,'Shawnee Mission, Kansas 66227',21757,26502);
INSERT INTO "django_geo_db_zipcode" VALUES(29693,66250,-6,'Shawnee Mission, Kansas 66250',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29694,66251,-6,'Shawnee Mission, Kansas 66251',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29695,66276,-6,'Shawnee Mission, Kansas 66276',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29696,66279,-6,'Shawnee Mission, Kansas 66279',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29697,66282,-6,'Shawnee Mission, Kansas 66282',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29698,66283,-6,'Shawnee Mission, Kansas 66283',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29699,66285,-6,'Shawnee Mission, Kansas 66285',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29700,66286,-6,'Shawnee Mission, Kansas 66286',21757,26428);
INSERT INTO "django_geo_db_zipcode" VALUES(29701,66352,-6,'Robinson, Kansas 66352',21758,26503);
INSERT INTO "django_geo_db_zipcode" VALUES(29702,66356,-6,'Lincoln, Kansas 66356',21759,26504);
INSERT INTO "django_geo_db_zipcode" VALUES(29703,66401,-6,'Alma, Kansas 66401',21760,26505);
INSERT INTO "django_geo_db_zipcode" VALUES(29704,66402,-6,'Auburn, Kansas 66402',21761,26506);
INSERT INTO "django_geo_db_zipcode" VALUES(29705,66403,-6,'Axtell, Kansas 66403',21762,26507);
INSERT INTO "django_geo_db_zipcode" VALUES(29706,66404,-6,'Baileyville, Kansas 66404',21763,26508);
INSERT INTO "django_geo_db_zipcode" VALUES(29707,66406,-6,'Beattie, Kansas 66406',21764,26509);
INSERT INTO "django_geo_db_zipcode" VALUES(29708,66407,-6,'Belvue, Kansas 66407',21765,26510);
INSERT INTO "django_geo_db_zipcode" VALUES(29709,66408,-6,'Bern, Kansas 66408',21766,26511);
INSERT INTO "django_geo_db_zipcode" VALUES(29710,66409,-6,'Berryton, Kansas 66409',21767,26512);
INSERT INTO "django_geo_db_zipcode" VALUES(29711,66411,-6,'Blue Rapids, Kansas 66411',21768,26513);
INSERT INTO "django_geo_db_zipcode" VALUES(29712,66412,-6,'Bremen, Kansas 66412',21769,26514);
INSERT INTO "django_geo_db_zipcode" VALUES(29713,66413,-6,'Burlingame, Kansas 66413',21770,26515);
INSERT INTO "django_geo_db_zipcode" VALUES(29714,66414,-6,'Carbondale, Kansas 66414',21771,26516);
INSERT INTO "django_geo_db_zipcode" VALUES(29715,66415,-6,'Centralia, Kansas 66415',21755,26517);
INSERT INTO "django_geo_db_zipcode" VALUES(29716,66416,-6,'Circleville, Kansas 66416',21772,26518);
INSERT INTO "django_geo_db_zipcode" VALUES(29717,66417,-6,'Corning, Kansas 66417',21773,26519);
INSERT INTO "django_geo_db_zipcode" VALUES(29718,66418,-6,'Delia, Kansas 66418',21774,26520);
INSERT INTO "django_geo_db_zipcode" VALUES(29719,66419,-6,'Denison, Kansas 66419',21775,26521);
INSERT INTO "django_geo_db_zipcode" VALUES(29720,66420,-6,'Dover, Kansas 66420',21776,26522);
INSERT INTO "django_geo_db_zipcode" VALUES(29721,66422,-6,'Emmett, Kansas 66422',21777,26523);
INSERT INTO "django_geo_db_zipcode" VALUES(29722,66423,-6,'Eskridge, Kansas 66423',21778,26524);
INSERT INTO "django_geo_db_zipcode" VALUES(29723,66424,-6,'Everest, Kansas 66424',21779,26525);
INSERT INTO "django_geo_db_zipcode" VALUES(29724,66425,-6,'Fairview, Kansas 66425',21780,26526);
INSERT INTO "django_geo_db_zipcode" VALUES(29725,66426,-6,'Fostoria, Kansas 66426',21781,26527);
INSERT INTO "django_geo_db_zipcode" VALUES(29726,66427,-6,'Frankfort, Kansas 66427',21782,26528);
INSERT INTO "django_geo_db_zipcode" VALUES(29727,66428,-6,'Goff, Kansas 66428',21783,26529);
INSERT INTO "django_geo_db_zipcode" VALUES(29728,66429,-6,'Grantville, Kansas 66429',21784,26530);
INSERT INTO "django_geo_db_zipcode" VALUES(29729,66431,-6,'Harveyville, Kansas 66431',21785,26531);
INSERT INTO "django_geo_db_zipcode" VALUES(29730,66432,-6,'Havensville, Kansas 66432',21786,26532);
INSERT INTO "django_geo_db_zipcode" VALUES(29731,66434,-6,'Hiawatha, Kansas 66434',21787,26533);
INSERT INTO "django_geo_db_zipcode" VALUES(29732,66436,-6,'Holton, Kansas 66436',21788,26534);
INSERT INTO "django_geo_db_zipcode" VALUES(29733,66438,-6,'Home, Kansas 66438',21789,26535);
INSERT INTO "django_geo_db_zipcode" VALUES(29734,66439,-6,'Horton, Kansas 66439',21790,26536);
INSERT INTO "django_geo_db_zipcode" VALUES(29735,66440,-6,'Hoyt, Kansas 66440',21791,26537);
INSERT INTO "django_geo_db_zipcode" VALUES(29736,66441,-6,'Junction City, Kansas 66441',21792,26538);
INSERT INTO "django_geo_db_zipcode" VALUES(29737,66442,-6,'Fort Riley, Kansas 66442',21793,26539);
INSERT INTO "django_geo_db_zipcode" VALUES(29738,66449,-6,'Leonardville, Kansas 66449',21794,26540);
INSERT INTO "django_geo_db_zipcode" VALUES(29739,66450,-6,'Louisville, Kansas 66450',21795,26541);
INSERT INTO "django_geo_db_zipcode" VALUES(29740,66451,-6,'Lyndon, Kansas 66451',21796,26542);
INSERT INTO "django_geo_db_zipcode" VALUES(29741,66481,-6,'Weir, Kansas 66481',21797,26543);
INSERT INTO "django_geo_db_zipcode" VALUES(29742,66501,-6,'McFarland, Kansas 66501',21798,26544);
INSERT INTO "django_geo_db_zipcode" VALUES(29743,66502,-6,'Manhattan, Kansas 66502',21799,26545);
INSERT INTO "django_geo_db_zipcode" VALUES(29744,66503,-6,'Manhattan, Kansas 66503',21799,26546);
INSERT INTO "django_geo_db_zipcode" VALUES(29745,66505,-6,'Manhattan, Kansas 66505',21799,26547);
INSERT INTO "django_geo_db_zipcode" VALUES(29746,66506,-6,'Manhattan, Kansas 66506',21799,26548);
INSERT INTO "django_geo_db_zipcode" VALUES(29747,66507,-6,'Maple Hill, Kansas 66507',21800,26549);
INSERT INTO "django_geo_db_zipcode" VALUES(29748,66508,-6,'Marysville, Kansas 66508',21801,26550);
INSERT INTO "django_geo_db_zipcode" VALUES(29749,66509,-6,'Mayetta, Kansas 66509',21802,26551);
INSERT INTO "django_geo_db_zipcode" VALUES(29750,66510,-6,'Melvern, Kansas 66510',21803,26552);
INSERT INTO "django_geo_db_zipcode" VALUES(29751,66512,-6,'Meriden, Kansas 66512',21804,26553);
INSERT INTO "django_geo_db_zipcode" VALUES(29752,66514,-6,'Milford, Kansas 66514',21805,26554);
INSERT INTO "django_geo_db_zipcode" VALUES(29753,66515,-6,'Morrill, Kansas 66515',21756,26555);
INSERT INTO "django_geo_db_zipcode" VALUES(29754,66516,-6,'Netawaka, Kansas 66516',21806,26556);
INSERT INTO "django_geo_db_zipcode" VALUES(29755,66517,-6,'Ogden, Kansas 66517',21807,26557);
INSERT INTO "django_geo_db_zipcode" VALUES(29756,66518,-6,'Oketo, Kansas 66518',21808,26558);
INSERT INTO "django_geo_db_zipcode" VALUES(29757,66520,-6,'Olsburg, Kansas 66520',21809,26559);
INSERT INTO "django_geo_db_zipcode" VALUES(29758,66521,-6,'Onaga, Kansas 66521',21810,26560);
INSERT INTO "django_geo_db_zipcode" VALUES(29759,66522,-6,'Oneida, Kansas 66522',21811,26561);
INSERT INTO "django_geo_db_zipcode" VALUES(29760,66523,-6,'Osage City, Kansas 66523',21812,26562);
INSERT INTO "django_geo_db_zipcode" VALUES(29761,66524,-6,'Overbrook, Kansas 66524',21813,26563);
INSERT INTO "django_geo_db_zipcode" VALUES(29762,66526,-6,'Paxico, Kansas 66526',21814,26564);
INSERT INTO "django_geo_db_zipcode" VALUES(29763,66527,-6,'Powhattan, Kansas 66527',21815,26565);
INSERT INTO "django_geo_db_zipcode" VALUES(29764,66528,-6,'Quenemo, Kansas 66528',21816,26566);
INSERT INTO "django_geo_db_zipcode" VALUES(29765,66531,-6,'Riley, Kansas 66531',21817,26567);
INSERT INTO "django_geo_db_zipcode" VALUES(29766,66532,-6,'Robinson, Kansas 66532',21758,26568);
INSERT INTO "django_geo_db_zipcode" VALUES(29767,66533,-6,'Rossville, Kansas 66533',21818,26569);
INSERT INTO "django_geo_db_zipcode" VALUES(29768,66534,-6,'Sabetha, Kansas 66534',21819,26570);
INSERT INTO "django_geo_db_zipcode" VALUES(29769,66535,-6,'Saint George, Kansas 66535',21820,26571);
INSERT INTO "django_geo_db_zipcode" VALUES(29770,66536,-6,'Saint Marys, Kansas 66536',21821,26572);
INSERT INTO "django_geo_db_zipcode" VALUES(29771,66537,-6,'Scranton, Kansas 66537',21822,26573);
INSERT INTO "django_geo_db_zipcode" VALUES(29772,66538,-6,'Seneca, Kansas 66538',21823,26574);
INSERT INTO "django_geo_db_zipcode" VALUES(29773,66539,-6,'Silver Lake, Kansas 66539',21824,26575);
INSERT INTO "django_geo_db_zipcode" VALUES(29774,66540,-6,'Soldier, Kansas 66540',21825,26576);
INSERT INTO "django_geo_db_zipcode" VALUES(29775,66541,-6,'Summerfield, Kansas 66541',21826,26577);
INSERT INTO "django_geo_db_zipcode" VALUES(29776,66542,-6,'Tecumseh, Kansas 66542',21827,26578);
INSERT INTO "django_geo_db_zipcode" VALUES(29777,66543,-6,'Vassar, Kansas 66543',21828,26579);
INSERT INTO "django_geo_db_zipcode" VALUES(29778,66544,-6,'Vermillion, Kansas 66544',21829,26580);
INSERT INTO "django_geo_db_zipcode" VALUES(29779,66546,-6,'Wakarusa, Kansas 66546',21830,26581);
INSERT INTO "django_geo_db_zipcode" VALUES(29780,66547,-6,'Wamego, Kansas 66547',21831,26582);
INSERT INTO "django_geo_db_zipcode" VALUES(29781,66548,-6,'Waterville, Kansas 66548',21832,26583);
INSERT INTO "django_geo_db_zipcode" VALUES(29782,66549,-6,'Westmoreland, Kansas 66549',21833,26584);
INSERT INTO "django_geo_db_zipcode" VALUES(29783,66550,-6,'Wetmore, Kansas 66550',21834,26585);
INSERT INTO "django_geo_db_zipcode" VALUES(29784,66551,-6,'Wheaton, Kansas 66551',21835,26586);
INSERT INTO "django_geo_db_zipcode" VALUES(29785,66552,-6,'Whiting, Kansas 66552',21836,26587);
INSERT INTO "django_geo_db_zipcode" VALUES(29786,66554,-6,'Randolph, Kansas 66554',21837,26588);
INSERT INTO "django_geo_db_zipcode" VALUES(29787,66555,-6,'Marysville, Kansas 66555',21801,26589);
INSERT INTO "django_geo_db_zipcode" VALUES(29788,66601,-6,'Topeka, Kansas 66601',21838,26590);
INSERT INTO "django_geo_db_zipcode" VALUES(29789,66603,-6,'Topeka, Kansas 66603',21838,26591);
INSERT INTO "django_geo_db_zipcode" VALUES(29790,66604,-6,'Topeka, Kansas 66604',21838,26592);
INSERT INTO "django_geo_db_zipcode" VALUES(29791,66605,-6,'Topeka, Kansas 66605',21838,26593);
INSERT INTO "django_geo_db_zipcode" VALUES(29792,66606,-6,'Topeka, Kansas 66606',21838,26594);
INSERT INTO "django_geo_db_zipcode" VALUES(29793,66607,-6,'Topeka, Kansas 66607',21838,26595);
INSERT INTO "django_geo_db_zipcode" VALUES(29794,66608,-6,'Topeka, Kansas 66608',21838,26596);
INSERT INTO "django_geo_db_zipcode" VALUES(29795,66609,-6,'Topeka, Kansas 66609',21838,26597);
INSERT INTO "django_geo_db_zipcode" VALUES(29796,66610,-6,'Topeka, Kansas 66610',21838,26598);
INSERT INTO "django_geo_db_zipcode" VALUES(29797,66611,-6,'Topeka, Kansas 66611',21838,26599);
INSERT INTO "django_geo_db_zipcode" VALUES(29798,66612,-6,'Topeka, Kansas 66612',21838,26600);
INSERT INTO "django_geo_db_zipcode" VALUES(29799,66614,-6,'Topeka, Kansas 66614',21838,26601);
INSERT INTO "django_geo_db_zipcode" VALUES(29800,66615,-6,'Topeka, Kansas 66615',21838,26602);
INSERT INTO "django_geo_db_zipcode" VALUES(29801,66616,-6,'Topeka, Kansas 66616',21838,26603);
INSERT INTO "django_geo_db_zipcode" VALUES(29802,66617,-6,'Topeka, Kansas 66617',21838,26604);
INSERT INTO "django_geo_db_zipcode" VALUES(29803,66618,-6,'Topeka, Kansas 66618',21838,26605);
INSERT INTO "django_geo_db_zipcode" VALUES(29804,66619,-6,'Topeka, Kansas 66619',21838,26606);
INSERT INTO "django_geo_db_zipcode" VALUES(29805,66620,-6,'Topeka, Kansas 66620',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29806,66621,-6,'Topeka, Kansas 66621',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29807,66622,-6,'Topeka, Kansas 66622',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29808,66624,-6,'Topeka, Kansas 66624',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29809,66625,-6,'Topeka, Kansas 66625',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29810,66626,-6,'Topeka, Kansas 66626',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29811,66628,-6,'Topeka, Kansas 66628',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29812,66629,-6,'Topeka, Kansas 66629',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29813,66634,-6,'Topeka, Kansas 66634',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29814,66635,-6,'St. George, Kansas 66635',21839,26608);
INSERT INTO "django_geo_db_zipcode" VALUES(29815,66636,-6,'Topeka, Kansas 66636',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29816,66637,-6,'Topeka, Kansas 66637',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29817,66638,-6,'Topeka, Kansas 66638',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29818,66642,-6,'Topeka, Kansas 66642',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29819,66647,-6,'Topeka, Kansas 66647',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29820,66650,-6,'Powhattan, Kansas 66650',21815,26609);
INSERT INTO "django_geo_db_zipcode" VALUES(29821,66652,-6,'Topeka, Kansas 66652',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29822,66653,-6,'Topeka, Kansas 66653',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29823,66658,-6,'Topeka, Kansas 66658',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29824,66667,-6,'Topeka, Kansas 66667',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29825,66675,-6,'Topeka, Kansas 66675',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29826,66683,-6,'Topeka, Kansas 66683',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29827,66686,-6,'Topeka, Kansas 66686',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29828,66692,-6,'Topeka, Kansas 66692',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29829,66699,-6,'Topeka, Kansas 66699',21838,26607);
INSERT INTO "django_geo_db_zipcode" VALUES(29830,66701,-6,'Fort Scott, Kansas 66701',21840,26610);
INSERT INTO "django_geo_db_zipcode" VALUES(29831,66710,-6,'Altoona, Kansas 66710',21841,26611);
INSERT INTO "django_geo_db_zipcode" VALUES(29832,66711,-6,'Arcadia, Kansas 66711',21842,26612);
INSERT INTO "django_geo_db_zipcode" VALUES(29833,66712,-6,'Arma, Kansas 66712',21843,26613);
INSERT INTO "django_geo_db_zipcode" VALUES(29834,66713,-6,'Baxter Springs, Kansas 66713',21844,26614);
INSERT INTO "django_geo_db_zipcode" VALUES(29835,66714,-6,'Benedict, Kansas 66714',21845,26615);
INSERT INTO "django_geo_db_zipcode" VALUES(29836,66716,-6,'Bronson, Kansas 66716',21846,26616);
INSERT INTO "django_geo_db_zipcode" VALUES(29837,66717,-6,'Buffalo, Kansas 66717',21847,26617);
INSERT INTO "django_geo_db_zipcode" VALUES(29838,66720,-6,'Chanute, Kansas 66720',21848,26618);
INSERT INTO "django_geo_db_zipcode" VALUES(29839,66721,-6,'Lincoln, Kansas 66721',21759,26619);
INSERT INTO "django_geo_db_zipcode" VALUES(29840,66724,-6,'Cherokee, Kansas 66724',21849,26620);
INSERT INTO "django_geo_db_zipcode" VALUES(29841,66725,-6,'Columbus, Kansas 66725',21850,26621);
INSERT INTO "django_geo_db_zipcode" VALUES(29842,66727,-6,'Coyville, Kansas 66727',21851,26622);
INSERT INTO "django_geo_db_zipcode" VALUES(29843,66728,-6,'Crestline, Kansas 66728',21852,26623);
INSERT INTO "django_geo_db_zipcode" VALUES(29844,66732,-6,'Elsmore, Kansas 66732',21853,26624);
INSERT INTO "django_geo_db_zipcode" VALUES(29845,66733,-6,'Erie, Kansas 66733',21854,26625);
INSERT INTO "django_geo_db_zipcode" VALUES(29846,66734,-6,'Farlington, Kansas 66734',21855,26626);
INSERT INTO "django_geo_db_zipcode" VALUES(29847,66735,-6,'Franklin, Kansas 66735',21856,26627);
INSERT INTO "django_geo_db_zipcode" VALUES(29848,66736,-6,'Fredonia, Kansas 66736',21857,26628);
INSERT INTO "django_geo_db_zipcode" VALUES(29849,66738,-6,'Fulton, Kansas 66738',21858,26629);
INSERT INTO "django_geo_db_zipcode" VALUES(29850,66739,-6,'Galena, Kansas 66739',21859,26630);
INSERT INTO "django_geo_db_zipcode" VALUES(29851,66740,-6,'Galesburg, Kansas 66740',21860,26631);
INSERT INTO "django_geo_db_zipcode" VALUES(29852,66741,-6,'Arcadia, Kansas 66741',21842,26632);
INSERT INTO "django_geo_db_zipcode" VALUES(29853,66742,-6,'Gas, Kansas 66742',21861,26633);
INSERT INTO "django_geo_db_zipcode" VALUES(29854,66743,-6,'Girard, Kansas 66743',21862,26634);
INSERT INTO "django_geo_db_zipcode" VALUES(29855,66746,-6,'Hepler, Kansas 66746',21863,26635);
INSERT INTO "django_geo_db_zipcode" VALUES(29856,66747,-6,'Neodesha, Kansas 66747',21864,26636);
INSERT INTO "django_geo_db_zipcode" VALUES(29857,66748,-6,'Humboldt, Kansas 66748',21865,26637);
INSERT INTO "django_geo_db_zipcode" VALUES(29858,66749,-6,'Iola, Kansas 66749',21866,26638);
INSERT INTO "django_geo_db_zipcode" VALUES(29859,66751,-6,'La Harpe, Kansas 66751',21867,26639);
INSERT INTO "django_geo_db_zipcode" VALUES(29860,66752,-6,'Ross, Kansas 66752',21868,26640);
INSERT INTO "django_geo_db_zipcode" VALUES(29861,66753,-6,'McCune, Kansas 66753',21869,26641);
INSERT INTO "django_geo_db_zipcode" VALUES(29862,66754,-6,'Mapleton, Kansas 66754',21870,26642);
INSERT INTO "django_geo_db_zipcode" VALUES(29863,66755,-6,'Moran, Kansas 66755',21871,26643);
INSERT INTO "django_geo_db_zipcode" VALUES(29864,66756,-6,'Mulberry, Kansas 66756',21872,26644);
INSERT INTO "django_geo_db_zipcode" VALUES(29865,66757,-6,'Neodesha, Kansas 66757',21864,26645);
INSERT INTO "django_geo_db_zipcode" VALUES(29866,66758,-6,'Neosho Falls, Kansas 66758',21873,26646);
INSERT INTO "django_geo_db_zipcode" VALUES(29867,66759,-6,'New Albany, Kansas 66759',21874,26647);
INSERT INTO "django_geo_db_zipcode" VALUES(29868,66760,-6,'Opolis, Kansas 66760',21875,26648);
INSERT INTO "django_geo_db_zipcode" VALUES(29869,66761,-6,'Piqua, Kansas 66761',21876,26649);
INSERT INTO "django_geo_db_zipcode" VALUES(29870,66762,-6,'Pittsburg, Kansas 66762',21877,26650);
INSERT INTO "django_geo_db_zipcode" VALUES(29871,66763,-6,'Frontenac, Kansas 66763',21878,26651);
INSERT INTO "django_geo_db_zipcode" VALUES(29872,66767,-6,'Prescott, Kansas 66767',21879,26652);
INSERT INTO "django_geo_db_zipcode" VALUES(29873,66769,-6,'Redfield, Kansas 66769',21880,26653);
INSERT INTO "django_geo_db_zipcode" VALUES(29874,66770,-6,'Riverton, Kansas 66770',21881,26654);
INSERT INTO "django_geo_db_zipcode" VALUES(29875,66771,-6,'Saint Paul, Kansas 66771',21882,26655);
INSERT INTO "django_geo_db_zipcode" VALUES(29876,66772,-6,'Savonburg, Kansas 66772',21883,26656);
INSERT INTO "django_geo_db_zipcode" VALUES(29877,66773,-6,'Scammon, Kansas 66773',21884,26657);
INSERT INTO "django_geo_db_zipcode" VALUES(29878,66775,-6,'Stark, Kansas 66775',21885,26658);
INSERT INTO "django_geo_db_zipcode" VALUES(29879,66776,-6,'Thayer, Kansas 66776',21886,26659);
INSERT INTO "django_geo_db_zipcode" VALUES(29880,66777,-6,'Toronto, Kansas 66777',21887,26660);
INSERT INTO "django_geo_db_zipcode" VALUES(29881,66778,-6,'Treece, Kansas 66778',21888,26661);
INSERT INTO "django_geo_db_zipcode" VALUES(29882,66779,-6,'Uniontown, Kansas 66779',21889,26662);
INSERT INTO "django_geo_db_zipcode" VALUES(29883,66780,-6,'Walnut, Kansas 66780',21890,26663);
INSERT INTO "django_geo_db_zipcode" VALUES(29884,66781,-6,'Weir, Kansas 66781',21797,26664);
INSERT INTO "django_geo_db_zipcode" VALUES(29885,66782,-6,'West Mineral, Kansas 66782',21891,26665);
INSERT INTO "django_geo_db_zipcode" VALUES(29886,66783,-6,'Yates Center, Kansas 66783',21892,26666);
INSERT INTO "django_geo_db_zipcode" VALUES(29887,66801,-6,'Emporia, Kansas 66801',21893,26667);
INSERT INTO "django_geo_db_zipcode" VALUES(29888,66804,-6,'Bern, Kansas 66804',21766,26668);
INSERT INTO "django_geo_db_zipcode" VALUES(29889,66830,-6,'Admire, Kansas 66830',21894,26669);
INSERT INTO "django_geo_db_zipcode" VALUES(29890,66833,-6,'Allen, Kansas 66833',21895,26670);
INSERT INTO "django_geo_db_zipcode" VALUES(29891,66834,-6,'Alta Vista, Kansas 66834',21896,26671);
INSERT INTO "django_geo_db_zipcode" VALUES(29892,66835,-6,'Americus, Kansas 66835',21897,26672);
INSERT INTO "django_geo_db_zipcode" VALUES(29893,66838,-6,'Burdick, Kansas 66838',21898,26673);
INSERT INTO "django_geo_db_zipcode" VALUES(29894,66839,-6,'Burlington, Kansas 66839',21899,26674);
INSERT INTO "django_geo_db_zipcode" VALUES(29895,66840,-6,'Burns, Kansas 66840',21900,26675);
INSERT INTO "django_geo_db_zipcode" VALUES(29896,66842,-6,'Cassoday, Kansas 66842',21901,26676);
INSERT INTO "django_geo_db_zipcode" VALUES(29897,66843,-6,'Cedar Point, Kansas 66843',21902,26677);
INSERT INTO "django_geo_db_zipcode" VALUES(29898,66845,-6,'Cottonwood Falls, Kansas 66845',21903,26678);
INSERT INTO "django_geo_db_zipcode" VALUES(29899,66846,-6,'Council Grove, Kansas 66846',21904,26679);
INSERT INTO "django_geo_db_zipcode" VALUES(29900,66849,-6,'Dwight, Kansas 66849',21905,26680);
INSERT INTO "django_geo_db_zipcode" VALUES(29901,66850,-6,'Elmdale, Kansas 66850',21906,26681);
INSERT INTO "django_geo_db_zipcode" VALUES(29902,66851,-6,'Florence, Kansas 66851',21907,26682);
INSERT INTO "django_geo_db_zipcode" VALUES(29903,66852,-6,'Gridley, Kansas 66852',21908,26683);
INSERT INTO "django_geo_db_zipcode" VALUES(29904,66853,-6,'Hamilton, Kansas 66853',21909,26684);
INSERT INTO "django_geo_db_zipcode" VALUES(29905,66854,-6,'Hartford, Kansas 66854',21910,26685);
INSERT INTO "django_geo_db_zipcode" VALUES(29906,66855,-6,'Lamont, Kansas 66855',21911,26686);
INSERT INTO "django_geo_db_zipcode" VALUES(29907,66856,-6,'Lebo, Kansas 66856',21912,26687);
INSERT INTO "django_geo_db_zipcode" VALUES(29908,66857,-6,'Le Roy, Kansas 66857',21913,26688);
INSERT INTO "django_geo_db_zipcode" VALUES(29909,66858,-6,'Lincolnville, Kansas 66858',21914,26689);
INSERT INTO "django_geo_db_zipcode" VALUES(29910,66859,-6,'Lost Springs, Kansas 66859',21915,26690);
INSERT INTO "django_geo_db_zipcode" VALUES(29911,66860,-6,'Madison, Kansas 66860',21916,26691);
INSERT INTO "django_geo_db_zipcode" VALUES(29912,66861,-6,'Marion, Kansas 66861',21917,26692);
INSERT INTO "django_geo_db_zipcode" VALUES(29913,66862,-6,'Matfield Green, Kansas 66862',21918,26693);
INSERT INTO "django_geo_db_zipcode" VALUES(29914,66863,-6,'Neal, Kansas 66863',21919,26694);
INSERT INTO "django_geo_db_zipcode" VALUES(29915,66864,-6,'Neosho Rapids, Kansas 66864',21920,26695);
INSERT INTO "django_geo_db_zipcode" VALUES(29916,66865,-6,'Olpe, Kansas 66865',21921,26696);
INSERT INTO "django_geo_db_zipcode" VALUES(29917,66866,-6,'Peabody, Kansas 66866',21922,26697);
INSERT INTO "django_geo_db_zipcode" VALUES(29918,66868,-6,'Reading, Kansas 66868',21923,26698);
INSERT INTO "django_geo_db_zipcode" VALUES(29919,66869,-6,'Strong City, Kansas 66869',21924,26699);
INSERT INTO "django_geo_db_zipcode" VALUES(29920,66870,-6,'Virgil, Kansas 66870',21925,26700);
INSERT INTO "django_geo_db_zipcode" VALUES(29921,66871,-6,'Waverly, Kansas 66871',21926,26701);
INSERT INTO "django_geo_db_zipcode" VALUES(29922,66872,-6,'White City, Kansas 66872',21927,26702);
INSERT INTO "django_geo_db_zipcode" VALUES(29923,66873,-6,'Wilsey, Kansas 66873',21928,26703);
INSERT INTO "django_geo_db_zipcode" VALUES(29924,66901,-6,'Concordia, Kansas 66901',21929,26704);
INSERT INTO "django_geo_db_zipcode" VALUES(29925,66930,-6,'Agenda, Kansas 66930',21930,26705);
INSERT INTO "django_geo_db_zipcode" VALUES(29926,66932,-6,'Athol, Kansas 66932',21931,26706);
INSERT INTO "django_geo_db_zipcode" VALUES(29927,66933,-6,'Barnes, Kansas 66933',21932,26707);
INSERT INTO "django_geo_db_zipcode" VALUES(29928,66935,-6,'Belleville, Kansas 66935',21933,26708);
INSERT INTO "django_geo_db_zipcode" VALUES(29929,66936,-6,'Burr Oak, Kansas 66936',21934,26709);
INSERT INTO "django_geo_db_zipcode" VALUES(29930,66937,-6,'Clifton, Kansas 66937',21935,26710);
INSERT INTO "django_geo_db_zipcode" VALUES(29931,66938,-6,'Clyde, Kansas 66938',21936,26711);
INSERT INTO "django_geo_db_zipcode" VALUES(29932,66939,-6,'Courtland, Kansas 66939',21937,26712);
INSERT INTO "django_geo_db_zipcode" VALUES(29933,66940,-6,'Cuba, Kansas 66940',21938,26713);
INSERT INTO "django_geo_db_zipcode" VALUES(29934,66941,-6,'Esbon, Kansas 66941',21939,26714);
INSERT INTO "django_geo_db_zipcode" VALUES(29935,66942,-6,'Formoso, Kansas 66942',21940,26715);
INSERT INTO "django_geo_db_zipcode" VALUES(29936,66943,-6,'Greenleaf, Kansas 66943',21941,26716);
INSERT INTO "django_geo_db_zipcode" VALUES(29937,66944,-6,'Haddam, Kansas 66944',21942,26717);
INSERT INTO "django_geo_db_zipcode" VALUES(29938,66945,-6,'Hanover, Kansas 66945',21943,26718);
INSERT INTO "django_geo_db_zipcode" VALUES(29939,66946,-6,'Hollenberg, Kansas 66946',21944,26719);
INSERT INTO "django_geo_db_zipcode" VALUES(29940,66948,-6,'Jamestown, Kansas 66948',21945,26720);
INSERT INTO "django_geo_db_zipcode" VALUES(29941,66949,-6,'Jewell, Kansas 66949',21946,26721);
INSERT INTO "django_geo_db_zipcode" VALUES(29942,66951,-6,'Kensington, Kansas 66951',21947,26722);
INSERT INTO "django_geo_db_zipcode" VALUES(29943,66952,-6,'Lebanon, Kansas 66952',21948,26723);
INSERT INTO "django_geo_db_zipcode" VALUES(29944,66953,-6,'Linn, Kansas 66953',21949,26724);
INSERT INTO "django_geo_db_zipcode" VALUES(29945,66955,-6,'Mahaska, Kansas 66955',21950,26725);
INSERT INTO "django_geo_db_zipcode" VALUES(29946,66956,-6,'Mankato, Kansas 66956',21951,26726);
INSERT INTO "django_geo_db_zipcode" VALUES(29947,66958,-6,'Morrowville, Kansas 66958',21952,26727);
INSERT INTO "django_geo_db_zipcode" VALUES(29948,66959,-6,'Munden, Kansas 66959',21953,26728);
INSERT INTO "django_geo_db_zipcode" VALUES(29949,66960,-6,'Narka, Kansas 66960',21954,26729);
INSERT INTO "django_geo_db_zipcode" VALUES(29950,66961,-6,'Norway, Kansas 66961',21955,26730);
INSERT INTO "django_geo_db_zipcode" VALUES(29951,66962,-6,'Palmer, Kansas 66962',21956,26731);
INSERT INTO "django_geo_db_zipcode" VALUES(29952,66963,-6,'Randall, Kansas 66963',21957,26732);
INSERT INTO "django_geo_db_zipcode" VALUES(29953,66964,-6,'Republic, Kansas 66964',21958,26733);
INSERT INTO "django_geo_db_zipcode" VALUES(29954,66966,-6,'Scandia, Kansas 66966',21959,26734);
INSERT INTO "django_geo_db_zipcode" VALUES(29955,66967,-6,'Smith Center, Kansas 66967',21960,26735);
INSERT INTO "django_geo_db_zipcode" VALUES(29956,66968,-6,'Washington, Kansas 66968',21961,26736);
INSERT INTO "django_geo_db_zipcode" VALUES(29957,66969,-6,'Scandia, Kansas 66969',21959,26737);
INSERT INTO "django_geo_db_zipcode" VALUES(29958,66970,-6,'Webber, Kansas 66970',21962,26738);
INSERT INTO "django_geo_db_zipcode" VALUES(29959,66998,-6,'Buffalo, Kansas 66998',21847,26739);
INSERT INTO "django_geo_db_zipcode" VALUES(29960,67001,-6,'Andale, Kansas 67001',21963,26740);
INSERT INTO "django_geo_db_zipcode" VALUES(29961,67002,-6,'Andover, Kansas 67002',21964,26741);
INSERT INTO "django_geo_db_zipcode" VALUES(29962,67003,-6,'Anthony, Kansas 67003',21965,26742);
INSERT INTO "django_geo_db_zipcode" VALUES(29963,67004,-6,'Argonia, Kansas 67004',21966,26743);
INSERT INTO "django_geo_db_zipcode" VALUES(29964,67005,-6,'Arkansas City, Kansas 67005',21967,26744);
INSERT INTO "django_geo_db_zipcode" VALUES(29965,67008,-6,'Atlanta, Kansas 67008',21968,26745);
INSERT INTO "django_geo_db_zipcode" VALUES(29966,67009,-6,'Attica, Kansas 67009',21969,26746);
INSERT INTO "django_geo_db_zipcode" VALUES(29967,67010,-6,'Augusta, Kansas 67010',21970,26747);
INSERT INTO "django_geo_db_zipcode" VALUES(29968,67012,-6,'Beaumont, Kansas 67012',21971,26748);
INSERT INTO "django_geo_db_zipcode" VALUES(29969,67013,-6,'Belle Plaine, Kansas 67013',21972,26749);
INSERT INTO "django_geo_db_zipcode" VALUES(29970,67016,-6,'Bentley, Kansas 67016',21973,26750);
INSERT INTO "django_geo_db_zipcode" VALUES(29971,67017,-6,'Benton, Kansas 67017',21974,26751);
INSERT INTO "django_geo_db_zipcode" VALUES(29972,67018,-6,'Bluff City, Kansas 67018',21975,26752);
INSERT INTO "django_geo_db_zipcode" VALUES(29973,67019,-6,'Burden, Kansas 67019',21976,26753);
INSERT INTO "django_geo_db_zipcode" VALUES(29974,67020,-6,'Burrton, Kansas 67020',21977,26754);
INSERT INTO "django_geo_db_zipcode" VALUES(29975,67021,-6,'Byers, Kansas 67021',21978,26755);
INSERT INTO "django_geo_db_zipcode" VALUES(29976,67022,-6,'Caldwell, Kansas 67022',21979,26756);
INSERT INTO "django_geo_db_zipcode" VALUES(29977,67023,-6,'Cambridge, Kansas 67023',21980,26757);
INSERT INTO "django_geo_db_zipcode" VALUES(29978,67024,-6,'Cedar Vale, Kansas 67024',21981,26758);
INSERT INTO "django_geo_db_zipcode" VALUES(29979,67025,-6,'Cheney, Kansas 67025',21982,26759);
INSERT INTO "django_geo_db_zipcode" VALUES(29980,67026,-6,'Clearwater, Kansas 67026',21983,26760);
INSERT INTO "django_geo_db_zipcode" VALUES(29981,67028,-6,'Coats, Kansas 67028',21984,26761);
INSERT INTO "django_geo_db_zipcode" VALUES(29982,67029,-6,'Coldwater, Kansas 67029',21985,26762);
INSERT INTO "django_geo_db_zipcode" VALUES(29983,67030,-6,'Colwich, Kansas 67030',21986,26763);
INSERT INTO "django_geo_db_zipcode" VALUES(29984,67031,-6,'Conway Springs, Kansas 67031',21987,26764);
INSERT INTO "django_geo_db_zipcode" VALUES(29985,67033,-6,'Richland, Kansas 67033',21988,26765);
INSERT INTO "django_geo_db_zipcode" VALUES(29986,67035,-6,'Cunningham, Kansas 67035',21989,26766);
INSERT INTO "django_geo_db_zipcode" VALUES(29987,67036,-6,'Danville, Kansas 67036',21990,26767);
INSERT INTO "django_geo_db_zipcode" VALUES(29988,67037,-6,'Derby, Kansas 67037',21991,26768);
INSERT INTO "django_geo_db_zipcode" VALUES(29989,67038,-6,'Dexter, Kansas 67038',21992,26769);
INSERT INTO "django_geo_db_zipcode" VALUES(29990,67039,-6,'Douglass, Kansas 67039',21993,26770);
INSERT INTO "django_geo_db_zipcode" VALUES(29991,67041,-6,'Elbing, Kansas 67041',21994,26771);
INSERT INTO "django_geo_db_zipcode" VALUES(29992,67042,-6,'El Dorado, Kansas 67042',21995,26772);
INSERT INTO "django_geo_db_zipcode" VALUES(29993,67045,-6,'Eureka, Kansas 67045',21996,26773);
INSERT INTO "django_geo_db_zipcode" VALUES(29994,67047,-6,'Fall River, Kansas 67047',21997,26774);
INSERT INTO "django_geo_db_zipcode" VALUES(29995,67049,-6,'Freeport, Kansas 67049',21998,26775);
INSERT INTO "django_geo_db_zipcode" VALUES(29996,67050,-6,'Garden Plain, Kansas 67050',21999,26776);
INSERT INTO "django_geo_db_zipcode" VALUES(29997,67051,-6,'Geuda Springs, Kansas 67051',22000,26777);
INSERT INTO "django_geo_db_zipcode" VALUES(29998,67052,-6,'Goddard, Kansas 67052',22001,26778);
INSERT INTO "django_geo_db_zipcode" VALUES(29999,67053,-6,'Goessel, Kansas 67053',22002,26779);
INSERT INTO "django_geo_db_zipcode" VALUES(30000,67054,-6,'Greensburg, Kansas 67054',22003,26780);
INSERT INTO "django_geo_db_zipcode" VALUES(30001,67055,-6,'Greenwich, Kansas 67055',22004,26781);
INSERT INTO "django_geo_db_zipcode" VALUES(30002,67056,-6,'Halstead, Kansas 67056',22005,26782);
INSERT INTO "django_geo_db_zipcode" VALUES(30003,67057,-6,'Hardtner, Kansas 67057',22006,26783);
INSERT INTO "django_geo_db_zipcode" VALUES(30004,67058,-6,'Harper, Kansas 67058',22007,26784);
INSERT INTO "django_geo_db_zipcode" VALUES(30005,67059,-6,'Haviland, Kansas 67059',22008,26785);
INSERT INTO "django_geo_db_zipcode" VALUES(30006,67060,-6,'Haysville, Kansas 67060',22009,26786);
INSERT INTO "django_geo_db_zipcode" VALUES(30007,67061,-6,'Hazelton, Kansas 67061',22010,26787);
INSERT INTO "django_geo_db_zipcode" VALUES(30008,67062,-6,'Hesston, Kansas 67062',22011,26788);
INSERT INTO "django_geo_db_zipcode" VALUES(30009,67063,-6,'Hillsboro, Kansas 67063',22012,26789);
INSERT INTO "django_geo_db_zipcode" VALUES(30010,67065,-6,'Isabel, Kansas 67065',22013,26790);
INSERT INTO "django_geo_db_zipcode" VALUES(30011,67066,-6,'Iuka, Kansas 67066',22014,26791);
INSERT INTO "django_geo_db_zipcode" VALUES(30012,67067,-6,'Kechi, Kansas 67067',22015,26792);
INSERT INTO "django_geo_db_zipcode" VALUES(30013,67068,-6,'Kingman, Kansas 67068',22016,26793);
INSERT INTO "django_geo_db_zipcode" VALUES(30014,67069,-6,'Ninnescah, Kansas 67069',22017,26794);
INSERT INTO "django_geo_db_zipcode" VALUES(30015,67070,-6,'Kiowa, Kansas 67070',22018,26795);
INSERT INTO "django_geo_db_zipcode" VALUES(30016,67071,-6,'Lake City, Kansas 67071',22019,26796);
INSERT INTO "django_geo_db_zipcode" VALUES(30017,67072,-6,'Latham, Kansas 67072',22020,26797);
INSERT INTO "django_geo_db_zipcode" VALUES(30018,67073,-6,'Lehigh, Kansas 67073',22021,26798);
INSERT INTO "django_geo_db_zipcode" VALUES(30019,67074,-6,'Leon, Kansas 67074',22022,26799);
INSERT INTO "django_geo_db_zipcode" VALUES(30020,67101,-6,'Maize, Kansas 67101',22023,26800);
INSERT INTO "django_geo_db_zipcode" VALUES(30021,67102,-6,'Maple City, Kansas 67102',22024,26801);
INSERT INTO "django_geo_db_zipcode" VALUES(30022,67103,-6,'Mayfield, Kansas 67103',22025,26802);
INSERT INTO "django_geo_db_zipcode" VALUES(30023,67104,-6,'Medicine Lodge, Kansas 67104',22026,26803);
INSERT INTO "django_geo_db_zipcode" VALUES(30024,67105,-6,'Milan, Kansas 67105',22027,26804);
INSERT INTO "django_geo_db_zipcode" VALUES(30025,67106,-6,'Milton, Kansas 67106',22028,26805);
INSERT INTO "django_geo_db_zipcode" VALUES(30026,67107,-6,'Moundridge, Kansas 67107',22029,26806);
INSERT INTO "django_geo_db_zipcode" VALUES(30027,67108,-6,'Mount Hope, Kansas 67108',22030,26807);
INSERT INTO "django_geo_db_zipcode" VALUES(30028,67109,-6,'Mullinville, Kansas 67109',22031,26808);
INSERT INTO "django_geo_db_zipcode" VALUES(30029,67110,-6,'Mulvane, Kansas 67110',22032,26809);
INSERT INTO "django_geo_db_zipcode" VALUES(30030,67111,-6,'Murdock, Kansas 67111',22033,26810);
INSERT INTO "django_geo_db_zipcode" VALUES(30031,67112,-6,'Nashville, Kansas 67112',22034,26811);
INSERT INTO "django_geo_db_zipcode" VALUES(30032,67114,-6,'Newton, Kansas 67114',22035,26812);
INSERT INTO "django_geo_db_zipcode" VALUES(30033,67117,-6,'North Newton, Kansas 67117',22036,26813);
INSERT INTO "django_geo_db_zipcode" VALUES(30034,67118,-6,'Norwich, Kansas 67118',22037,26814);
INSERT INTO "django_geo_db_zipcode" VALUES(30035,67119,-6,'Oxford, Kansas 67119',22038,26815);
INSERT INTO "django_geo_db_zipcode" VALUES(30036,67120,-6,'Peck, Kansas 67120',22039,26816);
INSERT INTO "django_geo_db_zipcode" VALUES(30037,67122,-6,'Piedmont, Kansas 67122',22040,26817);
INSERT INTO "django_geo_db_zipcode" VALUES(30038,67123,-6,'Potwin, Kansas 67123',22041,26818);
INSERT INTO "django_geo_db_zipcode" VALUES(30039,67124,-6,'Pratt, Kansas 67124',22042,26819);
INSERT INTO "django_geo_db_zipcode" VALUES(30040,67127,-6,'Protection, Kansas 67127',22043,26820);
INSERT INTO "django_geo_db_zipcode" VALUES(30041,67128,-6,'Rago, Kansas 67128',22044,26821);
INSERT INTO "django_geo_db_zipcode" VALUES(30042,67131,-6,'Rock, Kansas 67131',22045,26822);
INSERT INTO "django_geo_db_zipcode" VALUES(30043,67132,-6,'Rosalia, Kansas 67132',22046,26823);
INSERT INTO "django_geo_db_zipcode" VALUES(30044,67133,-6,'Rose Hill, Kansas 67133',22047,26824);
INSERT INTO "django_geo_db_zipcode" VALUES(30045,67134,-6,'Sawyer, Kansas 67134',22048,26825);
INSERT INTO "django_geo_db_zipcode" VALUES(30046,67135,-6,'Sedgwick, Kansas 67135',22049,26826);
INSERT INTO "django_geo_db_zipcode" VALUES(30047,67137,-6,'Severy, Kansas 67137',22050,26827);
INSERT INTO "django_geo_db_zipcode" VALUES(30048,67138,-6,'Sharon, Kansas 67138',22051,26828);
INSERT INTO "django_geo_db_zipcode" VALUES(30049,67140,-6,'South Haven, Kansas 67140',22052,26829);
INSERT INTO "django_geo_db_zipcode" VALUES(30050,67142,-6,'Spivey, Kansas 67142',22053,26830);
INSERT INTO "django_geo_db_zipcode" VALUES(30051,67143,-6,'Sun City, Kansas 67143',22054,26831);
INSERT INTO "django_geo_db_zipcode" VALUES(30052,67144,-6,'Towanda, Kansas 67144',22055,26832);
INSERT INTO "django_geo_db_zipcode" VALUES(30053,67146,-6,'Udall, Kansas 67146',22056,26833);
INSERT INTO "django_geo_db_zipcode" VALUES(30054,67147,-6,'Valley Center, Kansas 67147',22057,26834);
INSERT INTO "django_geo_db_zipcode" VALUES(30055,67149,-6,'Viola, Kansas 67149',22058,26835);
INSERT INTO "django_geo_db_zipcode" VALUES(30056,67150,-6,'Waldron, Kansas 67150',22059,26836);
INSERT INTO "django_geo_db_zipcode" VALUES(30057,67151,-6,'Walton, Kansas 67151',22060,26837);
INSERT INTO "django_geo_db_zipcode" VALUES(30058,67152,-6,'Wellington, Kansas 67152',22061,26838);
INSERT INTO "django_geo_db_zipcode" VALUES(30059,67154,-6,'Whitewater, Kansas 67154',22062,26839);
INSERT INTO "django_geo_db_zipcode" VALUES(30060,67155,-6,'Wilmore, Kansas 67155',22063,26840);
INSERT INTO "django_geo_db_zipcode" VALUES(30061,67156,-6,'Winfield, Kansas 67156',22064,26841);
INSERT INTO "django_geo_db_zipcode" VALUES(30062,67159,-6,'Zenda, Kansas 67159',22065,26842);
INSERT INTO "django_geo_db_zipcode" VALUES(30063,67201,-6,'Wichita, Kansas 67201',22066,26843);
INSERT INTO "django_geo_db_zipcode" VALUES(30064,67202,-6,'Wichita, Kansas 67202',22066,26844);
INSERT INTO "django_geo_db_zipcode" VALUES(30065,67203,-6,'Wichita, Kansas 67203',22066,26845);
INSERT INTO "django_geo_db_zipcode" VALUES(30066,67204,-6,'Wichita, Kansas 67204',22066,26846);
INSERT INTO "django_geo_db_zipcode" VALUES(30067,67205,-6,'Wichita, Kansas 67205',22066,26847);
INSERT INTO "django_geo_db_zipcode" VALUES(30068,67206,-6,'Wichita, Kansas 67206',22066,26848);
INSERT INTO "django_geo_db_zipcode" VALUES(30069,67207,-6,'Wichita, Kansas 67207',22066,26849);
INSERT INTO "django_geo_db_zipcode" VALUES(30070,67208,-6,'Wichita, Kansas 67208',22066,26850);
INSERT INTO "django_geo_db_zipcode" VALUES(30071,67209,-6,'Wichita, Kansas 67209',22066,26851);
INSERT INTO "django_geo_db_zipcode" VALUES(30072,67210,-6,'Wichita, Kansas 67210',22066,26852);
INSERT INTO "django_geo_db_zipcode" VALUES(30073,67211,-6,'Wichita, Kansas 67211',22066,26853);
INSERT INTO "django_geo_db_zipcode" VALUES(30074,67212,-6,'Wichita, Kansas 67212',22066,26854);
INSERT INTO "django_geo_db_zipcode" VALUES(30075,67213,-6,'Wichita, Kansas 67213',22066,26855);
INSERT INTO "django_geo_db_zipcode" VALUES(30076,67214,-6,'Wichita, Kansas 67214',22066,26856);
INSERT INTO "django_geo_db_zipcode" VALUES(30077,67215,-6,'Wichita, Kansas 67215',22066,26857);
INSERT INTO "django_geo_db_zipcode" VALUES(30078,67216,-6,'Wichita, Kansas 67216',22066,26858);
INSERT INTO "django_geo_db_zipcode" VALUES(30079,67217,-6,'Wichita, Kansas 67217',22066,26859);
INSERT INTO "django_geo_db_zipcode" VALUES(30080,67218,-6,'Wichita, Kansas 67218',22066,26860);
INSERT INTO "django_geo_db_zipcode" VALUES(30081,67219,-6,'Wichita, Kansas 67219',22066,26861);
INSERT INTO "django_geo_db_zipcode" VALUES(30082,67220,-6,'Wichita, Kansas 67220',22066,26862);
INSERT INTO "django_geo_db_zipcode" VALUES(30083,67221,-6,'McConnell A F B, Kansas 67221',22067,26863);
INSERT INTO "django_geo_db_zipcode" VALUES(30084,67222,-6,'Wichita, Kansas 67222',22066,26864);
INSERT INTO "django_geo_db_zipcode" VALUES(30085,67223,-6,'Wichita, Kansas 67223',22066,26865);
INSERT INTO "django_geo_db_zipcode" VALUES(30086,67226,-6,'Wichita, Kansas 67226',22066,26866);
INSERT INTO "django_geo_db_zipcode" VALUES(30087,67227,-6,'Wichita, Kansas 67227',22066,26867);
INSERT INTO "django_geo_db_zipcode" VALUES(30088,67228,-6,'Wichita, Kansas 67228',22066,26868);
INSERT INTO "django_geo_db_zipcode" VALUES(30089,67230,-6,'Wichita, Kansas 67230',22066,26869);
INSERT INTO "django_geo_db_zipcode" VALUES(30090,67231,-6,'Wichita, Kansas 67231',22066,26870);
INSERT INTO "django_geo_db_zipcode" VALUES(30091,67232,-6,'Wichita, Kansas 67232',22066,26871);
INSERT INTO "django_geo_db_zipcode" VALUES(30092,67233,-6,'Wichita, Kansas 67233',22066,26872);
INSERT INTO "django_geo_db_zipcode" VALUES(30093,67235,-6,'Wichita, Kansas 67235',22066,26873);
INSERT INTO "django_geo_db_zipcode" VALUES(30094,67236,-6,'Wichita, Kansas 67236',22066,26874);
INSERT INTO "django_geo_db_zipcode" VALUES(30095,67251,-6,'Wichita, Kansas 67251',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30096,67256,-6,'Wichita, Kansas 67256',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30097,67257,-6,'Wichita, Kansas 67257',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30098,67259,-6,'Wichita, Kansas 67259',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30099,67260,-6,'Wichita, Kansas 67260',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30100,67275,-6,'Wichita, Kansas 67275',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30101,67276,-6,'Wichita, Kansas 67276',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30102,67277,-6,'Wichita, Kansas 67277',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30103,67278,-6,'Wichita, Kansas 67278',22066,26875);
INSERT INTO "django_geo_db_zipcode" VALUES(30104,67301,-6,'Independence, Kansas 67301',22068,26876);
INSERT INTO "django_geo_db_zipcode" VALUES(30105,67330,-6,'Altamont, Kansas 67330',22069,26877);
INSERT INTO "django_geo_db_zipcode" VALUES(30106,67332,-6,'Bartlett, Kansas 67332',22070,26878);
INSERT INTO "django_geo_db_zipcode" VALUES(30107,67333,-6,'Caney, Kansas 67333',22071,26879);
INSERT INTO "django_geo_db_zipcode" VALUES(30108,67334,-6,'Chautauqua, Kansas 67334',22072,26880);
INSERT INTO "django_geo_db_zipcode" VALUES(30109,67335,-6,'Cherryvale, Kansas 67335',22073,26881);
INSERT INTO "django_geo_db_zipcode" VALUES(30110,67336,-6,'Chetopa, Kansas 67336',22074,26882);
INSERT INTO "django_geo_db_zipcode" VALUES(30111,67337,-6,'Coffeyville, Kansas 67337',22075,26883);
INSERT INTO "django_geo_db_zipcode" VALUES(30112,67339,-6,'Howard, Kansas 67339',22076,26884);
INSERT INTO "django_geo_db_zipcode" VALUES(30113,67340,-6,'Dearing, Kansas 67340',22077,26885);
INSERT INTO "django_geo_db_zipcode" VALUES(30114,67341,-6,'Dennis, Kansas 67341',22078,26886);
INSERT INTO "django_geo_db_zipcode" VALUES(30115,67342,-6,'Edna, Kansas 67342',22079,26887);
INSERT INTO "django_geo_db_zipcode" VALUES(30116,67344,-6,'Elk City, Kansas 67344',22080,26888);
INSERT INTO "django_geo_db_zipcode" VALUES(30117,67345,-6,'Elk Falls, Kansas 67345',22081,26889);
INSERT INTO "django_geo_db_zipcode" VALUES(30118,67346,-6,'Grenola, Kansas 67346',22082,26890);
INSERT INTO "django_geo_db_zipcode" VALUES(30119,67347,-6,'Havana, Kansas 67347',22083,26891);
INSERT INTO "django_geo_db_zipcode" VALUES(30120,67349,-6,'Howard, Kansas 67349',22076,26892);
INSERT INTO "django_geo_db_zipcode" VALUES(30121,67351,-6,'Liberty, Kansas 67351',22084,26893);
INSERT INTO "django_geo_db_zipcode" VALUES(30122,67352,-6,'Longton, Kansas 67352',22085,26894);
INSERT INTO "django_geo_db_zipcode" VALUES(30123,67353,-6,'Moline, Kansas 67353',22086,26895);
INSERT INTO "django_geo_db_zipcode" VALUES(30124,67354,-6,'Mound Valley, Kansas 67354',22087,26896);
INSERT INTO "django_geo_db_zipcode" VALUES(30125,67355,-6,'Niotaze, Kansas 67355',22088,26897);
INSERT INTO "django_geo_db_zipcode" VALUES(30126,67356,-6,'Oswego, Kansas 67356',22089,26898);
INSERT INTO "django_geo_db_zipcode" VALUES(30127,67357,-6,'Parsons, Kansas 67357',22090,26899);
INSERT INTO "django_geo_db_zipcode" VALUES(30128,67360,-6,'Peru, Kansas 67360',22091,26900);
INSERT INTO "django_geo_db_zipcode" VALUES(30129,67361,-6,'Sedan, Kansas 67361',22092,26901);
INSERT INTO "django_geo_db_zipcode" VALUES(30130,67363,-6,'Sycamore, Kansas 67363',22093,26902);
INSERT INTO "django_geo_db_zipcode" VALUES(30131,67364,-6,'Tyro, Kansas 67364',22094,26903);
INSERT INTO "django_geo_db_zipcode" VALUES(30132,67401,-6,'Salina, Kansas 67401',22095,26904);
INSERT INTO "django_geo_db_zipcode" VALUES(30133,67402,-6,'Salina, Kansas 67402',22095,26905);
INSERT INTO "django_geo_db_zipcode" VALUES(30134,67410,-6,'Abilene, Kansas 67410',22096,26906);
INSERT INTO "django_geo_db_zipcode" VALUES(30135,67411,-6,'Fairview, Kansas 67411',21780,26907);
INSERT INTO "django_geo_db_zipcode" VALUES(30136,67416,-6,'Assaria, Kansas 67416',22097,26908);
INSERT INTO "django_geo_db_zipcode" VALUES(30137,67417,-6,'Aurora, Kansas 67417',22098,26909);
INSERT INTO "django_geo_db_zipcode" VALUES(30138,67418,-6,'Barnard, Kansas 67418',22099,26910);
INSERT INTO "django_geo_db_zipcode" VALUES(30139,67419,-6,'Union, Kansas 67419',22100,26911);
INSERT INTO "django_geo_db_zipcode" VALUES(30140,67420,-6,'Beloit, Kansas 67420',22101,26912);
INSERT INTO "django_geo_db_zipcode" VALUES(30141,67422,-6,'Bennington, Kansas 67422',22102,26913);
INSERT INTO "django_geo_db_zipcode" VALUES(30142,67423,-6,'Beverly, Kansas 67423',22103,26914);
INSERT INTO "django_geo_db_zipcode" VALUES(30143,67425,-6,'Brookville, Kansas 67425',22104,26915);
INSERT INTO "django_geo_db_zipcode" VALUES(30144,67427,-6,'Bushton, Kansas 67427',22105,26916);
INSERT INTO "django_geo_db_zipcode" VALUES(30145,67428,-6,'Canton, Kansas 67428',22106,26917);
INSERT INTO "django_geo_db_zipcode" VALUES(30146,67430,-6,'Cawker City, Kansas 67430',22107,26918);
INSERT INTO "django_geo_db_zipcode" VALUES(30147,67431,-6,'Chapman, Kansas 67431',22108,26919);
INSERT INTO "django_geo_db_zipcode" VALUES(30148,67432,-6,'Clay Center, Kansas 67432',22109,26920);
INSERT INTO "django_geo_db_zipcode" VALUES(30149,67435,-6,'Sedan, Kansas 67435',22092,26921);
INSERT INTO "django_geo_db_zipcode" VALUES(30150,67436,-6,'Delphos, Kansas 67436',22110,26922);
INSERT INTO "django_geo_db_zipcode" VALUES(30151,67437,-6,'Downs, Kansas 67437',22111,26923);
INSERT INTO "django_geo_db_zipcode" VALUES(30152,67438,-6,'Durham, Kansas 67438',22112,26924);
INSERT INTO "django_geo_db_zipcode" VALUES(30153,67439,-6,'Ellsworth, Kansas 67439',22113,26925);
INSERT INTO "django_geo_db_zipcode" VALUES(30154,67441,-6,'Enterprise, Kansas 67441',22114,26926);
INSERT INTO "django_geo_db_zipcode" VALUES(30155,67442,-6,'Falun, Kansas 67442',22115,26927);
INSERT INTO "django_geo_db_zipcode" VALUES(30156,67443,-6,'Galva, Kansas 67443',22116,26928);
INSERT INTO "django_geo_db_zipcode" VALUES(30157,67444,-6,'Geneseo, Kansas 67444',22117,26929);
INSERT INTO "django_geo_db_zipcode" VALUES(30158,67445,-6,'Glasco, Kansas 67445',22118,26930);
INSERT INTO "django_geo_db_zipcode" VALUES(30159,67446,-6,'Glen Elder, Kansas 67446',22119,26931);
INSERT INTO "django_geo_db_zipcode" VALUES(30160,67447,-6,'Green, Kansas 67447',22120,26932);
INSERT INTO "django_geo_db_zipcode" VALUES(30161,67448,-6,'Gypsum, Kansas 67448',22121,26933);
INSERT INTO "django_geo_db_zipcode" VALUES(30162,67449,-6,'Herington, Kansas 67449',22122,26934);
INSERT INTO "django_geo_db_zipcode" VALUES(30163,67450,-6,'Holyrood, Kansas 67450',22123,26935);
INSERT INTO "django_geo_db_zipcode" VALUES(30164,67451,-6,'Hope, Kansas 67451',22124,26936);
INSERT INTO "django_geo_db_zipcode" VALUES(30165,67452,-6,'Hunter, Kansas 67452',22125,26937);
INSERT INTO "django_geo_db_zipcode" VALUES(30166,67454,-6,'Kanopolis, Kansas 67454',22126,26938);
INSERT INTO "django_geo_db_zipcode" VALUES(30167,67455,-6,'Lincoln, Kansas 67455',21759,26939);
INSERT INTO "django_geo_db_zipcode" VALUES(30168,67456,-6,'Lindsborg, Kansas 67456',22127,26940);
INSERT INTO "django_geo_db_zipcode" VALUES(30169,67457,-6,'Little River, Kansas 67457',22128,26941);
INSERT INTO "django_geo_db_zipcode" VALUES(30170,67458,-6,'Longford, Kansas 67458',22129,26942);
INSERT INTO "django_geo_db_zipcode" VALUES(30171,67459,-6,'Lorraine, Kansas 67459',22130,26943);
INSERT INTO "django_geo_db_zipcode" VALUES(30172,67460,-6,'Mcpherson, Kansas 67460',22131,26944);
INSERT INTO "django_geo_db_zipcode" VALUES(30173,67464,-6,'Marquette, Kansas 67464',22132,26945);
INSERT INTO "django_geo_db_zipcode" VALUES(30174,67466,-6,'Miltonvale, Kansas 67466',22133,26946);
INSERT INTO "django_geo_db_zipcode" VALUES(30175,67467,-6,'Minneapolis, Kansas 67467',22134,26947);
INSERT INTO "django_geo_db_zipcode" VALUES(30176,67468,-6,'Morganville, Kansas 67468',22135,26948);
INSERT INTO "django_geo_db_zipcode" VALUES(30177,67470,-6,'New Cambria, Kansas 67470',22136,26949);
INSERT INTO "django_geo_db_zipcode" VALUES(30178,67472,-6,'Chapman, Kansas 67472',22108,26950);
INSERT INTO "django_geo_db_zipcode" VALUES(30179,67473,-6,'Osborne, Kansas 67473',22137,26951);
INSERT INTO "django_geo_db_zipcode" VALUES(30180,67474,-6,'Portis, Kansas 67474',22138,26952);
INSERT INTO "django_geo_db_zipcode" VALUES(30181,67475,-6,'Ramona, Kansas 67475',22139,26953);
INSERT INTO "django_geo_db_zipcode" VALUES(30182,67476,-6,'Roxbury, Kansas 67476',22140,26954);
INSERT INTO "django_geo_db_zipcode" VALUES(30183,67478,-6,'Simpson, Kansas 67478',22141,26955);
INSERT INTO "django_geo_db_zipcode" VALUES(30184,67479,-6,'Smolan, Kansas 67479',22142,26956);
INSERT INTO "django_geo_db_zipcode" VALUES(30185,67480,-6,'Solomon, Kansas 67480',22143,26957);
INSERT INTO "django_geo_db_zipcode" VALUES(30186,67481,-6,'Sylvan Grove, Kansas 67481',22144,26958);
INSERT INTO "django_geo_db_zipcode" VALUES(30187,67482,-6,'Talmage, Kansas 67482',22145,26959);
INSERT INTO "django_geo_db_zipcode" VALUES(30188,67483,-6,'Tampa, Kansas 67483',22146,26960);
INSERT INTO "django_geo_db_zipcode" VALUES(30189,67484,-6,'Tescott, Kansas 67484',22147,26961);
INSERT INTO "django_geo_db_zipcode" VALUES(30190,67485,-6,'Tipton, Kansas 67485',22148,26962);
INSERT INTO "django_geo_db_zipcode" VALUES(30191,67487,-6,'Wakefield, Kansas 67487',22149,26963);
INSERT INTO "django_geo_db_zipcode" VALUES(30192,67488,-6,'Durham, Kansas 67488',22112,26964);
INSERT INTO "django_geo_db_zipcode" VALUES(30193,67490,-6,'Wilson, Kansas 67490',22150,26965);
INSERT INTO "django_geo_db_zipcode" VALUES(30194,67491,-6,'Windom, Kansas 67491',22151,26966);
INSERT INTO "django_geo_db_zipcode" VALUES(30195,67492,-6,'Woodbine, Kansas 67492',22152,26967);
INSERT INTO "django_geo_db_zipcode" VALUES(30196,67495,-6,'Tipton, Kansas 67495',22148,26968);
INSERT INTO "django_geo_db_zipcode" VALUES(30197,67501,-6,'Hutchinson, Kansas 67501',22153,26969);
INSERT INTO "django_geo_db_zipcode" VALUES(30198,67502,-6,'Hutchinson, Kansas 67502',22153,26970);
INSERT INTO "django_geo_db_zipcode" VALUES(30199,67504,-6,'Hutchinson, Kansas 67504',22153,26971);
INSERT INTO "django_geo_db_zipcode" VALUES(30200,67505,-6,'South Hutchinson, Kansas 67505',22154,26972);
INSERT INTO "django_geo_db_zipcode" VALUES(30201,67510,-6,'Abbyville, Kansas 67510',22155,26973);
INSERT INTO "django_geo_db_zipcode" VALUES(30202,67511,-6,'Albert, Kansas 67511',22156,26974);
INSERT INTO "django_geo_db_zipcode" VALUES(30203,67512,-6,'Alden, Kansas 67512',22157,26975);
INSERT INTO "django_geo_db_zipcode" VALUES(30204,67513,-6,'Alexander, Kansas 67513',22158,26976);
INSERT INTO "django_geo_db_zipcode" VALUES(30205,67514,-6,'Arlington, Kansas 67514',22159,26977);
INSERT INTO "django_geo_db_zipcode" VALUES(30206,67515,-6,'Arnold, Kansas 67515',22160,26978);
INSERT INTO "django_geo_db_zipcode" VALUES(30207,67516,-6,'Bazine, Kansas 67516',22161,26979);
INSERT INTO "django_geo_db_zipcode" VALUES(30208,67518,-6,'Beeler, Kansas 67518',22162,26980);
INSERT INTO "django_geo_db_zipcode" VALUES(30209,67519,-6,'Belpre, Kansas 67519',22163,26981);
INSERT INTO "django_geo_db_zipcode" VALUES(30210,67520,-6,'Bison, Kansas 67520',22164,26982);
INSERT INTO "django_geo_db_zipcode" VALUES(30211,67521,-6,'Brownell, Kansas 67521',22165,26983);
INSERT INTO "django_geo_db_zipcode" VALUES(30212,67522,-6,'Buhler, Kansas 67522',22166,26984);
INSERT INTO "django_geo_db_zipcode" VALUES(30213,67523,-6,'Burdett, Kansas 67523',22167,26985);
INSERT INTO "django_geo_db_zipcode" VALUES(30214,67524,-6,'Chase, Kansas 67524',22168,26986);
INSERT INTO "django_geo_db_zipcode" VALUES(30215,67525,-6,'Claflin, Kansas 67525',22169,26987);
INSERT INTO "django_geo_db_zipcode" VALUES(30216,67526,-6,'Ellinwood, Kansas 67526',22170,26988);
INSERT INTO "django_geo_db_zipcode" VALUES(30217,67529,-6,'Garfield, Kansas 67529',22171,26989);
INSERT INTO "django_geo_db_zipcode" VALUES(30218,67530,-6,'Great Bend, Kansas 67530',22172,26990);
INSERT INTO "django_geo_db_zipcode" VALUES(30219,67543,-6,'Haven, Kansas 67543',22173,26991);
INSERT INTO "django_geo_db_zipcode" VALUES(30220,67544,-6,'Hoisington, Kansas 67544',22174,26992);
INSERT INTO "django_geo_db_zipcode" VALUES(30221,67545,-6,'Hudson, Kansas 67545',22175,26993);
INSERT INTO "django_geo_db_zipcode" VALUES(30222,67546,-6,'Inman, Kansas 67546',22176,26994);
INSERT INTO "django_geo_db_zipcode" VALUES(30223,67547,-6,'Kinsley, Kansas 67547',22177,26995);
INSERT INTO "django_geo_db_zipcode" VALUES(30224,67548,-6,'La Crosse, Kansas 67548',22178,26996);
INSERT INTO "django_geo_db_zipcode" VALUES(30225,67550,-6,'Larned, Kansas 67550',22179,26997);
INSERT INTO "django_geo_db_zipcode" VALUES(30226,67552,-6,'Lewis, Kansas 67552',22180,26998);
INSERT INTO "django_geo_db_zipcode" VALUES(30227,67553,-6,'Liebenthal, Kansas 67553',22181,26999);
INSERT INTO "django_geo_db_zipcode" VALUES(30228,67554,-6,'Lyons, Kansas 67554',22182,27000);
INSERT INTO "django_geo_db_zipcode" VALUES(30229,67556,-6,'McCracken, Kansas 67556',22183,27001);
INSERT INTO "django_geo_db_zipcode" VALUES(30230,67557,-6,'Macksville, Kansas 67557',22184,27002);
INSERT INTO "django_geo_db_zipcode" VALUES(30231,67559,-6,'Nekoma, Kansas 67559',22185,27003);
INSERT INTO "django_geo_db_zipcode" VALUES(30232,67560,-6,'Ness City, Kansas 67560',22186,27004);
INSERT INTO "django_geo_db_zipcode" VALUES(30233,67561,-6,'Nickerson, Kansas 67561',22187,27005);
INSERT INTO "django_geo_db_zipcode" VALUES(30234,67563,-6,'Offerle, Kansas 67563',22188,27006);
INSERT INTO "django_geo_db_zipcode" VALUES(30235,67564,-6,'Olmitz, Kansas 67564',22189,27007);
INSERT INTO "django_geo_db_zipcode" VALUES(30236,67565,-6,'Otis, Kansas 67565',22190,27008);
INSERT INTO "django_geo_db_zipcode" VALUES(30237,67566,-6,'Partridge, Kansas 67566',22191,27009);
INSERT INTO "django_geo_db_zipcode" VALUES(30238,67567,-6,'Pawnee Rock, Kansas 67567',22192,27010);
INSERT INTO "django_geo_db_zipcode" VALUES(30239,67568,-6,'Plevna, Kansas 67568',22193,27011);
INSERT INTO "django_geo_db_zipcode" VALUES(30240,67570,-6,'Pretty Prairie, Kansas 67570',22194,27012);
INSERT INTO "django_geo_db_zipcode" VALUES(30241,67572,-6,'Ransom, Kansas 67572',22195,27013);
INSERT INTO "django_geo_db_zipcode" VALUES(30242,67573,-6,'Raymond, Kansas 67573',22196,27014);
INSERT INTO "django_geo_db_zipcode" VALUES(30243,67574,-6,'Rozel, Kansas 67574',22197,27015);
INSERT INTO "django_geo_db_zipcode" VALUES(30244,67575,-6,'Rush Center, Kansas 67575',22198,27016);
INSERT INTO "django_geo_db_zipcode" VALUES(30245,67576,-6,'Saint John, Kansas 67576',22199,27017);
INSERT INTO "django_geo_db_zipcode" VALUES(30246,67578,-6,'Stafford, Kansas 67578',22200,27018);
INSERT INTO "django_geo_db_zipcode" VALUES(30247,67579,-6,'Sterling, Kansas 67579',22201,27019);
INSERT INTO "django_geo_db_zipcode" VALUES(30248,67581,-6,'Sylvia, Kansas 67581',22202,27020);
INSERT INTO "django_geo_db_zipcode" VALUES(30249,67583,-6,'Turon, Kansas 67583',22203,27021);
INSERT INTO "django_geo_db_zipcode" VALUES(30250,67584,-6,'Utica, Kansas 67584',22204,27022);
INSERT INTO "django_geo_db_zipcode" VALUES(30251,67585,-6,'Yoder, Kansas 67585',22205,27023);
INSERT INTO "django_geo_db_zipcode" VALUES(30252,67601,-6,'Hays, Kansas 67601',22206,27024);
INSERT INTO "django_geo_db_zipcode" VALUES(30253,67621,-6,'Agra, Kansas 67621',22207,27025);
INSERT INTO "django_geo_db_zipcode" VALUES(30254,67622,-6,'Almena, Kansas 67622',22208,27026);
INSERT INTO "django_geo_db_zipcode" VALUES(30255,67623,-6,'Alton, Kansas 67623',22209,27027);
INSERT INTO "django_geo_db_zipcode" VALUES(30256,67625,-6,'Bogue, Kansas 67625',22210,27028);
INSERT INTO "django_geo_db_zipcode" VALUES(30257,67626,-6,'Bunker Hill, Kansas 67626',22211,27029);
INSERT INTO "django_geo_db_zipcode" VALUES(30258,67627,-6,'Catharine, Kansas 67627',22212,27030);
INSERT INTO "django_geo_db_zipcode" VALUES(30259,67628,-6,'Cedar, Kansas 67628',22213,27031);
INSERT INTO "django_geo_db_zipcode" VALUES(30260,67629,-6,'Clayton, Kansas 67629',22214,27032);
INSERT INTO "django_geo_db_zipcode" VALUES(30261,67630,-6,'Belleville, Kansas 67630',21933,27033);
INSERT INTO "django_geo_db_zipcode" VALUES(30262,67631,-6,'Collyer, Kansas 67631',22215,27034);
INSERT INTO "django_geo_db_zipcode" VALUES(30263,67632,-6,'Damar, Kansas 67632',22216,27035);
INSERT INTO "django_geo_db_zipcode" VALUES(30264,67634,-6,'Dorrance, Kansas 67634',22217,27036);
INSERT INTO "django_geo_db_zipcode" VALUES(30265,67635,-6,'Dresden, Kansas 67635',22218,27037);
INSERT INTO "django_geo_db_zipcode" VALUES(30266,67637,-6,'Ellis, Kansas 67637',22219,27038);
INSERT INTO "django_geo_db_zipcode" VALUES(30267,67638,-6,'Gaylord, Kansas 67638',22220,27039);
INSERT INTO "django_geo_db_zipcode" VALUES(30268,67639,-6,'Glade, Kansas 67639',22221,27040);
INSERT INTO "django_geo_db_zipcode" VALUES(30269,67640,-6,'Gorham, Kansas 67640',22222,27041);
INSERT INTO "django_geo_db_zipcode" VALUES(30270,67642,-6,'Hill City, Kansas 67642',22223,27042);
INSERT INTO "django_geo_db_zipcode" VALUES(30271,67643,-6,'Jennings, Kansas 67643',22224,27043);
INSERT INTO "django_geo_db_zipcode" VALUES(30272,67644,-6,'Kirwin, Kansas 67644',22225,27044);
INSERT INTO "django_geo_db_zipcode" VALUES(30273,67645,-6,'Lenora, Kansas 67645',22226,27045);
INSERT INTO "django_geo_db_zipcode" VALUES(30274,67646,-6,'Logan, Kansas 67646',22227,27046);
INSERT INTO "django_geo_db_zipcode" VALUES(30275,67647,-6,'Long Island, Kansas 67647',22228,27047);
INSERT INTO "django_geo_db_zipcode" VALUES(30276,67648,-6,'Lucas, Kansas 67648',22229,27048);
INSERT INTO "django_geo_db_zipcode" VALUES(30277,67649,-6,'Luray, Kansas 67649',22230,27049);
INSERT INTO "django_geo_db_zipcode" VALUES(30278,67650,-6,'Morland, Kansas 67650',22231,27050);
INSERT INTO "django_geo_db_zipcode" VALUES(30279,67651,-6,'Natoma, Kansas 67651',22232,27051);
INSERT INTO "django_geo_db_zipcode" VALUES(30280,67653,-6,'Norcatur, Kansas 67653',22233,27052);
INSERT INTO "django_geo_db_zipcode" VALUES(30281,67654,-6,'Norton, Kansas 67654',22234,27053);
INSERT INTO "django_geo_db_zipcode" VALUES(30282,67656,-6,'Ogallah, Kansas 67656',22235,27054);
INSERT INTO "django_geo_db_zipcode" VALUES(30283,67657,-6,'Palco, Kansas 67657',22236,27055);
INSERT INTO "django_geo_db_zipcode" VALUES(30284,67658,-6,'Paradise, Kansas 67658',22237,27056);
INSERT INTO "django_geo_db_zipcode" VALUES(30285,67659,-6,'Penokee, Kansas 67659',22238,27057);
INSERT INTO "django_geo_db_zipcode" VALUES(30286,67660,-6,'Pfeifer, Kansas 67660',22239,27058);
INSERT INTO "django_geo_db_zipcode" VALUES(30287,67661,-6,'Phillipsburg, Kansas 67661',22240,27059);
INSERT INTO "django_geo_db_zipcode" VALUES(30288,67663,-6,'Plainville, Kansas 67663',22241,27060);
INSERT INTO "django_geo_db_zipcode" VALUES(30289,67664,-6,'Prairie View, Kansas 67664',22242,27061);
INSERT INTO "django_geo_db_zipcode" VALUES(30290,67665,-6,'Russell, Kansas 67665',22243,27062);
INSERT INTO "django_geo_db_zipcode" VALUES(30291,67666,-6,'Towanda, Kansas 67666',22055,27063);
INSERT INTO "django_geo_db_zipcode" VALUES(30292,67667,-6,'Schoenchen, Kansas 67667',22244,27064);
INSERT INTO "django_geo_db_zipcode" VALUES(30293,67669,-6,'Stockton, Kansas 67669',22245,27065);
INSERT INTO "django_geo_db_zipcode" VALUES(30294,67670,-6,'Stuttgart, Kansas 67670',22246,27066);
INSERT INTO "django_geo_db_zipcode" VALUES(30295,67671,-6,'Victoria, Kansas 67671',22247,27067);
INSERT INTO "django_geo_db_zipcode" VALUES(30296,67672,-6,'Wa Keeney, Kansas 67672',22248,27068);
INSERT INTO "django_geo_db_zipcode" VALUES(30297,67673,-6,'Waldo, Kansas 67673',22249,27069);
INSERT INTO "django_geo_db_zipcode" VALUES(30298,67674,-6,'Walker, Kansas 67674',22250,27070);
INSERT INTO "django_geo_db_zipcode" VALUES(30299,67675,-6,'Woodston, Kansas 67675',22251,27071);
INSERT INTO "django_geo_db_zipcode" VALUES(30300,67701,-6,'Colby, Kansas 67701',22252,27072);
INSERT INTO "django_geo_db_zipcode" VALUES(30301,67730,-6,'Atwood, Kansas 67730',22253,27073);
INSERT INTO "django_geo_db_zipcode" VALUES(30302,67731,-6,'Bird City, Kansas 67731',22254,27074);
INSERT INTO "django_geo_db_zipcode" VALUES(30303,67732,-6,'Brewster, Kansas 67732',22255,27075);
INSERT INTO "django_geo_db_zipcode" VALUES(30304,67733,-7,'Edson, Kansas 67733',22256,27076);
INSERT INTO "django_geo_db_zipcode" VALUES(30305,67734,-6,'Gem, Kansas 67734',22257,27077);
INSERT INTO "django_geo_db_zipcode" VALUES(30306,67735,-7,'Goodland, Kansas 67735',22258,27078);
INSERT INTO "django_geo_db_zipcode" VALUES(30307,67736,-6,'Gove, Kansas 67736',22259,27079);
INSERT INTO "django_geo_db_zipcode" VALUES(30308,67737,-6,'Grainfield, Kansas 67737',22260,27080);
INSERT INTO "django_geo_db_zipcode" VALUES(30309,67738,-6,'Grinnell, Kansas 67738',22261,27081);
INSERT INTO "django_geo_db_zipcode" VALUES(30310,67739,-6,'Herndon, Kansas 67739',22262,27082);
INSERT INTO "django_geo_db_zipcode" VALUES(30311,67740,-6,'Hoxie, Kansas 67740',22263,27083);
INSERT INTO "django_geo_db_zipcode" VALUES(30312,67741,-7,'Kanorado, Kansas 67741',22264,27084);
INSERT INTO "django_geo_db_zipcode" VALUES(30313,67743,-6,'Levant, Kansas 67743',22265,27085);
INSERT INTO "django_geo_db_zipcode" VALUES(30314,67744,-6,'Ludell, Kansas 67744',22266,27086);
INSERT INTO "django_geo_db_zipcode" VALUES(30315,67745,-6,'McDonald, Kansas 67745',22267,27087);
INSERT INTO "django_geo_db_zipcode" VALUES(30316,67747,-6,'Monument, Kansas 67747',22268,27088);
INSERT INTO "django_geo_db_zipcode" VALUES(30317,67748,-6,'Oakley, Kansas 67748',22269,27089);
INSERT INTO "django_geo_db_zipcode" VALUES(30318,67749,-6,'Oberlin, Kansas 67749',22270,27090);
INSERT INTO "django_geo_db_zipcode" VALUES(30319,67751,-6,'Park, Kansas 67751',22271,27091);
INSERT INTO "django_geo_db_zipcode" VALUES(30320,67752,-6,'Quinter, Kansas 67752',22272,27092);
INSERT INTO "django_geo_db_zipcode" VALUES(30321,67753,-6,'Rexford, Kansas 67753',22273,27093);
INSERT INTO "django_geo_db_zipcode" VALUES(30322,67756,-6,'Saint Francis, Kansas 67756',22274,27094);
INSERT INTO "django_geo_db_zipcode" VALUES(30323,67757,-6,'Selden, Kansas 67757',22275,27095);
INSERT INTO "django_geo_db_zipcode" VALUES(30324,67758,-7,'Sharon Springs, Kansas 67758',22276,27096);
INSERT INTO "django_geo_db_zipcode" VALUES(30325,67761,-7,'Wallace, Kansas 67761',22277,27097);
INSERT INTO "django_geo_db_zipcode" VALUES(30326,67762,-7,'Weskan, Kansas 67762',22278,27098);
INSERT INTO "django_geo_db_zipcode" VALUES(30327,67764,-6,'Winona, Kansas 67764',22279,27099);
INSERT INTO "django_geo_db_zipcode" VALUES(30328,67801,-6,'Dodge City, Kansas 67801',22280,27100);
INSERT INTO "django_geo_db_zipcode" VALUES(30329,67831,-6,'Ashland, Kansas 67831',22281,27101);
INSERT INTO "django_geo_db_zipcode" VALUES(30330,67834,-6,'Bucklin, Kansas 67834',22282,27102);
INSERT INTO "django_geo_db_zipcode" VALUES(30331,67835,-6,'Cimarron, Kansas 67835',22283,27103);
INSERT INTO "django_geo_db_zipcode" VALUES(30332,67836,-7,'Coolidge, Kansas 67836',22284,27104);
INSERT INTO "django_geo_db_zipcode" VALUES(30333,67837,-6,'Copeland, Kansas 67837',22285,27105);
INSERT INTO "django_geo_db_zipcode" VALUES(30334,67838,-6,'Deerfield, Kansas 67838',22286,27106);
INSERT INTO "django_geo_db_zipcode" VALUES(30335,67839,-6,'Dighton, Kansas 67839',22287,27107);
INSERT INTO "django_geo_db_zipcode" VALUES(30336,67840,-6,'Englewood, Kansas 67840',22288,27108);
INSERT INTO "django_geo_db_zipcode" VALUES(30337,67841,-6,'Ensign, Kansas 67841',22289,27109);
INSERT INTO "django_geo_db_zipcode" VALUES(30338,67842,-6,'Ford, Kansas 67842',22290,27110);
INSERT INTO "django_geo_db_zipcode" VALUES(30339,67844,-6,'Fowler, Kansas 67844',22291,27111);
INSERT INTO "django_geo_db_zipcode" VALUES(30340,67845,-6,'Bloom, Kansas 67845',22292,27112);
INSERT INTO "django_geo_db_zipcode" VALUES(30341,67846,-6,'Garden City, Kansas 67846',22293,27113);
INSERT INTO "django_geo_db_zipcode" VALUES(30342,67849,-6,'Hanston, Kansas 67849',22294,27114);
INSERT INTO "django_geo_db_zipcode" VALUES(30343,67850,-6,'Healy, Kansas 67850',22295,27115);
INSERT INTO "django_geo_db_zipcode" VALUES(30344,67851,-6,'Holcomb, Kansas 67851',22296,27116);
INSERT INTO "django_geo_db_zipcode" VALUES(30345,67852,-6,'Holcomb, Kansas 67852',22296,27117);
INSERT INTO "django_geo_db_zipcode" VALUES(30346,67853,-6,'Ingalls, Kansas 67853',22297,27118);
INSERT INTO "django_geo_db_zipcode" VALUES(30347,67854,-6,'Jetmore, Kansas 67854',22298,27119);
INSERT INTO "django_geo_db_zipcode" VALUES(30348,67855,-6,'Johnson, Kansas 67855',22299,27120);
INSERT INTO "django_geo_db_zipcode" VALUES(30349,67856,-6,'Garfield, Kansas 67856',22171,27121);
INSERT INTO "django_geo_db_zipcode" VALUES(30350,67857,-6,'Kendall, Kansas 67857',22300,27122);
INSERT INTO "django_geo_db_zipcode" VALUES(30351,67858,-6,'Sodville, Kansas 67858',22301,27123);
INSERT INTO "django_geo_db_zipcode" VALUES(30352,67859,-6,'Kismet, Kansas 67859',22302,27124);
INSERT INTO "django_geo_db_zipcode" VALUES(30353,67860,-6,'Lakin, Kansas 67860',22303,27125);
INSERT INTO "django_geo_db_zipcode" VALUES(30354,67861,-6,'Leoti, Kansas 67861',22304,27126);
INSERT INTO "django_geo_db_zipcode" VALUES(30355,67862,-6,'Manter, Kansas 67862',22305,27127);
INSERT INTO "django_geo_db_zipcode" VALUES(30356,67863,-6,'Marienthal, Kansas 67863',22306,27128);
INSERT INTO "django_geo_db_zipcode" VALUES(30357,67864,-6,'Meade, Kansas 67864',22307,27129);
INSERT INTO "django_geo_db_zipcode" VALUES(30358,67865,-6,'Minneola, Kansas 67865',22308,27130);
INSERT INTO "django_geo_db_zipcode" VALUES(30359,67867,-6,'Montezuma, Kansas 67867',22309,27131);
INSERT INTO "django_geo_db_zipcode" VALUES(30360,67868,-6,'Pierceville, Kansas 67868',22310,27132);
INSERT INTO "django_geo_db_zipcode" VALUES(30361,67869,-6,'Plains, Kansas 67869',22311,27133);
INSERT INTO "django_geo_db_zipcode" VALUES(30362,67870,-6,'Satanta, Kansas 67870',22312,27134);
INSERT INTO "django_geo_db_zipcode" VALUES(30363,67871,-6,'Scott City, Kansas 67871',22313,27135);
INSERT INTO "django_geo_db_zipcode" VALUES(30364,67876,-6,'Spearville, Kansas 67876',22314,27136);
INSERT INTO "django_geo_db_zipcode" VALUES(30365,67877,-6,'Sublette, Kansas 67877',22315,27137);
INSERT INTO "django_geo_db_zipcode" VALUES(30366,67878,-7,'Syracuse, Kansas 67878',22316,27138);
INSERT INTO "django_geo_db_zipcode" VALUES(30367,67879,-7,'Tribune, Kansas 67879',22317,27139);
INSERT INTO "django_geo_db_zipcode" VALUES(30368,67880,-6,'Ulysses, Kansas 67880',22318,27140);
INSERT INTO "django_geo_db_zipcode" VALUES(30369,67882,-6,'Wright, Kansas 67882',22319,27141);
INSERT INTO "django_geo_db_zipcode" VALUES(30370,67901,-6,'Liberal, Kansas 67901',22320,27142);
INSERT INTO "django_geo_db_zipcode" VALUES(30371,67905,-6,'Liberal, Kansas 67905',22320,27143);
INSERT INTO "django_geo_db_zipcode" VALUES(30372,67938,-6,'Colfax, Kansas 67938',22321,27144);
INSERT INTO "django_geo_db_zipcode" VALUES(30373,67950,-6,'Elkhart, Kansas 67950',22322,27145);
INSERT INTO "django_geo_db_zipcode" VALUES(30374,67951,-6,'Hugoton, Kansas 67951',22323,27146);
INSERT INTO "django_geo_db_zipcode" VALUES(30375,67952,-6,'Moscow, Kansas 67952',22324,27147);
INSERT INTO "django_geo_db_zipcode" VALUES(30376,67953,-6,'Richfield, Kansas 67953',22325,27148);
INSERT INTO "django_geo_db_zipcode" VALUES(30377,67954,-6,'Rolla, Kansas 67954',22326,27149);
INSERT INTO "django_geo_db_zipcode" VALUES(30378,68001,-6,'Abie, Nebraska 68001',22327,27150);
INSERT INTO "django_geo_db_zipcode" VALUES(30379,68002,-6,'Arlington, Nebraska 68002',22328,27151);
INSERT INTO "django_geo_db_zipcode" VALUES(30380,68003,-6,'Ashland, Nebraska 68003',22329,27152);
INSERT INTO "django_geo_db_zipcode" VALUES(30381,68004,-6,'Bancroft, Nebraska 68004',22330,27153);
INSERT INTO "django_geo_db_zipcode" VALUES(30382,68005,-6,'Bellevue, Nebraska 68005',22331,27154);
INSERT INTO "django_geo_db_zipcode" VALUES(30383,68007,-6,'Bennington, Nebraska 68007',22332,27155);
INSERT INTO "django_geo_db_zipcode" VALUES(30384,68008,-6,'Blair, Nebraska 68008',22333,27156);
INSERT INTO "django_geo_db_zipcode" VALUES(30385,68009,-6,'Blair, Nebraska 68009',22333,27157);
INSERT INTO "django_geo_db_zipcode" VALUES(30386,68010,-6,'Boys Town, Nebraska 68010',22334,27158);
INSERT INTO "django_geo_db_zipcode" VALUES(30387,68014,-6,'Bruno, Nebraska 68014',22335,27159);
INSERT INTO "django_geo_db_zipcode" VALUES(30388,68015,-6,'Cedar Bluffs, Nebraska 68015',22336,27160);
INSERT INTO "django_geo_db_zipcode" VALUES(30389,68016,-6,'Cedar Creek, Nebraska 68016',22337,27161);
INSERT INTO "django_geo_db_zipcode" VALUES(30390,68017,-6,'Ceresco, Nebraska 68017',22338,27162);
INSERT INTO "django_geo_db_zipcode" VALUES(30391,68018,-6,'Colon, Nebraska 68018',22339,27163);
INSERT INTO "django_geo_db_zipcode" VALUES(30392,68019,-6,'Craig, Nebraska 68019',22340,27164);
INSERT INTO "django_geo_db_zipcode" VALUES(30393,68020,-6,'Decatur, Nebraska 68020',22341,27165);
INSERT INTO "django_geo_db_zipcode" VALUES(30394,68022,-6,'Elkhorn, Nebraska 68022',22342,27166);
INSERT INTO "django_geo_db_zipcode" VALUES(30395,68023,-6,'Fort Calhoun, Nebraska 68023',22343,27167);
INSERT INTO "django_geo_db_zipcode" VALUES(30396,68025,-6,'Fremont, Nebraska 68025',22344,27168);
INSERT INTO "django_geo_db_zipcode" VALUES(30397,68026,-6,'Fremont, Nebraska 68026',22344,27169);
INSERT INTO "django_geo_db_zipcode" VALUES(30398,68028,-6,'Gretna, Nebraska 68028',22345,27170);
INSERT INTO "django_geo_db_zipcode" VALUES(30399,68029,-6,'Herman, Nebraska 68029',22346,27171);
INSERT INTO "django_geo_db_zipcode" VALUES(30400,68030,-6,'Homer, Nebraska 68030',22347,27172);
INSERT INTO "django_geo_db_zipcode" VALUES(30401,68031,-6,'Hooper, Nebraska 68031',22348,27173);
INSERT INTO "django_geo_db_zipcode" VALUES(30402,68032,-6,'Linwood, Nebraska 68032',22349,27174);
INSERT INTO "django_geo_db_zipcode" VALUES(30403,68033,-6,'Ithaca, Nebraska 68033',22350,27175);
INSERT INTO "django_geo_db_zipcode" VALUES(30404,68034,-6,'Kennard, Nebraska 68034',22351,27176);
INSERT INTO "django_geo_db_zipcode" VALUES(30405,68035,-6,'Leshara, Nebraska 68035',22352,27177);
INSERT INTO "django_geo_db_zipcode" VALUES(30406,68036,-6,'Linwood, Nebraska 68036',22349,27178);
INSERT INTO "django_geo_db_zipcode" VALUES(30407,68037,-6,'Louisville, Nebraska 68037',22353,27179);
INSERT INTO "django_geo_db_zipcode" VALUES(30408,68038,-6,'Lyons, Nebraska 68038',22354,27180);
INSERT INTO "django_geo_db_zipcode" VALUES(30409,68039,-6,'Macy, Nebraska 68039',22355,27181);
INSERT INTO "django_geo_db_zipcode" VALUES(30410,68040,-6,'Malmo, Nebraska 68040',22356,27182);
INSERT INTO "django_geo_db_zipcode" VALUES(30411,68041,-6,'Mead, Nebraska 68041',22357,27183);
INSERT INTO "django_geo_db_zipcode" VALUES(30412,68042,-6,'Memphis, Nebraska 68042',22358,27184);
INSERT INTO "django_geo_db_zipcode" VALUES(30413,68044,-6,'Nickerson, Nebraska 68044',22359,27185);
INSERT INTO "django_geo_db_zipcode" VALUES(30414,68045,-6,'Oakland, Nebraska 68045',22360,27186);
INSERT INTO "django_geo_db_zipcode" VALUES(30415,68046,-6,'Papillion, Nebraska 68046',22361,27187);
INSERT INTO "django_geo_db_zipcode" VALUES(30416,68047,-6,'Pender, Nebraska 68047',22362,27188);
INSERT INTO "django_geo_db_zipcode" VALUES(30417,68048,-6,'Plattsmouth, Nebraska 68048',22363,27189);
INSERT INTO "django_geo_db_zipcode" VALUES(30418,68050,-6,'Prague, Nebraska 68050',22364,27190);
INSERT INTO "django_geo_db_zipcode" VALUES(30419,68054,-6,'Richfield, Nebraska 68054',22365,27191);
INSERT INTO "django_geo_db_zipcode" VALUES(30420,68055,-6,'Rosalie, Nebraska 68055',22366,27192);
INSERT INTO "django_geo_db_zipcode" VALUES(30421,68056,-6,'St Columbans, Nebraska 68056',22367,27193);
INSERT INTO "django_geo_db_zipcode" VALUES(30422,68057,-6,'Scribner, Nebraska 68057',22368,27194);
INSERT INTO "django_geo_db_zipcode" VALUES(30423,68058,-6,'South Bend, Nebraska 68058',22369,27195);
INSERT INTO "django_geo_db_zipcode" VALUES(30424,68059,-6,'Springfield, Nebraska 68059',22370,27196);
INSERT INTO "django_geo_db_zipcode" VALUES(30425,68061,-6,'Tekamah, Nebraska 68061',22371,27197);
INSERT INTO "django_geo_db_zipcode" VALUES(30426,68062,-6,'Thurston, Nebraska 68062',22372,27198);
INSERT INTO "django_geo_db_zipcode" VALUES(30427,68063,-6,'Uehling, Nebraska 68063',22373,27199);
INSERT INTO "django_geo_db_zipcode" VALUES(30428,68064,-6,'Valley, Nebraska 68064',22374,27200);
INSERT INTO "django_geo_db_zipcode" VALUES(30429,68065,-6,'Valparaiso, Nebraska 68065',22375,27201);
INSERT INTO "django_geo_db_zipcode" VALUES(30430,68066,-6,'Wahoo, Nebraska 68066',22376,27202);
INSERT INTO "django_geo_db_zipcode" VALUES(30431,68067,-6,'Walthill, Nebraska 68067',22377,27203);
INSERT INTO "django_geo_db_zipcode" VALUES(30432,68068,-6,'Washington, Nebraska 68068',22378,27204);
INSERT INTO "django_geo_db_zipcode" VALUES(30433,68069,-6,'Waterloo, Nebraska 68069',22379,27205);
INSERT INTO "django_geo_db_zipcode" VALUES(30434,68070,-6,'Weston, Nebraska 68070',22380,27206);
INSERT INTO "django_geo_db_zipcode" VALUES(30435,68071,-6,'Winnebago, Nebraska 68071',22381,27207);
INSERT INTO "django_geo_db_zipcode" VALUES(30436,68072,-6,'Winslow, Nebraska 68072',22382,27208);
INSERT INTO "django_geo_db_zipcode" VALUES(30437,68073,-6,'Yutan, Nebraska 68073',22383,27209);
INSERT INTO "django_geo_db_zipcode" VALUES(30438,68101,-6,'Omaha, Nebraska 68101',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30439,68102,-6,'Omaha, Nebraska 68102',22384,27211);
INSERT INTO "django_geo_db_zipcode" VALUES(30440,68103,-6,'Omaha, Nebraska 68103',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30441,68104,-6,'Omaha, Nebraska 68104',22384,27212);
INSERT INTO "django_geo_db_zipcode" VALUES(30442,68105,-6,'Omaha, Nebraska 68105',22384,27213);
INSERT INTO "django_geo_db_zipcode" VALUES(30443,68106,-6,'Omaha, Nebraska 68106',22384,27214);
INSERT INTO "django_geo_db_zipcode" VALUES(30444,68107,-6,'Omaha, Nebraska 68107',22384,27215);
INSERT INTO "django_geo_db_zipcode" VALUES(30445,68108,-6,'Omaha, Nebraska 68108',22384,27216);
INSERT INTO "django_geo_db_zipcode" VALUES(30446,68109,-6,'Omaha, Nebraska 68109',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30447,68110,-6,'Omaha, Nebraska 68110',22384,27217);
INSERT INTO "django_geo_db_zipcode" VALUES(30448,68111,-6,'Omaha, Nebraska 68111',22384,27218);
INSERT INTO "django_geo_db_zipcode" VALUES(30449,68112,-6,'Omaha, Nebraska 68112',22384,27219);
INSERT INTO "django_geo_db_zipcode" VALUES(30450,68113,-6,'Offutt A F B, Nebraska 68113',22385,27220);
INSERT INTO "django_geo_db_zipcode" VALUES(30451,68114,-6,'Omaha, Nebraska 68114',22384,27221);
INSERT INTO "django_geo_db_zipcode" VALUES(30452,68116,-6,'Omaha, Nebraska 68116',22384,27222);
INSERT INTO "django_geo_db_zipcode" VALUES(30453,68117,-6,'Omaha, Nebraska 68117',22384,27223);
INSERT INTO "django_geo_db_zipcode" VALUES(30454,68118,-6,'Omaha, Nebraska 68118',22384,27224);
INSERT INTO "django_geo_db_zipcode" VALUES(30455,68119,-6,'Omaha, Nebraska 68119',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30456,68120,-6,'Omaha, Nebraska 68120',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30457,68122,-6,'Omaha, Nebraska 68122',22384,27225);
INSERT INTO "django_geo_db_zipcode" VALUES(30458,68123,-6,'Bellevue, Nebraska 68123',22331,27226);
INSERT INTO "django_geo_db_zipcode" VALUES(30459,68124,-6,'Omaha, Nebraska 68124',22384,27227);
INSERT INTO "django_geo_db_zipcode" VALUES(30460,68127,-6,'Omaha, Nebraska 68127',22384,27228);
INSERT INTO "django_geo_db_zipcode" VALUES(30461,68128,-6,'La Vista, Nebraska 68128',22386,27229);
INSERT INTO "django_geo_db_zipcode" VALUES(30462,68130,-6,'Omaha, Nebraska 68130',22384,27230);
INSERT INTO "django_geo_db_zipcode" VALUES(30463,68131,-6,'Omaha, Nebraska 68131',22384,27231);
INSERT INTO "django_geo_db_zipcode" VALUES(30464,68132,-6,'Omaha, Nebraska 68132',22384,27232);
INSERT INTO "django_geo_db_zipcode" VALUES(30465,68133,-6,'Papillion, Nebraska 68133',22361,27233);
INSERT INTO "django_geo_db_zipcode" VALUES(30466,68134,-6,'Omaha, Nebraska 68134',22384,27234);
INSERT INTO "django_geo_db_zipcode" VALUES(30467,68135,-6,'Omaha, Nebraska 68135',22384,27235);
INSERT INTO "django_geo_db_zipcode" VALUES(30468,68136,-6,'Omaha, Nebraska 68136',22384,27236);
INSERT INTO "django_geo_db_zipcode" VALUES(30469,68137,-6,'Omaha, Nebraska 68137',22384,27237);
INSERT INTO "django_geo_db_zipcode" VALUES(30470,68138,-6,'Omaha, Nebraska 68138',22384,27238);
INSERT INTO "django_geo_db_zipcode" VALUES(30471,68139,-6,'Omaha, Nebraska 68139',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30472,68142,-6,'Omaha, Nebraska 68142',22384,27239);
INSERT INTO "django_geo_db_zipcode" VALUES(30473,68144,-6,'Omaha, Nebraska 68144',22384,27240);
INSERT INTO "django_geo_db_zipcode" VALUES(30474,68145,-6,'Omaha, Nebraska 68145',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30475,68147,-6,'Bellevue, Nebraska 68147',22331,27241);
INSERT INTO "django_geo_db_zipcode" VALUES(30476,68152,-6,'Omaha, Nebraska 68152',22384,27242);
INSERT INTO "django_geo_db_zipcode" VALUES(30477,68154,-6,'Omaha, Nebraska 68154',22384,27243);
INSERT INTO "django_geo_db_zipcode" VALUES(30478,68155,-6,'Omaha, Nebraska 68155',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30479,68157,-6,'Omaha, Nebraska 68157',22384,27244);
INSERT INTO "django_geo_db_zipcode" VALUES(30480,68164,-6,'Omaha, Nebraska 68164',22384,27245);
INSERT INTO "django_geo_db_zipcode" VALUES(30481,68172,-6,'Omaha, Nebraska 68172',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30482,68175,-6,'Omaha, Nebraska 68175',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30483,68176,-6,'Omaha, Nebraska 68176',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30484,68178,-6,'Omaha, Nebraska 68178',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30485,68179,-6,'Omaha, Nebraska 68179',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30486,68180,-6,'Omaha, Nebraska 68180',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30487,68181,-6,'Omaha, Nebraska 68181',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30488,68182,-6,'Omaha, Nebraska 68182',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30489,68183,-6,'Omaha, Nebraska 68183',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30490,68198,-6,'Omaha, Nebraska 68198',22384,27210);
INSERT INTO "django_geo_db_zipcode" VALUES(30491,68226,-6,'Central City, Nebraska 68226',22387,27246);
INSERT INTO "django_geo_db_zipcode" VALUES(30492,68278,-6,'Omaha, Nebraska 68278',22384,27247);
INSERT INTO "django_geo_db_zipcode" VALUES(30493,68301,-6,'Adams, Nebraska 68301',22388,27248);
INSERT INTO "django_geo_db_zipcode" VALUES(30494,68303,-6,'Alexandria, Nebraska 68303',22389,27249);
INSERT INTO "django_geo_db_zipcode" VALUES(30495,68304,-6,'Alvo, Nebraska 68304',22390,27250);
INSERT INTO "django_geo_db_zipcode" VALUES(30496,68305,-6,'Auburn, Nebraska 68305',22391,27251);
INSERT INTO "django_geo_db_zipcode" VALUES(30497,68307,-6,'Avoca, Nebraska 68307',22392,27252);
INSERT INTO "django_geo_db_zipcode" VALUES(30498,68309,-6,'Barneston, Nebraska 68309',22393,27253);
INSERT INTO "django_geo_db_zipcode" VALUES(30499,68310,-6,'Beatrice, Nebraska 68310',22394,27254);
INSERT INTO "django_geo_db_zipcode" VALUES(30500,68313,-6,'Beaver Crossing, Nebraska 68313',22395,27255);
INSERT INTO "django_geo_db_zipcode" VALUES(30501,68314,-6,'Bee, Nebraska 68314',22396,27256);
INSERT INTO "django_geo_db_zipcode" VALUES(30502,68315,-6,'Belvidere, Nebraska 68315',22397,27257);
INSERT INTO "django_geo_db_zipcode" VALUES(30503,68316,-6,'Benedict, Nebraska 68316',22398,27258);
INSERT INTO "django_geo_db_zipcode" VALUES(30504,68317,-6,'Bennet, Nebraska 68317',22399,27259);
INSERT INTO "django_geo_db_zipcode" VALUES(30505,68318,-6,'Blue Springs, Nebraska 68318',22400,27260);
INSERT INTO "django_geo_db_zipcode" VALUES(30506,68319,-6,'Bradshaw, Nebraska 68319',22401,27261);
INSERT INTO "django_geo_db_zipcode" VALUES(30507,68320,-6,'Brock, Nebraska 68320',22402,27262);
INSERT INTO "django_geo_db_zipcode" VALUES(30508,68321,-6,'Brownville, Nebraska 68321',22403,27263);
INSERT INTO "django_geo_db_zipcode" VALUES(30509,68322,-6,'Bruning, Nebraska 68322',22404,27264);
INSERT INTO "django_geo_db_zipcode" VALUES(30510,68323,-6,'Burchard, Nebraska 68323',22405,27265);
INSERT INTO "django_geo_db_zipcode" VALUES(30511,68324,-6,'Burr, Nebraska 68324',22406,27266);
INSERT INTO "django_geo_db_zipcode" VALUES(30512,68325,-6,'Byron, Nebraska 68325',22407,27267);
INSERT INTO "django_geo_db_zipcode" VALUES(30513,68326,-6,'Carleton, Nebraska 68326',22408,27268);
INSERT INTO "django_geo_db_zipcode" VALUES(30514,68327,-6,'Chester, Nebraska 68327',22409,27269);
INSERT INTO "django_geo_db_zipcode" VALUES(30515,68328,-6,'Clatonia, Nebraska 68328',22410,27270);
INSERT INTO "django_geo_db_zipcode" VALUES(30516,68329,-6,'Cook, Nebraska 68329',22411,27271);
INSERT INTO "django_geo_db_zipcode" VALUES(30517,68330,-6,'Cordova, Nebraska 68330',22412,27272);
INSERT INTO "django_geo_db_zipcode" VALUES(30518,68331,-6,'Cortland, Nebraska 68331',22413,27273);
INSERT INTO "django_geo_db_zipcode" VALUES(30519,68332,-6,'Crab Orchard, Nebraska 68332',22414,27274);
INSERT INTO "django_geo_db_zipcode" VALUES(30520,68333,-6,'Crete, Nebraska 68333',22415,27275);
INSERT INTO "django_geo_db_zipcode" VALUES(30521,68335,-6,'Davenport, Nebraska 68335',22416,27276);
INSERT INTO "django_geo_db_zipcode" VALUES(30522,68336,-6,'Davey, Nebraska 68336',22417,27277);
INSERT INTO "django_geo_db_zipcode" VALUES(30523,68337,-6,'Dawson, Nebraska 68337',22418,27278);
INSERT INTO "django_geo_db_zipcode" VALUES(30524,68338,-6,'Daykin, Nebraska 68338',22419,27279);
INSERT INTO "django_geo_db_zipcode" VALUES(30525,68339,-6,'Denton, Nebraska 68339',22420,27280);
INSERT INTO "django_geo_db_zipcode" VALUES(30526,68340,-6,'Deshler, Nebraska 68340',22421,27281);
INSERT INTO "django_geo_db_zipcode" VALUES(30527,68341,-6,'De Witt, Nebraska 68341',22422,27282);
INSERT INTO "django_geo_db_zipcode" VALUES(30528,68342,-6,'Diller, Nebraska 68342',22423,27283);
INSERT INTO "django_geo_db_zipcode" VALUES(30529,68343,-6,'Dorchester, Nebraska 68343',22424,27284);
INSERT INTO "django_geo_db_zipcode" VALUES(30530,68344,-6,'Douglas, Nebraska 68344',22425,27285);
INSERT INTO "django_geo_db_zipcode" VALUES(30531,68345,-6,'Du Bois, Nebraska 68345',22426,27286);
INSERT INTO "django_geo_db_zipcode" VALUES(30532,68346,-6,'Dunbar, Nebraska 68346',22427,27287);
INSERT INTO "django_geo_db_zipcode" VALUES(30533,68347,-6,'Eagle, Nebraska 68347',22428,27288);
INSERT INTO "django_geo_db_zipcode" VALUES(30534,68348,-6,'Elk Creek, Nebraska 68348',22429,27289);
INSERT INTO "django_geo_db_zipcode" VALUES(30535,68349,-6,'Elmwood, Nebraska 68349',22430,27290);
INSERT INTO "django_geo_db_zipcode" VALUES(30536,68350,-6,'Endicott, Nebraska 68350',22431,27291);
INSERT INTO "django_geo_db_zipcode" VALUES(30537,68351,-6,'Exeter, Nebraska 68351',22432,27292);
INSERT INTO "django_geo_db_zipcode" VALUES(30538,68352,-6,'Fairbury, Nebraska 68352',22433,27293);
INSERT INTO "django_geo_db_zipcode" VALUES(30539,68354,-6,'Fairmont, Nebraska 68354',22434,27294);
INSERT INTO "django_geo_db_zipcode" VALUES(30540,68355,-6,'Falls City, Nebraska 68355',22435,27295);
INSERT INTO "django_geo_db_zipcode" VALUES(30541,68357,-6,'Filley, Nebraska 68357',22436,27296);
INSERT INTO "django_geo_db_zipcode" VALUES(30542,68358,-6,'Firth, Nebraska 68358',22437,27297);
INSERT INTO "django_geo_db_zipcode" VALUES(30543,68359,-6,'Friend, Nebraska 68359',22438,27298);
INSERT INTO "django_geo_db_zipcode" VALUES(30544,68360,-6,'Garland, Nebraska 68360',22439,27299);
INSERT INTO "django_geo_db_zipcode" VALUES(30545,68361,-6,'Geneva, Nebraska 68361',22440,27300);
INSERT INTO "django_geo_db_zipcode" VALUES(30546,68362,-6,'Gilead, Nebraska 68362',22441,27301);
INSERT INTO "django_geo_db_zipcode" VALUES(30547,68364,-6,'Goehner, Nebraska 68364',22442,27302);
INSERT INTO "django_geo_db_zipcode" VALUES(30548,68365,-6,'Grafton, Nebraska 68365',22443,27303);
INSERT INTO "django_geo_db_zipcode" VALUES(30549,68366,-6,'Greenwood, Nebraska 68366',22444,27304);
INSERT INTO "django_geo_db_zipcode" VALUES(30550,68367,-6,'Gresham, Nebraska 68367',22445,27305);
INSERT INTO "django_geo_db_zipcode" VALUES(30551,68368,-6,'Hallam, Nebraska 68368',22446,27306);
INSERT INTO "django_geo_db_zipcode" VALUES(30552,68370,-6,'Hebron, Nebraska 68370',22447,27307);
INSERT INTO "django_geo_db_zipcode" VALUES(30553,68371,-6,'Henderson, Nebraska 68371',22448,27308);
INSERT INTO "django_geo_db_zipcode" VALUES(30554,68372,-6,'Hickman, Nebraska 68372',22449,27309);
INSERT INTO "django_geo_db_zipcode" VALUES(30555,68374,-6,'Holmesville, Nebraska 68374',22450,27310);
INSERT INTO "django_geo_db_zipcode" VALUES(30556,68375,-6,'Hubbell, Nebraska 68375',22451,27311);
INSERT INTO "django_geo_db_zipcode" VALUES(30557,68376,-6,'Humboldt, Nebraska 68376',22452,27312);
INSERT INTO "django_geo_db_zipcode" VALUES(30558,68377,-6,'Jansen, Nebraska 68377',22453,27313);
INSERT INTO "django_geo_db_zipcode" VALUES(30559,68378,-6,'Johnson, Nebraska 68378',22454,27314);
INSERT INTO "django_geo_db_zipcode" VALUES(30560,68380,-6,'Lewiston, Nebraska 68380',22455,27315);
INSERT INTO "django_geo_db_zipcode" VALUES(30561,68381,-6,'Liberty, Nebraska 68381',22456,27316);
INSERT INTO "django_geo_db_zipcode" VALUES(30562,68382,-6,'Lorton, Nebraska 68382',22457,27317);
INSERT INTO "django_geo_db_zipcode" VALUES(30563,68401,-6,'McCool Junction, Nebraska 68401',22458,27318);
INSERT INTO "django_geo_db_zipcode" VALUES(30564,68402,-6,'Malcolm, Nebraska 68402',22459,27319);
INSERT INTO "django_geo_db_zipcode" VALUES(30565,68403,-6,'Manley, Nebraska 68403',22460,27320);
INSERT INTO "django_geo_db_zipcode" VALUES(30566,68404,-6,'Martell, Nebraska 68404',22461,27321);
INSERT INTO "django_geo_db_zipcode" VALUES(30567,68405,-6,'Milford, Nebraska 68405',22462,27322);
INSERT INTO "django_geo_db_zipcode" VALUES(30568,68406,-6,'Milligan, Nebraska 68406',22463,27323);
INSERT INTO "django_geo_db_zipcode" VALUES(30569,68407,-6,'Murdock, Nebraska 68407',22464,27324);
INSERT INTO "django_geo_db_zipcode" VALUES(30570,68409,-6,'Murray, Nebraska 68409',22465,27325);
INSERT INTO "django_geo_db_zipcode" VALUES(30571,68410,-6,'Nebraska City, Nebraska 68410',22466,27326);
INSERT INTO "django_geo_db_zipcode" VALUES(30572,68413,-6,'Nehawka, Nebraska 68413',22467,27327);
INSERT INTO "django_geo_db_zipcode" VALUES(30573,68414,-6,'Nemaha, Nebraska 68414',22468,27328);
INSERT INTO "django_geo_db_zipcode" VALUES(30574,68415,-6,'Odell, Nebraska 68415',22469,27329);
INSERT INTO "django_geo_db_zipcode" VALUES(30575,68416,-6,'Ohiowa, Nebraska 68416',22470,27330);
INSERT INTO "django_geo_db_zipcode" VALUES(30576,68417,-6,'Otoe, Nebraska 68417',22471,27331);
INSERT INTO "django_geo_db_zipcode" VALUES(30577,68418,-6,'Palmyra, Nebraska 68418',22472,27332);
INSERT INTO "django_geo_db_zipcode" VALUES(30578,68419,-6,'Panama, Nebraska 68419',22473,27333);
INSERT INTO "django_geo_db_zipcode" VALUES(30579,68420,-6,'Pawnee City, Nebraska 68420',22474,27334);
INSERT INTO "django_geo_db_zipcode" VALUES(30580,68421,-6,'Peru, Nebraska 68421',22475,27335);
INSERT INTO "django_geo_db_zipcode" VALUES(30581,68422,-6,'Pickrell, Nebraska 68422',22476,27336);
INSERT INTO "django_geo_db_zipcode" VALUES(30582,68423,-6,'Pleasant Dale, Nebraska 68423',22477,27337);
INSERT INTO "django_geo_db_zipcode" VALUES(30583,68424,-6,'Plymouth, Nebraska 68424',22478,27338);
INSERT INTO "django_geo_db_zipcode" VALUES(30584,68428,-6,'Raymond, Nebraska 68428',22479,27339);
INSERT INTO "django_geo_db_zipcode" VALUES(30585,68429,-6,'Reynolds, Nebraska 68429',22480,27340);
INSERT INTO "django_geo_db_zipcode" VALUES(30586,68430,-6,'Roca, Nebraska 68430',22481,27341);
INSERT INTO "django_geo_db_zipcode" VALUES(30587,68431,-6,'Rulo, Nebraska 68431',22482,27342);
INSERT INTO "django_geo_db_zipcode" VALUES(30588,68433,-6,'Salem, Nebraska 68433',22483,27343);
INSERT INTO "django_geo_db_zipcode" VALUES(30589,68434,-6,'Seward, Nebraska 68434',22484,27344);
INSERT INTO "django_geo_db_zipcode" VALUES(30590,68436,-6,'Shickley, Nebraska 68436',22485,27345);
INSERT INTO "django_geo_db_zipcode" VALUES(30591,68437,-6,'Shubert, Nebraska 68437',22486,27346);
INSERT INTO "django_geo_db_zipcode" VALUES(30592,68438,-6,'Sprague, Nebraska 68438',22487,27347);
INSERT INTO "django_geo_db_zipcode" VALUES(30593,68439,-6,'Staplehurst, Nebraska 68439',22488,27348);
INSERT INTO "django_geo_db_zipcode" VALUES(30594,68440,-6,'Steele City, Nebraska 68440',22489,27349);
INSERT INTO "django_geo_db_zipcode" VALUES(30595,68441,-6,'Steinauer, Nebraska 68441',22490,27350);
INSERT INTO "django_geo_db_zipcode" VALUES(30596,68442,-6,'Stella, Nebraska 68442',22491,27351);
INSERT INTO "django_geo_db_zipcode" VALUES(30597,68443,-6,'Sterling, Nebraska 68443',22492,27352);
INSERT INTO "django_geo_db_zipcode" VALUES(30598,68444,-6,'Strang, Nebraska 68444',22493,27353);
INSERT INTO "django_geo_db_zipcode" VALUES(30599,68445,-6,'Swanton, Nebraska 68445',22494,27354);
INSERT INTO "django_geo_db_zipcode" VALUES(30600,68446,-6,'Syracuse, Nebraska 68446',22495,27355);
INSERT INTO "django_geo_db_zipcode" VALUES(30601,68447,-6,'Table Rock, Nebraska 68447',22496,27356);
INSERT INTO "django_geo_db_zipcode" VALUES(30602,68448,-6,'Talmage, Nebraska 68448',22497,27357);
INSERT INTO "django_geo_db_zipcode" VALUES(30603,68450,-6,'Tecumseh, Nebraska 68450',22498,27358);
INSERT INTO "django_geo_db_zipcode" VALUES(30604,68452,-6,'Ong, Nebraska 68452',22499,27359);
INSERT INTO "django_geo_db_zipcode" VALUES(30605,68453,-6,'Tobias, Nebraska 68453',22500,27360);
INSERT INTO "django_geo_db_zipcode" VALUES(30606,68454,-6,'Unadilla, Nebraska 68454',22501,27361);
INSERT INTO "django_geo_db_zipcode" VALUES(30607,68455,-6,'Union, Nebraska 68455',22502,27362);
INSERT INTO "django_geo_db_zipcode" VALUES(30608,68456,-6,'Utica, Nebraska 68456',22503,27363);
INSERT INTO "django_geo_db_zipcode" VALUES(30609,68457,-6,'Verdon, Nebraska 68457',22504,27364);
INSERT INTO "django_geo_db_zipcode" VALUES(30610,68458,-6,'Virginia, Nebraska 68458',22505,27365);
INSERT INTO "django_geo_db_zipcode" VALUES(30611,68460,-6,'Waco, Nebraska 68460',22506,27366);
INSERT INTO "django_geo_db_zipcode" VALUES(30612,68461,-6,'Walton, Nebraska 68461',22507,27367);
INSERT INTO "django_geo_db_zipcode" VALUES(30613,68462,-6,'Waverly, Nebraska 68462',22508,27368);
INSERT INTO "django_geo_db_zipcode" VALUES(30614,68463,-6,'Weeping Water, Nebraska 68463',22509,27369);
INSERT INTO "django_geo_db_zipcode" VALUES(30615,68464,-6,'Western, Nebraska 68464',22510,27370);
INSERT INTO "django_geo_db_zipcode" VALUES(30616,68465,-6,'Wilber, Nebraska 68465',22511,27371);
INSERT INTO "django_geo_db_zipcode" VALUES(30617,68466,-6,'Wymore, Nebraska 68466',22512,27372);
INSERT INTO "django_geo_db_zipcode" VALUES(30618,68467,-6,'York, Nebraska 68467',22513,27373);
INSERT INTO "django_geo_db_zipcode" VALUES(30619,68501,-6,'Lincoln, Nebraska 68501',22514,27374);
INSERT INTO "django_geo_db_zipcode" VALUES(30620,68502,-6,'Lincoln, Nebraska 68502',22514,27375);
INSERT INTO "django_geo_db_zipcode" VALUES(30621,68503,-6,'Lincoln, Nebraska 68503',22514,27376);
INSERT INTO "django_geo_db_zipcode" VALUES(30622,68504,-6,'Lincoln, Nebraska 68504',22514,27377);
INSERT INTO "django_geo_db_zipcode" VALUES(30623,68505,-6,'Lincoln, Nebraska 68505',22514,27378);
INSERT INTO "django_geo_db_zipcode" VALUES(30624,68506,-6,'Lincoln, Nebraska 68506',22514,27379);
INSERT INTO "django_geo_db_zipcode" VALUES(30625,68507,-6,'Lincoln, Nebraska 68507',22514,27380);
INSERT INTO "django_geo_db_zipcode" VALUES(30626,68508,-6,'Lincoln, Nebraska 68508',22514,27381);
INSERT INTO "django_geo_db_zipcode" VALUES(30627,68509,-6,'Lincoln, Nebraska 68509',22514,27382);
INSERT INTO "django_geo_db_zipcode" VALUES(30628,68510,-6,'Lincoln, Nebraska 68510',22514,27383);
INSERT INTO "django_geo_db_zipcode" VALUES(30629,68512,-6,'Lincoln, Nebraska 68512',22514,27384);
INSERT INTO "django_geo_db_zipcode" VALUES(30630,68514,-6,'Lincoln, Nebraska 68514',22514,27385);
INSERT INTO "django_geo_db_zipcode" VALUES(30631,68516,-6,'Lincoln, Nebraska 68516',22514,27386);
INSERT INTO "django_geo_db_zipcode" VALUES(30632,68517,-6,'Lincoln, Nebraska 68517',22514,27387);
INSERT INTO "django_geo_db_zipcode" VALUES(30633,68520,-6,'Lincoln, Nebraska 68520',22514,27388);
INSERT INTO "django_geo_db_zipcode" VALUES(30634,68521,-6,'Lincoln, Nebraska 68521',22514,27389);
INSERT INTO "django_geo_db_zipcode" VALUES(30635,68522,-6,'Lincoln, Nebraska 68522',22514,27390);
INSERT INTO "django_geo_db_zipcode" VALUES(30636,68523,-6,'Lincoln, Nebraska 68523',22514,27391);
INSERT INTO "django_geo_db_zipcode" VALUES(30637,68524,-6,'Lincoln, Nebraska 68524',22514,27392);
INSERT INTO "django_geo_db_zipcode" VALUES(30638,68526,-6,'Lincoln, Nebraska 68526',22514,27393);
INSERT INTO "django_geo_db_zipcode" VALUES(30639,68527,-6,'Lincoln, Nebraska 68527',22514,27394);
INSERT INTO "django_geo_db_zipcode" VALUES(30640,68528,-6,'Lincoln, Nebraska 68528',22514,27395);
INSERT INTO "django_geo_db_zipcode" VALUES(30641,68529,-6,'Lincoln, Nebraska 68529',22514,27396);
INSERT INTO "django_geo_db_zipcode" VALUES(30642,68531,-6,'Lincoln, Nebraska 68531',22514,27397);
INSERT INTO "django_geo_db_zipcode" VALUES(30643,68532,-6,'Lincoln, Nebraska 68532',22514,27398);
INSERT INTO "django_geo_db_zipcode" VALUES(30644,68542,-6,'Lincoln, Nebraska 68542',22514,27382);
INSERT INTO "django_geo_db_zipcode" VALUES(30645,68544,-6,'Lincoln, Nebraska 68544',22514,27382);
INSERT INTO "django_geo_db_zipcode" VALUES(30646,68572,-6,'Lincoln, Nebraska 68572',22514,27382);
INSERT INTO "django_geo_db_zipcode" VALUES(30647,68583,-6,'Lincoln, Nebraska 68583',22514,27382);
INSERT INTO "django_geo_db_zipcode" VALUES(30648,68588,-6,'Lincoln, Nebraska 68588',22514,27399);
INSERT INTO "django_geo_db_zipcode" VALUES(30649,68601,-6,'Columbus, Nebraska 68601',22515,27400);
INSERT INTO "django_geo_db_zipcode" VALUES(30650,68602,-6,'Columbus, Nebraska 68602',22515,27401);
INSERT INTO "django_geo_db_zipcode" VALUES(30651,68620,-6,'Albion, Nebraska 68620',22516,27402);
INSERT INTO "django_geo_db_zipcode" VALUES(30652,68621,-6,'Ames, Nebraska 68621',22517,27403);
INSERT INTO "django_geo_db_zipcode" VALUES(30653,68622,-6,'Bartlett, Nebraska 68622',22518,27404);
INSERT INTO "django_geo_db_zipcode" VALUES(30654,68623,-6,'Belgrade, Nebraska 68623',22519,27405);
INSERT INTO "django_geo_db_zipcode" VALUES(30655,68624,-6,'Bellwood, Nebraska 68624',22520,27406);
INSERT INTO "django_geo_db_zipcode" VALUES(30656,68626,-6,'Brainard, Nebraska 68626',22521,27407);
INSERT INTO "django_geo_db_zipcode" VALUES(30657,68627,-6,'Cedar Rapids, Nebraska 68627',22522,27408);
INSERT INTO "django_geo_db_zipcode" VALUES(30658,68628,-6,'Clarks, Nebraska 68628',22523,27409);
INSERT INTO "django_geo_db_zipcode" VALUES(30659,68629,-6,'Clarkson, Nebraska 68629',22524,27410);
INSERT INTO "django_geo_db_zipcode" VALUES(30660,68631,-6,'Creston, Nebraska 68631',22525,27411);
INSERT INTO "django_geo_db_zipcode" VALUES(30661,68632,-6,'David City, Nebraska 68632',22526,27412);
INSERT INTO "django_geo_db_zipcode" VALUES(30662,68633,-6,'Dodge, Nebraska 68633',22527,27413);
INSERT INTO "django_geo_db_zipcode" VALUES(30663,68634,-6,'Duncan, Nebraska 68634',22528,27414);
INSERT INTO "django_geo_db_zipcode" VALUES(30664,68635,-6,'Dwight, Nebraska 68635',22529,27415);
INSERT INTO "django_geo_db_zipcode" VALUES(30665,68636,-6,'Elgin, Nebraska 68636',22530,27416);
INSERT INTO "django_geo_db_zipcode" VALUES(30666,68637,-6,'Ericson, Nebraska 68637',22531,27417);
INSERT INTO "django_geo_db_zipcode" VALUES(30667,68638,-6,'Fullerton, Nebraska 68638',22532,27418);
INSERT INTO "django_geo_db_zipcode" VALUES(30668,68640,-6,'Genoa, Nebraska 68640',22533,27419);
INSERT INTO "django_geo_db_zipcode" VALUES(30669,68641,-6,'Howells, Nebraska 68641',22534,27420);
INSERT INTO "django_geo_db_zipcode" VALUES(30670,68642,-6,'Humphrey, Nebraska 68642',22535,27421);
INSERT INTO "django_geo_db_zipcode" VALUES(30671,68643,-6,'Leigh, Nebraska 68643',22536,27422);
INSERT INTO "django_geo_db_zipcode" VALUES(30672,68644,-6,'Lindsay, Nebraska 68644',22537,27423);
INSERT INTO "django_geo_db_zipcode" VALUES(30673,68647,-6,'Monroe, Nebraska 68647',22538,27424);
INSERT INTO "django_geo_db_zipcode" VALUES(30674,68648,-6,'Morse Bluff, Nebraska 68648',22539,27425);
INSERT INTO "django_geo_db_zipcode" VALUES(30675,68649,-6,'North Bend, Nebraska 68649',22540,27426);
INSERT INTO "django_geo_db_zipcode" VALUES(30676,68651,-6,'Osceola, Nebraska 68651',22541,27427);
INSERT INTO "django_geo_db_zipcode" VALUES(30677,68652,-6,'Petersburg, Nebraska 68652',22542,27428);
INSERT INTO "django_geo_db_zipcode" VALUES(30678,68653,-6,'Platte Center, Nebraska 68653',22543,27429);
INSERT INTO "django_geo_db_zipcode" VALUES(30679,68654,-6,'Polk, Nebraska 68654',22544,27430);
INSERT INTO "django_geo_db_zipcode" VALUES(30680,68655,-6,'Primrose, Nebraska 68655',22545,27431);
INSERT INTO "django_geo_db_zipcode" VALUES(30681,68658,-6,'Rising City, Nebraska 68658',22546,27432);
INSERT INTO "django_geo_db_zipcode" VALUES(30682,68659,-6,'Rogers, Nebraska 68659',22547,27433);
INSERT INTO "django_geo_db_zipcode" VALUES(30683,68660,-6,'Saint Edward, Nebraska 68660',22548,27434);
INSERT INTO "django_geo_db_zipcode" VALUES(30684,68661,-6,'Schuyler, Nebraska 68661',22549,27435);
INSERT INTO "django_geo_db_zipcode" VALUES(30685,68662,-6,'Shelby, Nebraska 68662',22550,27436);
INSERT INTO "django_geo_db_zipcode" VALUES(30686,68663,-6,'Silver Creek, Nebraska 68663',22551,27437);
INSERT INTO "django_geo_db_zipcode" VALUES(30687,68664,-6,'Snyder, Nebraska 68664',22552,27438);
INSERT INTO "django_geo_db_zipcode" VALUES(30688,68665,-6,'Spalding, Nebraska 68665',22553,27439);
INSERT INTO "django_geo_db_zipcode" VALUES(30689,68666,-6,'Stromsburg, Nebraska 68666',22554,27440);
INSERT INTO "django_geo_db_zipcode" VALUES(30690,68667,-6,'Surprise, Nebraska 68667',22555,27441);
INSERT INTO "django_geo_db_zipcode" VALUES(30691,68669,-6,'Ulysses, Nebraska 68669',22556,27442);
INSERT INTO "django_geo_db_zipcode" VALUES(30692,68701,-6,'Norfolk, Nebraska 68701',22557,27443);
INSERT INTO "django_geo_db_zipcode" VALUES(30693,68702,-6,'Norfolk, Nebraska 68702',22557,27444);
INSERT INTO "django_geo_db_zipcode" VALUES(30694,68710,-6,'Allen, Nebraska 68710',22558,27445);
INSERT INTO "django_geo_db_zipcode" VALUES(30695,68711,-6,'Amelia, Nebraska 68711',22559,27446);
INSERT INTO "django_geo_db_zipcode" VALUES(30696,68713,-6,'Atkinson, Nebraska 68713',22560,27447);
INSERT INTO "django_geo_db_zipcode" VALUES(30697,68714,-6,'Bassett, Nebraska 68714',22561,27448);
INSERT INTO "django_geo_db_zipcode" VALUES(30698,68715,-6,'Battle Creek, Nebraska 68715',22562,27449);
INSERT INTO "django_geo_db_zipcode" VALUES(30699,68716,-6,'Beemer, Nebraska 68716',22563,27450);
INSERT INTO "django_geo_db_zipcode" VALUES(30700,68717,-6,'Belden, Nebraska 68717',22564,27451);
INSERT INTO "django_geo_db_zipcode" VALUES(30701,68718,-6,'Bloomfield, Nebraska 68718',22565,27452);
INSERT INTO "django_geo_db_zipcode" VALUES(30702,68719,-6,'Bristow, Nebraska 68719',22566,27453);
INSERT INTO "django_geo_db_zipcode" VALUES(30703,68720,-6,'Brunswick, Nebraska 68720',22567,27454);
INSERT INTO "django_geo_db_zipcode" VALUES(30704,68722,-6,'Butte, Nebraska 68722',22568,27455);
INSERT INTO "django_geo_db_zipcode" VALUES(30705,68723,-6,'Carroll, Nebraska 68723',22569,27456);
INSERT INTO "django_geo_db_zipcode" VALUES(30706,68724,-6,'Center, Nebraska 68724',22570,27457);
INSERT INTO "django_geo_db_zipcode" VALUES(30707,68725,-6,'Chambers, Nebraska 68725',22571,27458);
INSERT INTO "django_geo_db_zipcode" VALUES(30708,68726,-6,'Clearwater, Nebraska 68726',22572,27459);
INSERT INTO "django_geo_db_zipcode" VALUES(30709,68727,-6,'Coleridge, Nebraska 68727',22573,27460);
INSERT INTO "django_geo_db_zipcode" VALUES(30710,68728,-6,'Concord, Nebraska 68728',22574,27461);
INSERT INTO "django_geo_db_zipcode" VALUES(30711,68729,-6,'Creighton, Nebraska 68729',22575,27462);
INSERT INTO "django_geo_db_zipcode" VALUES(30712,68730,-6,'Crofton, Nebraska 68730',22576,27463);
INSERT INTO "django_geo_db_zipcode" VALUES(30713,68731,-6,'Dakota City, Nebraska 68731',22577,27464);
INSERT INTO "django_geo_db_zipcode" VALUES(30714,68732,-6,'Dixon, Nebraska 68732',22578,27465);
INSERT INTO "django_geo_db_zipcode" VALUES(30715,68733,-6,'Emerson, Nebraska 68733',22579,27466);
INSERT INTO "django_geo_db_zipcode" VALUES(30716,68734,-6,'Emmet, Nebraska 68734',22580,27467);
INSERT INTO "django_geo_db_zipcode" VALUES(30717,68735,-6,'Ewing, Nebraska 68735',22581,27468);
INSERT INTO "django_geo_db_zipcode" VALUES(30718,68736,-6,'Fordyce, Nebraska 68736',22582,27469);
INSERT INTO "django_geo_db_zipcode" VALUES(30719,68737,-6,'Foster, Nebraska 68737',22583,27470);
INSERT INTO "django_geo_db_zipcode" VALUES(30720,68738,-6,'Hadar, Nebraska 68738',22584,27471);
INSERT INTO "django_geo_db_zipcode" VALUES(30721,68739,-6,'Hartington, Nebraska 68739',22585,27472);
INSERT INTO "django_geo_db_zipcode" VALUES(30722,68740,-6,'Hoskins, Nebraska 68740',22586,27473);
INSERT INTO "django_geo_db_zipcode" VALUES(30723,68741,-6,'Hubbard, Nebraska 68741',22587,27474);
INSERT INTO "django_geo_db_zipcode" VALUES(30724,68742,-6,'Inman, Nebraska 68742',22588,27475);
INSERT INTO "django_geo_db_zipcode" VALUES(30725,68743,-6,'Jackson, Nebraska 68743',22589,27476);
INSERT INTO "django_geo_db_zipcode" VALUES(30726,68745,-6,'Laurel, Nebraska 68745',22590,27477);
INSERT INTO "django_geo_db_zipcode" VALUES(30727,68746,-6,'Lynch, Nebraska 68746',22591,27478);
INSERT INTO "django_geo_db_zipcode" VALUES(30728,68747,-6,'Mclean, Nebraska 68747',22592,27479);
INSERT INTO "django_geo_db_zipcode" VALUES(30729,68748,-6,'Madison, Nebraska 68748',22593,27480);
INSERT INTO "django_geo_db_zipcode" VALUES(30730,68749,-6,'Magnet, Nebraska 68749',22594,27481);
INSERT INTO "django_geo_db_zipcode" VALUES(30731,68751,-6,'Maskell, Nebraska 68751',22595,27482);
INSERT INTO "django_geo_db_zipcode" VALUES(30732,68752,-6,'Meadow Grove, Nebraska 68752',22596,27483);
INSERT INTO "django_geo_db_zipcode" VALUES(30733,68753,-6,'Mills, Nebraska 68753',22597,27484);
INSERT INTO "django_geo_db_zipcode" VALUES(30734,68755,-6,'Naper, Nebraska 68755',22598,27485);
INSERT INTO "django_geo_db_zipcode" VALUES(30735,68756,-6,'Neligh, Nebraska 68756',22599,27486);
INSERT INTO "django_geo_db_zipcode" VALUES(30736,68757,-6,'Newcastle, Nebraska 68757',22600,27487);
INSERT INTO "django_geo_db_zipcode" VALUES(30737,68758,-6,'Newman Grove, Nebraska 68758',22601,27488);
INSERT INTO "django_geo_db_zipcode" VALUES(30738,68759,-6,'Newport, Nebraska 68759',22602,27489);
INSERT INTO "django_geo_db_zipcode" VALUES(30739,68760,-6,'Niobrara, Nebraska 68760',22603,27490);
INSERT INTO "django_geo_db_zipcode" VALUES(30740,68761,-6,'Oakdale, Nebraska 68761',22604,27491);
INSERT INTO "django_geo_db_zipcode" VALUES(30741,68763,-6,'Oneill, Nebraska 68763',22605,27492);
INSERT INTO "django_geo_db_zipcode" VALUES(30742,68764,-6,'Orchard, Nebraska 68764',22606,27493);
INSERT INTO "django_geo_db_zipcode" VALUES(30743,68765,-6,'Osmond, Nebraska 68765',22607,27494);
INSERT INTO "django_geo_db_zipcode" VALUES(30744,68766,-6,'Page, Nebraska 68766',22608,27495);
INSERT INTO "django_geo_db_zipcode" VALUES(30745,68767,-6,'Pierce, Nebraska 68767',22609,27496);
INSERT INTO "django_geo_db_zipcode" VALUES(30746,68768,-6,'Pilger, Nebraska 68768',22610,27497);
INSERT INTO "django_geo_db_zipcode" VALUES(30747,68769,-6,'Plainview, Nebraska 68769',22611,27498);
INSERT INTO "django_geo_db_zipcode" VALUES(30748,68770,-6,'Ponca, Nebraska 68770',22612,27499);
INSERT INTO "django_geo_db_zipcode" VALUES(30749,68771,-6,'Randolph, Nebraska 68771',22613,27500);
INSERT INTO "django_geo_db_zipcode" VALUES(30750,68772,-6,'Rose, Nebraska 68772',22614,27501);
INSERT INTO "django_geo_db_zipcode" VALUES(30751,68773,-6,'Royal, Nebraska 68773',22615,27502);
INSERT INTO "django_geo_db_zipcode" VALUES(30752,68774,-6,'Saint Helena, Nebraska 68774',22616,27503);
INSERT INTO "django_geo_db_zipcode" VALUES(30753,68776,-6,'South Sioux City, Nebraska 68776',22617,27504);
INSERT INTO "django_geo_db_zipcode" VALUES(30754,68777,-6,'Spencer, Nebraska 68777',22618,27505);
INSERT INTO "django_geo_db_zipcode" VALUES(30755,68778,-6,'Springview, Nebraska 68778',22619,27506);
INSERT INTO "django_geo_db_zipcode" VALUES(30756,68779,-6,'Stanton, Nebraska 68779',22620,27507);
INSERT INTO "django_geo_db_zipcode" VALUES(30757,68780,-6,'Stuart, Nebraska 68780',22621,27508);
INSERT INTO "django_geo_db_zipcode" VALUES(30758,68781,-6,'Tilden, Nebraska 68781',22622,27509);
INSERT INTO "django_geo_db_zipcode" VALUES(30759,68782,-6,'Verdel, Nebraska 68782',22623,27510);
INSERT INTO "django_geo_db_zipcode" VALUES(30760,68783,-6,'Verdigre, Nebraska 68783',22624,27511);
INSERT INTO "django_geo_db_zipcode" VALUES(30761,68784,-6,'Wakefield, Nebraska 68784',22625,27512);
INSERT INTO "django_geo_db_zipcode" VALUES(30762,68785,-6,'Waterbury, Nebraska 68785',22626,27513);
INSERT INTO "django_geo_db_zipcode" VALUES(30763,68786,-6,'Wausa, Nebraska 68786',22627,27514);
INSERT INTO "django_geo_db_zipcode" VALUES(30764,68787,-6,'Wayne, Nebraska 68787',22628,27515);
INSERT INTO "django_geo_db_zipcode" VALUES(30765,68788,-6,'West Point, Nebraska 68788',22629,27516);
INSERT INTO "django_geo_db_zipcode" VALUES(30766,68789,-6,'Winnetoon, Nebraska 68789',22630,27517);
INSERT INTO "django_geo_db_zipcode" VALUES(30767,68790,-6,'Winside, Nebraska 68790',22631,27518);
INSERT INTO "django_geo_db_zipcode" VALUES(30768,68791,-6,'Wisner, Nebraska 68791',22632,27519);
INSERT INTO "django_geo_db_zipcode" VALUES(30769,68792,-6,'Wynot, Nebraska 68792',22633,27520);
INSERT INTO "django_geo_db_zipcode" VALUES(30770,68797,-6,'Sutton, Nebraska 68797',22634,27521);
INSERT INTO "django_geo_db_zipcode" VALUES(30771,68801,-6,'Grand Island, Nebraska 68801',22635,27522);
INSERT INTO "django_geo_db_zipcode" VALUES(30772,68802,-6,'Grand Island, Nebraska 68802',22635,27523);
INSERT INTO "django_geo_db_zipcode" VALUES(30773,68803,-6,'Grand Island, Nebraska 68803',22635,27524);
INSERT INTO "django_geo_db_zipcode" VALUES(30774,68810,-6,'Alda, Nebraska 68810',22636,27525);
INSERT INTO "django_geo_db_zipcode" VALUES(30775,68812,-6,'Amherst, Nebraska 68812',22637,27526);
INSERT INTO "django_geo_db_zipcode" VALUES(30776,68813,-6,'Anselmo, Nebraska 68813',22638,27527);
INSERT INTO "django_geo_db_zipcode" VALUES(30777,68814,-6,'Ansley, Nebraska 68814',22639,27528);
INSERT INTO "django_geo_db_zipcode" VALUES(30778,68815,-6,'Arcadia, Nebraska 68815',22640,27529);
INSERT INTO "django_geo_db_zipcode" VALUES(30779,68816,-6,'Archer, Nebraska 68816',22641,27530);
INSERT INTO "django_geo_db_zipcode" VALUES(30780,68817,-6,'Ashton, Nebraska 68817',22642,27531);
INSERT INTO "django_geo_db_zipcode" VALUES(30781,68818,-6,'Aurora, Nebraska 68818',22643,27532);
INSERT INTO "django_geo_db_zipcode" VALUES(30782,68819,-6,'Berwyn, Nebraska 68819',22644,27533);
INSERT INTO "django_geo_db_zipcode" VALUES(30783,68820,-6,'Boelus, Nebraska 68820',22645,27534);
INSERT INTO "django_geo_db_zipcode" VALUES(30784,68821,-6,'Brewster, Nebraska 68821',22646,27535);
INSERT INTO "django_geo_db_zipcode" VALUES(30785,68822,-6,'Broken Bow, Nebraska 68822',22647,27536);
INSERT INTO "django_geo_db_zipcode" VALUES(30786,68823,-6,'Burwell, Nebraska 68823',22648,27537);
INSERT INTO "django_geo_db_zipcode" VALUES(30787,68824,-6,'Cairo, Nebraska 68824',22649,27538);
INSERT INTO "django_geo_db_zipcode" VALUES(30788,68825,-6,'Callaway, Nebraska 68825',22650,27539);
INSERT INTO "django_geo_db_zipcode" VALUES(30789,68826,-6,'Central City, Nebraska 68826',22387,27540);
INSERT INTO "django_geo_db_zipcode" VALUES(30790,68827,-6,'Chapman, Nebraska 68827',22651,27541);
INSERT INTO "django_geo_db_zipcode" VALUES(30791,68828,-6,'Comstock, Nebraska 68828',22652,27542);
INSERT INTO "django_geo_db_zipcode" VALUES(30792,68831,-6,'Dannebrog, Nebraska 68831',22653,27543);
INSERT INTO "django_geo_db_zipcode" VALUES(30793,68832,-6,'Doniphan, Nebraska 68832',22654,27544);
INSERT INTO "django_geo_db_zipcode" VALUES(30794,68833,-6,'Dunning, Nebraska 68833',22655,27545);
INSERT INTO "django_geo_db_zipcode" VALUES(30795,68834,-6,'Eddyville, Nebraska 68834',22656,27546);
INSERT INTO "django_geo_db_zipcode" VALUES(30796,68835,-6,'Elba, Nebraska 68835',22657,27547);
INSERT INTO "django_geo_db_zipcode" VALUES(30797,68836,-6,'Elm Creek, Nebraska 68836',22658,27548);
INSERT INTO "django_geo_db_zipcode" VALUES(30798,68837,-6,'Elyria, Nebraska 68837',22659,27549);
INSERT INTO "django_geo_db_zipcode" VALUES(30799,68838,-6,'Farwell, Nebraska 68838',22660,27550);
INSERT INTO "django_geo_db_zipcode" VALUES(30800,68840,-6,'Gibbon, Nebraska 68840',22661,27551);
INSERT INTO "django_geo_db_zipcode" VALUES(30801,68841,-6,'Giltner, Nebraska 68841',22662,27552);
INSERT INTO "django_geo_db_zipcode" VALUES(30802,68842,-6,'Greeley, Nebraska 68842',22663,27553);
INSERT INTO "django_geo_db_zipcode" VALUES(30803,68843,-6,'Hampton, Nebraska 68843',22664,27554);
INSERT INTO "django_geo_db_zipcode" VALUES(30804,68844,-6,'Hazard, Nebraska 68844',22665,27555);
INSERT INTO "django_geo_db_zipcode" VALUES(30805,68845,-6,'Kearney, Nebraska 68845',22666,27556);
INSERT INTO "django_geo_db_zipcode" VALUES(30806,68846,-6,'Hordville, Nebraska 68846',22667,27557);
INSERT INTO "django_geo_db_zipcode" VALUES(30807,68847,-6,'Kearney, Nebraska 68847',22666,27558);
INSERT INTO "django_geo_db_zipcode" VALUES(30808,68848,-6,'Kearney, Nebraska 68848',22666,27559);
INSERT INTO "django_geo_db_zipcode" VALUES(30809,68849,-6,'Kearney, Nebraska 68849',22666,27560);
INSERT INTO "django_geo_db_zipcode" VALUES(30810,68850,-6,'Lexington, Nebraska 68850',22668,27561);
INSERT INTO "django_geo_db_zipcode" VALUES(30811,68852,-6,'Litchfield, Nebraska 68852',22669,27562);
INSERT INTO "django_geo_db_zipcode" VALUES(30812,68853,-6,'Loup City, Nebraska 68853',22670,27563);
INSERT INTO "django_geo_db_zipcode" VALUES(30813,68854,-6,'Marquette, Nebraska 68854',22671,27564);
INSERT INTO "django_geo_db_zipcode" VALUES(30814,68855,-6,'Mason City, Nebraska 68855',22672,27565);
INSERT INTO "django_geo_db_zipcode" VALUES(30815,68856,-6,'Merna, Nebraska 68856',22673,27566);
INSERT INTO "django_geo_db_zipcode" VALUES(30816,68858,-6,'Miller, Nebraska 68858',22674,27567);
INSERT INTO "django_geo_db_zipcode" VALUES(30817,68859,-6,'North Loup, Nebraska 68859',22675,27568);
INSERT INTO "django_geo_db_zipcode" VALUES(30818,68860,-6,'Oconto, Nebraska 68860',22676,27569);
INSERT INTO "django_geo_db_zipcode" VALUES(30819,68861,-6,'Odessa, Nebraska 68861',22677,27570);
INSERT INTO "django_geo_db_zipcode" VALUES(30820,68862,-6,'Ord, Nebraska 68862',22678,27571);
INSERT INTO "django_geo_db_zipcode" VALUES(30821,68863,-6,'Overton, Nebraska 68863',22679,27572);
INSERT INTO "django_geo_db_zipcode" VALUES(30822,68864,-6,'Palmer, Nebraska 68864',22680,27573);
INSERT INTO "django_geo_db_zipcode" VALUES(30823,68865,-6,'Phillips, Nebraska 68865',22681,27574);
INSERT INTO "django_geo_db_zipcode" VALUES(30824,68866,-6,'Pleasanton, Nebraska 68866',22682,27575);
INSERT INTO "django_geo_db_zipcode" VALUES(30825,68868,-6,'Martin, Nebraska 68868',22683,27576);
INSERT INTO "django_geo_db_zipcode" VALUES(30826,68869,-6,'Ravenna, Nebraska 68869',22684,27577);
INSERT INTO "django_geo_db_zipcode" VALUES(30827,68870,-6,'Riverdale, Nebraska 68870',22685,27578);
INSERT INTO "django_geo_db_zipcode" VALUES(30828,68871,-6,'Rockville, Nebraska 68871',22686,27579);
INSERT INTO "django_geo_db_zipcode" VALUES(30829,68872,-6,'Saint Libory, Nebraska 68872',22687,27580);
INSERT INTO "django_geo_db_zipcode" VALUES(30830,68873,-6,'Saint Paul, Nebraska 68873',22688,27581);
INSERT INTO "django_geo_db_zipcode" VALUES(30831,68874,-6,'Sargent, Nebraska 68874',22689,27582);
INSERT INTO "django_geo_db_zipcode" VALUES(30832,68875,-6,'Scotia, Nebraska 68875',22690,27583);
INSERT INTO "django_geo_db_zipcode" VALUES(30833,68876,-6,'Shelton, Nebraska 68876',22691,27584);
INSERT INTO "django_geo_db_zipcode" VALUES(30834,68878,-6,'Sumner, Nebraska 68878',22692,27585);
INSERT INTO "django_geo_db_zipcode" VALUES(30835,68879,-6,'Taylor, Nebraska 68879',22693,27586);
INSERT INTO "django_geo_db_zipcode" VALUES(30836,68880,-6,'Weissert, Nebraska 68880',22694,27587);
INSERT INTO "django_geo_db_zipcode" VALUES(30837,68881,-6,'Westerville, Nebraska 68881',22695,27588);
INSERT INTO "django_geo_db_zipcode" VALUES(30838,68882,-6,'Wolbach, Nebraska 68882',22696,27589);
INSERT INTO "django_geo_db_zipcode" VALUES(30839,68883,-6,'Wood River, Nebraska 68883',22697,27590);
INSERT INTO "django_geo_db_zipcode" VALUES(30840,68901,-6,'Hastings, Nebraska 68901',22698,27591);
INSERT INTO "django_geo_db_zipcode" VALUES(30841,68902,-6,'Hastings, Nebraska 68902',22698,27592);
INSERT INTO "django_geo_db_zipcode" VALUES(30842,68920,-6,'Alma, Nebraska 68920',22699,27593);
INSERT INTO "django_geo_db_zipcode" VALUES(30843,68922,-6,'Arapahoe, Nebraska 68922',22700,27594);
INSERT INTO "django_geo_db_zipcode" VALUES(30844,68923,-6,'Atlanta, Nebraska 68923',22701,27595);
INSERT INTO "django_geo_db_zipcode" VALUES(30845,68924,-6,'Axtell, Nebraska 68924',22702,27596);
INSERT INTO "django_geo_db_zipcode" VALUES(30846,68925,-6,'Ayr, Nebraska 68925',22703,27597);
INSERT INTO "django_geo_db_zipcode" VALUES(30847,68926,-6,'Beaver City, Nebraska 68926',22704,27598);
INSERT INTO "django_geo_db_zipcode" VALUES(30848,68927,-6,'Bertrand, Nebraska 68927',22705,27599);
INSERT INTO "django_geo_db_zipcode" VALUES(30849,68928,-6,'Bladen, Nebraska 68928',22706,27600);
INSERT INTO "django_geo_db_zipcode" VALUES(30850,68929,-6,'Bloomington, Nebraska 68929',22707,27601);
INSERT INTO "django_geo_db_zipcode" VALUES(30851,68930,-6,'Blue Hill, Nebraska 68930',22708,27602);
INSERT INTO "django_geo_db_zipcode" VALUES(30852,68932,-6,'Campbell, Nebraska 68932',22709,27603);
INSERT INTO "django_geo_db_zipcode" VALUES(30853,68933,-6,'Clay Center, Nebraska 68933',22710,27604);
INSERT INTO "django_geo_db_zipcode" VALUES(30854,68934,-6,'Deweese, Nebraska 68934',22711,27605);
INSERT INTO "django_geo_db_zipcode" VALUES(30855,68935,-6,'Edgar, Nebraska 68935',22712,27606);
INSERT INTO "django_geo_db_zipcode" VALUES(30856,68936,-6,'Edison, Nebraska 68936',22713,27607);
INSERT INTO "django_geo_db_zipcode" VALUES(30857,68937,-6,'Elwood, Nebraska 68937',22714,27608);
INSERT INTO "django_geo_db_zipcode" VALUES(30858,68938,-6,'Fairfield, Nebraska 68938',22715,27609);
INSERT INTO "django_geo_db_zipcode" VALUES(30859,68939,-6,'Franklin, Nebraska 68939',22716,27610);
INSERT INTO "django_geo_db_zipcode" VALUES(30860,68940,-6,'Funk, Nebraska 68940',22717,27611);
INSERT INTO "django_geo_db_zipcode" VALUES(30861,68941,-6,'Glenvil, Nebraska 68941',22718,27612);
INSERT INTO "django_geo_db_zipcode" VALUES(30862,68942,-6,'Guide Rock, Nebraska 68942',22719,27613);
INSERT INTO "django_geo_db_zipcode" VALUES(30863,68943,-6,'Hardy, Nebraska 68943',22720,27614);
INSERT INTO "django_geo_db_zipcode" VALUES(30864,68944,-6,'Harvard, Nebraska 68944',22721,27615);
INSERT INTO "django_geo_db_zipcode" VALUES(30865,68945,-6,'Heartwell, Nebraska 68945',22722,27616);
INSERT INTO "django_geo_db_zipcode" VALUES(30866,68946,-6,'Hendley, Nebraska 68946',22723,27617);
INSERT INTO "django_geo_db_zipcode" VALUES(30867,68947,-6,'Hildreth, Nebraska 68947',22724,27618);
INSERT INTO "django_geo_db_zipcode" VALUES(30868,68948,-6,'Holbrook, Nebraska 68948',22725,27619);
INSERT INTO "django_geo_db_zipcode" VALUES(30869,68949,-6,'Holdrege, Nebraska 68949',22726,27620);
INSERT INTO "django_geo_db_zipcode" VALUES(30870,68950,-6,'Holstein, Nebraska 68950',22727,27621);
INSERT INTO "django_geo_db_zipcode" VALUES(30871,68952,-6,'Inavale, Nebraska 68952',22728,27622);
INSERT INTO "django_geo_db_zipcode" VALUES(30872,68954,-6,'Inland, Nebraska 68954',22729,27623);
INSERT INTO "django_geo_db_zipcode" VALUES(30873,68955,-6,'Juniata, Nebraska 68955',22730,27624);
INSERT INTO "django_geo_db_zipcode" VALUES(30874,68956,-6,'Kenesaw, Nebraska 68956',22731,27625);
INSERT INTO "django_geo_db_zipcode" VALUES(30875,68957,-6,'Lawrence, Nebraska 68957',22732,27626);
INSERT INTO "django_geo_db_zipcode" VALUES(30876,68958,-6,'Loomis, Nebraska 68958',22733,27627);
INSERT INTO "django_geo_db_zipcode" VALUES(30877,68959,-6,'Minden, Nebraska 68959',22734,27628);
INSERT INTO "django_geo_db_zipcode" VALUES(30878,68960,-6,'Naponee, Nebraska 68960',22735,27629);
INSERT INTO "django_geo_db_zipcode" VALUES(30879,68961,-6,'Nelson, Nebraska 68961',22736,27630);
INSERT INTO "django_geo_db_zipcode" VALUES(30880,68963,-6,'Norman, Nebraska 68963',22737,27631);
INSERT INTO "django_geo_db_zipcode" VALUES(30881,68964,-6,'Oak, Nebraska 68964',22738,27632);
INSERT INTO "django_geo_db_zipcode" VALUES(30882,68966,-6,'Orleans, Nebraska 68966',22739,27633);
INSERT INTO "django_geo_db_zipcode" VALUES(30883,68967,-6,'Oxford, Nebraska 68967',22740,27634);
INSERT INTO "django_geo_db_zipcode" VALUES(30884,68969,-6,'Ragan, Nebraska 68969',22741,27635);
INSERT INTO "django_geo_db_zipcode" VALUES(30885,68970,-6,'Red Cloud, Nebraska 68970',22742,27636);
INSERT INTO "django_geo_db_zipcode" VALUES(30886,68971,-6,'Republican City, Nebraska 68971',22743,27637);
INSERT INTO "django_geo_db_zipcode" VALUES(30887,68972,-6,'Riverton, Nebraska 68972',22744,27638);
INSERT INTO "django_geo_db_zipcode" VALUES(30888,68973,-6,'Roseland, Nebraska 68973',22745,27639);
INSERT INTO "django_geo_db_zipcode" VALUES(30889,68974,-6,'Ruskin, Nebraska 68974',22746,27640);
INSERT INTO "django_geo_db_zipcode" VALUES(30890,68975,-6,'Saronville, Nebraska 68975',22747,27641);
INSERT INTO "django_geo_db_zipcode" VALUES(30891,68976,-6,'Smithfield, Nebraska 68976',22748,27642);
INSERT INTO "django_geo_db_zipcode" VALUES(30892,68977,-6,'Stamford, Nebraska 68977',22749,27643);
INSERT INTO "django_geo_db_zipcode" VALUES(30893,68978,-6,'Superior, Nebraska 68978',22750,27644);
INSERT INTO "django_geo_db_zipcode" VALUES(30894,68979,-6,'Sutton, Nebraska 68979',22634,27645);
INSERT INTO "django_geo_db_zipcode" VALUES(30895,68980,-6,'Trumbull, Nebraska 68980',22751,27646);
INSERT INTO "django_geo_db_zipcode" VALUES(30896,68981,-6,'Upland, Nebraska 68981',22752,27647);
INSERT INTO "django_geo_db_zipcode" VALUES(30897,68982,-6,'Wilcox, Nebraska 68982',22753,27648);
INSERT INTO "django_geo_db_zipcode" VALUES(30898,69001,-6,'McCook, Nebraska 69001',22754,27649);
INSERT INTO "django_geo_db_zipcode" VALUES(30899,69020,-6,'Bartley, Nebraska 69020',22755,27650);
INSERT INTO "django_geo_db_zipcode" VALUES(30900,69021,-7,'Benkelman, Nebraska 69021',22756,27651);
INSERT INTO "django_geo_db_zipcode" VALUES(30901,69022,-6,'Cambridge, Nebraska 69022',22757,27652);
INSERT INTO "django_geo_db_zipcode" VALUES(30902,69023,-7,'Champion, Nebraska 69023',22758,27653);
INSERT INTO "django_geo_db_zipcode" VALUES(30903,69024,-6,'Culbertson, Nebraska 69024',22759,27654);
INSERT INTO "django_geo_db_zipcode" VALUES(30904,69025,-6,'Curtis, Nebraska 69025',22760,27655);
INSERT INTO "django_geo_db_zipcode" VALUES(30905,69026,-6,'Danbury, Nebraska 69026',22761,27656);
INSERT INTO "django_geo_db_zipcode" VALUES(30906,69027,-7,'Enders, Nebraska 69027',22762,27657);
INSERT INTO "django_geo_db_zipcode" VALUES(30907,69028,-6,'Eustis, Nebraska 69028',22763,27658);
INSERT INTO "django_geo_db_zipcode" VALUES(30908,69029,-6,'Farnam, Nebraska 69029',22764,27659);
INSERT INTO "django_geo_db_zipcode" VALUES(30909,69030,-7,'Haigler, Nebraska 69030',22765,27660);
INSERT INTO "django_geo_db_zipcode" VALUES(30910,69031,-6,'Hamlet, Nebraska 69031',22766,27661);
INSERT INTO "django_geo_db_zipcode" VALUES(30911,69032,-6,'Hayes Center, Nebraska 69032',22767,27662);
INSERT INTO "django_geo_db_zipcode" VALUES(30912,69033,-7,'Imperial, Nebraska 69033',22768,27663);
INSERT INTO "django_geo_db_zipcode" VALUES(30913,69034,-6,'Indianola, Nebraska 69034',22769,27664);
INSERT INTO "django_geo_db_zipcode" VALUES(30914,69036,-6,'Lebanon, Nebraska 69036',22770,27665);
INSERT INTO "django_geo_db_zipcode" VALUES(30915,69037,-7,'Max, Nebraska 69037',22771,27666);
INSERT INTO "django_geo_db_zipcode" VALUES(30916,69038,-6,'Maywood, Nebraska 69038',22772,27667);
INSERT INTO "django_geo_db_zipcode" VALUES(30917,69039,-6,'Moorefield, Nebraska 69039',22773,27668);
INSERT INTO "django_geo_db_zipcode" VALUES(30918,69040,-6,'Palisade, Nebraska 69040',22774,27669);
INSERT INTO "django_geo_db_zipcode" VALUES(30919,69041,-7,'Parks, Nebraska 69041',22775,27670);
INSERT INTO "django_geo_db_zipcode" VALUES(30920,69042,-6,'Stockville, Nebraska 69042',22776,27671);
INSERT INTO "django_geo_db_zipcode" VALUES(30921,69043,-6,'Stratton, Nebraska 69043',22777,27672);
INSERT INTO "django_geo_db_zipcode" VALUES(30922,69044,-6,'Trenton, Nebraska 69044',22778,27673);
INSERT INTO "django_geo_db_zipcode" VALUES(30923,69045,-7,'Wauneta, Nebraska 69045',22779,27674);
INSERT INTO "django_geo_db_zipcode" VALUES(30924,69046,-6,'Wilsonville, Nebraska 69046',22780,27675);
INSERT INTO "django_geo_db_zipcode" VALUES(30925,69101,-6,'North Platte, Nebraska 69101',22781,27676);
INSERT INTO "django_geo_db_zipcode" VALUES(30926,69103,-6,'North Platte, Nebraska 69103',22781,27677);
INSERT INTO "django_geo_db_zipcode" VALUES(30927,69120,-6,'Arnold, Nebraska 69120',22782,27678);
INSERT INTO "django_geo_db_zipcode" VALUES(30928,69121,-7,'Arthur, Nebraska 69121',22783,27679);
INSERT INTO "django_geo_db_zipcode" VALUES(30929,69122,-7,'Big Springs, Nebraska 69122',22784,27680);
INSERT INTO "django_geo_db_zipcode" VALUES(30930,69123,-6,'Brady, Nebraska 69123',22785,27681);
INSERT INTO "django_geo_db_zipcode" VALUES(30931,69125,-7,'Broadwater, Nebraska 69125',22786,27682);
INSERT INTO "django_geo_db_zipcode" VALUES(30932,69127,-7,'Brule, Nebraska 69127',22787,27683);
INSERT INTO "django_geo_db_zipcode" VALUES(30933,69128,-7,'Bushnell, Nebraska 69128',22788,27684);
INSERT INTO "django_geo_db_zipcode" VALUES(30934,69129,-7,'Chappell, Nebraska 69129',22789,27685);
INSERT INTO "django_geo_db_zipcode" VALUES(30935,69130,-6,'Cozad, Nebraska 69130',22790,27686);
INSERT INTO "django_geo_db_zipcode" VALUES(30936,69131,-7,'Dalton, Nebraska 69131',22791,27687);
INSERT INTO "django_geo_db_zipcode" VALUES(30937,69132,-6,'Dickens, Nebraska 69132',22792,27688);
INSERT INTO "django_geo_db_zipcode" VALUES(30938,69133,-7,'Dix, Nebraska 69133',22793,27689);
INSERT INTO "django_geo_db_zipcode" VALUES(30939,69134,-7,'Elsie, Nebraska 69134',22794,27690);
INSERT INTO "django_geo_db_zipcode" VALUES(30940,69135,-6,'Elsmere, Nebraska 69135',22795,27691);
INSERT INTO "django_geo_db_zipcode" VALUES(30941,69138,-6,'Gothenburg, Nebraska 69138',22796,27692);
INSERT INTO "django_geo_db_zipcode" VALUES(30942,69140,-7,'Grant, Nebraska 69140',22797,27693);
INSERT INTO "django_geo_db_zipcode" VALUES(30943,69141,-7,'Gurley, Nebraska 69141',22798,27694);
INSERT INTO "django_geo_db_zipcode" VALUES(30944,69142,-6,'Halsey, Nebraska 69142',22799,27695);
INSERT INTO "django_geo_db_zipcode" VALUES(30945,69143,-6,'Hershey, Nebraska 69143',22800,27696);
INSERT INTO "django_geo_db_zipcode" VALUES(30946,69144,-7,'Keystone, Nebraska 69144',22801,27697);
INSERT INTO "django_geo_db_zipcode" VALUES(30947,69145,-7,'Kimball, Nebraska 69145',22802,27698);
INSERT INTO "django_geo_db_zipcode" VALUES(30948,69146,-7,'Lemoyne, Nebraska 69146',22803,27699);
INSERT INTO "django_geo_db_zipcode" VALUES(30949,69147,-7,'Lewellen, Nebraska 69147',22804,27700);
INSERT INTO "django_geo_db_zipcode" VALUES(30950,69148,-7,'Lisco, Nebraska 69148',22805,27701);
INSERT INTO "django_geo_db_zipcode" VALUES(30951,69149,-7,'Lodgepole, Nebraska 69149',22806,27702);
INSERT INTO "django_geo_db_zipcode" VALUES(30952,69150,-7,'Madrid, Nebraska 69150',22807,27703);
INSERT INTO "django_geo_db_zipcode" VALUES(30953,69151,-6,'Maxwell, Nebraska 69151',22808,27704);
INSERT INTO "django_geo_db_zipcode" VALUES(30954,69152,-7,'Mullen, Nebraska 69152',22809,27705);
INSERT INTO "django_geo_db_zipcode" VALUES(30955,69153,-7,'Ogallala, Nebraska 69153',22810,27706);
INSERT INTO "django_geo_db_zipcode" VALUES(30956,69154,-7,'Oshkosh, Nebraska 69154',22811,27707);
INSERT INTO "django_geo_db_zipcode" VALUES(30957,69155,-7,'Paxton, Nebraska 69155',22812,27708);
INSERT INTO "django_geo_db_zipcode" VALUES(30958,69156,-7,'Potter, Nebraska 69156',22813,27709);
INSERT INTO "django_geo_db_zipcode" VALUES(30959,69157,-6,'Purdum, Nebraska 69157',22814,27710);
INSERT INTO "django_geo_db_zipcode" VALUES(30960,69160,-7,'Sidney, Nebraska 69160',22815,27711);
INSERT INTO "django_geo_db_zipcode" VALUES(30961,69161,-6,'Seneca, Nebraska 69161',22816,27712);
INSERT INTO "django_geo_db_zipcode" VALUES(30962,69162,-7,'Sidney, Nebraska 69162',22815,27713);
INSERT INTO "django_geo_db_zipcode" VALUES(30963,69163,-6,'Stapleton, Nebraska 69163',22817,27714);
INSERT INTO "django_geo_db_zipcode" VALUES(30964,69165,-6,'Sutherland, Nebraska 69165',22818,27715);
INSERT INTO "django_geo_db_zipcode" VALUES(30965,69166,-6,'Thedford, Nebraska 69166',22819,27716);
INSERT INTO "django_geo_db_zipcode" VALUES(30966,69167,-6,'Tryon, Nebraska 69167',22820,27717);
INSERT INTO "django_geo_db_zipcode" VALUES(30967,69168,-7,'Venango, Nebraska 69168',22821,27718);
INSERT INTO "django_geo_db_zipcode" VALUES(30968,69169,-6,'Wallace, Nebraska 69169',22822,27719);
INSERT INTO "django_geo_db_zipcode" VALUES(30969,69170,-6,'Wellfleet, Nebraska 69170',22823,27720);
INSERT INTO "django_geo_db_zipcode" VALUES(30970,69171,-6,'Willow Island, Nebraska 69171',22824,27721);
INSERT INTO "django_geo_db_zipcode" VALUES(30971,69190,-7,'Oshkosh, Nebraska 69190',22811,27722);
INSERT INTO "django_geo_db_zipcode" VALUES(30972,69201,-6,'Valentine, Nebraska 69201',22825,27723);
INSERT INTO "django_geo_db_zipcode" VALUES(30973,69210,-6,'Ainsworth, Nebraska 69210',22826,27724);
INSERT INTO "django_geo_db_zipcode" VALUES(30974,69211,-7,'Cody, Nebraska 69211',22827,27725);
INSERT INTO "django_geo_db_zipcode" VALUES(30975,69212,-6,'Crookston, Nebraska 69212',22828,27726);
INSERT INTO "django_geo_db_zipcode" VALUES(30976,69214,-6,'Johnstown, Nebraska 69214',22829,27727);
INSERT INTO "django_geo_db_zipcode" VALUES(30977,69216,-7,'Kilgore, Nebraska 69216',22830,27728);
INSERT INTO "django_geo_db_zipcode" VALUES(30978,69217,-6,'Long Pine, Nebraska 69217',22831,27729);
INSERT INTO "django_geo_db_zipcode" VALUES(30979,69218,-7,'Merriman, Nebraska 69218',22832,27730);
INSERT INTO "django_geo_db_zipcode" VALUES(30980,69219,-7,'Nenzel, Nebraska 69219',22833,27731);
INSERT INTO "django_geo_db_zipcode" VALUES(30981,69220,-6,'Sparks, Nebraska 69220',22834,27732);
INSERT INTO "django_geo_db_zipcode" VALUES(30982,69221,-6,'Wood Lake, Nebraska 69221',22835,27733);
INSERT INTO "django_geo_db_zipcode" VALUES(30983,69301,-7,'Alliance, Nebraska 69301',22836,27734);
INSERT INTO "django_geo_db_zipcode" VALUES(30984,69331,-7,'Angora, Nebraska 69331',22837,27735);
INSERT INTO "django_geo_db_zipcode" VALUES(30985,69333,-7,'Ashby, Nebraska 69333',22838,27736);
INSERT INTO "django_geo_db_zipcode" VALUES(30986,69334,-7,'Bayard, Nebraska 69334',22839,27737);
INSERT INTO "django_geo_db_zipcode" VALUES(30987,69335,-7,'Bingham, Nebraska 69335',22840,27738);
INSERT INTO "django_geo_db_zipcode" VALUES(30988,69336,-7,'Bridgeport, Nebraska 69336',22841,27739);
INSERT INTO "django_geo_db_zipcode" VALUES(30989,69337,-7,'Chadron, Nebraska 69337',22842,27740);
INSERT INTO "django_geo_db_zipcode" VALUES(30990,69339,-7,'Crawford, Nebraska 69339',22843,27741);
INSERT INTO "django_geo_db_zipcode" VALUES(30991,69340,-7,'Ellsworth, Nebraska 69340',22844,27742);
INSERT INTO "django_geo_db_zipcode" VALUES(30992,69341,-7,'Gering, Nebraska 69341',22845,27743);
INSERT INTO "django_geo_db_zipcode" VALUES(30993,69343,-7,'Gordon, Nebraska 69343',22846,27744);
INSERT INTO "django_geo_db_zipcode" VALUES(30994,69345,-7,'Harrisburg, Nebraska 69345',22847,27745);
INSERT INTO "django_geo_db_zipcode" VALUES(30995,69346,-7,'Harrison, Nebraska 69346',22848,27746);
INSERT INTO "django_geo_db_zipcode" VALUES(30996,69347,-7,'Hay Springs, Nebraska 69347',22849,27747);
INSERT INTO "django_geo_db_zipcode" VALUES(30997,69348,-7,'Hemingford, Nebraska 69348',22850,27748);
INSERT INTO "django_geo_db_zipcode" VALUES(30998,69349,-7,'Henry, Nebraska 69349',22851,27749);
INSERT INTO "django_geo_db_zipcode" VALUES(30999,69350,-7,'Hyannis, Nebraska 69350',22852,27750);
INSERT INTO "django_geo_db_zipcode" VALUES(31000,69351,-7,'Lakeside, Nebraska 69351',22853,27751);
INSERT INTO "django_geo_db_zipcode" VALUES(31001,69352,-7,'Lyman, Nebraska 69352',22854,27752);
INSERT INTO "django_geo_db_zipcode" VALUES(31002,69353,-7,'Mcgrew, Nebraska 69353',22855,27753);
INSERT INTO "django_geo_db_zipcode" VALUES(31003,69354,-7,'Marsland, Nebraska 69354',22856,27754);
INSERT INTO "django_geo_db_zipcode" VALUES(31004,69355,-7,'Melbeta, Nebraska 69355',22857,27755);
INSERT INTO "django_geo_db_zipcode" VALUES(31005,69356,-7,'Minatare, Nebraska 69356',22858,27756);
INSERT INTO "django_geo_db_zipcode" VALUES(31006,69357,-7,'Mitchell, Nebraska 69357',22859,27757);
INSERT INTO "django_geo_db_zipcode" VALUES(31007,69358,-7,'Morrill, Nebraska 69358',22860,27758);
INSERT INTO "django_geo_db_zipcode" VALUES(31008,69360,-7,'Rushville, Nebraska 69360',22861,27759);
INSERT INTO "django_geo_db_zipcode" VALUES(31009,69361,-7,'Scottsbluff, Nebraska 69361',22862,27760);
INSERT INTO "django_geo_db_zipcode" VALUES(31010,69363,-7,'Scottsbluff, Nebraska 69363',22862,27761);
INSERT INTO "django_geo_db_zipcode" VALUES(31011,69365,-7,'Whiteclay, Nebraska 69365',22863,27762);
INSERT INTO "django_geo_db_zipcode" VALUES(31012,69366,-7,'Whitman, Nebraska 69366',22864,27763);
INSERT INTO "django_geo_db_zipcode" VALUES(31013,69367,-7,'Whitney, Nebraska 69367',22865,27764);
INSERT INTO "django_geo_db_zipcode" VALUES(31014,70000,-6,'Laplace, Louisiana 70000',22866,27765);
INSERT INTO "django_geo_db_zipcode" VALUES(31015,70001,-6,'Metairie, Louisiana 70001',22867,27766);
INSERT INTO "django_geo_db_zipcode" VALUES(31016,70002,-6,'Metairie, Louisiana 70002',22867,27767);
INSERT INTO "django_geo_db_zipcode" VALUES(31017,70003,-6,'Metairie, Louisiana 70003',22867,27768);
INSERT INTO "django_geo_db_zipcode" VALUES(31018,70004,-6,'Metairie, Louisiana 70004',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31019,70005,-6,'Metairie, Louisiana 70005',22867,27770);
INSERT INTO "django_geo_db_zipcode" VALUES(31020,70006,-6,'Metairie, Louisiana 70006',22867,27771);
INSERT INTO "django_geo_db_zipcode" VALUES(31021,70009,-6,'Metairie, Louisiana 70009',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31022,70010,-6,'Metairie, Louisiana 70010',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31023,70011,-6,'Metairie, Louisiana 70011',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31024,70021,-6,'Jefferson, Louisiana 70021',22868,27772);
INSERT INTO "django_geo_db_zipcode" VALUES(31025,70030,-6,'Des Allemands, Louisiana 70030',22869,27773);
INSERT INTO "django_geo_db_zipcode" VALUES(31026,70031,-6,'Ama, Louisiana 70031',22870,27774);
INSERT INTO "django_geo_db_zipcode" VALUES(31027,70032,-6,'Arabi, Louisiana 70032',22871,27775);
INSERT INTO "django_geo_db_zipcode" VALUES(31028,70033,-6,'Metairie, Louisiana 70033',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31029,70036,-6,'Barataria, Louisiana 70036',22872,27776);
INSERT INTO "django_geo_db_zipcode" VALUES(31030,70037,-6,'Belle Chasse, Louisiana 70037',22873,27777);
INSERT INTO "django_geo_db_zipcode" VALUES(31031,70038,-6,'Boothville, Louisiana 70038',22874,27778);
INSERT INTO "django_geo_db_zipcode" VALUES(31032,70039,-6,'Boutte, Louisiana 70039',22875,27779);
INSERT INTO "django_geo_db_zipcode" VALUES(31033,70040,-6,'Braithwaite, Louisiana 70040',22876,27780);
INSERT INTO "django_geo_db_zipcode" VALUES(31034,70041,-6,'Buras, Louisiana 70041',22877,27781);
INSERT INTO "django_geo_db_zipcode" VALUES(31035,70042,-6,'Carlisle, Louisiana 70042',22878,27782);
INSERT INTO "django_geo_db_zipcode" VALUES(31036,70043,-6,'Chalmette, Louisiana 70043',22879,27783);
INSERT INTO "django_geo_db_zipcode" VALUES(31037,70044,-6,'Chalmette, Louisiana 70044',22879,27784);
INSERT INTO "django_geo_db_zipcode" VALUES(31038,70046,-6,'Davant, Louisiana 70046',22880,27785);
INSERT INTO "django_geo_db_zipcode" VALUES(31039,70047,-6,'Destrehan, Louisiana 70047',22881,27786);
INSERT INTO "django_geo_db_zipcode" VALUES(31040,70048,-6,'Reserve, Louisiana 70048',22882,27787);
INSERT INTO "django_geo_db_zipcode" VALUES(31041,70049,-6,'Edgard, Louisiana 70049',22883,27788);
INSERT INTO "django_geo_db_zipcode" VALUES(31042,70050,-6,'Empire, Louisiana 70050',22884,27789);
INSERT INTO "django_geo_db_zipcode" VALUES(31043,70051,-6,'Garyville, Louisiana 70051',22885,27790);
INSERT INTO "django_geo_db_zipcode" VALUES(31044,70052,-6,'Gramercy, Louisiana 70052',22886,27791);
INSERT INTO "django_geo_db_zipcode" VALUES(31045,70053,-6,'Gretna, Louisiana 70053',22887,27792);
INSERT INTO "django_geo_db_zipcode" VALUES(31046,70054,-6,'Gretna, Louisiana 70054',22887,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31047,70055,-6,'Metairie, Louisiana 70055',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31048,70056,-6,'Gretna, Louisiana 70056',22887,27793);
INSERT INTO "django_geo_db_zipcode" VALUES(31049,70057,-6,'Hahnville, Louisiana 70057',22888,27794);
INSERT INTO "django_geo_db_zipcode" VALUES(31050,70058,-6,'Harvey, Louisiana 70058',22889,27795);
INSERT INTO "django_geo_db_zipcode" VALUES(31051,70059,-6,'Harvey, Louisiana 70059',22889,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31052,70060,-6,'Metairie, Louisiana 70060',22867,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31053,70062,-6,'Kenner, Louisiana 70062',22890,27796);
INSERT INTO "django_geo_db_zipcode" VALUES(31054,70063,-6,'Kenner, Louisiana 70063',22890,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31055,70064,-6,'Kenner, Louisiana 70064',22890,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31056,70065,-6,'Kenner, Louisiana 70065',22890,27797);
INSERT INTO "django_geo_db_zipcode" VALUES(31057,70066,-6,'Killona, Louisiana 70066',22891,27798);
INSERT INTO "django_geo_db_zipcode" VALUES(31058,70067,-6,'Lafitte, Louisiana 70067',22892,27799);
INSERT INTO "django_geo_db_zipcode" VALUES(31059,70068,-6,'La Place, Louisiana 70068',22893,27800);
INSERT INTO "django_geo_db_zipcode" VALUES(31060,70069,-6,'La Place, Louisiana 70069',22893,27801);
INSERT INTO "django_geo_db_zipcode" VALUES(31061,70070,-6,'Luling, Louisiana 70070',22894,27802);
INSERT INTO "django_geo_db_zipcode" VALUES(31062,70071,-6,'Lutcher, Louisiana 70071',22895,27803);
INSERT INTO "django_geo_db_zipcode" VALUES(31063,70072,-6,'Marrero, Louisiana 70072',22896,27804);
INSERT INTO "django_geo_db_zipcode" VALUES(31064,70073,-6,'Marrero, Louisiana 70073',22896,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31065,70075,-6,'Meraux, Louisiana 70075',22897,27805);
INSERT INTO "django_geo_db_zipcode" VALUES(31066,70076,-6,'Mount Airy, Louisiana 70076',22898,27806);
INSERT INTO "django_geo_db_zipcode" VALUES(31067,70078,-6,'New Sarpy, Louisiana 70078',22899,27807);
INSERT INTO "django_geo_db_zipcode" VALUES(31068,70079,-6,'Norco, Louisiana 70079',22900,27808);
INSERT INTO "django_geo_db_zipcode" VALUES(31069,70080,-6,'Paradis, Louisiana 70080',22901,27809);
INSERT INTO "django_geo_db_zipcode" VALUES(31070,70081,-6,'Pilottown, Louisiana 70081',22902,27810);
INSERT INTO "django_geo_db_zipcode" VALUES(31071,70082,-6,'Pointe A La Hache, Louisiana 70082',22903,27811);
INSERT INTO "django_geo_db_zipcode" VALUES(31072,70083,-6,'Port Sulphur, Louisiana 70083',22904,27812);
INSERT INTO "django_geo_db_zipcode" VALUES(31073,70084,-6,'Reserve, Louisiana 70084',22882,27813);
INSERT INTO "django_geo_db_zipcode" VALUES(31074,70085,-6,'Saint Bernard, Louisiana 70085',22905,27814);
INSERT INTO "django_geo_db_zipcode" VALUES(31075,70086,-6,'Saint James, Louisiana 70086',22906,27815);
INSERT INTO "django_geo_db_zipcode" VALUES(31076,70087,-6,'Saint Rose, Louisiana 70087',22907,27816);
INSERT INTO "django_geo_db_zipcode" VALUES(31077,70090,-6,'Vacherie, Louisiana 70090',22908,27817);
INSERT INTO "django_geo_db_zipcode" VALUES(31078,70091,-6,'Venice, Louisiana 70091',22909,27818);
INSERT INTO "django_geo_db_zipcode" VALUES(31079,70092,-6,'Violet, Louisiana 70092',22910,27819);
INSERT INTO "django_geo_db_zipcode" VALUES(31080,70093,-6,'Violet, Louisiana 70093',22910,27820);
INSERT INTO "django_geo_db_zipcode" VALUES(31081,70094,-6,'Westwego, Louisiana 70094',22911,27821);
INSERT INTO "django_geo_db_zipcode" VALUES(31082,70096,-6,'Westwego, Louisiana 70096',22911,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31083,70112,-6,'New Orleans, Louisiana 70112',22912,27822);
INSERT INTO "django_geo_db_zipcode" VALUES(31084,70113,-6,'New Orleans, Louisiana 70113',22912,27823);
INSERT INTO "django_geo_db_zipcode" VALUES(31085,70114,-6,'New Orleans, Louisiana 70114',22912,27824);
INSERT INTO "django_geo_db_zipcode" VALUES(31086,70115,-6,'New Orleans, Louisiana 70115',22912,27825);
INSERT INTO "django_geo_db_zipcode" VALUES(31087,70116,-6,'New Orleans, Louisiana 70116',22912,27826);
INSERT INTO "django_geo_db_zipcode" VALUES(31088,70117,-6,'New Orleans, Louisiana 70117',22912,27827);
INSERT INTO "django_geo_db_zipcode" VALUES(31089,70118,-6,'New Orleans, Louisiana 70118',22912,27828);
INSERT INTO "django_geo_db_zipcode" VALUES(31090,70119,-6,'New Orleans, Louisiana 70119',22912,27829);
INSERT INTO "django_geo_db_zipcode" VALUES(31091,70121,-6,'New Orleans, Louisiana 70121',22912,27830);
INSERT INTO "django_geo_db_zipcode" VALUES(31092,70122,-6,'New Orleans, Louisiana 70122',22912,27831);
INSERT INTO "django_geo_db_zipcode" VALUES(31093,70123,-6,'New Orleans, Louisiana 70123',22912,27832);
INSERT INTO "django_geo_db_zipcode" VALUES(31094,70124,-6,'New Orleans, Louisiana 70124',22912,27833);
INSERT INTO "django_geo_db_zipcode" VALUES(31095,70125,-6,'New Orleans, Louisiana 70125',22912,27834);
INSERT INTO "django_geo_db_zipcode" VALUES(31096,70126,-6,'New Orleans, Louisiana 70126',22912,27835);
INSERT INTO "django_geo_db_zipcode" VALUES(31097,70127,-6,'New Orleans, Louisiana 70127',22912,27836);
INSERT INTO "django_geo_db_zipcode" VALUES(31098,70128,-6,'New Orleans, Louisiana 70128',22912,27837);
INSERT INTO "django_geo_db_zipcode" VALUES(31099,70129,-6,'New Orleans, Louisiana 70129',22912,27838);
INSERT INTO "django_geo_db_zipcode" VALUES(31100,70130,-6,'New Orleans, Louisiana 70130',22912,27839);
INSERT INTO "django_geo_db_zipcode" VALUES(31101,70131,-6,'New Orleans, Louisiana 70131',22912,27840);
INSERT INTO "django_geo_db_zipcode" VALUES(31102,70139,-6,'New Orleans, Louisiana 70139',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31103,70140,-6,'New Orleans, Louisiana 70140',22912,27842);
INSERT INTO "django_geo_db_zipcode" VALUES(31104,70141,-6,'New Orleans, Louisiana 70141',22912,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31105,70142,-6,'New Orleans, Louisiana 70142',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31106,70143,-6,'New Orleans, Louisiana 70143',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31107,70144,-6,'New Orleans, Louisiana 70144',22912,27843);
INSERT INTO "django_geo_db_zipcode" VALUES(31108,70145,-6,'New Orleans, Louisiana 70145',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31109,70146,-6,'New Orleans, Louisiana 70146',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31110,70148,-6,'New Orleans, Louisiana 70148',22912,27844);
INSERT INTO "django_geo_db_zipcode" VALUES(31111,70149,-6,'New Orleans, Louisiana 70149',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31112,70150,-6,'New Orleans, Louisiana 70150',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31113,70151,-6,'New Orleans, Louisiana 70151',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31114,70152,-6,'New Orleans, Louisiana 70152',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31115,70153,-6,'New Orleans, Louisiana 70153',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31116,70154,-6,'New Orleans, Louisiana 70154',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31117,70155,-6,'New Orleans, Louisiana 70155',22912,27845);
INSERT INTO "django_geo_db_zipcode" VALUES(31118,70156,-6,'New Orleans, Louisiana 70156',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31119,70157,-6,'New Orleans, Louisiana 70157',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31120,70158,-6,'New Orleans, Louisiana 70158',22912,27846);
INSERT INTO "django_geo_db_zipcode" VALUES(31121,70159,-6,'New Orleans, Louisiana 70159',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31122,70160,-6,'New Orleans, Louisiana 70160',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31123,70161,-6,'New Orleans, Louisiana 70161',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31124,70162,-6,'New Orleans, Louisiana 70162',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31125,70163,-6,'New Orleans, Louisiana 70163',22912,27847);
INSERT INTO "django_geo_db_zipcode" VALUES(31126,70164,-6,'New Orleans, Louisiana 70164',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31127,70165,-6,'New Orleans, Louisiana 70165',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31128,70166,-6,'New Orleans, Louisiana 70166',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31129,70167,-6,'New Orleans, Louisiana 70167',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31130,70170,-6,'New Orleans, Louisiana 70170',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31131,70172,-6,'New Orleans, Louisiana 70172',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31132,70174,-6,'New Orleans, Louisiana 70174',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31133,70175,-6,'New Orleans, Louisiana 70175',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31134,70176,-6,'New Orleans, Louisiana 70176',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31135,70177,-6,'New Orleans, Louisiana 70177',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31136,70178,-6,'New Orleans, Louisiana 70178',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31137,70179,-6,'New Orleans, Louisiana 70179',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31138,70181,-6,'New Orleans, Louisiana 70181',22912,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31139,70182,-6,'New Orleans, Louisiana 70182',22912,27848);
INSERT INTO "django_geo_db_zipcode" VALUES(31140,70183,-6,'New Orleans, Louisiana 70183',22912,27769);
INSERT INTO "django_geo_db_zipcode" VALUES(31141,70184,-6,'New Orleans, Louisiana 70184',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31142,70185,-6,'New Orleans, Louisiana 70185',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31143,70186,-6,'New Orleans, Louisiana 70186',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31144,70187,-6,'New Orleans, Louisiana 70187',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31145,70189,-6,'New Orleans, Louisiana 70189',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31146,70190,-6,'New Orleans, Louisiana 70190',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31147,70195,-6,'New Orleans, Louisiana 70195',22912,27841);
INSERT INTO "django_geo_db_zipcode" VALUES(31148,70199,-6,'New Orleans, Louisiana 70199',22912,27849);
INSERT INTO "django_geo_db_zipcode" VALUES(31149,70301,-6,'Thibodaux, Louisiana 70301',22913,27850);
INSERT INTO "django_geo_db_zipcode" VALUES(31150,70302,-6,'Thibodaux, Louisiana 70302',22913,27851);
INSERT INTO "django_geo_db_zipcode" VALUES(31151,70310,-6,'Thibodaux, Louisiana 70310',22913,27852);
INSERT INTO "django_geo_db_zipcode" VALUES(31152,70339,-6,'Pierre Part, Louisiana 70339',22914,27853);
INSERT INTO "django_geo_db_zipcode" VALUES(31153,70340,-6,'Amelia, Louisiana 70340',22915,27854);
INSERT INTO "django_geo_db_zipcode" VALUES(31154,70341,-6,'Belle Rose, Louisiana 70341',22916,27855);
INSERT INTO "django_geo_db_zipcode" VALUES(31155,70342,-6,'Berwick, Louisiana 70342',22917,27856);
INSERT INTO "django_geo_db_zipcode" VALUES(31156,70343,-6,'Bourg, Louisiana 70343',22918,27857);
INSERT INTO "django_geo_db_zipcode" VALUES(31157,70344,-6,'Chauvin, Louisiana 70344',22919,27858);
INSERT INTO "django_geo_db_zipcode" VALUES(31158,70345,-6,'Cut Off, Louisiana 70345',22920,27859);
INSERT INTO "django_geo_db_zipcode" VALUES(31159,70346,-6,'Donaldsonville, Louisiana 70346',22921,27860);
INSERT INTO "django_geo_db_zipcode" VALUES(31160,70352,-6,'Donner, Louisiana 70352',22922,27861);
INSERT INTO "django_geo_db_zipcode" VALUES(31161,70353,-6,'Dulac, Louisiana 70353',22923,27862);
INSERT INTO "django_geo_db_zipcode" VALUES(31162,70354,-6,'Galliano, Louisiana 70354',22924,27863);
INSERT INTO "django_geo_db_zipcode" VALUES(31163,70355,-6,'Gheens, Louisiana 70355',22925,27864);
INSERT INTO "django_geo_db_zipcode" VALUES(31164,70356,-6,'Gibson, Louisiana 70356',22926,27865);
INSERT INTO "django_geo_db_zipcode" VALUES(31165,70357,-6,'Golden Meadow, Louisiana 70357',22927,27866);
INSERT INTO "django_geo_db_zipcode" VALUES(31166,70358,-6,'Grand Isle, Louisiana 70358',22928,27867);
INSERT INTO "django_geo_db_zipcode" VALUES(31167,70359,-6,'Gray, Louisiana 70359',22929,27868);
INSERT INTO "django_geo_db_zipcode" VALUES(31168,70360,-6,'Houma, Louisiana 70360',22930,27869);
INSERT INTO "django_geo_db_zipcode" VALUES(31169,70361,-6,'Houma, Louisiana 70361',22930,27870);
INSERT INTO "django_geo_db_zipcode" VALUES(31170,70363,-6,'Houma, Louisiana 70363',22930,27871);
INSERT INTO "django_geo_db_zipcode" VALUES(31171,70364,-6,'Houma, Louisiana 70364',22930,27872);
INSERT INTO "django_geo_db_zipcode" VALUES(31172,70369,-6,'Houma, Louisiana 70369',22930,27873);
INSERT INTO "django_geo_db_zipcode" VALUES(31173,70371,-6,'Kraemer, Louisiana 70371',22931,27874);
INSERT INTO "django_geo_db_zipcode" VALUES(31174,70372,-6,'Labadieville, Louisiana 70372',22932,27875);
INSERT INTO "django_geo_db_zipcode" VALUES(31175,70373,-6,'Larose, Louisiana 70373',22933,27876);
INSERT INTO "django_geo_db_zipcode" VALUES(31176,70374,-6,'Lockport, Louisiana 70374',22934,27877);
INSERT INTO "django_geo_db_zipcode" VALUES(31177,70375,-6,'Mathews, Louisiana 70375',22935,27878);
INSERT INTO "django_geo_db_zipcode" VALUES(31178,70376,-6,'Modeste, Louisiana 70376',22936,27879);
INSERT INTO "django_geo_db_zipcode" VALUES(31179,70377,-6,'Montegut, Louisiana 70377',22937,27880);
INSERT INTO "django_geo_db_zipcode" VALUES(31180,70380,-6,'Morgan City, Louisiana 70380',22938,27881);
INSERT INTO "django_geo_db_zipcode" VALUES(31181,70381,-6,'Morgan City, Louisiana 70381',22938,27882);
INSERT INTO "django_geo_db_zipcode" VALUES(31182,70384,-6,'Cankton, Louisiana 70384',22939,27883);
INSERT INTO "django_geo_db_zipcode" VALUES(31183,70390,-6,'Napoleonville, Louisiana 70390',22940,27884);
INSERT INTO "django_geo_db_zipcode" VALUES(31184,70391,-6,'Paincourtville, Louisiana 70391',22941,27885);
INSERT INTO "django_geo_db_zipcode" VALUES(31185,70392,-6,'Patterson, Louisiana 70392',22942,27886);
INSERT INTO "django_geo_db_zipcode" VALUES(31186,70393,-6,'Plattenville, Louisiana 70393',22943,27887);
INSERT INTO "django_geo_db_zipcode" VALUES(31187,70394,-6,'Raceland, Louisiana 70394',22944,27888);
INSERT INTO "django_geo_db_zipcode" VALUES(31188,70395,-6,'Schriever, Louisiana 70395',22945,27889);
INSERT INTO "django_geo_db_zipcode" VALUES(31189,70397,-6,'Theriot, Louisiana 70397',22946,27890);
INSERT INTO "django_geo_db_zipcode" VALUES(31190,70401,-6,'Hammond, Louisiana 70401',22947,27891);
INSERT INTO "django_geo_db_zipcode" VALUES(31191,70402,-6,'Hammond, Louisiana 70402',22947,27892);
INSERT INTO "django_geo_db_zipcode" VALUES(31192,70403,-6,'Hammond, Louisiana 70403',22947,27893);
INSERT INTO "django_geo_db_zipcode" VALUES(31193,70404,-6,'Hammond, Louisiana 70404',22947,27894);
INSERT INTO "django_geo_db_zipcode" VALUES(31194,70420,-6,'Abita Springs, Louisiana 70420',22948,27895);
INSERT INTO "django_geo_db_zipcode" VALUES(31195,70421,-6,'Akers, Louisiana 70421',22949,27896);
INSERT INTO "django_geo_db_zipcode" VALUES(31196,70422,-6,'Amite, Louisiana 70422',22950,27897);
INSERT INTO "django_geo_db_zipcode" VALUES(31197,70426,-6,'Angie, Louisiana 70426',22951,27898);
INSERT INTO "django_geo_db_zipcode" VALUES(31198,70427,-6,'Bogalusa, Louisiana 70427',22952,27899);
INSERT INTO "django_geo_db_zipcode" VALUES(31199,70428,-6,'Sun, Louisiana 70428',22953,27900);
INSERT INTO "django_geo_db_zipcode" VALUES(31200,70429,-6,'Bogalusa, Louisiana 70429',22952,27901);
INSERT INTO "django_geo_db_zipcode" VALUES(31201,70431,-6,'Bush, Louisiana 70431',22954,27902);
INSERT INTO "django_geo_db_zipcode" VALUES(31202,70432,-6,'Covington, Louisiana 70432',22955,27903);
INSERT INTO "django_geo_db_zipcode" VALUES(31203,70433,-6,'Covington, Louisiana 70433',22955,27904);
INSERT INTO "django_geo_db_zipcode" VALUES(31204,70434,-6,'Covington, Louisiana 70434',22955,27905);
INSERT INTO "django_geo_db_zipcode" VALUES(31205,70435,-6,'Covington, Louisiana 70435',22955,27906);
INSERT INTO "django_geo_db_zipcode" VALUES(31206,70436,-6,'Fluker, Louisiana 70436',22956,27907);
INSERT INTO "django_geo_db_zipcode" VALUES(31207,70437,-6,'Folsom, Louisiana 70437',22957,27908);
INSERT INTO "django_geo_db_zipcode" VALUES(31208,70438,-6,'Franklinton, Louisiana 70438',22958,27909);
INSERT INTO "django_geo_db_zipcode" VALUES(31209,70440,-6,'Mandeville, Louisiana 70440',22959,27910);
INSERT INTO "django_geo_db_zipcode" VALUES(31210,70441,-6,'Greensburg, Louisiana 70441',22960,27911);
INSERT INTO "django_geo_db_zipcode" VALUES(31211,70442,-6,'Husser, Louisiana 70442',22961,27912);
INSERT INTO "django_geo_db_zipcode" VALUES(31212,70443,-6,'Independence, Louisiana 70443',22962,27913);
INSERT INTO "django_geo_db_zipcode" VALUES(31213,70444,-6,'Kentwood, Louisiana 70444',22963,27914);
INSERT INTO "django_geo_db_zipcode" VALUES(31214,70445,-6,'Lacombe, Louisiana 70445',22964,27915);
INSERT INTO "django_geo_db_zipcode" VALUES(31215,70446,-6,'Loranger, Louisiana 70446',22965,27916);
INSERT INTO "django_geo_db_zipcode" VALUES(31216,70447,-6,'Madisonville, Louisiana 70447',22966,27917);
INSERT INTO "django_geo_db_zipcode" VALUES(31217,70448,-6,'Mandeville, Louisiana 70448',22959,27918);
INSERT INTO "django_geo_db_zipcode" VALUES(31218,70449,-6,'Maurepas, Louisiana 70449',22967,27919);
INSERT INTO "django_geo_db_zipcode" VALUES(31219,70450,-6,'Mount Hermon, Louisiana 70450',22968,27920);
INSERT INTO "django_geo_db_zipcode" VALUES(31220,70451,-6,'Natalbany, Louisiana 70451',22969,27921);
INSERT INTO "django_geo_db_zipcode" VALUES(31221,70452,-6,'Pearl River, Louisiana 70452',22970,27922);
INSERT INTO "django_geo_db_zipcode" VALUES(31222,70453,-6,'Pine Grove, Louisiana 70453',22971,27923);
INSERT INTO "django_geo_db_zipcode" VALUES(31223,70454,-6,'Ponchatoula, Louisiana 70454',22972,27924);
INSERT INTO "django_geo_db_zipcode" VALUES(31224,70455,-6,'Robert, Louisiana 70455',22973,27925);
INSERT INTO "django_geo_db_zipcode" VALUES(31225,70456,-6,'Roseland, Louisiana 70456',22974,27926);
INSERT INTO "django_geo_db_zipcode" VALUES(31226,70457,-6,'Saint Benedict, Louisiana 70457',22975,27927);
INSERT INTO "django_geo_db_zipcode" VALUES(31227,70458,-6,'Slidell, Louisiana 70458',22976,27928);
INSERT INTO "django_geo_db_zipcode" VALUES(31228,70459,-6,'Slidell, Louisiana 70459',22976,27927);
INSERT INTO "django_geo_db_zipcode" VALUES(31229,70460,-6,'Slidell, Louisiana 70460',22976,27929);
INSERT INTO "django_geo_db_zipcode" VALUES(31230,70461,-6,'Slidell, Louisiana 70461',22976,27930);
INSERT INTO "django_geo_db_zipcode" VALUES(31231,70462,-6,'Springfield, Louisiana 70462',22977,27931);
INSERT INTO "django_geo_db_zipcode" VALUES(31232,70463,-6,'Sun, Louisiana 70463',22953,27932);
INSERT INTO "django_geo_db_zipcode" VALUES(31233,70464,-6,'Talisheek, Louisiana 70464',22978,27933);
INSERT INTO "django_geo_db_zipcode" VALUES(31234,70465,-6,'Tangipahoa, Louisiana 70465',22979,27934);
INSERT INTO "django_geo_db_zipcode" VALUES(31235,70466,-6,'Tickfaw, Louisiana 70466',22980,27935);
INSERT INTO "django_geo_db_zipcode" VALUES(31236,70467,-6,'Angie, Louisiana 70467',22951,27936);
INSERT INTO "django_geo_db_zipcode" VALUES(31237,70469,-6,'Slidell, Louisiana 70469',22976,27927);
INSERT INTO "django_geo_db_zipcode" VALUES(31238,70470,-6,'Mandeville, Louisiana 70470',22959,27927);
INSERT INTO "django_geo_db_zipcode" VALUES(31239,70471,-6,'Mandeville, Louisiana 70471',22959,27937);
INSERT INTO "django_geo_db_zipcode" VALUES(31240,70494,-6,'Ponchatoula, Louisiana 70494',22972,27938);
INSERT INTO "django_geo_db_zipcode" VALUES(31241,70499,-6,'Franklinton, Louisiana 70499',22958,27939);
INSERT INTO "django_geo_db_zipcode" VALUES(31242,70501,-6,'Lafayette, Louisiana 70501',22981,27940);
INSERT INTO "django_geo_db_zipcode" VALUES(31243,70502,-6,'Lafayette, Louisiana 70502',22981,27941);
INSERT INTO "django_geo_db_zipcode" VALUES(31244,70503,-6,'Lafayette, Louisiana 70503',22981,27942);
INSERT INTO "django_geo_db_zipcode" VALUES(31245,70504,-6,'Lafayette, Louisiana 70504',22981,27943);
INSERT INTO "django_geo_db_zipcode" VALUES(31246,70505,-6,'Lafayette, Louisiana 70505',22981,27944);
INSERT INTO "django_geo_db_zipcode" VALUES(31247,70506,-6,'Lafayette, Louisiana 70506',22981,27945);
INSERT INTO "django_geo_db_zipcode" VALUES(31248,70507,-6,'Lafayette, Louisiana 70507',22981,27946);
INSERT INTO "django_geo_db_zipcode" VALUES(31249,70508,-6,'Lafayette, Louisiana 70508',22981,27947);
INSERT INTO "django_geo_db_zipcode" VALUES(31250,70509,-6,'Lafayette, Louisiana 70509',22981,27948);
INSERT INTO "django_geo_db_zipcode" VALUES(31251,70510,-6,'Abbeville, Louisiana 70510',22982,27949);
INSERT INTO "django_geo_db_zipcode" VALUES(31252,70511,-6,'Abbeville, Louisiana 70511',22982,27950);
INSERT INTO "django_geo_db_zipcode" VALUES(31253,70512,-6,'Arnaudville, Louisiana 70512',22983,27951);
INSERT INTO "django_geo_db_zipcode" VALUES(31254,70513,-6,'Avery Island, Louisiana 70513',22984,27952);
INSERT INTO "django_geo_db_zipcode" VALUES(31255,70514,-6,'Baldwin, Louisiana 70514',22985,27953);
INSERT INTO "django_geo_db_zipcode" VALUES(31256,70515,-6,'Basile, Louisiana 70515',22986,27954);
INSERT INTO "django_geo_db_zipcode" VALUES(31257,70516,-6,'Branch, Louisiana 70516',22987,27955);
INSERT INTO "django_geo_db_zipcode" VALUES(31258,70517,-6,'Breaux Bridge, Louisiana 70517',22988,27956);
INSERT INTO "django_geo_db_zipcode" VALUES(31259,70518,-6,'Broussard, Louisiana 70518',22989,27957);
INSERT INTO "django_geo_db_zipcode" VALUES(31260,70519,-6,'Cade, Louisiana 70519',22990,27958);
INSERT INTO "django_geo_db_zipcode" VALUES(31261,70520,-6,'Carencro, Louisiana 70520',22991,27959);
INSERT INTO "django_geo_db_zipcode" VALUES(31262,70521,-6,'Cecilia, Louisiana 70521',22992,27960);
INSERT INTO "django_geo_db_zipcode" VALUES(31263,70522,-6,'Centerville, Louisiana 70522',22993,27961);
INSERT INTO "django_geo_db_zipcode" VALUES(31264,70523,-6,'Charenton, Louisiana 70523',22994,27962);
INSERT INTO "django_geo_db_zipcode" VALUES(31265,70524,-6,'Chataignier, Louisiana 70524',22995,27963);
INSERT INTO "django_geo_db_zipcode" VALUES(31266,70525,-6,'Church Point, Louisiana 70525',22996,27964);
INSERT INTO "django_geo_db_zipcode" VALUES(31267,70526,-6,'Crowley, Louisiana 70526',22997,27965);
INSERT INTO "django_geo_db_zipcode" VALUES(31268,70527,-6,'Crowley, Louisiana 70527',22997,27966);
INSERT INTO "django_geo_db_zipcode" VALUES(31269,70528,-6,'Delcambre, Louisiana 70528',22998,27967);
INSERT INTO "django_geo_db_zipcode" VALUES(31270,70529,-6,'Duson, Louisiana 70529',22999,27968);
INSERT INTO "django_geo_db_zipcode" VALUES(31271,70531,-6,'Egan, Louisiana 70531',23000,27969);
INSERT INTO "django_geo_db_zipcode" VALUES(31272,70532,-6,'Elton, Louisiana 70532',23001,27970);
INSERT INTO "django_geo_db_zipcode" VALUES(31273,70533,-6,'Erath, Louisiana 70533',23002,27971);
INSERT INTO "django_geo_db_zipcode" VALUES(31274,70534,-6,'Estherwood, Louisiana 70534',23003,27972);
INSERT INTO "django_geo_db_zipcode" VALUES(31275,70535,-6,'Eunice, Louisiana 70535',23004,27973);
INSERT INTO "django_geo_db_zipcode" VALUES(31276,70537,-6,'Evangeline, Louisiana 70537',23005,27974);
INSERT INTO "django_geo_db_zipcode" VALUES(31277,70538,-6,'Franklin, Louisiana 70538',23006,27975);
INSERT INTO "django_geo_db_zipcode" VALUES(31278,70540,-6,'Garden City, Louisiana 70540',23007,27976);
INSERT INTO "django_geo_db_zipcode" VALUES(31279,70541,-6,'Grand Coteau, Louisiana 70541',23008,27977);
INSERT INTO "django_geo_db_zipcode" VALUES(31280,70542,-6,'Gueydan, Louisiana 70542',23009,27978);
INSERT INTO "django_geo_db_zipcode" VALUES(31281,70543,-6,'Iota, Louisiana 70543',23010,27979);
INSERT INTO "django_geo_db_zipcode" VALUES(31282,70544,-6,'Jeanerette, Louisiana 70544',23011,27980);
INSERT INTO "django_geo_db_zipcode" VALUES(31283,70546,-6,'Jennings, Louisiana 70546',23012,27981);
INSERT INTO "django_geo_db_zipcode" VALUES(31284,70548,-6,'Kaplan, Louisiana 70548',23013,27982);
INSERT INTO "django_geo_db_zipcode" VALUES(31285,70549,-6,'Lake Arthur, Louisiana 70549',23014,27983);
INSERT INTO "django_geo_db_zipcode" VALUES(31286,70550,-6,'Lawtell, Louisiana 70550',23015,27984);
INSERT INTO "django_geo_db_zipcode" VALUES(31287,70551,-6,'Leonville, Louisiana 70551',23016,27985);
INSERT INTO "django_geo_db_zipcode" VALUES(31288,70552,-6,'Loreauville, Louisiana 70552',23017,27986);
INSERT INTO "django_geo_db_zipcode" VALUES(31289,70554,-6,'Mamou, Louisiana 70554',23018,27987);
INSERT INTO "django_geo_db_zipcode" VALUES(31290,70555,-6,'Maurice, Louisiana 70555',23019,27988);
INSERT INTO "django_geo_db_zipcode" VALUES(31291,70556,-6,'Mermentau, Louisiana 70556',23020,27989);
INSERT INTO "django_geo_db_zipcode" VALUES(31292,70558,-6,'Milton, Louisiana 70558',23021,27990);
INSERT INTO "django_geo_db_zipcode" VALUES(31293,70559,-6,'Morse, Louisiana 70559',23022,27991);
INSERT INTO "django_geo_db_zipcode" VALUES(31294,70560,-6,'New Iberia, Louisiana 70560',23023,27992);
INSERT INTO "django_geo_db_zipcode" VALUES(31295,70562,-6,'New Iberia, Louisiana 70562',23023,27993);
INSERT INTO "django_geo_db_zipcode" VALUES(31296,70563,-6,'New Iberia, Louisiana 70563',23023,27994);
INSERT INTO "django_geo_db_zipcode" VALUES(31297,70569,-6,'Lydia, Louisiana 70569',23024,27995);
INSERT INTO "django_geo_db_zipcode" VALUES(31298,70570,-6,'Opelousas, Louisiana 70570',23025,27996);
INSERT INTO "django_geo_db_zipcode" VALUES(31299,70571,-6,'Opelousas, Louisiana 70571',23025,27997);
INSERT INTO "django_geo_db_zipcode" VALUES(31300,70575,-6,'Perry, Louisiana 70575',23026,27998);
INSERT INTO "django_geo_db_zipcode" VALUES(31301,70576,-6,'Pine Prairie, Louisiana 70576',23027,27999);
INSERT INTO "django_geo_db_zipcode" VALUES(31302,70577,-6,'Port Barre, Louisiana 70577',23028,28000);
INSERT INTO "django_geo_db_zipcode" VALUES(31303,70578,-6,'Rayne, Louisiana 70578',23029,28001);
INSERT INTO "django_geo_db_zipcode" VALUES(31304,70580,-6,'Reddell, Louisiana 70580',23030,28002);
INSERT INTO "django_geo_db_zipcode" VALUES(31305,70581,-6,'Roanoke, Louisiana 70581',23031,28003);
INSERT INTO "django_geo_db_zipcode" VALUES(31306,70582,-6,'Saint Martinville, Louisiana 70582',23032,28004);
INSERT INTO "django_geo_db_zipcode" VALUES(31307,70583,-6,'Scott, Louisiana 70583',23033,28005);
INSERT INTO "django_geo_db_zipcode" VALUES(31308,70584,-6,'Sunset, Louisiana 70584',23034,28006);
INSERT INTO "django_geo_db_zipcode" VALUES(31309,70585,-6,'Turkey Creek, Louisiana 70585',23035,28007);
INSERT INTO "django_geo_db_zipcode" VALUES(31310,70586,-6,'Ville Platte, Louisiana 70586',23036,28008);
INSERT INTO "django_geo_db_zipcode" VALUES(31311,70589,-6,'Washington, Louisiana 70589',23037,28009);
INSERT INTO "django_geo_db_zipcode" VALUES(31312,70591,-6,'Welsh, Louisiana 70591',23038,28010);
INSERT INTO "django_geo_db_zipcode" VALUES(31313,70592,-6,'Youngsville, Louisiana 70592',23039,28011);
INSERT INTO "django_geo_db_zipcode" VALUES(31314,70593,-6,'Lafayette, Louisiana 70593',22981,28012);
INSERT INTO "django_geo_db_zipcode" VALUES(31315,70594,-6,'Raceland, Louisiana 70594',22944,28013);
INSERT INTO "django_geo_db_zipcode" VALUES(31316,70596,-6,'Lafayette, Louisiana 70596',22981,28012);
INSERT INTO "django_geo_db_zipcode" VALUES(31317,70598,-6,'Lafayette, Louisiana 70598',22981,28012);
INSERT INTO "django_geo_db_zipcode" VALUES(31318,70601,-6,'Lake Charles, Louisiana 70601',23040,28014);
INSERT INTO "django_geo_db_zipcode" VALUES(31319,70602,-6,'Lake Charles, Louisiana 70602',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31320,70605,-6,'Lake Charles, Louisiana 70605',23040,28016);
INSERT INTO "django_geo_db_zipcode" VALUES(31321,70606,-6,'Lake Charles, Louisiana 70606',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31322,70607,-6,'Lake Charles, Louisiana 70607',23040,28017);
INSERT INTO "django_geo_db_zipcode" VALUES(31323,70609,-6,'Lake Charles, Louisiana 70609',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31324,70611,-6,'Lake Charles, Louisiana 70611',23040,28018);
INSERT INTO "django_geo_db_zipcode" VALUES(31325,70612,-6,'Lake Charles, Louisiana 70612',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31326,70615,-6,'Lake Charles, Louisiana 70615',23040,28019);
INSERT INTO "django_geo_db_zipcode" VALUES(31327,70616,-6,'Lake Charles, Louisiana 70616',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31328,70629,-6,'Lake Charles, Louisiana 70629',23040,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31329,70630,-6,'Bell City, Louisiana 70630',23041,28020);
INSERT INTO "django_geo_db_zipcode" VALUES(31330,70631,-6,'Cameron, Louisiana 70631',23042,28021);
INSERT INTO "django_geo_db_zipcode" VALUES(31331,70632,-6,'Creole, Louisiana 70632',23043,28022);
INSERT INTO "django_geo_db_zipcode" VALUES(31332,70633,-6,'Dequincy, Louisiana 70633',23044,28023);
INSERT INTO "django_geo_db_zipcode" VALUES(31333,70634,-6,'Deridder, Louisiana 70634',23045,28024);
INSERT INTO "django_geo_db_zipcode" VALUES(31334,70637,-6,'Dry Creek, Louisiana 70637',23046,28025);
INSERT INTO "django_geo_db_zipcode" VALUES(31335,70638,-6,'Elizabeth, Louisiana 70638',23047,28026);
INSERT INTO "django_geo_db_zipcode" VALUES(31336,70639,-6,'Evans, Louisiana 70639',23048,28027);
INSERT INTO "django_geo_db_zipcode" VALUES(31337,70640,-6,'Fenton, Louisiana 70640',23049,28028);
INSERT INTO "django_geo_db_zipcode" VALUES(31338,70642,-6,'Fullerton, Louisiana 70642',23050,28029);
INSERT INTO "django_geo_db_zipcode" VALUES(31339,70643,-6,'Grand Chenier, Louisiana 70643',23051,28030);
INSERT INTO "django_geo_db_zipcode" VALUES(31340,70644,-6,'Grant, Louisiana 70644',23052,28031);
INSERT INTO "django_geo_db_zipcode" VALUES(31341,70645,-6,'Hackberry, Louisiana 70645',23053,28032);
INSERT INTO "django_geo_db_zipcode" VALUES(31342,70646,-6,'Hayes, Louisiana 70646',23054,28033);
INSERT INTO "django_geo_db_zipcode" VALUES(31343,70647,-6,'Iowa, Louisiana 70647',23055,28034);
INSERT INTO "django_geo_db_zipcode" VALUES(31344,70648,-6,'Kinder, Louisiana 70648',23056,28035);
INSERT INTO "django_geo_db_zipcode" VALUES(31345,70650,-6,'Lacassine, Louisiana 70650',23057,28036);
INSERT INTO "django_geo_db_zipcode" VALUES(31346,70651,-6,'Leblanc, Louisiana 70651',23058,28037);
INSERT INTO "django_geo_db_zipcode" VALUES(31347,70652,-6,'Longville, Louisiana 70652',23059,28038);
INSERT INTO "django_geo_db_zipcode" VALUES(31348,70653,-6,'Merryville, Louisiana 70653',23060,28039);
INSERT INTO "django_geo_db_zipcode" VALUES(31349,70654,-6,'Mittie, Louisiana 70654',23061,28040);
INSERT INTO "django_geo_db_zipcode" VALUES(31350,70655,-6,'Oberlin, Louisiana 70655',23062,28041);
INSERT INTO "django_geo_db_zipcode" VALUES(31351,70656,-6,'Pitkin, Louisiana 70656',23063,28042);
INSERT INTO "django_geo_db_zipcode" VALUES(31352,70657,-6,'Ragley, Louisiana 70657',23064,28043);
INSERT INTO "django_geo_db_zipcode" VALUES(31353,70658,-6,'Reeves, Louisiana 70658',23065,28044);
INSERT INTO "django_geo_db_zipcode" VALUES(31354,70659,-6,'Rosepine, Louisiana 70659',23066,28045);
INSERT INTO "django_geo_db_zipcode" VALUES(31355,70660,-6,'Singer, Louisiana 70660',23067,28046);
INSERT INTO "django_geo_db_zipcode" VALUES(31356,70661,-6,'Starks, Louisiana 70661',23068,28047);
INSERT INTO "django_geo_db_zipcode" VALUES(31357,70662,-6,'Sugartown, Louisiana 70662',23069,28048);
INSERT INTO "django_geo_db_zipcode" VALUES(31358,70663,-6,'Sulphur, Louisiana 70663',23070,28049);
INSERT INTO "django_geo_db_zipcode" VALUES(31359,70664,-6,'Sulphur, Louisiana 70664',23070,28015);
INSERT INTO "django_geo_db_zipcode" VALUES(31360,70665,-6,'Sulphur, Louisiana 70665',23070,28050);
INSERT INTO "django_geo_db_zipcode" VALUES(31361,70668,-6,'Vinton, Louisiana 70668',23071,28051);
INSERT INTO "django_geo_db_zipcode" VALUES(31362,70669,-6,'Westlake, Louisiana 70669',23072,28052);
INSERT INTO "django_geo_db_zipcode" VALUES(31363,70704,-6,'Baker, Louisiana 70704',23073,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31364,70706,-6,'Denham Springs, Louisiana 70706',23074,28054);
INSERT INTO "django_geo_db_zipcode" VALUES(31365,70707,-6,'Gonzales, Louisiana 70707',23075,27879);
INSERT INTO "django_geo_db_zipcode" VALUES(31366,70710,-6,'Addis, Louisiana 70710',23076,28055);
INSERT INTO "django_geo_db_zipcode" VALUES(31367,70711,-6,'Albany, Louisiana 70711',23077,28056);
INSERT INTO "django_geo_db_zipcode" VALUES(31368,70712,-6,'Angola, Louisiana 70712',23078,28057);
INSERT INTO "django_geo_db_zipcode" VALUES(31369,70714,-6,'Baker, Louisiana 70714',23073,28058);
INSERT INTO "django_geo_db_zipcode" VALUES(31370,70715,-6,'Batchelor, Louisiana 70715',23079,28059);
INSERT INTO "django_geo_db_zipcode" VALUES(31371,70716,-6,'Bayou Goula, Louisiana 70716',23080,28060);
INSERT INTO "django_geo_db_zipcode" VALUES(31372,70717,-6,'Blanks, Louisiana 70717',23081,28061);
INSERT INTO "django_geo_db_zipcode" VALUES(31373,70718,-6,'Brittany, Louisiana 70718',23082,28062);
INSERT INTO "django_geo_db_zipcode" VALUES(31374,70719,-6,'Brusly, Louisiana 70719',23083,28063);
INSERT INTO "django_geo_db_zipcode" VALUES(31375,70720,-6,'Bueche, Louisiana 70720',23084,28064);
INSERT INTO "django_geo_db_zipcode" VALUES(31376,70721,-6,'Carville, Louisiana 70721',23085,28065);
INSERT INTO "django_geo_db_zipcode" VALUES(31377,70722,-6,'Clinton, Louisiana 70722',23086,28066);
INSERT INTO "django_geo_db_zipcode" VALUES(31378,70723,-6,'Convent, Louisiana 70723',23087,28067);
INSERT INTO "django_geo_db_zipcode" VALUES(31379,70725,-6,'Darrow, Louisiana 70725',23088,28068);
INSERT INTO "django_geo_db_zipcode" VALUES(31380,70726,-6,'Denham Springs, Louisiana 70726',23074,28069);
INSERT INTO "django_geo_db_zipcode" VALUES(31381,70727,-6,'Denham Springs, Louisiana 70727',23074,28070);
INSERT INTO "django_geo_db_zipcode" VALUES(31382,70728,-6,'Duplessis, Louisiana 70728',23089,28071);
INSERT INTO "django_geo_db_zipcode" VALUES(31383,70729,-6,'Erwinville, Louisiana 70729',23090,28072);
INSERT INTO "django_geo_db_zipcode" VALUES(31384,70730,-6,'Ethel, Louisiana 70730',23091,28073);
INSERT INTO "django_geo_db_zipcode" VALUES(31385,70732,-6,'Fordoche, Louisiana 70732',23092,28074);
INSERT INTO "django_geo_db_zipcode" VALUES(31386,70733,-6,'French Settlement, Louisiana 70733',23093,28075);
INSERT INTO "django_geo_db_zipcode" VALUES(31387,70734,-6,'Geismar, Louisiana 70734',23094,28076);
INSERT INTO "django_geo_db_zipcode" VALUES(31388,70736,-6,'Glynn, Louisiana 70736',23095,28077);
INSERT INTO "django_geo_db_zipcode" VALUES(31389,70737,-6,'Gonzales, Louisiana 70737',23075,28078);
INSERT INTO "django_geo_db_zipcode" VALUES(31390,70738,-6,'Burnside, Louisiana 70738',23096,27879);
INSERT INTO "django_geo_db_zipcode" VALUES(31391,70739,-6,'Greenwell Springs, Louisiana 70739',23097,28079);
INSERT INTO "django_geo_db_zipcode" VALUES(31392,70740,-6,'Grosse Tete, Louisiana 70740',23098,28080);
INSERT INTO "django_geo_db_zipcode" VALUES(31393,70743,-6,'Hester, Louisiana 70743',23099,28081);
INSERT INTO "django_geo_db_zipcode" VALUES(31394,70744,-6,'Holden, Louisiana 70744',23100,28082);
INSERT INTO "django_geo_db_zipcode" VALUES(31395,70747,-6,'Innis, Louisiana 70747',23101,28083);
INSERT INTO "django_geo_db_zipcode" VALUES(31396,70748,-6,'Jackson, Louisiana 70748',23102,28084);
INSERT INTO "django_geo_db_zipcode" VALUES(31397,70749,-6,'Jarreau, Louisiana 70749',23103,28085);
INSERT INTO "django_geo_db_zipcode" VALUES(31398,70750,-6,'Krotz Springs, Louisiana 70750',23104,28086);
INSERT INTO "django_geo_db_zipcode" VALUES(31399,70751,-6,'Labarre, Louisiana 70751',23105,28087);
INSERT INTO "django_geo_db_zipcode" VALUES(31400,70752,-6,'Lakeland, Louisiana 70752',23106,28088);
INSERT INTO "django_geo_db_zipcode" VALUES(31401,70753,-6,'Lettsworth, Louisiana 70753',23107,28089);
INSERT INTO "django_geo_db_zipcode" VALUES(31402,70754,-6,'Livingston, Louisiana 70754',23108,28090);
INSERT INTO "django_geo_db_zipcode" VALUES(31403,70755,-6,'Livonia, Louisiana 70755',23109,28091);
INSERT INTO "django_geo_db_zipcode" VALUES(31404,70756,-6,'Lottie, Louisiana 70756',23110,28092);
INSERT INTO "django_geo_db_zipcode" VALUES(31405,70757,-6,'Maringouin, Louisiana 70757',23111,28093);
INSERT INTO "django_geo_db_zipcode" VALUES(31406,70759,-6,'Morganza, Louisiana 70759',23112,28094);
INSERT INTO "django_geo_db_zipcode" VALUES(31407,70760,-6,'New Roads, Louisiana 70760',23113,28095);
INSERT INTO "django_geo_db_zipcode" VALUES(31408,70761,-6,'Norwood, Louisiana 70761',23114,28096);
INSERT INTO "django_geo_db_zipcode" VALUES(31409,70762,-6,'Oscar, Louisiana 70762',23115,28097);
INSERT INTO "django_geo_db_zipcode" VALUES(31410,70763,-6,'Paulina, Louisiana 70763',23116,28098);
INSERT INTO "django_geo_db_zipcode" VALUES(31411,70764,-6,'Plaquemine, Louisiana 70764',23117,28099);
INSERT INTO "django_geo_db_zipcode" VALUES(31412,70765,-6,'Plaquemine, Louisiana 70765',23117,28060);
INSERT INTO "django_geo_db_zipcode" VALUES(31413,70767,-6,'Port Allen, Louisiana 70767',23118,28100);
INSERT INTO "django_geo_db_zipcode" VALUES(31414,70769,-6,'Prairieville, Louisiana 70769',23119,28101);
INSERT INTO "django_geo_db_zipcode" VALUES(31415,70770,-6,'Pride, Louisiana 70770',23120,28102);
INSERT INTO "django_geo_db_zipcode" VALUES(31416,70772,-6,'Rosedale, Louisiana 70772',23121,28103);
INSERT INTO "django_geo_db_zipcode" VALUES(31417,70773,-6,'Rougon, Louisiana 70773',23122,28104);
INSERT INTO "django_geo_db_zipcode" VALUES(31418,70774,-6,'Saint Amant, Louisiana 70774',23123,28105);
INSERT INTO "django_geo_db_zipcode" VALUES(31419,70775,-6,'Saint Francisville, Louisiana 70775',23124,28106);
INSERT INTO "django_geo_db_zipcode" VALUES(31420,70776,-6,'Saint Gabriel, Louisiana 70776',23125,28107);
INSERT INTO "django_geo_db_zipcode" VALUES(31421,70777,-6,'Slaughter, Louisiana 70777',23126,28108);
INSERT INTO "django_geo_db_zipcode" VALUES(31422,70778,-6,'Sorrento, Louisiana 70778',23127,28109);
INSERT INTO "django_geo_db_zipcode" VALUES(31423,70780,-6,'Sunshine, Louisiana 70780',23128,28110);
INSERT INTO "django_geo_db_zipcode" VALUES(31424,70781,-6,'Torbert, Louisiana 70781',23129,28111);
INSERT INTO "django_geo_db_zipcode" VALUES(31425,70782,-6,'Tunica, Louisiana 70782',23130,28112);
INSERT INTO "django_geo_db_zipcode" VALUES(31426,70783,-6,'Ventress, Louisiana 70783',23131,28113);
INSERT INTO "django_geo_db_zipcode" VALUES(31427,70784,-6,'Wakefield, Louisiana 70784',23132,28114);
INSERT INTO "django_geo_db_zipcode" VALUES(31428,70785,-6,'Walker, Louisiana 70785',23133,28115);
INSERT INTO "django_geo_db_zipcode" VALUES(31429,70786,-6,'Watson, Louisiana 70786',23134,28116);
INSERT INTO "django_geo_db_zipcode" VALUES(31430,70787,-6,'Weyanoke, Louisiana 70787',23135,28117);
INSERT INTO "django_geo_db_zipcode" VALUES(31431,70788,-6,'White Castle, Louisiana 70788',23136,28118);
INSERT INTO "django_geo_db_zipcode" VALUES(31432,70789,-6,'Wilson, Louisiana 70789',23137,28119);
INSERT INTO "django_geo_db_zipcode" VALUES(31433,70791,-6,'Zachary, Louisiana 70791',23138,28120);
INSERT INTO "django_geo_db_zipcode" VALUES(31434,70792,-6,'Uncle Sam, Louisiana 70792',23139,28121);
INSERT INTO "django_geo_db_zipcode" VALUES(31435,70801,-6,'Baton Rouge, Louisiana 70801',23140,28122);
INSERT INTO "django_geo_db_zipcode" VALUES(31436,70802,-6,'Baton Rouge, Louisiana 70802',23140,28123);
INSERT INTO "django_geo_db_zipcode" VALUES(31437,70803,-6,'Baton Rouge, Louisiana 70803',23140,28124);
INSERT INTO "django_geo_db_zipcode" VALUES(31438,70804,-6,'Baton Rouge, Louisiana 70804',23140,28125);
INSERT INTO "django_geo_db_zipcode" VALUES(31439,70805,-6,'Baton Rouge, Louisiana 70805',23140,28126);
INSERT INTO "django_geo_db_zipcode" VALUES(31440,70806,-6,'Baton Rouge, Louisiana 70806',23140,28127);
INSERT INTO "django_geo_db_zipcode" VALUES(31441,70807,-6,'Baton Rouge, Louisiana 70807',23140,28128);
INSERT INTO "django_geo_db_zipcode" VALUES(31442,70808,-6,'Baton Rouge, Louisiana 70808',23140,28129);
INSERT INTO "django_geo_db_zipcode" VALUES(31443,70809,-6,'Baton Rouge, Louisiana 70809',23140,28130);
INSERT INTO "django_geo_db_zipcode" VALUES(31444,70810,-6,'Baton Rouge, Louisiana 70810',23140,28131);
INSERT INTO "django_geo_db_zipcode" VALUES(31445,70811,-6,'Baton Rouge, Louisiana 70811',23140,28132);
INSERT INTO "django_geo_db_zipcode" VALUES(31446,70812,-6,'Baton Rouge, Louisiana 70812',23140,28133);
INSERT INTO "django_geo_db_zipcode" VALUES(31447,70813,-6,'Baton Rouge, Louisiana 70813',23140,28134);
INSERT INTO "django_geo_db_zipcode" VALUES(31448,70814,-6,'Baton Rouge, Louisiana 70814',23140,28135);
INSERT INTO "django_geo_db_zipcode" VALUES(31449,70815,-6,'Baton Rouge, Louisiana 70815',23140,28136);
INSERT INTO "django_geo_db_zipcode" VALUES(31450,70816,-6,'Baton Rouge, Louisiana 70816',23140,28137);
INSERT INTO "django_geo_db_zipcode" VALUES(31451,70817,-6,'Baton Rouge, Louisiana 70817',23140,28138);
INSERT INTO "django_geo_db_zipcode" VALUES(31452,70818,-6,'Baton Rouge, Louisiana 70818',23140,28139);
INSERT INTO "django_geo_db_zipcode" VALUES(31453,70819,-6,'Baton Rouge, Louisiana 70819',23140,28140);
INSERT INTO "django_geo_db_zipcode" VALUES(31454,70820,-6,'Baton Rouge, Louisiana 70820',23140,28141);
INSERT INTO "django_geo_db_zipcode" VALUES(31455,70821,-6,'Baton Rouge, Louisiana 70821',23140,28142);
INSERT INTO "django_geo_db_zipcode" VALUES(31456,70822,-6,'Baton Rouge, Louisiana 70822',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31457,70823,-6,'Baton Rouge, Louisiana 70823',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31458,70825,-6,'Baton Rouge, Louisiana 70825',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31459,70826,-6,'Baton Rouge, Louisiana 70826',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31460,70827,-6,'Baton Rouge, Louisiana 70827',23140,28143);
INSERT INTO "django_geo_db_zipcode" VALUES(31461,70831,-6,'Baton Rouge, Louisiana 70831',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31462,70832,-6,'Elton, Louisiana 70832',23001,28144);
INSERT INTO "django_geo_db_zipcode" VALUES(31463,70833,-6,'Baton Rouge, Louisiana 70833',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31464,70835,-6,'Baton Rouge, Louisiana 70835',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31465,70836,-6,'Baton Rouge, Louisiana 70836',23140,28145);
INSERT INTO "django_geo_db_zipcode" VALUES(31466,70837,-6,'Baton Rouge, Louisiana 70837',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31467,70848,-6,'Baton Rouge, Louisiana 70848',23140,28146);
INSERT INTO "django_geo_db_zipcode" VALUES(31468,70874,-6,'Baton Rouge, Louisiana 70874',23140,28147);
INSERT INTO "django_geo_db_zipcode" VALUES(31469,70879,-6,'Baton Rouge, Louisiana 70879',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31470,70883,-6,'Baton Rouge, Louisiana 70883',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31471,70884,-6,'Baton Rouge, Louisiana 70884',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31472,70892,-6,'Baton Rouge, Louisiana 70892',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31473,70893,-6,'Baton Rouge, Louisiana 70893',23140,28148);
INSERT INTO "django_geo_db_zipcode" VALUES(31474,70894,-6,'Baton Rouge, Louisiana 70894',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31475,70895,-6,'Baton Rouge, Louisiana 70895',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31476,70896,-6,'Baton Rouge, Louisiana 70896',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31477,70898,-6,'Baton Rouge, Louisiana 70898',23140,28053);
INSERT INTO "django_geo_db_zipcode" VALUES(31478,70952,-6,'Youngsville, Louisiana 70952',23039,28149);
INSERT INTO "django_geo_db_zipcode" VALUES(31479,71001,-6,'Arcadia, Louisiana 71001',23141,28150);
INSERT INTO "django_geo_db_zipcode" VALUES(31480,71002,-6,'Ashland, Louisiana 71002',23142,28151);
INSERT INTO "django_geo_db_zipcode" VALUES(31481,71003,-6,'Athens, Louisiana 71003',23143,28152);
INSERT INTO "django_geo_db_zipcode" VALUES(31482,71004,-6,'Belcher, Louisiana 71004',23144,28153);
INSERT INTO "django_geo_db_zipcode" VALUES(31483,71006,-6,'Benton, Louisiana 71006',23145,28154);
INSERT INTO "django_geo_db_zipcode" VALUES(31484,71007,-6,'Bethany, Louisiana 71007',23146,28155);
INSERT INTO "django_geo_db_zipcode" VALUES(31485,71008,-6,'Bienville, Louisiana 71008',23147,28156);
INSERT INTO "django_geo_db_zipcode" VALUES(31486,71009,-6,'Blanchard, Louisiana 71009',23148,28157);
INSERT INTO "django_geo_db_zipcode" VALUES(31487,71016,-6,'Castor, Louisiana 71016',23149,28158);
INSERT INTO "django_geo_db_zipcode" VALUES(31488,71018,-6,'Cotton Valley, Louisiana 71018',23150,28159);
INSERT INTO "django_geo_db_zipcode" VALUES(31489,71019,-6,'Coushatta, Louisiana 71019',23151,28160);
INSERT INTO "django_geo_db_zipcode" VALUES(31490,71021,-6,'Cullen, Louisiana 71021',23152,28161);
INSERT INTO "django_geo_db_zipcode" VALUES(31491,71023,-6,'Doyline, Louisiana 71023',23153,28162);
INSERT INTO "django_geo_db_zipcode" VALUES(31492,71024,-6,'Dubberly, Louisiana 71024',23154,28163);
INSERT INTO "django_geo_db_zipcode" VALUES(31493,71025,-6,'East Point, Louisiana 71025',23155,28164);
INSERT INTO "django_geo_db_zipcode" VALUES(31494,71027,-6,'Frierson, Louisiana 71027',23156,28165);
INSERT INTO "django_geo_db_zipcode" VALUES(31495,71028,-6,'Gibsland, Louisiana 71028',23157,28166);
INSERT INTO "django_geo_db_zipcode" VALUES(31496,71029,-6,'Gilliam, Louisiana 71029',23158,28167);
INSERT INTO "django_geo_db_zipcode" VALUES(31497,71030,-6,'Gloster, Louisiana 71030',23159,28168);
INSERT INTO "django_geo_db_zipcode" VALUES(31498,71031,-6,'Goldonna, Louisiana 71031',23160,28169);
INSERT INTO "django_geo_db_zipcode" VALUES(31499,71032,-6,'Grand Cane, Louisiana 71032',23161,28170);
INSERT INTO "django_geo_db_zipcode" VALUES(31500,71033,-6,'Greenwood, Louisiana 71033',23162,28171);
INSERT INTO "django_geo_db_zipcode" VALUES(31501,71034,-6,'Hall Summit, Louisiana 71034',23163,28172);
INSERT INTO "django_geo_db_zipcode" VALUES(31502,71036,-6,'Harmon, Louisiana 71036',23164,28164);
INSERT INTO "django_geo_db_zipcode" VALUES(31503,71037,-6,'Haughton, Louisiana 71037',23165,28173);
INSERT INTO "django_geo_db_zipcode" VALUES(31504,71038,-6,'Haynesville, Louisiana 71038',23166,28174);
INSERT INTO "django_geo_db_zipcode" VALUES(31505,71039,-6,'Heflin, Louisiana 71039',23167,28175);
INSERT INTO "django_geo_db_zipcode" VALUES(31506,71040,-6,'Homer, Louisiana 71040',23168,28176);
INSERT INTO "django_geo_db_zipcode" VALUES(31507,71043,-6,'Hosston, Louisiana 71043',23169,28177);
INSERT INTO "django_geo_db_zipcode" VALUES(31508,71044,-6,'Ida, Louisiana 71044',23170,28178);
INSERT INTO "django_geo_db_zipcode" VALUES(31509,71045,-6,'Jamestown, Louisiana 71045',23171,28179);
INSERT INTO "django_geo_db_zipcode" VALUES(31510,71046,-6,'Keatchie, Louisiana 71046',23172,28180);
INSERT INTO "django_geo_db_zipcode" VALUES(31511,71047,-6,'Keithville, Louisiana 71047',23173,28181);
INSERT INTO "django_geo_db_zipcode" VALUES(31512,71048,-6,'Lisbon, Louisiana 71048',23174,28182);
INSERT INTO "django_geo_db_zipcode" VALUES(31513,71049,-6,'Logansport, Louisiana 71049',23175,28183);
INSERT INTO "django_geo_db_zipcode" VALUES(31514,71050,-6,'Longstreet, Louisiana 71050',23176,28184);
INSERT INTO "django_geo_db_zipcode" VALUES(31515,71051,-6,'Elm Grove, Louisiana 71051',23177,28185);
INSERT INTO "django_geo_db_zipcode" VALUES(31516,71052,-6,'Mansfield, Louisiana 71052',23178,28186);
INSERT INTO "django_geo_db_zipcode" VALUES(31517,71053,-6,'South Mansfield, Louisiana 71053',23179,28187);
INSERT INTO "django_geo_db_zipcode" VALUES(31518,71055,-6,'Minden, Louisiana 71055',23180,28188);
INSERT INTO "django_geo_db_zipcode" VALUES(31519,71058,-6,'Minden, Louisiana 71058',23180,28189);
INSERT INTO "django_geo_db_zipcode" VALUES(31520,71059,-6,'Mansfield, Louisiana 71059',23178,28190);
INSERT INTO "django_geo_db_zipcode" VALUES(31521,71060,-6,'Mooringsport, Louisiana 71060',23181,28191);
INSERT INTO "django_geo_db_zipcode" VALUES(31522,71061,-6,'Oil City, Louisiana 71061',23182,28192);
INSERT INTO "django_geo_db_zipcode" VALUES(31523,71063,-6,'Pelican, Louisiana 71063',23183,28193);
INSERT INTO "django_geo_db_zipcode" VALUES(31524,71064,-6,'Plain Dealing, Louisiana 71064',23184,28194);
INSERT INTO "django_geo_db_zipcode" VALUES(31525,71065,-6,'Pleasant Hill, Louisiana 71065',23185,28195);
INSERT INTO "django_geo_db_zipcode" VALUES(31526,71066,-6,'Powhatan, Louisiana 71066',23186,28196);
INSERT INTO "django_geo_db_zipcode" VALUES(31527,71067,-6,'Princeton, Louisiana 71067',23187,28197);
INSERT INTO "django_geo_db_zipcode" VALUES(31528,71068,-6,'Ringgold, Louisiana 71068',23188,28198);
INSERT INTO "django_geo_db_zipcode" VALUES(31529,71069,-6,'Rodessa, Louisiana 71069',23189,28199);
INSERT INTO "django_geo_db_zipcode" VALUES(31530,71070,-6,'Saline, Louisiana 71070',23190,28200);
INSERT INTO "django_geo_db_zipcode" VALUES(31531,71071,-6,'Sarepta, Louisiana 71071',23191,28201);
INSERT INTO "django_geo_db_zipcode" VALUES(31532,71072,-6,'Shongaloo, Louisiana 71072',23192,28202);
INSERT INTO "django_geo_db_zipcode" VALUES(31533,71073,-6,'Sibley, Louisiana 71073',23193,28203);
INSERT INTO "django_geo_db_zipcode" VALUES(31534,71075,-6,'Springhill, Louisiana 71075',23194,28204);
INSERT INTO "django_geo_db_zipcode" VALUES(31535,71076,-6,'Castor, Louisiana 71076',23149,28205);
INSERT INTO "django_geo_db_zipcode" VALUES(31536,71078,-6,'Stonewall, Louisiana 71078',23195,28206);
INSERT INTO "django_geo_db_zipcode" VALUES(31537,71079,-6,'Summerfield, Louisiana 71079',23196,28207);
INSERT INTO "django_geo_db_zipcode" VALUES(31538,71080,-6,'Taylor, Louisiana 71080',23197,28208);
INSERT INTO "django_geo_db_zipcode" VALUES(31539,71082,-6,'Vivian, Louisiana 71082',23198,28209);
INSERT INTO "django_geo_db_zipcode" VALUES(31540,71095,-6,'Jamestown, Louisiana 71095',23171,28210);
INSERT INTO "django_geo_db_zipcode" VALUES(31541,71101,-6,'Shreveport, Louisiana 71101',23199,28211);
INSERT INTO "django_geo_db_zipcode" VALUES(31542,71102,-6,'Shreveport, Louisiana 71102',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31543,71103,-6,'Shreveport, Louisiana 71103',23199,28213);
INSERT INTO "django_geo_db_zipcode" VALUES(31544,71104,-6,'Shreveport, Louisiana 71104',23199,28214);
INSERT INTO "django_geo_db_zipcode" VALUES(31545,71105,-6,'Shreveport, Louisiana 71105',23199,28215);
INSERT INTO "django_geo_db_zipcode" VALUES(31546,71106,-6,'Shreveport, Louisiana 71106',23199,28216);
INSERT INTO "django_geo_db_zipcode" VALUES(31547,71107,-6,'Shreveport, Louisiana 71107',23199,28217);
INSERT INTO "django_geo_db_zipcode" VALUES(31548,71108,-6,'Shreveport, Louisiana 71108',23199,28218);
INSERT INTO "django_geo_db_zipcode" VALUES(31549,71109,-6,'Shreveport, Louisiana 71109',23199,28219);
INSERT INTO "django_geo_db_zipcode" VALUES(31550,71110,-6,'Barksdale AFB, Louisiana 71110',23200,28220);
INSERT INTO "django_geo_db_zipcode" VALUES(31551,71111,-6,'Bossier City, Louisiana 71111',23201,28221);
INSERT INTO "django_geo_db_zipcode" VALUES(31552,71112,-6,'Bossier City, Louisiana 71112',23201,28222);
INSERT INTO "django_geo_db_zipcode" VALUES(31553,71113,-6,'Bossier City, Louisiana 71113',23201,28223);
INSERT INTO "django_geo_db_zipcode" VALUES(31554,71115,-6,'Shreveport, Louisiana 71115',23199,28224);
INSERT INTO "django_geo_db_zipcode" VALUES(31555,71118,-6,'Shreveport, Louisiana 71118',23199,28225);
INSERT INTO "django_geo_db_zipcode" VALUES(31556,71119,-6,'Shreveport, Louisiana 71119',23199,28226);
INSERT INTO "django_geo_db_zipcode" VALUES(31557,71120,-6,'Shreveport, Louisiana 71120',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31558,71129,-6,'Shreveport, Louisiana 71129',23199,28227);
INSERT INTO "django_geo_db_zipcode" VALUES(31559,71130,-6,'Shreveport, Louisiana 71130',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31560,71133,-6,'Shreveport, Louisiana 71133',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31561,71134,-6,'Shreveport, Louisiana 71134',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31562,71135,-6,'Shreveport, Louisiana 71135',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31563,71136,-6,'Shreveport, Louisiana 71136',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31564,71137,-6,'Shreveport, Louisiana 71137',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31565,71138,-6,'Shreveport, Louisiana 71138',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31566,71148,-6,'Shreveport, Louisiana 71148',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31567,71149,-6,'Shreveport, Louisiana 71149',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31568,71151,-6,'Shreveport, Louisiana 71151',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31569,71152,-6,'Shreveport, Louisiana 71152',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31570,71153,-6,'Shreveport, Louisiana 71153',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31571,71154,-6,'Shreveport, Louisiana 71154',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31572,71156,-6,'Shreveport, Louisiana 71156',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31573,71161,-6,'Shreveport, Louisiana 71161',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31574,71162,-6,'Shreveport, Louisiana 71162',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31575,71163,-6,'Shreveport, Louisiana 71163',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31576,71164,-6,'Shreveport, Louisiana 71164',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31577,71165,-6,'Shreveport, Louisiana 71165',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31578,71166,-6,'Shreveport, Louisiana 71166',23199,28212);
INSERT INTO "django_geo_db_zipcode" VALUES(31579,71171,-6,'Bossier City, Louisiana 71171',23201,28223);
INSERT INTO "django_geo_db_zipcode" VALUES(31580,71172,-6,'Bossier City, Louisiana 71172',23201,28223);
INSERT INTO "django_geo_db_zipcode" VALUES(31581,71201,-6,'Monroe, Louisiana 71201',23202,28228);
INSERT INTO "django_geo_db_zipcode" VALUES(31582,71202,-6,'Monroe, Louisiana 71202',23202,28229);
INSERT INTO "django_geo_db_zipcode" VALUES(31583,71203,-6,'Monroe, Louisiana 71203',23202,28230);
INSERT INTO "django_geo_db_zipcode" VALUES(31584,71207,-6,'Monroe, Louisiana 71207',23202,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31585,71208,-6,'Monroe, Louisiana 71208',23202,28232);
INSERT INTO "django_geo_db_zipcode" VALUES(31586,71209,-6,'Monroe, Louisiana 71209',23202,28233);
INSERT INTO "django_geo_db_zipcode" VALUES(31587,71210,-6,'Monroe, Louisiana 71210',23202,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31588,71211,-6,'Monroe, Louisiana 71211',23202,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31589,71212,-6,'Monroe, Louisiana 71212',23202,28234);
INSERT INTO "django_geo_db_zipcode" VALUES(31590,71213,-6,'Monroe, Louisiana 71213',23202,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31591,71218,-6,'Archibald, Louisiana 71218',23203,28235);
INSERT INTO "django_geo_db_zipcode" VALUES(31592,71219,-6,'Baskin, Louisiana 71219',23204,28236);
INSERT INTO "django_geo_db_zipcode" VALUES(31593,71220,-6,'Bastrop, Louisiana 71220',23205,28237);
INSERT INTO "django_geo_db_zipcode" VALUES(31594,71221,-6,'Bastrop, Louisiana 71221',23205,28238);
INSERT INTO "django_geo_db_zipcode" VALUES(31595,71222,-6,'Bernice, Louisiana 71222',23206,28239);
INSERT INTO "django_geo_db_zipcode" VALUES(31596,71223,-6,'Bonita, Louisiana 71223',23207,28240);
INSERT INTO "django_geo_db_zipcode" VALUES(31597,71225,-6,'Calhoun, Louisiana 71225',23208,28241);
INSERT INTO "django_geo_db_zipcode" VALUES(31598,71226,-6,'Chatham, Louisiana 71226',23209,28242);
INSERT INTO "django_geo_db_zipcode" VALUES(31599,71227,-6,'Choudrant, Louisiana 71227',23210,28243);
INSERT INTO "django_geo_db_zipcode" VALUES(31600,71229,-6,'Collinston, Louisiana 71229',23211,28244);
INSERT INTO "django_geo_db_zipcode" VALUES(31601,71230,-6,'Crowville, Louisiana 71230',23212,28245);
INSERT INTO "django_geo_db_zipcode" VALUES(31602,71232,-6,'Delhi, Louisiana 71232',23213,28246);
INSERT INTO "django_geo_db_zipcode" VALUES(31603,71233,-6,'Delta, Louisiana 71233',23214,28247);
INSERT INTO "django_geo_db_zipcode" VALUES(31604,71234,-6,'Downsville, Louisiana 71234',23215,28248);
INSERT INTO "django_geo_db_zipcode" VALUES(31605,71235,-6,'Dubach, Louisiana 71235',23216,28249);
INSERT INTO "django_geo_db_zipcode" VALUES(31606,71237,-6,'Epps, Louisiana 71237',23217,28250);
INSERT INTO "django_geo_db_zipcode" VALUES(31607,71238,-6,'Eros, Louisiana 71238',23218,28251);
INSERT INTO "django_geo_db_zipcode" VALUES(31608,71240,-6,'Fairbanks, Louisiana 71240',23219,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31609,71241,-6,'Farmerville, Louisiana 71241',23220,28252);
INSERT INTO "django_geo_db_zipcode" VALUES(31610,71242,-6,'Forest, Louisiana 71242',23221,28253);
INSERT INTO "django_geo_db_zipcode" VALUES(31611,71243,-6,'Fort Necessity, Louisiana 71243',23222,28254);
INSERT INTO "django_geo_db_zipcode" VALUES(31612,71245,-6,'Grambling, Louisiana 71245',23223,28255);
INSERT INTO "django_geo_db_zipcode" VALUES(31613,71247,-6,'Hodge, Louisiana 71247',23224,28256);
INSERT INTO "django_geo_db_zipcode" VALUES(31614,71249,-6,'Jigger, Louisiana 71249',23225,28245);
INSERT INTO "django_geo_db_zipcode" VALUES(31615,71250,-6,'Jones, Louisiana 71250',23226,28257);
INSERT INTO "django_geo_db_zipcode" VALUES(31616,71251,-6,'Jonesboro, Louisiana 71251',23227,28258);
INSERT INTO "django_geo_db_zipcode" VALUES(31617,71253,-6,'Kilbourne, Louisiana 71253',23228,28259);
INSERT INTO "django_geo_db_zipcode" VALUES(31618,71254,-6,'Lake Providence, Louisiana 71254',23229,28260);
INSERT INTO "django_geo_db_zipcode" VALUES(31619,71256,-6,'Lillie, Louisiana 71256',23230,28261);
INSERT INTO "django_geo_db_zipcode" VALUES(31620,71259,-6,'Mangham, Louisiana 71259',23231,28262);
INSERT INTO "django_geo_db_zipcode" VALUES(31621,71260,-6,'Marion, Louisiana 71260',23232,28263);
INSERT INTO "django_geo_db_zipcode" VALUES(31622,71261,-6,'Mer Rouge, Louisiana 71261',23233,28264);
INSERT INTO "django_geo_db_zipcode" VALUES(31623,71263,-6,'Oak Grove, Louisiana 71263',23234,28265);
INSERT INTO "django_geo_db_zipcode" VALUES(31624,71264,-6,'Oak Ridge, Louisiana 71264',23235,28266);
INSERT INTO "django_geo_db_zipcode" VALUES(31625,71266,-6,'Pioneer, Louisiana 71266',23236,28267);
INSERT INTO "django_geo_db_zipcode" VALUES(31626,71268,-6,'Quitman, Louisiana 71268',23237,28268);
INSERT INTO "django_geo_db_zipcode" VALUES(31627,71269,-6,'Rayville, Louisiana 71269',23238,28269);
INSERT INTO "django_geo_db_zipcode" VALUES(31628,71270,-6,'Ruston, Louisiana 71270',23239,28270);
INSERT INTO "django_geo_db_zipcode" VALUES(31629,71272,-6,'Ruston, Louisiana 71272',23239,28271);
INSERT INTO "django_geo_db_zipcode" VALUES(31630,71273,-6,'Ruston, Louisiana 71273',23239,28272);
INSERT INTO "django_geo_db_zipcode" VALUES(31631,71275,-6,'Simsboro, Louisiana 71275',23240,28273);
INSERT INTO "django_geo_db_zipcode" VALUES(31632,71276,-6,'Sondheimer, Louisiana 71276',23241,28274);
INSERT INTO "django_geo_db_zipcode" VALUES(31633,71277,-6,'Spearsville, Louisiana 71277',23242,28275);
INSERT INTO "django_geo_db_zipcode" VALUES(31634,71279,-6,'Start, Louisiana 71279',23243,28276);
INSERT INTO "django_geo_db_zipcode" VALUES(31635,71280,-6,'Sterlington, Louisiana 71280',23244,28277);
INSERT INTO "django_geo_db_zipcode" VALUES(31636,71281,-6,'Swartz, Louisiana 71281',23245,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31637,71282,-6,'Tallulah, Louisiana 71282',23246,28278);
INSERT INTO "django_geo_db_zipcode" VALUES(31638,71284,-6,'Tallulah, Louisiana 71284',23246,28247);
INSERT INTO "django_geo_db_zipcode" VALUES(31639,71286,-6,'Transylvania, Louisiana 71286',23247,28279);
INSERT INTO "django_geo_db_zipcode" VALUES(31640,71291,-6,'West Monroe, Louisiana 71291',23248,28280);
INSERT INTO "django_geo_db_zipcode" VALUES(31641,71292,-6,'West Monroe, Louisiana 71292',23248,28281);
INSERT INTO "django_geo_db_zipcode" VALUES(31642,71294,-6,'West Monroe, Louisiana 71294',23248,28231);
INSERT INTO "django_geo_db_zipcode" VALUES(31643,71295,-6,'Winnsboro, Louisiana 71295',23249,28282);
INSERT INTO "django_geo_db_zipcode" VALUES(31644,71301,-6,'Alexandria, Louisiana 71301',23250,28283);
INSERT INTO "django_geo_db_zipcode" VALUES(31645,71302,-6,'Alexandria, Louisiana 71302',23250,28284);
INSERT INTO "django_geo_db_zipcode" VALUES(31646,71303,-6,'Alexandria, Louisiana 71303',23250,28285);
INSERT INTO "django_geo_db_zipcode" VALUES(31647,71306,-6,'Alexandria, Louisiana 71306',23250,28286);
INSERT INTO "django_geo_db_zipcode" VALUES(31648,71307,-6,'Alexandria, Louisiana 71307',23250,28287);
INSERT INTO "django_geo_db_zipcode" VALUES(31649,71309,-6,'Alexandria, Louisiana 71309',23250,28288);
INSERT INTO "django_geo_db_zipcode" VALUES(31650,71315,-6,'Alexandria, Louisiana 71315',23250,28289);
INSERT INTO "django_geo_db_zipcode" VALUES(31651,71316,-6,'Acme, Louisiana 71316',23251,28290);
INSERT INTO "django_geo_db_zipcode" VALUES(31652,71320,-6,'Bordelonville, Louisiana 71320',23252,28291);
INSERT INTO "django_geo_db_zipcode" VALUES(31653,71322,-6,'Bunkie, Louisiana 71322',23253,28292);
INSERT INTO "django_geo_db_zipcode" VALUES(31654,71323,-6,'Center Point, Louisiana 71323',23254,28293);
INSERT INTO "django_geo_db_zipcode" VALUES(31655,71324,-6,'Chase, Louisiana 71324',23255,28245);
INSERT INTO "django_geo_db_zipcode" VALUES(31656,71325,-6,'Cheneyville, Louisiana 71325',23256,28294);
INSERT INTO "django_geo_db_zipcode" VALUES(31657,71326,-6,'Clayton, Louisiana 71326',23257,28295);
INSERT INTO "django_geo_db_zipcode" VALUES(31658,71327,-6,'Cottonport, Louisiana 71327',23258,28296);
INSERT INTO "django_geo_db_zipcode" VALUES(31659,71328,-6,'Deville, Louisiana 71328',23259,28297);
INSERT INTO "django_geo_db_zipcode" VALUES(31660,71329,-6,'Dupont, Louisiana 71329',23260,28298);
INSERT INTO "django_geo_db_zipcode" VALUES(31661,71330,-6,'Echo, Louisiana 71330',23261,28299);
INSERT INTO "django_geo_db_zipcode" VALUES(31662,71331,-6,'Effie, Louisiana 71331',23262,28300);
INSERT INTO "django_geo_db_zipcode" VALUES(31663,71333,-6,'Evergreen, Louisiana 71333',23263,28301);
INSERT INTO "django_geo_db_zipcode" VALUES(31664,71334,-6,'Ferriday, Louisiana 71334',23264,28302);
INSERT INTO "django_geo_db_zipcode" VALUES(31665,71336,-6,'Gilbert, Louisiana 71336',23265,28303);
INSERT INTO "django_geo_db_zipcode" VALUES(31666,71339,-6,'Hamburg, Louisiana 71339',23266,28304);
INSERT INTO "django_geo_db_zipcode" VALUES(31667,71340,-6,'Harrisonburg, Louisiana 71340',23267,28305);
INSERT INTO "django_geo_db_zipcode" VALUES(31668,71341,-6,'Hessmer, Louisiana 71341',23268,28306);
INSERT INTO "django_geo_db_zipcode" VALUES(31669,71342,-6,'Jena, Louisiana 71342',23269,28307);
INSERT INTO "django_geo_db_zipcode" VALUES(31670,71343,-6,'Jonesville, Louisiana 71343',23270,28308);
INSERT INTO "django_geo_db_zipcode" VALUES(31671,71345,-6,'Lebeau, Louisiana 71345',23271,28309);
INSERT INTO "django_geo_db_zipcode" VALUES(31672,71346,-6,'Lecompte, Louisiana 71346',23272,28310);
INSERT INTO "django_geo_db_zipcode" VALUES(31673,71348,-6,'Libuse, Louisiana 71348',23273,28287);
INSERT INTO "django_geo_db_zipcode" VALUES(31674,71350,-6,'Mansura, Louisiana 71350',23274,28311);
INSERT INTO "django_geo_db_zipcode" VALUES(31675,71351,-6,'Marksville, Louisiana 71351',23275,28312);
INSERT INTO "django_geo_db_zipcode" VALUES(31676,71353,-6,'Melville, Louisiana 71353',23276,28313);
INSERT INTO "django_geo_db_zipcode" VALUES(31677,71354,-6,'Monterey, Louisiana 71354',23277,28314);
INSERT INTO "django_geo_db_zipcode" VALUES(31678,71355,-6,'Moreauville, Louisiana 71355',23278,28315);
INSERT INTO "django_geo_db_zipcode" VALUES(31679,71356,-6,'Morrow, Louisiana 71356',23279,28316);
INSERT INTO "django_geo_db_zipcode" VALUES(31680,71357,-6,'Newellton, Louisiana 71357',23280,28317);
INSERT INTO "django_geo_db_zipcode" VALUES(31681,71358,-6,'Palmetto, Louisiana 71358',23281,28318);
INSERT INTO "django_geo_db_zipcode" VALUES(31682,71359,-6,'Pineville, Louisiana 71359',23282,28287);
INSERT INTO "django_geo_db_zipcode" VALUES(31683,71360,-6,'Pineville, Louisiana 71360',23282,28319);
INSERT INTO "django_geo_db_zipcode" VALUES(31684,71361,-6,'Pineville, Louisiana 71361',23282,28320);
INSERT INTO "django_geo_db_zipcode" VALUES(31685,71362,-6,'Plaucheville, Louisiana 71362',23283,28321);
INSERT INTO "django_geo_db_zipcode" VALUES(31686,71363,-6,'Rhinehart, Louisiana 71363',23284,28322);
INSERT INTO "django_geo_db_zipcode" VALUES(31687,71365,-6,'Ruby, Louisiana 71365',23285,28287);
INSERT INTO "django_geo_db_zipcode" VALUES(31688,71366,-6,'Saint Joseph, Louisiana 71366',23286,28323);
INSERT INTO "django_geo_db_zipcode" VALUES(31689,71367,-6,'Saint Landry, Louisiana 71367',23287,28324);
INSERT INTO "django_geo_db_zipcode" VALUES(31690,71368,-6,'Sicily Island, Louisiana 71368',23288,28325);
INSERT INTO "django_geo_db_zipcode" VALUES(31691,71369,-6,'Simmesport, Louisiana 71369',23289,28326);
INSERT INTO "django_geo_db_zipcode" VALUES(31692,71371,-6,'Trout, Louisiana 71371',23290,28327);
INSERT INTO "django_geo_db_zipcode" VALUES(31693,71373,-6,'Vidalia, Louisiana 71373',23291,28328);
INSERT INTO "django_geo_db_zipcode" VALUES(31694,71375,-6,'Waterproof, Louisiana 71375',23292,28329);
INSERT INTO "django_geo_db_zipcode" VALUES(31695,71377,-6,'Wildsville, Louisiana 71377',23293,28330);
INSERT INTO "django_geo_db_zipcode" VALUES(31696,71378,-6,'Wisner, Louisiana 71378',23294,28331);
INSERT INTO "django_geo_db_zipcode" VALUES(31697,71401,-6,'Aimwell, Louisiana 71401',23295,28332);
INSERT INTO "django_geo_db_zipcode" VALUES(31698,71403,-6,'Anacoco, Louisiana 71403',23296,28333);
INSERT INTO "django_geo_db_zipcode" VALUES(31699,71404,-6,'Atlanta, Louisiana 71404',23297,28334);
INSERT INTO "django_geo_db_zipcode" VALUES(31700,71405,-6,'Ball, Louisiana 71405',23298,28335);
INSERT INTO "django_geo_db_zipcode" VALUES(31701,71406,-6,'Belmont, Louisiana 71406',23299,28336);
INSERT INTO "django_geo_db_zipcode" VALUES(31702,71407,-6,'Bentley, Louisiana 71407',23300,28337);
INSERT INTO "django_geo_db_zipcode" VALUES(31703,71409,-6,'Boyce, Louisiana 71409',23301,28338);
INSERT INTO "django_geo_db_zipcode" VALUES(31704,71410,-6,'Calvin, Louisiana 71410',23302,28339);
INSERT INTO "django_geo_db_zipcode" VALUES(31705,71411,-6,'Campti, Louisiana 71411',23303,28340);
INSERT INTO "django_geo_db_zipcode" VALUES(31706,71414,-6,'Clarence, Louisiana 71414',23304,28341);
INSERT INTO "django_geo_db_zipcode" VALUES(31707,71415,-6,'Clarks, Louisiana 71415',23305,28342);
INSERT INTO "django_geo_db_zipcode" VALUES(31708,71416,-6,'Cloutierville, Louisiana 71416',23306,28343);
INSERT INTO "django_geo_db_zipcode" VALUES(31709,71417,-6,'Colfax, Louisiana 71417',23307,28344);
INSERT INTO "django_geo_db_zipcode" VALUES(31710,71418,-6,'Columbia, Louisiana 71418',23308,28345);
INSERT INTO "django_geo_db_zipcode" VALUES(31711,71419,-6,'Converse, Louisiana 71419',23309,28346);
INSERT INTO "django_geo_db_zipcode" VALUES(31712,71422,-6,'Dodson, Louisiana 71422',23310,28347);
INSERT INTO "django_geo_db_zipcode" VALUES(31713,71423,-6,'Dry Prong, Louisiana 71423',23311,28348);
INSERT INTO "django_geo_db_zipcode" VALUES(31714,71424,-6,'Elmer, Louisiana 71424',23312,28349);
INSERT INTO "django_geo_db_zipcode" VALUES(31715,71425,-6,'Enterprise, Louisiana 71425',23313,28350);
INSERT INTO "django_geo_db_zipcode" VALUES(31716,71426,-6,'Fisher, Louisiana 71426',23314,28351);
INSERT INTO "django_geo_db_zipcode" VALUES(31717,71427,-6,'Flatwoods, Louisiana 71427',23315,28352);
INSERT INTO "django_geo_db_zipcode" VALUES(31718,71428,-6,'Flora, Louisiana 71428',23316,28353);
INSERT INTO "django_geo_db_zipcode" VALUES(31719,71429,-6,'Florien, Louisiana 71429',23317,28354);
INSERT INTO "django_geo_db_zipcode" VALUES(31720,71430,-6,'Forest Hill, Louisiana 71430',23318,28355);
INSERT INTO "django_geo_db_zipcode" VALUES(31721,71431,-6,'Gardner, Louisiana 71431',23319,28356);
INSERT INTO "django_geo_db_zipcode" VALUES(31722,71432,-6,'Georgetown, Louisiana 71432',23320,28357);
INSERT INTO "django_geo_db_zipcode" VALUES(31723,71433,-6,'Glenmora, Louisiana 71433',23321,28358);
INSERT INTO "django_geo_db_zipcode" VALUES(31724,71434,-6,'Gorum, Louisiana 71434',23322,28359);
INSERT INTO "django_geo_db_zipcode" VALUES(31725,71435,-6,'Grayson, Louisiana 71435',23323,28360);
INSERT INTO "django_geo_db_zipcode" VALUES(31726,71436,-6,'McNary, Louisiana 71436',23324,28361);
INSERT INTO "django_geo_db_zipcode" VALUES(31727,71438,-6,'Hineston, Louisiana 71438',23325,28362);
INSERT INTO "django_geo_db_zipcode" VALUES(31728,71439,-6,'Hornbeck, Louisiana 71439',23326,28363);
INSERT INTO "django_geo_db_zipcode" VALUES(31729,71440,-6,'Joyce, Louisiana 71440',23327,28364);
INSERT INTO "django_geo_db_zipcode" VALUES(31730,71441,-6,'Kelly, Louisiana 71441',23328,28365);
INSERT INTO "django_geo_db_zipcode" VALUES(31731,71443,-6,'Kurthwood, Louisiana 71443',23329,28366);
INSERT INTO "django_geo_db_zipcode" VALUES(31732,71444,-6,'Lacamp, Louisiana 71444',23330,28367);
INSERT INTO "django_geo_db_zipcode" VALUES(31733,71446,-6,'Leesville, Louisiana 71446',23331,28368);
INSERT INTO "django_geo_db_zipcode" VALUES(31734,71447,-6,'Lena, Louisiana 71447',23332,28369);
INSERT INTO "django_geo_db_zipcode" VALUES(31735,71448,-6,'Longleaf, Louisiana 71448',23333,28287);
INSERT INTO "django_geo_db_zipcode" VALUES(31736,71449,-6,'Many, Louisiana 71449',23334,28370);
INSERT INTO "django_geo_db_zipcode" VALUES(31737,71450,-6,'Marthaville, Louisiana 71450',23335,28371);
INSERT INTO "django_geo_db_zipcode" VALUES(31738,71452,-6,'Melrose, Louisiana 71452',23336,28372);
INSERT INTO "django_geo_db_zipcode" VALUES(31739,71454,-6,'Montgomery, Louisiana 71454',23337,28373);
INSERT INTO "django_geo_db_zipcode" VALUES(31740,71455,-6,'Mora, Louisiana 71455',23338,28374);
INSERT INTO "django_geo_db_zipcode" VALUES(31741,71456,-6,'Natchez, Louisiana 71456',23339,28375);
INSERT INTO "django_geo_db_zipcode" VALUES(31742,71457,-6,'Natchitoches, Louisiana 71457',23340,28376);
INSERT INTO "django_geo_db_zipcode" VALUES(31743,71458,-6,'Natchitoches, Louisiana 71458',23340,28377);
INSERT INTO "django_geo_db_zipcode" VALUES(31744,71459,-6,'Leesville, Louisiana 71459',23331,28378);
INSERT INTO "django_geo_db_zipcode" VALUES(31745,71460,-6,'Negreet, Louisiana 71460',23341,28379);
INSERT INTO "django_geo_db_zipcode" VALUES(31746,71461,-6,'Newllano, Louisiana 71461',23342,28380);
INSERT INTO "django_geo_db_zipcode" VALUES(31747,71462,-6,'Noble, Louisiana 71462',23343,28381);
INSERT INTO "django_geo_db_zipcode" VALUES(31748,71463,-6,'Oakdale, Louisiana 71463',23344,28382);
INSERT INTO "django_geo_db_zipcode" VALUES(31749,71465,-6,'Olla, Louisiana 71465',23345,28383);
INSERT INTO "django_geo_db_zipcode" VALUES(31750,71466,-6,'Otis, Louisiana 71466',23346,28384);
INSERT INTO "django_geo_db_zipcode" VALUES(31751,71467,-6,'Pollock, Louisiana 71467',23347,28385);
INSERT INTO "django_geo_db_zipcode" VALUES(31752,71468,-6,'Provencal, Louisiana 71468',23348,28386);
INSERT INTO "django_geo_db_zipcode" VALUES(31753,71469,-6,'Robeline, Louisiana 71469',23349,28387);
INSERT INTO "django_geo_db_zipcode" VALUES(31754,71471,-6,'Saint Maurice, Louisiana 71471',23350,28388);
INSERT INTO "django_geo_db_zipcode" VALUES(31755,71472,-6,'Sieper, Louisiana 71472',23351,28389);
INSERT INTO "django_geo_db_zipcode" VALUES(31756,71473,-6,'Sikes, Louisiana 71473',23352,28390);
INSERT INTO "django_geo_db_zipcode" VALUES(31757,71474,-6,'Simpson, Louisiana 71474',23353,28391);
INSERT INTO "django_geo_db_zipcode" VALUES(31758,71475,-6,'Slagle, Louisiana 71475',23354,28029);
INSERT INTO "django_geo_db_zipcode" VALUES(31759,71477,-6,'Tioga, Louisiana 71477',23355,28392);
INSERT INTO "django_geo_db_zipcode" VALUES(31760,71479,-6,'Tullos, Louisiana 71479',23356,28393);
INSERT INTO "django_geo_db_zipcode" VALUES(31761,71480,-6,'Urania, Louisiana 71480',23357,28394);
INSERT INTO "django_geo_db_zipcode" VALUES(31762,71481,-6,'Verda, Louisiana 71481',23358,28395);
INSERT INTO "django_geo_db_zipcode" VALUES(31763,71483,-6,'Winnfield, Louisiana 71483',23359,28396);
INSERT INTO "django_geo_db_zipcode" VALUES(31764,71485,-6,'Woodworth, Louisiana 71485',23360,28397);
INSERT INTO "django_geo_db_zipcode" VALUES(31765,71486,-6,'Zwolle, Louisiana 71486',23361,28398);
INSERT INTO "django_geo_db_zipcode" VALUES(31766,71496,-6,'Leesville, Louisiana 71496',23331,28399);
INSERT INTO "django_geo_db_zipcode" VALUES(31767,71497,-6,'Natchitoches, Louisiana 71497',23340,28377);
INSERT INTO "django_geo_db_zipcode" VALUES(31768,71545,-6,'Montgomery, Louisiana 71545',23337,28400);
INSERT INTO "django_geo_db_zipcode" VALUES(31769,71601,-6,'Pine Bluff, Arkansas 71601',23362,28401);
INSERT INTO "django_geo_db_zipcode" VALUES(31770,71602,-6,'White Hall, Arkansas 71602',23363,28402);
INSERT INTO "django_geo_db_zipcode" VALUES(31771,71603,-6,'Pine Bluff, Arkansas 71603',23362,28403);
INSERT INTO "django_geo_db_zipcode" VALUES(31772,71611,-6,'Pine Bluff, Arkansas 71611',23362,28404);
INSERT INTO "django_geo_db_zipcode" VALUES(31773,71612,-6,'White Hall, Arkansas 71612',23363,28405);
INSERT INTO "django_geo_db_zipcode" VALUES(31774,71613,-6,'Pine Bluff, Arkansas 71613',23362,28406);
INSERT INTO "django_geo_db_zipcode" VALUES(31775,71630,-6,'Arkansas City, Arkansas 71630',23364,28407);
INSERT INTO "django_geo_db_zipcode" VALUES(31776,71631,-6,'Banks, Arkansas 71631',23365,28408);
INSERT INTO "django_geo_db_zipcode" VALUES(31777,71635,-6,'Crossett, Arkansas 71635',23366,28409);
INSERT INTO "django_geo_db_zipcode" VALUES(31778,71638,-6,'Dermott, Arkansas 71638',23367,28410);
INSERT INTO "django_geo_db_zipcode" VALUES(31779,71639,-6,'Dumas, Arkansas 71639',23368,28411);
INSERT INTO "django_geo_db_zipcode" VALUES(31780,71640,-6,'Eudora, Arkansas 71640',23369,28412);
INSERT INTO "django_geo_db_zipcode" VALUES(31781,71642,-6,'Fountain Hill, Arkansas 71642',23370,28413);
INSERT INTO "django_geo_db_zipcode" VALUES(31782,71643,-6,'Gould, Arkansas 71643',23371,28414);
INSERT INTO "django_geo_db_zipcode" VALUES(31783,71644,-6,'Grady, Arkansas 71644',23372,28415);
INSERT INTO "django_geo_db_zipcode" VALUES(31784,71646,-6,'Hamburg, Arkansas 71646',23373,28416);
INSERT INTO "django_geo_db_zipcode" VALUES(31785,71647,-6,'Hermitage, Arkansas 71647',23374,28417);
INSERT INTO "django_geo_db_zipcode" VALUES(31786,71649,-6,'Jennie, Arkansas 71649',23375,28418);
INSERT INTO "django_geo_db_zipcode" VALUES(31787,71650,-6,'Jerome, Arkansas 71650',23376,28419);
INSERT INTO "django_geo_db_zipcode" VALUES(31788,71651,-6,'Jersey, Arkansas 71651',23377,28420);
INSERT INTO "django_geo_db_zipcode" VALUES(31789,71652,-6,'Kingsland, Arkansas 71652',23378,28421);
INSERT INTO "django_geo_db_zipcode" VALUES(31790,71653,-6,'Lake Village, Arkansas 71653',23379,28422);
INSERT INTO "django_geo_db_zipcode" VALUES(31791,71654,-6,'McGehee, Arkansas 71654',23380,28423);
INSERT INTO "django_geo_db_zipcode" VALUES(31792,71655,-6,'Monticello, Arkansas 71655',23381,28424);
INSERT INTO "django_geo_db_zipcode" VALUES(31793,71656,-6,'Monticello, Arkansas 71656',23381,28425);
INSERT INTO "django_geo_db_zipcode" VALUES(31794,71657,-6,'Monticello, Arkansas 71657',23381,28419);
INSERT INTO "django_geo_db_zipcode" VALUES(31795,71658,-6,'Montrose, Arkansas 71658',23382,28426);
INSERT INTO "django_geo_db_zipcode" VALUES(31796,71659,-6,'Moscow, Arkansas 71659',23383,28427);
INSERT INTO "django_geo_db_zipcode" VALUES(31797,71660,-6,'New Edinburg, Arkansas 71660',23384,28428);
INSERT INTO "django_geo_db_zipcode" VALUES(31798,71661,-6,'Parkdale, Arkansas 71661',23385,28429);
INSERT INTO "django_geo_db_zipcode" VALUES(31799,71662,-6,'Pickens, Arkansas 71662',23386,28430);
INSERT INTO "django_geo_db_zipcode" VALUES(31800,71663,-6,'Portland, Arkansas 71663',23387,28431);
INSERT INTO "django_geo_db_zipcode" VALUES(31801,71665,-6,'Rison, Arkansas 71665',23388,28432);
INSERT INTO "django_geo_db_zipcode" VALUES(31802,71666,-6,'McGehee, Arkansas 71666',23380,28433);
INSERT INTO "django_geo_db_zipcode" VALUES(31803,71667,-6,'Star City, Arkansas 71667',23389,28434);
INSERT INTO "django_geo_db_zipcode" VALUES(31804,71670,-6,'Tillar, Arkansas 71670',23390,28435);
INSERT INTO "django_geo_db_zipcode" VALUES(31805,71671,-6,'Warren, Arkansas 71671',23391,28436);
INSERT INTO "django_geo_db_zipcode" VALUES(31806,71674,-6,'Watson, Arkansas 71674',23392,28437);
INSERT INTO "django_geo_db_zipcode" VALUES(31807,71675,-6,'Wilmar, Arkansas 71675',23393,28438);
INSERT INTO "django_geo_db_zipcode" VALUES(31808,71676,-6,'Wilmot, Arkansas 71676',23394,28439);
INSERT INTO "django_geo_db_zipcode" VALUES(31809,71677,-6,'Winchester, Arkansas 71677',23395,28440);
INSERT INTO "django_geo_db_zipcode" VALUES(31810,71678,-6,'Yorktown, Arkansas 71678',23396,28441);
INSERT INTO "django_geo_db_zipcode" VALUES(31811,71691,-6,'Warren, Arkansas 71691',23391,28442);
INSERT INTO "django_geo_db_zipcode" VALUES(31812,71701,-6,'Camden, Arkansas 71701',23397,28443);
INSERT INTO "django_geo_db_zipcode" VALUES(31813,71711,-6,'Camden, Arkansas 71711',23397,28444);
INSERT INTO "django_geo_db_zipcode" VALUES(31814,71720,-6,'Bearden, Arkansas 71720',23398,28445);
INSERT INTO "django_geo_db_zipcode" VALUES(31815,71721,-6,'Beirne, Arkansas 71721',23399,28446);
INSERT INTO "django_geo_db_zipcode" VALUES(31816,71722,-6,'Bluff City, Arkansas 71722',23400,28447);
INSERT INTO "django_geo_db_zipcode" VALUES(31817,71724,-6,'Calion, Arkansas 71724',23401,28448);
INSERT INTO "django_geo_db_zipcode" VALUES(31818,71725,-6,'Carthage, Arkansas 71725',23402,28449);
INSERT INTO "django_geo_db_zipcode" VALUES(31819,71726,-6,'Chidester, Arkansas 71726',23403,28450);
INSERT INTO "django_geo_db_zipcode" VALUES(31820,71728,-6,'Curtis, Arkansas 71728',23404,28451);
INSERT INTO "django_geo_db_zipcode" VALUES(31821,71730,-6,'El Dorado, Arkansas 71730',23405,28452);
INSERT INTO "django_geo_db_zipcode" VALUES(31822,71731,-6,'El Dorado, Arkansas 71731',23405,28453);
INSERT INTO "django_geo_db_zipcode" VALUES(31823,71740,-6,'Emerson, Arkansas 71740',23406,28454);
INSERT INTO "django_geo_db_zipcode" VALUES(31824,71742,-6,'Fordyce, Arkansas 71742',23407,28455);
INSERT INTO "django_geo_db_zipcode" VALUES(31825,71743,-6,'Gurdon, Arkansas 71743',23408,28456);
INSERT INTO "django_geo_db_zipcode" VALUES(31826,71744,-6,'Hampton, Arkansas 71744',23409,28457);
INSERT INTO "django_geo_db_zipcode" VALUES(31827,71745,-6,'Harrell, Arkansas 71745',23410,28458);
INSERT INTO "django_geo_db_zipcode" VALUES(31828,71747,-6,'Huttig, Arkansas 71747',23411,28459);
INSERT INTO "django_geo_db_zipcode" VALUES(31829,71748,-6,'Ivan, Arkansas 71748',23412,28460);
INSERT INTO "django_geo_db_zipcode" VALUES(31830,71749,-6,'Junction City, Arkansas 71749',23413,28461);
INSERT INTO "django_geo_db_zipcode" VALUES(31831,71750,-6,'Lawson, Arkansas 71750',23414,28453);
INSERT INTO "django_geo_db_zipcode" VALUES(31832,71751,-6,'Louann, Arkansas 71751',23415,28462);
INSERT INTO "django_geo_db_zipcode" VALUES(31833,71752,-6,'McNeil, Arkansas 71752',23416,28463);
INSERT INTO "django_geo_db_zipcode" VALUES(31834,71753,-6,'Magnolia, Arkansas 71753',23417,28464);
INSERT INTO "django_geo_db_zipcode" VALUES(31835,71754,-6,'Magnolia, Arkansas 71754',23417,28465);
INSERT INTO "django_geo_db_zipcode" VALUES(31836,71758,-6,'Mount Holly, Arkansas 71758',23418,28466);
INSERT INTO "django_geo_db_zipcode" VALUES(31837,71759,-6,'Norphlet, Arkansas 71759',23419,28467);
INSERT INTO "django_geo_db_zipcode" VALUES(31838,71762,-6,'Smackover, Arkansas 71762',23420,28468);
INSERT INTO "django_geo_db_zipcode" VALUES(31839,71763,-6,'Sparkman, Arkansas 71763',23421,28469);
INSERT INTO "django_geo_db_zipcode" VALUES(31840,71764,-6,'Stephens, Arkansas 71764',23422,28470);
INSERT INTO "django_geo_db_zipcode" VALUES(31841,71765,-6,'Strong, Arkansas 71765',23423,28471);
INSERT INTO "django_geo_db_zipcode" VALUES(31842,71766,-6,'Thornton, Arkansas 71766',23424,28472);
INSERT INTO "django_geo_db_zipcode" VALUES(31843,71767,-6,'Hampton, Arkansas 71767',23409,28473);
INSERT INTO "django_geo_db_zipcode" VALUES(31844,71768,-6,'Urbana, Arkansas 71768',23425,28453);
INSERT INTO "django_geo_db_zipcode" VALUES(31845,71769,-6,'Village, Arkansas 71769',23426,28474);
INSERT INTO "django_geo_db_zipcode" VALUES(31846,71770,-6,'Waldo, Arkansas 71770',23427,28475);
INSERT INTO "django_geo_db_zipcode" VALUES(31847,71772,-6,'Whelen Springs, Arkansas 71772',23428,28476);
INSERT INTO "django_geo_db_zipcode" VALUES(31848,71801,-6,'Hope, Arkansas 71801',23429,28477);
INSERT INTO "django_geo_db_zipcode" VALUES(31849,71802,-6,'Hope, Arkansas 71802',23429,28478);
INSERT INTO "django_geo_db_zipcode" VALUES(31850,71820,-6,'Alleene, Arkansas 71820',23430,28479);
INSERT INTO "django_geo_db_zipcode" VALUES(31851,71822,-6,'Ashdown, Arkansas 71822',23431,28480);
INSERT INTO "django_geo_db_zipcode" VALUES(31852,71823,-6,'Ben Lomond, Arkansas 71823',23432,28481);
INSERT INTO "django_geo_db_zipcode" VALUES(31853,71825,-6,'Blevins, Arkansas 71825',23433,28482);
INSERT INTO "django_geo_db_zipcode" VALUES(31854,71826,-6,'Bradley, Arkansas 71826',23434,28483);
INSERT INTO "django_geo_db_zipcode" VALUES(31855,71827,-6,'Buckner, Arkansas 71827',23435,28484);
INSERT INTO "django_geo_db_zipcode" VALUES(31856,71828,-6,'Cale, Arkansas 71828',23436,28485);
INSERT INTO "django_geo_db_zipcode" VALUES(31857,71831,-6,'Columbus, Arkansas 71831',23437,28486);
INSERT INTO "django_geo_db_zipcode" VALUES(31858,71832,-6,'De Queen, Arkansas 71832',23438,28487);
INSERT INTO "django_geo_db_zipcode" VALUES(31859,71833,-6,'Dierks, Arkansas 71833',23439,28488);
INSERT INTO "django_geo_db_zipcode" VALUES(31860,71834,-6,'Doddridge, Arkansas 71834',23440,28489);
INSERT INTO "django_geo_db_zipcode" VALUES(31861,71835,-6,'Emmet, Arkansas 71835',23441,28490);
INSERT INTO "django_geo_db_zipcode" VALUES(31862,71836,-6,'Foreman, Arkansas 71836',23442,28491);
INSERT INTO "django_geo_db_zipcode" VALUES(31863,71837,-6,'Fouke, Arkansas 71837',23443,28492);
INSERT INTO "django_geo_db_zipcode" VALUES(31864,71838,-6,'Fulton, Arkansas 71838',23444,28493);
INSERT INTO "django_geo_db_zipcode" VALUES(31865,71839,-6,'Garland City, Arkansas 71839',23445,28494);
INSERT INTO "django_geo_db_zipcode" VALUES(31866,71840,-6,'Genoa, Arkansas 71840',23446,28495);
INSERT INTO "django_geo_db_zipcode" VALUES(31867,71841,-6,'Gillham, Arkansas 71841',23447,28496);
INSERT INTO "django_geo_db_zipcode" VALUES(31868,71842,-6,'Horatio, Arkansas 71842',23448,28497);
INSERT INTO "django_geo_db_zipcode" VALUES(31869,71844,-6,'Laneburg, Arkansas 71844',23449,28485);
INSERT INTO "django_geo_db_zipcode" VALUES(31870,71845,-6,'Lewisville, Arkansas 71845',23450,28498);
INSERT INTO "django_geo_db_zipcode" VALUES(31871,71846,-6,'Lockesburg, Arkansas 71846',23451,28499);
INSERT INTO "django_geo_db_zipcode" VALUES(31872,71847,-6,'McCaskill, Arkansas 71847',23452,28500);
INSERT INTO "django_geo_db_zipcode" VALUES(31873,71851,-6,'Mineral Springs, Arkansas 71851',23453,28501);
INSERT INTO "django_geo_db_zipcode" VALUES(31874,71852,-6,'Nashville, Arkansas 71852',23454,28502);
INSERT INTO "django_geo_db_zipcode" VALUES(31875,71853,-6,'Ogden, Arkansas 71853',23455,28503);
INSERT INTO "django_geo_db_zipcode" VALUES(31876,71854,-6,'Texarkana, Arkansas 71854',23456,28504);
INSERT INTO "django_geo_db_zipcode" VALUES(31877,71855,-6,'Ozan, Arkansas 71855',23457,28505);
INSERT INTO "django_geo_db_zipcode" VALUES(31878,71857,-6,'Prescott, Arkansas 71857',23458,28506);
INSERT INTO "django_geo_db_zipcode" VALUES(31879,71858,-6,'Rosston, Arkansas 71858',23459,28507);
INSERT INTO "django_geo_db_zipcode" VALUES(31880,71859,-6,'Saratoga, Arkansas 71859',23460,28508);
INSERT INTO "django_geo_db_zipcode" VALUES(31881,71860,-6,'Stamps, Arkansas 71860',23461,28509);
INSERT INTO "django_geo_db_zipcode" VALUES(31882,71861,-6,'Taylor, Arkansas 71861',23462,28510);
INSERT INTO "django_geo_db_zipcode" VALUES(31883,71862,-6,'Washington, Arkansas 71862',23463,28511);
INSERT INTO "django_geo_db_zipcode" VALUES(31884,71864,-6,'Willisville, Arkansas 71864',23464,28485);
INSERT INTO "django_geo_db_zipcode" VALUES(31885,71865,-6,'Wilton, Arkansas 71865',23465,28512);
INSERT INTO "django_geo_db_zipcode" VALUES(31886,71866,-6,'Winthrop, Arkansas 71866',23466,28513);
INSERT INTO "django_geo_db_zipcode" VALUES(31887,71901,-6,'Hot Springs National Park, Arkansas 71901',23467,28514);
INSERT INTO "django_geo_db_zipcode" VALUES(31888,71902,-6,'Hot Springs National Park, Arkansas 71902',23467,28515);
INSERT INTO "django_geo_db_zipcode" VALUES(31889,71903,-6,'Hot Springs National Park, Arkansas 71903',23467,28515);
INSERT INTO "django_geo_db_zipcode" VALUES(31890,71907,-6,'Hot Springs, Arkansas 71907',23468,28516);
INSERT INTO "django_geo_db_zipcode" VALUES(31891,71909,-6,'Hot Springs Village, Arkansas 71909',23469,28517);
INSERT INTO "django_geo_db_zipcode" VALUES(31892,71910,-6,'Hot Springs Village, Arkansas 71910',23469,28515);
INSERT INTO "django_geo_db_zipcode" VALUES(31893,71913,-6,'Hot Springs National Park, Arkansas 71913',23467,28518);
INSERT INTO "django_geo_db_zipcode" VALUES(31894,71914,-6,'Hot Springs National Park, Arkansas 71914',23467,28519);
INSERT INTO "django_geo_db_zipcode" VALUES(31895,71920,-6,'Alpine, Arkansas 71920',23470,28446);
INSERT INTO "django_geo_db_zipcode" VALUES(31896,71921,-6,'Amity, Arkansas 71921',23471,28520);
INSERT INTO "django_geo_db_zipcode" VALUES(31897,71922,-6,'Antoine, Arkansas 71922',23472,28521);
INSERT INTO "django_geo_db_zipcode" VALUES(31898,71923,-6,'Arkadelphia, Arkansas 71923',23473,28522);
INSERT INTO "django_geo_db_zipcode" VALUES(31899,71929,-6,'Bismarck, Arkansas 71929',23474,28523);
INSERT INTO "django_geo_db_zipcode" VALUES(31900,71932,-6,'Board Camp, Arkansas 71932',23475,28524);
INSERT INTO "django_geo_db_zipcode" VALUES(31901,71933,-6,'Bonnerdale, Arkansas 71933',23476,28525);
INSERT INTO "django_geo_db_zipcode" VALUES(31902,71935,-6,'Caddo Gap, Arkansas 71935',23477,28526);
INSERT INTO "django_geo_db_zipcode" VALUES(31903,71937,-6,'Cove, Arkansas 71937',23478,28527);
INSERT INTO "django_geo_db_zipcode" VALUES(31904,71940,-6,'Delight, Arkansas 71940',23479,28528);
INSERT INTO "django_geo_db_zipcode" VALUES(31905,71941,-6,'Donaldson, Arkansas 71941',23480,28529);
INSERT INTO "django_geo_db_zipcode" VALUES(31906,71942,-6,'Friendship, Arkansas 71942',23481,28530);
INSERT INTO "django_geo_db_zipcode" VALUES(31907,71943,-6,'Glenwood, Arkansas 71943',23482,28531);
INSERT INTO "django_geo_db_zipcode" VALUES(31908,71944,-6,'Grannis, Arkansas 71944',23483,28532);
INSERT INTO "django_geo_db_zipcode" VALUES(31909,71945,-6,'Hatfield, Arkansas 71945',23484,28533);
INSERT INTO "django_geo_db_zipcode" VALUES(31910,71946,-6,'Hatton, Arkansas 71946',23485,28534);
INSERT INTO "django_geo_db_zipcode" VALUES(31911,71949,-6,'Jessieville, Arkansas 71949',23486,28535);
INSERT INTO "django_geo_db_zipcode" VALUES(31912,71950,-6,'Kirby, Arkansas 71950',23487,28536);
INSERT INTO "django_geo_db_zipcode" VALUES(31913,71951,-6,'Hot Springs National Park, Arkansas 71951',23467,28515);
INSERT INTO "django_geo_db_zipcode" VALUES(31914,71952,-6,'Langley, Arkansas 71952',23488,28537);
INSERT INTO "django_geo_db_zipcode" VALUES(31915,71953,-6,'Mena, Arkansas 71953',23489,28538);
INSERT INTO "django_geo_db_zipcode" VALUES(31916,71956,-6,'Mountain Pine, Arkansas 71956',23490,28539);
INSERT INTO "django_geo_db_zipcode" VALUES(31917,71957,-6,'Mount Ida, Arkansas 71957',23491,28540);
INSERT INTO "django_geo_db_zipcode" VALUES(31918,71958,-6,'Murfreesboro, Arkansas 71958',23492,28541);
INSERT INTO "django_geo_db_zipcode" VALUES(31919,71959,-6,'Newhope, Arkansas 71959',23493,28542);
INSERT INTO "django_geo_db_zipcode" VALUES(31920,71960,-6,'Norman, Arkansas 71960',23494,28543);
INSERT INTO "django_geo_db_zipcode" VALUES(31921,71961,-6,'Oden, Arkansas 71961',23495,28544);
INSERT INTO "django_geo_db_zipcode" VALUES(31922,71962,-6,'Okolona, Arkansas 71962',23496,28545);
INSERT INTO "django_geo_db_zipcode" VALUES(31923,71964,-6,'Pearcy, Arkansas 71964',23497,28546);
INSERT INTO "django_geo_db_zipcode" VALUES(31924,71965,-6,'Pencil Bluff, Arkansas 71965',23498,28547);
INSERT INTO "django_geo_db_zipcode" VALUES(31925,71966,-6,'Oden, Arkansas 71966',23495,28548);
INSERT INTO "django_geo_db_zipcode" VALUES(31926,71968,-6,'Royal, Arkansas 71968',23499,28549);
INSERT INTO "django_geo_db_zipcode" VALUES(31927,71969,-6,'Sims, Arkansas 71969',23500,28550);
INSERT INTO "django_geo_db_zipcode" VALUES(31928,71970,-6,'Story, Arkansas 71970',23501,28551);
INSERT INTO "django_geo_db_zipcode" VALUES(31929,71971,-6,'Umpire, Arkansas 71971',23502,28552);
INSERT INTO "django_geo_db_zipcode" VALUES(31930,71972,-6,'Vandervoort, Arkansas 71972',23503,28553);
INSERT INTO "django_geo_db_zipcode" VALUES(31931,71973,-6,'Wickes, Arkansas 71973',23504,28554);
INSERT INTO "django_geo_db_zipcode" VALUES(31932,71998,-6,'Arkadelphia, Arkansas 71998',23473,28446);
INSERT INTO "django_geo_db_zipcode" VALUES(31933,71999,-6,'Arkadelphia, Arkansas 71999',23473,28446);
INSERT INTO "django_geo_db_zipcode" VALUES(31934,72001,-6,'Adona, Arkansas 72001',23505,28555);
INSERT INTO "django_geo_db_zipcode" VALUES(31935,72002,-6,'Alexander, Arkansas 72002',23506,28556);
INSERT INTO "django_geo_db_zipcode" VALUES(31936,72003,-6,'Almyra, Arkansas 72003',23507,28557);
INSERT INTO "django_geo_db_zipcode" VALUES(31937,72004,-6,'Altheimer, Arkansas 72004',23508,28558);
INSERT INTO "django_geo_db_zipcode" VALUES(31938,72005,-6,'Amagon, Arkansas 72005',23509,28559);
INSERT INTO "django_geo_db_zipcode" VALUES(31939,72006,-6,'Augusta, Arkansas 72006',23510,28560);
INSERT INTO "django_geo_db_zipcode" VALUES(31940,72007,-6,'Austin, Arkansas 72007',23511,28561);
INSERT INTO "django_geo_db_zipcode" VALUES(31941,72010,-6,'Bald Knob, Arkansas 72010',23512,28562);
INSERT INTO "django_geo_db_zipcode" VALUES(31942,72011,-6,'Bauxite, Arkansas 72011',23513,28563);
INSERT INTO "django_geo_db_zipcode" VALUES(31943,72012,-6,'Beebe, Arkansas 72012',23514,28564);
INSERT INTO "django_geo_db_zipcode" VALUES(31944,72013,-6,'Bee Branch, Arkansas 72013',23515,28565);
INSERT INTO "django_geo_db_zipcode" VALUES(31945,72014,-6,'Beedeville, Arkansas 72014',23516,28566);
INSERT INTO "django_geo_db_zipcode" VALUES(31946,72015,-6,'Benton, Arkansas 72015',23517,28567);
INSERT INTO "django_geo_db_zipcode" VALUES(31947,72016,-6,'Bigelow, Arkansas 72016',23518,28568);
INSERT INTO "django_geo_db_zipcode" VALUES(31948,72017,-6,'Biscoe, Arkansas 72017',23519,28569);
INSERT INTO "django_geo_db_zipcode" VALUES(31949,72018,-6,'Benton, Arkansas 72018',23517,28570);
INSERT INTO "django_geo_db_zipcode" VALUES(31950,72019,-6,'North Little Rock, Arkansas 72019',23520,28571);
INSERT INTO "django_geo_db_zipcode" VALUES(31951,72020,-6,'Bradford, Arkansas 72020',23521,28572);
INSERT INTO "django_geo_db_zipcode" VALUES(31952,72021,-6,'Brinkley, Arkansas 72021',23522,28573);
INSERT INTO "django_geo_db_zipcode" VALUES(31953,72022,-6,'Bryant, Arkansas 72022',23523,28574);
INSERT INTO "django_geo_db_zipcode" VALUES(31954,72023,-6,'Cabot, Arkansas 72023',23524,28575);
INSERT INTO "django_geo_db_zipcode" VALUES(31955,72024,-6,'Carlisle, Arkansas 72024',23525,28576);
INSERT INTO "django_geo_db_zipcode" VALUES(31956,72025,-6,'Casa, Arkansas 72025',23526,28577);
INSERT INTO "django_geo_db_zipcode" VALUES(31957,72026,-6,'Casscoe, Arkansas 72026',23527,28578);
INSERT INTO "django_geo_db_zipcode" VALUES(31958,72027,-6,'Center Ridge, Arkansas 72027',23528,28579);
INSERT INTO "django_geo_db_zipcode" VALUES(31959,72028,-6,'Choctaw, Arkansas 72028',23529,28580);
INSERT INTO "django_geo_db_zipcode" VALUES(31960,72029,-6,'Clarendon, Arkansas 72029',23530,28581);
INSERT INTO "django_geo_db_zipcode" VALUES(31961,72030,-6,'Cleveland, Arkansas 72030',23531,28582);
INSERT INTO "django_geo_db_zipcode" VALUES(31962,72031,-6,'Clinton, Arkansas 72031',23532,28583);
INSERT INTO "django_geo_db_zipcode" VALUES(31963,72032,-6,'Conway, Arkansas 72032',23533,28584);
INSERT INTO "django_geo_db_zipcode" VALUES(31964,72033,-6,'Conway, Arkansas 72033',23533,28585);
INSERT INTO "django_geo_db_zipcode" VALUES(31965,72034,-6,'Conway, Arkansas 72034',23533,28586);
INSERT INTO "django_geo_db_zipcode" VALUES(31966,72035,-6,'Conway, Arkansas 72035',23533,28585);
INSERT INTO "django_geo_db_zipcode" VALUES(31967,72036,-6,'Cotton Plant, Arkansas 72036',23534,28587);
INSERT INTO "django_geo_db_zipcode" VALUES(31968,72037,-6,'Coy, Arkansas 72037',23535,28588);
INSERT INTO "django_geo_db_zipcode" VALUES(31969,72038,-6,'Crocketts Bluff, Arkansas 72038',23536,28589);
INSERT INTO "django_geo_db_zipcode" VALUES(31970,72039,-6,'Damascus, Arkansas 72039',23537,28590);
INSERT INTO "django_geo_db_zipcode" VALUES(31971,72040,-6,'Des Arc, Arkansas 72040',23538,28591);
INSERT INTO "django_geo_db_zipcode" VALUES(31972,72041,-6,'De Valls Bluff, Arkansas 72041',23539,28592);
INSERT INTO "django_geo_db_zipcode" VALUES(31973,72042,-6,'De Witt, Arkansas 72042',23540,28593);
INSERT INTO "django_geo_db_zipcode" VALUES(31974,72043,-6,'Diaz, Arkansas 72043',23541,28594);
INSERT INTO "django_geo_db_zipcode" VALUES(31975,72044,-6,'Edgemont, Arkansas 72044',23542,28595);
INSERT INTO "django_geo_db_zipcode" VALUES(31976,72045,-6,'El Paso, Arkansas 72045',23543,28596);
INSERT INTO "django_geo_db_zipcode" VALUES(31977,72046,-6,'England, Arkansas 72046',23544,28597);
INSERT INTO "django_geo_db_zipcode" VALUES(31978,72047,-6,'Enola, Arkansas 72047',23545,28598);
INSERT INTO "django_geo_db_zipcode" VALUES(31979,72048,-6,'Ethel, Arkansas 72048',23546,28599);
INSERT INTO "django_geo_db_zipcode" VALUES(31980,72051,-6,'Fox, Arkansas 72051',23547,28600);
INSERT INTO "django_geo_db_zipcode" VALUES(31981,72052,-6,'Garner, Arkansas 72052',23548,28601);
INSERT INTO "django_geo_db_zipcode" VALUES(31982,72053,-6,'College Station, Arkansas 72053',23549,28602);
INSERT INTO "django_geo_db_zipcode" VALUES(31983,72055,-6,'Gillett, Arkansas 72055',23550,28603);
INSERT INTO "django_geo_db_zipcode" VALUES(31984,72057,-6,'Grapevine, Arkansas 72057',23551,28604);
INSERT INTO "django_geo_db_zipcode" VALUES(31985,72058,-6,'Greenbrier, Arkansas 72058',23552,28605);
INSERT INTO "django_geo_db_zipcode" VALUES(31986,72059,-6,'Gregory, Arkansas 72059',23553,28606);
INSERT INTO "django_geo_db_zipcode" VALUES(31987,72060,-6,'Griffithville, Arkansas 72060',23554,28607);
INSERT INTO "django_geo_db_zipcode" VALUES(31988,72061,-6,'Guy, Arkansas 72061',23555,28608);
INSERT INTO "django_geo_db_zipcode" VALUES(31989,72063,-6,'Hattieville, Arkansas 72063',23556,28609);
INSERT INTO "django_geo_db_zipcode" VALUES(31990,72064,-6,'Hazen, Arkansas 72064',23557,28610);
INSERT INTO "django_geo_db_zipcode" VALUES(31991,72065,-6,'Hensley, Arkansas 72065',23558,28611);
INSERT INTO "django_geo_db_zipcode" VALUES(31992,72066,-6,'Hickory Plains, Arkansas 72066',23559,28612);
INSERT INTO "django_geo_db_zipcode" VALUES(31993,72067,-6,'Higden, Arkansas 72067',23560,28613);
INSERT INTO "django_geo_db_zipcode" VALUES(31994,72068,-6,'Higginson, Arkansas 72068',23561,28614);
INSERT INTO "django_geo_db_zipcode" VALUES(31995,72069,-6,'Holly Grove, Arkansas 72069',23562,28615);
INSERT INTO "django_geo_db_zipcode" VALUES(31996,72070,-6,'Houston, Arkansas 72070',23563,28616);
INSERT INTO "django_geo_db_zipcode" VALUES(31997,72071,-6,'Howell, Arkansas 72071',23564,28606);
INSERT INTO "django_geo_db_zipcode" VALUES(31998,72072,-6,'Humnoke, Arkansas 72072',23565,28617);
INSERT INTO "django_geo_db_zipcode" VALUES(31999,72073,-6,'Humphrey, Arkansas 72073',23566,28618);
INSERT INTO "django_geo_db_zipcode" VALUES(32000,72074,-6,'Hunter, Arkansas 72074',23567,28619);
INSERT INTO "django_geo_db_zipcode" VALUES(32001,72075,-6,'Jacksonport, Arkansas 72075',23568,28620);
INSERT INTO "django_geo_db_zipcode" VALUES(32002,72076,-6,'Jacksonville, Arkansas 72076',23569,28621);
INSERT INTO "django_geo_db_zipcode" VALUES(32003,72078,-6,'Jacksonville, Arkansas 72078',23569,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32004,72079,-6,'Jefferson, Arkansas 72079',23570,28623);
INSERT INTO "django_geo_db_zipcode" VALUES(32005,72080,-6,'Jerusalem, Arkansas 72080',23571,28624);
INSERT INTO "django_geo_db_zipcode" VALUES(32006,72081,-6,'Judsonia, Arkansas 72081',23572,28625);
INSERT INTO "django_geo_db_zipcode" VALUES(32007,72082,-6,'Kensett, Arkansas 72082',23573,28626);
INSERT INTO "django_geo_db_zipcode" VALUES(32008,72083,-6,'Keo, Arkansas 72083',23574,28627);
INSERT INTO "django_geo_db_zipcode" VALUES(32009,72084,-6,'Leola, Arkansas 72084',23575,28628);
INSERT INTO "django_geo_db_zipcode" VALUES(32010,72085,-6,'Letona, Arkansas 72085',23576,28629);
INSERT INTO "django_geo_db_zipcode" VALUES(32011,72086,-6,'Lonoke, Arkansas 72086',23577,28630);
INSERT INTO "django_geo_db_zipcode" VALUES(32012,72087,-6,'Lonsdale, Arkansas 72087',23578,28631);
INSERT INTO "django_geo_db_zipcode" VALUES(32013,72088,-6,'Fairfield Bay, Arkansas 72088',23579,28632);
INSERT INTO "django_geo_db_zipcode" VALUES(32014,72089,-6,'Bryant, Arkansas 72089',23523,28633);
INSERT INTO "django_geo_db_zipcode" VALUES(32015,72098,-6,'Jacksonville, Arkansas 72098',23569,28634);
INSERT INTO "django_geo_db_zipcode" VALUES(32016,72099,-6,'Little Rock Air Force Base, Arkansas 72099',23580,28635);
INSERT INTO "django_geo_db_zipcode" VALUES(32017,72101,-6,'McCrory, Arkansas 72101',23581,28636);
INSERT INTO "django_geo_db_zipcode" VALUES(32018,72102,-6,'McRae, Arkansas 72102',23582,28637);
INSERT INTO "django_geo_db_zipcode" VALUES(32019,72103,-6,'Mabelvale, Arkansas 72103',23583,28638);
INSERT INTO "django_geo_db_zipcode" VALUES(32020,72104,-6,'Malvern, Arkansas 72104',23584,28639);
INSERT INTO "django_geo_db_zipcode" VALUES(32021,72105,-6,'Jones Mill, Arkansas 72105',23585,28640);
INSERT INTO "django_geo_db_zipcode" VALUES(32022,72106,-6,'Mayflower, Arkansas 72106',23586,28641);
INSERT INTO "django_geo_db_zipcode" VALUES(32023,72107,-6,'Menifee, Arkansas 72107',23587,28642);
INSERT INTO "django_geo_db_zipcode" VALUES(32024,72108,-6,'Monroe, Arkansas 72108',23588,28643);
INSERT INTO "django_geo_db_zipcode" VALUES(32025,72110,-6,'Morrilton, Arkansas 72110',23589,28644);
INSERT INTO "django_geo_db_zipcode" VALUES(32026,72111,-6,'Mount Vernon, Arkansas 72111',23590,28645);
INSERT INTO "django_geo_db_zipcode" VALUES(32027,72112,-6,'Newport, Arkansas 72112',23591,28646);
INSERT INTO "django_geo_db_zipcode" VALUES(32028,72113,-6,'Maumelle, Arkansas 72113',23592,28647);
INSERT INTO "django_geo_db_zipcode" VALUES(32029,72114,-6,'North Little Rock, Arkansas 72114',23520,28648);
INSERT INTO "django_geo_db_zipcode" VALUES(32030,72115,-6,'North Little Rock, Arkansas 72115',23520,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32031,72116,-6,'North Little Rock, Arkansas 72116',23520,28649);
INSERT INTO "django_geo_db_zipcode" VALUES(32032,72117,-6,'North Little Rock, Arkansas 72117',23520,28650);
INSERT INTO "django_geo_db_zipcode" VALUES(32033,72118,-6,'North Little Rock, Arkansas 72118',23520,28651);
INSERT INTO "django_geo_db_zipcode" VALUES(32034,72119,-6,'North Little Rock, Arkansas 72119',23520,28652);
INSERT INTO "django_geo_db_zipcode" VALUES(32035,72120,-6,'Sherwood, Arkansas 72120',23593,28653);
INSERT INTO "django_geo_db_zipcode" VALUES(32036,72121,-6,'Pangburn, Arkansas 72121',23594,28654);
INSERT INTO "django_geo_db_zipcode" VALUES(32037,72122,-6,'Paron, Arkansas 72122',23595,28655);
INSERT INTO "django_geo_db_zipcode" VALUES(32038,72123,-6,'Patterson, Arkansas 72123',23596,28656);
INSERT INTO "django_geo_db_zipcode" VALUES(32039,72124,-6,'North Little Rock, Arkansas 72124',23520,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32040,72125,-6,'Perry, Arkansas 72125',23597,28657);
INSERT INTO "django_geo_db_zipcode" VALUES(32041,72126,-6,'Perryville, Arkansas 72126',23598,28658);
INSERT INTO "django_geo_db_zipcode" VALUES(32042,72127,-6,'Plumerville, Arkansas 72127',23599,28659);
INSERT INTO "django_geo_db_zipcode" VALUES(32043,72128,-6,'Poyen, Arkansas 72128',23600,28660);
INSERT INTO "django_geo_db_zipcode" VALUES(32044,72129,-6,'Prattsville, Arkansas 72129',23601,28661);
INSERT INTO "django_geo_db_zipcode" VALUES(32045,72130,-6,'Prim, Arkansas 72130',23602,28662);
INSERT INTO "django_geo_db_zipcode" VALUES(32046,72131,-6,'Quitman, Arkansas 72131',23603,28663);
INSERT INTO "django_geo_db_zipcode" VALUES(32047,72132,-6,'Redfield, Arkansas 72132',23604,28664);
INSERT INTO "django_geo_db_zipcode" VALUES(32048,72133,-6,'Reydell, Arkansas 72133',23605,28665);
INSERT INTO "django_geo_db_zipcode" VALUES(32049,72134,-6,'Roe, Arkansas 72134',23606,28666);
INSERT INTO "django_geo_db_zipcode" VALUES(32050,72135,-6,'Roland, Arkansas 72135',23607,28667);
INSERT INTO "django_geo_db_zipcode" VALUES(32051,72136,-6,'Romance, Arkansas 72136',23608,28668);
INSERT INTO "django_geo_db_zipcode" VALUES(32052,72137,-6,'Rose Bud, Arkansas 72137',23609,28669);
INSERT INTO "django_geo_db_zipcode" VALUES(32053,72139,-6,'Russell, Arkansas 72139',23610,28670);
INSERT INTO "django_geo_db_zipcode" VALUES(32054,72140,-6,'Saint Charles, Arkansas 72140',23611,28671);
INSERT INTO "django_geo_db_zipcode" VALUES(32055,72141,-6,'Scotland, Arkansas 72141',23612,28672);
INSERT INTO "django_geo_db_zipcode" VALUES(32056,72142,-6,'Scott, Arkansas 72142',23613,28673);
INSERT INTO "django_geo_db_zipcode" VALUES(32057,72143,-6,'Searcy, Arkansas 72143',23614,28674);
INSERT INTO "django_geo_db_zipcode" VALUES(32058,72145,-6,'Searcy, Arkansas 72145',23614,28675);
INSERT INTO "django_geo_db_zipcode" VALUES(32059,72149,-6,'Searcy, Arkansas 72149',23614,28676);
INSERT INTO "django_geo_db_zipcode" VALUES(32060,72150,-6,'Sheridan, Arkansas 72150',23615,28677);
INSERT INTO "django_geo_db_zipcode" VALUES(32061,72152,-6,'Sherrill, Arkansas 72152',23616,28678);
INSERT INTO "django_geo_db_zipcode" VALUES(32062,72153,-6,'Shirley, Arkansas 72153',23617,28679);
INSERT INTO "django_geo_db_zipcode" VALUES(32063,72156,-6,'Solgohachia, Arkansas 72156',23618,28680);
INSERT INTO "django_geo_db_zipcode" VALUES(32064,72157,-6,'Springfield, Arkansas 72157',23619,28681);
INSERT INTO "django_geo_db_zipcode" VALUES(32065,72158,-6,'Benton, Arkansas 72158',23517,28633);
INSERT INTO "django_geo_db_zipcode" VALUES(32066,72160,-6,'Stuttgart, Arkansas 72160',23620,28682);
INSERT INTO "django_geo_db_zipcode" VALUES(32067,72164,-6,'Sweet Home, Arkansas 72164',23621,28683);
INSERT INTO "django_geo_db_zipcode" VALUES(32068,72165,-6,'Thida, Arkansas 72165',23622,28684);
INSERT INTO "django_geo_db_zipcode" VALUES(32069,72166,-6,'Tichnor, Arkansas 72166',23623,28685);
INSERT INTO "django_geo_db_zipcode" VALUES(32070,72167,-6,'Traskwood, Arkansas 72167',23624,28686);
INSERT INTO "django_geo_db_zipcode" VALUES(32071,72168,-6,'Tucker, Arkansas 72168',23625,28687);
INSERT INTO "django_geo_db_zipcode" VALUES(32072,72169,-6,'Tupelo, Arkansas 72169',23626,28688);
INSERT INTO "django_geo_db_zipcode" VALUES(32073,72170,-6,'Ulm, Arkansas 72170',23627,28689);
INSERT INTO "django_geo_db_zipcode" VALUES(32074,72173,-6,'Vilonia, Arkansas 72173',23628,28690);
INSERT INTO "django_geo_db_zipcode" VALUES(32075,72175,-6,'Wabbaseka, Arkansas 72175',23629,28691);
INSERT INTO "django_geo_db_zipcode" VALUES(32076,72176,-6,'Ward, Arkansas 72176',23630,28692);
INSERT INTO "django_geo_db_zipcode" VALUES(32077,72178,-6,'West Point, Arkansas 72178',23631,28693);
INSERT INTO "django_geo_db_zipcode" VALUES(32078,72179,-6,'Wilburn, Arkansas 72179',23632,28694);
INSERT INTO "django_geo_db_zipcode" VALUES(32079,72180,-6,'Woodson, Arkansas 72180',23633,28695);
INSERT INTO "django_geo_db_zipcode" VALUES(32080,72181,-6,'Wooster, Arkansas 72181',23634,28696);
INSERT INTO "django_geo_db_zipcode" VALUES(32081,72182,-6,'Wright, Arkansas 72182',23635,28697);
INSERT INTO "django_geo_db_zipcode" VALUES(32082,72183,-6,'Wrightsville, Arkansas 72183',23636,28698);
INSERT INTO "django_geo_db_zipcode" VALUES(32083,72189,-6,'McCrory, Arkansas 72189',23581,28606);
INSERT INTO "django_geo_db_zipcode" VALUES(32084,72190,-6,'North Little Rock, Arkansas 72190',23520,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32085,72199,-6,'North Little Rock, Arkansas 72199',23520,28699);
INSERT INTO "django_geo_db_zipcode" VALUES(32086,72201,-6,'Little Rock, Arkansas 72201',23637,28700);
INSERT INTO "django_geo_db_zipcode" VALUES(32087,72202,-6,'Little Rock, Arkansas 72202',23637,28701);
INSERT INTO "django_geo_db_zipcode" VALUES(32088,72203,-6,'Little Rock, Arkansas 72203',23637,28702);
INSERT INTO "django_geo_db_zipcode" VALUES(32089,72204,-6,'Little Rock, Arkansas 72204',23637,28703);
INSERT INTO "django_geo_db_zipcode" VALUES(32090,72205,-6,'Little Rock, Arkansas 72205',23637,28704);
INSERT INTO "django_geo_db_zipcode" VALUES(32091,72206,-6,'Little Rock, Arkansas 72206',23637,28705);
INSERT INTO "django_geo_db_zipcode" VALUES(32092,72207,-6,'Little Rock, Arkansas 72207',23637,28706);
INSERT INTO "django_geo_db_zipcode" VALUES(32093,72209,-6,'Little Rock, Arkansas 72209',23637,28707);
INSERT INTO "django_geo_db_zipcode" VALUES(32094,72210,-6,'Little Rock, Arkansas 72210',23637,28708);
INSERT INTO "django_geo_db_zipcode" VALUES(32095,72211,-6,'Little Rock, Arkansas 72211',23637,28709);
INSERT INTO "django_geo_db_zipcode" VALUES(32096,72212,-6,'Little Rock, Arkansas 72212',23637,28710);
INSERT INTO "django_geo_db_zipcode" VALUES(32097,72214,-6,'Little Rock, Arkansas 72214',23637,28711);
INSERT INTO "django_geo_db_zipcode" VALUES(32098,72215,-6,'Little Rock, Arkansas 72215',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32099,72216,-6,'Little Rock, Arkansas 72216',23637,28712);
INSERT INTO "django_geo_db_zipcode" VALUES(32100,72217,-6,'Little Rock, Arkansas 72217',23637,28713);
INSERT INTO "django_geo_db_zipcode" VALUES(32101,72219,-6,'Little Rock, Arkansas 72219',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32102,72221,-6,'Little Rock, Arkansas 72221',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32103,72222,-6,'Little Rock, Arkansas 72222',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32104,72223,-6,'Little Rock, Arkansas 72223',23637,28714);
INSERT INTO "django_geo_db_zipcode" VALUES(32105,72225,-6,'Little Rock, Arkansas 72225',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32106,72227,-6,'Little Rock, Arkansas 72227',23637,28715);
INSERT INTO "django_geo_db_zipcode" VALUES(32107,72231,-6,'Little Rock, Arkansas 72231',23637,28716);
INSERT INTO "django_geo_db_zipcode" VALUES(32108,72259,-6,'Little Rock, Arkansas 72259',23637,28717);
INSERT INTO "django_geo_db_zipcode" VALUES(32109,72295,-6,'Little Rock, Arkansas 72295',23637,28622);
INSERT INTO "django_geo_db_zipcode" VALUES(32110,72301,-6,'West Memphis, Arkansas 72301',23638,28718);
INSERT INTO "django_geo_db_zipcode" VALUES(32111,72303,-6,'West Memphis, Arkansas 72303',23638,28719);
INSERT INTO "django_geo_db_zipcode" VALUES(32112,72310,-6,'Armorel, Arkansas 72310',23639,28720);
INSERT INTO "django_geo_db_zipcode" VALUES(32113,72311,-6,'Aubrey, Arkansas 72311',23640,28721);
INSERT INTO "django_geo_db_zipcode" VALUES(32114,72312,-6,'Barton, Arkansas 72312',23641,28722);
INSERT INTO "django_geo_db_zipcode" VALUES(32115,72313,-6,'Bassett, Arkansas 72313',23642,28723);
INSERT INTO "django_geo_db_zipcode" VALUES(32116,72314,-6,'Birdeye, Arkansas 72314',23643,28724);
INSERT INTO "django_geo_db_zipcode" VALUES(32117,72315,-6,'Blytheville, Arkansas 72315',23644,28725);
INSERT INTO "django_geo_db_zipcode" VALUES(32118,72316,-6,'Blytheville, Arkansas 72316',23644,28726);
INSERT INTO "django_geo_db_zipcode" VALUES(32119,72319,-6,'Gosnell, Arkansas 72319',23645,28726);
INSERT INTO "django_geo_db_zipcode" VALUES(32120,72320,-6,'Brickeys, Arkansas 72320',23646,28727);
INSERT INTO "django_geo_db_zipcode" VALUES(32121,72321,-6,'Burdette, Arkansas 72321',23647,28728);
INSERT INTO "django_geo_db_zipcode" VALUES(32122,72322,-6,'Caldwell, Arkansas 72322',23648,28729);
INSERT INTO "django_geo_db_zipcode" VALUES(32123,72324,-6,'Cherry Valley, Arkansas 72324',23649,28730);
INSERT INTO "django_geo_db_zipcode" VALUES(32124,72325,-6,'Clarkedale, Arkansas 72325',23650,28731);
INSERT INTO "django_geo_db_zipcode" VALUES(32125,72326,-6,'Colt, Arkansas 72326',23651,28732);
INSERT INTO "django_geo_db_zipcode" VALUES(32126,72327,-6,'Crawfordsville, Arkansas 72327',23652,28733);
INSERT INTO "django_geo_db_zipcode" VALUES(32127,72328,-6,'Crumrod, Arkansas 72328',23653,28734);
INSERT INTO "django_geo_db_zipcode" VALUES(32128,72329,-6,'Driver, Arkansas 72329',23654,28735);
INSERT INTO "django_geo_db_zipcode" VALUES(32129,72330,-6,'Dyess, Arkansas 72330',23655,28736);
INSERT INTO "django_geo_db_zipcode" VALUES(32130,72331,-6,'Earle, Arkansas 72331',23656,28737);
INSERT INTO "django_geo_db_zipcode" VALUES(32131,72332,-6,'Edmondson, Arkansas 72332',23657,28738);
INSERT INTO "django_geo_db_zipcode" VALUES(32132,72333,-6,'Elaine, Arkansas 72333',23658,28739);
INSERT INTO "django_geo_db_zipcode" VALUES(32133,72335,-6,'Forrest City, Arkansas 72335',23659,28740);
INSERT INTO "django_geo_db_zipcode" VALUES(32134,72336,-6,'Forrest City, Arkansas 72336',23659,28741);
INSERT INTO "django_geo_db_zipcode" VALUES(32135,72338,-6,'Frenchmans Bayou, Arkansas 72338',23660,28742);
INSERT INTO "django_geo_db_zipcode" VALUES(32136,72339,-6,'Gilmore, Arkansas 72339',23661,28743);
INSERT INTO "django_geo_db_zipcode" VALUES(32137,72340,-6,'Goodwin, Arkansas 72340',23662,28744);
INSERT INTO "django_geo_db_zipcode" VALUES(32138,72341,-6,'Haynes, Arkansas 72341',23663,28745);
INSERT INTO "django_geo_db_zipcode" VALUES(32139,72342,-6,'Helena, Arkansas 72342',23664,28746);
INSERT INTO "django_geo_db_zipcode" VALUES(32140,72345,-6,'Marked Tree, Arkansas 72345',23665,28747);
INSERT INTO "django_geo_db_zipcode" VALUES(32141,72346,-6,'Heth, Arkansas 72346',23666,28748);
INSERT INTO "django_geo_db_zipcode" VALUES(32142,72347,-6,'Hickory Ridge, Arkansas 72347',23667,28749);
INSERT INTO "django_geo_db_zipcode" VALUES(32143,72348,-6,'Hughes, Arkansas 72348',23668,28750);
INSERT INTO "django_geo_db_zipcode" VALUES(32144,72350,-6,'Joiner, Arkansas 72350',23669,28751);
INSERT INTO "django_geo_db_zipcode" VALUES(32145,72351,-6,'Keiser, Arkansas 72351',23670,28752);
INSERT INTO "django_geo_db_zipcode" VALUES(32146,72352,-6,'La Grange, Arkansas 72352',23671,28753);
INSERT INTO "django_geo_db_zipcode" VALUES(32147,72353,-6,'Lambrook, Arkansas 72353',23672,28754);
INSERT INTO "django_geo_db_zipcode" VALUES(32148,72354,-6,'Lepanto, Arkansas 72354',23673,28755);
INSERT INTO "django_geo_db_zipcode" VALUES(32149,72355,-6,'Lexa, Arkansas 72355',23674,28756);
INSERT INTO "django_geo_db_zipcode" VALUES(32150,72358,-6,'Luxora, Arkansas 72358',23675,28757);
INSERT INTO "django_geo_db_zipcode" VALUES(32151,72359,-6,'Madison, Arkansas 72359',23676,28758);
INSERT INTO "django_geo_db_zipcode" VALUES(32152,72360,-6,'Marianna, Arkansas 72360',23677,28759);
INSERT INTO "django_geo_db_zipcode" VALUES(32153,72364,-6,'Marion, Arkansas 72364',23678,28760);
INSERT INTO "django_geo_db_zipcode" VALUES(32154,72365,-6,'Marked Tree, Arkansas 72365',23665,28761);
INSERT INTO "django_geo_db_zipcode" VALUES(32155,72366,-6,'Marvell, Arkansas 72366',23679,28762);
INSERT INTO "django_geo_db_zipcode" VALUES(32156,72367,-6,'Mellwood, Arkansas 72367',23680,28763);
INSERT INTO "django_geo_db_zipcode" VALUES(32157,72368,-6,'Moro, Arkansas 72368',23681,28764);
INSERT INTO "django_geo_db_zipcode" VALUES(32158,72369,-6,'Oneida, Arkansas 72369',23682,28765);
INSERT INTO "django_geo_db_zipcode" VALUES(32159,72370,-6,'Osceola, Arkansas 72370',23683,28766);
INSERT INTO "django_geo_db_zipcode" VALUES(32160,72372,-6,'Palestine, Arkansas 72372',23684,28767);
INSERT INTO "django_geo_db_zipcode" VALUES(32161,72373,-6,'Parkin, Arkansas 72373',23685,28768);
INSERT INTO "django_geo_db_zipcode" VALUES(32162,72374,-6,'Poplar Grove, Arkansas 72374',23686,28769);
INSERT INTO "django_geo_db_zipcode" VALUES(32163,72376,-6,'Proctor, Arkansas 72376',23687,28770);
INSERT INTO "django_geo_db_zipcode" VALUES(32164,72377,-6,'Rivervale, Arkansas 72377',23688,28771);
INSERT INTO "django_geo_db_zipcode" VALUES(32165,72379,-6,'Snow Lake, Arkansas 72379',23689,28772);
INSERT INTO "django_geo_db_zipcode" VALUES(32166,72381,-6,'Tomato, Arkansas 72381',23690,28726);
INSERT INTO "django_geo_db_zipcode" VALUES(32167,72383,-6,'Turner, Arkansas 72383',23691,28773);
INSERT INTO "django_geo_db_zipcode" VALUES(32168,72384,-6,'Turrell, Arkansas 72384',23692,28774);
INSERT INTO "django_geo_db_zipcode" VALUES(32169,72385,-6,'Twist, Arkansas 72385',23693,28775);
INSERT INTO "django_geo_db_zipcode" VALUES(32170,72386,-6,'Tyronza, Arkansas 72386',23694,28776);
INSERT INTO "django_geo_db_zipcode" VALUES(32171,72387,-6,'Vanndale, Arkansas 72387',23695,28777);
INSERT INTO "django_geo_db_zipcode" VALUES(32172,72389,-6,'Wabash, Arkansas 72389',23696,28778);
INSERT INTO "django_geo_db_zipcode" VALUES(32173,72390,-6,'West Helena, Arkansas 72390',23697,28779);
INSERT INTO "django_geo_db_zipcode" VALUES(32174,72391,-6,'West Ridge, Arkansas 72391',23698,28726);
INSERT INTO "django_geo_db_zipcode" VALUES(32175,72392,-6,'Wheatley, Arkansas 72392',23699,28780);
INSERT INTO "django_geo_db_zipcode" VALUES(32176,72394,-6,'Widener, Arkansas 72394',23700,28781);
INSERT INTO "django_geo_db_zipcode" VALUES(32177,72395,-6,'Wilson, Arkansas 72395',23701,28782);
INSERT INTO "django_geo_db_zipcode" VALUES(32178,72396,-6,'Wynne, Arkansas 72396',23702,28783);
INSERT INTO "django_geo_db_zipcode" VALUES(32179,72397,-6,'McCrory, Arkansas 72397',23581,28775);
INSERT INTO "django_geo_db_zipcode" VALUES(32180,72401,-6,'Jonesboro, Arkansas 72401',23703,28784);
INSERT INTO "django_geo_db_zipcode" VALUES(32181,72402,-6,'Jonesboro, Arkansas 72402',23703,28785);
INSERT INTO "django_geo_db_zipcode" VALUES(32182,72403,-6,'Jonesboro, Arkansas 72403',23703,28786);
INSERT INTO "django_geo_db_zipcode" VALUES(32183,72404,-6,'Jonesboro, Arkansas 72404',23703,28787);
INSERT INTO "django_geo_db_zipcode" VALUES(32184,72410,-6,'Alicia, Arkansas 72410',23704,28788);
INSERT INTO "django_geo_db_zipcode" VALUES(32185,72411,-6,'Bay, Arkansas 72411',23705,28789);
INSERT INTO "django_geo_db_zipcode" VALUES(32186,72412,-6,'Beech Grove, Arkansas 72412',23706,28790);
INSERT INTO "django_geo_db_zipcode" VALUES(32187,72413,-6,'Biggers, Arkansas 72413',23707,28791);
INSERT INTO "django_geo_db_zipcode" VALUES(32188,72414,-6,'Black Oak, Arkansas 72414',23708,28792);
INSERT INTO "django_geo_db_zipcode" VALUES(32189,72415,-6,'Black Rock, Arkansas 72415',23709,28793);
INSERT INTO "django_geo_db_zipcode" VALUES(32190,72416,-6,'Bono, Arkansas 72416',23710,28794);
INSERT INTO "django_geo_db_zipcode" VALUES(32191,72417,-6,'Brookland, Arkansas 72417',23711,28795);
INSERT INTO "django_geo_db_zipcode" VALUES(32192,72419,-6,'Caraway, Arkansas 72419',23712,28796);
INSERT INTO "django_geo_db_zipcode" VALUES(32193,72421,-6,'Cash, Arkansas 72421',23713,28797);
INSERT INTO "django_geo_db_zipcode" VALUES(32194,72422,-6,'Corning, Arkansas 72422',23714,28798);
INSERT INTO "django_geo_db_zipcode" VALUES(32195,72423,-6,'Tuckerman, Arkansas 72423',23715,28799);
INSERT INTO "django_geo_db_zipcode" VALUES(32196,72424,-6,'Datto, Arkansas 72424',23716,28800);
INSERT INTO "django_geo_db_zipcode" VALUES(32197,72425,-6,'Delaplaine, Arkansas 72425',23717,28801);
INSERT INTO "django_geo_db_zipcode" VALUES(32198,72426,-6,'Dell, Arkansas 72426',23718,28802);
INSERT INTO "django_geo_db_zipcode" VALUES(32199,72427,-6,'Egypt, Arkansas 72427',23719,28803);
INSERT INTO "django_geo_db_zipcode" VALUES(32200,72428,-6,'Etowah, Arkansas 72428',23720,28804);
INSERT INTO "django_geo_db_zipcode" VALUES(32201,72429,-6,'Fisher, Arkansas 72429',23721,28805);
INSERT INTO "django_geo_db_zipcode" VALUES(32202,72430,-6,'Greenway, Arkansas 72430',23722,28806);
INSERT INTO "django_geo_db_zipcode" VALUES(32203,72431,-6,'Grubbs, Arkansas 72431',23723,28807);
INSERT INTO "django_geo_db_zipcode" VALUES(32204,72432,-6,'Harrisburg, Arkansas 72432',23724,28808);
INSERT INTO "django_geo_db_zipcode" VALUES(32205,72433,-6,'Hoxie, Arkansas 72433',23725,28809);
INSERT INTO "django_geo_db_zipcode" VALUES(32206,72434,-6,'Imboden, Arkansas 72434',23726,28810);
INSERT INTO "django_geo_db_zipcode" VALUES(32207,72435,-6,'Knobel, Arkansas 72435',23727,28811);
INSERT INTO "django_geo_db_zipcode" VALUES(32208,72436,-6,'Lafe, Arkansas 72436',23728,28812);
INSERT INTO "django_geo_db_zipcode" VALUES(32209,72437,-6,'Lake City, Arkansas 72437',23729,28813);
INSERT INTO "django_geo_db_zipcode" VALUES(32210,72438,-6,'Leachville, Arkansas 72438',23730,28814);
INSERT INTO "django_geo_db_zipcode" VALUES(32211,72439,-6,'Light, Arkansas 72439',23731,28815);
INSERT INTO "django_geo_db_zipcode" VALUES(32212,72440,-6,'Lynn, Arkansas 72440',23732,28816);
INSERT INTO "django_geo_db_zipcode" VALUES(32213,72441,-6,'McDougal, Arkansas 72441',23733,28817);
INSERT INTO "django_geo_db_zipcode" VALUES(32214,72442,-6,'Manila, Arkansas 72442',23734,28818);
INSERT INTO "django_geo_db_zipcode" VALUES(32215,72443,-6,'Marmaduke, Arkansas 72443',23735,28819);
INSERT INTO "django_geo_db_zipcode" VALUES(32216,72444,-6,'Maynard, Arkansas 72444',23736,28820);
INSERT INTO "django_geo_db_zipcode" VALUES(32217,72445,-6,'Minturn, Arkansas 72445',23737,28821);
INSERT INTO "django_geo_db_zipcode" VALUES(32218,72447,-6,'Monette, Arkansas 72447',23738,28822);
INSERT INTO "django_geo_db_zipcode" VALUES(32219,72448,-6,'Marmaduke, Arkansas 72448',23735,28823);
INSERT INTO "django_geo_db_zipcode" VALUES(32220,72449,-6,'O Kean, Arkansas 72449',23739,28824);
INSERT INTO "django_geo_db_zipcode" VALUES(32221,72450,-6,'Paragould, Arkansas 72450',23740,28825);
INSERT INTO "django_geo_db_zipcode" VALUES(32222,72451,-6,'Paragould, Arkansas 72451',23740,28826);
INSERT INTO "django_geo_db_zipcode" VALUES(32223,72452,-6,'Paragould, Arkansas 72452',23740,28827);
INSERT INTO "django_geo_db_zipcode" VALUES(32224,72453,-6,'Peach Orchard, Arkansas 72453',23741,28828);
INSERT INTO "django_geo_db_zipcode" VALUES(32225,72454,-6,'Piggott, Arkansas 72454',23742,28829);
INSERT INTO "django_geo_db_zipcode" VALUES(32226,72455,-6,'Pocahontas, Arkansas 72455',23743,28830);
INSERT INTO "django_geo_db_zipcode" VALUES(32227,72456,-6,'Pollard, Arkansas 72456',23744,28831);
INSERT INTO "django_geo_db_zipcode" VALUES(32228,72457,-6,'Portia, Arkansas 72457',23745,28832);
INSERT INTO "django_geo_db_zipcode" VALUES(32229,72458,-6,'Powhatan, Arkansas 72458',23746,28833);
INSERT INTO "django_geo_db_zipcode" VALUES(32230,72459,-6,'Ravenden, Arkansas 72459',23747,28834);
INSERT INTO "django_geo_db_zipcode" VALUES(32231,72460,-6,'Ravenden Springs, Arkansas 72460',23748,28835);
INSERT INTO "django_geo_db_zipcode" VALUES(32232,72461,-6,'Rector, Arkansas 72461',23749,28836);
INSERT INTO "django_geo_db_zipcode" VALUES(32233,72462,-6,'Reyno, Arkansas 72462',23750,28837);
INSERT INTO "django_geo_db_zipcode" VALUES(32234,72464,-6,'Saint Francis, Arkansas 72464',23751,28838);
INSERT INTO "django_geo_db_zipcode" VALUES(32235,72465,-6,'Sedgwick, Arkansas 72465',23752,28839);
INSERT INTO "django_geo_db_zipcode" VALUES(32236,72466,-6,'Smithville, Arkansas 72466',23753,28840);
INSERT INTO "django_geo_db_zipcode" VALUES(32237,72467,-6,'State University, Arkansas 72467',23754,28841);
INSERT INTO "django_geo_db_zipcode" VALUES(32238,72469,-6,'Strawberry, Arkansas 72469',23755,28842);
INSERT INTO "django_geo_db_zipcode" VALUES(32239,72470,-6,'Success, Arkansas 72470',23756,28843);
INSERT INTO "django_geo_db_zipcode" VALUES(32240,72471,-6,'Swifton, Arkansas 72471',23757,28844);
INSERT INTO "django_geo_db_zipcode" VALUES(32241,72472,-6,'Trumann, Arkansas 72472',23758,28845);
INSERT INTO "django_geo_db_zipcode" VALUES(32242,72473,-6,'Tuckerman, Arkansas 72473',23715,28846);
INSERT INTO "django_geo_db_zipcode" VALUES(32243,72474,-6,'Walcott, Arkansas 72474',23759,28847);
INSERT INTO "django_geo_db_zipcode" VALUES(32244,72475,-6,'Waldenburg, Arkansas 72475',23760,28848);
INSERT INTO "django_geo_db_zipcode" VALUES(32245,72476,-6,'Walnut Ridge, Arkansas 72476',23761,28849);
INSERT INTO "django_geo_db_zipcode" VALUES(32246,72477,-6,'Maynard, Arkansas 72477',23736,28850);
INSERT INTO "django_geo_db_zipcode" VALUES(32247,72478,-6,'Warm Springs, Arkansas 72478',23762,28851);
INSERT INTO "django_geo_db_zipcode" VALUES(32248,72479,-6,'Weiner, Arkansas 72479',23763,28852);
INSERT INTO "django_geo_db_zipcode" VALUES(32249,72482,-6,'Williford, Arkansas 72482',23764,28853);
INSERT INTO "django_geo_db_zipcode" VALUES(32250,72501,-6,'Batesville, Arkansas 72501',23765,28854);
INSERT INTO "django_geo_db_zipcode" VALUES(32251,72503,-6,'Batesville, Arkansas 72503',23765,28855);
INSERT INTO "django_geo_db_zipcode" VALUES(32252,72512,-6,'Horseshoe Bend, Arkansas 72512',23766,28856);
INSERT INTO "django_geo_db_zipcode" VALUES(32253,72513,-6,'Ash Flat, Arkansas 72513',23767,28857);
INSERT INTO "django_geo_db_zipcode" VALUES(32254,72515,-6,'Bexar, Arkansas 72515',23768,28858);
INSERT INTO "django_geo_db_zipcode" VALUES(32255,72516,-6,'Boswell, Arkansas 72516',23769,28859);
INSERT INTO "django_geo_db_zipcode" VALUES(32256,72517,-6,'Brockwell, Arkansas 72517',23770,28860);
INSERT INTO "django_geo_db_zipcode" VALUES(32257,72519,-6,'Calico Rock, Arkansas 72519',23771,28861);
INSERT INTO "django_geo_db_zipcode" VALUES(32258,72520,-6,'Camp, Arkansas 72520',23772,28862);
INSERT INTO "django_geo_db_zipcode" VALUES(32259,72521,-6,'Cave City, Arkansas 72521',23773,28863);
INSERT INTO "django_geo_db_zipcode" VALUES(32260,72522,-6,'Charlotte, Arkansas 72522',23774,28864);
INSERT INTO "django_geo_db_zipcode" VALUES(32261,72523,-6,'Concord, Arkansas 72523',23775,28865);
INSERT INTO "django_geo_db_zipcode" VALUES(32262,72524,-6,'Cord, Arkansas 72524',23776,28866);
INSERT INTO "django_geo_db_zipcode" VALUES(32263,72525,-6,'Cherokee Village, Arkansas 72525',23777,28867);
INSERT INTO "django_geo_db_zipcode" VALUES(32264,72526,-6,'Cushman, Arkansas 72526',23778,28868);
INSERT INTO "django_geo_db_zipcode" VALUES(32265,72527,-6,'Desha, Arkansas 72527',23779,28869);
INSERT INTO "django_geo_db_zipcode" VALUES(32266,72528,-6,'Dolph, Arkansas 72528',23780,28870);
INSERT INTO "django_geo_db_zipcode" VALUES(32267,72529,-6,'Cherokee Village, Arkansas 72529',23777,28871);
INSERT INTO "django_geo_db_zipcode" VALUES(32268,72530,-6,'Drasco, Arkansas 72530',23781,28872);
INSERT INTO "django_geo_db_zipcode" VALUES(32269,72531,-6,'Elizabeth, Arkansas 72531',23782,28873);
INSERT INTO "django_geo_db_zipcode" VALUES(32270,72532,-6,'Evening Shade, Arkansas 72532',23783,28874);
INSERT INTO "django_geo_db_zipcode" VALUES(32271,72533,-6,'Fifty Six, Arkansas 72533',23784,28875);
INSERT INTO "django_geo_db_zipcode" VALUES(32272,72534,-6,'Floral, Arkansas 72534',23785,28876);
INSERT INTO "django_geo_db_zipcode" VALUES(32273,72536,-6,'Franklin, Arkansas 72536',23786,28877);
INSERT INTO "django_geo_db_zipcode" VALUES(32274,72537,-6,'Gamaliel, Arkansas 72537',23787,28878);
INSERT INTO "django_geo_db_zipcode" VALUES(32275,72538,-6,'Gepp, Arkansas 72538',23788,28879);
INSERT INTO "django_geo_db_zipcode" VALUES(32276,72539,-6,'Glencoe, Arkansas 72539',23789,28880);
INSERT INTO "django_geo_db_zipcode" VALUES(32277,72540,-6,'Guion, Arkansas 72540',23790,28881);
INSERT INTO "django_geo_db_zipcode" VALUES(32278,72542,-6,'Hardy, Arkansas 72542',23791,28882);
INSERT INTO "django_geo_db_zipcode" VALUES(32279,72543,-6,'Heber Springs, Arkansas 72543',23792,28883);
INSERT INTO "django_geo_db_zipcode" VALUES(32280,72544,-6,'Henderson, Arkansas 72544',23793,28884);
INSERT INTO "django_geo_db_zipcode" VALUES(32281,72545,-6,'Heber Springs, Arkansas 72545',23792,28885);
INSERT INTO "django_geo_db_zipcode" VALUES(32282,72546,-6,'Ida, Arkansas 72546',23794,28886);
INSERT INTO "django_geo_db_zipcode" VALUES(32283,72550,-6,'Locust Grove, Arkansas 72550',23795,28887);
INSERT INTO "django_geo_db_zipcode" VALUES(32284,72553,-6,'Magness, Arkansas 72553',23796,28888);
INSERT INTO "django_geo_db_zipcode" VALUES(32285,72554,-6,'Mammoth Spring, Arkansas 72554',23797,28889);
INSERT INTO "django_geo_db_zipcode" VALUES(32286,72555,-6,'Marcella, Arkansas 72555',23798,28890);
INSERT INTO "django_geo_db_zipcode" VALUES(32287,72556,-6,'Melbourne, Arkansas 72556',23799,28891);
INSERT INTO "django_geo_db_zipcode" VALUES(32288,72557,-6,'Moko, Arkansas 72557',23800,28892);
INSERT INTO "django_geo_db_zipcode" VALUES(32289,72559,-6,'Salem, Arkansas 72559',23801,28893);
INSERT INTO "django_geo_db_zipcode" VALUES(32290,72560,-6,'Mountain View, Arkansas 72560',23802,28894);
INSERT INTO "django_geo_db_zipcode" VALUES(32291,72561,-6,'Mount Pleasant, Arkansas 72561',23803,28895);
INSERT INTO "django_geo_db_zipcode" VALUES(32292,72562,-6,'Newark, Arkansas 72562',23804,28896);
INSERT INTO "django_geo_db_zipcode" VALUES(32293,72564,-6,'Oil Trough, Arkansas 72564',23805,28897);
INSERT INTO "django_geo_db_zipcode" VALUES(32294,72565,-6,'Oxford, Arkansas 72565',23806,28898);
INSERT INTO "django_geo_db_zipcode" VALUES(32295,72566,-6,'Pineville, Arkansas 72566',23807,28899);
INSERT INTO "django_geo_db_zipcode" VALUES(32296,72567,-6,'Pleasant Grove, Arkansas 72567',23808,28900);
INSERT INTO "django_geo_db_zipcode" VALUES(32297,72568,-6,'Pleasant Plains, Arkansas 72568',23809,28901);
INSERT INTO "django_geo_db_zipcode" VALUES(32298,72569,-6,'Poughkeepsie, Arkansas 72569',23810,28902);
INSERT INTO "django_geo_db_zipcode" VALUES(32299,72571,-6,'Rosie, Arkansas 72571',23811,28903);
INSERT INTO "django_geo_db_zipcode" VALUES(32300,72572,-6,'Saffell, Arkansas 72572',23812,28904);
INSERT INTO "django_geo_db_zipcode" VALUES(32301,72573,-6,'Sage, Arkansas 72573',23813,28905);
INSERT INTO "django_geo_db_zipcode" VALUES(32302,72575,-6,'Salado, Arkansas 72575',23814,28906);
INSERT INTO "django_geo_db_zipcode" VALUES(32303,72576,-6,'Salem, Arkansas 72576',23801,28907);
INSERT INTO "django_geo_db_zipcode" VALUES(32304,72577,-6,'Sidney, Arkansas 72577',23815,28908);
INSERT INTO "django_geo_db_zipcode" VALUES(32305,72578,-6,'Sturkie, Arkansas 72578',23816,28909);
INSERT INTO "django_geo_db_zipcode" VALUES(32306,72579,-6,'Sulphur Rock, Arkansas 72579',23817,28910);
INSERT INTO "django_geo_db_zipcode" VALUES(32307,72581,-6,'Tumbling Shoals, Arkansas 72581',23818,28911);
INSERT INTO "django_geo_db_zipcode" VALUES(32308,72583,-6,'Viola, Arkansas 72583',23819,28912);
INSERT INTO "django_geo_db_zipcode" VALUES(32309,72584,-6,'Violet Hill, Arkansas 72584',23820,28913);
INSERT INTO "django_geo_db_zipcode" VALUES(32310,72585,-6,'Wideman, Arkansas 72585',23821,28914);
INSERT INTO "django_geo_db_zipcode" VALUES(32311,72587,-6,'Wiseman, Arkansas 72587',23822,28915);
INSERT INTO "django_geo_db_zipcode" VALUES(32312,72601,-6,'Harrison, Arkansas 72601',23823,28916);
INSERT INTO "django_geo_db_zipcode" VALUES(32313,72602,-6,'Harrison, Arkansas 72602',23823,28917);
INSERT INTO "django_geo_db_zipcode" VALUES(32314,72610,-6,'Alco, Arkansas 72610',23824,28918);
INSERT INTO "django_geo_db_zipcode" VALUES(32315,72611,-6,'Alpena, Arkansas 72611',23825,28919);
INSERT INTO "django_geo_db_zipcode" VALUES(32316,72613,-6,'Beaver, Arkansas 72613',23826,28920);
INSERT INTO "django_geo_db_zipcode" VALUES(32317,72615,-6,'Bergman, Arkansas 72615',23827,28921);
INSERT INTO "django_geo_db_zipcode" VALUES(32318,72616,-6,'Berryville, Arkansas 72616',23828,28922);
INSERT INTO "django_geo_db_zipcode" VALUES(32319,72617,-6,'Big Flat, Arkansas 72617',23829,28923);
INSERT INTO "django_geo_db_zipcode" VALUES(32320,72619,-6,'Bull Shoals, Arkansas 72619',23830,28924);
INSERT INTO "django_geo_db_zipcode" VALUES(32321,72623,-6,'Clarkridge, Arkansas 72623',23831,28925);
INSERT INTO "django_geo_db_zipcode" VALUES(32322,72624,-6,'Compton, Arkansas 72624',23832,28926);
INSERT INTO "django_geo_db_zipcode" VALUES(32323,72626,-6,'Cotter, Arkansas 72626',23833,28927);
INSERT INTO "django_geo_db_zipcode" VALUES(32324,72628,-6,'Deer, Arkansas 72628',23834,28928);
INSERT INTO "django_geo_db_zipcode" VALUES(32325,72629,-6,'Dennard, Arkansas 72629',23835,28929);
INSERT INTO "django_geo_db_zipcode" VALUES(32326,72630,-6,'Diamond City, Arkansas 72630',23836,28930);
INSERT INTO "django_geo_db_zipcode" VALUES(32327,72631,-6,'Eureka Springs, Arkansas 72631',23837,28931);
INSERT INTO "django_geo_db_zipcode" VALUES(32328,72632,-6,'Eureka Springs, Arkansas 72632',23837,28932);
INSERT INTO "django_geo_db_zipcode" VALUES(32329,72633,-6,'Everton, Arkansas 72633',23838,28933);
INSERT INTO "django_geo_db_zipcode" VALUES(32330,72634,-6,'Flippin, Arkansas 72634',23839,28934);
INSERT INTO "django_geo_db_zipcode" VALUES(32331,72635,-6,'Gassville, Arkansas 72635',23840,28935);
INSERT INTO "django_geo_db_zipcode" VALUES(32332,72636,-6,'Gilbert, Arkansas 72636',23841,28936);
INSERT INTO "django_geo_db_zipcode" VALUES(32333,72638,-6,'Green Forest, Arkansas 72638',23842,28937);
INSERT INTO "django_geo_db_zipcode" VALUES(32334,72639,-6,'Harriet, Arkansas 72639',23843,28938);
INSERT INTO "django_geo_db_zipcode" VALUES(32335,72640,-6,'Hasty, Arkansas 72640',23844,28939);
INSERT INTO "django_geo_db_zipcode" VALUES(32336,72641,-6,'Jasper, Arkansas 72641',23845,28940);
INSERT INTO "django_geo_db_zipcode" VALUES(32337,72642,-6,'Lakeview, Arkansas 72642',23846,28941);
INSERT INTO "django_geo_db_zipcode" VALUES(32338,72644,-6,'Lead Hill, Arkansas 72644',23847,28942);
INSERT INTO "django_geo_db_zipcode" VALUES(32339,72645,-6,'Leslie, Arkansas 72645',23848,28943);
INSERT INTO "django_geo_db_zipcode" VALUES(32340,72648,-6,'Marble Falls, Arkansas 72648',23849,28944);
INSERT INTO "django_geo_db_zipcode" VALUES(32341,72650,-6,'Marshall, Arkansas 72650',23850,28945);
INSERT INTO "django_geo_db_zipcode" VALUES(32342,72651,-6,'Midway, Arkansas 72651',23851,28946);
INSERT INTO "django_geo_db_zipcode" VALUES(32343,72653,-6,'Mountain Home, Arkansas 72653',23852,28947);
INSERT INTO "django_geo_db_zipcode" VALUES(32344,72654,-6,'Mountain Home, Arkansas 72654',23852,28948);
INSERT INTO "django_geo_db_zipcode" VALUES(32345,72655,-6,'Mount Judea, Arkansas 72655',23853,28949);
INSERT INTO "django_geo_db_zipcode" VALUES(32346,72657,-6,'Timbo, Arkansas 72657',23854,28950);
INSERT INTO "django_geo_db_zipcode" VALUES(32347,72658,-6,'Norfork, Arkansas 72658',23855,28951);
INSERT INTO "django_geo_db_zipcode" VALUES(32348,72659,-6,'Norfork, Arkansas 72659',23855,28948);
INSERT INTO "django_geo_db_zipcode" VALUES(32349,72660,-6,'Oak Grove, Arkansas 72660',23856,28952);
INSERT INTO "django_geo_db_zipcode" VALUES(32350,72661,-6,'Oakland, Arkansas 72661',23857,28953);
INSERT INTO "django_geo_db_zipcode" VALUES(32351,72662,-6,'Omaha, Arkansas 72662',23858,28954);
INSERT INTO "django_geo_db_zipcode" VALUES(32352,72663,-6,'Onia, Arkansas 72663',23859,28955);
INSERT INTO "django_geo_db_zipcode" VALUES(32353,72666,-6,'Parthenon, Arkansas 72666',23860,28956);
INSERT INTO "django_geo_db_zipcode" VALUES(32354,72668,-6,'Peel, Arkansas 72668',23861,28957);
INSERT INTO "django_geo_db_zipcode" VALUES(32355,72669,-6,'Pindall, Arkansas 72669',23862,28958);
INSERT INTO "django_geo_db_zipcode" VALUES(32356,72670,-6,'Ponca, Arkansas 72670',23863,28959);
INSERT INTO "django_geo_db_zipcode" VALUES(32357,72672,-6,'Pyatt, Arkansas 72672',23864,28960);
INSERT INTO "django_geo_db_zipcode" VALUES(32358,72675,-6,'Saint Joe, Arkansas 72675',23865,28961);
INSERT INTO "django_geo_db_zipcode" VALUES(32359,72677,-6,'Summit, Arkansas 72677',23866,28962);
INSERT INTO "django_geo_db_zipcode" VALUES(32360,72679,-6,'Tilly, Arkansas 72679',23867,28963);
INSERT INTO "django_geo_db_zipcode" VALUES(32361,72680,-6,'Timbo, Arkansas 72680',23854,28964);
INSERT INTO "django_geo_db_zipcode" VALUES(32362,72682,-6,'Valley Springs, Arkansas 72682',23868,28965);
INSERT INTO "django_geo_db_zipcode" VALUES(32363,72683,-6,'Vendor, Arkansas 72683',23869,28966);
INSERT INTO "django_geo_db_zipcode" VALUES(32364,72685,-6,'Western Grove, Arkansas 72685',23870,28967);
INSERT INTO "django_geo_db_zipcode" VALUES(32365,72686,-6,'Witts Springs, Arkansas 72686',23871,28968);
INSERT INTO "django_geo_db_zipcode" VALUES(32366,72687,-6,'Yellville, Arkansas 72687',23872,28969);
INSERT INTO "django_geo_db_zipcode" VALUES(32367,72701,-6,'Fayetteville, Arkansas 72701',23873,28970);
INSERT INTO "django_geo_db_zipcode" VALUES(32368,72702,-6,'Fayetteville, Arkansas 72702',23873,28971);
INSERT INTO "django_geo_db_zipcode" VALUES(32369,72703,-6,'Fayetteville, Arkansas 72703',23873,28972);
INSERT INTO "django_geo_db_zipcode" VALUES(32370,72704,-6,'Fayetteville, Arkansas 72704',23873,28973);
INSERT INTO "django_geo_db_zipcode" VALUES(32371,72711,-6,'Avoca, Arkansas 72711',23874,28974);
INSERT INTO "django_geo_db_zipcode" VALUES(32372,72712,-6,'Bentonville, Arkansas 72712',23875,28975);
INSERT INTO "django_geo_db_zipcode" VALUES(32373,72714,-6,'Bella Vista, Arkansas 72714',23876,28976);
INSERT INTO "django_geo_db_zipcode" VALUES(32374,72715,-6,'Bella Vista, Arkansas 72715',23876,28977);
INSERT INTO "django_geo_db_zipcode" VALUES(32375,72716,-6,'Bentonville, Arkansas 72716',23875,28978);
INSERT INTO "django_geo_db_zipcode" VALUES(32376,72717,-6,'Canehill, Arkansas 72717',23877,28979);
INSERT INTO "django_geo_db_zipcode" VALUES(32377,72718,-6,'Cave Springs, Arkansas 72718',23878,28980);
INSERT INTO "django_geo_db_zipcode" VALUES(32378,72719,-6,'Centerton, Arkansas 72719',23879,28981);
INSERT INTO "django_geo_db_zipcode" VALUES(32379,72721,-6,'Combs, Arkansas 72721',23880,28982);
INSERT INTO "django_geo_db_zipcode" VALUES(32380,72722,-6,'Decatur, Arkansas 72722',23881,28983);
INSERT INTO "django_geo_db_zipcode" VALUES(32381,72727,-6,'Elkins, Arkansas 72727',23882,28984);
INSERT INTO "django_geo_db_zipcode" VALUES(32382,72728,-6,'Elm Springs, Arkansas 72728',23883,28985);
INSERT INTO "django_geo_db_zipcode" VALUES(32383,72729,-6,'Evansville, Arkansas 72729',23884,28986);
INSERT INTO "django_geo_db_zipcode" VALUES(32384,72730,-6,'Farmington, Arkansas 72730',23885,28987);
INSERT INTO "django_geo_db_zipcode" VALUES(32385,72732,-6,'Garfield, Arkansas 72732',23886,28988);
INSERT INTO "django_geo_db_zipcode" VALUES(32386,72733,-6,'Gateway, Arkansas 72733',23887,28989);
INSERT INTO "django_geo_db_zipcode" VALUES(32387,72734,-6,'Gentry, Arkansas 72734',23888,28990);
INSERT INTO "django_geo_db_zipcode" VALUES(32388,72735,-6,'Goshen, Arkansas 72735',23889,28991);
INSERT INTO "django_geo_db_zipcode" VALUES(32389,72736,-6,'Gravette, Arkansas 72736',23890,28992);
INSERT INTO "django_geo_db_zipcode" VALUES(32390,72737,-6,'Greenland, Arkansas 72737',23891,28993);
INSERT INTO "django_geo_db_zipcode" VALUES(32391,72738,-6,'Hindsville, Arkansas 72738',23892,28994);
INSERT INTO "django_geo_db_zipcode" VALUES(32392,72739,-6,'Hiwasse, Arkansas 72739',23893,28995);
INSERT INTO "django_geo_db_zipcode" VALUES(32393,72740,-6,'Huntsville, Arkansas 72740',23894,28996);
INSERT INTO "django_geo_db_zipcode" VALUES(32394,72741,-6,'Johnson, Arkansas 72741',23895,28971);
INSERT INTO "django_geo_db_zipcode" VALUES(32395,72742,-6,'Kingston, Arkansas 72742',23896,28997);
INSERT INTO "django_geo_db_zipcode" VALUES(32396,72744,-6,'Lincoln, Arkansas 72744',23897,28998);
INSERT INTO "django_geo_db_zipcode" VALUES(32397,72745,-6,'Lowell, Arkansas 72745',23898,28999);
INSERT INTO "django_geo_db_zipcode" VALUES(32398,72747,-6,'Maysville, Arkansas 72747',23899,29000);
INSERT INTO "django_geo_db_zipcode" VALUES(32399,72749,-6,'Morrow, Arkansas 72749',23900,29001);
INSERT INTO "django_geo_db_zipcode" VALUES(32400,72751,-6,'Pea Ridge, Arkansas 72751',23901,29002);
INSERT INTO "django_geo_db_zipcode" VALUES(32401,72752,-6,'Pettigrew, Arkansas 72752',23902,29003);
INSERT INTO "django_geo_db_zipcode" VALUES(32402,72753,-6,'Prairie Grove, Arkansas 72753',23903,29004);
INSERT INTO "django_geo_db_zipcode" VALUES(32403,72756,-6,'Rogers, Arkansas 72756',23904,29005);
INSERT INTO "django_geo_db_zipcode" VALUES(32404,72757,-6,'Rogers, Arkansas 72757',23904,29006);
INSERT INTO "django_geo_db_zipcode" VALUES(32405,72758,-6,'Rogers, Arkansas 72758',23904,29007);
INSERT INTO "django_geo_db_zipcode" VALUES(32406,72760,-6,'Saint Paul, Arkansas 72760',23905,29008);
INSERT INTO "django_geo_db_zipcode" VALUES(32407,72761,-6,'Siloam Springs, Arkansas 72761',23906,29009);
INSERT INTO "django_geo_db_zipcode" VALUES(32408,72762,-6,'Springdale, Arkansas 72762',23907,29010);
INSERT INTO "django_geo_db_zipcode" VALUES(32409,72764,-6,'Springdale, Arkansas 72764',23907,29011);
INSERT INTO "django_geo_db_zipcode" VALUES(32410,72765,-6,'Springdale, Arkansas 72765',23907,29012);
INSERT INTO "django_geo_db_zipcode" VALUES(32411,72766,-6,'Springdale, Arkansas 72766',23907,28971);
INSERT INTO "django_geo_db_zipcode" VALUES(32412,72768,-6,'Sulphur Springs, Arkansas 72768',23908,29013);
INSERT INTO "django_geo_db_zipcode" VALUES(32413,72769,-6,'Summers, Arkansas 72769',23909,29014);
INSERT INTO "django_geo_db_zipcode" VALUES(32414,72770,-6,'Tontitown, Arkansas 72770',23910,29015);
INSERT INTO "django_geo_db_zipcode" VALUES(32415,72773,-6,'Wesley, Arkansas 72773',23911,29016);
INSERT INTO "django_geo_db_zipcode" VALUES(32416,72774,-6,'West Fork, Arkansas 72774',23912,29017);
INSERT INTO "django_geo_db_zipcode" VALUES(32417,72776,-6,'Witter, Arkansas 72776',23913,29018);
INSERT INTO "django_geo_db_zipcode" VALUES(32418,72801,-6,'Russellville, Arkansas 72801',23914,29019);
INSERT INTO "django_geo_db_zipcode" VALUES(32419,72802,-6,'Russellville, Arkansas 72802',23914,29020);
INSERT INTO "django_geo_db_zipcode" VALUES(32420,72811,-6,'Russellville, Arkansas 72811',23914,29021);
INSERT INTO "django_geo_db_zipcode" VALUES(32421,72812,-6,'Russellville, Arkansas 72812',23914,29022);
INSERT INTO "django_geo_db_zipcode" VALUES(32422,72820,-6,'Alix, Arkansas 72820',23915,29023);
INSERT INTO "django_geo_db_zipcode" VALUES(32423,72821,-6,'Altus, Arkansas 72821',23916,29024);
INSERT INTO "django_geo_db_zipcode" VALUES(32424,72822,-6,'Russellville, Arkansas 72822',23914,29025);
INSERT INTO "django_geo_db_zipcode" VALUES(32425,72823,-6,'Atkins, Arkansas 72823',23917,29026);
INSERT INTO "django_geo_db_zipcode" VALUES(32426,72824,-6,'Belleville, Arkansas 72824',23918,29027);
INSERT INTO "django_geo_db_zipcode" VALUES(32427,72826,-6,'Blue Mountain, Arkansas 72826',23919,29028);
INSERT INTO "django_geo_db_zipcode" VALUES(32428,72827,-6,'Bluffton, Arkansas 72827',23920,29029);
INSERT INTO "django_geo_db_zipcode" VALUES(32429,72828,-6,'Briggsville, Arkansas 72828',23921,29030);
INSERT INTO "django_geo_db_zipcode" VALUES(32430,72829,-6,'Centerville, Arkansas 72829',23922,29031);
INSERT INTO "django_geo_db_zipcode" VALUES(32431,72830,-6,'Clarksville, Arkansas 72830',23923,29032);
INSERT INTO "django_geo_db_zipcode" VALUES(32432,72832,-6,'Coal Hill, Arkansas 72832',23924,29033);
INSERT INTO "django_geo_db_zipcode" VALUES(32433,72833,-6,'Danville, Arkansas 72833',23925,29034);
INSERT INTO "django_geo_db_zipcode" VALUES(32434,72834,-6,'Dardanelle, Arkansas 72834',23926,29035);
INSERT INTO "django_geo_db_zipcode" VALUES(32435,72835,-6,'Delaware, Arkansas 72835',23927,29036);
INSERT INTO "django_geo_db_zipcode" VALUES(32436,72837,-6,'Dover, Arkansas 72837',23928,29037);
INSERT INTO "django_geo_db_zipcode" VALUES(32437,72838,-6,'Gravelly, Arkansas 72838',23929,29038);
INSERT INTO "django_geo_db_zipcode" VALUES(32438,72839,-6,'Hagarville, Arkansas 72839',23930,29039);
INSERT INTO "django_geo_db_zipcode" VALUES(32439,72840,-6,'Hartman, Arkansas 72840',23931,29040);
INSERT INTO "django_geo_db_zipcode" VALUES(32440,72841,-6,'Harvey, Arkansas 72841',23932,29041);
INSERT INTO "django_geo_db_zipcode" VALUES(32441,72842,-6,'Havana, Arkansas 72842',23933,29042);
INSERT INTO "django_geo_db_zipcode" VALUES(32442,72843,-6,'Hector, Arkansas 72843',23934,29043);
INSERT INTO "django_geo_db_zipcode" VALUES(32443,72845,-6,'Knoxville, Arkansas 72845',23935,29044);
INSERT INTO "django_geo_db_zipcode" VALUES(32444,72846,-6,'Lamar, Arkansas 72846',23936,29045);
INSERT INTO "django_geo_db_zipcode" VALUES(32445,72847,-6,'London, Arkansas 72847',23937,29046);
INSERT INTO "django_geo_db_zipcode" VALUES(32446,72851,-6,'New Blaine, Arkansas 72851',23938,29047);
INSERT INTO "django_geo_db_zipcode" VALUES(32447,72852,-6,'Oark, Arkansas 72852',23939,29048);
INSERT INTO "django_geo_db_zipcode" VALUES(32448,72853,-6,'Ola, Arkansas 72853',23940,29049);
INSERT INTO "django_geo_db_zipcode" VALUES(32449,72854,-6,'Ozone, Arkansas 72854',23941,29050);
INSERT INTO "django_geo_db_zipcode" VALUES(32450,72855,-6,'Paris, Arkansas 72855',23942,29051);
INSERT INTO "django_geo_db_zipcode" VALUES(32451,72856,-6,'Pelsor, Arkansas 72856',23943,29052);
INSERT INTO "django_geo_db_zipcode" VALUES(32452,72857,-6,'Plainview, Arkansas 72857',23944,29053);
INSERT INTO "django_geo_db_zipcode" VALUES(32453,72858,-6,'Pottsville, Arkansas 72858',23945,29054);
INSERT INTO "django_geo_db_zipcode" VALUES(32454,72860,-6,'Rover, Arkansas 72860',23946,29055);
INSERT INTO "django_geo_db_zipcode" VALUES(32455,72863,-6,'Scranton, Arkansas 72863',23947,29056);
INSERT INTO "django_geo_db_zipcode" VALUES(32456,72865,-6,'Subiaco, Arkansas 72865',23948,29057);
INSERT INTO "django_geo_db_zipcode" VALUES(32457,72901,-6,'Fort Smith, Arkansas 72901',23949,29058);
INSERT INTO "django_geo_db_zipcode" VALUES(32458,72902,-6,'Fort Smith, Arkansas 72902',23949,29059);
INSERT INTO "django_geo_db_zipcode" VALUES(32459,72903,-6,'Fort Smith, Arkansas 72903',23949,29060);
INSERT INTO "django_geo_db_zipcode" VALUES(32460,72904,-6,'Fort Smith, Arkansas 72904',23949,29061);
INSERT INTO "django_geo_db_zipcode" VALUES(32461,72905,-6,'Fort Smith, Arkansas 72905',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32462,72906,-6,'Fort Smith, Arkansas 72906',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32463,72908,-6,'Fort Smith, Arkansas 72908',23949,29063);
INSERT INTO "django_geo_db_zipcode" VALUES(32464,72913,-6,'Fort Smith, Arkansas 72913',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32465,72914,-6,'Fort Smith, Arkansas 72914',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32466,72916,-6,'Fort Smith, Arkansas 72916',23949,29064);
INSERT INTO "django_geo_db_zipcode" VALUES(32467,72917,-6,'Fort Smith, Arkansas 72917',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32468,72918,-6,'Fort Smith, Arkansas 72918',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32469,72919,-6,'Fort Smith, Arkansas 72919',23949,29062);
INSERT INTO "django_geo_db_zipcode" VALUES(32470,72921,-6,'Alma, Arkansas 72921',23950,29065);
INSERT INTO "django_geo_db_zipcode" VALUES(32471,72923,-6,'Barling, Arkansas 72923',23951,29066);
INSERT INTO "django_geo_db_zipcode" VALUES(32472,72924,-6,'Bates, Arkansas 72924',23952,29067);
INSERT INTO "django_geo_db_zipcode" VALUES(32473,72926,-6,'Boles, Arkansas 72926',23953,29068);
INSERT INTO "django_geo_db_zipcode" VALUES(32474,72927,-6,'Booneville, Arkansas 72927',23954,29069);
INSERT INTO "django_geo_db_zipcode" VALUES(32475,72928,-6,'Branch, Arkansas 72928',23955,29070);
INSERT INTO "django_geo_db_zipcode" VALUES(32476,72930,-6,'Cecil, Arkansas 72930',23956,29071);
INSERT INTO "django_geo_db_zipcode" VALUES(32477,72932,-6,'Cedarville, Arkansas 72932',23957,29072);
INSERT INTO "django_geo_db_zipcode" VALUES(32478,72933,-6,'Charleston, Arkansas 72933',23958,29073);
INSERT INTO "django_geo_db_zipcode" VALUES(32479,72934,-6,'Chester, Arkansas 72934',23959,29074);
INSERT INTO "django_geo_db_zipcode" VALUES(32480,72935,-6,'Dyer, Arkansas 72935',23960,29075);
INSERT INTO "django_geo_db_zipcode" VALUES(32481,72936,-6,'Greenwood, Arkansas 72936',23961,29076);
INSERT INTO "django_geo_db_zipcode" VALUES(32482,72937,-6,'Hackett, Arkansas 72937',23962,29077);
INSERT INTO "django_geo_db_zipcode" VALUES(32483,72938,-6,'Hartford, Arkansas 72938',23963,29078);
INSERT INTO "django_geo_db_zipcode" VALUES(32484,72940,-6,'Huntington, Arkansas 72940',23964,29079);
INSERT INTO "django_geo_db_zipcode" VALUES(32485,72941,-6,'Lavaca, Arkansas 72941',23965,29080);
INSERT INTO "django_geo_db_zipcode" VALUES(32486,72943,-6,'Magazine, Arkansas 72943',23966,29081);
INSERT INTO "django_geo_db_zipcode" VALUES(32487,72944,-6,'Mansfield, Arkansas 72944',23967,29082);
INSERT INTO "django_geo_db_zipcode" VALUES(32488,72945,-6,'Midland, Arkansas 72945',23968,29083);
INSERT INTO "django_geo_db_zipcode" VALUES(32489,72946,-6,'Mountainburg, Arkansas 72946',23969,29084);
INSERT INTO "django_geo_db_zipcode" VALUES(32490,72947,-6,'Mulberry, Arkansas 72947',23970,29085);
INSERT INTO "django_geo_db_zipcode" VALUES(32491,72948,-6,'Natural Dam, Arkansas 72948',23971,29086);
INSERT INTO "django_geo_db_zipcode" VALUES(32492,72949,-6,'Ozark, Arkansas 72949',23972,29087);
INSERT INTO "django_geo_db_zipcode" VALUES(32493,72950,-6,'Parks, Arkansas 72950',23973,29088);
INSERT INTO "django_geo_db_zipcode" VALUES(32494,72951,-6,'Ratcliff, Arkansas 72951',23974,29089);
INSERT INTO "django_geo_db_zipcode" VALUES(32495,72952,-6,'Rudy, Arkansas 72952',23975,29090);
INSERT INTO "django_geo_db_zipcode" VALUES(32496,72955,-6,'Uniontown, Arkansas 72955',23976,29091);
INSERT INTO "django_geo_db_zipcode" VALUES(32497,72956,-6,'Van Buren, Arkansas 72956',23977,29092);
INSERT INTO "django_geo_db_zipcode" VALUES(32498,72957,-6,'Van Buren, Arkansas 72957',23977,29093);
INSERT INTO "django_geo_db_zipcode" VALUES(32499,72958,-6,'Waldron, Arkansas 72958',23978,29094);
INSERT INTO "django_geo_db_zipcode" VALUES(32500,72959,-6,'Winslow, Arkansas 72959',23979,29095);
INSERT INTO "django_geo_db_zipcode" VALUES(32501,73001,-6,'Albert, Oklahoma 73001',23980,29096);
INSERT INTO "django_geo_db_zipcode" VALUES(32502,73002,-6,'Alex, Oklahoma 73002',23981,29097);
INSERT INTO "django_geo_db_zipcode" VALUES(32503,73003,-6,'Edmond, Oklahoma 73003',23982,29098);
INSERT INTO "django_geo_db_zipcode" VALUES(32504,73004,-6,'Amber, Oklahoma 73004',23983,29099);
INSERT INTO "django_geo_db_zipcode" VALUES(32505,73005,-6,'Anadarko, Oklahoma 73005',23984,29100);
INSERT INTO "django_geo_db_zipcode" VALUES(32506,73006,-6,'Apache, Oklahoma 73006',23985,29101);
INSERT INTO "django_geo_db_zipcode" VALUES(32507,73007,-6,'Arcadia, Oklahoma 73007',23986,29102);
INSERT INTO "django_geo_db_zipcode" VALUES(32508,73008,-6,'Bethany, Oklahoma 73008',23987,29103);
INSERT INTO "django_geo_db_zipcode" VALUES(32509,73009,-6,'Binger, Oklahoma 73009',23988,29104);
INSERT INTO "django_geo_db_zipcode" VALUES(32510,73010,-6,'Blanchard, Oklahoma 73010',23989,29105);
INSERT INTO "django_geo_db_zipcode" VALUES(32511,73011,-6,'Bradley, Oklahoma 73011',23990,29106);
INSERT INTO "django_geo_db_zipcode" VALUES(32512,73012,-6,'Bray, Oklahoma 73012',23991,29107);
INSERT INTO "django_geo_db_zipcode" VALUES(32513,73013,-6,'Edmond, Oklahoma 73013',23982,29108);
INSERT INTO "django_geo_db_zipcode" VALUES(32514,73014,-6,'Calumet, Oklahoma 73014',23992,29109);
INSERT INTO "django_geo_db_zipcode" VALUES(32515,73015,-6,'Carnegie, Oklahoma 73015',23993,29110);
INSERT INTO "django_geo_db_zipcode" VALUES(32516,73016,-6,'Cashion, Oklahoma 73016',23994,29111);
INSERT INTO "django_geo_db_zipcode" VALUES(32517,73017,-6,'Cement, Oklahoma 73017',23995,29112);
INSERT INTO "django_geo_db_zipcode" VALUES(32518,73018,-6,'Chickasha, Oklahoma 73018',23996,29113);
INSERT INTO "django_geo_db_zipcode" VALUES(32519,73019,-6,'Norman, Oklahoma 73019',23997,29114);
INSERT INTO "django_geo_db_zipcode" VALUES(32520,73020,-6,'Choctaw, Oklahoma 73020',23998,29115);
INSERT INTO "django_geo_db_zipcode" VALUES(32521,73021,-6,'Colony, Oklahoma 73021',23999,29116);
INSERT INTO "django_geo_db_zipcode" VALUES(32522,73022,-6,'Concho, Oklahoma 73022',24000,29117);
INSERT INTO "django_geo_db_zipcode" VALUES(32523,73023,-6,'Chickasha, Oklahoma 73023',23996,29118);
INSERT INTO "django_geo_db_zipcode" VALUES(32524,73024,-6,'Corn, Oklahoma 73024',24001,29119);
INSERT INTO "django_geo_db_zipcode" VALUES(32525,73026,-6,'Norman, Oklahoma 73026',23997,29120);
INSERT INTO "django_geo_db_zipcode" VALUES(32526,73027,-6,'Coyle, Oklahoma 73027',24002,29121);
INSERT INTO "django_geo_db_zipcode" VALUES(32527,73028,-6,'Crescent, Oklahoma 73028',24003,29122);
INSERT INTO "django_geo_db_zipcode" VALUES(32528,73029,-6,'Cyril, Oklahoma 73029',24004,29123);
INSERT INTO "django_geo_db_zipcode" VALUES(32529,73030,-6,'Davis, Oklahoma 73030',24005,29124);
INSERT INTO "django_geo_db_zipcode" VALUES(32530,73031,-6,'Dibble, Oklahoma 73031',24006,29125);
INSERT INTO "django_geo_db_zipcode" VALUES(32531,73032,-6,'Dougherty, Oklahoma 73032',24007,29126);
INSERT INTO "django_geo_db_zipcode" VALUES(32532,73033,-6,'Eakly, Oklahoma 73033',24008,29127);
INSERT INTO "django_geo_db_zipcode" VALUES(32533,73034,-6,'Edmond, Oklahoma 73034',23982,29128);
INSERT INTO "django_geo_db_zipcode" VALUES(32534,73036,-6,'El Reno, Oklahoma 73036',24009,29129);
INSERT INTO "django_geo_db_zipcode" VALUES(32535,73038,-6,'Fort Cobb, Oklahoma 73038',24010,29130);
INSERT INTO "django_geo_db_zipcode" VALUES(32536,73040,-6,'Geary, Oklahoma 73040',24011,29131);
INSERT INTO "django_geo_db_zipcode" VALUES(32537,73041,-6,'Gotebo, Oklahoma 73041',24012,29132);
INSERT INTO "django_geo_db_zipcode" VALUES(32538,73042,-6,'Gracemont, Oklahoma 73042',24013,29133);
INSERT INTO "django_geo_db_zipcode" VALUES(32539,73043,-6,'Greenfield, Oklahoma 73043',24014,29134);
INSERT INTO "django_geo_db_zipcode" VALUES(32540,73044,-6,'Guthrie, Oklahoma 73044',24015,29135);
INSERT INTO "django_geo_db_zipcode" VALUES(32541,73045,-6,'Harrah, Oklahoma 73045',24016,29136);
INSERT INTO "django_geo_db_zipcode" VALUES(32542,73047,-6,'Hinton, Oklahoma 73047',24017,29137);
INSERT INTO "django_geo_db_zipcode" VALUES(32543,73048,-6,'Hydro, Oklahoma 73048',24018,29138);
INSERT INTO "django_geo_db_zipcode" VALUES(32544,73049,-6,'Jones, Oklahoma 73049',24019,29139);
INSERT INTO "django_geo_db_zipcode" VALUES(32545,73050,-6,'Langston, Oklahoma 73050',24020,29140);
INSERT INTO "django_geo_db_zipcode" VALUES(32546,73051,-6,'Lexington, Oklahoma 73051',24021,29141);
INSERT INTO "django_geo_db_zipcode" VALUES(32547,73052,-6,'Lindsay, Oklahoma 73052',24022,29142);
INSERT INTO "django_geo_db_zipcode" VALUES(32548,73053,-6,'Lookeba, Oklahoma 73053',24023,29143);
INSERT INTO "django_geo_db_zipcode" VALUES(32549,73054,-6,'Luther, Oklahoma 73054',24024,29144);
INSERT INTO "django_geo_db_zipcode" VALUES(32550,73055,-6,'Marlow, Oklahoma 73055',24025,29145);
INSERT INTO "django_geo_db_zipcode" VALUES(32551,73056,-6,'Marshall, Oklahoma 73056',24026,29146);
INSERT INTO "django_geo_db_zipcode" VALUES(32552,73057,-6,'Maysville, Oklahoma 73057',24027,29147);
INSERT INTO "django_geo_db_zipcode" VALUES(32553,73058,-6,'Meridian, Oklahoma 73058',24028,29148);
INSERT INTO "django_geo_db_zipcode" VALUES(32554,73059,-6,'Minco, Oklahoma 73059',24029,29149);
INSERT INTO "django_geo_db_zipcode" VALUES(32555,73061,-6,'Morrison, Oklahoma 73061',24030,29150);
INSERT INTO "django_geo_db_zipcode" VALUES(32556,73062,-6,'Mountain View, Oklahoma 73062',24031,29151);
INSERT INTO "django_geo_db_zipcode" VALUES(32557,73063,-6,'Mulhall, Oklahoma 73063',24032,29152);
INSERT INTO "django_geo_db_zipcode" VALUES(32558,73064,-6,'Mustang, Oklahoma 73064',24033,29153);
INSERT INTO "django_geo_db_zipcode" VALUES(32559,73065,-6,'Newcastle, Oklahoma 73065',24034,29154);
INSERT INTO "django_geo_db_zipcode" VALUES(32560,73066,-6,'Nicoma Park, Oklahoma 73066',24035,29155);
INSERT INTO "django_geo_db_zipcode" VALUES(32561,73067,-6,'Ninnekah, Oklahoma 73067',24036,29156);
INSERT INTO "django_geo_db_zipcode" VALUES(32562,73068,-6,'Noble, Oklahoma 73068',24037,29157);
INSERT INTO "django_geo_db_zipcode" VALUES(32563,73069,-6,'Norman, Oklahoma 73069',23997,29158);
INSERT INTO "django_geo_db_zipcode" VALUES(32564,73070,-6,'Norman, Oklahoma 73070',23997,29159);
INSERT INTO "django_geo_db_zipcode" VALUES(32565,73071,-6,'Norman, Oklahoma 73071',23997,29160);
INSERT INTO "django_geo_db_zipcode" VALUES(32566,73072,-6,'Norman, Oklahoma 73072',23997,29161);
INSERT INTO "django_geo_db_zipcode" VALUES(32567,73073,-6,'Orlando, Oklahoma 73073',24038,29162);
INSERT INTO "django_geo_db_zipcode" VALUES(32568,73074,-6,'Paoli, Oklahoma 73074',24039,29163);
INSERT INTO "django_geo_db_zipcode" VALUES(32569,73075,-6,'Pauls Valley, Oklahoma 73075',24040,29164);
INSERT INTO "django_geo_db_zipcode" VALUES(32570,73077,-6,'Perry, Oklahoma 73077',24041,29165);
INSERT INTO "django_geo_db_zipcode" VALUES(32571,73078,-6,'Piedmont, Oklahoma 73078',24042,29166);
INSERT INTO "django_geo_db_zipcode" VALUES(32572,73079,-6,'Pocasset, Oklahoma 73079',24043,29167);
INSERT INTO "django_geo_db_zipcode" VALUES(32573,73080,-6,'Purcell, Oklahoma 73080',24044,29168);
INSERT INTO "django_geo_db_zipcode" VALUES(32574,73082,-6,'Rush Springs, Oklahoma 73082',24045,29169);
INSERT INTO "django_geo_db_zipcode" VALUES(32575,73083,-6,'Edmond, Oklahoma 73083',23982,29170);
INSERT INTO "django_geo_db_zipcode" VALUES(32576,73084,-6,'Spencer, Oklahoma 73084',24046,29171);
INSERT INTO "django_geo_db_zipcode" VALUES(32577,73085,-6,'Yukon, Oklahoma 73085',24047,29172);
INSERT INTO "django_geo_db_zipcode" VALUES(32578,73086,-6,'Sulphur, Oklahoma 73086',24048,29173);
INSERT INTO "django_geo_db_zipcode" VALUES(32579,73089,-6,'Tuttle, Oklahoma 73089',24049,29174);
INSERT INTO "django_geo_db_zipcode" VALUES(32580,73090,-6,'Union City, Oklahoma 73090',24050,29175);
INSERT INTO "django_geo_db_zipcode" VALUES(32581,73092,-6,'Verden, Oklahoma 73092',24051,29176);
INSERT INTO "django_geo_db_zipcode" VALUES(32582,73093,-6,'Washington, Oklahoma 73093',24052,29177);
INSERT INTO "django_geo_db_zipcode" VALUES(32583,73094,-6,'Washita, Oklahoma 73094',24053,29096);
INSERT INTO "django_geo_db_zipcode" VALUES(32584,73095,-6,'Wayne, Oklahoma 73095',24054,29178);
INSERT INTO "django_geo_db_zipcode" VALUES(32585,73096,-6,'Weatherford, Oklahoma 73096',24055,29179);
INSERT INTO "django_geo_db_zipcode" VALUES(32586,73097,-6,'Wheatland, Oklahoma 73097',24056,29180);
INSERT INTO "django_geo_db_zipcode" VALUES(32587,73098,-6,'Wynnewood, Oklahoma 73098',24057,29181);
INSERT INTO "django_geo_db_zipcode" VALUES(32588,73099,-6,'Yukon, Oklahoma 73099',24047,29182);
INSERT INTO "django_geo_db_zipcode" VALUES(32589,73101,-6,'Oklahoma City, Oklahoma 73101',24058,29183);
INSERT INTO "django_geo_db_zipcode" VALUES(32590,73102,-6,'Oklahoma City, Oklahoma 73102',24058,29184);
INSERT INTO "django_geo_db_zipcode" VALUES(32591,73103,-6,'Oklahoma City, Oklahoma 73103',24058,29185);
INSERT INTO "django_geo_db_zipcode" VALUES(32592,73104,-6,'Oklahoma City, Oklahoma 73104',24058,29186);
INSERT INTO "django_geo_db_zipcode" VALUES(32593,73105,-6,'Oklahoma City, Oklahoma 73105',24058,29187);
INSERT INTO "django_geo_db_zipcode" VALUES(32594,73106,-6,'Oklahoma City, Oklahoma 73106',24058,29188);
INSERT INTO "django_geo_db_zipcode" VALUES(32595,73107,-6,'Oklahoma City, Oklahoma 73107',24058,29189);
INSERT INTO "django_geo_db_zipcode" VALUES(32596,73108,-6,'Oklahoma City, Oklahoma 73108',24058,29190);
INSERT INTO "django_geo_db_zipcode" VALUES(32597,73109,-6,'Oklahoma City, Oklahoma 73109',24058,29191);
INSERT INTO "django_geo_db_zipcode" VALUES(32598,73110,-6,'Oklahoma City, Oklahoma 73110',24058,29192);
INSERT INTO "django_geo_db_zipcode" VALUES(32599,73111,-6,'Oklahoma City, Oklahoma 73111',24058,29193);
INSERT INTO "django_geo_db_zipcode" VALUES(32600,73112,-6,'Oklahoma City, Oklahoma 73112',24058,29194);
INSERT INTO "django_geo_db_zipcode" VALUES(32601,73113,-6,'Oklahoma City, Oklahoma 73113',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32602,73114,-6,'Oklahoma City, Oklahoma 73114',24058,29196);
INSERT INTO "django_geo_db_zipcode" VALUES(32603,73115,-6,'Oklahoma City, Oklahoma 73115',24058,29197);
INSERT INTO "django_geo_db_zipcode" VALUES(32604,73116,-6,'Oklahoma City, Oklahoma 73116',24058,29198);
INSERT INTO "django_geo_db_zipcode" VALUES(32605,73117,-6,'Oklahoma City, Oklahoma 73117',24058,29199);
INSERT INTO "django_geo_db_zipcode" VALUES(32606,73118,-6,'Oklahoma City, Oklahoma 73118',24058,29200);
INSERT INTO "django_geo_db_zipcode" VALUES(32607,73119,-6,'Oklahoma City, Oklahoma 73119',24058,29201);
INSERT INTO "django_geo_db_zipcode" VALUES(32608,73120,-6,'Oklahoma City, Oklahoma 73120',24058,29202);
INSERT INTO "django_geo_db_zipcode" VALUES(32609,73121,-6,'Oklahoma City, Oklahoma 73121',24058,29203);
INSERT INTO "django_geo_db_zipcode" VALUES(32610,73122,-6,'Oklahoma City, Oklahoma 73122',24058,29204);
INSERT INTO "django_geo_db_zipcode" VALUES(32611,73123,-6,'Oklahoma City, Oklahoma 73123',24058,29205);
INSERT INTO "django_geo_db_zipcode" VALUES(32612,73124,-6,'Oklahoma City, Oklahoma 73124',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32613,73125,-6,'Oklahoma City, Oklahoma 73125',24058,29206);
INSERT INTO "django_geo_db_zipcode" VALUES(32614,73126,-6,'Oklahoma City, Oklahoma 73126',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32615,73127,-6,'Oklahoma City, Oklahoma 73127',24058,29207);
INSERT INTO "django_geo_db_zipcode" VALUES(32616,73128,-6,'Oklahoma City, Oklahoma 73128',24058,29208);
INSERT INTO "django_geo_db_zipcode" VALUES(32617,73129,-6,'Oklahoma City, Oklahoma 73129',24058,29209);
INSERT INTO "django_geo_db_zipcode" VALUES(32618,73130,-6,'Oklahoma City, Oklahoma 73130',24058,29210);
INSERT INTO "django_geo_db_zipcode" VALUES(32619,73131,-6,'Oklahoma City, Oklahoma 73131',24058,29211);
INSERT INTO "django_geo_db_zipcode" VALUES(32620,73132,-6,'Oklahoma City, Oklahoma 73132',24058,29212);
INSERT INTO "django_geo_db_zipcode" VALUES(32621,73134,-6,'Oklahoma City, Oklahoma 73134',24058,29213);
INSERT INTO "django_geo_db_zipcode" VALUES(32622,73135,-6,'Oklahoma City, Oklahoma 73135',24058,29214);
INSERT INTO "django_geo_db_zipcode" VALUES(32623,73136,-6,'Oklahoma City, Oklahoma 73136',24058,29215);
INSERT INTO "django_geo_db_zipcode" VALUES(32624,73137,-6,'Oklahoma City, Oklahoma 73137',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32625,73139,-6,'Oklahoma City, Oklahoma 73139',24058,29216);
INSERT INTO "django_geo_db_zipcode" VALUES(32626,73140,-6,'Oklahoma City, Oklahoma 73140',24058,29217);
INSERT INTO "django_geo_db_zipcode" VALUES(32627,73141,-6,'Oklahoma City, Oklahoma 73141',24058,29218);
INSERT INTO "django_geo_db_zipcode" VALUES(32628,73142,-6,'Oklahoma City, Oklahoma 73142',24058,29219);
INSERT INTO "django_geo_db_zipcode" VALUES(32629,73143,-6,'Oklahoma City, Oklahoma 73143',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32630,73144,-6,'Oklahoma City, Oklahoma 73144',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32631,73145,-6,'Oklahoma City, Oklahoma 73145',24058,29220);
INSERT INTO "django_geo_db_zipcode" VALUES(32632,73146,-6,'Oklahoma City, Oklahoma 73146',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32633,73147,-6,'Oklahoma City, Oklahoma 73147',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32634,73148,-6,'Oklahoma City, Oklahoma 73148',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32635,73149,-6,'Oklahoma City, Oklahoma 73149',24058,29221);
INSERT INTO "django_geo_db_zipcode" VALUES(32636,73150,-6,'Oklahoma City, Oklahoma 73150',24058,29222);
INSERT INTO "django_geo_db_zipcode" VALUES(32637,73151,-6,'Oklahoma City, Oklahoma 73151',24058,29223);
INSERT INTO "django_geo_db_zipcode" VALUES(32638,73152,-6,'Oklahoma City, Oklahoma 73152',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32639,73153,-6,'Oklahoma City, Oklahoma 73153',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32640,73154,-6,'Oklahoma City, Oklahoma 73154',24058,29224);
INSERT INTO "django_geo_db_zipcode" VALUES(32641,73155,-6,'Oklahoma City, Oklahoma 73155',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32642,73156,-6,'Oklahoma City, Oklahoma 73156',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32643,73157,-6,'Oklahoma City, Oklahoma 73157',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32644,73159,-6,'Oklahoma City, Oklahoma 73159',24058,29225);
INSERT INTO "django_geo_db_zipcode" VALUES(32645,73160,-6,'Oklahoma City, Oklahoma 73160',24058,29226);
INSERT INTO "django_geo_db_zipcode" VALUES(32646,73162,-6,'Oklahoma City, Oklahoma 73162',24058,29227);
INSERT INTO "django_geo_db_zipcode" VALUES(32647,73163,-6,'Oklahoma City, Oklahoma 73163',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32648,73164,-6,'Oklahoma City, Oklahoma 73164',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32649,73165,-6,'Oklahoma City, Oklahoma 73165',24058,29228);
INSERT INTO "django_geo_db_zipcode" VALUES(32650,73167,-6,'Oklahoma City, Oklahoma 73167',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32651,73169,-6,'Oklahoma City, Oklahoma 73169',24058,29229);
INSERT INTO "django_geo_db_zipcode" VALUES(32652,73170,-6,'Oklahoma City, Oklahoma 73170',24058,29230);
INSERT INTO "django_geo_db_zipcode" VALUES(32653,73172,-6,'Oklahoma City, Oklahoma 73172',24058,29231);
INSERT INTO "django_geo_db_zipcode" VALUES(32654,73173,-6,'Oklahoma City, Oklahoma 73173',24058,29232);
INSERT INTO "django_geo_db_zipcode" VALUES(32655,73177,-6,'Oklahoma City, Oklahoma 73177',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32656,73178,-6,'Oklahoma City, Oklahoma 73178',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32657,73179,-6,'Oklahoma City, Oklahoma 73179',24058,29233);
INSERT INTO "django_geo_db_zipcode" VALUES(32658,73180,-6,'Oklahoma City, Oklahoma 73180',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32659,73184,-6,'Oklahoma City, Oklahoma 73184',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32660,73185,-6,'Oklahoma City, Oklahoma 73185',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32661,73189,-6,'Oklahoma City, Oklahoma 73189',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32662,73190,-6,'Oklahoma City, Oklahoma 73190',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32663,73193,-6,'Oklahoma City, Oklahoma 73193',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32664,73194,-6,'Oklahoma City, Oklahoma 73194',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32665,73196,-6,'Oklahoma City, Oklahoma 73196',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32666,73197,-6,'Oklahoma City, Oklahoma 73197',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32667,73198,-6,'Oklahoma City, Oklahoma 73198',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32668,73199,-6,'Oklahoma City, Oklahoma 73199',24058,29195);
INSERT INTO "django_geo_db_zipcode" VALUES(32669,73301,-6,'Austin, Texas 73301',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(32670,73344,-6,'Austin, Texas 73344',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(32671,73367,-6,'Sterling, Oklahoma 73367',24060,29235);
INSERT INTO "django_geo_db_zipcode" VALUES(32672,73371,-6,'Ames, Oklahoma 73371',24061,29236);
INSERT INTO "django_geo_db_zipcode" VALUES(32673,73401,-6,'Ardmore, Oklahoma 73401',24062,29237);
INSERT INTO "django_geo_db_zipcode" VALUES(32674,73402,-6,'Ardmore, Oklahoma 73402',24062,29238);
INSERT INTO "django_geo_db_zipcode" VALUES(32675,73403,-6,'Ardmore, Oklahoma 73403',24062,29238);
INSERT INTO "django_geo_db_zipcode" VALUES(32676,73425,-6,'Countyline, Oklahoma 73425',24063,29239);
INSERT INTO "django_geo_db_zipcode" VALUES(32677,73430,-6,'Burneyville, Oklahoma 73430',24064,29240);
INSERT INTO "django_geo_db_zipcode" VALUES(32678,73432,-6,'Coleman, Oklahoma 73432',24065,29241);
INSERT INTO "django_geo_db_zipcode" VALUES(32679,73433,-6,'Elmore City, Oklahoma 73433',24066,29242);
INSERT INTO "django_geo_db_zipcode" VALUES(32680,73434,-6,'Foster, Oklahoma 73434',24067,29243);
INSERT INTO "django_geo_db_zipcode" VALUES(32681,73435,-6,'Fox, Oklahoma 73435',24068,29244);
INSERT INTO "django_geo_db_zipcode" VALUES(32682,73436,-6,'Gene Autry, Oklahoma 73436',24069,29245);
INSERT INTO "django_geo_db_zipcode" VALUES(32683,73437,-6,'Graham, Oklahoma 73437',24070,29246);
INSERT INTO "django_geo_db_zipcode" VALUES(32684,73438,-6,'Healdton, Oklahoma 73438',24071,29247);
INSERT INTO "django_geo_db_zipcode" VALUES(32685,73439,-6,'Kingston, Oklahoma 73439',24072,29248);
INSERT INTO "django_geo_db_zipcode" VALUES(32686,73440,-6,'Lebanon, Oklahoma 73440',24073,29249);
INSERT INTO "django_geo_db_zipcode" VALUES(32687,73441,-6,'Leon, Oklahoma 73441',24074,29250);
INSERT INTO "django_geo_db_zipcode" VALUES(32688,73442,-6,'Loco, Oklahoma 73442',24075,29251);
INSERT INTO "django_geo_db_zipcode" VALUES(32689,73443,-6,'Lone Grove, Oklahoma 73443',24076,29252);
INSERT INTO "django_geo_db_zipcode" VALUES(32690,73444,-6,'Hennepin, Oklahoma 73444',24077,29253);
INSERT INTO "django_geo_db_zipcode" VALUES(32691,73445,-6,'Ravia, Oklahoma 73445',24078,29254);
INSERT INTO "django_geo_db_zipcode" VALUES(32692,73446,-6,'Madill, Oklahoma 73446',24079,29255);
INSERT INTO "django_geo_db_zipcode" VALUES(32693,73447,-6,'Mannsville, Oklahoma 73447',24080,29256);
INSERT INTO "django_geo_db_zipcode" VALUES(32694,73448,-6,'Marietta, Oklahoma 73448',24081,29257);
INSERT INTO "django_geo_db_zipcode" VALUES(32695,73449,-6,'Mead, Oklahoma 73449',24082,29258);
INSERT INTO "django_geo_db_zipcode" VALUES(32696,73450,-6,'Milburn, Oklahoma 73450',24083,29259);
INSERT INTO "django_geo_db_zipcode" VALUES(32697,73453,-6,'Overbrook, Oklahoma 73453',24084,29260);
INSERT INTO "django_geo_db_zipcode" VALUES(32698,73455,-6,'Ravia, Oklahoma 73455',24078,29261);
INSERT INTO "django_geo_db_zipcode" VALUES(32699,73456,-6,'Ringling, Oklahoma 73456',24085,29262);
INSERT INTO "django_geo_db_zipcode" VALUES(32700,73458,-6,'Springer, Oklahoma 73458',24086,29263);
INSERT INTO "django_geo_db_zipcode" VALUES(32701,73459,-6,'Thackerville, Oklahoma 73459',24087,29264);
INSERT INTO "django_geo_db_zipcode" VALUES(32702,73460,-6,'Tishomingo, Oklahoma 73460',24088,29265);
INSERT INTO "django_geo_db_zipcode" VALUES(32703,73461,-6,'Wapanucka, Oklahoma 73461',24089,29266);
INSERT INTO "django_geo_db_zipcode" VALUES(32704,73463,-6,'Wilson, Oklahoma 73463',24090,29267);
INSERT INTO "django_geo_db_zipcode" VALUES(32705,73476,-6,'Pernell, Oklahoma 73476',24091,29268);
INSERT INTO "django_geo_db_zipcode" VALUES(32706,73481,-6,'Ratliff City, Oklahoma 73481',24092,29269);
INSERT INTO "django_geo_db_zipcode" VALUES(32707,73487,-6,'Tatums, Oklahoma 73487',24093,29270);
INSERT INTO "django_geo_db_zipcode" VALUES(32708,73488,-6,'Tussy, Oklahoma 73488',24094,29271);
INSERT INTO "django_geo_db_zipcode" VALUES(32709,73491,-6,'Velma, Oklahoma 73491',24095,29272);
INSERT INTO "django_geo_db_zipcode" VALUES(32710,73501,-6,'Lawton, Oklahoma 73501',24096,29273);
INSERT INTO "django_geo_db_zipcode" VALUES(32711,73502,-6,'Lawton, Oklahoma 73502',24096,29274);
INSERT INTO "django_geo_db_zipcode" VALUES(32712,73503,-6,'Fort Sill, Oklahoma 73503',24097,29275);
INSERT INTO "django_geo_db_zipcode" VALUES(32713,73505,-6,'Lawton, Oklahoma 73505',24096,29276);
INSERT INTO "django_geo_db_zipcode" VALUES(32714,73506,-6,'Lawton, Oklahoma 73506',24096,29274);
INSERT INTO "django_geo_db_zipcode" VALUES(32715,73507,-6,'Lawton, Oklahoma 73507',24096,29277);
INSERT INTO "django_geo_db_zipcode" VALUES(32716,73520,-6,'Addington, Oklahoma 73520',24098,29278);
INSERT INTO "django_geo_db_zipcode" VALUES(32717,73521,-6,'Altus, Oklahoma 73521',24099,29279);
INSERT INTO "django_geo_db_zipcode" VALUES(32718,73522,-6,'Altus, Oklahoma 73522',24099,29280);
INSERT INTO "django_geo_db_zipcode" VALUES(32719,73523,-6,'Altus AFB, Oklahoma 73523',24100,29281);
INSERT INTO "django_geo_db_zipcode" VALUES(32720,73526,-6,'Blair, Oklahoma 73526',24101,29282);
INSERT INTO "django_geo_db_zipcode" VALUES(32721,73527,-6,'Cache, Oklahoma 73527',24102,29283);
INSERT INTO "django_geo_db_zipcode" VALUES(32722,73528,-6,'Chattanooga, Oklahoma 73528',24103,29284);
INSERT INTO "django_geo_db_zipcode" VALUES(32723,73529,-6,'Comanche, Oklahoma 73529',24104,29285);
INSERT INTO "django_geo_db_zipcode" VALUES(32724,73530,-6,'Davidson, Oklahoma 73530',24105,29286);
INSERT INTO "django_geo_db_zipcode" VALUES(32725,73531,-6,'Devol, Oklahoma 73531',24106,29287);
INSERT INTO "django_geo_db_zipcode" VALUES(32726,73532,-6,'Duke, Oklahoma 73532',24107,29288);
INSERT INTO "django_geo_db_zipcode" VALUES(32727,73533,-6,'Duncan, Oklahoma 73533',24108,29289);
INSERT INTO "django_geo_db_zipcode" VALUES(32728,73534,-6,'Duncan, Oklahoma 73534',24108,29290);
INSERT INTO "django_geo_db_zipcode" VALUES(32729,73536,-6,'Duncan, Oklahoma 73536',24108,29107);
INSERT INTO "django_geo_db_zipcode" VALUES(32730,73537,-6,'Eldorado, Oklahoma 73537',24109,29291);
INSERT INTO "django_geo_db_zipcode" VALUES(32731,73538,-6,'Elgin, Oklahoma 73538',24110,29292);
INSERT INTO "django_geo_db_zipcode" VALUES(32732,73539,-6,'Elmer, Oklahoma 73539',24111,29293);
INSERT INTO "django_geo_db_zipcode" VALUES(32733,73540,-6,'Faxon, Oklahoma 73540',24112,29294);
INSERT INTO "django_geo_db_zipcode" VALUES(32734,73541,-6,'Fletcher, Oklahoma 73541',24113,29295);
INSERT INTO "django_geo_db_zipcode" VALUES(32735,73542,-6,'Frederick, Oklahoma 73542',24114,29296);
INSERT INTO "django_geo_db_zipcode" VALUES(32736,73543,-6,'Geronimo, Oklahoma 73543',24115,29297);
INSERT INTO "django_geo_db_zipcode" VALUES(32737,73544,-6,'Gould, Oklahoma 73544',24116,29298);
INSERT INTO "django_geo_db_zipcode" VALUES(32738,73546,-6,'Grandfield, Oklahoma 73546',24117,29299);
INSERT INTO "django_geo_db_zipcode" VALUES(32739,73547,-6,'Granite, Oklahoma 73547',24118,29300);
INSERT INTO "django_geo_db_zipcode" VALUES(32740,73548,-6,'Hastings, Oklahoma 73548',24119,29301);
INSERT INTO "django_geo_db_zipcode" VALUES(32741,73549,-6,'Headrick, Oklahoma 73549',24120,29302);
INSERT INTO "django_geo_db_zipcode" VALUES(32742,73550,-6,'Hollis, Oklahoma 73550',24121,29303);
INSERT INTO "django_geo_db_zipcode" VALUES(32743,73551,-6,'Hollister, Oklahoma 73551',24122,29304);
INSERT INTO "django_geo_db_zipcode" VALUES(32744,73552,-6,'Indiahoma, Oklahoma 73552',24123,29305);
INSERT INTO "django_geo_db_zipcode" VALUES(32745,73553,-6,'Loveland, Oklahoma 73553',24124,29306);
INSERT INTO "django_geo_db_zipcode" VALUES(32746,73554,-6,'Mangum, Oklahoma 73554',24125,29307);
INSERT INTO "django_geo_db_zipcode" VALUES(32747,73555,-6,'Manitou, Oklahoma 73555',24126,29308);
INSERT INTO "django_geo_db_zipcode" VALUES(32748,73556,-6,'Martha, Oklahoma 73556',24127,29309);
INSERT INTO "django_geo_db_zipcode" VALUES(32749,73557,-6,'Medicine Park, Oklahoma 73557',24128,29310);
INSERT INTO "django_geo_db_zipcode" VALUES(32750,73558,-6,'Meers, Oklahoma 73558',24129,29274);
INSERT INTO "django_geo_db_zipcode" VALUES(32751,73559,-6,'Mountain Park, Oklahoma 73559',24130,29311);
INSERT INTO "django_geo_db_zipcode" VALUES(32752,73560,-6,'Olustee, Oklahoma 73560',24131,29312);
INSERT INTO "django_geo_db_zipcode" VALUES(32753,73561,-6,'Oscar, Oklahoma 73561',24132,29313);
INSERT INTO "django_geo_db_zipcode" VALUES(32754,73562,-6,'Randlett, Oklahoma 73562',24133,29314);
INSERT INTO "django_geo_db_zipcode" VALUES(32755,73564,-6,'Roosevelt, Oklahoma 73564',24134,29315);
INSERT INTO "django_geo_db_zipcode" VALUES(32756,73565,-6,'Ryan, Oklahoma 73565',24135,29316);
INSERT INTO "django_geo_db_zipcode" VALUES(32757,73566,-6,'Snyder, Oklahoma 73566',24136,29317);
INSERT INTO "django_geo_db_zipcode" VALUES(32758,73567,-6,'Sterling, Oklahoma 73567',24060,29318);
INSERT INTO "django_geo_db_zipcode" VALUES(32759,73568,-6,'Temple, Oklahoma 73568',24137,29319);
INSERT INTO "django_geo_db_zipcode" VALUES(32760,73569,-6,'Terral, Oklahoma 73569',24138,29320);
INSERT INTO "django_geo_db_zipcode" VALUES(32761,73570,-6,'Tipton, Oklahoma 73570',24139,29321);
INSERT INTO "django_geo_db_zipcode" VALUES(32762,73571,-6,'Vinson, Oklahoma 73571',24140,29322);
INSERT INTO "django_geo_db_zipcode" VALUES(32763,73572,-6,'Walters, Oklahoma 73572',24141,29323);
INSERT INTO "django_geo_db_zipcode" VALUES(32764,73573,-6,'Waurika, Oklahoma 73573',24142,29324);
INSERT INTO "django_geo_db_zipcode" VALUES(32765,73575,-6,'Duncan, Oklahoma 73575',24108,29107);
INSERT INTO "django_geo_db_zipcode" VALUES(32766,73601,-6,'Clinton, Oklahoma 73601',24143,29325);
INSERT INTO "django_geo_db_zipcode" VALUES(32767,73620,-6,'Arapaho, Oklahoma 73620',24144,29326);
INSERT INTO "django_geo_db_zipcode" VALUES(32768,73622,-6,'Bessie, Oklahoma 73622',24145,29327);
INSERT INTO "django_geo_db_zipcode" VALUES(32769,73624,-6,'Burns Flat, Oklahoma 73624',24146,29328);
INSERT INTO "django_geo_db_zipcode" VALUES(32770,73625,-6,'Butler, Oklahoma 73625',24147,29329);
INSERT INTO "django_geo_db_zipcode" VALUES(32771,73626,-6,'Canute, Oklahoma 73626',24148,29330);
INSERT INTO "django_geo_db_zipcode" VALUES(32772,73627,-6,'Carter, Oklahoma 73627',24149,29331);
INSERT INTO "django_geo_db_zipcode" VALUES(32773,73628,-6,'Cheyenne, Oklahoma 73628',24150,29332);
INSERT INTO "django_geo_db_zipcode" VALUES(32774,73632,-6,'Cordell, Oklahoma 73632',24151,29333);
INSERT INTO "django_geo_db_zipcode" VALUES(32775,73638,-6,'Crawford, Oklahoma 73638',24152,29334);
INSERT INTO "django_geo_db_zipcode" VALUES(32776,73639,-6,'Custer City, Oklahoma 73639',24153,29335);
INSERT INTO "django_geo_db_zipcode" VALUES(32777,73641,-6,'Dill City, Oklahoma 73641',24154,29336);
INSERT INTO "django_geo_db_zipcode" VALUES(32778,73642,-6,'Durham, Oklahoma 73642',24155,29337);
INSERT INTO "django_geo_db_zipcode" VALUES(32779,73644,-6,'Elk City, Oklahoma 73644',24156,29338);
INSERT INTO "django_geo_db_zipcode" VALUES(32780,73645,-6,'Erick, Oklahoma 73645',24157,29339);
INSERT INTO "django_geo_db_zipcode" VALUES(32781,73646,-6,'Fay, Oklahoma 73646',24158,29340);
INSERT INTO "django_geo_db_zipcode" VALUES(32782,73647,-6,'Foss, Oklahoma 73647',24159,29341);
INSERT INTO "django_geo_db_zipcode" VALUES(32783,73648,-6,'Elk City, Oklahoma 73648',24156,29342);
INSERT INTO "django_geo_db_zipcode" VALUES(32784,73650,-6,'Hammon, Oklahoma 73650',24160,29343);
INSERT INTO "django_geo_db_zipcode" VALUES(32785,73651,-6,'Hobart, Oklahoma 73651',24161,29344);
INSERT INTO "django_geo_db_zipcode" VALUES(32786,73654,-6,'Leedey, Oklahoma 73654',24162,29345);
INSERT INTO "django_geo_db_zipcode" VALUES(32787,73655,-6,'Lone Wolf, Oklahoma 73655',24163,29346);
INSERT INTO "django_geo_db_zipcode" VALUES(32788,73656,-6,'Mayfield, Oklahoma 73656',24164,29342);
INSERT INTO "django_geo_db_zipcode" VALUES(32789,73658,-6,'Oakwood, Oklahoma 73658',24165,29347);
INSERT INTO "django_geo_db_zipcode" VALUES(32790,73659,-6,'Putnam, Oklahoma 73659',24166,29348);
INSERT INTO "django_geo_db_zipcode" VALUES(32791,73660,-6,'Reydon, Oklahoma 73660',24167,29349);
INSERT INTO "django_geo_db_zipcode" VALUES(32792,73661,-6,'Rocky, Oklahoma 73661',24168,29350);
INSERT INTO "django_geo_db_zipcode" VALUES(32793,73662,-6,'Sayre, Oklahoma 73662',24169,29351);
INSERT INTO "django_geo_db_zipcode" VALUES(32794,73663,-6,'Seiling, Oklahoma 73663',24170,29352);
INSERT INTO "django_geo_db_zipcode" VALUES(32795,73664,-6,'Sentinel, Oklahoma 73664',24171,29353);
INSERT INTO "django_geo_db_zipcode" VALUES(32796,73666,-6,'Sweetwater, Oklahoma 73666',24172,29354);
INSERT INTO "django_geo_db_zipcode" VALUES(32797,73667,-6,'Taloga, Oklahoma 73667',24173,29355);
INSERT INTO "django_geo_db_zipcode" VALUES(32798,73668,-6,'Texola, Oklahoma 73668',24174,29356);
INSERT INTO "django_geo_db_zipcode" VALUES(32799,73669,-6,'Thomas, Oklahoma 73669',24175,29357);
INSERT INTO "django_geo_db_zipcode" VALUES(32800,73673,-6,'Willow, Oklahoma 73673',24176,29358);
INSERT INTO "django_geo_db_zipcode" VALUES(32801,73701,-6,'Enid, Oklahoma 73701',24177,29359);
INSERT INTO "django_geo_db_zipcode" VALUES(32802,73702,-6,'Enid, Oklahoma 73702',24177,29360);
INSERT INTO "django_geo_db_zipcode" VALUES(32803,73703,-6,'Enid, Oklahoma 73703',24177,29361);
INSERT INTO "django_geo_db_zipcode" VALUES(32804,73705,-6,'Enid, Oklahoma 73705',24177,29360);
INSERT INTO "django_geo_db_zipcode" VALUES(32805,73706,-6,'Enid, Oklahoma 73706',24177,29360);
INSERT INTO "django_geo_db_zipcode" VALUES(32806,73716,-6,'Aline, Oklahoma 73716',24178,29362);
INSERT INTO "django_geo_db_zipcode" VALUES(32807,73717,-6,'Alva, Oklahoma 73717',24179,29363);
INSERT INTO "django_geo_db_zipcode" VALUES(32808,73718,-6,'Ames, Oklahoma 73718',24061,29364);
INSERT INTO "django_geo_db_zipcode" VALUES(32809,73719,-6,'Amorita, Oklahoma 73719',24180,29365);
INSERT INTO "django_geo_db_zipcode" VALUES(32810,73720,-6,'Bison, Oklahoma 73720',24181,29366);
INSERT INTO "django_geo_db_zipcode" VALUES(32811,73722,-6,'Burlington, Oklahoma 73722',24182,29367);
INSERT INTO "django_geo_db_zipcode" VALUES(32812,73724,-6,'Canton, Oklahoma 73724',24183,29368);
INSERT INTO "django_geo_db_zipcode" VALUES(32813,73726,-6,'Carmen, Oklahoma 73726',24184,29369);
INSERT INTO "django_geo_db_zipcode" VALUES(32814,73727,-6,'Carrier, Oklahoma 73727',24185,29370);
INSERT INTO "django_geo_db_zipcode" VALUES(32815,73728,-6,'Cherokee, Oklahoma 73728',24186,29371);
INSERT INTO "django_geo_db_zipcode" VALUES(32816,73729,-6,'Cleo Springs, Oklahoma 73729',24187,29372);
INSERT INTO "django_geo_db_zipcode" VALUES(32817,73730,-6,'Covington, Oklahoma 73730',24188,29373);
INSERT INTO "django_geo_db_zipcode" VALUES(32818,73731,-6,'Dacoma, Oklahoma 73731',24189,29374);
INSERT INTO "django_geo_db_zipcode" VALUES(32819,73733,-6,'Douglas, Oklahoma 73733',24190,29375);
INSERT INTO "django_geo_db_zipcode" VALUES(32820,73734,-6,'Dover, Oklahoma 73734',24191,29376);
INSERT INTO "django_geo_db_zipcode" VALUES(32821,73735,-6,'Drummond, Oklahoma 73735',24192,29377);
INSERT INTO "django_geo_db_zipcode" VALUES(32822,73736,-6,'Fairmont, Oklahoma 73736',24193,29378);
INSERT INTO "django_geo_db_zipcode" VALUES(32823,73737,-6,'Fairview, Oklahoma 73737',24194,29379);
INSERT INTO "django_geo_db_zipcode" VALUES(32824,73738,-6,'Garber, Oklahoma 73738',24195,29380);
INSERT INTO "django_geo_db_zipcode" VALUES(32825,73739,-6,'Goltry, Oklahoma 73739',24196,29381);
INSERT INTO "django_geo_db_zipcode" VALUES(32826,73741,-6,'Helena, Oklahoma 73741',24197,29382);
INSERT INTO "django_geo_db_zipcode" VALUES(32827,73742,-6,'Hennessey, Oklahoma 73742',24198,29383);
INSERT INTO "django_geo_db_zipcode" VALUES(32828,73743,-6,'Hillsdale, Oklahoma 73743',24199,29384);
INSERT INTO "django_geo_db_zipcode" VALUES(32829,73744,-6,'Hitchcock, Oklahoma 73744',24200,29385);
INSERT INTO "django_geo_db_zipcode" VALUES(32830,73746,-6,'Hopeton, Oklahoma 73746',24201,29386);
INSERT INTO "django_geo_db_zipcode" VALUES(32831,73747,-6,'Isabella, Oklahoma 73747',24202,29387);
INSERT INTO "django_geo_db_zipcode" VALUES(32832,73749,-6,'Jet, Oklahoma 73749',24203,29388);
INSERT INTO "django_geo_db_zipcode" VALUES(32833,73750,-6,'Kingfisher, Oklahoma 73750',24204,29389);
INSERT INTO "django_geo_db_zipcode" VALUES(32834,73753,-6,'Kremlin, Oklahoma 73753',24205,29390);
INSERT INTO "django_geo_db_zipcode" VALUES(32835,73754,-6,'Lahoma, Oklahoma 73754',24206,29391);
INSERT INTO "django_geo_db_zipcode" VALUES(32836,73755,-6,'Longdale, Oklahoma 73755',24207,29392);
INSERT INTO "django_geo_db_zipcode" VALUES(32837,73756,-6,'Loyal, Oklahoma 73756',24208,29393);
INSERT INTO "django_geo_db_zipcode" VALUES(32838,73757,-6,'Lucien, Oklahoma 73757',24209,29394);
INSERT INTO "django_geo_db_zipcode" VALUES(32839,73758,-6,'Manchester, Oklahoma 73758',24210,29395);
INSERT INTO "django_geo_db_zipcode" VALUES(32840,73759,-6,'Medford, Oklahoma 73759',24211,29396);
INSERT INTO "django_geo_db_zipcode" VALUES(32841,73760,-6,'Meno, Oklahoma 73760',24212,29397);
INSERT INTO "django_geo_db_zipcode" VALUES(32842,73761,-6,'Nash, Oklahoma 73761',24213,29398);
INSERT INTO "django_geo_db_zipcode" VALUES(32843,73762,-6,'Okarche, Oklahoma 73762',24214,29399);
INSERT INTO "django_geo_db_zipcode" VALUES(32844,73763,-6,'Okeene, Oklahoma 73763',24215,29400);
INSERT INTO "django_geo_db_zipcode" VALUES(32845,73764,-6,'Omega, Oklahoma 73764',24216,29401);
INSERT INTO "django_geo_db_zipcode" VALUES(32846,73766,-6,'Pond Creek, Oklahoma 73766',24217,29402);
INSERT INTO "django_geo_db_zipcode" VALUES(32847,73768,-6,'Ringwood, Oklahoma 73768',24218,29403);
INSERT INTO "django_geo_db_zipcode" VALUES(32848,73770,-6,'Southard, Oklahoma 73770',24219,29404);
INSERT INTO "django_geo_db_zipcode" VALUES(32849,73771,-6,'Wakita, Oklahoma 73771',24220,29405);
INSERT INTO "django_geo_db_zipcode" VALUES(32850,73772,-6,'Watonga, Oklahoma 73772',24221,29406);
INSERT INTO "django_geo_db_zipcode" VALUES(32851,73773,-6,'Waukomis, Oklahoma 73773',24222,29407);
INSERT INTO "django_geo_db_zipcode" VALUES(32852,73801,-6,'Woodward, Oklahoma 73801',24223,29408);
INSERT INTO "django_geo_db_zipcode" VALUES(32853,73802,-6,'Woodward, Oklahoma 73802',24223,29409);
INSERT INTO "django_geo_db_zipcode" VALUES(32854,73832,-6,'Arnett, Oklahoma 73832',24224,29410);
INSERT INTO "django_geo_db_zipcode" VALUES(32855,73834,-6,'Buffalo, Oklahoma 73834',24225,29411);
INSERT INTO "django_geo_db_zipcode" VALUES(32856,73835,-6,'Camargo, Oklahoma 73835',24226,29412);
INSERT INTO "django_geo_db_zipcode" VALUES(32857,73838,-6,'Chester, Oklahoma 73838',24227,29413);
INSERT INTO "django_geo_db_zipcode" VALUES(32858,73840,-6,'Fargo, Oklahoma 73840',24228,29414);
INSERT INTO "django_geo_db_zipcode" VALUES(32859,73841,-6,'Fort Supply, Oklahoma 73841',24229,29415);
INSERT INTO "django_geo_db_zipcode" VALUES(32860,73842,-6,'Freedom, Oklahoma 73842',24230,29416);
INSERT INTO "django_geo_db_zipcode" VALUES(32861,73843,-6,'Gage, Oklahoma 73843',24231,29417);
INSERT INTO "django_geo_db_zipcode" VALUES(32862,73844,-6,'Gate, Oklahoma 73844',24232,29418);
INSERT INTO "django_geo_db_zipcode" VALUES(32863,73847,-6,'Knowles, Oklahoma 73847',24233,29419);
INSERT INTO "django_geo_db_zipcode" VALUES(32864,73848,-6,'Laverne, Oklahoma 73848',24234,29420);
INSERT INTO "django_geo_db_zipcode" VALUES(32865,73851,-6,'May, Oklahoma 73851',24235,29421);
INSERT INTO "django_geo_db_zipcode" VALUES(32866,73852,-6,'Mooreland, Oklahoma 73852',24236,29422);
INSERT INTO "django_geo_db_zipcode" VALUES(32867,73853,-6,'Mutual, Oklahoma 73853',24237,29423);
INSERT INTO "django_geo_db_zipcode" VALUES(32868,73855,-6,'Rosston, Oklahoma 73855',24238,29424);
INSERT INTO "django_geo_db_zipcode" VALUES(32869,73857,-6,'Sharon, Oklahoma 73857',24239,29425);
INSERT INTO "django_geo_db_zipcode" VALUES(32870,73858,-6,'Shattuck, Oklahoma 73858',24240,29426);
INSERT INTO "django_geo_db_zipcode" VALUES(32871,73859,-6,'Vici, Oklahoma 73859',24241,29427);
INSERT INTO "django_geo_db_zipcode" VALUES(32872,73860,-6,'Waynoka, Oklahoma 73860',24242,29428);
INSERT INTO "django_geo_db_zipcode" VALUES(32873,73901,-6,'Adams, Oklahoma 73901',24243,29429);
INSERT INTO "django_geo_db_zipcode" VALUES(32874,73931,-6,'Balko, Oklahoma 73931',24244,29430);
INSERT INTO "django_geo_db_zipcode" VALUES(32875,73932,-6,'Beaver, Oklahoma 73932',24245,29431);
INSERT INTO "django_geo_db_zipcode" VALUES(32876,73933,-6,'Boise City, Oklahoma 73933',24246,29432);
INSERT INTO "django_geo_db_zipcode" VALUES(32877,73937,-6,'Felt, Oklahoma 73937',24247,29433);
INSERT INTO "django_geo_db_zipcode" VALUES(32878,73938,-6,'Forgan, Oklahoma 73938',24248,29434);
INSERT INTO "django_geo_db_zipcode" VALUES(32879,73939,-6,'Goodwell, Oklahoma 73939',24249,29435);
INSERT INTO "django_geo_db_zipcode" VALUES(32880,73942,-6,'Guymon, Oklahoma 73942',24250,29436);
INSERT INTO "django_geo_db_zipcode" VALUES(32881,73944,-6,'Hardesty, Oklahoma 73944',24251,29437);
INSERT INTO "django_geo_db_zipcode" VALUES(32882,73945,-6,'Hooker, Oklahoma 73945',24252,29438);
INSERT INTO "django_geo_db_zipcode" VALUES(32883,73946,-6,'Kenton, Oklahoma 73946',24253,29439);
INSERT INTO "django_geo_db_zipcode" VALUES(32884,73947,-6,'Keyes, Oklahoma 73947',24254,29440);
INSERT INTO "django_geo_db_zipcode" VALUES(32885,73949,-6,'Texhoma, Oklahoma 73949',24255,29441);
INSERT INTO "django_geo_db_zipcode" VALUES(32886,73950,-6,'Turpin, Oklahoma 73950',24256,29442);
INSERT INTO "django_geo_db_zipcode" VALUES(32887,73951,-6,'Tyrone, Oklahoma 73951',24257,29443);
INSERT INTO "django_geo_db_zipcode" VALUES(32888,74001,-6,'Avant, Oklahoma 74001',24258,29444);
INSERT INTO "django_geo_db_zipcode" VALUES(32889,74002,-6,'Barnsdall, Oklahoma 74002',24259,29445);
INSERT INTO "django_geo_db_zipcode" VALUES(32890,74003,-6,'Bartlesville, Oklahoma 74003',24260,29446);
INSERT INTO "django_geo_db_zipcode" VALUES(32891,74004,-6,'Bartlesville, Oklahoma 74004',24260,29447);
INSERT INTO "django_geo_db_zipcode" VALUES(32892,74005,-6,'Bartlesville, Oklahoma 74005',24260,29447);
INSERT INTO "django_geo_db_zipcode" VALUES(32893,74006,-6,'Bartlesville, Oklahoma 74006',24260,29448);
INSERT INTO "django_geo_db_zipcode" VALUES(32894,74008,-6,'Bixby, Oklahoma 74008',24261,29449);
INSERT INTO "django_geo_db_zipcode" VALUES(32895,74009,-6,'Bowring, Oklahoma 74009',24262,29450);
INSERT INTO "django_geo_db_zipcode" VALUES(32896,74010,-6,'Bristow, Oklahoma 74010',24263,29451);
INSERT INTO "django_geo_db_zipcode" VALUES(32897,74011,-6,'Broken Arrow, Oklahoma 74011',24264,29452);
INSERT INTO "django_geo_db_zipcode" VALUES(32898,74012,-6,'Broken Arrow, Oklahoma 74012',24264,29453);
INSERT INTO "django_geo_db_zipcode" VALUES(32899,74013,-6,'Broken Arrow, Oklahoma 74013',24264,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32900,74014,-6,'Broken Arrow, Oklahoma 74014',24264,29455);
INSERT INTO "django_geo_db_zipcode" VALUES(32901,74015,-6,'Catoosa, Oklahoma 74015',24265,29456);
INSERT INTO "django_geo_db_zipcode" VALUES(32902,74016,-6,'Chelsea, Oklahoma 74016',24266,29457);
INSERT INTO "django_geo_db_zipcode" VALUES(32903,74017,-6,'Claremore, Oklahoma 74017',24267,29458);
INSERT INTO "django_geo_db_zipcode" VALUES(32904,74018,-6,'Claremore, Oklahoma 74018',24267,29459);
INSERT INTO "django_geo_db_zipcode" VALUES(32905,74020,-6,'Cleveland, Oklahoma 74020',24268,29460);
INSERT INTO "django_geo_db_zipcode" VALUES(32906,74021,-6,'Collinsville, Oklahoma 74021',24269,29461);
INSERT INTO "django_geo_db_zipcode" VALUES(32907,74022,-6,'Copan, Oklahoma 74022',24270,29462);
INSERT INTO "django_geo_db_zipcode" VALUES(32908,74023,-6,'Cushing, Oklahoma 74023',24271,29463);
INSERT INTO "django_geo_db_zipcode" VALUES(32909,74026,-6,'Davenport, Oklahoma 74026',24272,29464);
INSERT INTO "django_geo_db_zipcode" VALUES(32910,74027,-6,'Delaware, Oklahoma 74027',24273,29465);
INSERT INTO "django_geo_db_zipcode" VALUES(32911,74028,-6,'Depew, Oklahoma 74028',24274,29466);
INSERT INTO "django_geo_db_zipcode" VALUES(32912,74029,-6,'Dewey, Oklahoma 74029',24275,29467);
INSERT INTO "django_geo_db_zipcode" VALUES(32913,74030,-6,'Drumright, Oklahoma 74030',24276,29468);
INSERT INTO "django_geo_db_zipcode" VALUES(32914,74031,-6,'Foyil, Oklahoma 74031',24277,29469);
INSERT INTO "django_geo_db_zipcode" VALUES(32915,74032,-6,'Glencoe, Oklahoma 74032',24278,29470);
INSERT INTO "django_geo_db_zipcode" VALUES(32916,74033,-6,'Glenpool, Oklahoma 74033',24279,29471);
INSERT INTO "django_geo_db_zipcode" VALUES(32917,74034,-6,'Hallett, Oklahoma 74034',24280,29472);
INSERT INTO "django_geo_db_zipcode" VALUES(32918,74035,-6,'Hominy, Oklahoma 74035',24281,29473);
INSERT INTO "django_geo_db_zipcode" VALUES(32919,74036,-6,'Inola, Oklahoma 74036',24282,29474);
INSERT INTO "django_geo_db_zipcode" VALUES(32920,74037,-6,'Jenks, Oklahoma 74037',24283,29475);
INSERT INTO "django_geo_db_zipcode" VALUES(32921,74038,-6,'Jennings, Oklahoma 74038',24284,29476);
INSERT INTO "django_geo_db_zipcode" VALUES(32922,74039,-6,'Kellyville, Oklahoma 74039',24285,29477);
INSERT INTO "django_geo_db_zipcode" VALUES(32923,74041,-6,'Kiefer, Oklahoma 74041',24286,29478);
INSERT INTO "django_geo_db_zipcode" VALUES(32924,74042,-6,'Lenapah, Oklahoma 74042',24287,29479);
INSERT INTO "django_geo_db_zipcode" VALUES(32925,74043,-6,'Leonard, Oklahoma 74043',24288,29480);
INSERT INTO "django_geo_db_zipcode" VALUES(32926,74044,-6,'Mannford, Oklahoma 74044',24289,29481);
INSERT INTO "django_geo_db_zipcode" VALUES(32927,74045,-6,'Maramec, Oklahoma 74045',24290,29482);
INSERT INTO "django_geo_db_zipcode" VALUES(32928,74046,-6,'Milfay, Oklahoma 74046',24291,29483);
INSERT INTO "django_geo_db_zipcode" VALUES(32929,74047,-6,'Mounds, Oklahoma 74047',24292,29484);
INSERT INTO "django_geo_db_zipcode" VALUES(32930,74048,-6,'Nowata, Oklahoma 74048',24293,29485);
INSERT INTO "django_geo_db_zipcode" VALUES(32931,74050,-6,'Oakhurst, Oklahoma 74050',24294,29486);
INSERT INTO "django_geo_db_zipcode" VALUES(32932,74051,-6,'Ochelata, Oklahoma 74051',24295,29487);
INSERT INTO "django_geo_db_zipcode" VALUES(32933,74052,-6,'Oilton, Oklahoma 74052',24296,29488);
INSERT INTO "django_geo_db_zipcode" VALUES(32934,74053,-6,'Oologah, Oklahoma 74053',24297,29489);
INSERT INTO "django_geo_db_zipcode" VALUES(32935,74054,-6,'Osage, Oklahoma 74054',24298,29490);
INSERT INTO "django_geo_db_zipcode" VALUES(32936,74055,-6,'Owasso, Oklahoma 74055',24299,29491);
INSERT INTO "django_geo_db_zipcode" VALUES(32937,74056,-6,'Pawhuska, Oklahoma 74056',24300,29492);
INSERT INTO "django_geo_db_zipcode" VALUES(32938,74058,-6,'Pawnee, Oklahoma 74058',24301,29493);
INSERT INTO "django_geo_db_zipcode" VALUES(32939,74059,-6,'Perkins, Oklahoma 74059',24302,29494);
INSERT INTO "django_geo_db_zipcode" VALUES(32940,74060,-6,'Prue, Oklahoma 74060',24303,29495);
INSERT INTO "django_geo_db_zipcode" VALUES(32941,74061,-6,'Ramona, Oklahoma 74061',24304,29496);
INSERT INTO "django_geo_db_zipcode" VALUES(32942,74062,-6,'Ripley, Oklahoma 74062',24305,29497);
INSERT INTO "django_geo_db_zipcode" VALUES(32943,74063,-6,'Sand Springs, Oklahoma 74063',24306,29498);
INSERT INTO "django_geo_db_zipcode" VALUES(32944,74064,-6,'McCord, Oklahoma 74064',24307,29499);
INSERT INTO "django_geo_db_zipcode" VALUES(32945,74066,-6,'Sapulpa, Oklahoma 74066',24308,29500);
INSERT INTO "django_geo_db_zipcode" VALUES(32946,74067,-6,'Sapulpa, Oklahoma 74067',24308,29501);
INSERT INTO "django_geo_db_zipcode" VALUES(32947,74068,-6,'Shamrock, Oklahoma 74068',24309,29502);
INSERT INTO "django_geo_db_zipcode" VALUES(32948,74070,-6,'Skiatook, Oklahoma 74070',24310,29503);
INSERT INTO "django_geo_db_zipcode" VALUES(32949,74071,-6,'Slick, Oklahoma 74071',24311,29504);
INSERT INTO "django_geo_db_zipcode" VALUES(32950,74072,-6,'S Coffeyville, Oklahoma 74072',24312,29505);
INSERT INTO "django_geo_db_zipcode" VALUES(32951,74073,-6,'Sperry, Oklahoma 74073',24313,29506);
INSERT INTO "django_geo_db_zipcode" VALUES(32952,74074,-6,'Stillwater, Oklahoma 74074',24314,29507);
INSERT INTO "django_geo_db_zipcode" VALUES(32953,74075,-6,'Stillwater, Oklahoma 74075',24314,29508);
INSERT INTO "django_geo_db_zipcode" VALUES(32954,74076,-6,'Stillwater, Oklahoma 74076',24314,29509);
INSERT INTO "django_geo_db_zipcode" VALUES(32955,74077,-6,'Stillwater, Oklahoma 74077',24314,29510);
INSERT INTO "django_geo_db_zipcode" VALUES(32956,74078,-6,'Stillwater, Oklahoma 74078',24314,29510);
INSERT INTO "django_geo_db_zipcode" VALUES(32957,74079,-6,'Stroud, Oklahoma 74079',24315,29511);
INSERT INTO "django_geo_db_zipcode" VALUES(32958,74080,-6,'Talala, Oklahoma 74080',24316,29512);
INSERT INTO "django_geo_db_zipcode" VALUES(32959,74081,-6,'Terlton, Oklahoma 74081',24317,29513);
INSERT INTO "django_geo_db_zipcode" VALUES(32960,74082,-6,'Vera, Oklahoma 74082',24318,29514);
INSERT INTO "django_geo_db_zipcode" VALUES(32961,74083,-6,'Wann, Oklahoma 74083',24319,29515);
INSERT INTO "django_geo_db_zipcode" VALUES(32962,74084,-6,'Wynona, Oklahoma 74084',24320,29516);
INSERT INTO "django_geo_db_zipcode" VALUES(32963,74085,-6,'Yale, Oklahoma 74085',24321,29517);
INSERT INTO "django_geo_db_zipcode" VALUES(32964,74101,-6,'Tulsa, Oklahoma 74101',24322,29518);
INSERT INTO "django_geo_db_zipcode" VALUES(32965,74102,-6,'Tulsa, Oklahoma 74102',24322,29519);
INSERT INTO "django_geo_db_zipcode" VALUES(32966,74103,-6,'Tulsa, Oklahoma 74103',24322,29520);
INSERT INTO "django_geo_db_zipcode" VALUES(32967,74104,-6,'Tulsa, Oklahoma 74104',24322,29521);
INSERT INTO "django_geo_db_zipcode" VALUES(32968,74105,-6,'Tulsa, Oklahoma 74105',24322,29522);
INSERT INTO "django_geo_db_zipcode" VALUES(32969,74106,-6,'Tulsa, Oklahoma 74106',24322,29523);
INSERT INTO "django_geo_db_zipcode" VALUES(32970,74107,-6,'Tulsa, Oklahoma 74107',24322,29524);
INSERT INTO "django_geo_db_zipcode" VALUES(32971,74108,-6,'Tulsa, Oklahoma 74108',24322,29525);
INSERT INTO "django_geo_db_zipcode" VALUES(32972,74110,-6,'Tulsa, Oklahoma 74110',24322,29526);
INSERT INTO "django_geo_db_zipcode" VALUES(32973,74112,-6,'Tulsa, Oklahoma 74112',24322,29527);
INSERT INTO "django_geo_db_zipcode" VALUES(32974,74114,-6,'Tulsa, Oklahoma 74114',24322,29528);
INSERT INTO "django_geo_db_zipcode" VALUES(32975,74115,-6,'Tulsa, Oklahoma 74115',24322,29529);
INSERT INTO "django_geo_db_zipcode" VALUES(32976,74116,-6,'Tulsa, Oklahoma 74116',24322,29530);
INSERT INTO "django_geo_db_zipcode" VALUES(32977,74117,-6,'Tulsa, Oklahoma 74117',24322,29531);
INSERT INTO "django_geo_db_zipcode" VALUES(32978,74119,-6,'Tulsa, Oklahoma 74119',24322,29532);
INSERT INTO "django_geo_db_zipcode" VALUES(32979,74120,-6,'Tulsa, Oklahoma 74120',24322,29533);
INSERT INTO "django_geo_db_zipcode" VALUES(32980,74121,-6,'Tulsa, Oklahoma 74121',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32981,74126,-6,'Tulsa, Oklahoma 74126',24322,29534);
INSERT INTO "django_geo_db_zipcode" VALUES(32982,74127,-6,'Tulsa, Oklahoma 74127',24322,29535);
INSERT INTO "django_geo_db_zipcode" VALUES(32983,74128,-6,'Tulsa, Oklahoma 74128',24322,29536);
INSERT INTO "django_geo_db_zipcode" VALUES(32984,74129,-6,'Tulsa, Oklahoma 74129',24322,29537);
INSERT INTO "django_geo_db_zipcode" VALUES(32985,74130,-6,'Tulsa, Oklahoma 74130',24322,29538);
INSERT INTO "django_geo_db_zipcode" VALUES(32986,74131,-6,'Tulsa, Oklahoma 74131',24322,29539);
INSERT INTO "django_geo_db_zipcode" VALUES(32987,74132,-6,'Tulsa, Oklahoma 74132',24322,29540);
INSERT INTO "django_geo_db_zipcode" VALUES(32988,74133,-6,'Tulsa, Oklahoma 74133',24322,29541);
INSERT INTO "django_geo_db_zipcode" VALUES(32989,74134,-6,'Tulsa, Oklahoma 74134',24322,29542);
INSERT INTO "django_geo_db_zipcode" VALUES(32990,74135,-6,'Tulsa, Oklahoma 74135',24322,29543);
INSERT INTO "django_geo_db_zipcode" VALUES(32991,74136,-6,'Tulsa, Oklahoma 74136',24322,29544);
INSERT INTO "django_geo_db_zipcode" VALUES(32992,74137,-6,'Tulsa, Oklahoma 74137',24322,29545);
INSERT INTO "django_geo_db_zipcode" VALUES(32993,74141,-6,'Tulsa, Oklahoma 74141',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32994,74145,-6,'Tulsa, Oklahoma 74145',24322,29546);
INSERT INTO "django_geo_db_zipcode" VALUES(32995,74146,-6,'Tulsa, Oklahoma 74146',24322,29547);
INSERT INTO "django_geo_db_zipcode" VALUES(32996,74147,-6,'Tulsa, Oklahoma 74147',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32997,74148,-6,'Tulsa, Oklahoma 74148',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32998,74149,-6,'Tulsa, Oklahoma 74149',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(32999,74150,-6,'Tulsa, Oklahoma 74150',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33000,74152,-6,'Tulsa, Oklahoma 74152',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33001,74153,-6,'Tulsa, Oklahoma 74153',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33002,74155,-6,'Tulsa, Oklahoma 74155',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33003,74156,-6,'Tulsa, Oklahoma 74156',24322,29548);
INSERT INTO "django_geo_db_zipcode" VALUES(33004,74157,-6,'Tulsa, Oklahoma 74157',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33005,74158,-6,'Tulsa, Oklahoma 74158',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33006,74159,-6,'Tulsa, Oklahoma 74159',24322,29549);
INSERT INTO "django_geo_db_zipcode" VALUES(33007,74169,-6,'Tulsa, Oklahoma 74169',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33008,74170,-6,'Tulsa, Oklahoma 74170',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33009,74171,-6,'Tulsa, Oklahoma 74171',24322,29550);
INSERT INTO "django_geo_db_zipcode" VALUES(33010,74172,-6,'Tulsa, Oklahoma 74172',24322,29551);
INSERT INTO "django_geo_db_zipcode" VALUES(33011,74177,-6,'Tulsa, Oklahoma 74177',24322,29552);
INSERT INTO "django_geo_db_zipcode" VALUES(33012,74182,-6,'Tulsa, Oklahoma 74182',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33013,74183,-6,'Tulsa, Oklahoma 74183',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33014,74184,-6,'Tulsa, Oklahoma 74184',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33015,74186,-6,'Tulsa, Oklahoma 74186',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33016,74187,-6,'Tulsa, Oklahoma 74187',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33017,74189,-6,'Tulsa, Oklahoma 74189',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33018,74192,-6,'Tulsa, Oklahoma 74192',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33019,74193,-6,'Tulsa, Oklahoma 74193',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33020,74194,-6,'Tulsa, Oklahoma 74194',24322,29454);
INSERT INTO "django_geo_db_zipcode" VALUES(33021,74301,-6,'Vinita, Oklahoma 74301',24323,29553);
INSERT INTO "django_geo_db_zipcode" VALUES(33022,74328,-6,'Colcord, Oklahoma 74328',24324,29554);
INSERT INTO "django_geo_db_zipcode" VALUES(33023,74330,-6,'Adair, Oklahoma 74330',24325,29555);
INSERT INTO "django_geo_db_zipcode" VALUES(33024,74331,-6,'Afton, Oklahoma 74331',24326,29556);
INSERT INTO "django_geo_db_zipcode" VALUES(33025,74332,-6,'Big Cabin, Oklahoma 74332',24327,29557);
INSERT INTO "django_geo_db_zipcode" VALUES(33026,74333,-6,'Bluejacket, Oklahoma 74333',24328,29558);
INSERT INTO "django_geo_db_zipcode" VALUES(33027,74334,-6,'Dodge, Oklahoma 74334',24329,29559);
INSERT INTO "django_geo_db_zipcode" VALUES(33028,74335,-6,'Cardin, Oklahoma 74335',24330,29560);
INSERT INTO "django_geo_db_zipcode" VALUES(33029,74336,-6,'Jay, Oklahoma 74336',24331,29561);
INSERT INTO "django_geo_db_zipcode" VALUES(33030,74337,-6,'Chouteau, Oklahoma 74337',24332,29562);
INSERT INTO "django_geo_db_zipcode" VALUES(33031,74338,-6,'Colcord, Oklahoma 74338',24324,29563);
INSERT INTO "django_geo_db_zipcode" VALUES(33032,74339,-6,'Commerce, Oklahoma 74339',24333,29564);
INSERT INTO "django_geo_db_zipcode" VALUES(33033,74340,-6,'Disney, Oklahoma 74340',24334,29565);
INSERT INTO "django_geo_db_zipcode" VALUES(33034,74342,-6,'Eucha, Oklahoma 74342',24335,29566);
INSERT INTO "django_geo_db_zipcode" VALUES(33035,74343,-6,'Fairland, Oklahoma 74343',24336,29567);
INSERT INTO "django_geo_db_zipcode" VALUES(33036,74344,-6,'Grove, Oklahoma 74344',24337,29568);
INSERT INTO "django_geo_db_zipcode" VALUES(33037,74345,-6,'Grove, Oklahoma 74345',24337,29569);
INSERT INTO "django_geo_db_zipcode" VALUES(33038,74346,-6,'Jay, Oklahoma 74346',24331,29570);
INSERT INTO "django_geo_db_zipcode" VALUES(33039,74347,-6,'Kansas, Oklahoma 74347',24338,29571);
INSERT INTO "django_geo_db_zipcode" VALUES(33040,74349,-6,'Ketchum, Oklahoma 74349',24339,29572);
INSERT INTO "django_geo_db_zipcode" VALUES(33041,74350,-6,'Langley, Oklahoma 74350',24340,29573);
INSERT INTO "django_geo_db_zipcode" VALUES(33042,74352,-6,'Locust Grove, Oklahoma 74352',24341,29574);
INSERT INTO "django_geo_db_zipcode" VALUES(33043,74353,-6,'Mazie, Oklahoma 74353',24342,29575);
INSERT INTO "django_geo_db_zipcode" VALUES(33044,74354,-6,'Miami, Oklahoma 74354',24343,29576);
INSERT INTO "django_geo_db_zipcode" VALUES(33045,74355,-6,'Miami, Oklahoma 74355',24343,29577);
INSERT INTO "django_geo_db_zipcode" VALUES(33046,74358,-6,'North Miami, Oklahoma 74358',24344,29578);
INSERT INTO "django_geo_db_zipcode" VALUES(33047,74359,-6,'Oaks, Oklahoma 74359',24345,29579);
INSERT INTO "django_geo_db_zipcode" VALUES(33048,74360,-6,'Picher, Oklahoma 74360',24346,29580);
INSERT INTO "django_geo_db_zipcode" VALUES(33049,74361,-6,'Pryor, Oklahoma 74361',24347,29581);
INSERT INTO "django_geo_db_zipcode" VALUES(33050,74362,-6,'Pryor, Oklahoma 74362',24347,29575);
INSERT INTO "django_geo_db_zipcode" VALUES(33051,74363,-6,'Quapaw, Oklahoma 74363',24348,29582);
INSERT INTO "django_geo_db_zipcode" VALUES(33052,74364,-6,'Rose, Oklahoma 74364',24349,29583);
INSERT INTO "django_geo_db_zipcode" VALUES(33053,74365,-6,'Salina, Oklahoma 74365',24350,29584);
INSERT INTO "django_geo_db_zipcode" VALUES(33054,74366,-6,'Spavinaw, Oklahoma 74366',24351,29585);
INSERT INTO "django_geo_db_zipcode" VALUES(33055,74367,-6,'Strang, Oklahoma 74367',24352,29586);
INSERT INTO "django_geo_db_zipcode" VALUES(33056,74368,-6,'Twin Oaks, Oklahoma 74368',24353,29587);
INSERT INTO "django_geo_db_zipcode" VALUES(33057,74369,-6,'Welch, Oklahoma 74369',24354,29588);
INSERT INTO "django_geo_db_zipcode" VALUES(33058,74370,-6,'Wyandotte, Oklahoma 74370',24355,29589);
INSERT INTO "django_geo_db_zipcode" VALUES(33059,74399,-6,'Commerce, Oklahoma 74399',24333,29590);
INSERT INTO "django_geo_db_zipcode" VALUES(33060,74401,-6,'Muskogee, Oklahoma 74401',24356,29591);
INSERT INTO "django_geo_db_zipcode" VALUES(33061,74402,-6,'Muskogee, Oklahoma 74402',24356,29592);
INSERT INTO "django_geo_db_zipcode" VALUES(33062,74403,-6,'Muskogee, Oklahoma 74403',24356,29593);
INSERT INTO "django_geo_db_zipcode" VALUES(33063,74421,-6,'Beggs, Oklahoma 74421',24357,29594);
INSERT INTO "django_geo_db_zipcode" VALUES(33064,74422,-6,'Boynton, Oklahoma 74422',24358,29595);
INSERT INTO "django_geo_db_zipcode" VALUES(33065,74423,-6,'Braggs, Oklahoma 74423',24359,29596);
INSERT INTO "django_geo_db_zipcode" VALUES(33066,74425,-6,'Canadian, Oklahoma 74425',24360,29597);
INSERT INTO "django_geo_db_zipcode" VALUES(33067,74426,-6,'Checotah, Oklahoma 74426',24361,29598);
INSERT INTO "django_geo_db_zipcode" VALUES(33068,74427,-6,'Cookson, Oklahoma 74427',24362,29599);
INSERT INTO "django_geo_db_zipcode" VALUES(33069,74428,-6,'Council Hill, Oklahoma 74428',24363,29600);
INSERT INTO "django_geo_db_zipcode" VALUES(33070,74429,-6,'Coweta, Oklahoma 74429',24364,29601);
INSERT INTO "django_geo_db_zipcode" VALUES(33071,74430,-6,'Crowder, Oklahoma 74430',24365,29602);
INSERT INTO "django_geo_db_zipcode" VALUES(33072,74431,-6,'Dewar, Oklahoma 74431',24366,29603);
INSERT INTO "django_geo_db_zipcode" VALUES(33073,74432,-6,'Eufaula, Oklahoma 74432',24367,29604);
INSERT INTO "django_geo_db_zipcode" VALUES(33074,74434,-6,'Fort Gibson, Oklahoma 74434',24368,29605);
INSERT INTO "django_geo_db_zipcode" VALUES(33075,74435,-6,'Gore, Oklahoma 74435',24369,29606);
INSERT INTO "django_geo_db_zipcode" VALUES(33076,74436,-6,'Haskell, Oklahoma 74436',24370,29607);
INSERT INTO "django_geo_db_zipcode" VALUES(33077,74437,-6,'Henryetta, Oklahoma 74437',24371,29608);
INSERT INTO "django_geo_db_zipcode" VALUES(33078,74438,-6,'Hitchita, Oklahoma 74438',24372,29609);
INSERT INTO "django_geo_db_zipcode" VALUES(33079,74440,-6,'Hoyt, Oklahoma 74440',24373,29610);
INSERT INTO "django_geo_db_zipcode" VALUES(33080,74441,-6,'Hulbert, Oklahoma 74441',24374,29611);
INSERT INTO "django_geo_db_zipcode" VALUES(33081,74442,-6,'Indianola, Oklahoma 74442',24375,29612);
INSERT INTO "django_geo_db_zipcode" VALUES(33082,74444,-6,'Moodys, Oklahoma 74444',24376,29613);
INSERT INTO "django_geo_db_zipcode" VALUES(33083,74445,-6,'Morris, Oklahoma 74445',24377,29614);
INSERT INTO "django_geo_db_zipcode" VALUES(33084,74446,-6,'Okay, Oklahoma 74446',24378,29615);
INSERT INTO "django_geo_db_zipcode" VALUES(33085,74447,-6,'Okmulgee, Oklahoma 74447',24379,29616);
INSERT INTO "django_geo_db_zipcode" VALUES(33086,74450,-6,'Oktaha, Oklahoma 74450',24380,29617);
INSERT INTO "django_geo_db_zipcode" VALUES(33087,74451,-6,'Park Hill, Oklahoma 74451',24381,29618);
INSERT INTO "django_geo_db_zipcode" VALUES(33088,74452,-6,'Peggs, Oklahoma 74452',24382,29619);
INSERT INTO "django_geo_db_zipcode" VALUES(33089,74454,-6,'Porter, Oklahoma 74454',24383,29620);
INSERT INTO "django_geo_db_zipcode" VALUES(33090,74455,-6,'Porum, Oklahoma 74455',24384,29621);
INSERT INTO "django_geo_db_zipcode" VALUES(33091,74456,-6,'Preston, Oklahoma 74456',24385,29622);
INSERT INTO "django_geo_db_zipcode" VALUES(33092,74457,-6,'Proctor, Oklahoma 74457',24386,29623);
INSERT INTO "django_geo_db_zipcode" VALUES(33093,74458,-6,'Redbird, Oklahoma 74458',24387,29624);
INSERT INTO "django_geo_db_zipcode" VALUES(33094,74459,-6,'Rentiesville, Oklahoma 74459',24388,29625);
INSERT INTO "django_geo_db_zipcode" VALUES(33095,74460,-6,'Schulter, Oklahoma 74460',24389,29626);
INSERT INTO "django_geo_db_zipcode" VALUES(33096,74461,-6,'Stidham, Oklahoma 74461',24390,29627);
INSERT INTO "django_geo_db_zipcode" VALUES(33097,74462,-6,'Stigler, Oklahoma 74462',24391,29628);
INSERT INTO "django_geo_db_zipcode" VALUES(33098,74463,-6,'Taft, Oklahoma 74463',24392,29629);
INSERT INTO "django_geo_db_zipcode" VALUES(33099,74464,-6,'Tahlequah, Oklahoma 74464',24393,29630);
INSERT INTO "django_geo_db_zipcode" VALUES(33100,74465,-6,'Tahlequah, Oklahoma 74465',24393,29631);
INSERT INTO "django_geo_db_zipcode" VALUES(33101,74466,-6,'Tullahassee, Oklahoma 74466',24394,29624);
INSERT INTO "django_geo_db_zipcode" VALUES(33102,74467,-6,'Wagoner, Oklahoma 74467',24395,29632);
INSERT INTO "django_geo_db_zipcode" VALUES(33103,74468,-6,'Wainwright, Oklahoma 74468',24396,29633);
INSERT INTO "django_geo_db_zipcode" VALUES(33104,74469,-6,'Warner, Oklahoma 74469',24397,29634);
INSERT INTO "django_geo_db_zipcode" VALUES(33105,74470,-6,'Webbers Falls, Oklahoma 74470',24398,29635);
INSERT INTO "django_geo_db_zipcode" VALUES(33106,74471,-6,'Welling, Oklahoma 74471',24399,29636);
INSERT INTO "django_geo_db_zipcode" VALUES(33107,74472,-6,'Whitefield, Oklahoma 74472',24400,29637);
INSERT INTO "django_geo_db_zipcode" VALUES(33108,74477,-6,'Wagoner, Oklahoma 74477',24395,29624);
INSERT INTO "django_geo_db_zipcode" VALUES(33109,74501,-6,'Mcalester, Oklahoma 74501',24401,29638);
INSERT INTO "django_geo_db_zipcode" VALUES(33110,74502,-6,'Mcalester, Oklahoma 74502',24401,29639);
INSERT INTO "django_geo_db_zipcode" VALUES(33111,74520,-6,'Ada, Oklahoma 74520',24402,29640);
INSERT INTO "django_geo_db_zipcode" VALUES(33112,74521,-6,'Albion, Oklahoma 74521',24403,29641);
INSERT INTO "django_geo_db_zipcode" VALUES(33113,74522,-6,'Alderson, Oklahoma 74522',24404,29642);
INSERT INTO "django_geo_db_zipcode" VALUES(33114,74523,-6,'Antlers, Oklahoma 74523',24405,29643);
INSERT INTO "django_geo_db_zipcode" VALUES(33115,74525,-6,'Atoka, Oklahoma 74525',24406,29644);
INSERT INTO "django_geo_db_zipcode" VALUES(33116,74528,-6,'Blanco, Oklahoma 74528',24407,29645);
INSERT INTO "django_geo_db_zipcode" VALUES(33117,74529,-6,'Blocker, Oklahoma 74529',24408,29639);
INSERT INTO "django_geo_db_zipcode" VALUES(33118,74530,-6,'Bromide, Oklahoma 74530',24409,29646);
INSERT INTO "django_geo_db_zipcode" VALUES(33119,74531,-6,'Calvin, Oklahoma 74531',24410,29647);
INSERT INTO "django_geo_db_zipcode" VALUES(33120,74533,-6,'Caney, Oklahoma 74533',24411,29648);
INSERT INTO "django_geo_db_zipcode" VALUES(33121,74534,-6,'Centrahoma, Oklahoma 74534',24412,29649);
INSERT INTO "django_geo_db_zipcode" VALUES(33122,74535,-6,'Clarita, Oklahoma 74535',24413,29650);
INSERT INTO "django_geo_db_zipcode" VALUES(33123,74536,-6,'Clayton, Oklahoma 74536',24414,29651);
INSERT INTO "django_geo_db_zipcode" VALUES(33124,74538,-6,'Coalgate, Oklahoma 74538',24415,29652);
INSERT INTO "django_geo_db_zipcode" VALUES(33125,74540,-6,'Daisy, Oklahoma 74540',24416,29653);
INSERT INTO "django_geo_db_zipcode" VALUES(33126,74542,-6,'Atoka, Oklahoma 74542',24406,29654);
INSERT INTO "django_geo_db_zipcode" VALUES(33127,74543,-6,'Finley, Oklahoma 74543',24417,29655);
INSERT INTO "django_geo_db_zipcode" VALUES(33128,74545,-6,'Gowen, Oklahoma 74545',24418,29656);
INSERT INTO "django_geo_db_zipcode" VALUES(33129,74546,-6,'Haileyville, Oklahoma 74546',24419,29657);
INSERT INTO "django_geo_db_zipcode" VALUES(33130,74547,-6,'Hartshorne, Oklahoma 74547',24420,29658);
INSERT INTO "django_geo_db_zipcode" VALUES(33131,74549,-6,'Honobia, Oklahoma 74549',24421,29659);
INSERT INTO "django_geo_db_zipcode" VALUES(33132,74552,-6,'Kinta, Oklahoma 74552',24422,29660);
INSERT INTO "django_geo_db_zipcode" VALUES(33133,74553,-6,'Kiowa, Oklahoma 74553',24423,29661);
INSERT INTO "django_geo_db_zipcode" VALUES(33134,74554,-6,'Krebs, Oklahoma 74554',24424,29662);
INSERT INTO "django_geo_db_zipcode" VALUES(33135,74555,-6,'Lane, Oklahoma 74555',24425,29663);
INSERT INTO "django_geo_db_zipcode" VALUES(33136,74556,-6,'Lehigh, Oklahoma 74556',24426,29664);
INSERT INTO "django_geo_db_zipcode" VALUES(33137,74557,-6,'Moyers, Oklahoma 74557',24427,29665);
INSERT INTO "django_geo_db_zipcode" VALUES(33138,74558,-6,'Nashoba, Oklahoma 74558',24428,29666);
INSERT INTO "django_geo_db_zipcode" VALUES(33139,74559,-6,'Panola, Oklahoma 74559',24429,29667);
INSERT INTO "django_geo_db_zipcode" VALUES(33140,74560,-6,'Pittsburg, Oklahoma 74560',24430,29668);
INSERT INTO "django_geo_db_zipcode" VALUES(33141,74561,-6,'Quinton, Oklahoma 74561',24431,29669);
INSERT INTO "django_geo_db_zipcode" VALUES(33142,74562,-6,'Rattan, Oklahoma 74562',24432,29670);
INSERT INTO "django_geo_db_zipcode" VALUES(33143,74563,-6,'Red Oak, Oklahoma 74563',24433,29671);
INSERT INTO "django_geo_db_zipcode" VALUES(33144,74565,-6,'Savanna, Oklahoma 74565',24434,29672);
INSERT INTO "django_geo_db_zipcode" VALUES(33145,74567,-6,'Snow, Oklahoma 74567',24435,29673);
INSERT INTO "django_geo_db_zipcode" VALUES(33146,74569,-6,'Stringtown, Oklahoma 74569',24436,29674);
INSERT INTO "django_geo_db_zipcode" VALUES(33147,74570,-6,'Stuart, Oklahoma 74570',24437,29675);
INSERT INTO "django_geo_db_zipcode" VALUES(33148,74571,-6,'Talihina, Oklahoma 74571',24438,29676);
INSERT INTO "django_geo_db_zipcode" VALUES(33149,74572,-6,'Tupelo, Oklahoma 74572',24439,29677);
INSERT INTO "django_geo_db_zipcode" VALUES(33150,74574,-6,'Tuskahoma, Oklahoma 74574',24440,29678);
INSERT INTO "django_geo_db_zipcode" VALUES(33151,74576,-6,'Wardville, Oklahoma 74576',24441,29679);
INSERT INTO "django_geo_db_zipcode" VALUES(33152,74577,-6,'Whitesboro, Oklahoma 74577',24442,29680);
INSERT INTO "django_geo_db_zipcode" VALUES(33153,74578,-6,'Wilburton, Oklahoma 74578',24443,29681);
INSERT INTO "django_geo_db_zipcode" VALUES(33154,74601,-6,'Ponca City, Oklahoma 74601',24444,29682);
INSERT INTO "django_geo_db_zipcode" VALUES(33155,74602,-6,'Ponca City, Oklahoma 74602',24444,29683);
INSERT INTO "django_geo_db_zipcode" VALUES(33156,74603,-6,'Ponca City, Oklahoma 74603',24444,29684);
INSERT INTO "django_geo_db_zipcode" VALUES(33157,74604,-6,'Ponca City, Oklahoma 74604',24444,29685);
INSERT INTO "django_geo_db_zipcode" VALUES(33158,74630,-6,'Billings, Oklahoma 74630',24445,29686);
INSERT INTO "django_geo_db_zipcode" VALUES(33159,74631,-6,'Blackwell, Oklahoma 74631',24446,29687);
INSERT INTO "django_geo_db_zipcode" VALUES(33160,74632,-6,'Braman, Oklahoma 74632',24447,29688);
INSERT INTO "django_geo_db_zipcode" VALUES(33161,74633,-6,'Burbank, Oklahoma 74633',24448,29689);
INSERT INTO "django_geo_db_zipcode" VALUES(33162,74636,-6,'Deer Creek, Oklahoma 74636',24449,29690);
INSERT INTO "django_geo_db_zipcode" VALUES(33163,74637,-6,'Fairfax, Oklahoma 74637',24450,29691);
INSERT INTO "django_geo_db_zipcode" VALUES(33164,74640,-6,'Hunter, Oklahoma 74640',24451,29692);
INSERT INTO "django_geo_db_zipcode" VALUES(33165,74641,-6,'Kaw City, Oklahoma 74641',24452,29693);
INSERT INTO "django_geo_db_zipcode" VALUES(33166,74643,-6,'Lamont, Oklahoma 74643',24453,29694);
INSERT INTO "django_geo_db_zipcode" VALUES(33167,74644,-6,'Marland, Oklahoma 74644',24454,29695);
INSERT INTO "django_geo_db_zipcode" VALUES(33168,74646,-6,'Nardin, Oklahoma 74646',24455,29696);
INSERT INTO "django_geo_db_zipcode" VALUES(33169,74647,-6,'Newkirk, Oklahoma 74647',24456,29697);
INSERT INTO "django_geo_db_zipcode" VALUES(33170,74650,-6,'Ralston, Oklahoma 74650',24457,29698);
INSERT INTO "django_geo_db_zipcode" VALUES(33171,74651,-6,'Red Rock, Oklahoma 74651',24458,29699);
INSERT INTO "django_geo_db_zipcode" VALUES(33172,74652,-6,'Shidler, Oklahoma 74652',24459,29700);
INSERT INTO "django_geo_db_zipcode" VALUES(33173,74653,-6,'Tonkawa, Oklahoma 74653',24460,29701);
INSERT INTO "django_geo_db_zipcode" VALUES(33174,74701,-6,'Durant, Oklahoma 74701',24461,29702);
INSERT INTO "django_geo_db_zipcode" VALUES(33175,74702,-6,'Durant, Oklahoma 74702',24461,29703);
INSERT INTO "django_geo_db_zipcode" VALUES(33176,74720,-6,'Achille, Oklahoma 74720',24462,29704);
INSERT INTO "django_geo_db_zipcode" VALUES(33177,74721,-6,'Albany, Oklahoma 74721',24463,29705);
INSERT INTO "django_geo_db_zipcode" VALUES(33178,74722,-6,'Battiest, Oklahoma 74722',24464,29706);
INSERT INTO "django_geo_db_zipcode" VALUES(33179,74723,-6,'Bennington, Oklahoma 74723',24465,29707);
INSERT INTO "django_geo_db_zipcode" VALUES(33180,74724,-6,'Bethel, Oklahoma 74724',24466,29708);
INSERT INTO "django_geo_db_zipcode" VALUES(33181,74726,-6,'Bokchito, Oklahoma 74726',24467,29709);
INSERT INTO "django_geo_db_zipcode" VALUES(33182,74727,-6,'Boswell, Oklahoma 74727',24468,29710);
INSERT INTO "django_geo_db_zipcode" VALUES(33183,74728,-6,'Broken Bow, Oklahoma 74728',24469,29711);
INSERT INTO "django_geo_db_zipcode" VALUES(33184,74729,-6,'Caddo, Oklahoma 74729',24470,29712);
INSERT INTO "django_geo_db_zipcode" VALUES(33185,74730,-6,'Calera, Oklahoma 74730',24471,29713);
INSERT INTO "django_geo_db_zipcode" VALUES(33186,74731,-6,'Cartwright, Oklahoma 74731',24472,29714);
INSERT INTO "django_geo_db_zipcode" VALUES(33187,74733,-6,'Colbert, Oklahoma 74733',24473,29715);
INSERT INTO "django_geo_db_zipcode" VALUES(33188,74734,-6,'Eagletown, Oklahoma 74734',24474,29716);
INSERT INTO "django_geo_db_zipcode" VALUES(33189,74735,-6,'Fort Towson, Oklahoma 74735',24475,29717);
INSERT INTO "django_geo_db_zipcode" VALUES(33190,74736,-6,'Garvin, Oklahoma 74736',24476,29718);
INSERT INTO "django_geo_db_zipcode" VALUES(33191,74737,-6,'Golden, Oklahoma 74737',24477,29719);
INSERT INTO "django_geo_db_zipcode" VALUES(33192,74738,-6,'Grant, Oklahoma 74738',24478,29720);
INSERT INTO "django_geo_db_zipcode" VALUES(33193,74740,-6,'Haworth, Oklahoma 74740',24479,29721);
INSERT INTO "django_geo_db_zipcode" VALUES(33194,74741,-6,'Hendrix, Oklahoma 74741',24480,29722);
INSERT INTO "django_geo_db_zipcode" VALUES(33195,74743,-6,'Hugo, Oklahoma 74743',24481,29723);
INSERT INTO "django_geo_db_zipcode" VALUES(33196,74745,-6,'Idabel, Oklahoma 74745',24482,29724);
INSERT INTO "django_geo_db_zipcode" VALUES(33197,74747,-6,'Kemp, Oklahoma 74747',24483,29725);
INSERT INTO "django_geo_db_zipcode" VALUES(33198,74748,-6,'Kenefic, Oklahoma 74748',24484,29726);
INSERT INTO "django_geo_db_zipcode" VALUES(33199,74750,-6,'Millerton, Oklahoma 74750',24485,29727);
INSERT INTO "django_geo_db_zipcode" VALUES(33200,74752,-6,'Pickens, Oklahoma 74752',24486,29728);
INSERT INTO "django_geo_db_zipcode" VALUES(33201,74753,-6,'Platter, Oklahoma 74753',24487,29729);
INSERT INTO "django_geo_db_zipcode" VALUES(33202,74754,-6,'Ringold, Oklahoma 74754',24488,29730);
INSERT INTO "django_geo_db_zipcode" VALUES(33203,74755,-6,'Rufe, Oklahoma 74755',24489,29731);
INSERT INTO "django_geo_db_zipcode" VALUES(33204,74756,-6,'Sawyer, Oklahoma 74756',24490,29732);
INSERT INTO "django_geo_db_zipcode" VALUES(33205,74759,-6,'Soper, Oklahoma 74759',24491,29733);
INSERT INTO "django_geo_db_zipcode" VALUES(33206,74760,-6,'Spencerville, Oklahoma 74760',24492,29734);
INSERT INTO "django_geo_db_zipcode" VALUES(33207,74761,-6,'Swink, Oklahoma 74761',24493,29735);
INSERT INTO "django_geo_db_zipcode" VALUES(33208,74764,-6,'Valliant, Oklahoma 74764',24494,29736);
INSERT INTO "django_geo_db_zipcode" VALUES(33209,74766,-6,'Wright City, Oklahoma 74766',24495,29737);
INSERT INTO "django_geo_db_zipcode" VALUES(33210,74801,-6,'Shawnee, Oklahoma 74801',24496,29738);
INSERT INTO "django_geo_db_zipcode" VALUES(33211,74802,-6,'Shawnee, Oklahoma 74802',24496,29739);
INSERT INTO "django_geo_db_zipcode" VALUES(33212,74804,-6,'Shawnee, Oklahoma 74804',24496,29740);
INSERT INTO "django_geo_db_zipcode" VALUES(33213,74807,-6,'Shawnee, Oklahoma 74807',24496,29741);
INSERT INTO "django_geo_db_zipcode" VALUES(33214,74818,-6,'Seminole, Oklahoma 74818',24497,29742);
INSERT INTO "django_geo_db_zipcode" VALUES(33215,74820,-6,'Ada, Oklahoma 74820',24402,29743);
INSERT INTO "django_geo_db_zipcode" VALUES(33216,74821,-6,'Ada, Oklahoma 74821',24402,29744);
INSERT INTO "django_geo_db_zipcode" VALUES(33217,74824,-6,'Agra, Oklahoma 74824',24498,29745);
INSERT INTO "django_geo_db_zipcode" VALUES(33218,74825,-6,'Allen, Oklahoma 74825',24499,29746);
INSERT INTO "django_geo_db_zipcode" VALUES(33219,74826,-6,'Asher, Oklahoma 74826',24500,29747);
INSERT INTO "django_geo_db_zipcode" VALUES(33220,74827,-6,'Atwood, Oklahoma 74827',24501,29748);
INSERT INTO "django_geo_db_zipcode" VALUES(33221,74829,-6,'Boley, Oklahoma 74829',24502,29749);
INSERT INTO "django_geo_db_zipcode" VALUES(33222,74830,-6,'Bowlegs, Oklahoma 74830',24503,29750);
INSERT INTO "django_geo_db_zipcode" VALUES(33223,74831,-6,'Byars, Oklahoma 74831',24504,29751);
INSERT INTO "django_geo_db_zipcode" VALUES(33224,74832,-6,'Carney, Oklahoma 74832',24505,29752);
INSERT INTO "django_geo_db_zipcode" VALUES(33225,74833,-6,'Castle, Oklahoma 74833',24506,29753);
INSERT INTO "django_geo_db_zipcode" VALUES(33226,74834,-6,'Chandler, Oklahoma 74834',24507,29754);
INSERT INTO "django_geo_db_zipcode" VALUES(33227,74836,-6,'Connerville, Oklahoma 74836',24508,29755);
INSERT INTO "django_geo_db_zipcode" VALUES(33228,74837,-6,'Cromwell, Oklahoma 74837',24509,29756);
INSERT INTO "django_geo_db_zipcode" VALUES(33229,74839,-6,'Dustin, Oklahoma 74839',24510,29757);
INSERT INTO "django_geo_db_zipcode" VALUES(33230,74840,-6,'Earlsboro, Oklahoma 74840',24511,29758);
INSERT INTO "django_geo_db_zipcode" VALUES(33231,74842,-6,'Fittstown, Oklahoma 74842',24512,29759);
INSERT INTO "django_geo_db_zipcode" VALUES(33232,74843,-6,'Fitzhugh, Oklahoma 74843',24513,29760);
INSERT INTO "django_geo_db_zipcode" VALUES(33233,74844,-6,'Francis, Oklahoma 74844',24514,29761);
INSERT INTO "django_geo_db_zipcode" VALUES(33234,74845,-6,'Hanna, Oklahoma 74845',24515,29762);
INSERT INTO "django_geo_db_zipcode" VALUES(33235,74848,-6,'Holdenville, Oklahoma 74848',24516,29763);
INSERT INTO "django_geo_db_zipcode" VALUES(33236,74849,-6,'Konawa, Oklahoma 74849',24517,29764);
INSERT INTO "django_geo_db_zipcode" VALUES(33237,74850,-6,'Lamar, Oklahoma 74850',24518,29765);
INSERT INTO "django_geo_db_zipcode" VALUES(33238,74851,-6,'Mcloud, Oklahoma 74851',24519,29766);
INSERT INTO "django_geo_db_zipcode" VALUES(33239,74852,-6,'Macomb, Oklahoma 74852',24520,29767);
INSERT INTO "django_geo_db_zipcode" VALUES(33240,74853,-6,'Wetumka, Oklahoma 74853',24521,29768);
INSERT INTO "django_geo_db_zipcode" VALUES(33241,74854,-6,'Maud, Oklahoma 74854',24522,29769);
INSERT INTO "django_geo_db_zipcode" VALUES(33242,74855,-6,'Meeker, Oklahoma 74855',24523,29770);
INSERT INTO "django_geo_db_zipcode" VALUES(33243,74856,-6,'Mill Creek, Oklahoma 74856',24524,29771);
INSERT INTO "django_geo_db_zipcode" VALUES(33244,74857,-6,'Newalla, Oklahoma 74857',24525,29772);
INSERT INTO "django_geo_db_zipcode" VALUES(33245,74859,-6,'Okemah, Oklahoma 74859',24526,29773);
INSERT INTO "django_geo_db_zipcode" VALUES(33246,74860,-6,'Paden, Oklahoma 74860',24527,29774);
INSERT INTO "django_geo_db_zipcode" VALUES(33247,74864,-6,'Prague, Oklahoma 74864',24528,29775);
INSERT INTO "django_geo_db_zipcode" VALUES(33248,74865,-6,'Roff, Oklahoma 74865',24529,29776);
INSERT INTO "django_geo_db_zipcode" VALUES(33249,74866,-6,'Saint Louis, Oklahoma 74866',24530,29777);
INSERT INTO "django_geo_db_zipcode" VALUES(33250,74867,-6,'Sasakwa, Oklahoma 74867',24531,29778);
INSERT INTO "django_geo_db_zipcode" VALUES(33251,74868,-6,'Seminole, Oklahoma 74868',24497,29779);
INSERT INTO "django_geo_db_zipcode" VALUES(33252,74869,-6,'Sparks, Oklahoma 74869',24532,29780);
INSERT INTO "django_geo_db_zipcode" VALUES(33253,74871,-6,'Stonewall, Oklahoma 74871',24533,29781);
INSERT INTO "django_geo_db_zipcode" VALUES(33254,74872,-6,'Stratford, Oklahoma 74872',24534,29782);
INSERT INTO "django_geo_db_zipcode" VALUES(33255,74873,-6,'Tecumseh, Oklahoma 74873',24535,29783);
INSERT INTO "django_geo_db_zipcode" VALUES(33256,74875,-6,'Tryon, Oklahoma 74875',24536,29784);
INSERT INTO "django_geo_db_zipcode" VALUES(33257,74878,-6,'Wanette, Oklahoma 74878',24537,29785);
INSERT INTO "django_geo_db_zipcode" VALUES(33258,74880,-6,'Weleetka, Oklahoma 74880',24538,29786);
INSERT INTO "django_geo_db_zipcode" VALUES(33259,74881,-6,'Wellston, Oklahoma 74881',24539,29787);
INSERT INTO "django_geo_db_zipcode" VALUES(33260,74883,-6,'Wetumka, Oklahoma 74883',24521,29788);
INSERT INTO "django_geo_db_zipcode" VALUES(33261,74884,-6,'Wewoka, Oklahoma 74884',24540,29789);
INSERT INTO "django_geo_db_zipcode" VALUES(33262,74894,-6,'Konawa, Oklahoma 74894',24517,29790);
INSERT INTO "django_geo_db_zipcode" VALUES(33263,74901,-6,'Arkoma, Oklahoma 74901',24541,29791);
INSERT INTO "django_geo_db_zipcode" VALUES(33264,74902,-6,'Pocola, Oklahoma 74902',24542,29792);
INSERT INTO "django_geo_db_zipcode" VALUES(33265,74930,-6,'Bokoshe, Oklahoma 74930',24543,29793);
INSERT INTO "django_geo_db_zipcode" VALUES(33266,74931,-6,'Bunch, Oklahoma 74931',24544,29794);
INSERT INTO "django_geo_db_zipcode" VALUES(33267,74932,-6,'Cameron, Oklahoma 74932',24545,29795);
INSERT INTO "django_geo_db_zipcode" VALUES(33268,74935,-6,'Fanshawe, Oklahoma 74935',24546,29796);
INSERT INTO "django_geo_db_zipcode" VALUES(33269,74936,-6,'Gans, Oklahoma 74936',24547,29797);
INSERT INTO "django_geo_db_zipcode" VALUES(33270,74937,-6,'Heavener, Oklahoma 74937',24548,29798);
INSERT INTO "django_geo_db_zipcode" VALUES(33271,74939,-6,'Hodgen, Oklahoma 74939',24549,29799);
INSERT INTO "django_geo_db_zipcode" VALUES(33272,74940,-6,'Howe, Oklahoma 74940',24550,29800);
INSERT INTO "django_geo_db_zipcode" VALUES(33273,74941,-6,'Keota, Oklahoma 74941',24551,29801);
INSERT INTO "django_geo_db_zipcode" VALUES(33274,74942,-6,'Leflore, Oklahoma 74942',24552,29802);
INSERT INTO "django_geo_db_zipcode" VALUES(33275,74943,-6,'Lequire, Oklahoma 74943',24553,29803);
INSERT INTO "django_geo_db_zipcode" VALUES(33276,74944,-6,'Mccurtain, Oklahoma 74944',24554,29804);
INSERT INTO "django_geo_db_zipcode" VALUES(33277,74945,-6,'Marble City, Oklahoma 74945',24555,29805);
INSERT INTO "django_geo_db_zipcode" VALUES(33278,74946,-6,'Moffett, Oklahoma 74946',24556,29806);
INSERT INTO "django_geo_db_zipcode" VALUES(33279,74947,-6,'Monroe, Oklahoma 74947',24557,29807);
INSERT INTO "django_geo_db_zipcode" VALUES(33280,74948,-6,'Muldrow, Oklahoma 74948',24558,29808);
INSERT INTO "django_geo_db_zipcode" VALUES(33281,74949,-6,'Muse, Oklahoma 74949',24559,29809);
INSERT INTO "django_geo_db_zipcode" VALUES(33282,74951,-6,'Panama, Oklahoma 74951',24560,29810);
INSERT INTO "django_geo_db_zipcode" VALUES(33283,74953,-6,'Poteau, Oklahoma 74953',24561,29811);
INSERT INTO "django_geo_db_zipcode" VALUES(33284,74954,-6,'Roland, Oklahoma 74954',24562,29812);
INSERT INTO "django_geo_db_zipcode" VALUES(33285,74955,-6,'Sallisaw, Oklahoma 74955',24563,29813);
INSERT INTO "django_geo_db_zipcode" VALUES(33286,74956,-6,'Shady Point, Oklahoma 74956',24564,29814);
INSERT INTO "django_geo_db_zipcode" VALUES(33287,74957,-6,'Smithville, Oklahoma 74957',24565,29815);
INSERT INTO "django_geo_db_zipcode" VALUES(33288,74959,-6,'Spiro, Oklahoma 74959',24566,29816);
INSERT INTO "django_geo_db_zipcode" VALUES(33289,74960,-6,'Stilwell, Oklahoma 74960',24567,29817);
INSERT INTO "django_geo_db_zipcode" VALUES(33290,74962,-6,'Vian, Oklahoma 74962',24568,29818);
INSERT INTO "django_geo_db_zipcode" VALUES(33291,74963,-6,'Watson, Oklahoma 74963',24569,29819);
INSERT INTO "django_geo_db_zipcode" VALUES(33292,74964,-6,'Watts, Oklahoma 74964',24570,29820);
INSERT INTO "django_geo_db_zipcode" VALUES(33293,74965,-6,'Westville, Oklahoma 74965',24571,29821);
INSERT INTO "django_geo_db_zipcode" VALUES(33294,74966,-6,'Wister, Oklahoma 74966',24572,29822);
INSERT INTO "django_geo_db_zipcode" VALUES(33295,74968,-6,'Muldrow, Oklahoma 74968',24558,29823);
INSERT INTO "django_geo_db_zipcode" VALUES(33296,75001,-6,'Addison, Texas 75001',24573,29824);
INSERT INTO "django_geo_db_zipcode" VALUES(33297,75002,-6,'Allen, Texas 75002',24574,29825);
INSERT INTO "django_geo_db_zipcode" VALUES(33298,75006,-6,'Carrollton, Texas 75006',24575,29826);
INSERT INTO "django_geo_db_zipcode" VALUES(33299,75007,-6,'Carrollton, Texas 75007',24575,29827);
INSERT INTO "django_geo_db_zipcode" VALUES(33300,75008,-6,'Carrollton, Texas 75008',24575,29828);
INSERT INTO "django_geo_db_zipcode" VALUES(33301,75009,-6,'Celina, Texas 75009',24576,29829);
INSERT INTO "django_geo_db_zipcode" VALUES(33302,75010,-6,'Carrollton, Texas 75010',24575,29830);
INSERT INTO "django_geo_db_zipcode" VALUES(33303,75011,-6,'Carrollton, Texas 75011',24575,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33304,75013,-6,'Allen, Texas 75013',24574,29832);
INSERT INTO "django_geo_db_zipcode" VALUES(33305,75014,-6,'Irving, Texas 75014',24577,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33306,75015,-6,'Irving, Texas 75015',24577,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33307,75016,-6,'Irving, Texas 75016',24577,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33308,75017,-6,'Irving, Texas 75017',24577,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33309,75019,-6,'Coppell, Texas 75019',24578,29833);
INSERT INTO "django_geo_db_zipcode" VALUES(33310,75020,-6,'Denison, Texas 75020',24579,29834);
INSERT INTO "django_geo_db_zipcode" VALUES(33311,75021,-6,'Denison, Texas 75021',24579,29835);
INSERT INTO "django_geo_db_zipcode" VALUES(33312,75022,-6,'Flower Mound, Texas 75022',24580,29836);
INSERT INTO "django_geo_db_zipcode" VALUES(33313,75023,-6,'Plano, Texas 75023',24581,29837);
INSERT INTO "django_geo_db_zipcode" VALUES(33314,75024,-6,'Plano, Texas 75024',24581,29838);
INSERT INTO "django_geo_db_zipcode" VALUES(33315,75025,-6,'Plano, Texas 75025',24581,29839);
INSERT INTO "django_geo_db_zipcode" VALUES(33316,75026,-6,'Plano, Texas 75026',24581,29840);
INSERT INTO "django_geo_db_zipcode" VALUES(33317,75027,-6,'Flower Mound, Texas 75027',24580,29828);
INSERT INTO "django_geo_db_zipcode" VALUES(33318,75028,-6,'Flower Mound, Texas 75028',24580,29841);
INSERT INTO "django_geo_db_zipcode" VALUES(33319,75029,-6,'Lewisville, Texas 75029',24582,29828);
INSERT INTO "django_geo_db_zipcode" VALUES(33320,75030,-6,'Rowlett, Texas 75030',24583,29842);
INSERT INTO "django_geo_db_zipcode" VALUES(33321,75032,-6,'Rockwall, Texas 75032',24584,29843);
INSERT INTO "django_geo_db_zipcode" VALUES(33322,75034,-6,'Frisco, Texas 75034',24585,29844);
INSERT INTO "django_geo_db_zipcode" VALUES(33323,75035,-6,'Frisco, Texas 75035',24585,29845);
INSERT INTO "django_geo_db_zipcode" VALUES(33324,75037,-6,'Irving, Texas 75037',24577,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33325,75038,-6,'Irving, Texas 75038',24577,29846);
INSERT INTO "django_geo_db_zipcode" VALUES(33326,75039,-6,'Irving, Texas 75039',24577,29847);
INSERT INTO "django_geo_db_zipcode" VALUES(33327,75040,-6,'Garland, Texas 75040',24586,29848);
INSERT INTO "django_geo_db_zipcode" VALUES(33328,75041,-6,'Garland, Texas 75041',24586,29849);
INSERT INTO "django_geo_db_zipcode" VALUES(33329,75042,-6,'Garland, Texas 75042',24586,29850);
INSERT INTO "django_geo_db_zipcode" VALUES(33330,75043,-6,'Garland, Texas 75043',24586,29851);
INSERT INTO "django_geo_db_zipcode" VALUES(33331,75044,-6,'Garland, Texas 75044',24586,29852);
INSERT INTO "django_geo_db_zipcode" VALUES(33332,75045,-6,'Garland, Texas 75045',24586,29853);
INSERT INTO "django_geo_db_zipcode" VALUES(33333,75046,-6,'Garland, Texas 75046',24586,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33334,75047,-6,'Garland, Texas 75047',24586,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33335,75048,-6,'Garland, Texas 75048',24586,29854);
INSERT INTO "django_geo_db_zipcode" VALUES(33336,75049,-6,'Garland, Texas 75049',24586,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33337,75050,-6,'Grand Prairie, Texas 75050',24587,29855);
INSERT INTO "django_geo_db_zipcode" VALUES(33338,75051,-6,'Grand Prairie, Texas 75051',24587,29856);
INSERT INTO "django_geo_db_zipcode" VALUES(33339,75052,-6,'Grand Prairie, Texas 75052',24587,29857);
INSERT INTO "django_geo_db_zipcode" VALUES(33340,75053,-6,'Grand Prairie, Texas 75053',24587,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33341,75054,-6,'Grand Prairie, Texas 75054',24587,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33342,75056,-6,'The Colony, Texas 75056',24588,29858);
INSERT INTO "django_geo_db_zipcode" VALUES(33343,75057,-6,'Lewisville, Texas 75057',24582,29859);
INSERT INTO "django_geo_db_zipcode" VALUES(33344,75058,-6,'Gunter, Texas 75058',24589,29860);
INSERT INTO "django_geo_db_zipcode" VALUES(33345,75059,-6,'Irving, Texas 75059',24577,29861);
INSERT INTO "django_geo_db_zipcode" VALUES(33346,75060,-6,'Irving, Texas 75060',24577,29862);
INSERT INTO "django_geo_db_zipcode" VALUES(33347,75061,-6,'Irving, Texas 75061',24577,29863);
INSERT INTO "django_geo_db_zipcode" VALUES(33348,75062,-6,'Irving, Texas 75062',24577,29864);
INSERT INTO "django_geo_db_zipcode" VALUES(33349,75063,-6,'Irving, Texas 75063',24577,29865);
INSERT INTO "django_geo_db_zipcode" VALUES(33350,75065,-6,'Lake Dallas, Texas 75065',24590,29866);
INSERT INTO "django_geo_db_zipcode" VALUES(33351,75066,-6,'Carrollton, Texas 75066',24575,29867);
INSERT INTO "django_geo_db_zipcode" VALUES(33352,75067,-6,'Lewisville, Texas 75067',24582,29868);
INSERT INTO "django_geo_db_zipcode" VALUES(33353,75068,-6,'Little Elm, Texas 75068',24591,29869);
INSERT INTO "django_geo_db_zipcode" VALUES(33354,75069,-6,'McKinney, Texas 75069',24592,29870);
INSERT INTO "django_geo_db_zipcode" VALUES(33355,75070,-6,'McKinney, Texas 75070',24592,29871);
INSERT INTO "django_geo_db_zipcode" VALUES(33356,75071,-6,'Frisco, Texas 75071',24585,29872);
INSERT INTO "django_geo_db_zipcode" VALUES(33357,75074,-6,'Plano, Texas 75074',24581,29873);
INSERT INTO "django_geo_db_zipcode" VALUES(33358,75075,-6,'Plano, Texas 75075',24581,29874);
INSERT INTO "django_geo_db_zipcode" VALUES(33359,75076,-6,'Pottsboro, Texas 75076',24593,29875);
INSERT INTO "django_geo_db_zipcode" VALUES(33360,75077,-6,'Lewisville, Texas 75077',24582,29876);
INSERT INTO "django_geo_db_zipcode" VALUES(33361,75078,-6,'Prosper, Texas 75078',24594,29877);
INSERT INTO "django_geo_db_zipcode" VALUES(33362,75080,-6,'Richardson, Texas 75080',24595,29878);
INSERT INTO "django_geo_db_zipcode" VALUES(33363,75081,-6,'Richardson, Texas 75081',24595,29879);
INSERT INTO "django_geo_db_zipcode" VALUES(33364,75082,-6,'Richardson, Texas 75082',24595,29880);
INSERT INTO "django_geo_db_zipcode" VALUES(33365,75083,-6,'Richardson, Texas 75083',24595,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33366,75085,-6,'Richardson, Texas 75085',24595,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33367,75086,-6,'Plano, Texas 75086',24581,29881);
INSERT INTO "django_geo_db_zipcode" VALUES(33368,75087,-6,'Rockwall, Texas 75087',24584,29882);
INSERT INTO "django_geo_db_zipcode" VALUES(33369,75088,-6,'Rowlett, Texas 75088',24583,29883);
INSERT INTO "django_geo_db_zipcode" VALUES(33370,75089,-6,'Rowlett, Texas 75089',24583,29884);
INSERT INTO "django_geo_db_zipcode" VALUES(33371,75090,-6,'Sherman, Texas 75090',24596,29885);
INSERT INTO "django_geo_db_zipcode" VALUES(33372,75091,-6,'Sherman, Texas 75091',24596,29886);
INSERT INTO "django_geo_db_zipcode" VALUES(33373,75092,-6,'Sherman, Texas 75092',24596,29887);
INSERT INTO "django_geo_db_zipcode" VALUES(33374,75093,-6,'Plano, Texas 75093',24581,29888);
INSERT INTO "django_geo_db_zipcode" VALUES(33375,75094,-6,'Plano, Texas 75094',24581,29889);
INSERT INTO "django_geo_db_zipcode" VALUES(33376,75097,-6,'Weston, Texas 75097',24597,29890);
INSERT INTO "django_geo_db_zipcode" VALUES(33377,75098,-6,'Wylie, Texas 75098',24598,29891);
INSERT INTO "django_geo_db_zipcode" VALUES(33378,75099,-6,'Coppell, Texas 75099',24578,29892);
INSERT INTO "django_geo_db_zipcode" VALUES(33379,75101,-6,'Bardwell, Texas 75101',24599,29893);
INSERT INTO "django_geo_db_zipcode" VALUES(33380,75102,-6,'Barry, Texas 75102',24600,29894);
INSERT INTO "django_geo_db_zipcode" VALUES(33381,75103,-6,'Canton, Texas 75103',24601,29895);
INSERT INTO "django_geo_db_zipcode" VALUES(33382,75104,-6,'Cedar Hill, Texas 75104',24602,29896);
INSERT INTO "django_geo_db_zipcode" VALUES(33383,75105,-6,'Chatfield, Texas 75105',24603,29897);
INSERT INTO "django_geo_db_zipcode" VALUES(33384,75106,-6,'Cedar Hill, Texas 75106',24602,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33385,75109,-6,'Angus, Texas 75109',24604,29898);
INSERT INTO "django_geo_db_zipcode" VALUES(33386,75110,-6,'Corsicana, Texas 75110',24605,29899);
INSERT INTO "django_geo_db_zipcode" VALUES(33387,75114,-6,'Crandall, Texas 75114',24606,29900);
INSERT INTO "django_geo_db_zipcode" VALUES(33388,75115,-6,'Desoto, Texas 75115',24607,29901);
INSERT INTO "django_geo_db_zipcode" VALUES(33389,75116,-6,'Duncanville, Texas 75116',24608,29902);
INSERT INTO "django_geo_db_zipcode" VALUES(33390,75117,-6,'Edgewood, Texas 75117',24609,29903);
INSERT INTO "django_geo_db_zipcode" VALUES(33391,75118,-6,'Elmo, Texas 75118',24610,29904);
INSERT INTO "django_geo_db_zipcode" VALUES(33392,75119,-6,'Ennis, Texas 75119',24611,29905);
INSERT INTO "django_geo_db_zipcode" VALUES(33393,75120,-6,'Ennis, Texas 75120',24611,29906);
INSERT INTO "django_geo_db_zipcode" VALUES(33394,75121,-6,'Copeville, Texas 75121',24612,29907);
INSERT INTO "django_geo_db_zipcode" VALUES(33395,75123,-6,'Desoto, Texas 75123',24607,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33396,75124,-6,'Eustace, Texas 75124',24613,29908);
INSERT INTO "django_geo_db_zipcode" VALUES(33397,75125,-6,'Ferris, Texas 75125',24614,29909);
INSERT INTO "django_geo_db_zipcode" VALUES(33398,75126,-6,'Forney, Texas 75126',24615,29910);
INSERT INTO "django_geo_db_zipcode" VALUES(33399,75127,-6,'Fruitvale, Texas 75127',24616,29911);
INSERT INTO "django_geo_db_zipcode" VALUES(33400,75132,-6,'Fate, Texas 75132',24617,29912);
INSERT INTO "django_geo_db_zipcode" VALUES(33401,75134,-6,'Lancaster, Texas 75134',24618,29913);
INSERT INTO "django_geo_db_zipcode" VALUES(33402,75135,-6,'Caddo Mills, Texas 75135',24619,29914);
INSERT INTO "django_geo_db_zipcode" VALUES(33403,75137,-6,'Duncanville, Texas 75137',24608,29915);
INSERT INTO "django_geo_db_zipcode" VALUES(33404,75138,-6,'Duncanville, Texas 75138',24608,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33405,75140,-6,'Grand Saline, Texas 75140',24620,29916);
INSERT INTO "django_geo_db_zipcode" VALUES(33406,75141,-6,'Hutchins, Texas 75141',24621,29917);
INSERT INTO "django_geo_db_zipcode" VALUES(33407,75142,-6,'Kaufman, Texas 75142',24622,29918);
INSERT INTO "django_geo_db_zipcode" VALUES(33408,75143,-6,'Kemp, Texas 75143',24623,29919);
INSERT INTO "django_geo_db_zipcode" VALUES(33409,75144,-6,'Kerens, Texas 75144',24624,29920);
INSERT INTO "django_geo_db_zipcode" VALUES(33410,75146,-6,'Lancaster, Texas 75146',24618,29921);
INSERT INTO "django_geo_db_zipcode" VALUES(33411,75147,-6,'Mabank, Texas 75147',24625,29922);
INSERT INTO "django_geo_db_zipcode" VALUES(33412,75148,-6,'Malakoff, Texas 75148',24626,29923);
INSERT INTO "django_geo_db_zipcode" VALUES(33413,75149,-6,'Mesquite, Texas 75149',24627,29924);
INSERT INTO "django_geo_db_zipcode" VALUES(33414,75150,-6,'Mesquite, Texas 75150',24627,29925);
INSERT INTO "django_geo_db_zipcode" VALUES(33415,75151,-6,'Corsicana, Texas 75151',24605,29926);
INSERT INTO "django_geo_db_zipcode" VALUES(33416,75152,-6,'Palmer, Texas 75152',24628,29927);
INSERT INTO "django_geo_db_zipcode" VALUES(33417,75153,-6,'Powell, Texas 75153',24629,29928);
INSERT INTO "django_geo_db_zipcode" VALUES(33418,75154,-6,'Red Oak, Texas 75154',24630,29929);
INSERT INTO "django_geo_db_zipcode" VALUES(33419,75155,-6,'Rice, Texas 75155',24631,29930);
INSERT INTO "django_geo_db_zipcode" VALUES(33420,75156,-6,'Gun Barrel City, Texas 75156',24632,29931);
INSERT INTO "django_geo_db_zipcode" VALUES(33421,75157,-6,'Rosser, Texas 75157',24633,29932);
INSERT INTO "django_geo_db_zipcode" VALUES(33422,75158,-6,'Scurry, Texas 75158',24634,29933);
INSERT INTO "django_geo_db_zipcode" VALUES(33423,75159,-6,'Seagoville, Texas 75159',24635,29934);
INSERT INTO "django_geo_db_zipcode" VALUES(33424,75160,-6,'Terrell, Texas 75160',24636,29935);
INSERT INTO "django_geo_db_zipcode" VALUES(33425,75161,-6,'Terrell, Texas 75161',24636,29936);
INSERT INTO "django_geo_db_zipcode" VALUES(33426,75163,-6,'Trinidad, Texas 75163',24637,29937);
INSERT INTO "django_geo_db_zipcode" VALUES(33427,75164,-6,'Josephine, Texas 75164',24638,29938);
INSERT INTO "django_geo_db_zipcode" VALUES(33428,75165,-6,'Waxahachie, Texas 75165',24639,29939);
INSERT INTO "django_geo_db_zipcode" VALUES(33429,75166,-6,'Lavon, Texas 75166',24640,29940);
INSERT INTO "django_geo_db_zipcode" VALUES(33430,75167,-6,'Waxahachie, Texas 75167',24639,29941);
INSERT INTO "django_geo_db_zipcode" VALUES(33431,75168,-6,'Waxahachie, Texas 75168',24639,29942);
INSERT INTO "django_geo_db_zipcode" VALUES(33432,75169,-6,'Wills Point, Texas 75169',24641,29943);
INSERT INTO "django_geo_db_zipcode" VALUES(33433,75172,-6,'Wilmer, Texas 75172',24642,29944);
INSERT INTO "django_geo_db_zipcode" VALUES(33434,75173,-6,'Nevada, Texas 75173',24643,29945);
INSERT INTO "django_geo_db_zipcode" VALUES(33435,75180,-6,'Mesquite, Texas 75180',24627,29946);
INSERT INTO "django_geo_db_zipcode" VALUES(33436,75181,-6,'Mesquite, Texas 75181',24627,29947);
INSERT INTO "django_geo_db_zipcode" VALUES(33437,75182,-6,'Sunnyvale, Texas 75182',24644,29948);
INSERT INTO "django_geo_db_zipcode" VALUES(33438,75185,-6,'Mesquite, Texas 75185',24627,29949);
INSERT INTO "django_geo_db_zipcode" VALUES(33439,75187,-6,'Mesquite, Texas 75187',24627,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33440,75189,-6,'Royse City, Texas 75189',24645,29950);
INSERT INTO "django_geo_db_zipcode" VALUES(33441,75201,-6,'Dallas, Texas 75201',24646,29951);
INSERT INTO "django_geo_db_zipcode" VALUES(33442,75202,-6,'Dallas, Texas 75202',24646,29952);
INSERT INTO "django_geo_db_zipcode" VALUES(33443,75203,-6,'Dallas, Texas 75203',24646,29953);
INSERT INTO "django_geo_db_zipcode" VALUES(33444,75204,-6,'Dallas, Texas 75204',24646,29954);
INSERT INTO "django_geo_db_zipcode" VALUES(33445,75205,-6,'Dallas, Texas 75205',24646,29955);
INSERT INTO "django_geo_db_zipcode" VALUES(33446,75206,-6,'Dallas, Texas 75206',24646,29956);
INSERT INTO "django_geo_db_zipcode" VALUES(33447,75207,-6,'Dallas, Texas 75207',24646,29957);
INSERT INTO "django_geo_db_zipcode" VALUES(33448,75208,-6,'Dallas, Texas 75208',24646,29958);
INSERT INTO "django_geo_db_zipcode" VALUES(33449,75209,-6,'Dallas, Texas 75209',24646,29959);
INSERT INTO "django_geo_db_zipcode" VALUES(33450,75210,-6,'Dallas, Texas 75210',24646,29960);
INSERT INTO "django_geo_db_zipcode" VALUES(33451,75211,-6,'Dallas, Texas 75211',24646,29961);
INSERT INTO "django_geo_db_zipcode" VALUES(33452,75212,-6,'Dallas, Texas 75212',24646,29962);
INSERT INTO "django_geo_db_zipcode" VALUES(33453,75214,-6,'Dallas, Texas 75214',24646,29963);
INSERT INTO "django_geo_db_zipcode" VALUES(33454,75215,-6,'Dallas, Texas 75215',24646,29964);
INSERT INTO "django_geo_db_zipcode" VALUES(33455,75216,-6,'Dallas, Texas 75216',24646,29965);
INSERT INTO "django_geo_db_zipcode" VALUES(33456,75217,-6,'Dallas, Texas 75217',24646,29966);
INSERT INTO "django_geo_db_zipcode" VALUES(33457,75218,-6,'Dallas, Texas 75218',24646,29967);
INSERT INTO "django_geo_db_zipcode" VALUES(33458,75219,-6,'Dallas, Texas 75219',24646,29968);
INSERT INTO "django_geo_db_zipcode" VALUES(33459,75220,-6,'Dallas, Texas 75220',24646,29969);
INSERT INTO "django_geo_db_zipcode" VALUES(33460,75221,-6,'Dallas, Texas 75221',24646,29970);
INSERT INTO "django_geo_db_zipcode" VALUES(33461,75222,-6,'Dallas, Texas 75222',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33462,75223,-6,'Dallas, Texas 75223',24646,29971);
INSERT INTO "django_geo_db_zipcode" VALUES(33463,75224,-6,'Dallas, Texas 75224',24646,29972);
INSERT INTO "django_geo_db_zipcode" VALUES(33464,75225,-6,'Dallas, Texas 75225',24646,29973);
INSERT INTO "django_geo_db_zipcode" VALUES(33465,75226,-6,'Dallas, Texas 75226',24646,29974);
INSERT INTO "django_geo_db_zipcode" VALUES(33466,75227,-6,'Dallas, Texas 75227',24646,29975);
INSERT INTO "django_geo_db_zipcode" VALUES(33467,75228,-6,'Dallas, Texas 75228',24646,29976);
INSERT INTO "django_geo_db_zipcode" VALUES(33468,75229,-6,'Dallas, Texas 75229',24646,29977);
INSERT INTO "django_geo_db_zipcode" VALUES(33469,75230,-6,'Dallas, Texas 75230',24646,29978);
INSERT INTO "django_geo_db_zipcode" VALUES(33470,75231,-6,'Dallas, Texas 75231',24646,29979);
INSERT INTO "django_geo_db_zipcode" VALUES(33471,75232,-6,'Dallas, Texas 75232',24646,29980);
INSERT INTO "django_geo_db_zipcode" VALUES(33472,75233,-6,'Dallas, Texas 75233',24646,29981);
INSERT INTO "django_geo_db_zipcode" VALUES(33473,75234,-6,'Dallas, Texas 75234',24646,29982);
INSERT INTO "django_geo_db_zipcode" VALUES(33474,75235,-6,'Dallas, Texas 75235',24646,29983);
INSERT INTO "django_geo_db_zipcode" VALUES(33475,75236,-6,'Dallas, Texas 75236',24646,29984);
INSERT INTO "django_geo_db_zipcode" VALUES(33476,75237,-6,'Dallas, Texas 75237',24646,29985);
INSERT INTO "django_geo_db_zipcode" VALUES(33477,75238,-6,'Dallas, Texas 75238',24646,29986);
INSERT INTO "django_geo_db_zipcode" VALUES(33478,75239,-6,'Dallas, Texas 75239',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33479,75240,-6,'Dallas, Texas 75240',24646,29987);
INSERT INTO "django_geo_db_zipcode" VALUES(33480,75241,-6,'Dallas, Texas 75241',24646,29988);
INSERT INTO "django_geo_db_zipcode" VALUES(33481,75242,-6,'Dallas, Texas 75242',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33482,75243,-6,'Dallas, Texas 75243',24646,29989);
INSERT INTO "django_geo_db_zipcode" VALUES(33483,75244,-6,'Dallas, Texas 75244',24646,29990);
INSERT INTO "django_geo_db_zipcode" VALUES(33484,75245,-6,'Dallas, Texas 75245',24646,29991);
INSERT INTO "django_geo_db_zipcode" VALUES(33485,75246,-6,'Dallas, Texas 75246',24646,29992);
INSERT INTO "django_geo_db_zipcode" VALUES(33486,75247,-6,'Dallas, Texas 75247',24646,29993);
INSERT INTO "django_geo_db_zipcode" VALUES(33487,75248,-6,'Dallas, Texas 75248',24646,29994);
INSERT INTO "django_geo_db_zipcode" VALUES(33488,75249,-6,'Dallas, Texas 75249',24646,29995);
INSERT INTO "django_geo_db_zipcode" VALUES(33489,75250,-6,'Dallas, Texas 75250',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33490,75251,-6,'Dallas, Texas 75251',24646,29996);
INSERT INTO "django_geo_db_zipcode" VALUES(33491,75252,-6,'Dallas, Texas 75252',24646,29997);
INSERT INTO "django_geo_db_zipcode" VALUES(33492,75253,-6,'Dallas, Texas 75253',24646,29998);
INSERT INTO "django_geo_db_zipcode" VALUES(33493,75254,-6,'Dallas, Texas 75254',24646,29999);
INSERT INTO "django_geo_db_zipcode" VALUES(33494,75255,-6,'Dallas, Texas 75255',24646,30000);
INSERT INTO "django_geo_db_zipcode" VALUES(33495,75258,-6,'Dallas, Texas 75258',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33496,75260,-6,'Dallas, Texas 75260',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33497,75261,-6,'Dallas, Texas 75261',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33498,75262,-6,'Dallas, Texas 75262',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33499,75263,-6,'Dallas, Texas 75263',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33500,75264,-6,'Dallas, Texas 75264',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33501,75265,-6,'Dallas, Texas 75265',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33502,75266,-6,'Dallas, Texas 75266',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33503,75267,-6,'Dallas, Texas 75267',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33504,75270,-6,'Dallas, Texas 75270',24646,30001);
INSERT INTO "django_geo_db_zipcode" VALUES(33505,75275,-6,'Dallas, Texas 75275',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33506,75277,-6,'Dallas, Texas 75277',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33507,75283,-6,'Dallas, Texas 75283',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33508,75284,-6,'Dallas, Texas 75284',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33509,75285,-6,'Dallas, Texas 75285',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33510,75286,-6,'Dallas, Texas 75286',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33511,75287,-6,'Dallas, Texas 75287',24646,30002);
INSERT INTO "django_geo_db_zipcode" VALUES(33512,75294,-6,'Dallas, Texas 75294',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33513,75295,-6,'Dallas, Texas 75295',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33514,75301,-6,'Dallas, Texas 75301',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33515,75303,-6,'Dallas, Texas 75303',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33516,75310,-6,'Dallas, Texas 75310',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33517,75312,-6,'Dallas, Texas 75312',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33518,75313,-6,'Dallas, Texas 75313',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33519,75315,-6,'Dallas, Texas 75315',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33520,75320,-6,'Dallas, Texas 75320',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33521,75323,-6,'Dallas, Texas 75323',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33522,75326,-6,'Dallas, Texas 75326',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33523,75336,-6,'Dallas, Texas 75336',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33524,75339,-6,'Dallas, Texas 75339',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33525,75342,-6,'Dallas, Texas 75342',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33526,75346,-6,'Dallas, Texas 75346',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33527,75350,-6,'Dallas, Texas 75350',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33528,75353,-6,'Dallas, Texas 75353',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33529,75354,-6,'Dallas, Texas 75354',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33530,75355,-6,'Dallas, Texas 75355',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33531,75356,-6,'Dallas, Texas 75356',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33532,75357,-6,'Dallas, Texas 75357',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33533,75359,-6,'Dallas, Texas 75359',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33534,75360,-6,'Dallas, Texas 75360',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33535,75363,-6,'Dallas, Texas 75363',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33536,75364,-6,'Dallas, Texas 75364',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33537,75367,-6,'Dallas, Texas 75367',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33538,75368,-6,'Dallas, Texas 75368',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33539,75370,-6,'Dallas, Texas 75370',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33540,75371,-6,'Dallas, Texas 75371',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33541,75372,-6,'Dallas, Texas 75372',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33542,75373,-6,'Dallas, Texas 75373',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33543,75374,-6,'Dallas, Texas 75374',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33544,75376,-6,'Dallas, Texas 75376',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33545,75378,-6,'Dallas, Texas 75378',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33546,75379,-6,'Dallas, Texas 75379',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33547,75380,-6,'Dallas, Texas 75380',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33548,75381,-6,'Dallas, Texas 75381',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33549,75382,-6,'Dallas, Texas 75382',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33550,75386,-6,'Dallas, Texas 75386',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33551,75387,-6,'Dallas, Texas 75387',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33552,75388,-6,'Dallas, Texas 75388',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33553,75389,-6,'Dallas, Texas 75389',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33554,75390,-6,'Dallas, Texas 75390',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33555,75391,-6,'Dallas, Texas 75391',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33556,75392,-6,'Dallas, Texas 75392',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33557,75393,-6,'Dallas, Texas 75393',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33558,75394,-6,'Dallas, Texas 75394',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33559,75395,-6,'Dallas, Texas 75395',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33560,75396,-6,'Dallas, Texas 75396',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33561,75397,-6,'Dallas, Texas 75397',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33562,75398,-6,'Dallas, Texas 75398',24646,29831);
INSERT INTO "django_geo_db_zipcode" VALUES(33563,75401,-6,'Greenville, Texas 75401',24647,30003);
INSERT INTO "django_geo_db_zipcode" VALUES(33564,75402,-6,'Greenville, Texas 75402',24647,30004);
INSERT INTO "django_geo_db_zipcode" VALUES(33565,75403,-6,'Greenville, Texas 75403',24647,30005);
INSERT INTO "django_geo_db_zipcode" VALUES(33566,75404,-6,'Greenville, Texas 75404',24647,30006);
INSERT INTO "django_geo_db_zipcode" VALUES(33567,75407,-6,'Princeton, Texas 75407',24648,30007);
INSERT INTO "django_geo_db_zipcode" VALUES(33568,75408,-6,'Anna, Texas 75408',24649,30008);
INSERT INTO "django_geo_db_zipcode" VALUES(33569,75409,-6,'Anna, Texas 75409',24649,30009);
INSERT INTO "django_geo_db_zipcode" VALUES(33570,75410,-6,'Alba, Texas 75410',24650,30010);
INSERT INTO "django_geo_db_zipcode" VALUES(33571,75411,-6,'Arthur City, Texas 75411',24651,30011);
INSERT INTO "django_geo_db_zipcode" VALUES(33572,75412,-6,'Bagwell, Texas 75412',24652,30012);
INSERT INTO "django_geo_db_zipcode" VALUES(33573,75413,-6,'Bailey, Texas 75413',24653,30013);
INSERT INTO "django_geo_db_zipcode" VALUES(33574,75414,-6,'Bells, Texas 75414',24654,30014);
INSERT INTO "django_geo_db_zipcode" VALUES(33575,75415,-6,'Ben Franklin, Texas 75415',24655,30015);
INSERT INTO "django_geo_db_zipcode" VALUES(33576,75416,-6,'Blossom, Texas 75416',24656,30016);
INSERT INTO "django_geo_db_zipcode" VALUES(33577,75417,-6,'Bogata, Texas 75417',24657,30017);
INSERT INTO "django_geo_db_zipcode" VALUES(33578,75418,-6,'Bonham, Texas 75418',24658,30018);
INSERT INTO "django_geo_db_zipcode" VALUES(33579,75420,-6,'Brashear, Texas 75420',24659,30019);
INSERT INTO "django_geo_db_zipcode" VALUES(33580,75421,-6,'Brookston, Texas 75421',24660,30020);
INSERT INTO "django_geo_db_zipcode" VALUES(33581,75422,-6,'Campbell, Texas 75422',24661,30021);
INSERT INTO "django_geo_db_zipcode" VALUES(33582,75423,-6,'Celeste, Texas 75423',24662,30022);
INSERT INTO "django_geo_db_zipcode" VALUES(33583,75424,-6,'Blue Ridge, Texas 75424',24663,30023);
INSERT INTO "django_geo_db_zipcode" VALUES(33584,75425,-6,'Chicota, Texas 75425',24664,30024);
INSERT INTO "django_geo_db_zipcode" VALUES(33585,75426,-6,'Clarksville, Texas 75426',24665,30025);
INSERT INTO "django_geo_db_zipcode" VALUES(33586,75428,-6,'Commerce, Texas 75428',24666,30026);
INSERT INTO "django_geo_db_zipcode" VALUES(33587,75429,-6,'Commerce, Texas 75429',24666,30027);
INSERT INTO "django_geo_db_zipcode" VALUES(33588,75431,-6,'Como, Texas 75431',24667,30028);
INSERT INTO "django_geo_db_zipcode" VALUES(33589,75432,-6,'Cooper, Texas 75432',24668,30029);
INSERT INTO "django_geo_db_zipcode" VALUES(33590,75433,-6,'Cumby, Texas 75433',24669,30030);
INSERT INTO "django_geo_db_zipcode" VALUES(33591,75434,-6,'Cunningham, Texas 75434',24670,30031);
INSERT INTO "django_geo_db_zipcode" VALUES(33592,75435,-6,'Deport, Texas 75435',24671,30032);
INSERT INTO "django_geo_db_zipcode" VALUES(33593,75436,-6,'Detroit, Texas 75436',24672,30033);
INSERT INTO "django_geo_db_zipcode" VALUES(33594,75437,-6,'Dike, Texas 75437',24673,30034);
INSERT INTO "django_geo_db_zipcode" VALUES(33595,75438,-6,'Dodd City, Texas 75438',24674,30035);
INSERT INTO "django_geo_db_zipcode" VALUES(33596,75439,-6,'Ector, Texas 75439',24675,30036);
INSERT INTO "django_geo_db_zipcode" VALUES(33597,75440,-6,'Emory, Texas 75440',24676,30037);
INSERT INTO "django_geo_db_zipcode" VALUES(33598,75441,-6,'Enloe, Texas 75441',24677,30038);
INSERT INTO "django_geo_db_zipcode" VALUES(33599,75442,-6,'Farmersville, Texas 75442',24678,30039);
INSERT INTO "django_geo_db_zipcode" VALUES(33600,75443,-6,'Gober, Texas 75443',24679,30040);
INSERT INTO "django_geo_db_zipcode" VALUES(33601,75444,-6,'Golden, Texas 75444',24680,30041);
INSERT INTO "django_geo_db_zipcode" VALUES(33602,75446,-6,'Honey Grove, Texas 75446',24681,30042);
INSERT INTO "django_geo_db_zipcode" VALUES(33603,75447,-6,'Ivanhoe, Texas 75447',24682,30043);
INSERT INTO "django_geo_db_zipcode" VALUES(33604,75448,-6,'Klondike, Texas 75448',24683,30044);
INSERT INTO "django_geo_db_zipcode" VALUES(33605,75449,-6,'Ladonia, Texas 75449',24684,30045);
INSERT INTO "django_geo_db_zipcode" VALUES(33606,75450,-6,'Lake Creek, Texas 75450',24685,30046);
INSERT INTO "django_geo_db_zipcode" VALUES(33607,75451,-6,'Leesburg, Texas 75451',24686,30047);
INSERT INTO "django_geo_db_zipcode" VALUES(33608,75452,-6,'Leonard, Texas 75452',24687,30048);
INSERT INTO "django_geo_db_zipcode" VALUES(33609,75453,-6,'Lone Oak, Texas 75453',24688,30049);
INSERT INTO "django_geo_db_zipcode" VALUES(33610,75454,-6,'Melissa, Texas 75454',24689,30050);
INSERT INTO "django_geo_db_zipcode" VALUES(33611,75455,-6,'Mount Pleasant, Texas 75455',24690,30051);
INSERT INTO "django_geo_db_zipcode" VALUES(33612,75456,-6,'Mount Pleasant, Texas 75456',24690,30052);
INSERT INTO "django_geo_db_zipcode" VALUES(33613,75457,-6,'Mount Vernon, Texas 75457',24691,30053);
INSERT INTO "django_geo_db_zipcode" VALUES(33614,75458,-6,'Merit, Texas 75458',24692,30054);
INSERT INTO "django_geo_db_zipcode" VALUES(33615,75459,-6,'Howe, Texas 75459',24693,30055);
INSERT INTO "django_geo_db_zipcode" VALUES(33616,75460,-6,'Paris, Texas 75460',24694,30056);
INSERT INTO "django_geo_db_zipcode" VALUES(33617,75461,-6,'Paris, Texas 75461',24694,30057);
INSERT INTO "django_geo_db_zipcode" VALUES(33618,75462,-6,'Paris, Texas 75462',24694,30058);
INSERT INTO "django_geo_db_zipcode" VALUES(33619,75468,-6,'Pattonville, Texas 75468',24695,30059);
INSERT INTO "django_geo_db_zipcode" VALUES(33620,75469,-6,'Pecan Gap, Texas 75469',24696,30060);
INSERT INTO "django_geo_db_zipcode" VALUES(33621,75470,-6,'Petty, Texas 75470',24697,30061);
INSERT INTO "django_geo_db_zipcode" VALUES(33622,75471,-6,'Pickton, Texas 75471',24698,30062);
INSERT INTO "django_geo_db_zipcode" VALUES(33623,75472,-6,'Point, Texas 75472',24699,30063);
INSERT INTO "django_geo_db_zipcode" VALUES(33624,75473,-6,'Powderly, Texas 75473',24700,30064);
INSERT INTO "django_geo_db_zipcode" VALUES(33625,75474,-6,'Quinlan, Texas 75474',24701,30065);
INSERT INTO "django_geo_db_zipcode" VALUES(33626,75475,-6,'Randolph, Texas 75475',24702,30066);
INSERT INTO "django_geo_db_zipcode" VALUES(33627,75476,-6,'Ravenna, Texas 75476',24703,30067);
INSERT INTO "django_geo_db_zipcode" VALUES(33628,75477,-6,'Roxton, Texas 75477',24704,30068);
INSERT INTO "django_geo_db_zipcode" VALUES(33629,75478,-6,'Saltillo, Texas 75478',24705,30069);
INSERT INTO "django_geo_db_zipcode" VALUES(33630,75479,-6,'Savoy, Texas 75479',24706,30070);
INSERT INTO "django_geo_db_zipcode" VALUES(33631,75480,-6,'Scroggins, Texas 75480',24707,30071);
INSERT INTO "django_geo_db_zipcode" VALUES(33632,75481,-6,'Sulphur Bluff, Texas 75481',24708,30072);
INSERT INTO "django_geo_db_zipcode" VALUES(33633,75482,-6,'Sulphur Springs, Texas 75482',24709,30073);
INSERT INTO "django_geo_db_zipcode" VALUES(33634,75483,-6,'Sulphur Springs, Texas 75483',24709,30074);
INSERT INTO "django_geo_db_zipcode" VALUES(33635,75485,-6,'Westminster, Texas 75485',24710,30075);
INSERT INTO "django_geo_db_zipcode" VALUES(33636,75486,-6,'Sumner, Texas 75486',24711,30076);
INSERT INTO "django_geo_db_zipcode" VALUES(33637,75487,-6,'Talco, Texas 75487',24712,30077);
INSERT INTO "django_geo_db_zipcode" VALUES(33638,75488,-6,'Telephone, Texas 75488',24713,30078);
INSERT INTO "django_geo_db_zipcode" VALUES(33639,75489,-6,'Tom Bean, Texas 75489',24714,30079);
INSERT INTO "django_geo_db_zipcode" VALUES(33640,75490,-6,'Trenton, Texas 75490',24715,30080);
INSERT INTO "django_geo_db_zipcode" VALUES(33641,75491,-6,'Whitewright, Texas 75491',24716,30081);
INSERT INTO "django_geo_db_zipcode" VALUES(33642,75492,-6,'Windom, Texas 75492',24717,30082);
INSERT INTO "django_geo_db_zipcode" VALUES(33643,75493,-6,'Winfield, Texas 75493',24718,30083);
INSERT INTO "django_geo_db_zipcode" VALUES(33644,75494,-6,'Winnsboro, Texas 75494',24719,30084);
INSERT INTO "django_geo_db_zipcode" VALUES(33645,75495,-6,'Van Alstyne, Texas 75495',24720,30085);
INSERT INTO "django_geo_db_zipcode" VALUES(33646,75496,-6,'Wolfe City, Texas 75496',24721,30086);
INSERT INTO "django_geo_db_zipcode" VALUES(33647,75497,-6,'Yantis, Texas 75497',24722,30087);
INSERT INTO "django_geo_db_zipcode" VALUES(33648,75499,-6,'Savoy, Texas 75499',24706,30088);
INSERT INTO "django_geo_db_zipcode" VALUES(33649,75501,-6,'Texarkana, Texas 75501',24723,30089);
INSERT INTO "django_geo_db_zipcode" VALUES(33650,75502,-6,'Texarkana, Texas 75502',24723,30090);
INSERT INTO "django_geo_db_zipcode" VALUES(33651,75503,-6,'Texarkana, Texas 75503',24723,30091);
INSERT INTO "django_geo_db_zipcode" VALUES(33652,75504,-6,'Texarkana, Texas 75504',24723,30092);
INSERT INTO "django_geo_db_zipcode" VALUES(33653,75505,-6,'Texarkana, Texas 75505',24723,30093);
INSERT INTO "django_geo_db_zipcode" VALUES(33654,75507,-6,'Texarkana, Texas 75507',24723,30094);
INSERT INTO "django_geo_db_zipcode" VALUES(33655,75550,-6,'Annona, Texas 75550',24724,30095);
INSERT INTO "django_geo_db_zipcode" VALUES(33656,75551,-6,'Atlanta, Texas 75551',24725,30096);
INSERT INTO "django_geo_db_zipcode" VALUES(33657,75554,-6,'Avery, Texas 75554',24726,30097);
INSERT INTO "django_geo_db_zipcode" VALUES(33658,75555,-6,'Bivins, Texas 75555',24727,30098);
INSERT INTO "django_geo_db_zipcode" VALUES(33659,75556,-6,'Bloomburg, Texas 75556',24728,30099);
INSERT INTO "django_geo_db_zipcode" VALUES(33660,75558,-6,'Cookville, Texas 75558',24729,30100);
INSERT INTO "django_geo_db_zipcode" VALUES(33661,75559,-6,'De Kalb, Texas 75559',24730,30101);
INSERT INTO "django_geo_db_zipcode" VALUES(33662,75560,-6,'Douglassville, Texas 75560',24731,30102);
INSERT INTO "django_geo_db_zipcode" VALUES(33663,75561,-6,'Hooks, Texas 75561',24732,30103);
INSERT INTO "django_geo_db_zipcode" VALUES(33664,75562,-6,'Kildare, Texas 75562',24733,30104);
INSERT INTO "django_geo_db_zipcode" VALUES(33665,75563,-6,'Linden, Texas 75563',24734,30105);
INSERT INTO "django_geo_db_zipcode" VALUES(33666,75564,-6,'Lodi, Texas 75564',24735,30106);
INSERT INTO "django_geo_db_zipcode" VALUES(33667,75565,-6,'McLeod, Texas 75565',24736,30107);
INSERT INTO "django_geo_db_zipcode" VALUES(33668,75566,-6,'Marietta, Texas 75566',24737,30108);
INSERT INTO "django_geo_db_zipcode" VALUES(33669,75567,-6,'Maud, Texas 75567',24738,30109);
INSERT INTO "django_geo_db_zipcode" VALUES(33670,75568,-6,'Naples, Texas 75568',24739,30110);
INSERT INTO "django_geo_db_zipcode" VALUES(33671,75569,-6,'Nash, Texas 75569',24740,30111);
INSERT INTO "django_geo_db_zipcode" VALUES(33672,75570,-6,'New Boston, Texas 75570',24741,30112);
INSERT INTO "django_geo_db_zipcode" VALUES(33673,75571,-6,'Omaha, Texas 75571',24742,30113);
INSERT INTO "django_geo_db_zipcode" VALUES(33674,75572,-6,'Queen City, Texas 75572',24743,30114);
INSERT INTO "django_geo_db_zipcode" VALUES(33675,75573,-6,'Redwater, Texas 75573',24744,30115);
INSERT INTO "django_geo_db_zipcode" VALUES(33676,75574,-6,'Simms, Texas 75574',24745,30116);
INSERT INTO "django_geo_db_zipcode" VALUES(33677,75599,-6,'Texarkana, Texas 75599',24723,30092);
INSERT INTO "django_geo_db_zipcode" VALUES(33678,75601,-6,'Longview, Texas 75601',24746,30117);
INSERT INTO "django_geo_db_zipcode" VALUES(33679,75602,-6,'Longview, Texas 75602',24746,30118);
INSERT INTO "django_geo_db_zipcode" VALUES(33680,75603,-6,'Longview, Texas 75603',24746,30119);
INSERT INTO "django_geo_db_zipcode" VALUES(33681,75604,-6,'Longview, Texas 75604',24746,30120);
INSERT INTO "django_geo_db_zipcode" VALUES(33682,75605,-6,'Longview, Texas 75605',24746,30121);
INSERT INTO "django_geo_db_zipcode" VALUES(33683,75606,-6,'Longview, Texas 75606',24746,30122);
INSERT INTO "django_geo_db_zipcode" VALUES(33684,75607,-6,'Longview, Texas 75607',24746,30123);
INSERT INTO "django_geo_db_zipcode" VALUES(33685,75608,-6,'Longview, Texas 75608',24746,30124);
INSERT INTO "django_geo_db_zipcode" VALUES(33686,75615,-6,'Longview, Texas 75615',24746,30123);
INSERT INTO "django_geo_db_zipcode" VALUES(33687,75630,-6,'Avinger, Texas 75630',24747,30125);
INSERT INTO "django_geo_db_zipcode" VALUES(33688,75631,-6,'Beckville, Texas 75631',24748,30126);
INSERT INTO "django_geo_db_zipcode" VALUES(33689,75633,-6,'Carthage, Texas 75633',24749,30127);
INSERT INTO "django_geo_db_zipcode" VALUES(33690,75636,-6,'Cason, Texas 75636',24750,30128);
INSERT INTO "django_geo_db_zipcode" VALUES(33691,75637,-6,'Clayton, Texas 75637',24751,30129);
INSERT INTO "django_geo_db_zipcode" VALUES(33692,75638,-6,'Daingerfield, Texas 75638',24752,30130);
INSERT INTO "django_geo_db_zipcode" VALUES(33693,75639,-6,'De Berry, Texas 75639',24753,30131);
INSERT INTO "django_geo_db_zipcode" VALUES(33694,75640,-6,'Diana, Texas 75640',24754,30132);
INSERT INTO "django_geo_db_zipcode" VALUES(33695,75641,-6,'Easton, Texas 75641',24755,30133);
INSERT INTO "django_geo_db_zipcode" VALUES(33696,75642,-6,'Elysian Fields, Texas 75642',24756,30134);
INSERT INTO "django_geo_db_zipcode" VALUES(33697,75643,-6,'Gary, Texas 75643',24757,30135);
INSERT INTO "django_geo_db_zipcode" VALUES(33698,75644,-6,'Gilmer, Texas 75644',24758,30136);
INSERT INTO "django_geo_db_zipcode" VALUES(33699,75645,-6,'Gilmer, Texas 75645',24758,30137);
INSERT INTO "django_geo_db_zipcode" VALUES(33700,75647,-6,'Gladewater, Texas 75647',24759,30138);
INSERT INTO "django_geo_db_zipcode" VALUES(33701,75650,-6,'Hallsville, Texas 75650',24760,30139);
INSERT INTO "django_geo_db_zipcode" VALUES(33702,75651,-6,'Harleton, Texas 75651',24761,30140);
INSERT INTO "django_geo_db_zipcode" VALUES(33703,75652,-6,'Henderson, Texas 75652',24762,30141);
INSERT INTO "django_geo_db_zipcode" VALUES(33704,75653,-6,'Henderson, Texas 75653',24762,30142);
INSERT INTO "django_geo_db_zipcode" VALUES(33705,75654,-6,'Henderson, Texas 75654',24762,30143);
INSERT INTO "django_geo_db_zipcode" VALUES(33706,75656,-6,'Hughes Springs, Texas 75656',24763,30144);
INSERT INTO "django_geo_db_zipcode" VALUES(33707,75657,-6,'Jefferson, Texas 75657',24764,30145);
INSERT INTO "django_geo_db_zipcode" VALUES(33708,75658,-6,'Joinerville, Texas 75658',24765,30146);
INSERT INTO "django_geo_db_zipcode" VALUES(33709,75659,-6,'Jonesville, Texas 75659',24766,30147);
INSERT INTO "django_geo_db_zipcode" VALUES(33710,75660,-6,'Judson, Texas 75660',24767,30123);
INSERT INTO "django_geo_db_zipcode" VALUES(33711,75661,-6,'Karnack, Texas 75661',24768,30148);
INSERT INTO "django_geo_db_zipcode" VALUES(33712,75662,-6,'Kilgore, Texas 75662',24769,30149);
INSERT INTO "django_geo_db_zipcode" VALUES(33713,75663,-6,'Kilgore, Texas 75663',24769,30150);
INSERT INTO "django_geo_db_zipcode" VALUES(33714,75666,-6,'Laird Hill, Texas 75666',24770,30151);
INSERT INTO "django_geo_db_zipcode" VALUES(33715,75667,-6,'Laneville, Texas 75667',24771,30152);
INSERT INTO "django_geo_db_zipcode" VALUES(33716,75668,-6,'Lone Star, Texas 75668',24772,30153);
INSERT INTO "django_geo_db_zipcode" VALUES(33717,75669,-6,'Long Branch, Texas 75669',24773,30154);
INSERT INTO "django_geo_db_zipcode" VALUES(33718,75670,-6,'Marshall, Texas 75670',24774,30155);
INSERT INTO "django_geo_db_zipcode" VALUES(33719,75671,-6,'Marshall, Texas 75671',24774,30156);
INSERT INTO "django_geo_db_zipcode" VALUES(33720,75672,-6,'Marshall, Texas 75672',24774,30157);
INSERT INTO "django_geo_db_zipcode" VALUES(33721,75680,-6,'Minden, Texas 75680',24775,30158);
INSERT INTO "django_geo_db_zipcode" VALUES(33722,75681,-6,'Mount Enterprise, Texas 75681',24776,30159);
INSERT INTO "django_geo_db_zipcode" VALUES(33723,75682,-6,'New London, Texas 75682',24777,30160);
INSERT INTO "django_geo_db_zipcode" VALUES(33724,75683,-6,'Ore City, Texas 75683',24778,30161);
INSERT INTO "django_geo_db_zipcode" VALUES(33725,75684,-6,'Overton, Texas 75684',24779,30162);
INSERT INTO "django_geo_db_zipcode" VALUES(33726,75685,-6,'Panola, Texas 75685',24780,30163);
INSERT INTO "django_geo_db_zipcode" VALUES(33727,75686,-6,'Pittsburg, Texas 75686',24781,30164);
INSERT INTO "django_geo_db_zipcode" VALUES(33728,75687,-6,'Price, Texas 75687',24782,30165);
INSERT INTO "django_geo_db_zipcode" VALUES(33729,75688,-6,'Scottsville, Texas 75688',24783,30166);
INSERT INTO "django_geo_db_zipcode" VALUES(33730,75689,-6,'Selman City, Texas 75689',24784,30167);
INSERT INTO "django_geo_db_zipcode" VALUES(33731,75691,-6,'Tatum, Texas 75691',24785,30168);
INSERT INTO "django_geo_db_zipcode" VALUES(33732,75692,-6,'Waskom, Texas 75692',24786,30169);
INSERT INTO "django_geo_db_zipcode" VALUES(33733,75693,-6,'White Oak, Texas 75693',24787,30170);
INSERT INTO "django_geo_db_zipcode" VALUES(33734,75694,-6,'Woodlawn, Texas 75694',24788,30171);
INSERT INTO "django_geo_db_zipcode" VALUES(33735,75701,-6,'Tyler, Texas 75701',24789,30172);
INSERT INTO "django_geo_db_zipcode" VALUES(33736,75702,-6,'Tyler, Texas 75702',24789,30173);
INSERT INTO "django_geo_db_zipcode" VALUES(33737,75703,-6,'Tyler, Texas 75703',24789,30174);
INSERT INTO "django_geo_db_zipcode" VALUES(33738,75704,-6,'Tyler, Texas 75704',24789,30175);
INSERT INTO "django_geo_db_zipcode" VALUES(33739,75705,-6,'Tyler, Texas 75705',24789,30176);
INSERT INTO "django_geo_db_zipcode" VALUES(33740,75706,-6,'Tyler, Texas 75706',24789,30177);
INSERT INTO "django_geo_db_zipcode" VALUES(33741,75707,-6,'Tyler, Texas 75707',24789,30178);
INSERT INTO "django_geo_db_zipcode" VALUES(33742,75708,-6,'Tyler, Texas 75708',24789,30179);
INSERT INTO "django_geo_db_zipcode" VALUES(33743,75709,-6,'Tyler, Texas 75709',24789,30180);
INSERT INTO "django_geo_db_zipcode" VALUES(33744,75710,-6,'Tyler, Texas 75710',24789,30181);
INSERT INTO "django_geo_db_zipcode" VALUES(33745,75711,-6,'Tyler, Texas 75711',24789,30182);
INSERT INTO "django_geo_db_zipcode" VALUES(33746,75712,-6,'Tyler, Texas 75712',24789,30183);
INSERT INTO "django_geo_db_zipcode" VALUES(33747,75713,-6,'Tyler, Texas 75713',24789,30183);
INSERT INTO "django_geo_db_zipcode" VALUES(33748,75750,-6,'Arp, Texas 75750',24790,30184);
INSERT INTO "django_geo_db_zipcode" VALUES(33749,75751,-6,'Athens, Texas 75751',24791,30185);
INSERT INTO "django_geo_db_zipcode" VALUES(33750,75752,-6,'Winona, Texas 75752',24792,30186);
INSERT INTO "django_geo_db_zipcode" VALUES(33751,75754,-6,'Ben Wheeler, Texas 75754',24793,30187);
INSERT INTO "django_geo_db_zipcode" VALUES(33752,75755,-6,'Big Sandy, Texas 75755',24794,30188);
INSERT INTO "django_geo_db_zipcode" VALUES(33753,75756,-6,'Brownsboro, Texas 75756',24795,30189);
INSERT INTO "django_geo_db_zipcode" VALUES(33754,75757,-6,'Bullard, Texas 75757',24796,30190);
INSERT INTO "django_geo_db_zipcode" VALUES(33755,75758,-6,'Chandler, Texas 75758',24797,30191);
INSERT INTO "django_geo_db_zipcode" VALUES(33756,75759,-6,'Cuney, Texas 75759',24798,30192);
INSERT INTO "django_geo_db_zipcode" VALUES(33757,75760,-6,'Cushing, Texas 75760',24799,30193);
INSERT INTO "django_geo_db_zipcode" VALUES(33758,75762,-6,'Flint, Texas 75762',24800,30194);
INSERT INTO "django_geo_db_zipcode" VALUES(33759,75763,-6,'Frankston, Texas 75763',24801,30195);
INSERT INTO "django_geo_db_zipcode" VALUES(33760,75764,-6,'Gallatin, Texas 75764',24802,30196);
INSERT INTO "django_geo_db_zipcode" VALUES(33761,75765,-6,'Hawkins, Texas 75765',24803,30197);
INSERT INTO "django_geo_db_zipcode" VALUES(33762,75766,-6,'Jacksonville, Texas 75766',24804,30198);
INSERT INTO "django_geo_db_zipcode" VALUES(33763,75770,-6,'Larue, Texas 75770',24805,30199);
INSERT INTO "django_geo_db_zipcode" VALUES(33764,75771,-6,'Lindale, Texas 75771',24806,30200);
INSERT INTO "django_geo_db_zipcode" VALUES(33765,75772,-6,'Maydelle, Texas 75772',24807,30201);
INSERT INTO "django_geo_db_zipcode" VALUES(33766,75773,-6,'Mineola, Texas 75773',24808,30202);
INSERT INTO "django_geo_db_zipcode" VALUES(33767,75778,-6,'Murchison, Texas 75778',24809,30203);
INSERT INTO "django_geo_db_zipcode" VALUES(33768,75779,-6,'Neches, Texas 75779',24810,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33769,75780,-6,'New Summerfield, Texas 75780',24811,30205);
INSERT INTO "django_geo_db_zipcode" VALUES(33770,75782,-6,'Poynor, Texas 75782',24812,30206);
INSERT INTO "django_geo_db_zipcode" VALUES(33771,75783,-6,'Quitman, Texas 75783',24813,30207);
INSERT INTO "django_geo_db_zipcode" VALUES(33772,75784,-6,'Reklaw, Texas 75784',24814,30208);
INSERT INTO "django_geo_db_zipcode" VALUES(33773,75785,-6,'Rusk, Texas 75785',24815,30209);
INSERT INTO "django_geo_db_zipcode" VALUES(33774,75788,-6,'Sacul, Texas 75788',24816,30210);
INSERT INTO "django_geo_db_zipcode" VALUES(33775,75789,-6,'Troup, Texas 75789',24817,30211);
INSERT INTO "django_geo_db_zipcode" VALUES(33776,75790,-6,'Van, Texas 75790',24818,30212);
INSERT INTO "django_geo_db_zipcode" VALUES(33777,75791,-6,'Whitehouse, Texas 75791',24819,30213);
INSERT INTO "django_geo_db_zipcode" VALUES(33778,75792,-6,'Winona, Texas 75792',24792,30214);
INSERT INTO "django_geo_db_zipcode" VALUES(33779,75798,-6,'Tyler, Texas 75798',24789,30183);
INSERT INTO "django_geo_db_zipcode" VALUES(33780,75799,-6,'Tyler, Texas 75799',24789,30183);
INSERT INTO "django_geo_db_zipcode" VALUES(33781,75801,-6,'Palestine, Texas 75801',24820,30215);
INSERT INTO "django_geo_db_zipcode" VALUES(33782,75802,-6,'Palestine, Texas 75802',24820,30216);
INSERT INTO "django_geo_db_zipcode" VALUES(33783,75803,-6,'Palestine, Texas 75803',24820,30217);
INSERT INTO "django_geo_db_zipcode" VALUES(33784,75806,-6,'Little Elm, Texas 75806',24591,30218);
INSERT INTO "django_geo_db_zipcode" VALUES(33785,75825,-6,'Alto, Texas 75825',24821,30219);
INSERT INTO "django_geo_db_zipcode" VALUES(33786,75831,-6,'Buffalo, Texas 75831',24822,30220);
INSERT INTO "django_geo_db_zipcode" VALUES(33787,75832,-6,'Cayuga, Texas 75832',24823,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33788,75833,-6,'Centerville, Texas 75833',24824,30221);
INSERT INTO "django_geo_db_zipcode" VALUES(33789,75834,-6,'Centralia, Texas 75834',24825,30222);
INSERT INTO "django_geo_db_zipcode" VALUES(33790,75835,-6,'Crockett, Texas 75835',24826,30223);
INSERT INTO "django_geo_db_zipcode" VALUES(33791,75838,-6,'Donie, Texas 75838',24827,30224);
INSERT INTO "django_geo_db_zipcode" VALUES(33792,75839,-6,'Elkhart, Texas 75839',24828,30225);
INSERT INTO "django_geo_db_zipcode" VALUES(33793,75840,-6,'Fairfield, Texas 75840',24829,30226);
INSERT INTO "django_geo_db_zipcode" VALUES(33794,75844,-6,'Grapeland, Texas 75844',24830,30227);
INSERT INTO "django_geo_db_zipcode" VALUES(33795,75845,-6,'Groveton, Texas 75845',24831,30228);
INSERT INTO "django_geo_db_zipcode" VALUES(33796,75846,-6,'Jewett, Texas 75846',24832,30229);
INSERT INTO "django_geo_db_zipcode" VALUES(33797,75847,-6,'Kennard, Texas 75847',24833,30230);
INSERT INTO "django_geo_db_zipcode" VALUES(33798,75848,-6,'Kirvin, Texas 75848',24834,30231);
INSERT INTO "django_geo_db_zipcode" VALUES(33799,75849,-6,'Latexo, Texas 75849',24835,30232);
INSERT INTO "django_geo_db_zipcode" VALUES(33800,75850,-6,'Leona, Texas 75850',24836,30233);
INSERT INTO "django_geo_db_zipcode" VALUES(33801,75851,-6,'Lovelady, Texas 75851',24837,30234);
INSERT INTO "django_geo_db_zipcode" VALUES(33802,75852,-6,'Midway, Texas 75852',24838,30235);
INSERT INTO "django_geo_db_zipcode" VALUES(33803,75853,-6,'Montalba, Texas 75853',24839,30236);
INSERT INTO "django_geo_db_zipcode" VALUES(33804,75855,-6,'Oakwood, Texas 75855',24840,30237);
INSERT INTO "django_geo_db_zipcode" VALUES(33805,75856,-6,'Pennington, Texas 75856',24841,30238);
INSERT INTO "django_geo_db_zipcode" VALUES(33806,75858,-6,'Ratcliff, Texas 75858',24842,30239);
INSERT INTO "django_geo_db_zipcode" VALUES(33807,75859,-6,'Streetman, Texas 75859',24843,30240);
INSERT INTO "django_geo_db_zipcode" VALUES(33808,75860,-6,'Teague, Texas 75860',24844,30241);
INSERT INTO "django_geo_db_zipcode" VALUES(33809,75861,-6,'Tennessee Colony, Texas 75861',24845,30242);
INSERT INTO "django_geo_db_zipcode" VALUES(33810,75862,-6,'Trinity, Texas 75862',24846,30243);
INSERT INTO "django_geo_db_zipcode" VALUES(33811,75865,-6,'Woodlake, Texas 75865',24847,30222);
INSERT INTO "django_geo_db_zipcode" VALUES(33812,75875,-6,'Rusk, Texas 75875',24815,30244);
INSERT INTO "django_geo_db_zipcode" VALUES(33813,75880,-6,'Tennessee Colony, Texas 75880',24845,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33814,75882,-6,'Palestine, Texas 75882',24820,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33815,75884,-6,'Tennessee Colony, Texas 75884',24845,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33816,75886,-6,'Tennessee Colony, Texas 75886',24845,30204);
INSERT INTO "django_geo_db_zipcode" VALUES(33817,75901,-6,'Lufkin, Texas 75901',24848,30245);
INSERT INTO "django_geo_db_zipcode" VALUES(33818,75902,-6,'Lufkin, Texas 75902',24848,30246);
INSERT INTO "django_geo_db_zipcode" VALUES(33819,75903,-6,'Lufkin, Texas 75903',24848,30247);
INSERT INTO "django_geo_db_zipcode" VALUES(33820,75904,-6,'Lufkin, Texas 75904',24848,30248);
INSERT INTO "django_geo_db_zipcode" VALUES(33821,75915,-6,'Lufkin, Texas 75915',24848,30249);
INSERT INTO "django_geo_db_zipcode" VALUES(33822,75925,-6,'Alto, Texas 75925',24821,30250);
INSERT INTO "django_geo_db_zipcode" VALUES(33823,75926,-6,'Apple Springs, Texas 75926',24849,30251);
INSERT INTO "django_geo_db_zipcode" VALUES(33824,75928,-6,'Bon Wier, Texas 75928',24850,30252);
INSERT INTO "django_geo_db_zipcode" VALUES(33825,75929,-6,'Broaddus, Texas 75929',24851,30253);
INSERT INTO "django_geo_db_zipcode" VALUES(33826,75930,-6,'Bronson, Texas 75930',24852,30254);
INSERT INTO "django_geo_db_zipcode" VALUES(33827,75931,-6,'Brookeland, Texas 75931',24853,30255);
INSERT INTO "django_geo_db_zipcode" VALUES(33828,75932,-6,'Burkeville, Texas 75932',24854,30256);
INSERT INTO "django_geo_db_zipcode" VALUES(33829,75933,-6,'Call, Texas 75933',24855,30257);
INSERT INTO "django_geo_db_zipcode" VALUES(33830,75934,-6,'Camden, Texas 75934',24856,30258);
INSERT INTO "django_geo_db_zipcode" VALUES(33831,75935,-6,'Center, Texas 75935',24857,30259);
INSERT INTO "django_geo_db_zipcode" VALUES(33832,75936,-6,'Chester, Texas 75936',24858,30260);
INSERT INTO "django_geo_db_zipcode" VALUES(33833,75937,-6,'Chireno, Texas 75937',24859,30261);
INSERT INTO "django_geo_db_zipcode" VALUES(33834,75938,-6,'Colmesneil, Texas 75938',24860,30262);
INSERT INTO "django_geo_db_zipcode" VALUES(33835,75939,-6,'Corrigan, Texas 75939',24861,30263);
INSERT INTO "django_geo_db_zipcode" VALUES(33836,75941,-6,'Diboll, Texas 75941',24862,30264);
INSERT INTO "django_geo_db_zipcode" VALUES(33837,75942,-6,'Doucette, Texas 75942',24863,30265);
INSERT INTO "django_geo_db_zipcode" VALUES(33838,75943,-6,'Douglass, Texas 75943',24864,30266);
INSERT INTO "django_geo_db_zipcode" VALUES(33839,75944,-6,'Etoile, Texas 75944',24865,30267);
INSERT INTO "django_geo_db_zipcode" VALUES(33840,75946,-6,'Garrison, Texas 75946',24866,30268);
INSERT INTO "django_geo_db_zipcode" VALUES(33841,75947,-6,'Geneva, Texas 75947',24867,30269);
INSERT INTO "django_geo_db_zipcode" VALUES(33842,75948,-6,'Hemphill, Texas 75948',24868,30270);
INSERT INTO "django_geo_db_zipcode" VALUES(33843,75949,-6,'Huntington, Texas 75949',24869,30271);
INSERT INTO "django_geo_db_zipcode" VALUES(33844,75951,-6,'Jasper, Texas 75951',24870,30272);
INSERT INTO "django_geo_db_zipcode" VALUES(33845,75954,-6,'Joaquin, Texas 75954',24871,30273);
INSERT INTO "django_geo_db_zipcode" VALUES(33846,75956,-6,'Kirbyville, Texas 75956',24872,30274);
INSERT INTO "django_geo_db_zipcode" VALUES(33847,75957,-6,'Timpson, Texas 75957',24873,30275);
INSERT INTO "django_geo_db_zipcode" VALUES(33848,75958,-6,'Martinsville, Texas 75958',24874,30276);
INSERT INTO "django_geo_db_zipcode" VALUES(33849,75959,-6,'Milam, Texas 75959',24875,30277);
INSERT INTO "django_geo_db_zipcode" VALUES(33850,75960,-6,'Moscow, Texas 75960',24876,30278);
INSERT INTO "django_geo_db_zipcode" VALUES(33851,75961,-6,'Nacogdoches, Texas 75961',24877,30279);
INSERT INTO "django_geo_db_zipcode" VALUES(33852,75962,-6,'Nacogdoches, Texas 75962',24877,30280);
INSERT INTO "django_geo_db_zipcode" VALUES(33853,75963,-6,'Nacogdoches, Texas 75963',24877,30281);
INSERT INTO "django_geo_db_zipcode" VALUES(33854,75964,-6,'Nacogdoches, Texas 75964',24877,30282);
INSERT INTO "django_geo_db_zipcode" VALUES(33855,75965,-6,'Nacogdoches, Texas 75965',24877,30283);
INSERT INTO "django_geo_db_zipcode" VALUES(33856,75966,-6,'Newton, Texas 75966',24878,30284);
INSERT INTO "django_geo_db_zipcode" VALUES(33857,75968,-6,'Pineland, Texas 75968',24879,30285);
INSERT INTO "django_geo_db_zipcode" VALUES(33858,75969,-6,'Pollok, Texas 75969',24880,30286);
INSERT INTO "django_geo_db_zipcode" VALUES(33859,75972,-6,'San Augustine, Texas 75972',24881,30287);
INSERT INTO "django_geo_db_zipcode" VALUES(33860,75973,-6,'Shelbyville, Texas 75973',24882,30288);
INSERT INTO "django_geo_db_zipcode" VALUES(33861,75974,-6,'Tenaha, Texas 75974',24883,30289);
INSERT INTO "django_geo_db_zipcode" VALUES(33862,75975,-6,'Timpson, Texas 75975',24873,30290);
INSERT INTO "django_geo_db_zipcode" VALUES(33863,75976,-6,'Wells, Texas 75976',24884,30291);
INSERT INTO "django_geo_db_zipcode" VALUES(33864,75977,-6,'Wiergate, Texas 75977',24885,30292);
INSERT INTO "django_geo_db_zipcode" VALUES(33865,75978,-6,'Woden, Texas 75978',24886,30293);
INSERT INTO "django_geo_db_zipcode" VALUES(33866,75979,-6,'Woodville, Texas 75979',24887,30294);
INSERT INTO "django_geo_db_zipcode" VALUES(33867,75980,-6,'Zavalla, Texas 75980',24888,30295);
INSERT INTO "django_geo_db_zipcode" VALUES(33868,75990,-6,'Woodville, Texas 75990',24887,30296);
INSERT INTO "django_geo_db_zipcode" VALUES(33869,76001,-6,'Arlington, Texas 76001',24889,30297);
INSERT INTO "django_geo_db_zipcode" VALUES(33870,76002,-6,'Arlington, Texas 76002',24889,30298);
INSERT INTO "django_geo_db_zipcode" VALUES(33871,76003,-6,'Arlington, Texas 76003',24889,30299);
INSERT INTO "django_geo_db_zipcode" VALUES(33872,76004,-6,'Arlington, Texas 76004',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33873,76005,-6,'Arlington, Texas 76005',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33874,76006,-6,'Arlington, Texas 76006',24889,30301);
INSERT INTO "django_geo_db_zipcode" VALUES(33875,76007,-6,'Arlington, Texas 76007',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33876,76008,-6,'Aledo, Texas 76008',24890,30302);
INSERT INTO "django_geo_db_zipcode" VALUES(33877,76009,-6,'Alvarado, Texas 76009',24891,30303);
INSERT INTO "django_geo_db_zipcode" VALUES(33878,76010,-6,'Arlington, Texas 76010',24889,30304);
INSERT INTO "django_geo_db_zipcode" VALUES(33879,76011,-6,'Arlington, Texas 76011',24889,30305);
INSERT INTO "django_geo_db_zipcode" VALUES(33880,76012,-6,'Arlington, Texas 76012',24889,30306);
INSERT INTO "django_geo_db_zipcode" VALUES(33881,76013,-6,'Arlington, Texas 76013',24889,30307);
INSERT INTO "django_geo_db_zipcode" VALUES(33882,76014,-6,'Arlington, Texas 76014',24889,30308);
INSERT INTO "django_geo_db_zipcode" VALUES(33883,76015,-6,'Arlington, Texas 76015',24889,30309);
INSERT INTO "django_geo_db_zipcode" VALUES(33884,76016,-6,'Arlington, Texas 76016',24889,30310);
INSERT INTO "django_geo_db_zipcode" VALUES(33885,76017,-6,'Arlington, Texas 76017',24889,30311);
INSERT INTO "django_geo_db_zipcode" VALUES(33886,76018,-6,'Arlington, Texas 76018',24889,30312);
INSERT INTO "django_geo_db_zipcode" VALUES(33887,76019,-6,'Arlington, Texas 76019',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33888,76020,-6,'Azle, Texas 76020',24892,30313);
INSERT INTO "django_geo_db_zipcode" VALUES(33889,76021,-6,'Bedford, Texas 76021',24893,30314);
INSERT INTO "django_geo_db_zipcode" VALUES(33890,76022,-6,'Bedford, Texas 76022',24893,30315);
INSERT INTO "django_geo_db_zipcode" VALUES(33891,76023,-6,'Boyd, Texas 76023',24894,30316);
INSERT INTO "django_geo_db_zipcode" VALUES(33892,76025,-6,'Plano, Texas 76025',24581,30317);
INSERT INTO "django_geo_db_zipcode" VALUES(33893,76028,-6,'Burleson, Texas 76028',24895,30318);
INSERT INTO "django_geo_db_zipcode" VALUES(33894,76031,-6,'Cleburne, Texas 76031',24896,30319);
INSERT INTO "django_geo_db_zipcode" VALUES(33895,76033,-6,'Cleburne, Texas 76033',24896,30320);
INSERT INTO "django_geo_db_zipcode" VALUES(33896,76034,-6,'Colleyville, Texas 76034',24897,30321);
INSERT INTO "django_geo_db_zipcode" VALUES(33897,76035,-6,'Cresson, Texas 76035',24898,30322);
INSERT INTO "django_geo_db_zipcode" VALUES(33898,76036,-6,'Crowley, Texas 76036',24899,30323);
INSERT INTO "django_geo_db_zipcode" VALUES(33899,76039,-6,'Euless, Texas 76039',24900,30324);
INSERT INTO "django_geo_db_zipcode" VALUES(33900,76040,-6,'Euless, Texas 76040',24900,30325);
INSERT INTO "django_geo_db_zipcode" VALUES(33901,76041,-6,'Forreston, Texas 76041',24901,30326);
INSERT INTO "django_geo_db_zipcode" VALUES(33902,76043,-6,'Glen Rose, Texas 76043',24902,30327);
INSERT INTO "django_geo_db_zipcode" VALUES(33903,76044,-6,'Godley, Texas 76044',24903,30328);
INSERT INTO "django_geo_db_zipcode" VALUES(33904,76048,-6,'Granbury, Texas 76048',24904,30329);
INSERT INTO "django_geo_db_zipcode" VALUES(33905,76049,-6,'Granbury, Texas 76049',24904,30330);
INSERT INTO "django_geo_db_zipcode" VALUES(33906,76050,-6,'Grandview, Texas 76050',24905,30331);
INSERT INTO "django_geo_db_zipcode" VALUES(33907,76051,-6,'Grapevine, Texas 76051',24906,30332);
INSERT INTO "django_geo_db_zipcode" VALUES(33908,76052,-6,'Haslet, Texas 76052',24907,30333);
INSERT INTO "django_geo_db_zipcode" VALUES(33909,76053,-6,'Hurst, Texas 76053',24908,30334);
INSERT INTO "django_geo_db_zipcode" VALUES(33910,76054,-6,'Hurst, Texas 76054',24908,30335);
INSERT INTO "django_geo_db_zipcode" VALUES(33911,76055,-6,'Itasca, Texas 76055',24909,30336);
INSERT INTO "django_geo_db_zipcode" VALUES(33912,76058,-6,'Joshua, Texas 76058',24910,30337);
INSERT INTO "django_geo_db_zipcode" VALUES(33913,76059,-6,'Keene, Texas 76059',24911,30338);
INSERT INTO "django_geo_db_zipcode" VALUES(33914,76060,-6,'Kennedale, Texas 76060',24912,30339);
INSERT INTO "django_geo_db_zipcode" VALUES(33915,76061,-6,'Lillian, Texas 76061',24913,30340);
INSERT INTO "django_geo_db_zipcode" VALUES(33916,76063,-6,'Mansfield, Texas 76063',24914,30341);
INSERT INTO "django_geo_db_zipcode" VALUES(33917,76064,-6,'Maypearl, Texas 76064',24915,30342);
INSERT INTO "django_geo_db_zipcode" VALUES(33918,76065,-6,'Midlothian, Texas 76065',24916,30343);
INSERT INTO "django_geo_db_zipcode" VALUES(33919,76066,-6,'Millsap, Texas 76066',24917,30344);
INSERT INTO "django_geo_db_zipcode" VALUES(33920,76067,-6,'Mineral Wells, Texas 76067',24918,30345);
INSERT INTO "django_geo_db_zipcode" VALUES(33921,76068,-6,'Mineral Wells, Texas 76068',24918,30346);
INSERT INTO "django_geo_db_zipcode" VALUES(33922,76070,-6,'Nemo, Texas 76070',24919,30347);
INSERT INTO "django_geo_db_zipcode" VALUES(33923,76071,-6,'Newark, Texas 76071',24920,30348);
INSERT INTO "django_geo_db_zipcode" VALUES(33924,76073,-6,'Paradise, Texas 76073',24921,30349);
INSERT INTO "django_geo_db_zipcode" VALUES(33925,76077,-6,'Rainbow, Texas 76077',24922,30350);
INSERT INTO "django_geo_db_zipcode" VALUES(33926,76078,-6,'Rhome, Texas 76078',24923,30351);
INSERT INTO "django_geo_db_zipcode" VALUES(33927,76082,-6,'Springtown, Texas 76082',24924,30352);
INSERT INTO "django_geo_db_zipcode" VALUES(33928,76084,-6,'Venus, Texas 76084',24925,30353);
INSERT INTO "django_geo_db_zipcode" VALUES(33929,76085,-6,'Weatherford, Texas 76085',24926,30354);
INSERT INTO "django_geo_db_zipcode" VALUES(33930,76086,-6,'Weatherford, Texas 76086',24926,30355);
INSERT INTO "django_geo_db_zipcode" VALUES(33931,76087,-6,'Weatherford, Texas 76087',24926,30356);
INSERT INTO "django_geo_db_zipcode" VALUES(33932,76088,-6,'Weatherford, Texas 76088',24926,30357);
INSERT INTO "django_geo_db_zipcode" VALUES(33933,76092,-6,'Southlake, Texas 76092',24927,30358);
INSERT INTO "django_geo_db_zipcode" VALUES(33934,76093,-6,'Rio Vista, Texas 76093',24928,30359);
INSERT INTO "django_geo_db_zipcode" VALUES(33935,76094,-6,'Arlington, Texas 76094',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33936,76095,-6,'Bedford, Texas 76095',24893,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33937,76096,-6,'Arlington, Texas 76096',24889,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33938,76097,-6,'Burleson, Texas 76097',24895,30360);
INSERT INTO "django_geo_db_zipcode" VALUES(33939,76098,-6,'Azle, Texas 76098',24892,30361);
INSERT INTO "django_geo_db_zipcode" VALUES(33940,76099,-6,'Grapevine, Texas 76099',24906,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33941,76101,-6,'Fort Worth, Texas 76101',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33942,76102,-6,'Fort Worth, Texas 76102',24929,30362);
INSERT INTO "django_geo_db_zipcode" VALUES(33943,76103,-6,'Fort Worth, Texas 76103',24929,30363);
INSERT INTO "django_geo_db_zipcode" VALUES(33944,76104,-6,'Fort Worth, Texas 76104',24929,30364);
INSERT INTO "django_geo_db_zipcode" VALUES(33945,76105,-6,'Fort Worth, Texas 76105',24929,30365);
INSERT INTO "django_geo_db_zipcode" VALUES(33946,76106,-6,'Fort Worth, Texas 76106',24929,30366);
INSERT INTO "django_geo_db_zipcode" VALUES(33947,76107,-6,'Fort Worth, Texas 76107',24929,30367);
INSERT INTO "django_geo_db_zipcode" VALUES(33948,76108,-6,'Fort Worth, Texas 76108',24929,30368);
INSERT INTO "django_geo_db_zipcode" VALUES(33949,76109,-6,'Fort Worth, Texas 76109',24929,30369);
INSERT INTO "django_geo_db_zipcode" VALUES(33950,76110,-6,'Fort Worth, Texas 76110',24929,30370);
INSERT INTO "django_geo_db_zipcode" VALUES(33951,76111,-6,'Fort Worth, Texas 76111',24929,30371);
INSERT INTO "django_geo_db_zipcode" VALUES(33952,76112,-6,'Fort Worth, Texas 76112',24929,30372);
INSERT INTO "django_geo_db_zipcode" VALUES(33953,76113,-6,'Fort Worth, Texas 76113',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33954,76114,-6,'Fort Worth, Texas 76114',24929,30373);
INSERT INTO "django_geo_db_zipcode" VALUES(33955,76115,-6,'Fort Worth, Texas 76115',24929,30374);
INSERT INTO "django_geo_db_zipcode" VALUES(33956,76116,-6,'Fort Worth, Texas 76116',24929,30375);
INSERT INTO "django_geo_db_zipcode" VALUES(33957,76117,-6,'Haltom City, Texas 76117',24930,30376);
INSERT INTO "django_geo_db_zipcode" VALUES(33958,76118,-6,'Fort Worth, Texas 76118',24929,30377);
INSERT INTO "django_geo_db_zipcode" VALUES(33959,76119,-6,'Fort Worth, Texas 76119',24929,30378);
INSERT INTO "django_geo_db_zipcode" VALUES(33960,76120,-6,'Fort Worth, Texas 76120',24929,30379);
INSERT INTO "django_geo_db_zipcode" VALUES(33961,76121,-6,'Fort Worth, Texas 76121',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33962,76122,-6,'Fort Worth, Texas 76122',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33963,76123,-6,'Fort Worth, Texas 76123',24929,30380);
INSERT INTO "django_geo_db_zipcode" VALUES(33964,76124,-6,'Fort Worth, Texas 76124',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33965,76126,-6,'Fort Worth, Texas 76126',24929,30381);
INSERT INTO "django_geo_db_zipcode" VALUES(33966,76127,-6,'Naval Air Station/ Jrb, Texas 76127',24931,30382);
INSERT INTO "django_geo_db_zipcode" VALUES(33967,76129,-6,'Fort Worth, Texas 76129',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33968,76130,-6,'Fort Worth, Texas 76130',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33969,76131,-6,'Fort Worth, Texas 76131',24929,30383);
INSERT INTO "django_geo_db_zipcode" VALUES(33970,76132,-6,'Fort Worth, Texas 76132',24929,30384);
INSERT INTO "django_geo_db_zipcode" VALUES(33971,76133,-6,'Fort Worth, Texas 76133',24929,30385);
INSERT INTO "django_geo_db_zipcode" VALUES(33972,76134,-6,'Fort Worth, Texas 76134',24929,30386);
INSERT INTO "django_geo_db_zipcode" VALUES(33973,76135,-6,'Fort Worth, Texas 76135',24929,30387);
INSERT INTO "django_geo_db_zipcode" VALUES(33974,76136,-6,'Fort Worth, Texas 76136',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33975,76137,-6,'Fort Worth, Texas 76137',24929,30388);
INSERT INTO "django_geo_db_zipcode" VALUES(33976,76140,-6,'Fort Worth, Texas 76140',24929,30389);
INSERT INTO "django_geo_db_zipcode" VALUES(33977,76147,-6,'Fort Worth, Texas 76147',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33978,76148,-6,'Fort Worth, Texas 76148',24929,30390);
INSERT INTO "django_geo_db_zipcode" VALUES(33979,76150,-6,'Fort Worth, Texas 76150',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33980,76153,-6,'Fort Worth, Texas 76153',24929,30391);
INSERT INTO "django_geo_db_zipcode" VALUES(33981,76155,-6,'Fort Worth, Texas 76155',24929,30392);
INSERT INTO "django_geo_db_zipcode" VALUES(33982,76161,-6,'Fort Worth, Texas 76161',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33983,76162,-6,'Fort Worth, Texas 76162',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33984,76163,-6,'Fort Worth, Texas 76163',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33985,76164,-6,'Fort Worth, Texas 76164',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33986,76177,-6,'Fort Worth, Texas 76177',24929,30393);
INSERT INTO "django_geo_db_zipcode" VALUES(33987,76178,-6,'Fort Worth, Texas 76178',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33988,76179,-6,'Fort Worth, Texas 76179',24929,30394);
INSERT INTO "django_geo_db_zipcode" VALUES(33989,76180,-6,'North Richland Hills, Texas 76180',24932,30395);
INSERT INTO "django_geo_db_zipcode" VALUES(33990,76181,-6,'Fort Worth, Texas 76181',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33991,76182,-6,'North Richland Hills, Texas 76182',24932,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33992,76185,-6,'Fort Worth, Texas 76185',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33993,76191,-6,'Fort Worth, Texas 76191',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33994,76192,-6,'Fort Worth, Texas 76192',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33995,76193,-6,'Fort Worth, Texas 76193',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33996,76195,-6,'Fort Worth, Texas 76195',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33997,76196,-6,'Fort Worth, Texas 76196',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33998,76197,-6,'Fort Worth, Texas 76197',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(33999,76198,-6,'Fort Worth, Texas 76198',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(34000,76199,-6,'Fort Worth, Texas 76199',24929,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(34001,76201,-6,'Denton, Texas 76201',24933,30396);
INSERT INTO "django_geo_db_zipcode" VALUES(34002,76202,-6,'Denton, Texas 76202',24933,30397);
INSERT INTO "django_geo_db_zipcode" VALUES(34003,76203,-6,'Denton, Texas 76203',24933,30398);
INSERT INTO "django_geo_db_zipcode" VALUES(34004,76204,-6,'Denton, Texas 76204',24933,29828);
INSERT INTO "django_geo_db_zipcode" VALUES(34005,76205,-6,'Denton, Texas 76205',24933,30399);
INSERT INTO "django_geo_db_zipcode" VALUES(34006,76206,-6,'Denton, Texas 76206',24933,30400);
INSERT INTO "django_geo_db_zipcode" VALUES(34007,76207,-6,'Denton, Texas 76207',24933,30401);
INSERT INTO "django_geo_db_zipcode" VALUES(34008,76208,-6,'Denton, Texas 76208',24933,30402);
INSERT INTO "django_geo_db_zipcode" VALUES(34009,76209,-6,'Denton, Texas 76209',24933,30403);
INSERT INTO "django_geo_db_zipcode" VALUES(34010,76210,-6,'Corinth, Texas 76210',24934,30404);
INSERT INTO "django_geo_db_zipcode" VALUES(34011,76225,-6,'Alvord, Texas 76225',24935,30405);
INSERT INTO "django_geo_db_zipcode" VALUES(34012,76226,-6,'Argyle, Texas 76226',24936,30406);
INSERT INTO "django_geo_db_zipcode" VALUES(34013,76227,-6,'Aubrey, Texas 76227',24937,30407);
INSERT INTO "django_geo_db_zipcode" VALUES(34014,76228,-6,'Bellevue, Texas 76228',24938,30408);
INSERT INTO "django_geo_db_zipcode" VALUES(34015,76230,-6,'Bowie, Texas 76230',24939,30409);
INSERT INTO "django_geo_db_zipcode" VALUES(34016,76233,-6,'Collinsville, Texas 76233',24940,30410);
INSERT INTO "django_geo_db_zipcode" VALUES(34017,76234,-6,'Decatur, Texas 76234',24941,30411);
INSERT INTO "django_geo_db_zipcode" VALUES(34018,76238,-6,'Era, Texas 76238',24942,30412);
INSERT INTO "django_geo_db_zipcode" VALUES(34019,76239,-6,'Forestburg, Texas 76239',24943,30413);
INSERT INTO "django_geo_db_zipcode" VALUES(34020,76240,-6,'Gainesville, Texas 76240',24944,30414);
INSERT INTO "django_geo_db_zipcode" VALUES(34021,76241,-6,'Gainesville, Texas 76241',24944,30415);
INSERT INTO "django_geo_db_zipcode" VALUES(34022,76244,-6,'Keller, Texas 76244',24945,30300);
INSERT INTO "django_geo_db_zipcode" VALUES(34023,76245,-6,'Gordonville, Texas 76245',24946,30416);
INSERT INTO "django_geo_db_zipcode" VALUES(34024,76246,-6,'Greenwood, Texas 76246',24947,30417);
INSERT INTO "django_geo_db_zipcode" VALUES(34025,76247,-6,'Justin, Texas 76247',24948,30418);
INSERT INTO "django_geo_db_zipcode" VALUES(34026,76248,-6,'Keller, Texas 76248',24945,30419);
INSERT INTO "django_geo_db_zipcode" VALUES(34027,76249,-6,'Krum, Texas 76249',24949,30420);
INSERT INTO "django_geo_db_zipcode" VALUES(34028,76250,-6,'Lindsay, Texas 76250',24950,30421);
INSERT INTO "django_geo_db_zipcode" VALUES(34029,76251,-6,'Montague, Texas 76251',24951,30422);
INSERT INTO "django_geo_db_zipcode" VALUES(34030,76252,-6,'Muenster, Texas 76252',24952,30423);
INSERT INTO "django_geo_db_zipcode" VALUES(34031,76253,-6,'Myra, Texas 76253',24953,30424);
INSERT INTO "django_geo_db_zipcode" VALUES(34032,76255,-6,'Nocona, Texas 76255',24954,30425);
INSERT INTO "django_geo_db_zipcode" VALUES(34033,76258,-6,'Pilot Point, Texas 76258',24955,30426);
INSERT INTO "django_geo_db_zipcode" VALUES(34034,76259,-6,'Ponder, Texas 76259',24956,30427);
INSERT INTO "django_geo_db_zipcode" VALUES(34035,76261,-6,'Ringgold, Texas 76261',24957,30428);
INSERT INTO "django_geo_db_zipcode" VALUES(34036,76262,-6,'Roanoke, Texas 76262',24958,30429);
INSERT INTO "django_geo_db_zipcode" VALUES(34037,76263,-6,'Rosston, Texas 76263',24959,30430);
INSERT INTO "django_geo_db_zipcode" VALUES(34038,76264,-6,'Sadler, Texas 76264',24960,30431);
INSERT INTO "django_geo_db_zipcode" VALUES(34039,76265,-6,'Saint Jo, Texas 76265',24961,30432);
INSERT INTO "django_geo_db_zipcode" VALUES(34040,76266,-6,'Sanger, Texas 76266',24962,30433);
INSERT INTO "django_geo_db_zipcode" VALUES(34041,76267,-6,'Slidell, Texas 76267',24963,30434);
INSERT INTO "django_geo_db_zipcode" VALUES(34042,76268,-6,'Southmayd, Texas 76268',24964,30435);
INSERT INTO "django_geo_db_zipcode" VALUES(34043,76270,-6,'Sunset, Texas 76270',24965,30436);
INSERT INTO "django_geo_db_zipcode" VALUES(34044,76271,-6,'Tioga, Texas 76271',24966,30437);
INSERT INTO "django_geo_db_zipcode" VALUES(34045,76272,-6,'Valley View, Texas 76272',24967,30438);
INSERT INTO "django_geo_db_zipcode" VALUES(34046,76273,-6,'Whitesboro, Texas 76273',24968,30439);
INSERT INTO "django_geo_db_zipcode" VALUES(34047,76299,-6,'Roanoke, Texas 76299',24958,29828);
INSERT INTO "django_geo_db_zipcode" VALUES(34048,76301,-6,'Wichita Falls, Texas 76301',24969,30440);
INSERT INTO "django_geo_db_zipcode" VALUES(34049,76302,-6,'Wichita Falls, Texas 76302',24969,30441);
INSERT INTO "django_geo_db_zipcode" VALUES(34050,76303,-6,'Wichita Falls, Texas 76303',24969,30442);
INSERT INTO "django_geo_db_zipcode" VALUES(34051,76304,-6,'Wichita Falls, Texas 76304',24969,30443);
INSERT INTO "django_geo_db_zipcode" VALUES(34052,76305,-6,'Wichita Falls, Texas 76305',24969,30444);
INSERT INTO "django_geo_db_zipcode" VALUES(34053,76306,-6,'Wichita Falls, Texas 76306',24969,30445);
INSERT INTO "django_geo_db_zipcode" VALUES(34054,76307,-6,'Wichita Falls, Texas 76307',24969,30446);
INSERT INTO "django_geo_db_zipcode" VALUES(34055,76308,-6,'Wichita Falls, Texas 76308',24969,30447);
INSERT INTO "django_geo_db_zipcode" VALUES(34056,76309,-6,'Wichita Falls, Texas 76309',24969,30448);
INSERT INTO "django_geo_db_zipcode" VALUES(34057,76310,-6,'Wichita Falls, Texas 76310',24969,30449);
INSERT INTO "django_geo_db_zipcode" VALUES(34058,76311,-6,'Sheppard AFB, Texas 76311',24970,30450);
INSERT INTO "django_geo_db_zipcode" VALUES(34059,76345,-6,'Fort Worth, Texas 76345',24929,30451);
INSERT INTO "django_geo_db_zipcode" VALUES(34060,76351,-6,'Archer City, Texas 76351',24971,30452);
INSERT INTO "django_geo_db_zipcode" VALUES(34061,76352,-6,'Bluegrove, Texas 76352',24972,30453);
INSERT INTO "django_geo_db_zipcode" VALUES(34062,76354,-6,'Burkburnett, Texas 76354',24973,30454);
INSERT INTO "django_geo_db_zipcode" VALUES(34063,76356,-6,'Terral, Oklahoma 76356',24138,30455);
INSERT INTO "django_geo_db_zipcode" VALUES(34064,76357,-6,'Byers, Texas 76357',24974,30456);
INSERT INTO "django_geo_db_zipcode" VALUES(34065,76360,-6,'Electra, Texas 76360',24975,30457);
INSERT INTO "django_geo_db_zipcode" VALUES(34066,76363,-6,'Goree, Texas 76363',24976,30458);
INSERT INTO "django_geo_db_zipcode" VALUES(34067,76364,-6,'Harrold, Texas 76364',24977,30459);
INSERT INTO "django_geo_db_zipcode" VALUES(34068,76365,-6,'Henrietta, Texas 76365',24978,30460);
INSERT INTO "django_geo_db_zipcode" VALUES(34069,76366,-6,'Holliday, Texas 76366',24979,30461);
INSERT INTO "django_geo_db_zipcode" VALUES(34070,76367,-6,'Iowa Park, Texas 76367',24980,30462);
INSERT INTO "django_geo_db_zipcode" VALUES(34071,76369,-6,'Kamay, Texas 76369',24981,30463);
INSERT INTO "django_geo_db_zipcode" VALUES(34072,76370,-6,'Megargel, Texas 76370',24982,30464);
INSERT INTO "django_geo_db_zipcode" VALUES(34073,76371,-6,'Munday, Texas 76371',24983,30465);
INSERT INTO "django_geo_db_zipcode" VALUES(34074,76372,-6,'Newcastle, Texas 76372',24984,30466);
INSERT INTO "django_geo_db_zipcode" VALUES(34075,76373,-6,'Oklaunion, Texas 76373',24985,30467);
INSERT INTO "django_geo_db_zipcode" VALUES(34076,76374,-6,'Olney, Texas 76374',24986,30468);
INSERT INTO "django_geo_db_zipcode" VALUES(34077,76377,-6,'Petrolia, Texas 76377',24987,30469);
INSERT INTO "django_geo_db_zipcode" VALUES(34078,76379,-6,'Scotland, Texas 76379',24988,30470);
INSERT INTO "django_geo_db_zipcode" VALUES(34079,76380,-6,'Seymour, Texas 76380',24989,30471);
INSERT INTO "django_geo_db_zipcode" VALUES(34080,76384,-6,'Vernon, Texas 76384',24990,30472);
INSERT INTO "django_geo_db_zipcode" VALUES(34081,76385,-6,'Vernon, Texas 76385',24990,30473);
INSERT INTO "django_geo_db_zipcode" VALUES(34082,76388,-6,'Weinert, Texas 76388',24991,30474);
INSERT INTO "django_geo_db_zipcode" VALUES(34083,76389,-6,'Windthorst, Texas 76389',24992,30475);
INSERT INTO "django_geo_db_zipcode" VALUES(34084,76401,-6,'Stephenville, Texas 76401',24993,30476);
INSERT INTO "django_geo_db_zipcode" VALUES(34085,76402,-6,'Stephenville, Texas 76402',24993,30477);
INSERT INTO "django_geo_db_zipcode" VALUES(34086,76420,-6,'Albany, Texas 76420',24994,30478);
INSERT INTO "django_geo_db_zipcode" VALUES(34087,76424,-6,'Breckenridge, Texas 76424',24995,30479);
INSERT INTO "django_geo_db_zipcode" VALUES(34088,76426,-6,'Bridgeport, Texas 76426',24996,30480);
INSERT INTO "django_geo_db_zipcode" VALUES(34089,76427,-6,'Bryson, Texas 76427',24997,30481);
INSERT INTO "django_geo_db_zipcode" VALUES(34090,76429,-6,'Caddo, Texas 76429',24998,30482);
INSERT INTO "django_geo_db_zipcode" VALUES(34091,76430,-6,'Albany, Texas 76430',24994,30483);
INSERT INTO "django_geo_db_zipcode" VALUES(34092,76431,-6,'Chico, Texas 76431',24999,30484);
INSERT INTO "django_geo_db_zipcode" VALUES(34093,76432,-6,'Blanket, Texas 76432',25000,30485);
INSERT INTO "django_geo_db_zipcode" VALUES(34094,76433,-6,'Bluff Dale, Texas 76433',25001,30486);
INSERT INTO "django_geo_db_zipcode" VALUES(34095,76435,-6,'Carbon, Texas 76435',25002,30487);
INSERT INTO "django_geo_db_zipcode" VALUES(34096,76436,-6,'Carlton, Texas 76436',25003,30488);
INSERT INTO "django_geo_db_zipcode" VALUES(34097,76437,-6,'Cisco, Texas 76437',25004,30489);
INSERT INTO "django_geo_db_zipcode" VALUES(34098,76439,-6,'Dennis, Texas 76439',25005,30490);
INSERT INTO "django_geo_db_zipcode" VALUES(34099,76442,-6,'Comanche, Texas 76442',25006,30491);
INSERT INTO "django_geo_db_zipcode" VALUES(34100,76443,-6,'Cross Plains, Texas 76443',25007,30492);
INSERT INTO "django_geo_db_zipcode" VALUES(34101,76444,-6,'De Leon, Texas 76444',25008,30493);
INSERT INTO "django_geo_db_zipcode" VALUES(34102,76445,-6,'Desdemona, Texas 76445',25009,30494);
INSERT INTO "django_geo_db_zipcode" VALUES(34103,76446,-6,'Dublin, Texas 76446',25010,30495);
INSERT INTO "django_geo_db_zipcode" VALUES(34104,76448,-6,'Eastland, Texas 76448',25011,30496);
INSERT INTO "django_geo_db_zipcode" VALUES(34105,76449,-6,'Graford, Texas 76449',25012,30497);
INSERT INTO "django_geo_db_zipcode" VALUES(34106,76450,-6,'Graham, Texas 76450',25013,30498);
INSERT INTO "django_geo_db_zipcode" VALUES(34107,76452,-6,'Energy, Texas 76452',25014,30499);
INSERT INTO "django_geo_db_zipcode" VALUES(34108,76453,-6,'Gordon, Texas 76453',25015,30500);
INSERT INTO "django_geo_db_zipcode" VALUES(34109,76454,-6,'Gorman, Texas 76454',25016,30501);
INSERT INTO "django_geo_db_zipcode" VALUES(34110,76455,-6,'Gustine, Texas 76455',25017,30502);
INSERT INTO "django_geo_db_zipcode" VALUES(34111,76457,-6,'Hico, Texas 76457',25018,30503);
INSERT INTO "django_geo_db_zipcode" VALUES(34112,76458,-6,'Jacksboro, Texas 76458',25019,30504);
INSERT INTO "django_geo_db_zipcode" VALUES(34113,76459,-6,'Jermyn, Texas 76459',25020,30505);
INSERT INTO "django_geo_db_zipcode" VALUES(34114,76460,-6,'Loving, Texas 76460',25021,30506);
INSERT INTO "django_geo_db_zipcode" VALUES(34115,76461,-6,'Lingleville, Texas 76461',25022,30507);
INSERT INTO "django_geo_db_zipcode" VALUES(34116,76462,-6,'Lipan, Texas 76462',25023,30508);
INSERT INTO "django_geo_db_zipcode" VALUES(34117,76463,-6,'Mingus, Texas 76463',25024,30509);
INSERT INTO "django_geo_db_zipcode" VALUES(34118,76464,-6,'Moran, Texas 76464',25025,30510);
INSERT INTO "django_geo_db_zipcode" VALUES(34119,76465,-6,'Morgan Mill, Texas 76465',25026,30477);
INSERT INTO "django_geo_db_zipcode" VALUES(34120,76466,-6,'Olden, Texas 76466',25027,30511);
INSERT INTO "django_geo_db_zipcode" VALUES(34121,76467,-6,'Paluxy, Texas 76467',25028,30512);
INSERT INTO "django_geo_db_zipcode" VALUES(34122,76468,-6,'Proctor, Texas 76468',25029,30513);
INSERT INTO "django_geo_db_zipcode" VALUES(34123,76469,-6,'Putnam, Texas 76469',25030,30514);
INSERT INTO "django_geo_db_zipcode" VALUES(34124,76470,-6,'Ranger, Texas 76470',25031,30515);
INSERT INTO "django_geo_db_zipcode" VALUES(34125,76471,-6,'Rising Star, Texas 76471',25032,30516);
INSERT INTO "django_geo_db_zipcode" VALUES(34126,76472,-6,'Santo, Texas 76472',25033,30517);
INSERT INTO "django_geo_db_zipcode" VALUES(34127,76474,-6,'Sidney, Texas 76474',25034,30518);
INSERT INTO "django_geo_db_zipcode" VALUES(34128,76475,-6,'Strawn, Texas 76475',25035,30519);
INSERT INTO "django_geo_db_zipcode" VALUES(34129,76476,-6,'Tolar, Texas 76476',25036,30520);
INSERT INTO "django_geo_db_zipcode" VALUES(34130,76481,-6,'South Bend, Texas 76481',25037,30521);
INSERT INTO "django_geo_db_zipcode" VALUES(34131,76483,-6,'Throckmorton, Texas 76483',25038,30522);
INSERT INTO "django_geo_db_zipcode" VALUES(34132,76484,-6,'Palo Pinto, Texas 76484',25039,30523);
INSERT INTO "django_geo_db_zipcode" VALUES(34133,76485,-6,'Peaster, Texas 76485',25040,30524);
INSERT INTO "django_geo_db_zipcode" VALUES(34134,76486,-6,'Perrin, Texas 76486',25041,30525);
INSERT INTO "django_geo_db_zipcode" VALUES(34135,76487,-6,'Poolville, Texas 76487',25042,30526);
INSERT INTO "django_geo_db_zipcode" VALUES(34136,76490,-6,'Whitt, Texas 76490',25043,30527);
INSERT INTO "django_geo_db_zipcode" VALUES(34137,76491,-6,'Woodson, Texas 76491',25044,30528);
INSERT INTO "django_geo_db_zipcode" VALUES(34138,76501,-6,'Temple, Texas 76501',25045,30529);
INSERT INTO "django_geo_db_zipcode" VALUES(34139,76502,-6,'Temple, Texas 76502',25045,30530);
INSERT INTO "django_geo_db_zipcode" VALUES(34140,76503,-6,'Temple, Texas 76503',25045,30531);
INSERT INTO "django_geo_db_zipcode" VALUES(34141,76504,-6,'Temple, Texas 76504',25045,30532);
INSERT INTO "django_geo_db_zipcode" VALUES(34142,76505,-6,'Temple, Texas 76505',25045,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34143,76508,-6,'Temple, Texas 76508',25045,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34144,76511,-6,'Bartlett, Texas 76511',25046,30534);
INSERT INTO "django_geo_db_zipcode" VALUES(34145,76513,-6,'Belton, Texas 76513',25047,30535);
INSERT INTO "django_geo_db_zipcode" VALUES(34146,76518,-6,'Buckholts, Texas 76518',25048,30536);
INSERT INTO "django_geo_db_zipcode" VALUES(34147,76519,-6,'Burlington, Texas 76519',25049,30537);
INSERT INTO "django_geo_db_zipcode" VALUES(34148,76520,-6,'Cameron, Texas 76520',25050,30538);
INSERT INTO "django_geo_db_zipcode" VALUES(34149,76522,-6,'Copperas Cove, Texas 76522',25051,30539);
INSERT INTO "django_geo_db_zipcode" VALUES(34150,76523,-6,'Davilla, Texas 76523',25052,30540);
INSERT INTO "django_geo_db_zipcode" VALUES(34151,76524,-6,'Eddy, Texas 76524',25053,30541);
INSERT INTO "django_geo_db_zipcode" VALUES(34152,76525,-6,'Evant, Texas 76525',25054,30542);
INSERT INTO "django_geo_db_zipcode" VALUES(34153,76526,-6,'Flat, Texas 76526',25055,30543);
INSERT INTO "django_geo_db_zipcode" VALUES(34154,76527,-6,'Florence, Texas 76527',25056,30544);
INSERT INTO "django_geo_db_zipcode" VALUES(34155,76528,-6,'Gatesville, Texas 76528',25057,30545);
INSERT INTO "django_geo_db_zipcode" VALUES(34156,76530,-6,'Granger, Texas 76530',25058,30546);
INSERT INTO "django_geo_db_zipcode" VALUES(34157,76531,-6,'Hamilton, Texas 76531',25059,30547);
INSERT INTO "django_geo_db_zipcode" VALUES(34158,76533,-6,'Heidenheimer, Texas 76533',25060,30548);
INSERT INTO "django_geo_db_zipcode" VALUES(34159,76534,-6,'Holland, Texas 76534',25061,30549);
INSERT INTO "django_geo_db_zipcode" VALUES(34160,76537,-6,'Jarrell, Texas 76537',25062,30550);
INSERT INTO "django_geo_db_zipcode" VALUES(34161,76538,-6,'Jonesboro, Texas 76538',25063,30551);
INSERT INTO "django_geo_db_zipcode" VALUES(34162,76539,-6,'Kempner, Texas 76539',25064,30552);
INSERT INTO "django_geo_db_zipcode" VALUES(34163,76540,-6,'Killeen, Texas 76540',25065,30553);
INSERT INTO "django_geo_db_zipcode" VALUES(34164,76541,-6,'Killeen, Texas 76541',25065,30554);
INSERT INTO "django_geo_db_zipcode" VALUES(34165,76542,-6,'Killeen, Texas 76542',25065,30555);
INSERT INTO "django_geo_db_zipcode" VALUES(34166,76543,-6,'Killeen, Texas 76543',25065,30556);
INSERT INTO "django_geo_db_zipcode" VALUES(34167,76544,-6,'Killeen, Texas 76544',25065,30557);
INSERT INTO "django_geo_db_zipcode" VALUES(34168,76545,-6,'Killeen, Texas 76545',25065,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34169,76546,-6,'Killeen, Texas 76546',25065,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34170,76547,-6,'Killeen, Texas 76547',25065,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34171,76548,-6,'Harker Heights, Texas 76548',25066,30558);
INSERT INTO "django_geo_db_zipcode" VALUES(34172,76549,-6,'Killeen, Texas 76549',25065,30559);
INSERT INTO "django_geo_db_zipcode" VALUES(34173,76550,-6,'Lampasas, Texas 76550',25067,30560);
INSERT INTO "django_geo_db_zipcode" VALUES(34174,76552,-6,'Leon Junction, Texas 76552',25068,30561);
INSERT INTO "django_geo_db_zipcode" VALUES(34175,76554,-6,'Little River, Texas 76554',25069,30562);
INSERT INTO "django_geo_db_zipcode" VALUES(34176,76555,-6,'Maysfield, Texas 76555',25070,30563);
INSERT INTO "django_geo_db_zipcode" VALUES(34177,76556,-6,'Milano, Texas 76556',25071,30564);
INSERT INTO "django_geo_db_zipcode" VALUES(34178,76557,-6,'Moody, Texas 76557',25072,30565);
INSERT INTO "django_geo_db_zipcode" VALUES(34179,76558,-6,'Mound, Texas 76558',25073,30566);
INSERT INTO "django_geo_db_zipcode" VALUES(34180,76559,-6,'Nolanville, Texas 76559',25074,30567);
INSERT INTO "django_geo_db_zipcode" VALUES(34181,76561,-6,'Oglesby, Texas 76561',25075,30568);
INSERT INTO "django_geo_db_zipcode" VALUES(34182,76564,-6,'Pendleton, Texas 76564',25076,30533);
INSERT INTO "django_geo_db_zipcode" VALUES(34183,76565,-6,'Pottsville, Texas 76565',25077,30569);
INSERT INTO "django_geo_db_zipcode" VALUES(34184,76566,-6,'Purmela, Texas 76566',25078,30570);
INSERT INTO "django_geo_db_zipcode" VALUES(34185,76567,-6,'Rockdale, Texas 76567',25079,30571);
INSERT INTO "django_geo_db_zipcode" VALUES(34186,76569,-6,'Rogers, Texas 76569',25080,30572);
INSERT INTO "django_geo_db_zipcode" VALUES(34187,76570,-6,'Rosebud, Texas 76570',25081,30573);
INSERT INTO "django_geo_db_zipcode" VALUES(34188,76571,-6,'Salado, Texas 76571',25082,30574);
INSERT INTO "django_geo_db_zipcode" VALUES(34189,76573,-6,'Schwertner, Texas 76573',25083,30575);
INSERT INTO "django_geo_db_zipcode" VALUES(34190,76574,-6,'Taylor, Texas 76574',25084,30576);
INSERT INTO "django_geo_db_zipcode" VALUES(34191,76576,-6,'Salado, Texas 76576',25082,30577);
INSERT INTO "django_geo_db_zipcode" VALUES(34192,76577,-6,'Thorndale, Texas 76577',25085,30578);
INSERT INTO "django_geo_db_zipcode" VALUES(34193,76578,-6,'Thrall, Texas 76578',25086,30579);
INSERT INTO "django_geo_db_zipcode" VALUES(34194,76579,-6,'Troy, Texas 76579',25087,30580);
INSERT INTO "django_geo_db_zipcode" VALUES(34195,76596,-6,'Gatesville, Texas 76596',25057,30581);
INSERT INTO "django_geo_db_zipcode" VALUES(34196,76597,-6,'Gatesville, Texas 76597',25057,30581);
INSERT INTO "django_geo_db_zipcode" VALUES(34197,76598,-6,'Gatesville, Texas 76598',25057,30581);
INSERT INTO "django_geo_db_zipcode" VALUES(34198,76599,-6,'Gatesville, Texas 76599',25057,30582);
INSERT INTO "django_geo_db_zipcode" VALUES(34199,76607,-6,'Milford, Texas 76607',25088,30583);
INSERT INTO "django_geo_db_zipcode" VALUES(34200,76618,-6,'Richland, Texas 76618',25089,30584);
INSERT INTO "django_geo_db_zipcode" VALUES(34201,76621,-6,'Abbott, Texas 76621',25090,30585);
INSERT INTO "django_geo_db_zipcode" VALUES(34202,76622,-6,'Aquilla, Texas 76622',25091,30586);
INSERT INTO "django_geo_db_zipcode" VALUES(34203,76623,-6,'Avalon, Texas 76623',25092,30587);
INSERT INTO "django_geo_db_zipcode" VALUES(34204,76624,-6,'Axtell, Texas 76624',25093,30588);
INSERT INTO "django_geo_db_zipcode" VALUES(34205,76626,-6,'Blooming Grove, Texas 76626',25094,30589);
INSERT INTO "django_geo_db_zipcode" VALUES(34206,76627,-6,'Blum, Texas 76627',25095,30590);
INSERT INTO "django_geo_db_zipcode" VALUES(34207,76628,-6,'Brandon, Texas 76628',25096,30591);
INSERT INTO "django_geo_db_zipcode" VALUES(34208,76629,-6,'Bremond, Texas 76629',25097,30592);
INSERT INTO "django_geo_db_zipcode" VALUES(34209,76630,-6,'Bruceville, Texas 76630',25098,30593);
INSERT INTO "django_geo_db_zipcode" VALUES(34210,76631,-6,'Bynum, Texas 76631',25099,30594);
INSERT INTO "django_geo_db_zipcode" VALUES(34211,76632,-6,'Chilton, Texas 76632',25100,30595);
INSERT INTO "django_geo_db_zipcode" VALUES(34212,76633,-6,'China Spring, Texas 76633',25101,30596);
INSERT INTO "django_geo_db_zipcode" VALUES(34213,76634,-6,'Clifton, Texas 76634',25102,30597);
INSERT INTO "django_geo_db_zipcode" VALUES(34214,76635,-6,'Coolidge, Texas 76635',25103,30598);
INSERT INTO "django_geo_db_zipcode" VALUES(34215,76636,-6,'Covington, Texas 76636',25104,30599);
INSERT INTO "django_geo_db_zipcode" VALUES(34216,76637,-6,'Cranfills Gap, Texas 76637',25105,30600);
INSERT INTO "django_geo_db_zipcode" VALUES(34217,76638,-6,'Crawford, Texas 76638',25106,30601);
INSERT INTO "django_geo_db_zipcode" VALUES(34218,76639,-6,'Dawson, Texas 76639',25107,30602);
INSERT INTO "django_geo_db_zipcode" VALUES(34219,76640,-6,'Elm Mott, Texas 76640',25108,30603);
INSERT INTO "django_geo_db_zipcode" VALUES(34220,76641,-6,'Frost, Texas 76641',25109,30604);
INSERT INTO "django_geo_db_zipcode" VALUES(34221,76642,-6,'Groesbeck, Texas 76642',25110,30605);
INSERT INTO "django_geo_db_zipcode" VALUES(34222,76643,-6,'Hewitt, Texas 76643',25111,30606);
INSERT INTO "django_geo_db_zipcode" VALUES(34223,76644,-6,'Laguna Park, Texas 76644',25112,30607);
INSERT INTO "django_geo_db_zipcode" VALUES(34224,76645,-6,'Hillsboro, Texas 76645',25113,30608);
INSERT INTO "django_geo_db_zipcode" VALUES(34225,76648,-6,'Hubbard, Texas 76648',25114,30609);
INSERT INTO "django_geo_db_zipcode" VALUES(34226,76649,-6,'Iredell, Texas 76649',25115,30610);
INSERT INTO "django_geo_db_zipcode" VALUES(34227,76650,-6,'Irene, Texas 76650',25116,30611);
INSERT INTO "django_geo_db_zipcode" VALUES(34228,76651,-6,'Italy, Texas 76651',25117,30612);
INSERT INTO "django_geo_db_zipcode" VALUES(34229,76652,-6,'Kopperl, Texas 76652',25118,30613);
INSERT INTO "django_geo_db_zipcode" VALUES(34230,76653,-6,'Kosse, Texas 76653',25119,30614);
INSERT INTO "django_geo_db_zipcode" VALUES(34231,76654,-6,'Leroy, Texas 76654',25120,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34232,76655,-6,'Lorena, Texas 76655',25121,30616);
INSERT INTO "django_geo_db_zipcode" VALUES(34233,76656,-6,'Lott, Texas 76656',25122,30617);
INSERT INTO "django_geo_db_zipcode" VALUES(34234,76657,-6,'McGregor, Texas 76657',25123,30618);
INSERT INTO "django_geo_db_zipcode" VALUES(34235,76660,-6,'Malone, Texas 76660',25124,30619);
INSERT INTO "django_geo_db_zipcode" VALUES(34236,76661,-6,'Marlin, Texas 76661',25125,30620);
INSERT INTO "django_geo_db_zipcode" VALUES(34237,76664,-6,'Mart, Texas 76664',25126,30621);
INSERT INTO "django_geo_db_zipcode" VALUES(34238,76665,-6,'Meridian, Texas 76665',25127,30622);
INSERT INTO "django_geo_db_zipcode" VALUES(34239,76666,-6,'Mertens, Texas 76666',25128,30623);
INSERT INTO "django_geo_db_zipcode" VALUES(34240,76667,-6,'Mexia, Texas 76667',25129,30624);
INSERT INTO "django_geo_db_zipcode" VALUES(34241,76670,-6,'Milford, Texas 76670',25088,30625);
INSERT INTO "django_geo_db_zipcode" VALUES(34242,76671,-6,'Morgan, Texas 76671',25130,30626);
INSERT INTO "django_geo_db_zipcode" VALUES(34243,76673,-6,'Mount Calm, Texas 76673',25131,30627);
INSERT INTO "django_geo_db_zipcode" VALUES(34244,76675,-6,'Otto, Texas 76675',25132,30628);
INSERT INTO "django_geo_db_zipcode" VALUES(34245,76676,-6,'Penelope, Texas 76676',25133,30629);
INSERT INTO "django_geo_db_zipcode" VALUES(34246,76677,-6,'Perry, Texas 76677',25134,30630);
INSERT INTO "django_geo_db_zipcode" VALUES(34247,76678,-6,'Prairie Hill, Texas 76678',25135,30631);
INSERT INTO "django_geo_db_zipcode" VALUES(34248,76679,-6,'Purdon, Texas 76679',25136,30632);
INSERT INTO "django_geo_db_zipcode" VALUES(34249,76680,-6,'Reagan, Texas 76680',25137,30633);
INSERT INTO "django_geo_db_zipcode" VALUES(34250,76681,-6,'Richland, Texas 76681',25089,30634);
INSERT INTO "django_geo_db_zipcode" VALUES(34251,76682,-6,'Riesel, Texas 76682',25138,30635);
INSERT INTO "django_geo_db_zipcode" VALUES(34252,76683,-6,'Riesel, Texas 76683',25138,30636);
INSERT INTO "django_geo_db_zipcode" VALUES(34253,76684,-6,'Ross, Texas 76684',25139,30637);
INSERT INTO "django_geo_db_zipcode" VALUES(34254,76685,-6,'Satin, Texas 76685',25140,30638);
INSERT INTO "django_geo_db_zipcode" VALUES(34255,76686,-6,'Tehuacana, Texas 76686',25141,30639);
INSERT INTO "django_geo_db_zipcode" VALUES(34256,76687,-6,'Thornton, Texas 76687',25142,30640);
INSERT INTO "django_geo_db_zipcode" VALUES(34257,76689,-6,'Valley Mills, Texas 76689',25143,30641);
INSERT INTO "django_geo_db_zipcode" VALUES(34258,76690,-6,'Walnut Springs, Texas 76690',25144,30642);
INSERT INTO "django_geo_db_zipcode" VALUES(34259,76691,-6,'West, Texas 76691',25145,30643);
INSERT INTO "django_geo_db_zipcode" VALUES(34260,76692,-6,'Whitney, Texas 76692',25146,30644);
INSERT INTO "django_geo_db_zipcode" VALUES(34261,76693,-6,'Wortham, Texas 76693',25147,30645);
INSERT INTO "django_geo_db_zipcode" VALUES(34262,76701,-6,'Waco, Texas 76701',25148,30646);
INSERT INTO "django_geo_db_zipcode" VALUES(34263,76702,-6,'Waco, Texas 76702',25148,30647);
INSERT INTO "django_geo_db_zipcode" VALUES(34264,76703,-6,'Waco, Texas 76703',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34265,76704,-6,'Waco, Texas 76704',25148,30648);
INSERT INTO "django_geo_db_zipcode" VALUES(34266,76705,-6,'Waco, Texas 76705',25148,30649);
INSERT INTO "django_geo_db_zipcode" VALUES(34267,76706,-6,'Waco, Texas 76706',25148,30650);
INSERT INTO "django_geo_db_zipcode" VALUES(34268,76707,-6,'Waco, Texas 76707',25148,30651);
INSERT INTO "django_geo_db_zipcode" VALUES(34269,76708,-6,'Waco, Texas 76708',25148,30652);
INSERT INTO "django_geo_db_zipcode" VALUES(34270,76710,-6,'Waco, Texas 76710',25148,30653);
INSERT INTO "django_geo_db_zipcode" VALUES(34271,76711,-6,'Waco, Texas 76711',25148,30654);
INSERT INTO "django_geo_db_zipcode" VALUES(34272,76712,-6,'Woodway, Texas 76712',25149,30655);
INSERT INTO "django_geo_db_zipcode" VALUES(34273,76714,-6,'Waco, Texas 76714',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34274,76715,-6,'Waco, Texas 76715',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34275,76716,-6,'Waco, Texas 76716',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34276,76795,-6,'Waco, Texas 76795',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34277,76797,-6,'Waco, Texas 76797',25148,30615);
INSERT INTO "django_geo_db_zipcode" VALUES(34278,76798,-6,'Waco, Texas 76798',25148,30656);
INSERT INTO "django_geo_db_zipcode" VALUES(34279,76799,-6,'Waco, Texas 76799',25148,30657);
INSERT INTO "django_geo_db_zipcode" VALUES(34280,76801,-6,'Brownwood, Texas 76801',25150,30658);
INSERT INTO "django_geo_db_zipcode" VALUES(34281,76802,-6,'Early, Texas 76802',25151,30659);
INSERT INTO "django_geo_db_zipcode" VALUES(34282,76803,-6,'Brownwood, Texas 76803',25150,30660);
INSERT INTO "django_geo_db_zipcode" VALUES(34283,76804,-6,'Brownwood, Texas 76804',25150,30661);
INSERT INTO "django_geo_db_zipcode" VALUES(34284,76820,-6,'Art, Texas 76820',25152,30662);
INSERT INTO "django_geo_db_zipcode" VALUES(34285,76821,-6,'Ballinger, Texas 76821',25153,30663);
INSERT INTO "django_geo_db_zipcode" VALUES(34286,76823,-6,'Bangs, Texas 76823',25154,30664);
INSERT INTO "django_geo_db_zipcode" VALUES(34287,76824,-6,'Bend, Texas 76824',25155,30665);
INSERT INTO "django_geo_db_zipcode" VALUES(34288,76825,-6,'Brady, Texas 76825',25156,30666);
INSERT INTO "django_geo_db_zipcode" VALUES(34289,76827,-6,'Brookesmith, Texas 76827',25157,30667);
INSERT INTO "django_geo_db_zipcode" VALUES(34290,76828,-6,'Burkett, Texas 76828',25158,30668);
INSERT INTO "django_geo_db_zipcode" VALUES(34291,76831,-6,'Castell, Texas 76831',25159,30669);
INSERT INTO "django_geo_db_zipcode" VALUES(34292,76832,-6,'Cherokee, Texas 76832',25160,30670);
INSERT INTO "django_geo_db_zipcode" VALUES(34293,76834,-6,'Coleman, Texas 76834',25161,30671);
INSERT INTO "django_geo_db_zipcode" VALUES(34294,76836,-6,'Doole, Texas 76836',25162,30672);
INSERT INTO "django_geo_db_zipcode" VALUES(34295,76837,-6,'Eden, Texas 76837',25163,30673);
INSERT INTO "django_geo_db_zipcode" VALUES(34296,76841,-6,'Fort McKavett, Texas 76841',25164,30674);
INSERT INTO "django_geo_db_zipcode" VALUES(34297,76842,-6,'Fredonia, Texas 76842',25165,30675);
INSERT INTO "django_geo_db_zipcode" VALUES(34298,76844,-6,'Goldthwaite, Texas 76844',25166,30676);
INSERT INTO "django_geo_db_zipcode" VALUES(34299,76845,-6,'Gouldbusk, Texas 76845',25167,30677);
INSERT INTO "django_geo_db_zipcode" VALUES(34300,76848,-6,'Hext, Texas 76848',25168,30678);
INSERT INTO "django_geo_db_zipcode" VALUES(34301,76849,-6,'Junction, Texas 76849',25169,30679);
INSERT INTO "django_geo_db_zipcode" VALUES(34302,76852,-6,'Lohn, Texas 76852',25170,30680);
INSERT INTO "django_geo_db_zipcode" VALUES(34303,76853,-6,'Lometa, Texas 76853',25171,30681);
INSERT INTO "django_geo_db_zipcode" VALUES(34304,76854,-6,'London, Texas 76854',25172,30682);
INSERT INTO "django_geo_db_zipcode" VALUES(34305,76855,-6,'Lowake, Texas 76855',25173,30683);
INSERT INTO "django_geo_db_zipcode" VALUES(34306,76856,-6,'Mason, Texas 76856',25174,30684);
INSERT INTO "django_geo_db_zipcode" VALUES(34307,76857,-6,'May, Texas 76857',25175,30685);
INSERT INTO "django_geo_db_zipcode" VALUES(34308,76858,-6,'Melvin, Texas 76858',25176,30686);
INSERT INTO "django_geo_db_zipcode" VALUES(34309,76859,-6,'Menard, Texas 76859',25177,30687);
INSERT INTO "django_geo_db_zipcode" VALUES(34310,76861,-6,'Miles, Texas 76861',25178,30688);
INSERT INTO "django_geo_db_zipcode" VALUES(34311,76862,-6,'Millersview, Texas 76862',25179,30689);
INSERT INTO "django_geo_db_zipcode" VALUES(34312,76864,-6,'Mullin, Texas 76864',25180,30690);
INSERT INTO "django_geo_db_zipcode" VALUES(34313,76865,-6,'Norton, Texas 76865',25181,30691);
INSERT INTO "django_geo_db_zipcode" VALUES(34314,76866,-6,'Paint Rock, Texas 76866',25182,30692);
INSERT INTO "django_geo_db_zipcode" VALUES(34315,76867,-6,'Pear Valley, Texas 76867',25183,30672);
INSERT INTO "django_geo_db_zipcode" VALUES(34316,76869,-6,'Pontotoc, Texas 76869',25184,30693);
INSERT INTO "django_geo_db_zipcode" VALUES(34317,76870,-6,'Priddy, Texas 76870',25185,30694);
INSERT INTO "django_geo_db_zipcode" VALUES(34318,76871,-6,'Richland Springs, Texas 76871',25186,30695);
INSERT INTO "django_geo_db_zipcode" VALUES(34319,76872,-6,'Rochelle, Texas 76872',25187,30696);
INSERT INTO "django_geo_db_zipcode" VALUES(34320,76873,-6,'Rockwood, Texas 76873',25188,30697);
INSERT INTO "django_geo_db_zipcode" VALUES(34321,76874,-6,'Roosevelt, Texas 76874',25189,30698);
INSERT INTO "django_geo_db_zipcode" VALUES(34322,76875,-6,'Rowena, Texas 76875',25190,30699);
INSERT INTO "django_geo_db_zipcode" VALUES(34323,76877,-6,'San Saba, Texas 76877',25191,30700);
INSERT INTO "django_geo_db_zipcode" VALUES(34324,76878,-6,'Santa Anna, Texas 76878',25192,30701);
INSERT INTO "django_geo_db_zipcode" VALUES(34325,76880,-6,'Star, Texas 76880',25193,30702);
INSERT INTO "django_geo_db_zipcode" VALUES(34326,76882,-6,'Talpa, Texas 76882',25194,30703);
INSERT INTO "django_geo_db_zipcode" VALUES(34327,76883,-6,'Telegraph, Texas 76883',25195,30704);
INSERT INTO "django_geo_db_zipcode" VALUES(34328,76884,-6,'Valera, Texas 76884',25196,30705);
INSERT INTO "django_geo_db_zipcode" VALUES(34329,76885,-6,'Valley Spring, Texas 76885',25197,30706);
INSERT INTO "django_geo_db_zipcode" VALUES(34330,76886,-6,'Veribest, Texas 76886',25198,30707);
INSERT INTO "django_geo_db_zipcode" VALUES(34331,76887,-6,'Voca, Texas 76887',25199,30708);
INSERT INTO "django_geo_db_zipcode" VALUES(34332,76888,-6,'Voss, Texas 76888',25200,30709);
INSERT INTO "django_geo_db_zipcode" VALUES(34333,76890,-6,'Zephyr, Texas 76890',25201,30710);
INSERT INTO "django_geo_db_zipcode" VALUES(34334,76901,-6,'San Angelo, Texas 76901',25202,30711);
INSERT INTO "django_geo_db_zipcode" VALUES(34335,76902,-6,'San Angelo, Texas 76902',25202,30712);
INSERT INTO "django_geo_db_zipcode" VALUES(34336,76903,-6,'San Angelo, Texas 76903',25202,30713);
INSERT INTO "django_geo_db_zipcode" VALUES(34337,76904,-6,'San Angelo, Texas 76904',25202,30714);
INSERT INTO "django_geo_db_zipcode" VALUES(34338,76905,-6,'San Angelo, Texas 76905',25202,30715);
INSERT INTO "django_geo_db_zipcode" VALUES(34339,76906,-6,'San Angelo, Texas 76906',25202,30716);
INSERT INTO "django_geo_db_zipcode" VALUES(34340,76908,-6,'Goodfellow AFB, Texas 76908',25203,30712);
INSERT INTO "django_geo_db_zipcode" VALUES(34341,76909,-6,'San Angelo, Texas 76909',25202,30712);
INSERT INTO "django_geo_db_zipcode" VALUES(34342,76930,-6,'Barnhart, Texas 76930',25204,30717);
INSERT INTO "django_geo_db_zipcode" VALUES(34343,76932,-6,'Big Lake, Texas 76932',25205,30718);
INSERT INTO "django_geo_db_zipcode" VALUES(34344,76933,-6,'Bronte, Texas 76933',25206,30719);
INSERT INTO "django_geo_db_zipcode" VALUES(34345,76934,-6,'Carlsbad, Texas 76934',25207,30720);
INSERT INTO "django_geo_db_zipcode" VALUES(34346,76935,-6,'Christoval, Texas 76935',25208,30721);
INSERT INTO "django_geo_db_zipcode" VALUES(34347,76936,-6,'Eldorado, Texas 76936',25209,30722);
INSERT INTO "django_geo_db_zipcode" VALUES(34348,76937,-6,'Eola, Texas 76937',25210,30723);
INSERT INTO "django_geo_db_zipcode" VALUES(34349,76939,-6,'Knickerbocker, Texas 76939',25211,30724);
INSERT INTO "django_geo_db_zipcode" VALUES(34350,76940,-6,'Mereta, Texas 76940',25212,30725);
INSERT INTO "django_geo_db_zipcode" VALUES(34351,76941,-6,'Mertzon, Texas 76941',25213,30726);
INSERT INTO "django_geo_db_zipcode" VALUES(34352,76943,-6,'Ozona, Texas 76943',25214,30727);
INSERT INTO "django_geo_db_zipcode" VALUES(34353,76945,-6,'Robert Lee, Texas 76945',25215,30728);
INSERT INTO "django_geo_db_zipcode" VALUES(34354,76949,-6,'Silver, Texas 76949',25216,30729);
INSERT INTO "django_geo_db_zipcode" VALUES(34355,76950,-6,'Sonora, Texas 76950',25217,30730);
INSERT INTO "django_geo_db_zipcode" VALUES(34356,76951,-6,'Sterling City, Texas 76951',25218,30731);
INSERT INTO "django_geo_db_zipcode" VALUES(34357,76953,-6,'Tennyson, Texas 76953',25219,30732);
INSERT INTO "django_geo_db_zipcode" VALUES(34358,76955,-6,'Vancourt, Texas 76955',25220,30733);
INSERT INTO "django_geo_db_zipcode" VALUES(34359,76957,-6,'Wall, Texas 76957',25221,30734);
INSERT INTO "django_geo_db_zipcode" VALUES(34360,76958,-6,'Water Valley, Texas 76958',25222,30735);
INSERT INTO "django_geo_db_zipcode" VALUES(34361,77000,-6,'Houston, Texas 77000',25223,30736);
INSERT INTO "django_geo_db_zipcode" VALUES(34362,77001,-6,'Houston, Texas 77001',25223,30737);
INSERT INTO "django_geo_db_zipcode" VALUES(34363,77002,-6,'Houston, Texas 77002',25223,30738);
INSERT INTO "django_geo_db_zipcode" VALUES(34364,77003,-6,'Houston, Texas 77003',25223,30739);
INSERT INTO "django_geo_db_zipcode" VALUES(34365,77004,-6,'Houston, Texas 77004',25223,30740);
INSERT INTO "django_geo_db_zipcode" VALUES(34366,77005,-6,'Houston, Texas 77005',25223,30741);
INSERT INTO "django_geo_db_zipcode" VALUES(34367,77006,-6,'Houston, Texas 77006',25223,30742);
INSERT INTO "django_geo_db_zipcode" VALUES(34368,77007,-6,'Houston, Texas 77007',25223,30743);
INSERT INTO "django_geo_db_zipcode" VALUES(34369,77008,-6,'Houston, Texas 77008',25223,30744);
INSERT INTO "django_geo_db_zipcode" VALUES(34370,77009,-6,'Houston, Texas 77009',25223,30745);
INSERT INTO "django_geo_db_zipcode" VALUES(34371,77010,-6,'Houston, Texas 77010',25223,30746);
INSERT INTO "django_geo_db_zipcode" VALUES(34372,77011,-6,'Houston, Texas 77011',25223,30747);
INSERT INTO "django_geo_db_zipcode" VALUES(34373,77012,-6,'Houston, Texas 77012',25223,30748);
INSERT INTO "django_geo_db_zipcode" VALUES(34374,77013,-6,'Houston, Texas 77013',25223,30749);
INSERT INTO "django_geo_db_zipcode" VALUES(34375,77014,-6,'Houston, Texas 77014',25223,30750);
INSERT INTO "django_geo_db_zipcode" VALUES(34376,77015,-6,'Houston, Texas 77015',25223,30751);
INSERT INTO "django_geo_db_zipcode" VALUES(34377,77016,-6,'Houston, Texas 77016',25223,30752);
INSERT INTO "django_geo_db_zipcode" VALUES(34378,77017,-6,'Houston, Texas 77017',25223,30753);
INSERT INTO "django_geo_db_zipcode" VALUES(34379,77018,-6,'Houston, Texas 77018',25223,30754);
INSERT INTO "django_geo_db_zipcode" VALUES(34380,77019,-6,'Houston, Texas 77019',25223,30755);
INSERT INTO "django_geo_db_zipcode" VALUES(34381,77020,-6,'Houston, Texas 77020',25223,30756);
INSERT INTO "django_geo_db_zipcode" VALUES(34382,77021,-6,'Houston, Texas 77021',25223,30757);
INSERT INTO "django_geo_db_zipcode" VALUES(34383,77022,-6,'Houston, Texas 77022',25223,30758);
INSERT INTO "django_geo_db_zipcode" VALUES(34384,77023,-6,'Houston, Texas 77023',25223,30759);
INSERT INTO "django_geo_db_zipcode" VALUES(34385,77024,-6,'Houston, Texas 77024',25223,30760);
INSERT INTO "django_geo_db_zipcode" VALUES(34386,77025,-6,'Houston, Texas 77025',25223,30761);
INSERT INTO "django_geo_db_zipcode" VALUES(34387,77026,-6,'Houston, Texas 77026',25223,30762);
INSERT INTO "django_geo_db_zipcode" VALUES(34388,77027,-6,'Houston, Texas 77027',25223,30763);
INSERT INTO "django_geo_db_zipcode" VALUES(34389,77028,-6,'Houston, Texas 77028',25223,30764);
INSERT INTO "django_geo_db_zipcode" VALUES(34390,77029,-6,'Houston, Texas 77029',25223,30765);
INSERT INTO "django_geo_db_zipcode" VALUES(34391,77030,-6,'Houston, Texas 77030',25223,30766);
INSERT INTO "django_geo_db_zipcode" VALUES(34392,77031,-6,'Houston, Texas 77031',25223,30767);
INSERT INTO "django_geo_db_zipcode" VALUES(34393,77032,-6,'Houston, Texas 77032',25223,30768);
INSERT INTO "django_geo_db_zipcode" VALUES(34394,77033,-6,'Houston, Texas 77033',25223,30769);
INSERT INTO "django_geo_db_zipcode" VALUES(34395,77034,-6,'Houston, Texas 77034',25223,30770);
INSERT INTO "django_geo_db_zipcode" VALUES(34396,77035,-6,'Houston, Texas 77035',25223,30771);
INSERT INTO "django_geo_db_zipcode" VALUES(34397,77036,-6,'Houston, Texas 77036',25223,30772);
INSERT INTO "django_geo_db_zipcode" VALUES(34398,77037,-6,'Houston, Texas 77037',25223,30773);
INSERT INTO "django_geo_db_zipcode" VALUES(34399,77038,-6,'Houston, Texas 77038',25223,30774);
INSERT INTO "django_geo_db_zipcode" VALUES(34400,77039,-6,'Houston, Texas 77039',25223,30775);
INSERT INTO "django_geo_db_zipcode" VALUES(34401,77040,-6,'Houston, Texas 77040',25223,30776);
INSERT INTO "django_geo_db_zipcode" VALUES(34402,77041,-6,'Houston, Texas 77041',25223,30777);
INSERT INTO "django_geo_db_zipcode" VALUES(34403,77042,-6,'Houston, Texas 77042',25223,30778);
INSERT INTO "django_geo_db_zipcode" VALUES(34404,77043,-6,'Houston, Texas 77043',25223,30779);
INSERT INTO "django_geo_db_zipcode" VALUES(34405,77044,-6,'Houston, Texas 77044',25223,30780);
INSERT INTO "django_geo_db_zipcode" VALUES(34406,77045,-6,'Houston, Texas 77045',25223,30781);
INSERT INTO "django_geo_db_zipcode" VALUES(34407,77046,-6,'Houston, Texas 77046',25223,30782);
INSERT INTO "django_geo_db_zipcode" VALUES(34408,77047,-6,'Houston, Texas 77047',25223,30783);
INSERT INTO "django_geo_db_zipcode" VALUES(34409,77048,-6,'Houston, Texas 77048',25223,30784);
INSERT INTO "django_geo_db_zipcode" VALUES(34410,77049,-6,'Houston, Texas 77049',25223,30785);
INSERT INTO "django_geo_db_zipcode" VALUES(34411,77050,-6,'Houston, Texas 77050',25223,30786);
INSERT INTO "django_geo_db_zipcode" VALUES(34412,77051,-6,'Houston, Texas 77051',25223,30787);
INSERT INTO "django_geo_db_zipcode" VALUES(34413,77052,-6,'Houston, Texas 77052',25223,30788);
INSERT INTO "django_geo_db_zipcode" VALUES(34414,77053,-6,'Houston, Texas 77053',25223,30789);
INSERT INTO "django_geo_db_zipcode" VALUES(34415,77054,-6,'Houston, Texas 77054',25223,30790);
INSERT INTO "django_geo_db_zipcode" VALUES(34416,77055,-6,'Houston, Texas 77055',25223,30791);
INSERT INTO "django_geo_db_zipcode" VALUES(34417,77056,-6,'Houston, Texas 77056',25223,30792);
INSERT INTO "django_geo_db_zipcode" VALUES(34418,77057,-6,'Houston, Texas 77057',25223,30793);
INSERT INTO "django_geo_db_zipcode" VALUES(34419,77058,-6,'Houston, Texas 77058',25223,30794);
INSERT INTO "django_geo_db_zipcode" VALUES(34420,77059,-6,'Houston, Texas 77059',25223,30795);
INSERT INTO "django_geo_db_zipcode" VALUES(34421,77060,-6,'Houston, Texas 77060',25223,30796);
INSERT INTO "django_geo_db_zipcode" VALUES(34422,77061,-6,'Houston, Texas 77061',25223,30797);
INSERT INTO "django_geo_db_zipcode" VALUES(34423,77062,-6,'Houston, Texas 77062',25223,30798);
INSERT INTO "django_geo_db_zipcode" VALUES(34424,77063,-6,'Houston, Texas 77063',25223,30799);
INSERT INTO "django_geo_db_zipcode" VALUES(34425,77064,-6,'Houston, Texas 77064',25223,30800);
INSERT INTO "django_geo_db_zipcode" VALUES(34426,77065,-6,'Houston, Texas 77065',25223,30801);
INSERT INTO "django_geo_db_zipcode" VALUES(34427,77066,-6,'Houston, Texas 77066',25223,30802);
INSERT INTO "django_geo_db_zipcode" VALUES(34428,77067,-6,'Houston, Texas 77067',25223,30803);
INSERT INTO "django_geo_db_zipcode" VALUES(34429,77068,-6,'Houston, Texas 77068',25223,30804);
INSERT INTO "django_geo_db_zipcode" VALUES(34430,77069,-6,'Houston, Texas 77069',25223,30805);
INSERT INTO "django_geo_db_zipcode" VALUES(34431,77070,-6,'Houston, Texas 77070',25223,30806);
INSERT INTO "django_geo_db_zipcode" VALUES(34432,77071,-6,'Houston, Texas 77071',25223,30807);
INSERT INTO "django_geo_db_zipcode" VALUES(34433,77072,-6,'Houston, Texas 77072',25223,30808);
INSERT INTO "django_geo_db_zipcode" VALUES(34434,77073,-6,'Houston, Texas 77073',25223,30809);
INSERT INTO "django_geo_db_zipcode" VALUES(34435,77074,-6,'Houston, Texas 77074',25223,30810);
INSERT INTO "django_geo_db_zipcode" VALUES(34436,77075,-6,'Houston, Texas 77075',25223,30811);
INSERT INTO "django_geo_db_zipcode" VALUES(34437,77076,-6,'Houston, Texas 77076',25223,30812);
INSERT INTO "django_geo_db_zipcode" VALUES(34438,77077,-6,'Houston, Texas 77077',25223,30813);
INSERT INTO "django_geo_db_zipcode" VALUES(34439,77078,-6,'Houston, Texas 77078',25223,30814);
INSERT INTO "django_geo_db_zipcode" VALUES(34440,77079,-6,'Houston, Texas 77079',25223,30815);
INSERT INTO "django_geo_db_zipcode" VALUES(34441,77080,-6,'Houston, Texas 77080',25223,30816);
INSERT INTO "django_geo_db_zipcode" VALUES(34442,77081,-6,'Houston, Texas 77081',25223,30817);
INSERT INTO "django_geo_db_zipcode" VALUES(34443,77082,-6,'Houston, Texas 77082',25223,30818);
INSERT INTO "django_geo_db_zipcode" VALUES(34444,77083,-6,'Houston, Texas 77083',25223,30819);
INSERT INTO "django_geo_db_zipcode" VALUES(34445,77084,-6,'Houston, Texas 77084',25223,30820);
INSERT INTO "django_geo_db_zipcode" VALUES(34446,77085,-6,'Houston, Texas 77085',25223,30821);
INSERT INTO "django_geo_db_zipcode" VALUES(34447,77086,-6,'Houston, Texas 77086',25223,30822);
INSERT INTO "django_geo_db_zipcode" VALUES(34448,77087,-6,'Houston, Texas 77087',25223,30823);
INSERT INTO "django_geo_db_zipcode" VALUES(34449,77088,-6,'Houston, Texas 77088',25223,30824);
INSERT INTO "django_geo_db_zipcode" VALUES(34450,77089,-6,'Houston, Texas 77089',25223,30825);
INSERT INTO "django_geo_db_zipcode" VALUES(34451,77090,-6,'Houston, Texas 77090',25223,30826);
INSERT INTO "django_geo_db_zipcode" VALUES(34452,77091,-6,'Houston, Texas 77091',25223,30827);
INSERT INTO "django_geo_db_zipcode" VALUES(34453,77092,-6,'Houston, Texas 77092',25223,30828);
INSERT INTO "django_geo_db_zipcode" VALUES(34454,77093,-6,'Houston, Texas 77093',25223,30829);
INSERT INTO "django_geo_db_zipcode" VALUES(34455,77094,-6,'Houston, Texas 77094',25223,30830);
INSERT INTO "django_geo_db_zipcode" VALUES(34456,77095,-6,'Houston, Texas 77095',25223,30831);
INSERT INTO "django_geo_db_zipcode" VALUES(34457,77096,-6,'Houston, Texas 77096',25223,30832);
INSERT INTO "django_geo_db_zipcode" VALUES(34458,77097,-6,'Houston, Texas 77097',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34459,77098,-6,'Houston, Texas 77098',25223,30834);
INSERT INTO "django_geo_db_zipcode" VALUES(34460,77099,-6,'Houston, Texas 77099',25223,30835);
INSERT INTO "django_geo_db_zipcode" VALUES(34461,77201,-6,'Houston, Texas 77201',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34462,77202,-6,'Houston, Texas 77202',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34463,77203,-6,'Houston, Texas 77203',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34464,77204,-6,'Houston, Texas 77204',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34465,77205,-6,'Houston, Texas 77205',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34466,77206,-6,'Houston, Texas 77206',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34467,77207,-6,'Houston, Texas 77207',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34468,77208,-6,'Houston, Texas 77208',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34469,77209,-6,'Houston, Texas 77209',25223,30836);
INSERT INTO "django_geo_db_zipcode" VALUES(34470,77210,-6,'Houston, Texas 77210',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34471,77212,-6,'Houston, Texas 77212',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34472,77213,-6,'Houston, Texas 77213',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34473,77215,-6,'Houston, Texas 77215',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34474,77216,-6,'Houston, Texas 77216',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34475,77217,-6,'Houston, Texas 77217',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34476,77218,-6,'Houston, Texas 77218',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34477,77219,-6,'Houston, Texas 77219',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34478,77220,-6,'Houston, Texas 77220',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34479,77221,-6,'Houston, Texas 77221',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34480,77222,-6,'Houston, Texas 77222',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34481,77223,-6,'Houston, Texas 77223',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34482,77224,-6,'Houston, Texas 77224',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34483,77225,-6,'Houston, Texas 77225',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34484,77226,-6,'Houston, Texas 77226',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34485,77227,-6,'Houston, Texas 77227',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34486,77228,-6,'Houston, Texas 77228',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34487,77229,-6,'Houston, Texas 77229',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34488,77230,-6,'Houston, Texas 77230',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34489,77231,-6,'Houston, Texas 77231',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34490,77233,-6,'Houston, Texas 77233',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34491,77234,-6,'Houston, Texas 77234',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34492,77235,-6,'Houston, Texas 77235',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34493,77236,-6,'Houston, Texas 77236',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34494,77237,-6,'Houston, Texas 77237',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34495,77238,-6,'Houston, Texas 77238',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34496,77240,-6,'Houston, Texas 77240',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34497,77241,-6,'Houston, Texas 77241',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34498,77242,-6,'Houston, Texas 77242',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34499,77243,-6,'Houston, Texas 77243',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34500,77244,-6,'Houston, Texas 77244',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34501,77245,-6,'Houston, Texas 77245',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34502,77248,-6,'Houston, Texas 77248',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34503,77249,-6,'Houston, Texas 77249',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34504,77251,-6,'Houston, Texas 77251',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34505,77252,-6,'Houston, Texas 77252',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34506,77253,-6,'Houston, Texas 77253',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34507,77254,-6,'Houston, Texas 77254',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34508,77255,-6,'Houston, Texas 77255',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34509,77256,-6,'Houston, Texas 77256',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34510,77257,-6,'Houston, Texas 77257',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34511,77258,-6,'Houston, Texas 77258',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34512,77259,-6,'Houston, Texas 77259',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34513,77261,-6,'Houston, Texas 77261',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34514,77262,-6,'Houston, Texas 77262',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34515,77263,-6,'Houston, Texas 77263',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34516,77265,-6,'Houston, Texas 77265',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34517,77266,-6,'Houston, Texas 77266',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34518,77267,-6,'Houston, Texas 77267',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34519,77268,-6,'Houston, Texas 77268',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34520,77269,-6,'Houston, Texas 77269',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34521,77270,-6,'Houston, Texas 77270',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34522,77271,-6,'Houston, Texas 77271',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34523,77272,-6,'Houston, Texas 77272',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34524,77273,-6,'Houston, Texas 77273',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34525,77274,-6,'Houston, Texas 77274',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34526,77275,-6,'Houston, Texas 77275',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34527,77277,-6,'Houston, Texas 77277',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34528,77279,-6,'Houston, Texas 77279',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34529,77280,-6,'Houston, Texas 77280',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34530,77281,-6,'Houston, Texas 77281',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34531,77282,-6,'Houston, Texas 77282',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34532,77284,-6,'Houston, Texas 77284',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34533,77287,-6,'Houston, Texas 77287',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34534,77288,-6,'Houston, Texas 77288',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34535,77289,-6,'Houston, Texas 77289',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34536,77290,-6,'Houston, Texas 77290',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34537,77291,-6,'Houston, Texas 77291',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34538,77292,-6,'Houston, Texas 77292',25223,30837);
INSERT INTO "django_geo_db_zipcode" VALUES(34539,77293,-6,'Houston, Texas 77293',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34540,77297,-6,'Houston, Texas 77297',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34541,77298,-6,'Houston, Texas 77298',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34542,77299,-6,'Houston, Texas 77299',25223,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34543,77301,-6,'Conroe, Texas 77301',25224,30838);
INSERT INTO "django_geo_db_zipcode" VALUES(34544,77302,-6,'Conroe, Texas 77302',25224,30839);
INSERT INTO "django_geo_db_zipcode" VALUES(34545,77303,-6,'Conroe, Texas 77303',25224,30840);
INSERT INTO "django_geo_db_zipcode" VALUES(34546,77304,-6,'Conroe, Texas 77304',25224,30841);
INSERT INTO "django_geo_db_zipcode" VALUES(34547,77305,-6,'Conroe, Texas 77305',25224,30842);
INSERT INTO "django_geo_db_zipcode" VALUES(34548,77306,-6,'Conroe, Texas 77306',25224,30843);
INSERT INTO "django_geo_db_zipcode" VALUES(34549,77315,-6,'North Houston, Texas 77315',25225,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34550,77316,-6,'Montgomery, Texas 77316',25226,30844);
INSERT INTO "django_geo_db_zipcode" VALUES(34551,77318,-6,'Willis, Texas 77318',25227,30845);
INSERT INTO "django_geo_db_zipcode" VALUES(34552,77320,-6,'Huntsville, Texas 77320',25228,30846);
INSERT INTO "django_geo_db_zipcode" VALUES(34553,77325,-6,'Humble, Texas 77325',25229,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34554,77326,-6,'Ace, Texas 77326',25230,30847);
INSERT INTO "django_geo_db_zipcode" VALUES(34555,77327,-6,'Cleveland, Texas 77327',25231,30848);
INSERT INTO "django_geo_db_zipcode" VALUES(34556,77328,-6,'Cleveland, Texas 77328',25231,30849);
INSERT INTO "django_geo_db_zipcode" VALUES(34557,77331,-6,'Coldspring, Texas 77331',25232,30850);
INSERT INTO "django_geo_db_zipcode" VALUES(34558,77332,-6,'Dallardsville, Texas 77332',25233,30851);
INSERT INTO "django_geo_db_zipcode" VALUES(34559,77333,-6,'Dobbin, Texas 77333',25234,30852);
INSERT INTO "django_geo_db_zipcode" VALUES(34560,77334,-6,'Dodge, Texas 77334',25235,30853);
INSERT INTO "django_geo_db_zipcode" VALUES(34561,77335,-6,'Goodrich, Texas 77335',25236,30854);
INSERT INTO "django_geo_db_zipcode" VALUES(34562,77336,-6,'Huffman, Texas 77336',25237,30855);
INSERT INTO "django_geo_db_zipcode" VALUES(34563,77337,-6,'Hufsmith, Texas 77337',25238,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34564,77338,-6,'Humble, Texas 77338',25229,30856);
INSERT INTO "django_geo_db_zipcode" VALUES(34565,77339,-6,'Humble, Texas 77339',25229,30857);
INSERT INTO "django_geo_db_zipcode" VALUES(34566,77340,-6,'Huntsville, Texas 77340',25228,30858);
INSERT INTO "django_geo_db_zipcode" VALUES(34567,77341,-6,'Huntsville, Texas 77341',25228,30859);
INSERT INTO "django_geo_db_zipcode" VALUES(34568,77342,-6,'Huntsville, Texas 77342',25228,30860);
INSERT INTO "django_geo_db_zipcode" VALUES(34569,77343,-6,'Huntsville, Texas 77343',25228,30860);
INSERT INTO "django_geo_db_zipcode" VALUES(34570,77344,-6,'Huntsville, Texas 77344',25228,30860);
INSERT INTO "django_geo_db_zipcode" VALUES(34571,77345,-6,'Humble, Texas 77345',25229,30861);
INSERT INTO "django_geo_db_zipcode" VALUES(34572,77346,-6,'Humble, Texas 77346',25229,30862);
INSERT INTO "django_geo_db_zipcode" VALUES(34573,77347,-6,'Humble, Texas 77347',25229,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34574,77348,-6,'Huntsville, Texas 77348',25228,30860);
INSERT INTO "django_geo_db_zipcode" VALUES(34575,77349,-6,'Huntsville, Texas 77349',25228,30860);
INSERT INTO "django_geo_db_zipcode" VALUES(34576,77350,-6,'Leggett, Texas 77350',25239,30863);
INSERT INTO "django_geo_db_zipcode" VALUES(34577,77351,-6,'Livingston, Texas 77351',25240,30864);
INSERT INTO "django_geo_db_zipcode" VALUES(34578,77353,-6,'Magnolia, Texas 77353',25241,30865);
INSERT INTO "django_geo_db_zipcode" VALUES(34579,77354,-6,'Magnolia, Texas 77354',25241,30866);
INSERT INTO "django_geo_db_zipcode" VALUES(34580,77355,-6,'Magnolia, Texas 77355',25241,30867);
INSERT INTO "django_geo_db_zipcode" VALUES(34581,77356,-6,'Montgomery, Texas 77356',25226,30868);
INSERT INTO "django_geo_db_zipcode" VALUES(34582,77357,-6,'New Caney, Texas 77357',25242,30869);
INSERT INTO "django_geo_db_zipcode" VALUES(34583,77358,-6,'New Waverly, Texas 77358',25243,30870);
INSERT INTO "django_geo_db_zipcode" VALUES(34584,77359,-6,'Oakhurst, Texas 77359',25244,30871);
INSERT INTO "django_geo_db_zipcode" VALUES(34585,77360,-6,'Onalaska, Texas 77360',25245,30872);
INSERT INTO "django_geo_db_zipcode" VALUES(34586,77362,-6,'Pinehurst, Texas 77362',25246,30873);
INSERT INTO "django_geo_db_zipcode" VALUES(34587,77363,-6,'Plantersville, Texas 77363',25247,30874);
INSERT INTO "django_geo_db_zipcode" VALUES(34588,77364,-6,'Pointblank, Texas 77364',25248,30875);
INSERT INTO "django_geo_db_zipcode" VALUES(34589,77365,-6,'Porter, Texas 77365',25249,30876);
INSERT INTO "django_geo_db_zipcode" VALUES(34590,77367,-6,'Riverside, Texas 77367',25250,30877);
INSERT INTO "django_geo_db_zipcode" VALUES(34591,77368,-6,'Romayor, Texas 77368',25251,30878);
INSERT INTO "django_geo_db_zipcode" VALUES(34592,77369,-6,'Rye, Texas 77369',25252,30879);
INSERT INTO "django_geo_db_zipcode" VALUES(34593,77371,-6,'Shepherd, Texas 77371',25253,30880);
INSERT INTO "django_geo_db_zipcode" VALUES(34594,77372,-6,'Splendora, Texas 77372',25254,30881);
INSERT INTO "django_geo_db_zipcode" VALUES(34595,77373,-6,'Spring, Texas 77373',25255,30882);
INSERT INTO "django_geo_db_zipcode" VALUES(34596,77374,-6,'Thicket, Texas 77374',25256,30883);
INSERT INTO "django_geo_db_zipcode" VALUES(34597,77375,-6,'Tomball, Texas 77375',25257,30884);
INSERT INTO "django_geo_db_zipcode" VALUES(34598,77376,-6,'Votaw, Texas 77376',25258,30885);
INSERT INTO "django_geo_db_zipcode" VALUES(34599,77377,-6,'Tomball, Texas 77377',25257,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34600,77378,-6,'Willis, Texas 77378',25227,30886);
INSERT INTO "django_geo_db_zipcode" VALUES(34601,77379,-6,'Spring, Texas 77379',25255,30887);
INSERT INTO "django_geo_db_zipcode" VALUES(34602,77380,-6,'Spring, Texas 77380',25255,30888);
INSERT INTO "django_geo_db_zipcode" VALUES(34603,77381,-6,'Spring, Texas 77381',25255,30889);
INSERT INTO "django_geo_db_zipcode" VALUES(34604,77382,-6,'Spring, Texas 77382',25255,30890);
INSERT INTO "django_geo_db_zipcode" VALUES(34605,77383,-6,'Spring, Texas 77383',25255,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34606,77384,-6,'Conroe, Texas 77384',25224,30891);
INSERT INTO "django_geo_db_zipcode" VALUES(34607,77385,-6,'Conroe, Texas 77385',25224,30892);
INSERT INTO "django_geo_db_zipcode" VALUES(34608,77386,-6,'Spring, Texas 77386',25255,30893);
INSERT INTO "django_geo_db_zipcode" VALUES(34609,77387,-6,'Spring, Texas 77387',25255,30894);
INSERT INTO "django_geo_db_zipcode" VALUES(34610,77388,-6,'Spring, Texas 77388',25255,30895);
INSERT INTO "django_geo_db_zipcode" VALUES(34611,77389,-6,'Spring, Texas 77389',25255,30896);
INSERT INTO "django_geo_db_zipcode" VALUES(34612,77391,-6,'Spring, Texas 77391',25255,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34613,77393,-6,'Spring, Texas 77393',25255,30897);
INSERT INTO "django_geo_db_zipcode" VALUES(34614,77396,-6,'Humble, Texas 77396',25229,30898);
INSERT INTO "django_geo_db_zipcode" VALUES(34615,77399,-6,'Livingston, Texas 77399',25240,30851);
INSERT INTO "django_geo_db_zipcode" VALUES(34616,77401,-6,'Bellaire, Texas 77401',25259,30899);
INSERT INTO "django_geo_db_zipcode" VALUES(34617,77402,-6,'Bellaire, Texas 77402',25259,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34618,77404,-6,'Bay City, Texas 77404',25260,30900);
INSERT INTO "django_geo_db_zipcode" VALUES(34619,77406,-6,'Richmond, Texas 77406',25261,30901);
INSERT INTO "django_geo_db_zipcode" VALUES(34620,77410,-6,'Cypress, Texas 77410',25262,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34621,77411,-6,'Alief, Texas 77411',25263,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34622,77412,-6,'Altair, Texas 77412',25264,30902);
INSERT INTO "django_geo_db_zipcode" VALUES(34623,77413,-6,'Barker, Texas 77413',25265,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34624,77414,-6,'Bay City, Texas 77414',25260,30903);
INSERT INTO "django_geo_db_zipcode" VALUES(34625,77415,-6,'Cedar Lane, Texas 77415',25266,30904);
INSERT INTO "django_geo_db_zipcode" VALUES(34626,77417,-6,'Beasley, Texas 77417',25267,30905);
INSERT INTO "django_geo_db_zipcode" VALUES(34627,77418,-6,'Bellville, Texas 77418',25268,30906);
INSERT INTO "django_geo_db_zipcode" VALUES(34628,77419,-6,'Blessing, Texas 77419',25269,30907);
INSERT INTO "django_geo_db_zipcode" VALUES(34629,77420,-6,'Boling, Texas 77420',25270,30908);
INSERT INTO "django_geo_db_zipcode" VALUES(34630,77422,-6,'Brazoria, Texas 77422',25271,30909);
INSERT INTO "django_geo_db_zipcode" VALUES(34631,77423,-6,'Brookshire, Texas 77423',25272,30910);
INSERT INTO "django_geo_db_zipcode" VALUES(34632,77426,-6,'Chappell Hill, Texas 77426',25273,30911);
INSERT INTO "django_geo_db_zipcode" VALUES(34633,77428,-6,'Collegeport, Texas 77428',25274,30912);
INSERT INTO "django_geo_db_zipcode" VALUES(34634,77429,-6,'Cypress, Texas 77429',25262,30913);
INSERT INTO "django_geo_db_zipcode" VALUES(34635,77430,-6,'Damon, Texas 77430',25275,30914);
INSERT INTO "django_geo_db_zipcode" VALUES(34636,77431,-6,'Danciger, Texas 77431',25276,30915);
INSERT INTO "django_geo_db_zipcode" VALUES(34637,77432,-6,'Danevang, Texas 77432',25277,30916);
INSERT INTO "django_geo_db_zipcode" VALUES(34638,77433,-6,'Cypress, Texas 77433',25262,30917);
INSERT INTO "django_geo_db_zipcode" VALUES(34639,77434,-6,'Eagle Lake, Texas 77434',25278,30918);
INSERT INTO "django_geo_db_zipcode" VALUES(34640,77435,-6,'East Bernard, Texas 77435',25279,30919);
INSERT INTO "django_geo_db_zipcode" VALUES(34641,77436,-6,'Egypt, Texas 77436',25280,30920);
INSERT INTO "django_geo_db_zipcode" VALUES(34642,77437,-6,'El Campo, Texas 77437',25281,30921);
INSERT INTO "django_geo_db_zipcode" VALUES(34643,77439,-6,'San Leon, Texas 77439',25282,30922);
INSERT INTO "django_geo_db_zipcode" VALUES(34644,77440,-6,'Elmaton, Texas 77440',25283,30923);
INSERT INTO "django_geo_db_zipcode" VALUES(34645,77441,-6,'Fulshear, Texas 77441',25284,30924);
INSERT INTO "django_geo_db_zipcode" VALUES(34646,77442,-6,'Garwood, Texas 77442',25285,30925);
INSERT INTO "django_geo_db_zipcode" VALUES(34647,77443,-6,'Glen Flora, Texas 77443',25286,30926);
INSERT INTO "django_geo_db_zipcode" VALUES(34648,77444,-6,'Guy, Texas 77444',25287,30927);
INSERT INTO "django_geo_db_zipcode" VALUES(34649,77445,-6,'Hempstead, Texas 77445',25288,30928);
INSERT INTO "django_geo_db_zipcode" VALUES(34650,77446,-6,'Prairie View, Texas 77446',25289,30929);
INSERT INTO "django_geo_db_zipcode" VALUES(34651,77447,-6,'Hockley, Texas 77447',25290,30930);
INSERT INTO "django_geo_db_zipcode" VALUES(34652,77448,-6,'Hungerford, Texas 77448',25291,30931);
INSERT INTO "django_geo_db_zipcode" VALUES(34653,77449,-6,'Katy, Texas 77449',25292,30932);
INSERT INTO "django_geo_db_zipcode" VALUES(34654,77450,-6,'Katy, Texas 77450',25292,30933);
INSERT INTO "django_geo_db_zipcode" VALUES(34655,77451,-6,'Kendleton, Texas 77451',25293,30934);
INSERT INTO "django_geo_db_zipcode" VALUES(34656,77452,-6,'Kenney, Texas 77452',25294,30935);
INSERT INTO "django_geo_db_zipcode" VALUES(34657,77453,-6,'Lane City, Texas 77453',25295,30936);
INSERT INTO "django_geo_db_zipcode" VALUES(34658,77454,-6,'Lissie, Texas 77454',25296,30937);
INSERT INTO "django_geo_db_zipcode" VALUES(34659,77455,-6,'Louise, Texas 77455',25297,30938);
INSERT INTO "django_geo_db_zipcode" VALUES(34660,77456,-6,'Markham, Texas 77456',25298,30939);
INSERT INTO "django_geo_db_zipcode" VALUES(34661,77457,-6,'Matagorda, Texas 77457',25299,30940);
INSERT INTO "django_geo_db_zipcode" VALUES(34662,77458,-6,'Midfield, Texas 77458',25300,30941);
INSERT INTO "django_geo_db_zipcode" VALUES(34663,77459,-6,'Missouri City, Texas 77459',25301,30942);
INSERT INTO "django_geo_db_zipcode" VALUES(34664,77460,-6,'Nada, Texas 77460',25302,30943);
INSERT INTO "django_geo_db_zipcode" VALUES(34665,77461,-6,'Needville, Texas 77461',25303,30944);
INSERT INTO "django_geo_db_zipcode" VALUES(34666,77462,-6,'Newgulf, Texas 77462',25304,30945);
INSERT INTO "django_geo_db_zipcode" VALUES(34667,77463,-6,'Old Ocean, Texas 77463',25305,30946);
INSERT INTO "django_geo_db_zipcode" VALUES(34668,77464,-6,'Orchard, Texas 77464',25306,30947);
INSERT INTO "django_geo_db_zipcode" VALUES(34669,77465,-6,'Palacios, Texas 77465',25307,30948);
INSERT INTO "django_geo_db_zipcode" VALUES(34670,77466,-6,'Pattison, Texas 77466',25308,30949);
INSERT INTO "django_geo_db_zipcode" VALUES(34671,77467,-6,'Pierce, Texas 77467',25309,30950);
INSERT INTO "django_geo_db_zipcode" VALUES(34672,77468,-6,'Pledger, Texas 77468',25310,30951);
INSERT INTO "django_geo_db_zipcode" VALUES(34673,77469,-6,'Richmond, Texas 77469',25261,30952);
INSERT INTO "django_geo_db_zipcode" VALUES(34674,77470,-6,'Rock Island, Texas 77470',25311,30953);
INSERT INTO "django_geo_db_zipcode" VALUES(34675,77471,-6,'Rosenberg, Texas 77471',25312,30954);
INSERT INTO "django_geo_db_zipcode" VALUES(34676,77473,-6,'San Felipe, Texas 77473',25313,30955);
INSERT INTO "django_geo_db_zipcode" VALUES(34677,77474,-6,'Sealy, Texas 77474',25314,30956);
INSERT INTO "django_geo_db_zipcode" VALUES(34678,77475,-6,'Sheridan, Texas 77475',25315,30957);
INSERT INTO "django_geo_db_zipcode" VALUES(34679,77476,-6,'Simonton, Texas 77476',25316,30958);
INSERT INTO "django_geo_db_zipcode" VALUES(34680,77477,-6,'Stafford, Texas 77477',25317,30959);
INSERT INTO "django_geo_db_zipcode" VALUES(34681,77478,-6,'Sugar Land, Texas 77478',25318,30960);
INSERT INTO "django_geo_db_zipcode" VALUES(34682,77479,-6,'Sugar Land, Texas 77479',25318,30961);
INSERT INTO "django_geo_db_zipcode" VALUES(34683,77480,-6,'Sweeny, Texas 77480',25319,30962);
INSERT INTO "django_geo_db_zipcode" VALUES(34684,77481,-6,'Thompsons, Texas 77481',25320,30963);
INSERT INTO "django_geo_db_zipcode" VALUES(34685,77482,-6,'Van Vleck, Texas 77482',25321,30964);
INSERT INTO "django_geo_db_zipcode" VALUES(34686,77483,-6,'Wadsworth, Texas 77483',25322,30965);
INSERT INTO "django_geo_db_zipcode" VALUES(34687,77484,-6,'Waller, Texas 77484',25323,30966);
INSERT INTO "django_geo_db_zipcode" VALUES(34688,77485,-6,'Wallis, Texas 77485',25324,30967);
INSERT INTO "django_geo_db_zipcode" VALUES(34689,77486,-6,'West Columbia, Texas 77486',25325,30968);
INSERT INTO "django_geo_db_zipcode" VALUES(34690,77487,-6,'Sugar Land, Texas 77487',25318,30969);
INSERT INTO "django_geo_db_zipcode" VALUES(34691,77488,-6,'Wharton, Texas 77488',25326,30970);
INSERT INTO "django_geo_db_zipcode" VALUES(34692,77489,-6,'Missouri City, Texas 77489',25301,30971);
INSERT INTO "django_geo_db_zipcode" VALUES(34693,77491,-6,'Katy, Texas 77491',25292,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34694,77492,-6,'Katy, Texas 77492',25292,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34695,77493,-6,'Katy, Texas 77493',25292,30972);
INSERT INTO "django_geo_db_zipcode" VALUES(34696,77494,-6,'Katy, Texas 77494',25292,30973);
INSERT INTO "django_geo_db_zipcode" VALUES(34697,77496,-6,'Sugar Land, Texas 77496',25318,30969);
INSERT INTO "django_geo_db_zipcode" VALUES(34698,77497,-6,'Stafford, Texas 77497',25317,30969);
INSERT INTO "django_geo_db_zipcode" VALUES(34699,77501,-6,'Pasadena, Texas 77501',25327,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34700,77502,-6,'Pasadena, Texas 77502',25327,30974);
INSERT INTO "django_geo_db_zipcode" VALUES(34701,77503,-6,'Pasadena, Texas 77503',25327,30975);
INSERT INTO "django_geo_db_zipcode" VALUES(34702,77504,-6,'Pasadena, Texas 77504',25327,30976);
INSERT INTO "django_geo_db_zipcode" VALUES(34703,77505,-6,'Pasadena, Texas 77505',25327,30977);
INSERT INTO "django_geo_db_zipcode" VALUES(34704,77506,-6,'Pasadena, Texas 77506',25327,30978);
INSERT INTO "django_geo_db_zipcode" VALUES(34705,77507,-6,'Pasadena, Texas 77507',25327,30979);
INSERT INTO "django_geo_db_zipcode" VALUES(34706,77508,-6,'Pasadena, Texas 77508',25327,30980);
INSERT INTO "django_geo_db_zipcode" VALUES(34707,77510,-6,'Santa Fe, Texas 77510',25328,30981);
INSERT INTO "django_geo_db_zipcode" VALUES(34708,77511,-6,'Alvin, Texas 77511',25329,30982);
INSERT INTO "django_geo_db_zipcode" VALUES(34709,77512,-6,'Alvin, Texas 77512',25329,30983);
INSERT INTO "django_geo_db_zipcode" VALUES(34710,77514,-6,'Anahuac, Texas 77514',25330,30984);
INSERT INTO "django_geo_db_zipcode" VALUES(34711,77515,-6,'Angleton, Texas 77515',25331,30985);
INSERT INTO "django_geo_db_zipcode" VALUES(34712,77516,-6,'Angleton, Texas 77516',25331,30986);
INSERT INTO "django_geo_db_zipcode" VALUES(34713,77517,-6,'Santa Fe, Texas 77517',25328,30987);
INSERT INTO "django_geo_db_zipcode" VALUES(34714,77518,-6,'Bacliff, Texas 77518',25332,30988);
INSERT INTO "django_geo_db_zipcode" VALUES(34715,77519,-6,'Batson, Texas 77519',25333,30989);
INSERT INTO "django_geo_db_zipcode" VALUES(34716,77520,-6,'Baytown, Texas 77520',25334,30990);
INSERT INTO "django_geo_db_zipcode" VALUES(34717,77521,-6,'Baytown, Texas 77521',25334,30991);
INSERT INTO "django_geo_db_zipcode" VALUES(34718,77522,-6,'Baytown, Texas 77522',25334,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34719,77530,-6,'Channelview, Texas 77530',25335,30992);
INSERT INTO "django_geo_db_zipcode" VALUES(34720,77531,-6,'Clute, Texas 77531',25336,30993);
INSERT INTO "django_geo_db_zipcode" VALUES(34721,77532,-6,'Crosby, Texas 77532',25337,30994);
INSERT INTO "django_geo_db_zipcode" VALUES(34722,77533,-6,'Daisetta, Texas 77533',25338,30995);
INSERT INTO "django_geo_db_zipcode" VALUES(34723,77534,-6,'Danbury, Texas 77534',25339,30996);
INSERT INTO "django_geo_db_zipcode" VALUES(34724,77535,-6,'Dayton, Texas 77535',25340,30997);
INSERT INTO "django_geo_db_zipcode" VALUES(34725,77536,-6,'Deer Park, Texas 77536',25341,30998);
INSERT INTO "django_geo_db_zipcode" VALUES(34726,77537,-6,'Dickinson, Texas 77537',25342,30999);
INSERT INTO "django_geo_db_zipcode" VALUES(34727,77538,-6,'Devers, Texas 77538',25343,31000);
INSERT INTO "django_geo_db_zipcode" VALUES(34728,77539,-6,'Dickinson, Texas 77539',25342,31001);
INSERT INTO "django_geo_db_zipcode" VALUES(34729,77541,-6,'Freeport, Texas 77541',25344,31002);
INSERT INTO "django_geo_db_zipcode" VALUES(34730,77542,-6,'Freeport, Texas 77542',25344,30986);
INSERT INTO "django_geo_db_zipcode" VALUES(34731,77545,-6,'Fresno, Texas 77545',25345,31003);
INSERT INTO "django_geo_db_zipcode" VALUES(34732,77546,-6,'Friendswood, Texas 77546',25346,31004);
INSERT INTO "django_geo_db_zipcode" VALUES(34733,77547,-6,'Galena Park, Texas 77547',25347,31005);
INSERT INTO "django_geo_db_zipcode" VALUES(34734,77549,-6,'Friendswood, Texas 77549',25346,31006);
INSERT INTO "django_geo_db_zipcode" VALUES(34735,77550,-6,'Galveston, Texas 77550',25348,31007);
INSERT INTO "django_geo_db_zipcode" VALUES(34736,77551,-6,'Galveston, Texas 77551',25348,31008);
INSERT INTO "django_geo_db_zipcode" VALUES(34737,77552,-6,'Galveston, Texas 77552',25348,31009);
INSERT INTO "django_geo_db_zipcode" VALUES(34738,77553,-6,'Galveston, Texas 77553',25348,31010);
INSERT INTO "django_geo_db_zipcode" VALUES(34739,77554,-6,'Galveston, Texas 77554',25348,31011);
INSERT INTO "django_geo_db_zipcode" VALUES(34740,77555,-6,'Galveston, Texas 77555',25348,31006);
INSERT INTO "django_geo_db_zipcode" VALUES(34741,77560,-6,'Hankamer, Texas 77560',25349,31012);
INSERT INTO "django_geo_db_zipcode" VALUES(34742,77561,-6,'Hardin, Texas 77561',25350,31013);
INSERT INTO "django_geo_db_zipcode" VALUES(34743,77562,-6,'Highlands, Texas 77562',25351,31014);
INSERT INTO "django_geo_db_zipcode" VALUES(34744,77563,-6,'Hitchcock, Texas 77563',25352,31015);
INSERT INTO "django_geo_db_zipcode" VALUES(34745,77564,-6,'Hull, Texas 77564',25353,31016);
INSERT INTO "django_geo_db_zipcode" VALUES(34746,77565,-6,'Kemah, Texas 77565',25354,31017);
INSERT INTO "django_geo_db_zipcode" VALUES(34747,77566,-6,'Lake Jackson, Texas 77566',25355,31018);
INSERT INTO "django_geo_db_zipcode" VALUES(34748,77567,-6,'League City, Texas 77567',25356,31019);
INSERT INTO "django_geo_db_zipcode" VALUES(34749,77568,-6,'La Marque, Texas 77568',25357,31020);
INSERT INTO "django_geo_db_zipcode" VALUES(34750,77571,-6,'La Porte, Texas 77571',25358,31021);
INSERT INTO "django_geo_db_zipcode" VALUES(34751,77572,-6,'La Porte, Texas 77572',25358,30833);
INSERT INTO "django_geo_db_zipcode" VALUES(34752,77573,-6,'League City, Texas 77573',25356,31022);
INSERT INTO "django_geo_db_zipcode" VALUES(34753,77574,-6,'League City, Texas 77574',25356,31023);
INSERT INTO "django_geo_db_zipcode" VALUES(34754,77575,-6,'Liberty, Texas 77575',25359,31024);
INSERT INTO "django_geo_db_zipcode" VALUES(34755,77577,-6,'Liverpool, Texas 77577',25360,31025);
INSERT INTO "django_geo_db_zipcode" VALUES(34756,77578,-6,'Manvel, Texas 77578',25361,31026);
INSERT INTO "django_geo_db_zipcode" VALUES(34757,77580,-6,'Mont Belvieu, Texas 77580',25362,31027);
INSERT INTO "django_geo_db_zipcode" VALUES(34758,77581,-6,'Pearland, Texas 77581',25363,31028);
INSERT INTO "django_geo_db_zipcode" VALUES(34759,77582,-6,'Raywood, Texas 77582',25364,31029);
INSERT INTO "django_geo_db_zipcode" VALUES(34760,77583,-6,'Rosharon, Texas 77583',25365,31030);
INSERT INTO "django_geo_db_zipcode" VALUES(34761,77584,-6,'Pearland, Texas 77584',25363,31031);
INSERT INTO "django_geo_db_zipcode" VALUES(34762,77585,-6,'Saratoga, Texas 77585',25366,31032);
INSERT INTO "django_geo_db_zipcode" VALUES(34763,77586,-6,'Seabrook, Texas 77586',25367,31033);
INSERT INTO "django_geo_db_zipcode" VALUES(34764,77587,-6,'South Houston, Texas 77587',25368,31034);
INSERT INTO "django_geo_db_zipcode" VALUES(34765,77588,-6,'Pearland, Texas 77588',25363,31035);
INSERT INTO "django_geo_db_zipcode" VALUES(34766,77590,-6,'Texas City, Texas 77590',25369,31036);
INSERT INTO "django_geo_db_zipcode" VALUES(34767,77591,-6,'Texas City, Texas 77591',25369,31037);
INSERT INTO "django_geo_db_zipcode" VALUES(34768,77592,-6,'Texas City, Texas 77592',25369,31006);
INSERT INTO "django_geo_db_zipcode" VALUES(34769,77593,-6,'League City, Texas 77593',25356,31038);
INSERT INTO "django_geo_db_zipcode" VALUES(34770,77597,-6,'Wallisville, Texas 77597',25370,31039);
INSERT INTO "django_geo_db_zipcode" VALUES(34771,77598,-6,'Webster, Texas 77598',25371,31040);
INSERT INTO "django_geo_db_zipcode" VALUES(34772,77611,-6,'Bridge City, Texas 77611',25372,31041);
INSERT INTO "django_geo_db_zipcode" VALUES(34773,77612,-6,'Buna, Texas 77612',25373,31042);
INSERT INTO "django_geo_db_zipcode" VALUES(34774,77613,-6,'China, Texas 77613',25374,31043);
INSERT INTO "django_geo_db_zipcode" VALUES(34775,77614,-6,'Deweyville, Texas 77614',25375,31044);
INSERT INTO "django_geo_db_zipcode" VALUES(34776,77615,-6,'Evadale, Texas 77615',25376,31045);
INSERT INTO "django_geo_db_zipcode" VALUES(34777,77616,-6,'Fred, Texas 77616',25377,31046);
INSERT INTO "django_geo_db_zipcode" VALUES(34778,77617,-6,'Gilchrist, Texas 77617',25378,31047);
INSERT INTO "django_geo_db_zipcode" VALUES(34779,77619,-6,'Groves, Texas 77619',25379,31048);
INSERT INTO "django_geo_db_zipcode" VALUES(34780,77622,-6,'Hamshire, Texas 77622',25380,31049);
INSERT INTO "django_geo_db_zipcode" VALUES(34781,77623,-6,'High Island, Texas 77623',25381,31050);
INSERT INTO "django_geo_db_zipcode" VALUES(34782,77624,-6,'Hillister, Texas 77624',25382,31051);
INSERT INTO "django_geo_db_zipcode" VALUES(34783,77625,-6,'Kountze, Texas 77625',25383,31052);
INSERT INTO "django_geo_db_zipcode" VALUES(34784,77626,-6,'Mauriceville, Texas 77626',25384,31053);
INSERT INTO "django_geo_db_zipcode" VALUES(34785,77627,-6,'Nederland, Texas 77627',25385,31054);
INSERT INTO "django_geo_db_zipcode" VALUES(34786,77629,-6,'Nome, Texas 77629',25386,31055);
INSERT INTO "django_geo_db_zipcode" VALUES(34787,77630,-6,'Orange, Texas 77630',25387,31056);
INSERT INTO "django_geo_db_zipcode" VALUES(34788,77631,-6,'Orange, Texas 77631',25387,31057);
INSERT INTO "django_geo_db_zipcode" VALUES(34789,77632,-6,'Orange, Texas 77632',25387,31058);
INSERT INTO "django_geo_db_zipcode" VALUES(34790,77633,-6,'Brenham, Texas 77633',25388,31059);
INSERT INTO "django_geo_db_zipcode" VALUES(34791,77639,-6,'Orangefield, Texas 77639',25389,31060);
INSERT INTO "django_geo_db_zipcode" VALUES(34792,77640,-6,'Port Arthur, Texas 77640',25390,31061);
INSERT INTO "django_geo_db_zipcode" VALUES(34793,77641,-6,'Port Arthur, Texas 77641',25390,31062);
INSERT INTO "django_geo_db_zipcode" VALUES(34794,77642,-6,'Port Arthur, Texas 77642',25390,31063);
INSERT INTO "django_geo_db_zipcode" VALUES(34795,77643,-6,'Port Arthur, Texas 77643',25390,31064);
INSERT INTO "django_geo_db_zipcode" VALUES(34796,77650,-6,'Port Bolivar, Texas 77650',25391,31065);
INSERT INTO "django_geo_db_zipcode" VALUES(34797,77651,-6,'Port Neches, Texas 77651',25392,31066);
INSERT INTO "django_geo_db_zipcode" VALUES(34798,77655,-6,'Sabine Pass, Texas 77655',25393,31067);
INSERT INTO "django_geo_db_zipcode" VALUES(34799,77656,-6,'Silsbee, Texas 77656',25394,31068);
INSERT INTO "django_geo_db_zipcode" VALUES(34800,77657,-6,'Lumberton, Texas 77657',25395,31069);
INSERT INTO "django_geo_db_zipcode" VALUES(34801,77659,-6,'Sour Lake, Texas 77659',25396,31070);
INSERT INTO "django_geo_db_zipcode" VALUES(34802,77660,-6,'Spurger, Texas 77660',25397,31071);
INSERT INTO "django_geo_db_zipcode" VALUES(34803,77661,-6,'Stowell, Texas 77661',25398,31072);
INSERT INTO "django_geo_db_zipcode" VALUES(34804,77662,-6,'Vidor, Texas 77662',25399,31073);
INSERT INTO "django_geo_db_zipcode" VALUES(34805,77663,-6,'Village Mills, Texas 77663',25400,31074);
INSERT INTO "django_geo_db_zipcode" VALUES(34806,77664,-6,'Warren, Texas 77664',25401,31075);
INSERT INTO "django_geo_db_zipcode" VALUES(34807,77665,-6,'Winnie, Texas 77665',25402,31076);
INSERT INTO "django_geo_db_zipcode" VALUES(34808,77670,-6,'Vidor, Texas 77670',25399,31057);
INSERT INTO "django_geo_db_zipcode" VALUES(34809,77701,-6,'Beaumont, Texas 77701',25403,31077);
INSERT INTO "django_geo_db_zipcode" VALUES(34810,77702,-6,'Beaumont, Texas 77702',25403,31078);
INSERT INTO "django_geo_db_zipcode" VALUES(34811,77703,-6,'Beaumont, Texas 77703',25403,31079);
INSERT INTO "django_geo_db_zipcode" VALUES(34812,77704,-6,'Beaumont, Texas 77704',25403,31080);
INSERT INTO "django_geo_db_zipcode" VALUES(34813,77705,-6,'Beaumont, Texas 77705',25403,31081);
INSERT INTO "django_geo_db_zipcode" VALUES(34814,77706,-6,'Beaumont, Texas 77706',25403,31082);
INSERT INTO "django_geo_db_zipcode" VALUES(34815,77707,-6,'Beaumont, Texas 77707',25403,31083);
INSERT INTO "django_geo_db_zipcode" VALUES(34816,77708,-6,'Beaumont, Texas 77708',25403,31084);
INSERT INTO "django_geo_db_zipcode" VALUES(34817,77709,-6,'Voth, Texas 77709',25404,31085);
INSERT INTO "django_geo_db_zipcode" VALUES(34818,77710,-6,'Beaumont, Texas 77710',25403,31062);
INSERT INTO "django_geo_db_zipcode" VALUES(34819,77713,-6,'Beaumont, Texas 77713',25403,31086);
INSERT INTO "django_geo_db_zipcode" VALUES(34820,77720,-6,'Beaumont, Texas 77720',25403,31062);
INSERT INTO "django_geo_db_zipcode" VALUES(34821,77725,-6,'Beaumont, Texas 77725',25403,31062);
INSERT INTO "django_geo_db_zipcode" VALUES(34822,77726,-6,'Beaumont, Texas 77726',25403,31087);
INSERT INTO "django_geo_db_zipcode" VALUES(34823,77735,-6,'Tomball, Texas 77735',25257,31088);
INSERT INTO "django_geo_db_zipcode" VALUES(34824,77801,-6,'Bryan, Texas 77801',25405,31089);
INSERT INTO "django_geo_db_zipcode" VALUES(34825,77802,-6,'Bryan, Texas 77802',25405,31090);
INSERT INTO "django_geo_db_zipcode" VALUES(34826,77803,-6,'Bryan, Texas 77803',25405,31091);
INSERT INTO "django_geo_db_zipcode" VALUES(34827,77805,-6,'Bryan, Texas 77805',25405,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34828,77806,-6,'Bryan, Texas 77806',25405,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34829,77807,-6,'Bryan, Texas 77807',25405,31093);
INSERT INTO "django_geo_db_zipcode" VALUES(34830,77808,-6,'Bryan, Texas 77808',25405,31094);
INSERT INTO "django_geo_db_zipcode" VALUES(34831,77830,-6,'Anderson, Texas 77830',25406,31095);
INSERT INTO "django_geo_db_zipcode" VALUES(34832,77831,-6,'Bedias, Texas 77831',25407,31096);
INSERT INTO "django_geo_db_zipcode" VALUES(34833,77833,-6,'Brenham, Texas 77833',25388,31097);
INSERT INTO "django_geo_db_zipcode" VALUES(34834,77834,-6,'Brenham, Texas 77834',25388,31098);
INSERT INTO "django_geo_db_zipcode" VALUES(34835,77835,-6,'Burton, Texas 77835',25408,31099);
INSERT INTO "django_geo_db_zipcode" VALUES(34836,77836,-6,'Caldwell, Texas 77836',25409,31100);
INSERT INTO "django_geo_db_zipcode" VALUES(34837,77837,-6,'Calvert, Texas 77837',25410,31101);
INSERT INTO "django_geo_db_zipcode" VALUES(34838,77838,-6,'Chriesman, Texas 77838',25411,31102);
INSERT INTO "django_geo_db_zipcode" VALUES(34839,77839,-6,'Clay, Texas 77839',25412,31103);
INSERT INTO "django_geo_db_zipcode" VALUES(34840,77840,-6,'College Station, Texas 77840',25413,31104);
INSERT INTO "django_geo_db_zipcode" VALUES(34841,77841,-6,'College Station, Texas 77841',25413,31105);
INSERT INTO "django_geo_db_zipcode" VALUES(34842,77842,-6,'College Station, Texas 77842',25413,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34843,77843,-6,'College Station, Texas 77843',25413,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34844,77844,-6,'College Station, Texas 77844',25413,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34845,77845,-6,'College Station, Texas 77845',25413,31106);
INSERT INTO "django_geo_db_zipcode" VALUES(34846,77850,-6,'Concord, Texas 77850',25414,31107);
INSERT INTO "django_geo_db_zipcode" VALUES(34847,77852,-6,'Deanville, Texas 77852',25415,31102);
INSERT INTO "django_geo_db_zipcode" VALUES(34848,77853,-6,'Dime Box, Texas 77853',25416,31108);
INSERT INTO "django_geo_db_zipcode" VALUES(34849,77855,-6,'Flynn, Texas 77855',25417,31109);
INSERT INTO "django_geo_db_zipcode" VALUES(34850,77856,-6,'Franklin, Texas 77856',25418,31110);
INSERT INTO "django_geo_db_zipcode" VALUES(34851,77857,-6,'Gause, Texas 77857',25419,31111);
INSERT INTO "django_geo_db_zipcode" VALUES(34852,77859,-6,'Hearne, Texas 77859',25420,31112);
INSERT INTO "django_geo_db_zipcode" VALUES(34853,77861,-6,'Iola, Texas 77861',25421,31113);
INSERT INTO "django_geo_db_zipcode" VALUES(34854,77862,-6,'Kurten, Texas 77862',25422,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34855,77863,-6,'Lyons, Texas 77863',25423,31114);
INSERT INTO "django_geo_db_zipcode" VALUES(34856,77864,-6,'Madisonville, Texas 77864',25424,31115);
INSERT INTO "django_geo_db_zipcode" VALUES(34857,77865,-6,'Marquez, Texas 77865',25425,31116);
INSERT INTO "django_geo_db_zipcode" VALUES(34858,77866,-6,'Millican, Texas 77866',25426,31117);
INSERT INTO "django_geo_db_zipcode" VALUES(34859,77867,-6,'Mumford, Texas 77867',25427,31118);
INSERT INTO "django_geo_db_zipcode" VALUES(34860,77868,-6,'Navasota, Texas 77868',25428,31119);
INSERT INTO "django_geo_db_zipcode" VALUES(34861,77869,-6,'Navasota, Texas 77869',25428,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34862,77870,-6,'New Baden, Texas 77870',25429,31120);
INSERT INTO "django_geo_db_zipcode" VALUES(34863,77871,-6,'Normangee, Texas 77871',25430,31121);
INSERT INTO "django_geo_db_zipcode" VALUES(34864,77872,-6,'North Zulch, Texas 77872',25431,31122);
INSERT INTO "django_geo_db_zipcode" VALUES(34865,77873,-6,'Richards, Texas 77873',25432,31123);
INSERT INTO "django_geo_db_zipcode" VALUES(34866,77874,-6,'Waller, Texas 77874',25323,31124);
INSERT INTO "django_geo_db_zipcode" VALUES(34867,77875,-6,'Roans Prairie, Texas 77875',25433,31125);
INSERT INTO "django_geo_db_zipcode" VALUES(34868,77876,-6,'Shiro, Texas 77876',25434,31126);
INSERT INTO "django_geo_db_zipcode" VALUES(34869,77878,-6,'Snook, Texas 77878',25435,31127);
INSERT INTO "django_geo_db_zipcode" VALUES(34870,77879,-6,'Somerville, Texas 77879',25436,31128);
INSERT INTO "django_geo_db_zipcode" VALUES(34871,77880,-6,'Washington, Texas 77880',25437,31129);
INSERT INTO "django_geo_db_zipcode" VALUES(34872,77881,-6,'Wellborn, Texas 77881',25438,31092);
INSERT INTO "django_geo_db_zipcode" VALUES(34873,77882,-6,'Wheelock, Texas 77882',25439,31130);
INSERT INTO "django_geo_db_zipcode" VALUES(34874,77889,-6,'Sienna Plantation, Texas 77889',25440,31131);
INSERT INTO "django_geo_db_zipcode" VALUES(34875,77901,-6,'Victoria, Texas 77901',25441,31132);
INSERT INTO "django_geo_db_zipcode" VALUES(34876,77902,-6,'Victoria, Texas 77902',25441,31133);
INSERT INTO "django_geo_db_zipcode" VALUES(34877,77903,-6,'Victoria, Texas 77903',25441,31134);
INSERT INTO "django_geo_db_zipcode" VALUES(34878,77904,-6,'Victoria, Texas 77904',25441,31135);
INSERT INTO "django_geo_db_zipcode" VALUES(34879,77905,-6,'Victoria, Texas 77905',25441,31136);
INSERT INTO "django_geo_db_zipcode" VALUES(34880,77950,-6,'Austwell, Texas 77950',25442,31137);
INSERT INTO "django_geo_db_zipcode" VALUES(34881,77951,-6,'Bloomington, Texas 77951',25443,31138);
INSERT INTO "django_geo_db_zipcode" VALUES(34882,77954,-6,'Cuero, Texas 77954',25444,31139);
INSERT INTO "django_geo_db_zipcode" VALUES(34883,77957,-6,'Edna, Texas 77957',25445,31140);
INSERT INTO "django_geo_db_zipcode" VALUES(34884,77960,-6,'Fannin, Texas 77960',25446,31141);
INSERT INTO "django_geo_db_zipcode" VALUES(34885,77961,-6,'Francitas, Texas 77961',25447,31142);
INSERT INTO "django_geo_db_zipcode" VALUES(34886,77962,-6,'Ganado, Texas 77962',25448,31143);
INSERT INTO "django_geo_db_zipcode" VALUES(34887,77963,-6,'Goliad, Texas 77963',25449,31144);
INSERT INTO "django_geo_db_zipcode" VALUES(34888,77964,-6,'Hallettsville, Texas 77964',25450,31145);
INSERT INTO "django_geo_db_zipcode" VALUES(34889,77965,-6,'Hallettsville, Texas 77965',25450,31146);
INSERT INTO "django_geo_db_zipcode" VALUES(34890,77967,-6,'Hochheim, Texas 77967',25451,31147);
INSERT INTO "django_geo_db_zipcode" VALUES(34891,77968,-6,'Inez, Texas 77968',25452,31148);
INSERT INTO "django_geo_db_zipcode" VALUES(34892,77969,-6,'La Salle, Texas 77969',25453,31149);
INSERT INTO "django_geo_db_zipcode" VALUES(34893,77970,-6,'La Ward, Texas 77970',25454,31150);
INSERT INTO "django_geo_db_zipcode" VALUES(34894,77971,-6,'Lolita, Texas 77971',25455,31151);
INSERT INTO "django_geo_db_zipcode" VALUES(34895,77972,-6,'Long Mott, Texas 77972',25456,31152);
INSERT INTO "django_geo_db_zipcode" VALUES(34896,77973,-6,'Mcfaddin, Texas 77973',25457,31153);
INSERT INTO "django_geo_db_zipcode" VALUES(34897,77974,-6,'Meyersville, Texas 77974',25458,31154);
INSERT INTO "django_geo_db_zipcode" VALUES(34898,77975,-6,'Moulton, Texas 77975',25459,31155);
INSERT INTO "django_geo_db_zipcode" VALUES(34899,77976,-6,'Nursery, Texas 77976',25460,31156);
INSERT INTO "django_geo_db_zipcode" VALUES(34900,77977,-6,'Placedo, Texas 77977',25461,31157);
INSERT INTO "django_geo_db_zipcode" VALUES(34901,77978,-6,'Point Comfort, Texas 77978',25462,31158);
INSERT INTO "django_geo_db_zipcode" VALUES(34902,77979,-6,'Port Lavaca, Texas 77979',25463,31159);
INSERT INTO "django_geo_db_zipcode" VALUES(34903,77982,-6,'Port O Connor, Texas 77982',25464,31160);
INSERT INTO "django_geo_db_zipcode" VALUES(34904,77983,-6,'Seadrift, Texas 77983',25465,31161);
INSERT INTO "django_geo_db_zipcode" VALUES(34905,77984,-6,'Shiner, Texas 77984',25466,31162);
INSERT INTO "django_geo_db_zipcode" VALUES(34906,77985,-6,'Speaks, Texas 77985',25467,31163);
INSERT INTO "django_geo_db_zipcode" VALUES(34907,77986,-6,'Sublime, Texas 77986',25468,31164);
INSERT INTO "django_geo_db_zipcode" VALUES(34908,77987,-6,'Sweet Home, Texas 77987',25469,31163);
INSERT INTO "django_geo_db_zipcode" VALUES(34909,77988,-6,'Telferner, Texas 77988',25470,31165);
INSERT INTO "django_geo_db_zipcode" VALUES(34910,77989,-6,'Thomaston, Texas 77989',25471,31166);
INSERT INTO "django_geo_db_zipcode" VALUES(34911,77990,-6,'Tivoli, Texas 77990',25472,31167);
INSERT INTO "django_geo_db_zipcode" VALUES(34912,77991,-6,'Vanderbilt, Texas 77991',25473,31168);
INSERT INTO "django_geo_db_zipcode" VALUES(34913,77993,-6,'Weesatche, Texas 77993',25474,31169);
INSERT INTO "django_geo_db_zipcode" VALUES(34914,77994,-6,'Westhoff, Texas 77994',25475,31170);
INSERT INTO "django_geo_db_zipcode" VALUES(34915,77995,-6,'Yoakum, Texas 77995',25476,31171);
INSERT INTO "django_geo_db_zipcode" VALUES(34916,77999,-6,'Texas City, Texas 77999',25369,31172);
INSERT INTO "django_geo_db_zipcode" VALUES(34917,78001,-6,'Artesia Wells, Texas 78001',25477,31173);
INSERT INTO "django_geo_db_zipcode" VALUES(34918,78002,-6,'Atascosa, Texas 78002',25478,31174);
INSERT INTO "django_geo_db_zipcode" VALUES(34919,78003,-6,'Bandera, Texas 78003',25479,31175);
INSERT INTO "django_geo_db_zipcode" VALUES(34920,78004,-6,'Bergheim, Texas 78004',25480,31176);
INSERT INTO "django_geo_db_zipcode" VALUES(34921,78005,-6,'Bigfoot, Texas 78005',25481,31177);
INSERT INTO "django_geo_db_zipcode" VALUES(34922,78006,-6,'Boerne, Texas 78006',25482,31178);
INSERT INTO "django_geo_db_zipcode" VALUES(34923,78007,-6,'Calliham, Texas 78007',25483,31179);
INSERT INTO "django_geo_db_zipcode" VALUES(34924,78008,-6,'Campbellton, Texas 78008',25484,31180);
INSERT INTO "django_geo_db_zipcode" VALUES(34925,78009,-6,'Castroville, Texas 78009',25485,31181);
INSERT INTO "django_geo_db_zipcode" VALUES(34926,78010,-6,'Center Point, Texas 78010',25486,31182);
INSERT INTO "django_geo_db_zipcode" VALUES(34927,78011,-6,'Charlotte, Texas 78011',25487,31183);
INSERT INTO "django_geo_db_zipcode" VALUES(34928,78012,-6,'Christine, Texas 78012',25488,31184);
INSERT INTO "django_geo_db_zipcode" VALUES(34929,78013,-6,'Comfort, Texas 78013',25489,31185);
INSERT INTO "django_geo_db_zipcode" VALUES(34930,78014,-6,'Cotulla, Texas 78014',25490,31186);
INSERT INTO "django_geo_db_zipcode" VALUES(34931,78015,-6,'Boerne, Texas 78015',25482,31187);
INSERT INTO "django_geo_db_zipcode" VALUES(34932,78016,-6,'Devine, Texas 78016',25491,31188);
INSERT INTO "django_geo_db_zipcode" VALUES(34933,78017,-6,'Dilley, Texas 78017',25492,31189);
INSERT INTO "django_geo_db_zipcode" VALUES(34934,78019,-6,'Encinal, Texas 78019',25493,31190);
INSERT INTO "django_geo_db_zipcode" VALUES(34935,78021,-6,'Fowlerton, Texas 78021',25494,31191);
INSERT INTO "django_geo_db_zipcode" VALUES(34936,78022,-6,'George West, Texas 78022',25495,31192);
INSERT INTO "django_geo_db_zipcode" VALUES(34937,78023,-6,'Helotes, Texas 78023',25496,31193);
INSERT INTO "django_geo_db_zipcode" VALUES(34938,78024,-6,'Hunt, Texas 78024',25497,31194);
INSERT INTO "django_geo_db_zipcode" VALUES(34939,78025,-6,'Ingram, Texas 78025',25498,31195);
INSERT INTO "django_geo_db_zipcode" VALUES(34940,78026,-6,'Jourdanton, Texas 78026',25499,31196);
INSERT INTO "django_geo_db_zipcode" VALUES(34941,78027,-6,'Kendalia, Texas 78027',25500,31197);
INSERT INTO "django_geo_db_zipcode" VALUES(34942,78028,-6,'Kerrville, Texas 78028',25501,31198);
INSERT INTO "django_geo_db_zipcode" VALUES(34943,78029,-6,'Kerrville, Texas 78029',25501,31199);
INSERT INTO "django_geo_db_zipcode" VALUES(34944,78039,-6,'La Coste, Texas 78039',25502,31200);
INSERT INTO "django_geo_db_zipcode" VALUES(34945,78040,-6,'Laredo, Texas 78040',25503,31201);
INSERT INTO "django_geo_db_zipcode" VALUES(34946,78041,-6,'Laredo, Texas 78041',25503,31202);
INSERT INTO "django_geo_db_zipcode" VALUES(34947,78042,-6,'Laredo, Texas 78042',25503,31203);
INSERT INTO "django_geo_db_zipcode" VALUES(34948,78043,-6,'Laredo, Texas 78043',25503,31204);
INSERT INTO "django_geo_db_zipcode" VALUES(34949,78044,-6,'Laredo, Texas 78044',25503,31205);
INSERT INTO "django_geo_db_zipcode" VALUES(34950,78045,-6,'Laredo, Texas 78045',25503,31206);
INSERT INTO "django_geo_db_zipcode" VALUES(34951,78046,-6,'Laredo, Texas 78046',25503,31207);
INSERT INTO "django_geo_db_zipcode" VALUES(34952,78047,-6,'Laredo, Texas 78047',25503,31208);
INSERT INTO "django_geo_db_zipcode" VALUES(34953,78049,-6,'Laredo, Texas 78049',25503,31209);
INSERT INTO "django_geo_db_zipcode" VALUES(34954,78050,-6,'Leming, Texas 78050',25504,31210);
INSERT INTO "django_geo_db_zipcode" VALUES(34955,78052,-6,'Lytle, Texas 78052',25505,31211);
INSERT INTO "django_geo_db_zipcode" VALUES(34956,78053,-6,'McCoy, Texas 78053',25506,31212);
INSERT INTO "django_geo_db_zipcode" VALUES(34957,78054,-6,'Macdona, Texas 78054',25507,31213);
INSERT INTO "django_geo_db_zipcode" VALUES(34958,78055,-6,'Medina, Texas 78055',25508,31214);
INSERT INTO "django_geo_db_zipcode" VALUES(34959,78056,-6,'Mico, Texas 78056',25509,31215);
INSERT INTO "django_geo_db_zipcode" VALUES(34960,78057,-6,'Moore, Texas 78057',25510,31216);
INSERT INTO "django_geo_db_zipcode" VALUES(34961,78058,-6,'Mountain Home, Texas 78058',25511,31217);
INSERT INTO "django_geo_db_zipcode" VALUES(34962,78059,-6,'Natalia, Texas 78059',25512,31218);
INSERT INTO "django_geo_db_zipcode" VALUES(34963,78060,-6,'Oakville, Texas 78060',25513,31219);
INSERT INTO "django_geo_db_zipcode" VALUES(34964,78061,-6,'Pearsall, Texas 78061',25514,31220);
INSERT INTO "django_geo_db_zipcode" VALUES(34965,78062,-6,'Peggy, Texas 78062',25515,31221);
INSERT INTO "django_geo_db_zipcode" VALUES(34966,78063,-6,'Pipe Creek, Texas 78063',25516,31222);
INSERT INTO "django_geo_db_zipcode" VALUES(34967,78064,-6,'Pleasanton, Texas 78064',25517,31223);
INSERT INTO "django_geo_db_zipcode" VALUES(34968,78065,-6,'Poteet, Texas 78065',25518,31224);
INSERT INTO "django_geo_db_zipcode" VALUES(34969,78066,-6,'Rio Medina, Texas 78066',25519,31225);
INSERT INTO "django_geo_db_zipcode" VALUES(34970,78067,-6,'San Ygnacio, Texas 78067',25520,31226);
INSERT INTO "django_geo_db_zipcode" VALUES(34971,78069,-6,'Somerset, Texas 78069',25521,31227);
INSERT INTO "django_geo_db_zipcode" VALUES(34972,78070,-6,'Spring Branch, Texas 78070',25522,31228);
INSERT INTO "django_geo_db_zipcode" VALUES(34973,78071,-6,'Three Rivers, Texas 78071',25523,31229);
INSERT INTO "django_geo_db_zipcode" VALUES(34974,78072,-6,'Tilden, Texas 78072',25524,31230);
INSERT INTO "django_geo_db_zipcode" VALUES(34975,78073,-6,'Von Ormy, Texas 78073',25525,31231);
INSERT INTO "django_geo_db_zipcode" VALUES(34976,78074,-6,'Waring, Texas 78074',25526,31232);
INSERT INTO "django_geo_db_zipcode" VALUES(34977,78075,-6,'Whitsett, Texas 78075',25527,31233);
INSERT INTO "django_geo_db_zipcode" VALUES(34978,78076,-6,'Zapata, Texas 78076',25528,31234);
INSERT INTO "django_geo_db_zipcode" VALUES(34979,78081,-6,'Judsonia, Arkansas 78081',23572,31235);
INSERT INTO "django_geo_db_zipcode" VALUES(34980,78093,-6,'Laredo, Texas 78093',25503,31236);
INSERT INTO "django_geo_db_zipcode" VALUES(34981,78101,-6,'Adkins, Texas 78101',25529,31237);
INSERT INTO "django_geo_db_zipcode" VALUES(34982,78102,-6,'Beeville, Texas 78102',25530,31238);
INSERT INTO "django_geo_db_zipcode" VALUES(34983,78104,-6,'Beeville, Texas 78104',25530,31239);
INSERT INTO "django_geo_db_zipcode" VALUES(34984,78107,-6,'Berclair, Texas 78107',25531,31240);
INSERT INTO "django_geo_db_zipcode" VALUES(34985,78108,-6,'Cibolo, Texas 78108',25532,31241);
INSERT INTO "django_geo_db_zipcode" VALUES(34986,78109,-6,'Converse, Texas 78109',25533,31242);
INSERT INTO "django_geo_db_zipcode" VALUES(34987,78111,-6,'Ecleto, Texas 78111',25534,31243);
INSERT INTO "django_geo_db_zipcode" VALUES(34988,78112,-6,'Elmendorf, Texas 78112',25535,31244);
INSERT INTO "django_geo_db_zipcode" VALUES(34989,78113,-6,'Falls City, Texas 78113',25536,31245);
INSERT INTO "django_geo_db_zipcode" VALUES(34990,78114,-6,'Floresville, Texas 78114',25537,31246);
INSERT INTO "django_geo_db_zipcode" VALUES(34991,78115,-6,'Geronimo, Texas 78115',25538,31247);
INSERT INTO "django_geo_db_zipcode" VALUES(34992,78116,-6,'Gillett, Texas 78116',25539,31248);
INSERT INTO "django_geo_db_zipcode" VALUES(34993,78117,-6,'Hobson, Texas 78117',25540,31249);
INSERT INTO "django_geo_db_zipcode" VALUES(34994,78118,-6,'Karnes City, Texas 78118',25541,31250);
INSERT INTO "django_geo_db_zipcode" VALUES(34995,78119,-6,'Kenedy, Texas 78119',25542,31251);
INSERT INTO "django_geo_db_zipcode" VALUES(34996,78121,-6,'La Vernia, Texas 78121',25543,31252);
INSERT INTO "django_geo_db_zipcode" VALUES(34997,78122,-6,'Leesville, Texas 78122',25544,31253);
INSERT INTO "django_geo_db_zipcode" VALUES(34998,78123,-6,'McQueeney, Texas 78123',25545,31254);
INSERT INTO "django_geo_db_zipcode" VALUES(34999,78124,-6,'Marion, Texas 78124',25546,31255);
INSERT INTO "django_geo_db_zipcode" VALUES(35000,78125,-6,'Mineral, Texas 78125',25547,31256);
INSERT INTO "django_geo_db_zipcode" VALUES(35001,78126,-6,'San Antonio, Texas 78126',25548,31257);
INSERT INTO "django_geo_db_zipcode" VALUES(35002,78130,-6,'New Braunfels, Texas 78130',25549,31258);
INSERT INTO "django_geo_db_zipcode" VALUES(35003,78131,-6,'New Braunfels, Texas 78131',25549,31259);
INSERT INTO "django_geo_db_zipcode" VALUES(35004,78132,-6,'New Braunfels, Texas 78132',25549,31260);
INSERT INTO "django_geo_db_zipcode" VALUES(35005,78133,-6,'Canyon Lake, Texas 78133',25550,31261);
INSERT INTO "django_geo_db_zipcode" VALUES(35006,78134,-6,'New Braunfels, Texas 78134',25549,31262);
INSERT INTO "django_geo_db_zipcode" VALUES(35007,78135,-6,'New Braunfels, Texas 78135',25549,31263);
INSERT INTO "django_geo_db_zipcode" VALUES(35008,78136,-6,'McQueeney, Texas 78136',25545,31264);
INSERT INTO "django_geo_db_zipcode" VALUES(35009,78140,-6,'Nixon, Texas 78140',25551,31265);
INSERT INTO "django_geo_db_zipcode" VALUES(35010,78141,-6,'Nordheim, Texas 78141',25552,31266);
INSERT INTO "django_geo_db_zipcode" VALUES(35011,78142,-6,'Normanna, Texas 78142',25553,31267);
INSERT INTO "django_geo_db_zipcode" VALUES(35012,78143,-6,'Pandora, Texas 78143',25554,31268);
INSERT INTO "django_geo_db_zipcode" VALUES(35013,78144,-6,'Panna Maria, Texas 78144',25555,31269);
INSERT INTO "django_geo_db_zipcode" VALUES(35014,78145,-6,'Pawnee, Texas 78145',25556,31270);
INSERT INTO "django_geo_db_zipcode" VALUES(35015,78146,-6,'Pettus, Texas 78146',25557,31271);
INSERT INTO "django_geo_db_zipcode" VALUES(35016,78147,-6,'Poth, Texas 78147',25558,31272);
INSERT INTO "django_geo_db_zipcode" VALUES(35017,78148,-6,'Universal City, Texas 78148',25559,31273);
INSERT INTO "django_geo_db_zipcode" VALUES(35018,78150,-6,'Universal City, Texas 78150',25559,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35019,78151,-6,'Runge, Texas 78151',25560,31275);
INSERT INTO "django_geo_db_zipcode" VALUES(35020,78152,-6,'Saint Hedwig, Texas 78152',25561,31276);
INSERT INTO "django_geo_db_zipcode" VALUES(35021,78154,-6,'Schertz, Texas 78154',25562,31277);
INSERT INTO "django_geo_db_zipcode" VALUES(35022,78155,-6,'Seguin, Texas 78155',25563,31278);
INSERT INTO "django_geo_db_zipcode" VALUES(35023,78156,-6,'Seguin, Texas 78156',25563,31279);
INSERT INTO "django_geo_db_zipcode" VALUES(35024,78159,-6,'Smiley, Texas 78159',25564,31280);
INSERT INTO "django_geo_db_zipcode" VALUES(35025,78160,-6,'Stockdale, Texas 78160',25565,31281);
INSERT INTO "django_geo_db_zipcode" VALUES(35026,78161,-6,'Sutherland Springs, Texas 78161',25566,31282);
INSERT INTO "django_geo_db_zipcode" VALUES(35027,78162,-6,'Tuleta, Texas 78162',25567,31283);
INSERT INTO "django_geo_db_zipcode" VALUES(35028,78163,-6,'Bulverde, Texas 78163',25568,31284);
INSERT INTO "django_geo_db_zipcode" VALUES(35029,78164,-6,'Yorktown, Texas 78164',25569,31285);
INSERT INTO "django_geo_db_zipcode" VALUES(35030,78201,-6,'San Antonio, Texas 78201',25548,31286);
INSERT INTO "django_geo_db_zipcode" VALUES(35031,78202,-6,'San Antonio, Texas 78202',25548,31287);
INSERT INTO "django_geo_db_zipcode" VALUES(35032,78203,-6,'San Antonio, Texas 78203',25548,31288);
INSERT INTO "django_geo_db_zipcode" VALUES(35033,78204,-6,'San Antonio, Texas 78204',25548,31289);
INSERT INTO "django_geo_db_zipcode" VALUES(35034,78205,-6,'San Antonio, Texas 78205',25548,31290);
INSERT INTO "django_geo_db_zipcode" VALUES(35035,78206,-6,'San Antonio, Texas 78206',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35036,78207,-6,'San Antonio, Texas 78207',25548,31291);
INSERT INTO "django_geo_db_zipcode" VALUES(35037,78208,-6,'San Antonio, Texas 78208',25548,31292);
INSERT INTO "django_geo_db_zipcode" VALUES(35038,78209,-6,'San Antonio, Texas 78209',25548,31293);
INSERT INTO "django_geo_db_zipcode" VALUES(35039,78210,-6,'San Antonio, Texas 78210',25548,31294);
INSERT INTO "django_geo_db_zipcode" VALUES(35040,78211,-6,'San Antonio, Texas 78211',25548,31295);
INSERT INTO "django_geo_db_zipcode" VALUES(35041,78212,-6,'San Antonio, Texas 78212',25548,31296);
INSERT INTO "django_geo_db_zipcode" VALUES(35042,78213,-6,'San Antonio, Texas 78213',25548,31297);
INSERT INTO "django_geo_db_zipcode" VALUES(35043,78214,-6,'San Antonio, Texas 78214',25548,31298);
INSERT INTO "django_geo_db_zipcode" VALUES(35044,78215,-6,'San Antonio, Texas 78215',25548,31299);
INSERT INTO "django_geo_db_zipcode" VALUES(35045,78216,-6,'San Antonio, Texas 78216',25548,31300);
INSERT INTO "django_geo_db_zipcode" VALUES(35046,78217,-6,'San Antonio, Texas 78217',25548,31301);
INSERT INTO "django_geo_db_zipcode" VALUES(35047,78218,-6,'San Antonio, Texas 78218',25548,31302);
INSERT INTO "django_geo_db_zipcode" VALUES(35048,78219,-6,'San Antonio, Texas 78219',25548,31303);
INSERT INTO "django_geo_db_zipcode" VALUES(35049,78220,-6,'San Antonio, Texas 78220',25548,31304);
INSERT INTO "django_geo_db_zipcode" VALUES(35050,78221,-6,'San Antonio, Texas 78221',25548,31305);
INSERT INTO "django_geo_db_zipcode" VALUES(35051,78222,-6,'San Antonio, Texas 78222',25548,31306);
INSERT INTO "django_geo_db_zipcode" VALUES(35052,78223,-6,'San Antonio, Texas 78223',25548,31307);
INSERT INTO "django_geo_db_zipcode" VALUES(35053,78224,-6,'San Antonio, Texas 78224',25548,31308);
INSERT INTO "django_geo_db_zipcode" VALUES(35054,78225,-6,'San Antonio, Texas 78225',25548,31309);
INSERT INTO "django_geo_db_zipcode" VALUES(35055,78226,-6,'San Antonio, Texas 78226',25548,31310);
INSERT INTO "django_geo_db_zipcode" VALUES(35056,78227,-6,'San Antonio, Texas 78227',25548,31311);
INSERT INTO "django_geo_db_zipcode" VALUES(35057,78228,-6,'San Antonio, Texas 78228',25548,31312);
INSERT INTO "django_geo_db_zipcode" VALUES(35058,78229,-6,'San Antonio, Texas 78229',25548,31313);
INSERT INTO "django_geo_db_zipcode" VALUES(35059,78230,-6,'San Antonio, Texas 78230',25548,31314);
INSERT INTO "django_geo_db_zipcode" VALUES(35060,78231,-6,'San Antonio, Texas 78231',25548,31315);
INSERT INTO "django_geo_db_zipcode" VALUES(35061,78232,-6,'San Antonio, Texas 78232',25548,31316);
INSERT INTO "django_geo_db_zipcode" VALUES(35062,78233,-6,'San Antonio, Texas 78233',25548,31317);
INSERT INTO "django_geo_db_zipcode" VALUES(35063,78234,-6,'San Antonio, Texas 78234',25548,31318);
INSERT INTO "django_geo_db_zipcode" VALUES(35064,78235,-6,'San Antonio, Texas 78235',25548,31319);
INSERT INTO "django_geo_db_zipcode" VALUES(35065,78236,-6,'San Antonio, Texas 78236',25548,31320);
INSERT INTO "django_geo_db_zipcode" VALUES(35066,78237,-6,'San Antonio, Texas 78237',25548,31321);
INSERT INTO "django_geo_db_zipcode" VALUES(35067,78238,-6,'San Antonio, Texas 78238',25548,31322);
INSERT INTO "django_geo_db_zipcode" VALUES(35068,78239,-6,'San Antonio, Texas 78239',25548,31323);
INSERT INTO "django_geo_db_zipcode" VALUES(35069,78240,-6,'San Antonio, Texas 78240',25548,31324);
INSERT INTO "django_geo_db_zipcode" VALUES(35070,78241,-6,'San Antonio, Texas 78241',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35071,78242,-6,'San Antonio, Texas 78242',25548,31325);
INSERT INTO "django_geo_db_zipcode" VALUES(35072,78243,-6,'San Antonio, Texas 78243',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35073,78244,-6,'San Antonio, Texas 78244',25548,31326);
INSERT INTO "django_geo_db_zipcode" VALUES(35074,78245,-6,'San Antonio, Texas 78245',25548,31327);
INSERT INTO "django_geo_db_zipcode" VALUES(35075,78246,-6,'San Antonio, Texas 78246',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35076,78247,-6,'San Antonio, Texas 78247',25548,31328);
INSERT INTO "django_geo_db_zipcode" VALUES(35077,78248,-6,'San Antonio, Texas 78248',25548,31329);
INSERT INTO "django_geo_db_zipcode" VALUES(35078,78249,-6,'San Antonio, Texas 78249',25548,31330);
INSERT INTO "django_geo_db_zipcode" VALUES(35079,78250,-6,'San Antonio, Texas 78250',25548,31331);
INSERT INTO "django_geo_db_zipcode" VALUES(35080,78251,-6,'San Antonio, Texas 78251',25548,31332);
INSERT INTO "django_geo_db_zipcode" VALUES(35081,78252,-6,'San Antonio, Texas 78252',25548,31333);
INSERT INTO "django_geo_db_zipcode" VALUES(35082,78253,-6,'San Antonio, Texas 78253',25548,31334);
INSERT INTO "django_geo_db_zipcode" VALUES(35083,78254,-6,'San Antonio, Texas 78254',25548,31335);
INSERT INTO "django_geo_db_zipcode" VALUES(35084,78255,-6,'San Antonio, Texas 78255',25548,31336);
INSERT INTO "django_geo_db_zipcode" VALUES(35085,78256,-6,'San Antonio, Texas 78256',25548,31337);
INSERT INTO "django_geo_db_zipcode" VALUES(35086,78257,-6,'San Antonio, Texas 78257',25548,31338);
INSERT INTO "django_geo_db_zipcode" VALUES(35087,78258,-6,'San Antonio, Texas 78258',25548,31339);
INSERT INTO "django_geo_db_zipcode" VALUES(35088,78259,-6,'San Antonio, Texas 78259',25548,31340);
INSERT INTO "django_geo_db_zipcode" VALUES(35089,78260,-6,'San Antonio, Texas 78260',25548,31341);
INSERT INTO "django_geo_db_zipcode" VALUES(35090,78261,-6,'San Antonio, Texas 78261',25548,31342);
INSERT INTO "django_geo_db_zipcode" VALUES(35091,78262,-6,'San Antonio, Texas 78262',25548,31343);
INSERT INTO "django_geo_db_zipcode" VALUES(35092,78263,-6,'San Antonio, Texas 78263',25548,31344);
INSERT INTO "django_geo_db_zipcode" VALUES(35093,78264,-6,'San Antonio, Texas 78264',25548,31345);
INSERT INTO "django_geo_db_zipcode" VALUES(35094,78265,-6,'San Antonio, Texas 78265',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35095,78266,-6,'San Antonio, Texas 78266',25548,31346);
INSERT INTO "django_geo_db_zipcode" VALUES(35096,78268,-6,'San Antonio, Texas 78268',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35097,78269,-6,'San Antonio, Texas 78269',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35098,78270,-6,'San Antonio, Texas 78270',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35099,78275,-6,'San Antonio, Texas 78275',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35100,78278,-6,'San Antonio, Texas 78278',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35101,78279,-6,'San Antonio, Texas 78279',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35102,78280,-6,'San Antonio, Texas 78280',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35103,78283,-6,'San Antonio, Texas 78283',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35104,78284,-6,'San Antonio, Texas 78284',25548,31347);
INSERT INTO "django_geo_db_zipcode" VALUES(35105,78285,-6,'San Antonio, Texas 78285',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35106,78286,-6,'San Antonio, Texas 78286',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35107,78287,-6,'San Antonio, Texas 78287',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35108,78288,-6,'San Antonio, Texas 78288',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35109,78289,-6,'San Antonio, Texas 78289',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35110,78291,-6,'San Antonio, Texas 78291',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35111,78292,-6,'San Antonio, Texas 78292',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35112,78293,-6,'San Antonio, Texas 78293',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35113,78294,-6,'San Antonio, Texas 78294',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35114,78295,-6,'San Antonio, Texas 78295',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35115,78296,-6,'San Antonio, Texas 78296',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35116,78297,-6,'San Antonio, Texas 78297',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35117,78298,-6,'San Antonio, Texas 78298',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35118,78299,-6,'San Antonio, Texas 78299',25548,31274);
INSERT INTO "django_geo_db_zipcode" VALUES(35119,78301,-6,'McAllen, Texas 78301',25570,31348);
INSERT INTO "django_geo_db_zipcode" VALUES(35120,78330,-6,'Agua Dulce, Texas 78330',25571,31349);
INSERT INTO "django_geo_db_zipcode" VALUES(35121,78331,-6,'Alice, Texas 78331',25572,31350);
INSERT INTO "django_geo_db_zipcode" VALUES(35122,78332,-6,'Alice, Texas 78332',25572,31351);
INSERT INTO "django_geo_db_zipcode" VALUES(35123,78333,-6,'Alice, Texas 78333',25572,31352);
INSERT INTO "django_geo_db_zipcode" VALUES(35124,78335,-6,'Aransas Pass, Texas 78335',25573,31353);
INSERT INTO "django_geo_db_zipcode" VALUES(35125,78336,-6,'Aransas Pass, Texas 78336',25573,31354);
INSERT INTO "django_geo_db_zipcode" VALUES(35126,78337,-6,'Rancho Alegre, Texas 78337',25574,31355);
INSERT INTO "django_geo_db_zipcode" VALUES(35127,78338,-6,'Armstrong, Texas 78338',25575,31356);
INSERT INTO "django_geo_db_zipcode" VALUES(35128,78339,-6,'Banquete, Texas 78339',25576,31357);
INSERT INTO "django_geo_db_zipcode" VALUES(35129,78340,-6,'Bayside, Texas 78340',25577,31358);
INSERT INTO "django_geo_db_zipcode" VALUES(35130,78341,-6,'Benavides, Texas 78341',25578,31359);
INSERT INTO "django_geo_db_zipcode" VALUES(35131,78342,-6,'Ben Bolt, Texas 78342',25579,31352);
INSERT INTO "django_geo_db_zipcode" VALUES(35132,78343,-6,'Bishop, Texas 78343',25580,31360);
INSERT INTO "django_geo_db_zipcode" VALUES(35133,78344,-6,'Bruni, Texas 78344',25581,31361);
INSERT INTO "django_geo_db_zipcode" VALUES(35134,78347,-6,'Chapman Ranch, Texas 78347',25582,31362);
INSERT INTO "django_geo_db_zipcode" VALUES(35135,78349,-6,'Concepcion, Texas 78349',25583,31363);
INSERT INTO "django_geo_db_zipcode" VALUES(35136,78350,-6,'Dinero, Texas 78350',25584,31219);
INSERT INTO "django_geo_db_zipcode" VALUES(35137,78351,-6,'Driscoll, Texas 78351',25585,31364);
INSERT INTO "django_geo_db_zipcode" VALUES(35138,78352,-6,'Edroy, Texas 78352',25586,31365);
INSERT INTO "django_geo_db_zipcode" VALUES(35139,78353,-6,'Encino, Texas 78353',25587,31366);
INSERT INTO "django_geo_db_zipcode" VALUES(35140,78355,-6,'Falfurrias, Texas 78355',25588,31367);
INSERT INTO "django_geo_db_zipcode" VALUES(35141,78357,-6,'Freer, Texas 78357',25589,31368);
INSERT INTO "django_geo_db_zipcode" VALUES(35142,78358,-6,'Fulton, Texas 78358',25590,31369);
INSERT INTO "django_geo_db_zipcode" VALUES(35143,78359,-6,'Gregory, Texas 78359',25591,31370);
INSERT INTO "django_geo_db_zipcode" VALUES(35144,78360,-6,'Guerra, Texas 78360',25592,31371);
INSERT INTO "django_geo_db_zipcode" VALUES(35145,78361,-6,'Hebbronville, Texas 78361',25593,31372);
INSERT INTO "django_geo_db_zipcode" VALUES(35146,78362,-6,'Ingleside, Texas 78362',25594,31373);
INSERT INTO "django_geo_db_zipcode" VALUES(35147,78363,-6,'Kingsville, Texas 78363',25595,31374);
INSERT INTO "django_geo_db_zipcode" VALUES(35148,78364,-6,'Kingsville, Texas 78364',25595,31375);
INSERT INTO "django_geo_db_zipcode" VALUES(35149,78368,-6,'Mathis, Texas 78368',25596,31376);
INSERT INTO "django_geo_db_zipcode" VALUES(35150,78369,-6,'Mirando City, Texas 78369',25597,31377);
INSERT INTO "django_geo_db_zipcode" VALUES(35151,78370,-6,'Odem, Texas 78370',25598,31378);
INSERT INTO "django_geo_db_zipcode" VALUES(35152,78371,-6,'Oilton, Texas 78371',25599,31379);
INSERT INTO "django_geo_db_zipcode" VALUES(35153,78372,-6,'Orange Grove, Texas 78372',25600,31380);
INSERT INTO "django_geo_db_zipcode" VALUES(35154,78373,-6,'Port Aransas, Texas 78373',25601,31381);
INSERT INTO "django_geo_db_zipcode" VALUES(35155,78374,-6,'Portland, Texas 78374',25602,31382);
INSERT INTO "django_geo_db_zipcode" VALUES(35156,78375,-6,'Premont, Texas 78375',25603,31383);
INSERT INTO "django_geo_db_zipcode" VALUES(35157,78376,-6,'Realitos, Texas 78376',25604,31384);
INSERT INTO "django_geo_db_zipcode" VALUES(35158,78377,-6,'Refugio, Texas 78377',25605,31385);
INSERT INTO "django_geo_db_zipcode" VALUES(35159,78379,-6,'Riviera, Texas 78379',25606,31386);
INSERT INTO "django_geo_db_zipcode" VALUES(35160,78380,-6,'Robstown, Texas 78380',25607,31387);
INSERT INTO "django_geo_db_zipcode" VALUES(35161,78381,-6,'Rockport, Texas 78381',25608,31388);
INSERT INTO "django_geo_db_zipcode" VALUES(35162,78382,-6,'Rockport, Texas 78382',25608,31389);
INSERT INTO "django_geo_db_zipcode" VALUES(35163,78383,-6,'Sandia, Texas 78383',25609,31390);
INSERT INTO "django_geo_db_zipcode" VALUES(35164,78384,-6,'San Diego, Texas 78384',25610,31391);
INSERT INTO "django_geo_db_zipcode" VALUES(35165,78385,-6,'Sarita, Texas 78385',25611,31392);
INSERT INTO "django_geo_db_zipcode" VALUES(35166,78387,-6,'Sinton, Texas 78387',25612,31393);
INSERT INTO "django_geo_db_zipcode" VALUES(35167,78389,-6,'Skidmore, Texas 78389',25613,31394);
INSERT INTO "django_geo_db_zipcode" VALUES(35168,78390,-6,'Taft, Texas 78390',25614,31395);
INSERT INTO "django_geo_db_zipcode" VALUES(35169,78391,-6,'Tynan, Texas 78391',25615,31396);
INSERT INTO "django_geo_db_zipcode" VALUES(35170,78393,-6,'Woodsboro, Texas 78393',25616,31397);
INSERT INTO "django_geo_db_zipcode" VALUES(35171,78401,-6,'Corpus Christi, Texas 78401',25617,31398);
INSERT INTO "django_geo_db_zipcode" VALUES(35172,78402,-6,'Corpus Christi, Texas 78402',25617,31399);
INSERT INTO "django_geo_db_zipcode" VALUES(35173,78403,-6,'Corpus Christi, Texas 78403',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35174,78404,-6,'Corpus Christi, Texas 78404',25617,31401);
INSERT INTO "django_geo_db_zipcode" VALUES(35175,78405,-6,'Corpus Christi, Texas 78405',25617,31402);
INSERT INTO "django_geo_db_zipcode" VALUES(35176,78406,-6,'Corpus Christi, Texas 78406',25617,31403);
INSERT INTO "django_geo_db_zipcode" VALUES(35177,78407,-6,'Corpus Christi, Texas 78407',25617,31404);
INSERT INTO "django_geo_db_zipcode" VALUES(35178,78408,-6,'Corpus Christi, Texas 78408',25617,31405);
INSERT INTO "django_geo_db_zipcode" VALUES(35179,78409,-6,'Corpus Christi, Texas 78409',25617,31406);
INSERT INTO "django_geo_db_zipcode" VALUES(35180,78410,-6,'Corpus Christi, Texas 78410',25617,31407);
INSERT INTO "django_geo_db_zipcode" VALUES(35181,78411,-6,'Corpus Christi, Texas 78411',25617,31408);
INSERT INTO "django_geo_db_zipcode" VALUES(35182,78412,-6,'Corpus Christi, Texas 78412',25617,31409);
INSERT INTO "django_geo_db_zipcode" VALUES(35183,78413,-6,'Corpus Christi, Texas 78413',25617,31410);
INSERT INTO "django_geo_db_zipcode" VALUES(35184,78414,-6,'Corpus Christi, Texas 78414',25617,31411);
INSERT INTO "django_geo_db_zipcode" VALUES(35185,78415,-6,'Corpus Christi, Texas 78415',25617,31412);
INSERT INTO "django_geo_db_zipcode" VALUES(35186,78416,-6,'Corpus Christi, Texas 78416',25617,31413);
INSERT INTO "django_geo_db_zipcode" VALUES(35187,78417,-6,'Corpus Christi, Texas 78417',25617,31414);
INSERT INTO "django_geo_db_zipcode" VALUES(35188,78418,-6,'Corpus Christi, Texas 78418',25617,31415);
INSERT INTO "django_geo_db_zipcode" VALUES(35189,78419,-6,'Corpus Christi, Texas 78419',25617,31416);
INSERT INTO "django_geo_db_zipcode" VALUES(35190,78426,-6,'Corpus Christi, Texas 78426',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35191,78427,-6,'Corpus Christi, Texas 78427',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35192,78460,-6,'Corpus Christi, Texas 78460',25617,31417);
INSERT INTO "django_geo_db_zipcode" VALUES(35193,78461,-6,'Corpus Christi, Texas 78461',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35194,78463,-6,'Corpus Christi, Texas 78463',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35195,78465,-6,'Corpus Christi, Texas 78465',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35196,78466,-6,'Corpus Christi, Texas 78466',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35197,78467,-6,'Corpus Christi, Texas 78467',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35198,78468,-6,'Corpus Christi, Texas 78468',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35199,78469,-6,'Corpus Christi, Texas 78469',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35200,78470,-6,'Corpus Christi, Texas 78470',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35201,78471,-6,'Corpus Christi, Texas 78471',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35202,78472,-6,'Corpus Christi, Texas 78472',25617,31418);
INSERT INTO "django_geo_db_zipcode" VALUES(35203,78473,-6,'Corpus Christi, Texas 78473',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35204,78474,-6,'Corpus Christi, Texas 78474',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35205,78475,-6,'Corpus Christi, Texas 78475',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35206,78476,-6,'Corpus Christi, Texas 78476',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35207,78477,-6,'Corpus Christi, Texas 78477',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35208,78478,-6,'Corpus Christi, Texas 78478',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35209,78480,-6,'Corpus Christi, Texas 78480',25617,31400);
INSERT INTO "django_geo_db_zipcode" VALUES(35210,78501,-6,'Mcallen, Texas 78501',25618,31419);
INSERT INTO "django_geo_db_zipcode" VALUES(35211,78502,-6,'Mcallen, Texas 78502',25618,31420);
INSERT INTO "django_geo_db_zipcode" VALUES(35212,78503,-6,'Mcallen, Texas 78503',25618,31421);
INSERT INTO "django_geo_db_zipcode" VALUES(35213,78504,-6,'Mcallen, Texas 78504',25618,31422);
INSERT INTO "django_geo_db_zipcode" VALUES(35214,78505,-6,'Mcallen, Texas 78505',25618,31423);
INSERT INTO "django_geo_db_zipcode" VALUES(35215,78512,-6,'Mission, Texas 78512',25619,31424);
INSERT INTO "django_geo_db_zipcode" VALUES(35216,78516,-6,'Alamo, Texas 78516',25620,31425);
INSERT INTO "django_geo_db_zipcode" VALUES(35217,78520,-6,'Brownsville, Texas 78520',25621,31426);
INSERT INTO "django_geo_db_zipcode" VALUES(35218,78521,-6,'Brownsville, Texas 78521',25621,31427);
INSERT INTO "django_geo_db_zipcode" VALUES(35219,78522,-6,'Brownsville, Texas 78522',25621,31428);
INSERT INTO "django_geo_db_zipcode" VALUES(35220,78523,-6,'Brownsville, Texas 78523',25621,31429);
INSERT INTO "django_geo_db_zipcode" VALUES(35221,78526,-6,'Brownsville, Texas 78526',25621,31430);
INSERT INTO "django_geo_db_zipcode" VALUES(35222,78535,-6,'Combes, Texas 78535',25622,31431);
INSERT INTO "django_geo_db_zipcode" VALUES(35223,78536,-6,'Delmita, Texas 78536',25623,31432);
INSERT INTO "django_geo_db_zipcode" VALUES(35224,78537,-6,'Donna, Texas 78537',25624,31433);
INSERT INTO "django_geo_db_zipcode" VALUES(35225,78538,-6,'Edcouch, Texas 78538',25625,31434);
INSERT INTO "django_geo_db_zipcode" VALUES(35226,78539,-6,'Edinburg, Texas 78539',25626,31435);
INSERT INTO "django_geo_db_zipcode" VALUES(35227,78540,-6,'Edinburg, Texas 78540',25626,31436);
INSERT INTO "django_geo_db_zipcode" VALUES(35228,78541,-6,'Edinburg, Texas 78541',25626,31437);
INSERT INTO "django_geo_db_zipcode" VALUES(35229,78543,-6,'Elsa, Texas 78543',25627,31438);
INSERT INTO "django_geo_db_zipcode" VALUES(35230,78545,-6,'Falcon Heights, Texas 78545',25628,31439);
INSERT INTO "django_geo_db_zipcode" VALUES(35231,78547,-6,'Garciasville, Texas 78547',25629,31440);
INSERT INTO "django_geo_db_zipcode" VALUES(35232,78548,-6,'Grulla, Texas 78548',25630,31441);
INSERT INTO "django_geo_db_zipcode" VALUES(35233,78549,-6,'Hargill, Texas 78549',25631,31442);
INSERT INTO "django_geo_db_zipcode" VALUES(35234,78550,-6,'Harlingen, Texas 78550',25632,31443);
INSERT INTO "django_geo_db_zipcode" VALUES(35235,78551,-6,'Harlingen, Texas 78551',25632,31444);
INSERT INTO "django_geo_db_zipcode" VALUES(35236,78552,-6,'Harlingen, Texas 78552',25632,31445);
INSERT INTO "django_geo_db_zipcode" VALUES(35237,78553,-6,'Harlingen, Texas 78553',25632,31446);
INSERT INTO "django_geo_db_zipcode" VALUES(35238,78555,-6,'McAllen, Texas 78555',25570,31447);
INSERT INTO "django_geo_db_zipcode" VALUES(35239,78557,-6,'Hidalgo, Texas 78557',25633,31448);
INSERT INTO "django_geo_db_zipcode" VALUES(35240,78558,-6,'La Blanca, Texas 78558',25634,31449);
INSERT INTO "django_geo_db_zipcode" VALUES(35241,78559,-6,'La Feria, Texas 78559',25635,31450);
INSERT INTO "django_geo_db_zipcode" VALUES(35242,78560,-6,'La Joya, Texas 78560',25636,31451);
INSERT INTO "django_geo_db_zipcode" VALUES(35243,78561,-6,'Lasara, Texas 78561',25637,31452);
INSERT INTO "django_geo_db_zipcode" VALUES(35244,78562,-6,'La Villa, Texas 78562',25638,31453);
INSERT INTO "django_geo_db_zipcode" VALUES(35245,78563,-6,'Linn, Texas 78563',25639,31454);
INSERT INTO "django_geo_db_zipcode" VALUES(35246,78564,-6,'Lopeno, Texas 78564',25640,31455);
INSERT INTO "django_geo_db_zipcode" VALUES(35247,78565,-6,'Los Ebanos, Texas 78565',25641,31456);
INSERT INTO "django_geo_db_zipcode" VALUES(35248,78566,-6,'Los Fresnos, Texas 78566',25642,31457);
INSERT INTO "django_geo_db_zipcode" VALUES(35249,78567,-6,'Los Indios, Texas 78567',25643,31458);
INSERT INTO "django_geo_db_zipcode" VALUES(35250,78568,-6,'Lozano, Texas 78568',25644,31459);
INSERT INTO "django_geo_db_zipcode" VALUES(35251,78569,-6,'Lyford, Texas 78569',25645,31460);
INSERT INTO "django_geo_db_zipcode" VALUES(35252,78570,-6,'Mercedes, Texas 78570',25646,31461);
INSERT INTO "django_geo_db_zipcode" VALUES(35253,78571,-6,'Salado, Texas 78571',25082,31462);
INSERT INTO "django_geo_db_zipcode" VALUES(35254,78572,-6,'Mission, Texas 78572',25619,31463);
INSERT INTO "django_geo_db_zipcode" VALUES(35255,78573,-6,'Mission, Texas 78573',25619,31423);
INSERT INTO "django_geo_db_zipcode" VALUES(35256,78574,-6,'Sebastian, Texas 78574',25647,31464);
INSERT INTO "django_geo_db_zipcode" VALUES(35257,78575,-6,'Olmito, Texas 78575',25648,31465);
INSERT INTO "django_geo_db_zipcode" VALUES(35258,78576,-6,'Penitas, Texas 78576',25649,31466);
INSERT INTO "django_geo_db_zipcode" VALUES(35259,78577,-6,'Pharr, Texas 78577',25650,31467);
INSERT INTO "django_geo_db_zipcode" VALUES(35260,78578,-6,'Port Isabel, Texas 78578',25651,31468);
INSERT INTO "django_geo_db_zipcode" VALUES(35261,78579,-6,'Progreso, Texas 78579',25652,31469);
INSERT INTO "django_geo_db_zipcode" VALUES(35262,78580,-6,'Raymondville, Texas 78580',25653,31470);
INSERT INTO "django_geo_db_zipcode" VALUES(35263,78582,-6,'Rio Grande City, Texas 78582',25654,31471);
INSERT INTO "django_geo_db_zipcode" VALUES(35264,78583,-6,'Rio Hondo, Texas 78583',25655,31472);
INSERT INTO "django_geo_db_zipcode" VALUES(35265,78584,-6,'Roma, Texas 78584',25656,31473);
INSERT INTO "django_geo_db_zipcode" VALUES(35266,78585,-6,'Salineno, Texas 78585',25657,31474);
INSERT INTO "django_geo_db_zipcode" VALUES(35267,78586,-6,'San Benito, Texas 78586',25658,31475);
INSERT INTO "django_geo_db_zipcode" VALUES(35268,78587,-6,'La Victoria, Texas 78587',25659,31476);
INSERT INTO "django_geo_db_zipcode" VALUES(35269,78588,-6,'San Isidro, Texas 78588',25660,31477);
INSERT INTO "django_geo_db_zipcode" VALUES(35270,78589,-6,'San Juan, Texas 78589',25661,31478);
INSERT INTO "django_geo_db_zipcode" VALUES(35271,78590,-6,'San Perlita, Texas 78590',25662,31479);
INSERT INTO "django_geo_db_zipcode" VALUES(35272,78591,-6,'Santa Elena, Texas 78591',25663,31480);
INSERT INTO "django_geo_db_zipcode" VALUES(35273,78592,-6,'Santa Maria, Texas 78592',25664,31481);
INSERT INTO "django_geo_db_zipcode" VALUES(35274,78593,-6,'Santa Rosa, Texas 78593',25665,31482);
INSERT INTO "django_geo_db_zipcode" VALUES(35275,78594,-6,'Sebastian, Texas 78594',25647,31483);
INSERT INTO "django_geo_db_zipcode" VALUES(35276,78595,-6,'Sullivan City, Texas 78595',25666,31484);
INSERT INTO "django_geo_db_zipcode" VALUES(35277,78596,-6,'Weslaco, Texas 78596',25667,31485);
INSERT INTO "django_geo_db_zipcode" VALUES(35278,78597,-6,'South Padre Island, Texas 78597',25668,31486);
INSERT INTO "django_geo_db_zipcode" VALUES(35279,78598,-6,'Port Mansfield, Texas 78598',25669,31487);
INSERT INTO "django_geo_db_zipcode" VALUES(35280,78599,-6,'Weslaco, Texas 78599',25667,31423);
INSERT INTO "django_geo_db_zipcode" VALUES(35281,78602,-6,'Bastrop, Texas 78602',25670,31488);
INSERT INTO "django_geo_db_zipcode" VALUES(35282,78603,-6,'Bebe, Texas 78603',25671,31489);
INSERT INTO "django_geo_db_zipcode" VALUES(35283,78604,-6,'Belmont, Texas 78604',25672,31489);
INSERT INTO "django_geo_db_zipcode" VALUES(35284,78605,-6,'Bertram, Texas 78605',25673,31490);
INSERT INTO "django_geo_db_zipcode" VALUES(35285,78606,-6,'Blanco, Texas 78606',25674,31491);
INSERT INTO "django_geo_db_zipcode" VALUES(35286,78607,-6,'Bluffton, Texas 78607',25675,31492);
INSERT INTO "django_geo_db_zipcode" VALUES(35287,78608,-6,'Briggs, Texas 78608',25676,31493);
INSERT INTO "django_geo_db_zipcode" VALUES(35288,78609,-6,'Buchanan Dam, Texas 78609',25677,31494);
INSERT INTO "django_geo_db_zipcode" VALUES(35289,78610,-6,'Buda, Texas 78610',25678,31495);
INSERT INTO "django_geo_db_zipcode" VALUES(35290,78611,-6,'Burnet, Texas 78611',25679,31496);
INSERT INTO "django_geo_db_zipcode" VALUES(35291,78612,-6,'Cedar Creek, Texas 78612',25680,31497);
INSERT INTO "django_geo_db_zipcode" VALUES(35292,78613,-6,'Cedar Park, Texas 78613',25681,31498);
INSERT INTO "django_geo_db_zipcode" VALUES(35293,78614,-6,'Cost, Texas 78614',25682,31499);
INSERT INTO "django_geo_db_zipcode" VALUES(35294,78615,-6,'Coupland, Texas 78615',25683,31500);
INSERT INTO "django_geo_db_zipcode" VALUES(35295,78616,-6,'Dale, Texas 78616',25684,31501);
INSERT INTO "django_geo_db_zipcode" VALUES(35296,78617,-6,'Del Valle, Texas 78617',25685,31502);
INSERT INTO "django_geo_db_zipcode" VALUES(35297,78618,-6,'Doss, Texas 78618',25686,31503);
INSERT INTO "django_geo_db_zipcode" VALUES(35298,78619,-6,'Driftwood, Texas 78619',25687,31504);
INSERT INTO "django_geo_db_zipcode" VALUES(35299,78620,-6,'Dripping Springs, Texas 78620',25688,31505);
INSERT INTO "django_geo_db_zipcode" VALUES(35300,78621,-6,'Elgin, Texas 78621',25689,31506);
INSERT INTO "django_geo_db_zipcode" VALUES(35301,78622,-6,'Fentress, Texas 78622',25690,31507);
INSERT INTO "django_geo_db_zipcode" VALUES(35302,78623,-6,'Fischer, Texas 78623',25691,31508);
INSERT INTO "django_geo_db_zipcode" VALUES(35303,78624,-6,'Fredericksburg, Texas 78624',25692,31509);
INSERT INTO "django_geo_db_zipcode" VALUES(35304,78626,-6,'Georgetown, Texas 78626',25693,31510);
INSERT INTO "django_geo_db_zipcode" VALUES(35305,78627,-6,'Georgetown, Texas 78627',25693,31511);
INSERT INTO "django_geo_db_zipcode" VALUES(35306,78628,-6,'Georgetown, Texas 78628',25693,31512);
INSERT INTO "django_geo_db_zipcode" VALUES(35307,78629,-6,'Gonzales, Texas 78629',25694,31513);
INSERT INTO "django_geo_db_zipcode" VALUES(35308,78630,-6,'Cedar Park, Texas 78630',25681,31514);
INSERT INTO "django_geo_db_zipcode" VALUES(35309,78631,-6,'Harper, Texas 78631',25695,31515);
INSERT INTO "django_geo_db_zipcode" VALUES(35310,78632,-6,'Harwood, Texas 78632',25696,31516);
INSERT INTO "django_geo_db_zipcode" VALUES(35311,78634,-6,'Hutto, Texas 78634',25697,31517);
INSERT INTO "django_geo_db_zipcode" VALUES(35312,78635,-6,'Hye, Texas 78635',25698,31518);
INSERT INTO "django_geo_db_zipcode" VALUES(35313,78636,-6,'Johnson City, Texas 78636',25699,31519);
INSERT INTO "django_geo_db_zipcode" VALUES(35314,78638,-6,'Kingsbury, Texas 78638',25700,31520);
INSERT INTO "django_geo_db_zipcode" VALUES(35315,78639,-6,'Kingsland, Texas 78639',25701,31521);
INSERT INTO "django_geo_db_zipcode" VALUES(35316,78640,-6,'Kyle, Texas 78640',25702,31522);
INSERT INTO "django_geo_db_zipcode" VALUES(35317,78641,-6,'Leander, Texas 78641',25703,31523);
INSERT INTO "django_geo_db_zipcode" VALUES(35318,78642,-6,'Liberty Hill, Texas 78642',25704,31524);
INSERT INTO "django_geo_db_zipcode" VALUES(35319,78643,-6,'Llano, Texas 78643',25705,31525);
INSERT INTO "django_geo_db_zipcode" VALUES(35320,78644,-6,'Lockhart, Texas 78644',25706,31526);
INSERT INTO "django_geo_db_zipcode" VALUES(35321,78645,-6,'Leander, Texas 78645',25703,31527);
INSERT INTO "django_geo_db_zipcode" VALUES(35322,78646,-6,'Leander, Texas 78646',25703,31514);
INSERT INTO "django_geo_db_zipcode" VALUES(35323,78648,-6,'Luling, Texas 78648',25707,31528);
INSERT INTO "django_geo_db_zipcode" VALUES(35324,78650,-6,'McDade, Texas 78650',25708,31529);
INSERT INTO "django_geo_db_zipcode" VALUES(35325,78651,-6,'McNeil, Texas 78651',25709,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35326,78652,-6,'Manchaca, Texas 78652',25710,31530);
INSERT INTO "django_geo_db_zipcode" VALUES(35327,78653,-6,'Manor, Texas 78653',25711,31531);
INSERT INTO "django_geo_db_zipcode" VALUES(35328,78654,-6,'Marble Falls, Texas 78654',25712,31532);
INSERT INTO "django_geo_db_zipcode" VALUES(35329,78655,-6,'Martindale, Texas 78655',25713,31533);
INSERT INTO "django_geo_db_zipcode" VALUES(35330,78656,-6,'Maxwell, Texas 78656',25714,31534);
INSERT INTO "django_geo_db_zipcode" VALUES(35331,78657,-6,'Marble Falls, Texas 78657',25712,31535);
INSERT INTO "django_geo_db_zipcode" VALUES(35332,78658,-6,'Ottine, Texas 78658',25715,31536);
INSERT INTO "django_geo_db_zipcode" VALUES(35333,78659,-6,'Paige, Texas 78659',25716,31537);
INSERT INTO "django_geo_db_zipcode" VALUES(35334,78660,-6,'Pflugerville, Texas 78660',25717,31538);
INSERT INTO "django_geo_db_zipcode" VALUES(35335,78661,-6,'Prairie Lea, Texas 78661',25718,31539);
INSERT INTO "django_geo_db_zipcode" VALUES(35336,78662,-6,'Red Rock, Texas 78662',25719,31540);
INSERT INTO "django_geo_db_zipcode" VALUES(35337,78663,-6,'Round Mountain, Texas 78663',25720,31541);
INSERT INTO "django_geo_db_zipcode" VALUES(35338,78664,-6,'Round Rock, Texas 78664',25721,31542);
INSERT INTO "django_geo_db_zipcode" VALUES(35339,78665,-6,'Sandy, Texas 78665',25722,31543);
INSERT INTO "django_geo_db_zipcode" VALUES(35340,78666,-6,'San Marcos, Texas 78666',25723,31544);
INSERT INTO "django_geo_db_zipcode" VALUES(35341,78667,-6,'San Marcos, Texas 78667',25723,31545);
INSERT INTO "django_geo_db_zipcode" VALUES(35342,78669,-6,'Spicewood, Texas 78669',25724,31546);
INSERT INTO "django_geo_db_zipcode" VALUES(35343,78670,-6,'Staples, Texas 78670',25725,31547);
INSERT INTO "django_geo_db_zipcode" VALUES(35344,78671,-6,'Stonewall, Texas 78671',25726,31548);
INSERT INTO "django_geo_db_zipcode" VALUES(35345,78672,-6,'Tow, Texas 78672',25727,31549);
INSERT INTO "django_geo_db_zipcode" VALUES(35346,78673,-6,'Walburg, Texas 78673',25728,31550);
INSERT INTO "django_geo_db_zipcode" VALUES(35347,78674,-6,'Weir, Texas 78674',25729,31551);
INSERT INTO "django_geo_db_zipcode" VALUES(35348,78675,-6,'Willow City, Texas 78675',25730,31552);
INSERT INTO "django_geo_db_zipcode" VALUES(35349,78676,-6,'Wimberley, Texas 78676',25731,31553);
INSERT INTO "django_geo_db_zipcode" VALUES(35350,78677,-6,'Wrightsboro, Texas 78677',25732,31489);
INSERT INTO "django_geo_db_zipcode" VALUES(35351,78680,-6,'Round Rock, Texas 78680',25721,31514);
INSERT INTO "django_geo_db_zipcode" VALUES(35352,78681,-6,'Round Rock, Texas 78681',25721,31554);
INSERT INTO "django_geo_db_zipcode" VALUES(35353,78682,-6,'Round Rock, Texas 78682',25721,31514);
INSERT INTO "django_geo_db_zipcode" VALUES(35354,78683,-6,'Round Rock, Texas 78683',25721,31514);
INSERT INTO "django_geo_db_zipcode" VALUES(35355,78691,-6,'Pflugerville, Texas 78691',25717,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35356,78701,-6,'Austin, Texas 78701',24059,31555);
INSERT INTO "django_geo_db_zipcode" VALUES(35357,78702,-6,'Austin, Texas 78702',24059,31556);
INSERT INTO "django_geo_db_zipcode" VALUES(35358,78703,-6,'Austin, Texas 78703',24059,31557);
INSERT INTO "django_geo_db_zipcode" VALUES(35359,78704,-6,'Austin, Texas 78704',24059,31558);
INSERT INTO "django_geo_db_zipcode" VALUES(35360,78705,-6,'Austin, Texas 78705',24059,31559);
INSERT INTO "django_geo_db_zipcode" VALUES(35361,78708,-6,'Austin, Texas 78708',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35362,78709,-6,'Austin, Texas 78709',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35363,78710,-6,'Austin, Texas 78710',24059,31560);
INSERT INTO "django_geo_db_zipcode" VALUES(35364,78711,-6,'Austin, Texas 78711',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35365,78712,-6,'Austin, Texas 78712',24059,31561);
INSERT INTO "django_geo_db_zipcode" VALUES(35366,78713,-6,'Austin, Texas 78713',24059,31562);
INSERT INTO "django_geo_db_zipcode" VALUES(35367,78714,-6,'Austin, Texas 78714',24059,31563);
INSERT INTO "django_geo_db_zipcode" VALUES(35368,78715,-6,'Austin, Texas 78715',24059,31564);
INSERT INTO "django_geo_db_zipcode" VALUES(35369,78716,-6,'Austin, Texas 78716',24059,31565);
INSERT INTO "django_geo_db_zipcode" VALUES(35370,78717,-6,'Austin, Texas 78717',24059,31566);
INSERT INTO "django_geo_db_zipcode" VALUES(35371,78718,-6,'Austin, Texas 78718',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35372,78719,-6,'Austin, Texas 78719',24059,31567);
INSERT INTO "django_geo_db_zipcode" VALUES(35373,78720,-6,'Austin, Texas 78720',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35374,78721,-6,'Austin, Texas 78721',24059,31568);
INSERT INTO "django_geo_db_zipcode" VALUES(35375,78722,-6,'Austin, Texas 78722',24059,31569);
INSERT INTO "django_geo_db_zipcode" VALUES(35376,78723,-6,'Austin, Texas 78723',24059,31570);
INSERT INTO "django_geo_db_zipcode" VALUES(35377,78724,-6,'Austin, Texas 78724',24059,31571);
INSERT INTO "django_geo_db_zipcode" VALUES(35378,78725,-6,'Austin, Texas 78725',24059,31572);
INSERT INTO "django_geo_db_zipcode" VALUES(35379,78726,-6,'Austin, Texas 78726',24059,31573);
INSERT INTO "django_geo_db_zipcode" VALUES(35380,78727,-6,'Austin, Texas 78727',24059,31574);
INSERT INTO "django_geo_db_zipcode" VALUES(35381,78728,-6,'Austin, Texas 78728',24059,31575);
INSERT INTO "django_geo_db_zipcode" VALUES(35382,78729,-6,'Austin, Texas 78729',24059,31576);
INSERT INTO "django_geo_db_zipcode" VALUES(35383,78730,-6,'Austin, Texas 78730',24059,31577);
INSERT INTO "django_geo_db_zipcode" VALUES(35384,78731,-6,'Austin, Texas 78731',24059,31578);
INSERT INTO "django_geo_db_zipcode" VALUES(35385,78732,-6,'Austin, Texas 78732',24059,31579);
INSERT INTO "django_geo_db_zipcode" VALUES(35386,78733,-6,'Austin, Texas 78733',24059,31580);
INSERT INTO "django_geo_db_zipcode" VALUES(35387,78734,-6,'Austin, Texas 78734',24059,31581);
INSERT INTO "django_geo_db_zipcode" VALUES(35388,78735,-6,'Austin, Texas 78735',24059,31582);
INSERT INTO "django_geo_db_zipcode" VALUES(35389,78736,-6,'Austin, Texas 78736',24059,31583);
INSERT INTO "django_geo_db_zipcode" VALUES(35390,78737,-6,'Austin, Texas 78737',24059,31584);
INSERT INTO "django_geo_db_zipcode" VALUES(35391,78738,-6,'Austin, Texas 78738',24059,31585);
INSERT INTO "django_geo_db_zipcode" VALUES(35392,78739,-6,'Austin, Texas 78739',24059,31586);
INSERT INTO "django_geo_db_zipcode" VALUES(35393,78741,-6,'Austin, Texas 78741',24059,31587);
INSERT INTO "django_geo_db_zipcode" VALUES(35394,78742,-6,'Austin, Texas 78742',24059,31588);
INSERT INTO "django_geo_db_zipcode" VALUES(35395,78744,-6,'Austin, Texas 78744',24059,31589);
INSERT INTO "django_geo_db_zipcode" VALUES(35396,78745,-6,'Austin, Texas 78745',24059,31590);
INSERT INTO "django_geo_db_zipcode" VALUES(35397,78746,-6,'Austin, Texas 78746',24059,31591);
INSERT INTO "django_geo_db_zipcode" VALUES(35398,78747,-6,'Austin, Texas 78747',24059,31592);
INSERT INTO "django_geo_db_zipcode" VALUES(35399,78748,-6,'Austin, Texas 78748',24059,31593);
INSERT INTO "django_geo_db_zipcode" VALUES(35400,78749,-6,'Austin, Texas 78749',24059,31594);
INSERT INTO "django_geo_db_zipcode" VALUES(35401,78750,-6,'Austin, Texas 78750',24059,31595);
INSERT INTO "django_geo_db_zipcode" VALUES(35402,78751,-6,'Austin, Texas 78751',24059,31596);
INSERT INTO "django_geo_db_zipcode" VALUES(35403,78752,-6,'Austin, Texas 78752',24059,31597);
INSERT INTO "django_geo_db_zipcode" VALUES(35404,78753,-6,'Austin, Texas 78753',24059,31598);
INSERT INTO "django_geo_db_zipcode" VALUES(35405,78754,-6,'Austin, Texas 78754',24059,31599);
INSERT INTO "django_geo_db_zipcode" VALUES(35406,78755,-6,'Austin, Texas 78755',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35407,78756,-6,'Austin, Texas 78756',24059,31600);
INSERT INTO "django_geo_db_zipcode" VALUES(35408,78757,-6,'Austin, Texas 78757',24059,31601);
INSERT INTO "django_geo_db_zipcode" VALUES(35409,78758,-6,'Austin, Texas 78758',24059,31602);
INSERT INTO "django_geo_db_zipcode" VALUES(35410,78759,-6,'Austin, Texas 78759',24059,31603);
INSERT INTO "django_geo_db_zipcode" VALUES(35411,78760,-6,'Austin, Texas 78760',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35412,78761,-6,'Austin, Texas 78761',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35413,78762,-6,'Austin, Texas 78762',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35414,78763,-6,'Austin, Texas 78763',24059,31604);
INSERT INTO "django_geo_db_zipcode" VALUES(35415,78764,-6,'Austin, Texas 78764',24059,31605);
INSERT INTO "django_geo_db_zipcode" VALUES(35416,78765,-6,'Austin, Texas 78765',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35417,78766,-6,'Austin, Texas 78766',24059,31606);
INSERT INTO "django_geo_db_zipcode" VALUES(35418,78767,-6,'Austin, Texas 78767',24059,31607);
INSERT INTO "django_geo_db_zipcode" VALUES(35419,78768,-6,'Austin, Texas 78768',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35420,78769,-6,'Austin, Texas 78769',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35421,78771,-6,'Austin, Texas 78771',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35422,78772,-6,'Austin, Texas 78772',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35423,78773,-6,'Austin, Texas 78773',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35424,78774,-6,'Austin, Texas 78774',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35425,78778,-6,'Austin, Texas 78778',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35426,78779,-6,'Austin, Texas 78779',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35427,78780,-6,'Austin, Texas 78780',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35428,78781,-6,'Austin, Texas 78781',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35429,78782,-6,'Austin, Texas 78782',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35430,78783,-6,'Austin, Texas 78783',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35431,78785,-6,'Austin, Texas 78785',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35432,78786,-6,'Austin, Texas 78786',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35433,78787,-6,'Austin, Texas 78787',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35434,78788,-6,'Austin, Texas 78788',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35435,78789,-6,'Austin, Texas 78789',24059,29234);
INSERT INTO "django_geo_db_zipcode" VALUES(35436,78801,-6,'Uvalde, Texas 78801',25733,31608);
INSERT INTO "django_geo_db_zipcode" VALUES(35437,78802,-6,'Uvalde, Texas 78802',25733,31609);
INSERT INTO "django_geo_db_zipcode" VALUES(35438,78827,-6,'Asherton, Texas 78827',25734,31610);
INSERT INTO "django_geo_db_zipcode" VALUES(35439,78828,-6,'Barksdale, Texas 78828',25735,31611);
INSERT INTO "django_geo_db_zipcode" VALUES(35440,78829,-6,'Batesville, Texas 78829',25736,31612);
INSERT INTO "django_geo_db_zipcode" VALUES(35441,78830,-6,'Big Wells, Texas 78830',25737,31613);
INSERT INTO "django_geo_db_zipcode" VALUES(35442,78832,-6,'Brackettville, Texas 78832',25738,31614);
INSERT INTO "django_geo_db_zipcode" VALUES(35443,78833,-6,'Camp Wood, Texas 78833',25739,31615);
INSERT INTO "django_geo_db_zipcode" VALUES(35444,78834,-6,'Carrizo Springs, Texas 78834',25740,31616);
INSERT INTO "django_geo_db_zipcode" VALUES(35445,78835,-6,'Burton, Texas 78835',25408,31617);
INSERT INTO "django_geo_db_zipcode" VALUES(35446,78836,-6,'Catarina, Texas 78836',25741,31618);
INSERT INTO "django_geo_db_zipcode" VALUES(35447,78837,-6,'Comstock, Texas 78837',25742,31619);
INSERT INTO "django_geo_db_zipcode" VALUES(35448,78838,-6,'Concan, Texas 78838',25743,31620);
INSERT INTO "django_geo_db_zipcode" VALUES(35449,78839,-6,'Crystal City, Texas 78839',25744,31621);
INSERT INTO "django_geo_db_zipcode" VALUES(35450,78840,-6,'Del Rio, Texas 78840',25745,31622);
INSERT INTO "django_geo_db_zipcode" VALUES(35451,78841,-6,'Del Rio, Texas 78841',25745,31623);
INSERT INTO "django_geo_db_zipcode" VALUES(35452,78842,-6,'Del Rio, Texas 78842',25745,31624);
INSERT INTO "django_geo_db_zipcode" VALUES(35453,78843,-6,'Laughlin A F B, Texas 78843',25746,31625);
INSERT INTO "django_geo_db_zipcode" VALUES(35454,78847,-6,'Del Rio, Texas 78847',25745,31626);
INSERT INTO "django_geo_db_zipcode" VALUES(35455,78850,-6,'D Hanis, Texas 78850',25747,31627);
INSERT INTO "django_geo_db_zipcode" VALUES(35456,78851,-6,'Dryden, Texas 78851',25748,31628);
INSERT INTO "django_geo_db_zipcode" VALUES(35457,78852,-6,'Eagle Pass, Texas 78852',25749,31629);
INSERT INTO "django_geo_db_zipcode" VALUES(35458,78853,-6,'Eagle Pass, Texas 78853',25749,31630);
INSERT INTO "django_geo_db_zipcode" VALUES(35459,78860,-6,'El Indio, Texas 78860',25750,31631);
INSERT INTO "django_geo_db_zipcode" VALUES(35460,78861,-6,'Hondo, Texas 78861',25751,31632);
INSERT INTO "django_geo_db_zipcode" VALUES(35461,78870,-6,'Knippa, Texas 78870',25752,31633);
INSERT INTO "django_geo_db_zipcode" VALUES(35462,78871,-6,'Langtry, Texas 78871',25753,31626);
INSERT INTO "django_geo_db_zipcode" VALUES(35463,78872,-6,'La Pryor, Texas 78872',25754,31634);
INSERT INTO "django_geo_db_zipcode" VALUES(35464,78873,-6,'Leakey, Texas 78873',25755,31635);
INSERT INTO "django_geo_db_zipcode" VALUES(35465,78877,-6,'Quemado, Texas 78877',25756,31636);
INSERT INTO "django_geo_db_zipcode" VALUES(35466,78879,-6,'Rio Frio, Texas 78879',25757,31637);
INSERT INTO "django_geo_db_zipcode" VALUES(35467,78880,-6,'Rocksprings, Texas 78880',25758,31638);
INSERT INTO "django_geo_db_zipcode" VALUES(35468,78881,-6,'Sabinal, Texas 78881',25759,31639);
INSERT INTO "django_geo_db_zipcode" VALUES(35469,78883,-6,'Tarpley, Texas 78883',25760,31640);
INSERT INTO "django_geo_db_zipcode" VALUES(35470,78884,-6,'Utopia, Texas 78884',25761,31641);
INSERT INTO "django_geo_db_zipcode" VALUES(35471,78885,-6,'Vanderpool, Texas 78885',25762,31642);
INSERT INTO "django_geo_db_zipcode" VALUES(35472,78886,-6,'Yancey, Texas 78886',25763,31643);
INSERT INTO "django_geo_db_zipcode" VALUES(35473,78931,-6,'Bleiblerville, Texas 78931',25764,30935);
INSERT INTO "django_geo_db_zipcode" VALUES(35474,78932,-6,'Carmine, Texas 78932',25765,31644);
INSERT INTO "django_geo_db_zipcode" VALUES(35475,78933,-6,'Cat Spring, Texas 78933',25766,31645);
INSERT INTO "django_geo_db_zipcode" VALUES(35476,78934,-6,'Columbus, Texas 78934',25767,31646);
INSERT INTO "django_geo_db_zipcode" VALUES(35477,78935,-6,'Alleyton, Texas 78935',25768,31647);
INSERT INTO "django_geo_db_zipcode" VALUES(35478,78938,-6,'Ellinger, Texas 78938',25769,31648);
INSERT INTO "django_geo_db_zipcode" VALUES(35479,78940,-6,'Fayetteville, Texas 78940',25770,31649);
INSERT INTO "django_geo_db_zipcode" VALUES(35480,78941,-6,'Flatonia, Texas 78941',25771,31650);
INSERT INTO "django_geo_db_zipcode" VALUES(35481,78942,-6,'Giddings, Texas 78942',25772,31651);
INSERT INTO "django_geo_db_zipcode" VALUES(35482,78943,-6,'Glidden, Texas 78943',25773,31652);
INSERT INTO "django_geo_db_zipcode" VALUES(35483,78944,-6,'Industry, Texas 78944',25774,31653);
INSERT INTO "django_geo_db_zipcode" VALUES(35484,78945,-6,'La Grange, Texas 78945',25775,31654);
INSERT INTO "django_geo_db_zipcode" VALUES(35485,78946,-6,'Ledbetter, Texas 78946',25776,31655);
INSERT INTO "django_geo_db_zipcode" VALUES(35486,78947,-6,'Lexington, Texas 78947',25777,31656);
INSERT INTO "django_geo_db_zipcode" VALUES(35487,78948,-6,'Lincoln, Texas 78948',25778,31657);
INSERT INTO "django_geo_db_zipcode" VALUES(35488,78949,-6,'Muldoon, Texas 78949',25779,31658);
INSERT INTO "django_geo_db_zipcode" VALUES(35489,78950,-6,'New Ulm, Texas 78950',25780,31659);
INSERT INTO "django_geo_db_zipcode" VALUES(35490,78951,-6,'Oakland, Texas 78951',25781,30943);
INSERT INTO "django_geo_db_zipcode" VALUES(35491,78952,-6,'Plum, Texas 78952',25782,31660);
INSERT INTO "django_geo_db_zipcode" VALUES(35492,78953,-6,'Rosanky, Texas 78953',25783,31661);
INSERT INTO "django_geo_db_zipcode" VALUES(35493,78954,-6,'Round Top, Texas 78954',25784,31662);
INSERT INTO "django_geo_db_zipcode" VALUES(35494,78956,-6,'Schulenburg, Texas 78956',25785,31663);
INSERT INTO "django_geo_db_zipcode" VALUES(35495,78957,-6,'Smithville, Texas 78957',25786,31664);
INSERT INTO "django_geo_db_zipcode" VALUES(35496,78959,-6,'Waelder, Texas 78959',25787,31665);
INSERT INTO "django_geo_db_zipcode" VALUES(35497,78960,-6,'Warda, Texas 78960',25788,31666);
INSERT INTO "django_geo_db_zipcode" VALUES(35498,78961,-6,'Round Top, Texas 78961',25784,31667);
INSERT INTO "django_geo_db_zipcode" VALUES(35499,78962,-6,'Weimar, Texas 78962',25789,31668);
INSERT INTO "django_geo_db_zipcode" VALUES(35500,78963,-6,'West Point, Texas 78963',25790,31669);
INSERT INTO "django_geo_db_zipcode" VALUES(35501,78972,-6,'Austin, Texas 78972',24059,31670);
INSERT INTO "django_geo_db_zipcode" VALUES(35502,79001,-6,'Adrian, Texas 79001',25791,31671);
INSERT INTO "django_geo_db_zipcode" VALUES(35503,79002,-6,'Alanreed, Texas 79002',25792,31672);
INSERT INTO "django_geo_db_zipcode" VALUES(35504,79003,-6,'Allison, Texas 79003',25793,31673);
INSERT INTO "django_geo_db_zipcode" VALUES(35505,79005,-6,'Booker, Texas 79005',25794,31674);
INSERT INTO "django_geo_db_zipcode" VALUES(35506,79007,-6,'Borger, Texas 79007',25795,31675);
INSERT INTO "django_geo_db_zipcode" VALUES(35507,79008,-6,'Borger, Texas 79008',25795,31676);
INSERT INTO "django_geo_db_zipcode" VALUES(35508,79009,-6,'Bovina, Texas 79009',25796,31677);
INSERT INTO "django_geo_db_zipcode" VALUES(35509,79010,-6,'Boys Ranch, Texas 79010',25797,31678);
INSERT INTO "django_geo_db_zipcode" VALUES(35510,79011,-6,'Briscoe, Texas 79011',25798,31679);
INSERT INTO "django_geo_db_zipcode" VALUES(35511,79012,-6,'Bushland, Texas 79012',25799,31680);
INSERT INTO "django_geo_db_zipcode" VALUES(35512,79013,-6,'Cactus, Texas 79013',25800,31681);
INSERT INTO "django_geo_db_zipcode" VALUES(35513,79014,-6,'Canadian, Texas 79014',25801,31682);
INSERT INTO "django_geo_db_zipcode" VALUES(35514,79015,-6,'Canyon, Texas 79015',25802,31683);
INSERT INTO "django_geo_db_zipcode" VALUES(35515,79016,-6,'Canyon, Texas 79016',25802,31684);
INSERT INTO "django_geo_db_zipcode" VALUES(35516,79018,-6,'Channing, Texas 79018',25803,31685);
INSERT INTO "django_geo_db_zipcode" VALUES(35517,79019,-6,'Claude, Texas 79019',25804,31686);
INSERT INTO "django_geo_db_zipcode" VALUES(35518,79021,-6,'Cotton Center, Texas 79021',25805,31687);
INSERT INTO "django_geo_db_zipcode" VALUES(35519,79022,-6,'Dalhart, Texas 79022',25806,31688);
INSERT INTO "django_geo_db_zipcode" VALUES(35520,79024,-6,'Darrouzett, Texas 79024',25807,31689);
INSERT INTO "django_geo_db_zipcode" VALUES(35521,79025,-6,'Dawn, Texas 79025',25808,31690);
INSERT INTO "django_geo_db_zipcode" VALUES(35522,79027,-6,'Dimmitt, Texas 79027',25809,31691);
INSERT INTO "django_geo_db_zipcode" VALUES(35523,79029,-6,'Dumas, Texas 79029',25810,31692);
INSERT INTO "django_geo_db_zipcode" VALUES(35524,79031,-6,'Earth, Texas 79031',25811,31693);
INSERT INTO "django_geo_db_zipcode" VALUES(35525,79032,-6,'Edmonson, Texas 79032',25812,31694);
INSERT INTO "django_geo_db_zipcode" VALUES(35526,79033,-6,'Farnsworth, Texas 79033',25813,31695);
INSERT INTO "django_geo_db_zipcode" VALUES(35527,79034,-6,'Follett, Texas 79034',25814,31696);
INSERT INTO "django_geo_db_zipcode" VALUES(35528,79035,-6,'Friona, Texas 79035',25815,31697);
INSERT INTO "django_geo_db_zipcode" VALUES(35529,79036,-6,'Fritch, Texas 79036',25816,31698);
INSERT INTO "django_geo_db_zipcode" VALUES(35530,79039,-6,'Groom, Texas 79039',25817,31699);
INSERT INTO "django_geo_db_zipcode" VALUES(35531,79040,-6,'Gruver, Texas 79040',25818,31700);
INSERT INTO "django_geo_db_zipcode" VALUES(35532,79041,-6,'Hale Center, Texas 79041',25819,31701);
INSERT INTO "django_geo_db_zipcode" VALUES(35533,79042,-6,'Happy, Texas 79042',25820,31702);
INSERT INTO "django_geo_db_zipcode" VALUES(35534,79043,-6,'Hart, Texas 79043',25821,31703);
INSERT INTO "django_geo_db_zipcode" VALUES(35535,79044,-6,'Hartley, Texas 79044',25822,31704);
INSERT INTO "django_geo_db_zipcode" VALUES(35536,79045,-6,'Hereford, Texas 79045',25823,31705);
INSERT INTO "django_geo_db_zipcode" VALUES(35537,79046,-6,'Higgins, Texas 79046',25824,31706);
INSERT INTO "django_geo_db_zipcode" VALUES(35538,79051,-6,'Kerrick, Oklahoma 79051',25825,31707);
INSERT INTO "django_geo_db_zipcode" VALUES(35539,79052,-6,'Kress, Texas 79052',25826,31708);
INSERT INTO "django_geo_db_zipcode" VALUES(35540,79053,-6,'Lazbuddie, Texas 79053',25827,31709);
INSERT INTO "django_geo_db_zipcode" VALUES(35541,79054,-6,'Lefors, Texas 79054',25828,31710);
INSERT INTO "django_geo_db_zipcode" VALUES(35542,79056,-6,'Lipscomb, Texas 79056',25829,31711);
INSERT INTO "django_geo_db_zipcode" VALUES(35543,79057,-6,'Mclean, Texas 79057',25830,31712);
INSERT INTO "django_geo_db_zipcode" VALUES(35544,79058,-6,'Masterson, Texas 79058',25831,31713);
INSERT INTO "django_geo_db_zipcode" VALUES(35545,79059,-6,'Miami, Texas 79059',25832,31714);
INSERT INTO "django_geo_db_zipcode" VALUES(35546,79061,-6,'Mobeetie, Texas 79061',25833,31715);
INSERT INTO "django_geo_db_zipcode" VALUES(35547,79062,-6,'Morse, Texas 79062',25834,31716);
INSERT INTO "django_geo_db_zipcode" VALUES(35548,79063,-6,'Nazareth, Texas 79063',25835,31717);
INSERT INTO "django_geo_db_zipcode" VALUES(35549,79064,-6,'Olton, Texas 79064',25836,31718);
INSERT INTO "django_geo_db_zipcode" VALUES(35550,79065,-6,'Pampa, Texas 79065',25837,31719);
INSERT INTO "django_geo_db_zipcode" VALUES(35551,79066,-6,'Pampa, Texas 79066',25837,31720);
INSERT INTO "django_geo_db_zipcode" VALUES(35552,79068,-6,'Panhandle, Texas 79068',25838,31721);
INSERT INTO "django_geo_db_zipcode" VALUES(35553,79070,-6,'Perryton, Texas 79070',25839,31722);
INSERT INTO "django_geo_db_zipcode" VALUES(35554,79072,-6,'Plainview, Texas 79072',25840,31723);
INSERT INTO "django_geo_db_zipcode" VALUES(35555,79073,-6,'Plainview, Texas 79073',25840,31724);
INSERT INTO "django_geo_db_zipcode" VALUES(35556,79077,-6,'Samnorwood, Texas 79077',25841,31725);
INSERT INTO "django_geo_db_zipcode" VALUES(35557,79078,-6,'Sanford, Texas 79078',25842,31726);
INSERT INTO "django_geo_db_zipcode" VALUES(35558,79079,-6,'Shamrock, Texas 79079',25843,31727);
INSERT INTO "django_geo_db_zipcode" VALUES(35559,79080,-6,'Skellytown, Texas 79080',25844,31728);
INSERT INTO "django_geo_db_zipcode" VALUES(35560,79081,-6,'Spearman, Texas 79081',25845,31729);
INSERT INTO "django_geo_db_zipcode" VALUES(35561,79082,-6,'Springlake, Texas 79082',25846,31730);
INSERT INTO "django_geo_db_zipcode" VALUES(35562,79083,-6,'Stinnett, Texas 79083',25847,31731);
INSERT INTO "django_geo_db_zipcode" VALUES(35563,79084,-6,'Stratford, Texas 79084',25848,31732);
INSERT INTO "django_geo_db_zipcode" VALUES(35564,79085,-6,'Summerfield, Texas 79085',25849,31733);
INSERT INTO "django_geo_db_zipcode" VALUES(35565,79086,-6,'Sunray, Texas 79086',25850,31734);
INSERT INTO "django_geo_db_zipcode" VALUES(35566,79087,-6,'Texline, Texas 79087',25851,31735);
INSERT INTO "django_geo_db_zipcode" VALUES(35567,79088,-6,'Tulia, Texas 79088',25852,31736);
INSERT INTO "django_geo_db_zipcode" VALUES(35568,79091,-6,'Umbarger, Texas 79091',25853,31737);
INSERT INTO "django_geo_db_zipcode" VALUES(35569,79092,-6,'Vega, Texas 79092',25854,31738);
INSERT INTO "django_geo_db_zipcode" VALUES(35570,79093,-6,'Waka, Texas 79093',25855,31739);
INSERT INTO "django_geo_db_zipcode" VALUES(35571,79094,-6,'Wayside, Texas 79094',25856,31740);
INSERT INTO "django_geo_db_zipcode" VALUES(35572,79095,-6,'Wellington, Texas 79095',25857,31741);
INSERT INTO "django_geo_db_zipcode" VALUES(35573,79096,-6,'Wheeler, Texas 79096',25858,31742);
INSERT INTO "django_geo_db_zipcode" VALUES(35574,79097,-6,'White Deer, Texas 79097',25859,31743);
INSERT INTO "django_geo_db_zipcode" VALUES(35575,79098,-6,'Wildorado, Texas 79098',25860,31744);
INSERT INTO "django_geo_db_zipcode" VALUES(35576,79101,-6,'Amarillo, Texas 79101',25861,31745);
INSERT INTO "django_geo_db_zipcode" VALUES(35577,79102,-6,'Amarillo, Texas 79102',25861,31746);
INSERT INTO "django_geo_db_zipcode" VALUES(35578,79103,-6,'Amarillo, Texas 79103',25861,31747);
INSERT INTO "django_geo_db_zipcode" VALUES(35579,79104,-6,'Amarillo, Texas 79104',25861,31748);
INSERT INTO "django_geo_db_zipcode" VALUES(35580,79105,-6,'Amarillo, Texas 79105',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35581,79106,-6,'Amarillo, Texas 79106',25861,31750);
INSERT INTO "django_geo_db_zipcode" VALUES(35582,79107,-6,'Amarillo, Texas 79107',25861,31751);
INSERT INTO "django_geo_db_zipcode" VALUES(35583,79108,-6,'Amarillo, Texas 79108',25861,31752);
INSERT INTO "django_geo_db_zipcode" VALUES(35584,79109,-6,'Amarillo, Texas 79109',25861,31753);
INSERT INTO "django_geo_db_zipcode" VALUES(35585,79110,-6,'Amarillo, Texas 79110',25861,31754);
INSERT INTO "django_geo_db_zipcode" VALUES(35586,79111,-6,'Amarillo, Texas 79111',25861,31755);
INSERT INTO "django_geo_db_zipcode" VALUES(35587,79114,-6,'Amarillo, Texas 79114',25861,31756);
INSERT INTO "django_geo_db_zipcode" VALUES(35588,79116,-6,'Amarillo, Texas 79116',25861,31757);
INSERT INTO "django_geo_db_zipcode" VALUES(35589,79117,-6,'Amarillo, Texas 79117',25861,31758);
INSERT INTO "django_geo_db_zipcode" VALUES(35590,79118,-6,'Amarillo, Texas 79118',25861,31759);
INSERT INTO "django_geo_db_zipcode" VALUES(35591,79119,-6,'Amarillo, Texas 79119',25861,31760);
INSERT INTO "django_geo_db_zipcode" VALUES(35592,79120,-6,'Amarillo, Texas 79120',25861,31761);
INSERT INTO "django_geo_db_zipcode" VALUES(35593,79121,-6,'Amarillo, Texas 79121',25861,31762);
INSERT INTO "django_geo_db_zipcode" VALUES(35594,79123,-6,'Amarillo, Texas 79123',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35595,79124,-6,'Amarillo, Texas 79124',25861,31763);
INSERT INTO "django_geo_db_zipcode" VALUES(35596,79159,-6,'Amarillo, Texas 79159',25861,31764);
INSERT INTO "django_geo_db_zipcode" VALUES(35597,79160,-6,'Amarillo, Texas 79160',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35598,79163,-6,'Amarillo, Texas 79163',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35599,79164,-6,'Amarillo, Texas 79164',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35600,79165,-6,'Amarillo, Texas 79165',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35601,79166,-6,'Amarillo, Texas 79166',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35602,79167,-6,'Amarillo, Texas 79167',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35603,79168,-6,'Amarillo, Texas 79168',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35604,79170,-6,'Amarillo, Texas 79170',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35605,79171,-6,'Amarillo, Texas 79171',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35606,79172,-6,'Amarillo, Texas 79172',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35607,79174,-6,'Amarillo, Texas 79174',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35608,79175,-6,'Amarillo, Texas 79175',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35609,79178,-6,'Amarillo, Texas 79178',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35610,79180,-6,'Amarillo, Texas 79180',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35611,79181,-6,'Amarillo, Texas 79181',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35612,79182,-6,'Amarillo, Texas 79182',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35613,79184,-6,'Amarillo, Texas 79184',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35614,79185,-6,'Amarillo, Texas 79185',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35615,79186,-6,'Amarillo, Texas 79186',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35616,79187,-6,'Amarillo, Texas 79187',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35617,79189,-6,'Amarillo, Texas 79189',25861,31749);
INSERT INTO "django_geo_db_zipcode" VALUES(35618,79201,-6,'Childress, Texas 79201',25862,31765);
INSERT INTO "django_geo_db_zipcode" VALUES(35619,79220,-6,'Afton, Texas 79220',25863,31766);
INSERT INTO "django_geo_db_zipcode" VALUES(35620,79221,-6,'Aiken, Texas 79221',25864,31767);
INSERT INTO "django_geo_db_zipcode" VALUES(35621,79222,-6,'Carey, Texas 79222',25865,31768);
INSERT INTO "django_geo_db_zipcode" VALUES(35622,79223,-6,'Cee Vee, Texas 79223',25866,31769);
INSERT INTO "django_geo_db_zipcode" VALUES(35623,79224,-6,'Chalk, Texas 79224',25867,31770);
INSERT INTO "django_geo_db_zipcode" VALUES(35624,79225,-6,'Chillicothe, Texas 79225',25868,31771);
INSERT INTO "django_geo_db_zipcode" VALUES(35625,79226,-6,'Clarendon, Texas 79226',25869,31772);
INSERT INTO "django_geo_db_zipcode" VALUES(35626,79227,-6,'Crowell, Texas 79227',25870,31773);
INSERT INTO "django_geo_db_zipcode" VALUES(35627,79229,-6,'Dickens, Texas 79229',25871,31774);
INSERT INTO "django_geo_db_zipcode" VALUES(35628,79230,-6,'Dodson, Texas 79230',25872,31775);
INSERT INTO "django_geo_db_zipcode" VALUES(35629,79231,-6,'Dougherty, Texas 79231',25873,31776);
INSERT INTO "django_geo_db_zipcode" VALUES(35630,79232,-6,'Dumont, Texas 79232',25874,31777);
INSERT INTO "django_geo_db_zipcode" VALUES(35631,79233,-6,'Estelline, Texas 79233',25875,31778);
INSERT INTO "django_geo_db_zipcode" VALUES(35632,79234,-6,'Flomot, Texas 79234',25876,31779);
INSERT INTO "django_geo_db_zipcode" VALUES(35633,79235,-6,'Floydada, Texas 79235',25877,31780);
INSERT INTO "django_geo_db_zipcode" VALUES(35634,79236,-6,'Guthrie, Texas 79236',25878,31781);
INSERT INTO "django_geo_db_zipcode" VALUES(35635,79237,-6,'Hedley, Texas 79237',25879,31782);
INSERT INTO "django_geo_db_zipcode" VALUES(35636,79238,-6,'Kirkland, Texas 79238',25880,31768);
INSERT INTO "django_geo_db_zipcode" VALUES(35637,79239,-6,'Lakeview, Texas 79239',25881,31783);
INSERT INTO "django_geo_db_zipcode" VALUES(35638,79240,-6,'Lelia Lake, Texas 79240',25882,31784);
INSERT INTO "django_geo_db_zipcode" VALUES(35639,79241,-6,'Lockney, Texas 79241',25883,31785);
INSERT INTO "django_geo_db_zipcode" VALUES(35640,79243,-6,'Mcadoo, Texas 79243',25884,31786);
INSERT INTO "django_geo_db_zipcode" VALUES(35641,79244,-6,'Matador, Texas 79244',25885,31787);
INSERT INTO "django_geo_db_zipcode" VALUES(35642,79245,-6,'Memphis, Texas 79245',25886,31788);
INSERT INTO "django_geo_db_zipcode" VALUES(35643,79247,-6,'Odell, Texas 79247',25887,31789);
INSERT INTO "django_geo_db_zipcode" VALUES(35644,79248,-6,'Paducah, Texas 79248',25888,31790);
INSERT INTO "django_geo_db_zipcode" VALUES(35645,79250,-6,'Petersburg, Texas 79250',25889,31791);
INSERT INTO "django_geo_db_zipcode" VALUES(35646,79251,-6,'Quail, Texas 79251',25890,31792);
INSERT INTO "django_geo_db_zipcode" VALUES(35647,79252,-6,'Quanah, Texas 79252',25891,31793);
INSERT INTO "django_geo_db_zipcode" VALUES(35648,79255,-6,'Quitaque, Texas 79255',25892,31794);
INSERT INTO "django_geo_db_zipcode" VALUES(35649,79256,-6,'Roaring Springs, Texas 79256',25893,31795);
INSERT INTO "django_geo_db_zipcode" VALUES(35650,79257,-6,'Silverton, Texas 79257',25894,31796);
INSERT INTO "django_geo_db_zipcode" VALUES(35651,79258,-6,'South Plains, Texas 79258',25895,31767);
INSERT INTO "django_geo_db_zipcode" VALUES(35652,79259,-6,'Tell, Texas 79259',25896,31797);
INSERT INTO "django_geo_db_zipcode" VALUES(35653,79261,-6,'Turkey, Texas 79261',25897,31798);
INSERT INTO "django_geo_db_zipcode" VALUES(35654,79301,-6,'Earth, Texas 79301',25811,31799);
INSERT INTO "django_geo_db_zipcode" VALUES(35655,79311,-6,'Abernathy, Texas 79311',25898,31800);
INSERT INTO "django_geo_db_zipcode" VALUES(35656,79312,-6,'Amherst, Texas 79312',25899,31801);
INSERT INTO "django_geo_db_zipcode" VALUES(35657,79313,-6,'Anton, Texas 79313',25900,31802);
INSERT INTO "django_geo_db_zipcode" VALUES(35658,79314,-6,'Bledsoe, Texas 79314',25901,31803);
INSERT INTO "django_geo_db_zipcode" VALUES(35659,79316,-6,'Brownfield, Texas 79316',25902,31804);
INSERT INTO "django_geo_db_zipcode" VALUES(35660,79320,-6,'Bula, Texas 79320',25903,31805);
INSERT INTO "django_geo_db_zipcode" VALUES(35661,79321,-6,'Sudan, Texas 79321',25904,31806);
INSERT INTO "django_geo_db_zipcode" VALUES(35662,79322,-6,'Crosbyton, Texas 79322',25905,31807);
INSERT INTO "django_geo_db_zipcode" VALUES(35663,79323,-6,'Denver City, Texas 79323',25906,31808);
INSERT INTO "django_geo_db_zipcode" VALUES(35664,79324,-6,'Enochs, Texas 79324',25907,31809);
INSERT INTO "django_geo_db_zipcode" VALUES(35665,79325,-6,'Farwell, Texas 79325',25908,31810);
INSERT INTO "django_geo_db_zipcode" VALUES(35666,79326,-6,'Fieldton, Texas 79326',25909,31811);
INSERT INTO "django_geo_db_zipcode" VALUES(35667,79329,-6,'Idalou, Texas 79329',25910,31812);
INSERT INTO "django_geo_db_zipcode" VALUES(35668,79330,-6,'Justiceburg, Texas 79330',25911,31813);
INSERT INTO "django_geo_db_zipcode" VALUES(35669,79331,-6,'Lamesa, Texas 79331',25912,31814);
INSERT INTO "django_geo_db_zipcode" VALUES(35670,79336,-6,'Levelland, Texas 79336',25913,31815);
INSERT INTO "django_geo_db_zipcode" VALUES(35671,79338,-6,'Levelland, Texas 79338',25913,31816);
INSERT INTO "django_geo_db_zipcode" VALUES(35672,79339,-6,'Littlefield, Texas 79339',25914,31817);
INSERT INTO "django_geo_db_zipcode" VALUES(35673,79342,-6,'Loop, Texas 79342',25915,31818);
INSERT INTO "django_geo_db_zipcode" VALUES(35674,79343,-6,'Lorenzo, Texas 79343',25916,31819);
INSERT INTO "django_geo_db_zipcode" VALUES(35675,79344,-6,'Maple, Texas 79344',25917,31820);
INSERT INTO "django_geo_db_zipcode" VALUES(35676,79345,-6,'Meadow, Texas 79345',25918,31821);
INSERT INTO "django_geo_db_zipcode" VALUES(35677,79346,-6,'Morton, Texas 79346',25919,31822);
INSERT INTO "django_geo_db_zipcode" VALUES(35678,79347,-6,'Muleshoe, Texas 79347',25920,31823);
INSERT INTO "django_geo_db_zipcode" VALUES(35679,79350,-6,'New Deal, Texas 79350',25921,31824);
INSERT INTO "django_geo_db_zipcode" VALUES(35680,79351,-6,'Odonnell, Texas 79351',25922,31825);
INSERT INTO "django_geo_db_zipcode" VALUES(35681,79353,-6,'Pep, Texas 79353',25923,31826);
INSERT INTO "django_geo_db_zipcode" VALUES(35682,79355,-6,'Plains, Texas 79355',25924,31827);
INSERT INTO "django_geo_db_zipcode" VALUES(35683,79356,-6,'Post, Texas 79356',25925,31828);
INSERT INTO "django_geo_db_zipcode" VALUES(35684,79357,-6,'Ralls, Texas 79357',25926,31829);
INSERT INTO "django_geo_db_zipcode" VALUES(35685,79358,-6,'Ropesville, Texas 79358',25927,31830);
INSERT INTO "django_geo_db_zipcode" VALUES(35686,79359,-6,'Seagraves, Texas 79359',25928,31831);
INSERT INTO "django_geo_db_zipcode" VALUES(35687,79360,-6,'Seminole, Texas 79360',25929,31832);
INSERT INTO "django_geo_db_zipcode" VALUES(35688,79363,-6,'Shallowater, Texas 79363',25930,31833);
INSERT INTO "django_geo_db_zipcode" VALUES(35689,79364,-6,'Slaton, Texas 79364',25931,31834);
INSERT INTO "django_geo_db_zipcode" VALUES(35690,79366,-6,'Ransom Canyon, Texas 79366',25932,31835);
INSERT INTO "django_geo_db_zipcode" VALUES(35691,79367,-6,'Smyer, Texas 79367',25933,31836);
INSERT INTO "django_geo_db_zipcode" VALUES(35692,79368,-6,'Seminole, Texas 79368',25929,31837);
INSERT INTO "django_geo_db_zipcode" VALUES(35693,79369,-6,'Spade, Texas 79369',25934,31838);
INSERT INTO "django_geo_db_zipcode" VALUES(35694,79370,-6,'Spur, Texas 79370',25935,31839);
INSERT INTO "django_geo_db_zipcode" VALUES(35695,79371,-6,'Sudan, Texas 79371',25904,31840);
INSERT INTO "django_geo_db_zipcode" VALUES(35696,79372,-6,'Sundown, Texas 79372',25936,31841);
INSERT INTO "django_geo_db_zipcode" VALUES(35697,79373,-6,'Tahoka, Texas 79373',25937,31842);
INSERT INTO "django_geo_db_zipcode" VALUES(35698,79376,-6,'Tokio, Texas 79376',25938,31843);
INSERT INTO "django_geo_db_zipcode" VALUES(35699,79377,-6,'Welch, Texas 79377',25939,31844);
INSERT INTO "django_geo_db_zipcode" VALUES(35700,79378,-6,'Wellman, Texas 79378',25940,31845);
INSERT INTO "django_geo_db_zipcode" VALUES(35701,79379,-6,'Whiteface, Texas 79379',25941,31846);
INSERT INTO "django_geo_db_zipcode" VALUES(35702,79380,-6,'Whitharral, Texas 79380',25942,31847);
INSERT INTO "django_geo_db_zipcode" VALUES(35703,79381,-6,'Wilson, Texas 79381',25943,31848);
INSERT INTO "django_geo_db_zipcode" VALUES(35704,79382,-6,'Wolfforth, Texas 79382',25944,31849);
INSERT INTO "django_geo_db_zipcode" VALUES(35705,79383,-6,'New Home, Texas 79383',25945,31850);
INSERT INTO "django_geo_db_zipcode" VALUES(35706,79401,-6,'Lubbock, Texas 79401',25946,31851);
INSERT INTO "django_geo_db_zipcode" VALUES(35707,79402,-6,'Lubbock, Texas 79402',25946,31852);
INSERT INTO "django_geo_db_zipcode" VALUES(35708,79403,-6,'Lubbock, Texas 79403',25946,31853);
INSERT INTO "django_geo_db_zipcode" VALUES(35709,79404,-6,'Lubbock, Texas 79404',25946,31854);
INSERT INTO "django_geo_db_zipcode" VALUES(35710,79405,-6,'Lubbock, Texas 79405',25946,31855);
INSERT INTO "django_geo_db_zipcode" VALUES(35711,79406,-6,'Lubbock, Texas 79406',25946,31856);
INSERT INTO "django_geo_db_zipcode" VALUES(35712,79407,-6,'Lubbock, Texas 79407',25946,31857);
INSERT INTO "django_geo_db_zipcode" VALUES(35713,79408,-6,'Lubbock, Texas 79408',25946,31858);
INSERT INTO "django_geo_db_zipcode" VALUES(35714,79409,-6,'Lubbock, Texas 79409',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35715,79410,-6,'Lubbock, Texas 79410',25946,31860);
INSERT INTO "django_geo_db_zipcode" VALUES(35716,79411,-6,'Lubbock, Texas 79411',25946,31861);
INSERT INTO "django_geo_db_zipcode" VALUES(35717,79412,-6,'Lubbock, Texas 79412',25946,31862);
INSERT INTO "django_geo_db_zipcode" VALUES(35718,79413,-6,'Lubbock, Texas 79413',25946,31863);
INSERT INTO "django_geo_db_zipcode" VALUES(35719,79414,-6,'Lubbock, Texas 79414',25946,31864);
INSERT INTO "django_geo_db_zipcode" VALUES(35720,79415,-6,'Lubbock, Texas 79415',25946,31865);
INSERT INTO "django_geo_db_zipcode" VALUES(35721,79416,-6,'Lubbock, Texas 79416',25946,31866);
INSERT INTO "django_geo_db_zipcode" VALUES(35722,79423,-6,'Lubbock, Texas 79423',25946,31867);
INSERT INTO "django_geo_db_zipcode" VALUES(35723,79424,-6,'Lubbock, Texas 79424',25946,31868);
INSERT INTO "django_geo_db_zipcode" VALUES(35724,79430,-6,'Lubbock, Texas 79430',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35725,79452,-6,'Lubbock, Texas 79452',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35726,79453,-6,'Lubbock, Texas 79453',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35727,79457,-6,'Lubbock, Texas 79457',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35728,79464,-6,'Lubbock, Texas 79464',25946,31869);
INSERT INTO "django_geo_db_zipcode" VALUES(35729,79490,-6,'Lubbock, Texas 79490',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35730,79491,-6,'Lubbock, Texas 79491',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35731,79493,-6,'Lubbock, Texas 79493',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35732,79499,-6,'Lubbock, Texas 79499',25946,31859);
INSERT INTO "django_geo_db_zipcode" VALUES(35733,79501,-6,'Anson, Texas 79501',25947,31870);
INSERT INTO "django_geo_db_zipcode" VALUES(35734,79502,-6,'Aspermont, Texas 79502',25948,31871);
INSERT INTO "django_geo_db_zipcode" VALUES(35735,79503,-6,'Avoca, Texas 79503',25949,31872);
INSERT INTO "django_geo_db_zipcode" VALUES(35736,79504,-6,'Baird, Texas 79504',25950,31873);
INSERT INTO "django_geo_db_zipcode" VALUES(35737,79505,-6,'Benjamin, Texas 79505',25951,31874);
INSERT INTO "django_geo_db_zipcode" VALUES(35738,79506,-6,'Blackwell, Texas 79506',25952,31875);
INSERT INTO "django_geo_db_zipcode" VALUES(35739,79508,-6,'Buffalo Gap, Texas 79508',25953,31876);
INSERT INTO "django_geo_db_zipcode" VALUES(35740,79510,-6,'Clyde, Texas 79510',25954,31877);
INSERT INTO "django_geo_db_zipcode" VALUES(35741,79511,-6,'Coahoma, Texas 79511',25955,31878);
INSERT INTO "django_geo_db_zipcode" VALUES(35742,79512,-6,'Colorado City, Texas 79512',25956,31879);
INSERT INTO "django_geo_db_zipcode" VALUES(35743,79516,-6,'Dunn, Texas 79516',25957,31880);
INSERT INTO "django_geo_db_zipcode" VALUES(35744,79517,-6,'Fluvanna, Texas 79517',25958,31881);
INSERT INTO "django_geo_db_zipcode" VALUES(35745,79518,-6,'Girard, Texas 79518',25959,31882);
INSERT INTO "django_geo_db_zipcode" VALUES(35746,79519,-6,'Goldsboro, Texas 79519',25960,31883);
INSERT INTO "django_geo_db_zipcode" VALUES(35747,79520,-6,'Hamlin, Texas 79520',25961,31884);
INSERT INTO "django_geo_db_zipcode" VALUES(35748,79521,-6,'Haskell, Texas 79521',25962,31885);
INSERT INTO "django_geo_db_zipcode" VALUES(35749,79525,-6,'Hawley, Texas 79525',25963,31886);
INSERT INTO "django_geo_db_zipcode" VALUES(35750,79526,-6,'Hermleigh, Texas 79526',25964,31887);
INSERT INTO "django_geo_db_zipcode" VALUES(35751,79527,-6,'Ira, Texas 79527',25965,31888);
INSERT INTO "django_geo_db_zipcode" VALUES(35752,79528,-6,'Jayton, Texas 79528',25966,31889);
INSERT INTO "django_geo_db_zipcode" VALUES(35753,79529,-6,'Knox City, Texas 79529',25967,31890);
INSERT INTO "django_geo_db_zipcode" VALUES(35754,79530,-6,'Lawn, Texas 79530',25968,31891);
INSERT INTO "django_geo_db_zipcode" VALUES(35755,79532,-6,'Loraine, Texas 79532',25969,31892);
INSERT INTO "django_geo_db_zipcode" VALUES(35756,79533,-6,'Lueders, Texas 79533',25970,31893);
INSERT INTO "django_geo_db_zipcode" VALUES(35757,79534,-6,'McCaulley, Texas 79534',25971,31894);
INSERT INTO "django_geo_db_zipcode" VALUES(35758,79535,-6,'Maryneal, Texas 79535',25972,31895);
INSERT INTO "django_geo_db_zipcode" VALUES(35759,79536,-6,'Merkel, Texas 79536',25973,31896);
INSERT INTO "django_geo_db_zipcode" VALUES(35760,79537,-6,'Nolan, Texas 79537',25974,31897);
INSERT INTO "django_geo_db_zipcode" VALUES(35761,79538,-6,'Novice, Texas 79538',25975,31898);
INSERT INTO "django_geo_db_zipcode" VALUES(35762,79539,-6,'O Brien, Texas 79539',25976,31899);
INSERT INTO "django_geo_db_zipcode" VALUES(35763,79540,-6,'Old Glory, Texas 79540',25977,31900);
INSERT INTO "django_geo_db_zipcode" VALUES(35764,79541,-6,'Ovalo, Texas 79541',25978,31901);
INSERT INTO "django_geo_db_zipcode" VALUES(35765,79543,-6,'Roby, Texas 79543',25979,31902);
INSERT INTO "django_geo_db_zipcode" VALUES(35766,79544,-6,'Rochester, Texas 79544',25980,31903);
INSERT INTO "django_geo_db_zipcode" VALUES(35767,79545,-6,'Roscoe, Texas 79545',25981,31904);
INSERT INTO "django_geo_db_zipcode" VALUES(35768,79546,-6,'Rotan, Texas 79546',25982,31905);
INSERT INTO "django_geo_db_zipcode" VALUES(35769,79547,-6,'Rule, Texas 79547',25983,31906);
INSERT INTO "django_geo_db_zipcode" VALUES(35770,79548,-6,'Rule, Texas 79548',25983,31907);
INSERT INTO "django_geo_db_zipcode" VALUES(35771,79549,-6,'Snyder, Texas 79549',25984,31908);
INSERT INTO "django_geo_db_zipcode" VALUES(35772,79550,-6,'Snyder, Texas 79550',25984,31880);
INSERT INTO "django_geo_db_zipcode" VALUES(35773,79552,-6,'Stamford, Texas 79552',25985,31909);
INSERT INTO "django_geo_db_zipcode" VALUES(35774,79553,-6,'Stamford, Texas 79553',25985,31910);
INSERT INTO "django_geo_db_zipcode" VALUES(35775,79556,-6,'Sweetwater, Texas 79556',25986,31911);
INSERT INTO "django_geo_db_zipcode" VALUES(35776,79560,-6,'Sylvester, Texas 79560',25987,31912);
INSERT INTO "django_geo_db_zipcode" VALUES(35777,79561,-6,'Trent, Texas 79561',25988,31913);
INSERT INTO "django_geo_db_zipcode" VALUES(35778,79562,-6,'Tuscola, Texas 79562',25989,31914);
INSERT INTO "django_geo_db_zipcode" VALUES(35779,79563,-6,'Tye, Texas 79563',25990,31915);
INSERT INTO "django_geo_db_zipcode" VALUES(35780,79565,-6,'Westbrook, Texas 79565',25991,31916);
INSERT INTO "django_geo_db_zipcode" VALUES(35781,79566,-6,'Wingate, Texas 79566',25992,31917);
INSERT INTO "django_geo_db_zipcode" VALUES(35782,79567,-6,'Winters, Texas 79567',25993,31918);
INSERT INTO "django_geo_db_zipcode" VALUES(35783,79571,-6,'Haskell, Texas 79571',25962,31919);
INSERT INTO "django_geo_db_zipcode" VALUES(35784,79601,-6,'Abilene, Texas 79601',25994,31920);
INSERT INTO "django_geo_db_zipcode" VALUES(35785,79602,-6,'Abilene, Texas 79602',25994,31921);
INSERT INTO "django_geo_db_zipcode" VALUES(35786,79603,-6,'Abilene, Texas 79603',25994,31922);
INSERT INTO "django_geo_db_zipcode" VALUES(35787,79604,-6,'Abilene, Texas 79604',25994,31923);
INSERT INTO "django_geo_db_zipcode" VALUES(35788,79605,-6,'Abilene, Texas 79605',25994,31924);
INSERT INTO "django_geo_db_zipcode" VALUES(35789,79606,-6,'Abilene, Texas 79606',25994,31925);
INSERT INTO "django_geo_db_zipcode" VALUES(35790,79607,-6,'Dyess AFB, Texas 79607',25995,31926);
INSERT INTO "django_geo_db_zipcode" VALUES(35791,79608,-6,'Abilene, Texas 79608',25994,31927);
INSERT INTO "django_geo_db_zipcode" VALUES(35792,79643,-6,'Ozona, Texas 79643',25214,31928);
INSERT INTO "django_geo_db_zipcode" VALUES(35793,79697,-6,'Abilene, Texas 79697',25994,31927);
INSERT INTO "django_geo_db_zipcode" VALUES(35794,79698,-6,'Abilene, Texas 79698',25994,31929);
INSERT INTO "django_geo_db_zipcode" VALUES(35795,79699,-6,'Abilene, Texas 79699',25994,31930);
INSERT INTO "django_geo_db_zipcode" VALUES(35796,79701,-6,'Midland, Texas 79701',25996,31931);
INSERT INTO "django_geo_db_zipcode" VALUES(35797,79702,-6,'Midland, Texas 79702',25996,31932);
INSERT INTO "django_geo_db_zipcode" VALUES(35798,79703,-6,'Midland, Texas 79703',25996,31933);
INSERT INTO "django_geo_db_zipcode" VALUES(35799,79704,-6,'Midland, Texas 79704',25996,31934);
INSERT INTO "django_geo_db_zipcode" VALUES(35800,79705,-6,'Midland, Texas 79705',25996,31935);
INSERT INTO "django_geo_db_zipcode" VALUES(35801,79706,-6,'Midland, Texas 79706',25996,31936);
INSERT INTO "django_geo_db_zipcode" VALUES(35802,79707,-6,'Midland, Texas 79707',25996,31937);
INSERT INTO "django_geo_db_zipcode" VALUES(35803,79708,-6,'Midland, Texas 79708',25996,31934);
INSERT INTO "django_geo_db_zipcode" VALUES(35804,79710,-6,'Midland, Texas 79710',25996,31934);
INSERT INTO "django_geo_db_zipcode" VALUES(35805,79711,-6,'Midland, Texas 79711',25996,31934);
INSERT INTO "django_geo_db_zipcode" VALUES(35806,79712,-6,'Midland, Texas 79712',25996,31934);
INSERT INTO "django_geo_db_zipcode" VALUES(35807,79713,-6,'Ackerly, Texas 79713',25997,31938);
INSERT INTO "django_geo_db_zipcode" VALUES(35808,79714,-6,'Andrews, Texas 79714',25998,31939);
INSERT INTO "django_geo_db_zipcode" VALUES(35809,79718,-6,'Balmorhea, Texas 79718',25999,31940);
INSERT INTO "django_geo_db_zipcode" VALUES(35810,79719,-6,'Barstow, Texas 79719',26000,31941);
INSERT INTO "django_geo_db_zipcode" VALUES(35811,79720,-6,'Big Spring, Texas 79720',26001,31942);
INSERT INTO "django_geo_db_zipcode" VALUES(35812,79721,-6,'Big Spring, Texas 79721',26001,31943);
INSERT INTO "django_geo_db_zipcode" VALUES(35813,79730,-6,'Coyanosa, Texas 79730',26002,31944);
INSERT INTO "django_geo_db_zipcode" VALUES(35814,79731,-6,'Crane, Texas 79731',26003,31945);
INSERT INTO "django_geo_db_zipcode" VALUES(35815,79733,-6,'Forsan, Texas 79733',26004,31946);
INSERT INTO "django_geo_db_zipcode" VALUES(35816,79734,-6,'Fort Davis, Texas 79734',26005,31947);
INSERT INTO "django_geo_db_zipcode" VALUES(35817,79735,-6,'Fort Stockton, Texas 79735',26006,31948);
INSERT INTO "django_geo_db_zipcode" VALUES(35818,79738,-6,'Gail, Texas 79738',26007,31949);
INSERT INTO "django_geo_db_zipcode" VALUES(35819,79739,-6,'Garden City, Texas 79739',26008,31950);
INSERT INTO "django_geo_db_zipcode" VALUES(35820,79740,-6,'Girvin, Texas 79740',26009,31951);
INSERT INTO "django_geo_db_zipcode" VALUES(35821,79741,-6,'Goldsmith, Texas 79741',26010,31952);
INSERT INTO "django_geo_db_zipcode" VALUES(35822,79742,-6,'Grandfalls, Texas 79742',26011,31953);
INSERT INTO "django_geo_db_zipcode" VALUES(35823,79743,-6,'Imperial, Texas 79743',26012,31954);
INSERT INTO "django_geo_db_zipcode" VALUES(35824,79744,-6,'Iraan, Texas 79744',26013,31955);
INSERT INTO "django_geo_db_zipcode" VALUES(35825,79745,-6,'Kermit, Texas 79745',26014,31956);
INSERT INTO "django_geo_db_zipcode" VALUES(35826,79748,-6,'Knott, Texas 79748',26015,31957);
INSERT INTO "django_geo_db_zipcode" VALUES(35827,79749,-6,'Lenorah, Texas 79749',26016,31958);
INSERT INTO "django_geo_db_zipcode" VALUES(35828,79752,-6,'McCamey, Texas 79752',26017,31959);
INSERT INTO "django_geo_db_zipcode" VALUES(35829,79754,-6,'Mentone, Texas 79754',26018,31960);
INSERT INTO "django_geo_db_zipcode" VALUES(35830,79755,-6,'Midkiff, Texas 79755',26019,31961);
INSERT INTO "django_geo_db_zipcode" VALUES(35831,79756,-6,'Monahans, Texas 79756',26020,31962);
INSERT INTO "django_geo_db_zipcode" VALUES(35832,79757,-6,'Wickett, Texas 79757',26021,31963);
INSERT INTO "django_geo_db_zipcode" VALUES(35833,79758,-6,'Gardendale, Texas 79758',26022,31964);
INSERT INTO "django_geo_db_zipcode" VALUES(35834,79759,-6,'Notrees, Texas 79759',26023,31965);
INSERT INTO "django_geo_db_zipcode" VALUES(35835,79760,-6,'Odessa, Texas 79760',26024,31966);
INSERT INTO "django_geo_db_zipcode" VALUES(35836,79761,-6,'Odessa, Texas 79761',26024,31967);
INSERT INTO "django_geo_db_zipcode" VALUES(35837,79762,-6,'Odessa, Texas 79762',26024,31968);
INSERT INTO "django_geo_db_zipcode" VALUES(35838,79763,-6,'Odessa, Texas 79763',26024,31969);
INSERT INTO "django_geo_db_zipcode" VALUES(35839,79764,-6,'Odessa, Texas 79764',26024,31970);
INSERT INTO "django_geo_db_zipcode" VALUES(35840,79765,-6,'Odessa, Texas 79765',26024,31971);
INSERT INTO "django_geo_db_zipcode" VALUES(35841,79766,-6,'Odessa, Texas 79766',26024,31972);
INSERT INTO "django_geo_db_zipcode" VALUES(35842,79768,-6,'Odessa, Texas 79768',26024,31973);
INSERT INTO "django_geo_db_zipcode" VALUES(35843,79769,-6,'Odessa, Texas 79769',26024,31974);
INSERT INTO "django_geo_db_zipcode" VALUES(35844,79770,-6,'Orla, Texas 79770',26025,31975);
INSERT INTO "django_geo_db_zipcode" VALUES(35845,79772,-6,'Pecos, Texas 79772',26026,31976);
INSERT INTO "django_geo_db_zipcode" VALUES(35846,79776,-6,'Penwell, Texas 79776',26027,31977);
INSERT INTO "django_geo_db_zipcode" VALUES(35847,79777,-6,'Pyote, Texas 79777',26028,31978);
INSERT INTO "django_geo_db_zipcode" VALUES(35848,79778,-6,'Rankin, Texas 79778',26029,31979);
INSERT INTO "django_geo_db_zipcode" VALUES(35849,79779,-6,'Royalty, Texas 79779',26030,31980);
INSERT INTO "django_geo_db_zipcode" VALUES(35850,79780,-6,'Saragosa, Texas 79780',26031,31981);
INSERT INTO "django_geo_db_zipcode" VALUES(35851,79781,-6,'Sheffield, Texas 79781',26032,31982);
INSERT INTO "django_geo_db_zipcode" VALUES(35852,79782,-6,'Stanton, Texas 79782',26033,31983);
INSERT INTO "django_geo_db_zipcode" VALUES(35853,79783,-6,'Tarzan, Texas 79783',26034,31984);
INSERT INTO "django_geo_db_zipcode" VALUES(35854,79785,-6,'Toyah, Texas 79785',26035,31985);
INSERT INTO "django_geo_db_zipcode" VALUES(35855,79786,-6,'Toyahvale, Texas 79786',26036,31975);
INSERT INTO "django_geo_db_zipcode" VALUES(35856,79788,-6,'Wickett, Texas 79788',26021,31986);
INSERT INTO "django_geo_db_zipcode" VALUES(35857,79789,-6,'Wink, Texas 79789',26037,31987);
INSERT INTO "django_geo_db_zipcode" VALUES(35858,79821,-7,'Anthony, Texas 79821',26038,31988);
INSERT INTO "django_geo_db_zipcode" VALUES(35859,79830,-6,'Alpine, Texas 79830',26039,31989);
INSERT INTO "django_geo_db_zipcode" VALUES(35860,79831,-6,'Alpine, Texas 79831',26039,31990);
INSERT INTO "django_geo_db_zipcode" VALUES(35861,79832,-6,'Alpine, Texas 79832',26039,31991);
INSERT INTO "django_geo_db_zipcode" VALUES(35862,79834,-6,'Big Bend National Park, Texas 79834',26040,31992);
INSERT INTO "django_geo_db_zipcode" VALUES(35863,79835,-7,'Canutillo, Texas 79835',26041,31993);
INSERT INTO "django_geo_db_zipcode" VALUES(35864,79836,-7,'Clint, Texas 79836',26042,31994);
INSERT INTO "django_geo_db_zipcode" VALUES(35865,79837,-7,'Dell City, Texas 79837',26043,31995);
INSERT INTO "django_geo_db_zipcode" VALUES(35866,79838,-7,'Fabens, Texas 79838',26044,31996);
INSERT INTO "django_geo_db_zipcode" VALUES(35867,79839,-7,'Fort Hancock, Texas 79839',26045,31997);
INSERT INTO "django_geo_db_zipcode" VALUES(35868,79841,-7,'Sierra Blanca, Texas 79841',26046,31998);
INSERT INTO "django_geo_db_zipcode" VALUES(35869,79842,-6,'Marathon, Texas 79842',26047,31999);
INSERT INTO "django_geo_db_zipcode" VALUES(35870,79843,-6,'Marfa, Texas 79843',26048,32000);
INSERT INTO "django_geo_db_zipcode" VALUES(35871,79845,-6,'Presidio, Texas 79845',26049,32001);
INSERT INTO "django_geo_db_zipcode" VALUES(35872,79846,-6,'Redford, Texas 79846',26050,32002);
INSERT INTO "django_geo_db_zipcode" VALUES(35873,79847,-7,'Salt Flat, Texas 79847',26051,32003);
INSERT INTO "django_geo_db_zipcode" VALUES(35874,79848,-6,'Sanderson, Texas 79848',26052,32004);
INSERT INTO "django_geo_db_zipcode" VALUES(35875,79849,-7,'San Elizario, Texas 79849',26053,32005);
INSERT INTO "django_geo_db_zipcode" VALUES(35876,79850,-6,'Shafter, Texas 79850',26054,32006);
INSERT INTO "django_geo_db_zipcode" VALUES(35877,79851,-7,'Sierra Blanca, Texas 79851',26046,32007);
INSERT INTO "django_geo_db_zipcode" VALUES(35878,79852,-6,'Terlingua, Texas 79852',26055,32008);
INSERT INTO "django_geo_db_zipcode" VALUES(35879,79853,-7,'Tornillo, Texas 79853',26056,32009);
INSERT INTO "django_geo_db_zipcode" VALUES(35880,79854,-6,'Valentine, Texas 79854',26057,32010);
INSERT INTO "django_geo_db_zipcode" VALUES(35881,79855,-6,'Van Horn, Texas 79855',26058,32011);
INSERT INTO "django_geo_db_zipcode" VALUES(35882,79858,-7,'Fabens, Texas 79858',26044,32012);
INSERT INTO "django_geo_db_zipcode" VALUES(35883,79870,-6,'Alpine, Texas 79870',26039,32013);
INSERT INTO "django_geo_db_zipcode" VALUES(35884,79901,-7,'El Paso, Texas 79901',26059,32014);
INSERT INTO "django_geo_db_zipcode" VALUES(35885,79902,-7,'El Paso, Texas 79902',26059,32015);
INSERT INTO "django_geo_db_zipcode" VALUES(35886,79903,-7,'El Paso, Texas 79903',26059,32016);
INSERT INTO "django_geo_db_zipcode" VALUES(35887,79904,-7,'El Paso, Texas 79904',26059,32017);
INSERT INTO "django_geo_db_zipcode" VALUES(35888,79905,-7,'El Paso, Texas 79905',26059,32018);
INSERT INTO "django_geo_db_zipcode" VALUES(35889,79906,-7,'El Paso, Texas 79906',26059,32019);
INSERT INTO "django_geo_db_zipcode" VALUES(35890,79907,-7,'El Paso, Texas 79907',26059,32020);
INSERT INTO "django_geo_db_zipcode" VALUES(35891,79908,-7,'El Paso, Texas 79908',26059,32021);
INSERT INTO "django_geo_db_zipcode" VALUES(35892,79910,-7,'El Paso, Texas 79910',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35893,79911,-7,'El Paso, Texas 79911',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35894,79912,-7,'El Paso, Texas 79912',26059,32023);
INSERT INTO "django_geo_db_zipcode" VALUES(35895,79913,-7,'El Paso, Texas 79913',26059,32024);
INSERT INTO "django_geo_db_zipcode" VALUES(35896,79914,-7,'El Paso, Texas 79914',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35897,79915,-7,'El Paso, Texas 79915',26059,32025);
INSERT INTO "django_geo_db_zipcode" VALUES(35898,79916,-7,'El Paso, Texas 79916',26059,32026);
INSERT INTO "django_geo_db_zipcode" VALUES(35899,79917,-7,'El Paso, Texas 79917',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35900,79918,-7,'El Paso, Texas 79918',26059,32027);
INSERT INTO "django_geo_db_zipcode" VALUES(35901,79920,-7,'El Paso, Texas 79920',26059,32028);
INSERT INTO "django_geo_db_zipcode" VALUES(35902,79922,-7,'El Paso, New Mexico 79922',26060,32029);
INSERT INTO "django_geo_db_zipcode" VALUES(35903,79923,-7,'El Paso, Texas 79923',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35904,79924,-7,'El Paso, Texas 79924',26059,32030);
INSERT INTO "django_geo_db_zipcode" VALUES(35905,79925,-7,'El Paso, Texas 79925',26059,32031);
INSERT INTO "django_geo_db_zipcode" VALUES(35906,79926,-7,'El Paso, Texas 79926',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35907,79927,-7,'El Paso, Texas 79927',26059,32032);
INSERT INTO "django_geo_db_zipcode" VALUES(35908,79928,-7,'El Paso, Texas 79928',26059,32033);
INSERT INTO "django_geo_db_zipcode" VALUES(35909,79929,-7,'El Paso, Texas 79929',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35910,79930,-7,'El Paso, Texas 79930',26059,32034);
INSERT INTO "django_geo_db_zipcode" VALUES(35911,79931,-7,'El Paso, Texas 79931',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35912,79932,-7,'El Paso, Texas 79932',26059,32035);
INSERT INTO "django_geo_db_zipcode" VALUES(35913,79934,-7,'El Paso, Texas 79934',26059,32036);
INSERT INTO "django_geo_db_zipcode" VALUES(35914,79935,-7,'El Paso, Texas 79935',26059,32037);
INSERT INTO "django_geo_db_zipcode" VALUES(35915,79936,-7,'El Paso, Texas 79936',26059,32038);
INSERT INTO "django_geo_db_zipcode" VALUES(35916,79937,-7,'El Paso, Texas 79937',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35917,79938,-7,'El Paso, Texas 79938',26059,32039);
INSERT INTO "django_geo_db_zipcode" VALUES(35918,79940,-7,'El Paso, Texas 79940',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35919,79941,-7,'El Paso, Texas 79941',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35920,79942,-7,'El Paso, Texas 79942',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35921,79943,-7,'El Paso, Texas 79943',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35922,79944,-7,'El Paso, Texas 79944',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35923,79945,-7,'El Paso, Texas 79945',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35924,79946,-7,'El Paso, Texas 79946',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35925,79947,-7,'El Paso, Texas 79947',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35926,79948,-7,'El Paso, Texas 79948',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35927,79949,-7,'El Paso, Texas 79949',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35928,79950,-7,'El Paso, Texas 79950',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35929,79951,-7,'El Paso, Texas 79951',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35930,79952,-7,'El Paso, Texas 79952',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35931,79953,-7,'El Paso, Texas 79953',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35932,79954,-7,'El Paso, Texas 79954',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35933,79955,-7,'El Paso, Texas 79955',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35934,79958,-7,'El Paso, Texas 79958',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35935,79960,-7,'El Paso, Texas 79960',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35936,79961,-7,'El Paso, Texas 79961',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35937,79966,-7,'El Paso, Texas 79966',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35938,79968,-7,'El Paso, Texas 79968',26059,32040);
INSERT INTO "django_geo_db_zipcode" VALUES(35939,79973,-7,'El Paso, Texas 79973',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35940,79974,-7,'El Paso, Texas 79974',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35941,79975,-7,'El Paso, Texas 79975',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35942,79976,-7,'El Paso, Texas 79976',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35943,79977,-7,'El Paso, Texas 79977',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35944,79978,-7,'El Paso, Texas 79978',26059,32041);
INSERT INTO "django_geo_db_zipcode" VALUES(35945,79980,-7,'El Paso, Texas 79980',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35946,79982,-7,'El Paso, Texas 79982',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35947,79983,-7,'El Paso, Texas 79983',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35948,79984,-7,'El Paso, Texas 79984',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35949,79985,-7,'El Paso, Texas 79985',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35950,79986,-7,'El Paso, Texas 79986',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35951,79987,-7,'El Paso, Texas 79987',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35952,79988,-7,'El Paso, Texas 79988',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35953,79989,-7,'El Paso, Texas 79989',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35954,79990,-7,'El Paso, Texas 79990',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35955,79991,-7,'El Paso, Texas 79991',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35956,79992,-7,'El Paso, Texas 79992',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35957,79993,-7,'El Paso, Texas 79993',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35958,79994,-7,'El Paso, Texas 79994',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35959,79995,-7,'El Paso, Texas 79995',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35960,79996,-7,'El Paso, Texas 79996',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35961,79997,-7,'El Paso, Texas 79997',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35962,79998,-7,'El Paso, Texas 79998',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35963,79999,-7,'El Paso, Texas 79999',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(35964,80000,-7,'Aurora, Colorado 80000',26061,32042);
INSERT INTO "django_geo_db_zipcode" VALUES(35965,80001,-7,'Arvada, Colorado 80001',26062,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(35966,80002,-7,'Arvada, Colorado 80002',26062,32044);
INSERT INTO "django_geo_db_zipcode" VALUES(35967,80003,-7,'Arvada, Colorado 80003',26062,32045);
INSERT INTO "django_geo_db_zipcode" VALUES(35968,80004,-7,'Arvada, Colorado 80004',26062,32046);
INSERT INTO "django_geo_db_zipcode" VALUES(35969,80005,-7,'Arvada, Colorado 80005',26062,32047);
INSERT INTO "django_geo_db_zipcode" VALUES(35970,80006,-7,'Arvada, Colorado 80006',26062,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(35971,80007,-7,'Arvada, Colorado 80007',26062,32048);
INSERT INTO "django_geo_db_zipcode" VALUES(35972,80010,-7,'Aurora, Colorado 80010',26061,32049);
INSERT INTO "django_geo_db_zipcode" VALUES(35973,80011,-7,'Aurora, Colorado 80011',26061,32050);
INSERT INTO "django_geo_db_zipcode" VALUES(35974,80012,-7,'Aurora, Colorado 80012',26061,32051);
INSERT INTO "django_geo_db_zipcode" VALUES(35975,80013,-7,'Aurora, Colorado 80013',26061,32052);
INSERT INTO "django_geo_db_zipcode" VALUES(35976,80014,-7,'Aurora, Colorado 80014',26061,32053);
INSERT INTO "django_geo_db_zipcode" VALUES(35977,80015,-7,'Aurora, Colorado 80015',26061,32054);
INSERT INTO "django_geo_db_zipcode" VALUES(35978,80016,-7,'Aurora, Colorado 80016',26061,32055);
INSERT INTO "django_geo_db_zipcode" VALUES(35979,80017,-7,'Aurora, Colorado 80017',26061,32056);
INSERT INTO "django_geo_db_zipcode" VALUES(35980,80018,-7,'Aurora, Colorado 80018',26061,32057);
INSERT INTO "django_geo_db_zipcode" VALUES(35981,80019,-7,'Aurora, Colorado 80019',26061,32058);
INSERT INTO "django_geo_db_zipcode" VALUES(35982,80020,-7,'Broomfield, Colorado 80020',26063,32059);
INSERT INTO "django_geo_db_zipcode" VALUES(35983,80021,-7,'Broomfield, Colorado 80021',26063,32060);
INSERT INTO "django_geo_db_zipcode" VALUES(35984,80022,-7,'Commerce City, Colorado 80022',26064,32061);
INSERT INTO "django_geo_db_zipcode" VALUES(35985,80024,-7,'Dupont, Colorado 80024',26065,32062);
INSERT INTO "django_geo_db_zipcode" VALUES(35986,80025,-7,'Eldorado Springs, Colorado 80025',26066,32063);
INSERT INTO "django_geo_db_zipcode" VALUES(35987,80026,-7,'Lafayette, Colorado 80026',26067,32064);
INSERT INTO "django_geo_db_zipcode" VALUES(35988,80027,-7,'Louisville, Colorado 80027',26068,32065);
INSERT INTO "django_geo_db_zipcode" VALUES(35989,80028,-7,'Louisville, Colorado 80028',26068,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(35990,80030,-7,'Westminster, Colorado 80030',26069,32067);
INSERT INTO "django_geo_db_zipcode" VALUES(35991,80031,-7,'Westminster, Colorado 80031',26069,32068);
INSERT INTO "django_geo_db_zipcode" VALUES(35992,80033,-7,'Wheat Ridge, Colorado 80033',26070,32069);
INSERT INTO "django_geo_db_zipcode" VALUES(35993,80034,-7,'Wheat Ridge, Colorado 80034',26070,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(35994,80035,-7,'Westminster, Colorado 80035',26069,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(35995,80036,-7,'Westminster, Colorado 80036',26069,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(35996,80037,-7,'Commerce City, Colorado 80037',26064,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(35997,80038,-7,'Broomfield, Colorado 80038',26063,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(35998,80040,-7,'Aurora, Colorado 80040',26061,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(35999,80041,-7,'Aurora, Colorado 80041',26061,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36000,80042,-7,'Aurora, Colorado 80042',26061,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(36001,80044,-7,'Aurora, Colorado 80044',26061,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36002,80045,-7,'Aurora, Colorado 80045',26061,32072);
INSERT INTO "django_geo_db_zipcode" VALUES(36003,80046,-7,'Aurora, Colorado 80046',26061,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36004,80047,-7,'Aurora, Colorado 80047',26061,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36005,80061,-7,'Westminster, Colorado 80061',26069,32073);
INSERT INTO "django_geo_db_zipcode" VALUES(36006,80101,-7,'Agate, Colorado 80101',26071,32074);
INSERT INTO "django_geo_db_zipcode" VALUES(36007,80102,-7,'Bennett, Colorado 80102',26072,32075);
INSERT INTO "django_geo_db_zipcode" VALUES(36008,80103,-7,'Byers, Colorado 80103',26073,32076);
INSERT INTO "django_geo_db_zipcode" VALUES(36009,80104,-7,'Castle Rock, Colorado 80104',26074,32077);
INSERT INTO "django_geo_db_zipcode" VALUES(36010,80105,-7,'Deer Trail, Colorado 80105',26075,32078);
INSERT INTO "django_geo_db_zipcode" VALUES(36011,80106,-7,'Elbert, Colorado 80106',26076,32079);
INSERT INTO "django_geo_db_zipcode" VALUES(36012,80107,-7,'Elizabeth, Colorado 80107',26077,32080);
INSERT INTO "django_geo_db_zipcode" VALUES(36013,80108,-7,'Castle Rock, Colorado 80108',26074,32081);
INSERT INTO "django_geo_db_zipcode" VALUES(36014,80109,-7,'Castle Rock, Colorado 80109',26074,32082);
INSERT INTO "django_geo_db_zipcode" VALUES(36015,80110,-7,'Englewood, Colorado 80110',26078,32083);
INSERT INTO "django_geo_db_zipcode" VALUES(36016,80111,-7,'Englewood, Colorado 80111',26078,32084);
INSERT INTO "django_geo_db_zipcode" VALUES(36017,80112,-7,'Englewood, Colorado 80112',26078,32085);
INSERT INTO "django_geo_db_zipcode" VALUES(36018,80115,-7,'Aurora, Colorado 80115',26061,32086);
INSERT INTO "django_geo_db_zipcode" VALUES(36019,80116,-7,'Franktown, Colorado 80116',26079,32087);
INSERT INTO "django_geo_db_zipcode" VALUES(36020,80117,-7,'Kiowa, Colorado 80117',26080,32088);
INSERT INTO "django_geo_db_zipcode" VALUES(36021,80118,-7,'Larkspur, Colorado 80118',26081,32089);
INSERT INTO "django_geo_db_zipcode" VALUES(36022,80120,-7,'Littleton, Colorado 80120',26082,32090);
INSERT INTO "django_geo_db_zipcode" VALUES(36023,80121,-7,'Littleton, Colorado 80121',26082,32091);
INSERT INTO "django_geo_db_zipcode" VALUES(36024,80122,-7,'Littleton, Colorado 80122',26082,32092);
INSERT INTO "django_geo_db_zipcode" VALUES(36025,80123,-7,'Littleton, Colorado 80123',26082,32093);
INSERT INTO "django_geo_db_zipcode" VALUES(36026,80124,-7,'Littleton, Colorado 80124',26082,32094);
INSERT INTO "django_geo_db_zipcode" VALUES(36027,80125,-7,'Littleton, Colorado 80125',26082,32095);
INSERT INTO "django_geo_db_zipcode" VALUES(36028,80126,-7,'Littleton, Colorado 80126',26082,32096);
INSERT INTO "django_geo_db_zipcode" VALUES(36029,80127,-7,'Littleton, Colorado 80127',26082,32097);
INSERT INTO "django_geo_db_zipcode" VALUES(36030,80128,-7,'Littleton, Colorado 80128',26082,32098);
INSERT INTO "django_geo_db_zipcode" VALUES(36031,80129,-7,'Littleton, Colorado 80129',26082,32099);
INSERT INTO "django_geo_db_zipcode" VALUES(36032,80130,-7,'Lone Tree, Colorado 80130',26083,32100);
INSERT INTO "django_geo_db_zipcode" VALUES(36033,80131,-7,'Louviers, Colorado 80131',26084,32101);
INSERT INTO "django_geo_db_zipcode" VALUES(36034,80132,-7,'Monument, Colorado 80132',26085,32102);
INSERT INTO "django_geo_db_zipcode" VALUES(36035,80133,-7,'Palmer Lake, Colorado 80133',26086,32103);
INSERT INTO "django_geo_db_zipcode" VALUES(36036,80134,-7,'Parker, Colorado 80134',26087,32104);
INSERT INTO "django_geo_db_zipcode" VALUES(36037,80135,-7,'Sedalia, Colorado 80135',26088,32105);
INSERT INTO "django_geo_db_zipcode" VALUES(36038,80136,-7,'Strasburg, Colorado 80136',26089,32106);
INSERT INTO "django_geo_db_zipcode" VALUES(36039,80137,-7,'Watkins, Colorado 80137',26090,32107);
INSERT INTO "django_geo_db_zipcode" VALUES(36040,80138,-7,'Parker, Colorado 80138',26087,32108);
INSERT INTO "django_geo_db_zipcode" VALUES(36041,80139,-7,'Parker, Colorado 80139',26087,32109);
INSERT INTO "django_geo_db_zipcode" VALUES(36042,80150,-7,'Englewood, Colorado 80150',26078,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36043,80151,-7,'Englewood, Colorado 80151',26078,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36044,80154,-7,'Englewood, Colorado 80154',26078,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36045,80155,-7,'Englewood, Colorado 80155',26078,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36046,80160,-7,'Littleton, Colorado 80160',26082,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36047,80161,-7,'Littleton, Colorado 80161',26082,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36048,80162,-7,'Littleton, Colorado 80162',26082,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(36049,80163,-7,'Littleton, Colorado 80163',26082,32101);
INSERT INTO "django_geo_db_zipcode" VALUES(36050,80165,-7,'Littleton, Colorado 80165',26082,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36051,80166,-7,'Littleton, Colorado 80166',26082,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36052,80201,-7,'Denver, Colorado 80201',26091,32110);
INSERT INTO "django_geo_db_zipcode" VALUES(36053,80202,-7,'Denver, Colorado 80202',26091,32111);
INSERT INTO "django_geo_db_zipcode" VALUES(36054,80203,-7,'Denver, Colorado 80203',26091,32112);
INSERT INTO "django_geo_db_zipcode" VALUES(36055,80204,-7,'Denver, Colorado 80204',26091,32113);
INSERT INTO "django_geo_db_zipcode" VALUES(36056,80205,-7,'Denver, Colorado 80205',26091,32114);
INSERT INTO "django_geo_db_zipcode" VALUES(36057,80206,-7,'Denver, Colorado 80206',26091,32115);
INSERT INTO "django_geo_db_zipcode" VALUES(36058,80207,-7,'Denver, Colorado 80207',26091,32116);
INSERT INTO "django_geo_db_zipcode" VALUES(36059,80208,-7,'Denver, Colorado 80208',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36060,80209,-7,'Denver, Colorado 80209',26091,32117);
INSERT INTO "django_geo_db_zipcode" VALUES(36061,80210,-7,'Denver, Colorado 80210',26091,32118);
INSERT INTO "django_geo_db_zipcode" VALUES(36062,80211,-7,'Denver, Colorado 80211',26091,32119);
INSERT INTO "django_geo_db_zipcode" VALUES(36063,80212,-7,'Denver, Colorado 80212',26091,32120);
INSERT INTO "django_geo_db_zipcode" VALUES(36064,80214,-7,'Denver, Colorado 80214',26091,32121);
INSERT INTO "django_geo_db_zipcode" VALUES(36065,80215,-7,'Denver, Colorado 80215',26091,32122);
INSERT INTO "django_geo_db_zipcode" VALUES(36066,80216,-7,'Denver, Colorado 80216',26091,32123);
INSERT INTO "django_geo_db_zipcode" VALUES(36067,80217,-7,'Denver, Colorado 80217',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36068,80218,-7,'Denver, Colorado 80218',26091,32124);
INSERT INTO "django_geo_db_zipcode" VALUES(36069,80219,-7,'Denver, Colorado 80219',26091,32125);
INSERT INTO "django_geo_db_zipcode" VALUES(36070,80220,-7,'Denver, Colorado 80220',26091,32126);
INSERT INTO "django_geo_db_zipcode" VALUES(36071,80221,-7,'Denver, Colorado 80221',26091,32127);
INSERT INTO "django_geo_db_zipcode" VALUES(36072,80222,-7,'Denver, Colorado 80222',26091,32128);
INSERT INTO "django_geo_db_zipcode" VALUES(36073,80223,-7,'Denver, Colorado 80223',26091,32129);
INSERT INTO "django_geo_db_zipcode" VALUES(36074,80224,-7,'Denver, Colorado 80224',26091,32130);
INSERT INTO "django_geo_db_zipcode" VALUES(36075,80225,-7,'Denver, Colorado 80225',26091,32131);
INSERT INTO "django_geo_db_zipcode" VALUES(36076,80226,-7,'Denver, Colorado 80226',26091,32132);
INSERT INTO "django_geo_db_zipcode" VALUES(36077,80227,-7,'Denver, Colorado 80227',26091,32133);
INSERT INTO "django_geo_db_zipcode" VALUES(36078,80228,-7,'Denver, Colorado 80228',26091,32134);
INSERT INTO "django_geo_db_zipcode" VALUES(36079,80229,-7,'Denver, Colorado 80229',26091,32135);
INSERT INTO "django_geo_db_zipcode" VALUES(36080,80230,-7,'Denver, Colorado 80230',26091,32136);
INSERT INTO "django_geo_db_zipcode" VALUES(36081,80231,-7,'Denver, Colorado 80231',26091,32137);
INSERT INTO "django_geo_db_zipcode" VALUES(36082,80232,-7,'Denver, Colorado 80232',26091,32138);
INSERT INTO "django_geo_db_zipcode" VALUES(36083,80233,-7,'Denver, Colorado 80233',26091,32139);
INSERT INTO "django_geo_db_zipcode" VALUES(36084,80234,-7,'Denver, Colorado 80234',26091,32140);
INSERT INTO "django_geo_db_zipcode" VALUES(36085,80235,-7,'Denver, Colorado 80235',26091,32141);
INSERT INTO "django_geo_db_zipcode" VALUES(36086,80236,-7,'Denver, Colorado 80236',26091,32142);
INSERT INTO "django_geo_db_zipcode" VALUES(36087,80237,-7,'Denver, Colorado 80237',26091,32143);
INSERT INTO "django_geo_db_zipcode" VALUES(36088,80238,-7,'Denver, Colorado 80238',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36089,80239,-7,'Denver, Colorado 80239',26091,32144);
INSERT INTO "django_geo_db_zipcode" VALUES(36090,80241,-7,'Denver, Colorado 80241',26091,32145);
INSERT INTO "django_geo_db_zipcode" VALUES(36091,80243,-7,'Denver, Colorado 80243',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36092,80244,-7,'Denver, Colorado 80244',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36093,80246,-7,'Denver, Colorado 80246',26091,32146);
INSERT INTO "django_geo_db_zipcode" VALUES(36094,80247,-7,'Denver, Colorado 80247',26091,32147);
INSERT INTO "django_geo_db_zipcode" VALUES(36095,80248,-7,'Denver, Colorado 80248',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36096,80249,-7,'Denver, Colorado 80249',26091,32148);
INSERT INTO "django_geo_db_zipcode" VALUES(36097,80250,-7,'Denver, Colorado 80250',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36098,80251,-7,'Denver, Colorado 80251',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36099,80252,-7,'Denver, Colorado 80252',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36100,80254,-7,'Denver, Colorado 80254',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36101,80255,-7,'Denver, Colorado 80255',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36102,80256,-7,'Denver, Colorado 80256',26091,32149);
INSERT INTO "django_geo_db_zipcode" VALUES(36103,80257,-7,'Denver, Colorado 80257',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36104,80259,-7,'Denver, Colorado 80259',26091,32150);
INSERT INTO "django_geo_db_zipcode" VALUES(36105,80260,-7,'Denver, Colorado 80260',26091,32151);
INSERT INTO "django_geo_db_zipcode" VALUES(36106,80261,-7,'Denver, Colorado 80261',26091,32152);
INSERT INTO "django_geo_db_zipcode" VALUES(36107,80262,-7,'Denver, Colorado 80262',26091,32153);
INSERT INTO "django_geo_db_zipcode" VALUES(36108,80263,-7,'Denver, Colorado 80263',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36109,80264,-7,'Denver, Colorado 80264',26091,32154);
INSERT INTO "django_geo_db_zipcode" VALUES(36110,80265,-7,'Denver, Colorado 80265',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36111,80266,-7,'Denver, Colorado 80266',26091,32155);
INSERT INTO "django_geo_db_zipcode" VALUES(36112,80270,-7,'Denver, Colorado 80270',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36113,80271,-7,'Denver, Colorado 80271',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36114,80273,-7,'Denver, Colorado 80273',26091,32156);
INSERT INTO "django_geo_db_zipcode" VALUES(36115,80274,-7,'Denver, Colorado 80274',26091,32157);
INSERT INTO "django_geo_db_zipcode" VALUES(36116,80275,-7,'Denver, Colorado 80275',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36117,80279,-7,'Denver, Colorado 80279',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36118,80280,-7,'Denver, Colorado 80280',26091,32158);
INSERT INTO "django_geo_db_zipcode" VALUES(36119,80281,-7,'Denver, Colorado 80281',26091,32159);
INSERT INTO "django_geo_db_zipcode" VALUES(36120,80290,-7,'Denver, Colorado 80290',26091,32160);
INSERT INTO "django_geo_db_zipcode" VALUES(36121,80291,-7,'Denver, Colorado 80291',26091,32159);
INSERT INTO "django_geo_db_zipcode" VALUES(36122,80292,-7,'Denver, Colorado 80292',26091,32149);
INSERT INTO "django_geo_db_zipcode" VALUES(36123,80293,-7,'Denver, Colorado 80293',26091,32161);
INSERT INTO "django_geo_db_zipcode" VALUES(36124,80294,-7,'Denver, Colorado 80294',26091,32162);
INSERT INTO "django_geo_db_zipcode" VALUES(36125,80295,-7,'Denver, Colorado 80295',26091,32163);
INSERT INTO "django_geo_db_zipcode" VALUES(36126,80296,-7,'Sherrelwood, Colorado 80296',26092,32164);
INSERT INTO "django_geo_db_zipcode" VALUES(36127,80299,-7,'Denver, Colorado 80299',26091,32071);
INSERT INTO "django_geo_db_zipcode" VALUES(36128,80301,-7,'Boulder, Colorado 80301',26093,32165);
INSERT INTO "django_geo_db_zipcode" VALUES(36129,80302,-7,'Boulder, Colorado 80302',26093,32166);
INSERT INTO "django_geo_db_zipcode" VALUES(36130,80303,-7,'Boulder, Colorado 80303',26093,32167);
INSERT INTO "django_geo_db_zipcode" VALUES(36131,80304,-7,'Boulder, Colorado 80304',26093,32168);
INSERT INTO "django_geo_db_zipcode" VALUES(36132,80305,-7,'Boulder, Colorado 80305',26093,32169);
INSERT INTO "django_geo_db_zipcode" VALUES(36133,80306,-7,'Boulder, Colorado 80306',26093,32170);
INSERT INTO "django_geo_db_zipcode" VALUES(36134,80307,-7,'Boulder, Colorado 80307',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36135,80308,-7,'Boulder, Colorado 80308',26093,32171);
INSERT INTO "django_geo_db_zipcode" VALUES(36136,80309,-7,'Boulder, Colorado 80309',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36137,80310,-7,'Boulder, Colorado 80310',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36138,80314,-7,'Boulder, Colorado 80314',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36139,80321,-7,'Boulder, Colorado 80321',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36140,80322,-7,'Boulder, Colorado 80322',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36141,80323,-7,'Boulder, Colorado 80323',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36142,80328,-7,'Boulder, Colorado 80328',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36143,80329,-7,'Boulder, Colorado 80329',26093,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36144,80401,-7,'Golden, Colorado 80401',26094,32172);
INSERT INTO "django_geo_db_zipcode" VALUES(36145,80402,-7,'Golden, Colorado 80402',26094,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(36146,80403,-7,'Golden, Colorado 80403',26094,32173);
INSERT INTO "django_geo_db_zipcode" VALUES(36147,80419,-7,'Golden, Colorado 80419',26094,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(36148,80420,-7,'Alma, Colorado 80420',26095,32174);
INSERT INTO "django_geo_db_zipcode" VALUES(36149,80421,-7,'Bailey, Colorado 80421',26096,32175);
INSERT INTO "django_geo_db_zipcode" VALUES(36150,80422,-7,'Black Hawk, Colorado 80422',26097,32176);
INSERT INTO "django_geo_db_zipcode" VALUES(36151,80423,-7,'Bond, Colorado 80423',26098,32177);
INSERT INTO "django_geo_db_zipcode" VALUES(36152,80424,-7,'Breckenridge, Colorado 80424',26099,32178);
INSERT INTO "django_geo_db_zipcode" VALUES(36153,80425,-7,'Buffalo Creek, Colorado 80425',26100,32179);
INSERT INTO "django_geo_db_zipcode" VALUES(36154,80426,-7,'Burns, Colorado 80426',26101,32180);
INSERT INTO "django_geo_db_zipcode" VALUES(36155,80427,-7,'Central City, Colorado 80427',26102,32181);
INSERT INTO "django_geo_db_zipcode" VALUES(36156,80428,-7,'Clark, Colorado 80428',26103,32182);
INSERT INTO "django_geo_db_zipcode" VALUES(36157,80429,-7,'Climax, Colorado 80429',26104,32183);
INSERT INTO "django_geo_db_zipcode" VALUES(36158,80430,-7,'Coalmont, Colorado 80430',26105,32184);
INSERT INTO "django_geo_db_zipcode" VALUES(36159,80432,-7,'Como, Colorado 80432',26106,32185);
INSERT INTO "django_geo_db_zipcode" VALUES(36160,80433,-7,'Conifer, Colorado 80433',26107,32186);
INSERT INTO "django_geo_db_zipcode" VALUES(36161,80434,-7,'Cowdrey, Colorado 80434',26108,32187);
INSERT INTO "django_geo_db_zipcode" VALUES(36162,80435,-7,'Dillon, Colorado 80435',26109,32188);
INSERT INTO "django_geo_db_zipcode" VALUES(36163,80436,-7,'Dumont, Colorado 80436',26110,32189);
INSERT INTO "django_geo_db_zipcode" VALUES(36164,80437,-7,'Evergreen, Colorado 80437',26111,32043);
INSERT INTO "django_geo_db_zipcode" VALUES(36165,80438,-7,'Empire, Colorado 80438',26112,32190);
INSERT INTO "django_geo_db_zipcode" VALUES(36166,80439,-7,'Evergreen, Colorado 80439',26111,32191);
INSERT INTO "django_geo_db_zipcode" VALUES(36167,80440,-7,'Fairplay, Colorado 80440',26113,32192);
INSERT INTO "django_geo_db_zipcode" VALUES(36168,80442,-7,'Fraser, Colorado 80442',26114,32193);
INSERT INTO "django_geo_db_zipcode" VALUES(36169,80443,-7,'Frisco, Colorado 80443',26115,32194);
INSERT INTO "django_geo_db_zipcode" VALUES(36170,80444,-7,'Georgetown, Colorado 80444',26116,32195);
INSERT INTO "django_geo_db_zipcode" VALUES(36171,80446,-7,'Granby, Colorado 80446',26117,32196);
INSERT INTO "django_geo_db_zipcode" VALUES(36172,80447,-7,'Grand Lake, Colorado 80447',26118,32197);
INSERT INTO "django_geo_db_zipcode" VALUES(36173,80448,-7,'Grant, Colorado 80448',26119,32198);
INSERT INTO "django_geo_db_zipcode" VALUES(36174,80449,-7,'Hartsel, Colorado 80449',26120,32199);
INSERT INTO "django_geo_db_zipcode" VALUES(36175,80451,-7,'Hot Sulphur Springs, Colorado 80451',26121,32200);
INSERT INTO "django_geo_db_zipcode" VALUES(36176,80452,-7,'Idaho Springs, Colorado 80452',26122,32201);
INSERT INTO "django_geo_db_zipcode" VALUES(36177,80453,-7,'Idledale, Colorado 80453',26123,32202);
INSERT INTO "django_geo_db_zipcode" VALUES(36178,80454,-7,'Indian Hills, Colorado 80454',26124,32203);
INSERT INTO "django_geo_db_zipcode" VALUES(36179,80455,-7,'Jamestown, Colorado 80455',26125,32204);
INSERT INTO "django_geo_db_zipcode" VALUES(36180,80456,-7,'Jefferson, Colorado 80456',26126,32205);
INSERT INTO "django_geo_db_zipcode" VALUES(36181,80457,-7,'Kittredge, Colorado 80457',26127,32206);
INSERT INTO "django_geo_db_zipcode" VALUES(36182,80459,-7,'Kremmling, Colorado 80459',26128,32207);
INSERT INTO "django_geo_db_zipcode" VALUES(36183,80461,-7,'Leadville, Colorado 80461',26129,32208);
INSERT INTO "django_geo_db_zipcode" VALUES(36184,80463,-7,'McCoy, Colorado 80463',26130,32209);
INSERT INTO "django_geo_db_zipcode" VALUES(36185,80465,-7,'Morrison, Colorado 80465',26131,32210);
INSERT INTO "django_geo_db_zipcode" VALUES(36186,80466,-7,'Nederland, Colorado 80466',26132,32211);
INSERT INTO "django_geo_db_zipcode" VALUES(36187,80467,-7,'Oak Creek, Colorado 80467',26133,32212);
INSERT INTO "django_geo_db_zipcode" VALUES(36188,80468,-7,'Parshall, Colorado 80468',26134,32213);
INSERT INTO "django_geo_db_zipcode" VALUES(36189,80469,-7,'Phippsburg, Colorado 80469',26135,32214);
INSERT INTO "django_geo_db_zipcode" VALUES(36190,80470,-7,'Pine, Colorado 80470',26136,32215);
INSERT INTO "django_geo_db_zipcode" VALUES(36191,80471,-7,'Pinecliffe, Colorado 80471',26137,32216);
INSERT INTO "django_geo_db_zipcode" VALUES(36192,80473,-7,'Rand, Colorado 80473',26138,32217);
INSERT INTO "django_geo_db_zipcode" VALUES(36193,80474,-7,'Rollinsville, Colorado 80474',26139,32218);
INSERT INTO "django_geo_db_zipcode" VALUES(36194,80475,-7,'Shawnee, Colorado 80475',26140,32219);
INSERT INTO "django_geo_db_zipcode" VALUES(36195,80476,-7,'Silver Plume, Colorado 80476',26141,32220);
INSERT INTO "django_geo_db_zipcode" VALUES(36196,80477,-7,'Steamboat Springs, Colorado 80477',26142,32221);
INSERT INTO "django_geo_db_zipcode" VALUES(36197,80478,-7,'Tabernash, Colorado 80478',26143,32222);
INSERT INTO "django_geo_db_zipcode" VALUES(36198,80479,-7,'Toponas, Colorado 80479',26144,32223);
INSERT INTO "django_geo_db_zipcode" VALUES(36199,80480,-7,'Walden, Colorado 80480',26145,32224);
INSERT INTO "django_geo_db_zipcode" VALUES(36200,80481,-7,'Ward, Colorado 80481',26146,32225);
INSERT INTO "django_geo_db_zipcode" VALUES(36201,80482,-7,'Winter Park, Colorado 80482',26147,32226);
INSERT INTO "django_geo_db_zipcode" VALUES(36202,80483,-7,'Yampa, Colorado 80483',26148,32227);
INSERT INTO "django_geo_db_zipcode" VALUES(36203,80487,-7,'Steamboat Springs, Colorado 80487',26142,32228);
INSERT INTO "django_geo_db_zipcode" VALUES(36204,80488,-7,'Steamboat Springs, Colorado 80488',26142,32229);
INSERT INTO "django_geo_db_zipcode" VALUES(36205,80497,-7,'Silverthorne, Colorado 80497',26149,32230);
INSERT INTO "django_geo_db_zipcode" VALUES(36206,80498,-7,'Silverthorne, Colorado 80498',26149,32231);
INSERT INTO "django_geo_db_zipcode" VALUES(36207,80501,-7,'Longmont, Colorado 80501',26150,32232);
INSERT INTO "django_geo_db_zipcode" VALUES(36208,80502,-7,'Longmont, Colorado 80502',26150,32066);
INSERT INTO "django_geo_db_zipcode" VALUES(36209,80503,-7,'Longmont, Colorado 80503',26150,32233);
INSERT INTO "django_geo_db_zipcode" VALUES(36210,80504,-7,'Longmont, Colorado 80504',26150,32234);
INSERT INTO "django_geo_db_zipcode" VALUES(36211,80509,-7,'Colorado Springs, Colorado 80509',26151,32235);
INSERT INTO "django_geo_db_zipcode" VALUES(36212,80510,-7,'Allenspark, Colorado 80510',26152,32236);
INSERT INTO "django_geo_db_zipcode" VALUES(36213,80511,-7,'Estes Park, Colorado 80511',26153,32237);
INSERT INTO "django_geo_db_zipcode" VALUES(36214,80512,-7,'Bellvue, Colorado 80512',26154,32238);
INSERT INTO "django_geo_db_zipcode" VALUES(36215,80513,-7,'Berthoud, Colorado 80513',26155,32239);
INSERT INTO "django_geo_db_zipcode" VALUES(36216,80514,-7,'Dacono, Colorado 80514',26156,32240);
INSERT INTO "django_geo_db_zipcode" VALUES(36217,80515,-7,'Drake, Colorado 80515',26157,32241);
INSERT INTO "django_geo_db_zipcode" VALUES(36218,80516,-7,'Erie, Colorado 80516',26158,32242);
INSERT INTO "django_geo_db_zipcode" VALUES(36219,80517,-7,'Estes Park, Colorado 80517',26153,32243);
INSERT INTO "django_geo_db_zipcode" VALUES(36220,80520,-7,'Firestone, Colorado 80520',26159,32244);
INSERT INTO "django_geo_db_zipcode" VALUES(36221,80521,-7,'Fort Collins, Colorado 80521',26160,32245);
INSERT INTO "django_geo_db_zipcode" VALUES(36222,80522,-7,'Fort Collins, Colorado 80522',26160,32246);
INSERT INTO "django_geo_db_zipcode" VALUES(36223,80523,-7,'Fort Collins, Colorado 80523',26160,32247);
INSERT INTO "django_geo_db_zipcode" VALUES(36224,80524,-7,'Fort Collins, Colorado 80524',26160,32248);
INSERT INTO "django_geo_db_zipcode" VALUES(36225,80525,-7,'Fort Collins, Colorado 80525',26160,32249);
INSERT INTO "django_geo_db_zipcode" VALUES(36226,80526,-7,'Fort Collins, Colorado 80526',26160,32250);
INSERT INTO "django_geo_db_zipcode" VALUES(36227,80527,-7,'Fort Collins, Colorado 80527',26160,32251);
INSERT INTO "django_geo_db_zipcode" VALUES(36228,80528,-7,'Fort Collins, Colorado 80528',26160,32252);
INSERT INTO "django_geo_db_zipcode" VALUES(36229,80530,-7,'Frederick, Colorado 80530',26161,32253);
INSERT INTO "django_geo_db_zipcode" VALUES(36230,80532,-7,'Glen Haven, Colorado 80532',26162,32254);
INSERT INTO "django_geo_db_zipcode" VALUES(36231,80533,-7,'Hygiene, Colorado 80533',26163,32255);
INSERT INTO "django_geo_db_zipcode" VALUES(36232,80534,-7,'Johnstown, Colorado 80534',26164,32256);
INSERT INTO "django_geo_db_zipcode" VALUES(36233,80535,-7,'Laporte, Colorado 80535',26165,32257);
INSERT INTO "django_geo_db_zipcode" VALUES(36234,80536,-7,'Livermore, Colorado 80536',26166,32258);
INSERT INTO "django_geo_db_zipcode" VALUES(36235,80537,-7,'Loveland, Colorado 80537',26167,32259);
INSERT INTO "django_geo_db_zipcode" VALUES(36236,80538,-7,'Loveland, Colorado 80538',26167,32260);
INSERT INTO "django_geo_db_zipcode" VALUES(36237,80539,-7,'Loveland, Colorado 80539',26167,32261);
INSERT INTO "django_geo_db_zipcode" VALUES(36238,80540,-7,'Lyons, Colorado 80540',26168,32262);
INSERT INTO "django_geo_db_zipcode" VALUES(36239,80541,-7,'Masonville, Colorado 80541',26169,32263);
INSERT INTO "django_geo_db_zipcode" VALUES(36240,80542,-7,'Mead, Colorado 80542',26170,32264);
INSERT INTO "django_geo_db_zipcode" VALUES(36241,80543,-7,'Milliken, Colorado 80543',26171,32265);
INSERT INTO "django_geo_db_zipcode" VALUES(36242,80544,-7,'Niwot, Colorado 80544',26172,32266);
INSERT INTO "django_geo_db_zipcode" VALUES(36243,80545,-7,'Red Feather Lakes, Colorado 80545',26173,32267);
INSERT INTO "django_geo_db_zipcode" VALUES(36244,80546,-7,'Severance, Colorado 80546',26174,32268);
INSERT INTO "django_geo_db_zipcode" VALUES(36245,80547,-7,'Timnath, Colorado 80547',26175,32269);
INSERT INTO "django_geo_db_zipcode" VALUES(36246,80549,-7,'Wellington, Colorado 80549',26176,32270);
INSERT INTO "django_geo_db_zipcode" VALUES(36247,80550,-7,'Windsor, Colorado 80550',26177,32271);
INSERT INTO "django_geo_db_zipcode" VALUES(36248,80551,-7,'Windsor, Colorado 80551',26177,32272);
INSERT INTO "django_geo_db_zipcode" VALUES(36249,80553,-7,'Fort Collins, Colorado 80553',26160,32237);
INSERT INTO "django_geo_db_zipcode" VALUES(36250,80601,-7,'Brighton, Colorado 80601',26178,32273);
INSERT INTO "django_geo_db_zipcode" VALUES(36251,80602,-7,'Thornton, Colorado 80602',26179,32274);
INSERT INTO "django_geo_db_zipcode" VALUES(36252,80603,-7,'Lochbuie, Colorado 80603',26180,32275);
INSERT INTO "django_geo_db_zipcode" VALUES(36253,80610,-7,'Ault, Colorado 80610',26181,32276);
INSERT INTO "django_geo_db_zipcode" VALUES(36254,80611,-7,'Briggsdale, Colorado 80611',26182,32277);
INSERT INTO "django_geo_db_zipcode" VALUES(36255,80612,-7,'Carr, Colorado 80612',26183,32278);
INSERT INTO "django_geo_db_zipcode" VALUES(36256,80614,-7,'Eastlake, Colorado 80614',26184,32070);
INSERT INTO "django_geo_db_zipcode" VALUES(36257,80615,-7,'Eaton, Colorado 80615',26185,32279);
INSERT INTO "django_geo_db_zipcode" VALUES(36258,80620,-7,'Evans, Colorado 80620',26186,32280);
INSERT INTO "django_geo_db_zipcode" VALUES(36259,80621,-7,'Fort Lupton, Colorado 80621',26187,32281);
INSERT INTO "django_geo_db_zipcode" VALUES(36260,80622,-7,'Galeton, Colorado 80622',26188,32282);
INSERT INTO "django_geo_db_zipcode" VALUES(36261,80623,-7,'Gilcrest, Colorado 80623',26189,32283);
INSERT INTO "django_geo_db_zipcode" VALUES(36262,80624,-7,'Gill, Colorado 80624',26190,32284);
INSERT INTO "django_geo_db_zipcode" VALUES(36263,80630,-7,'Greeley, Colorado 80630',26191,32285);
INSERT INTO "django_geo_db_zipcode" VALUES(36264,80631,-7,'Greeley, Colorado 80631',26191,32286);
INSERT INTO "django_geo_db_zipcode" VALUES(36265,80632,-7,'Greeley, Colorado 80632',26191,32287);
INSERT INTO "django_geo_db_zipcode" VALUES(36266,80633,-7,'Greeley, Colorado 80633',26191,32288);
INSERT INTO "django_geo_db_zipcode" VALUES(36267,80634,-7,'Greeley, Colorado 80634',26191,32289);
INSERT INTO "django_geo_db_zipcode" VALUES(36268,80638,-7,'Greeley, Colorado 80638',26191,32288);
INSERT INTO "django_geo_db_zipcode" VALUES(36269,80639,-7,'Greeley, Colorado 80639',26191,32290);
INSERT INTO "django_geo_db_zipcode" VALUES(36270,80640,-7,'Henderson, Colorado 80640',26192,32291);
INSERT INTO "django_geo_db_zipcode" VALUES(36271,80642,-7,'Hudson, Colorado 80642',26193,32292);
INSERT INTO "django_geo_db_zipcode" VALUES(36272,80643,-7,'Keenesburg, Colorado 80643',26194,32293);
INSERT INTO "django_geo_db_zipcode" VALUES(36273,80644,-7,'Kersey, Colorado 80644',26195,32294);
INSERT INTO "django_geo_db_zipcode" VALUES(36274,80645,-7,'La Salle, Colorado 80645',26196,32295);
INSERT INTO "django_geo_db_zipcode" VALUES(36275,80646,-7,'Lucerne, Colorado 80646',26197,32296);
INSERT INTO "django_geo_db_zipcode" VALUES(36276,80648,-7,'Nunn, Colorado 80648',26198,32297);
INSERT INTO "django_geo_db_zipcode" VALUES(36277,80649,-7,'Orchard, Colorado 80649',26199,32298);
INSERT INTO "django_geo_db_zipcode" VALUES(36278,80650,-7,'Pierce, Colorado 80650',26200,32299);
INSERT INTO "django_geo_db_zipcode" VALUES(36279,80651,-7,'Platteville, Colorado 80651',26201,32300);
INSERT INTO "django_geo_db_zipcode" VALUES(36280,80652,-7,'Roggen, Colorado 80652',26202,32301);
INSERT INTO "django_geo_db_zipcode" VALUES(36281,80653,-7,'Weldona, Colorado 80653',26203,32302);
INSERT INTO "django_geo_db_zipcode" VALUES(36282,80654,-7,'Wiggins, Colorado 80654',26204,32303);
INSERT INTO "django_geo_db_zipcode" VALUES(36283,80701,-7,'Fort Morgan, Colorado 80701',26205,32304);
INSERT INTO "django_geo_db_zipcode" VALUES(36284,80705,-7,'Log Lane Village, Colorado 80705',26206,32305);
INSERT INTO "django_geo_db_zipcode" VALUES(36285,80720,-7,'Akron, Colorado 80720',26207,32306);
INSERT INTO "django_geo_db_zipcode" VALUES(36286,80721,-7,'Amherst, Colorado 80721',26208,32307);
INSERT INTO "django_geo_db_zipcode" VALUES(36287,80722,-7,'Atwood, Colorado 80722',26209,32308);
INSERT INTO "django_geo_db_zipcode" VALUES(36288,80723,-7,'Brush, Colorado 80723',26210,32309);
INSERT INTO "django_geo_db_zipcode" VALUES(36289,80726,-7,'Crook, Colorado 80726',26211,32310);
INSERT INTO "django_geo_db_zipcode" VALUES(36290,80727,-7,'Eckley, Colorado 80727',26212,32311);
INSERT INTO "django_geo_db_zipcode" VALUES(36291,80728,-7,'Fleming, Colorado 80728',26213,32312);
INSERT INTO "django_geo_db_zipcode" VALUES(36292,80729,-7,'Grover, Colorado 80729',26214,32313);
INSERT INTO "django_geo_db_zipcode" VALUES(36293,80731,-7,'Haxtun, Colorado 80731',26215,32314);
INSERT INTO "django_geo_db_zipcode" VALUES(36294,80732,-7,'Hereford, Colorado 80732',26216,32315);
INSERT INTO "django_geo_db_zipcode" VALUES(36295,80733,-7,'Hillrose, Colorado 80733',26217,32316);
INSERT INTO "django_geo_db_zipcode" VALUES(36296,80734,-7,'Holyoke, Colorado 80734',26218,32317);
INSERT INTO "django_geo_db_zipcode" VALUES(36297,80735,-7,'Idalia, Colorado 80735',26219,32318);
INSERT INTO "django_geo_db_zipcode" VALUES(36298,80736,-7,'Iliff, Colorado 80736',26220,32319);
INSERT INTO "django_geo_db_zipcode" VALUES(36299,80737,-7,'Julesburg, Colorado 80737',26221,32320);
INSERT INTO "django_geo_db_zipcode" VALUES(36300,80740,-7,'Lindon, Colorado 80740',26222,32321);
INSERT INTO "django_geo_db_zipcode" VALUES(36301,80741,-7,'Merino, Colorado 80741',26223,32322);
INSERT INTO "django_geo_db_zipcode" VALUES(36302,80742,-7,'New Raymer, Colorado 80742',26224,32323);
INSERT INTO "django_geo_db_zipcode" VALUES(36303,80743,-7,'Otis, Colorado 80743',26225,32324);
INSERT INTO "django_geo_db_zipcode" VALUES(36304,80744,-7,'Ovid, Colorado 80744',26226,32325);
INSERT INTO "django_geo_db_zipcode" VALUES(36305,80745,-7,'Padroni, Colorado 80745',26227,32326);
INSERT INTO "django_geo_db_zipcode" VALUES(36306,80746,-7,'Paoli, Colorado 80746',26228,32327);
INSERT INTO "django_geo_db_zipcode" VALUES(36307,80747,-7,'Peetz, Colorado 80747',26229,32328);
INSERT INTO "django_geo_db_zipcode" VALUES(36308,80749,-7,'Sedgwick, Colorado 80749',26230,32329);
INSERT INTO "django_geo_db_zipcode" VALUES(36309,80750,-7,'Snyder, Colorado 80750',26231,32330);
INSERT INTO "django_geo_db_zipcode" VALUES(36310,80751,-7,'Sterling, Colorado 80751',26232,32331);
INSERT INTO "django_geo_db_zipcode" VALUES(36311,80754,-7,'Stoneham, Colorado 80754',26233,32332);
INSERT INTO "django_geo_db_zipcode" VALUES(36312,80755,-7,'Vernon, Colorado 80755',26234,32333);
INSERT INTO "django_geo_db_zipcode" VALUES(36313,80757,-7,'Woodrow, Colorado 80757',26235,32334);
INSERT INTO "django_geo_db_zipcode" VALUES(36314,80758,-7,'Wray, Colorado 80758',26236,32335);
INSERT INTO "django_geo_db_zipcode" VALUES(36315,80759,-7,'Yuma, Colorado 80759',26237,32336);
INSERT INTO "django_geo_db_zipcode" VALUES(36316,80801,-7,'Anton, Colorado 80801',26238,32337);
INSERT INTO "django_geo_db_zipcode" VALUES(36317,80802,-7,'Arapahoe, Colorado 80802',26239,32338);
INSERT INTO "django_geo_db_zipcode" VALUES(36318,80804,-7,'Arriba, Colorado 80804',26240,32339);
INSERT INTO "django_geo_db_zipcode" VALUES(36319,80805,-7,'Bethune, Colorado 80805',26241,32340);
INSERT INTO "django_geo_db_zipcode" VALUES(36320,80807,-7,'Burlington, Colorado 80807',26242,32341);
INSERT INTO "django_geo_db_zipcode" VALUES(36321,80808,-7,'Calhan, Colorado 80808',26243,32342);
INSERT INTO "django_geo_db_zipcode" VALUES(36322,80809,-7,'Cascade, Colorado 80809',26244,32343);
INSERT INTO "django_geo_db_zipcode" VALUES(36323,80810,-7,'Cheyenne Wells, Colorado 80810',26245,32344);
INSERT INTO "django_geo_db_zipcode" VALUES(36324,80812,-7,'Cope, Colorado 80812',26246,32345);
INSERT INTO "django_geo_db_zipcode" VALUES(36325,80813,-7,'Cripple Creek, Colorado 80813',26247,32346);
INSERT INTO "django_geo_db_zipcode" VALUES(36326,80814,-7,'Divide, Colorado 80814',26248,32347);
INSERT INTO "django_geo_db_zipcode" VALUES(36327,80815,-7,'Flagler, Colorado 80815',26249,32348);
INSERT INTO "django_geo_db_zipcode" VALUES(36328,80816,-7,'Florissant, Colorado 80816',26250,32349);
INSERT INTO "django_geo_db_zipcode" VALUES(36329,80817,-7,'Fountain, Colorado 80817',26251,32350);
INSERT INTO "django_geo_db_zipcode" VALUES(36330,80818,-7,'Genoa, Colorado 80818',26252,32351);
INSERT INTO "django_geo_db_zipcode" VALUES(36331,80819,-7,'Green Mountain Falls, Colorado 80819',26253,32352);
INSERT INTO "django_geo_db_zipcode" VALUES(36332,80820,-7,'Guffey, Colorado 80820',26254,32353);
INSERT INTO "django_geo_db_zipcode" VALUES(36333,80821,-7,'Hugo, Colorado 80821',26255,32354);
INSERT INTO "django_geo_db_zipcode" VALUES(36334,80822,-7,'Joes, Colorado 80822',26256,32355);
INSERT INTO "django_geo_db_zipcode" VALUES(36335,80823,-7,'Karval, Colorado 80823',26257,32356);
INSERT INTO "django_geo_db_zipcode" VALUES(36336,80824,-7,'Kirk, Colorado 80824',26258,32357);
INSERT INTO "django_geo_db_zipcode" VALUES(36337,80825,-7,'Kit Carson, Colorado 80825',26259,32358);
INSERT INTO "django_geo_db_zipcode" VALUES(36338,80826,-7,'Limon, Colorado 80826',26260,32359);
INSERT INTO "django_geo_db_zipcode" VALUES(36339,80827,-7,'Lake George, Colorado 80827',26261,32360);
INSERT INTO "django_geo_db_zipcode" VALUES(36340,80828,-7,'Limon, Colorado 80828',26260,32361);
INSERT INTO "django_geo_db_zipcode" VALUES(36341,80829,-7,'Manitou Springs, Colorado 80829',26262,32362);
INSERT INTO "django_geo_db_zipcode" VALUES(36342,80830,-7,'Matheson, Colorado 80830',26263,32363);
INSERT INTO "django_geo_db_zipcode" VALUES(36343,80831,-7,'Peyton, Colorado 80831',26264,32364);
INSERT INTO "django_geo_db_zipcode" VALUES(36344,80832,-7,'Ramah, Colorado 80832',26265,32365);
INSERT INTO "django_geo_db_zipcode" VALUES(36345,80833,-7,'Rush, Colorado 80833',26266,32366);
INSERT INTO "django_geo_db_zipcode" VALUES(36346,80834,-7,'Seibert, Colorado 80834',26267,32367);
INSERT INTO "django_geo_db_zipcode" VALUES(36347,80835,-7,'Simla, Colorado 80835',26268,32368);
INSERT INTO "django_geo_db_zipcode" VALUES(36348,80836,-7,'Stratton, Colorado 80836',26269,32369);
INSERT INTO "django_geo_db_zipcode" VALUES(36349,80840,-7,'U S A F Academy, Colorado 80840',26270,32370);
INSERT INTO "django_geo_db_zipcode" VALUES(36350,80841,-7,'U S A F Academy, Colorado 80841',26270,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36351,80860,-7,'Victor, Colorado 80860',26271,32372);
INSERT INTO "django_geo_db_zipcode" VALUES(36352,80861,-7,'Vona, Colorado 80861',26272,32373);
INSERT INTO "django_geo_db_zipcode" VALUES(36353,80862,-7,'Wild Horse, Colorado 80862',26273,32374);
INSERT INTO "django_geo_db_zipcode" VALUES(36354,80863,-7,'Woodland Park, Colorado 80863',26274,32375);
INSERT INTO "django_geo_db_zipcode" VALUES(36355,80864,-7,'Yoder, Colorado 80864',26275,32376);
INSERT INTO "django_geo_db_zipcode" VALUES(36356,80866,-7,'Woodland Park, Colorado 80866',26274,32377);
INSERT INTO "django_geo_db_zipcode" VALUES(36357,80901,-7,'Colorado Springs, Colorado 80901',26151,32378);
INSERT INTO "django_geo_db_zipcode" VALUES(36358,80902,-7,'Colorado Springs, Colorado 80902',26151,32379);
INSERT INTO "django_geo_db_zipcode" VALUES(36359,80903,-7,'Colorado Springs, Colorado 80903',26151,32380);
INSERT INTO "django_geo_db_zipcode" VALUES(36360,80904,-7,'Colorado Springs, Colorado 80904',26151,32381);
INSERT INTO "django_geo_db_zipcode" VALUES(36361,80905,-7,'Colorado Springs, Colorado 80905',26151,32382);
INSERT INTO "django_geo_db_zipcode" VALUES(36362,80906,-7,'Colorado Springs, Colorado 80906',26151,32383);
INSERT INTO "django_geo_db_zipcode" VALUES(36363,80907,-7,'Colorado Springs, Colorado 80907',26151,32384);
INSERT INTO "django_geo_db_zipcode" VALUES(36364,80908,-7,'Colorado Springs, Colorado 80908',26151,32385);
INSERT INTO "django_geo_db_zipcode" VALUES(36365,80909,-7,'Colorado Springs, Colorado 80909',26151,32386);
INSERT INTO "django_geo_db_zipcode" VALUES(36366,80910,-7,'Colorado Springs, Colorado 80910',26151,32387);
INSERT INTO "django_geo_db_zipcode" VALUES(36367,80911,-7,'Colorado Springs, Colorado 80911',26151,32388);
INSERT INTO "django_geo_db_zipcode" VALUES(36368,80912,-7,'Colorado Springs, Colorado 80912',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36369,80913,-7,'Colorado Springs, Colorado 80913',26151,32389);
INSERT INTO "django_geo_db_zipcode" VALUES(36370,80914,-7,'Colorado Springs, Colorado 80914',26151,32390);
INSERT INTO "django_geo_db_zipcode" VALUES(36371,80915,-7,'Colorado Springs, Colorado 80915',26151,32391);
INSERT INTO "django_geo_db_zipcode" VALUES(36372,80916,-7,'Colorado Springs, Colorado 80916',26151,32392);
INSERT INTO "django_geo_db_zipcode" VALUES(36373,80917,-7,'Colorado Springs, Colorado 80917',26151,32393);
INSERT INTO "django_geo_db_zipcode" VALUES(36374,80918,-7,'Colorado Springs, Colorado 80918',26151,32394);
INSERT INTO "django_geo_db_zipcode" VALUES(36375,80919,-7,'Colorado Springs, Colorado 80919',26151,32395);
INSERT INTO "django_geo_db_zipcode" VALUES(36376,80920,-7,'Colorado Springs, Colorado 80920',26151,32396);
INSERT INTO "django_geo_db_zipcode" VALUES(36377,80921,-7,'Colorado Springs, Colorado 80921',26151,32397);
INSERT INTO "django_geo_db_zipcode" VALUES(36378,80922,-7,'Colorado Springs, Colorado 80922',26151,32398);
INSERT INTO "django_geo_db_zipcode" VALUES(36379,80924,-7,'Breckenridge, Colorado 80924',26099,32399);
INSERT INTO "django_geo_db_zipcode" VALUES(36380,80925,-7,'Colorado Springs, Colorado 80925',26151,32400);
INSERT INTO "django_geo_db_zipcode" VALUES(36381,80926,-7,'Colorado Springs, Colorado 80926',26151,32401);
INSERT INTO "django_geo_db_zipcode" VALUES(36382,80928,-7,'Colorado Springs, Colorado 80928',26151,32402);
INSERT INTO "django_geo_db_zipcode" VALUES(36383,80929,-7,'Colorado Springs, Colorado 80929',26151,32403);
INSERT INTO "django_geo_db_zipcode" VALUES(36384,80930,-7,'Colorado Springs, Colorado 80930',26151,32404);
INSERT INTO "django_geo_db_zipcode" VALUES(36385,80931,-7,'Colorado Springs, Colorado 80931',26151,32405);
INSERT INTO "django_geo_db_zipcode" VALUES(36386,80932,-7,'Colorado Springs, Colorado 80932',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36387,80933,-7,'Colorado Springs, Colorado 80933',26151,32406);
INSERT INTO "django_geo_db_zipcode" VALUES(36388,80934,-7,'Colorado Springs, Colorado 80934',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36389,80935,-7,'Colorado Springs, Colorado 80935',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36390,80936,-7,'Colorado Springs, Colorado 80936',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36391,80937,-7,'Colorado Springs, Colorado 80937',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36392,80940,-7,'Colorado Springs, Colorado 80940',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36393,80941,-7,'Colorado Springs, Colorado 80941',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36394,80942,-7,'Colorado Springs, Colorado 80942',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36395,80943,-7,'Colorado Springs, Colorado 80943',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36396,80944,-7,'Colorado Springs, Colorado 80944',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36397,80945,-7,'Colorado Springs, Colorado 80945',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36398,80946,-7,'Colorado Springs, Colorado 80946',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36399,80947,-7,'Colorado Springs, Colorado 80947',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36400,80949,-7,'Colorado Springs, Colorado 80949',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36401,80950,-7,'Colorado Springs, Colorado 80950',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36402,80960,-7,'Colorado Springs, Colorado 80960',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36403,80962,-7,'Colorado Springs, Colorado 80962',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36404,80970,-7,'Colorado Springs, Colorado 80970',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36405,80977,-7,'Colorado Springs, Colorado 80977',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36406,80995,-7,'Colorado Springs, Colorado 80995',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36407,80997,-7,'Colorado Springs, Colorado 80997',26151,32371);
INSERT INTO "django_geo_db_zipcode" VALUES(36408,81001,-7,'Pueblo, Colorado 81001',26276,32407);
INSERT INTO "django_geo_db_zipcode" VALUES(36409,81002,-7,'Pueblo, Colorado 81002',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36410,81003,-7,'Pueblo, Colorado 81003',26276,32409);
INSERT INTO "django_geo_db_zipcode" VALUES(36411,81004,-7,'Pueblo, Colorado 81004',26276,32410);
INSERT INTO "django_geo_db_zipcode" VALUES(36412,81005,-7,'Pueblo, Colorado 81005',26276,32411);
INSERT INTO "django_geo_db_zipcode" VALUES(36413,81006,-7,'Pueblo, Colorado 81006',26276,32412);
INSERT INTO "django_geo_db_zipcode" VALUES(36414,81007,-7,'Pueblo, Colorado 81007',26276,32413);
INSERT INTO "django_geo_db_zipcode" VALUES(36415,81008,-7,'Pueblo, Colorado 81008',26276,32414);
INSERT INTO "django_geo_db_zipcode" VALUES(36416,81009,-7,'Pueblo, Colorado 81009',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36417,81010,-7,'Pueblo, Colorado 81010',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36418,81011,-7,'Pueblo, Colorado 81011',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36419,81012,-7,'Pueblo, Colorado 81012',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36420,81013,-7,'Pueblo, Colorado 81013',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36421,81014,-7,'Pueblo, Colorado 81014',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36422,81015,-7,'Pueblo, Colorado 81015',26276,32408);
INSERT INTO "django_geo_db_zipcode" VALUES(36423,81019,-7,'Colorado City, Colorado 81019',26277,32415);
INSERT INTO "django_geo_db_zipcode" VALUES(36424,81020,-7,'Aguilar, Colorado 81020',26278,32416);
INSERT INTO "django_geo_db_zipcode" VALUES(36425,81021,-7,'Arlington, Colorado 81021',26279,32417);
INSERT INTO "django_geo_db_zipcode" VALUES(36426,81022,-7,'Avondale, Colorado 81022',26280,32418);
INSERT INTO "django_geo_db_zipcode" VALUES(36427,81023,-7,'Beulah, Colorado 81023',26281,32419);
INSERT INTO "django_geo_db_zipcode" VALUES(36428,81024,-7,'Boncarbo, Colorado 81024',26282,32420);
INSERT INTO "django_geo_db_zipcode" VALUES(36429,81025,-7,'Boone, Colorado 81025',26283,32421);
INSERT INTO "django_geo_db_zipcode" VALUES(36430,81027,-7,'Branson, Colorado 81027',26284,32422);
INSERT INTO "django_geo_db_zipcode" VALUES(36431,81029,-7,'Campo, Colorado 81029',26285,32423);
INSERT INTO "django_geo_db_zipcode" VALUES(36432,81030,-7,'Cheraw, Colorado 81030',26286,32424);
INSERT INTO "django_geo_db_zipcode" VALUES(36433,81033,-7,'Crowley, Colorado 81033',26287,32425);
INSERT INTO "django_geo_db_zipcode" VALUES(36434,81034,-7,'Crowley, Colorado 81034',26287,32426);
INSERT INTO "django_geo_db_zipcode" VALUES(36435,81036,-7,'Eads, Colorado 81036',26288,32427);
INSERT INTO "django_geo_db_zipcode" VALUES(36436,81038,-7,'Fort Lyon, Colorado 81038',26289,32428);
INSERT INTO "django_geo_db_zipcode" VALUES(36437,81039,-7,'Fowler, Colorado 81039',26290,32429);
INSERT INTO "django_geo_db_zipcode" VALUES(36438,81040,-7,'Gardner, Colorado 81040',26291,32430);
INSERT INTO "django_geo_db_zipcode" VALUES(36439,81041,-7,'Granada, Colorado 81041',26292,32431);
INSERT INTO "django_geo_db_zipcode" VALUES(36440,81042,-7,'Gulnare, Colorado 81042',26293,32432);
INSERT INTO "django_geo_db_zipcode" VALUES(36441,81043,-7,'Hartman, Colorado 81043',26294,32433);
INSERT INTO "django_geo_db_zipcode" VALUES(36442,81044,-7,'Hasty, Colorado 81044',26295,32434);
INSERT INTO "django_geo_db_zipcode" VALUES(36443,81045,-7,'Haswell, Colorado 81045',26296,32435);
INSERT INTO "django_geo_db_zipcode" VALUES(36444,81046,-7,'Hoehne, Colorado 81046',26297,32436);
INSERT INTO "django_geo_db_zipcode" VALUES(36445,81047,-7,'Holly, Colorado 81047',26298,32437);
INSERT INTO "django_geo_db_zipcode" VALUES(36446,81049,-7,'Kim, Colorado 81049',26299,32438);
INSERT INTO "django_geo_db_zipcode" VALUES(36447,81050,-7,'La Junta, Colorado 81050',26300,32439);
INSERT INTO "django_geo_db_zipcode" VALUES(36448,81052,-7,'Lamar, Colorado 81052',26301,32440);
INSERT INTO "django_geo_db_zipcode" VALUES(36449,81054,-7,'Las Animas, Colorado 81054',26302,32441);
INSERT INTO "django_geo_db_zipcode" VALUES(36450,81055,-7,'La Veta, Colorado 81055',26303,32442);
INSERT INTO "django_geo_db_zipcode" VALUES(36451,81057,-7,'McClave, Colorado 81057',26304,32443);
INSERT INTO "django_geo_db_zipcode" VALUES(36452,81058,-7,'Manzanola, Colorado 81058',26305,32444);
INSERT INTO "django_geo_db_zipcode" VALUES(36453,81059,-7,'Model, Colorado 81059',26306,32445);
INSERT INTO "django_geo_db_zipcode" VALUES(36454,81062,-7,'Olney Springs, Colorado 81062',26307,32446);
INSERT INTO "django_geo_db_zipcode" VALUES(36455,81063,-7,'Ordway, Colorado 81063',26308,32447);
INSERT INTO "django_geo_db_zipcode" VALUES(36456,81064,-7,'Pritchett, Colorado 81064',26309,32448);
INSERT INTO "django_geo_db_zipcode" VALUES(36457,81066,-7,'Red Wing, Colorado 81066',26310,32449);
INSERT INTO "django_geo_db_zipcode" VALUES(36458,81067,-7,'Rocky Ford, Colorado 81067',26311,32450);
INSERT INTO "django_geo_db_zipcode" VALUES(36459,81069,-7,'Rye, Colorado 81069',26312,32451);
INSERT INTO "django_geo_db_zipcode" VALUES(36460,81071,-7,'Sheridan Lake, Colorado 81071',26313,32452);
INSERT INTO "django_geo_db_zipcode" VALUES(36461,81073,-7,'Springfield, Colorado 81073',26314,32453);
INSERT INTO "django_geo_db_zipcode" VALUES(36462,81074,-7,'Starkville, Colorado 81074',26315,32454);
INSERT INTO "django_geo_db_zipcode" VALUES(36463,81076,-7,'Sugar City, Colorado 81076',26316,32455);
INSERT INTO "django_geo_db_zipcode" VALUES(36464,81077,-7,'Swink, Colorado 81077',26317,32456);
INSERT INTO "django_geo_db_zipcode" VALUES(36465,81079,-7,'Colorado City, Colorado 81079',26277,32457);
INSERT INTO "django_geo_db_zipcode" VALUES(36466,81081,-7,'Trinchera, Colorado 81081',26318,32458);
INSERT INTO "django_geo_db_zipcode" VALUES(36467,81082,-7,'Trinidad, Colorado 81082',26319,32459);
INSERT INTO "django_geo_db_zipcode" VALUES(36468,81084,-7,'Two Buttes, Colorado 81084',26320,32460);
INSERT INTO "django_geo_db_zipcode" VALUES(36469,81087,-7,'Vilas, Colorado 81087',26321,32461);
INSERT INTO "django_geo_db_zipcode" VALUES(36470,81089,-7,'Walsenburg, Colorado 81089',26322,32462);
INSERT INTO "django_geo_db_zipcode" VALUES(36471,81090,-7,'Walsh, Colorado 81090',26323,32463);
INSERT INTO "django_geo_db_zipcode" VALUES(36472,81091,-7,'Weston, Colorado 81091',26324,32464);
INSERT INTO "django_geo_db_zipcode" VALUES(36473,81092,-7,'Wiley, Colorado 81092',26325,32465);
INSERT INTO "django_geo_db_zipcode" VALUES(36474,81101,-7,'Alamosa, Colorado 81101',26326,32466);
INSERT INTO "django_geo_db_zipcode" VALUES(36475,81102,-7,'Alamosa, Colorado 81102',26326,32467);
INSERT INTO "django_geo_db_zipcode" VALUES(36476,81120,-7,'Antonito, Colorado 81120',26327,32468);
INSERT INTO "django_geo_db_zipcode" VALUES(36477,81121,-7,'Arboles, Colorado 81121',26328,32469);
INSERT INTO "django_geo_db_zipcode" VALUES(36478,81122,-7,'Bayfield, Colorado 81122',26329,32470);
INSERT INTO "django_geo_db_zipcode" VALUES(36479,81123,-7,'Blanca, Colorado 81123',26330,32471);
INSERT INTO "django_geo_db_zipcode" VALUES(36480,81124,-7,'Capulin, Colorado 81124',26331,32472);
INSERT INTO "django_geo_db_zipcode" VALUES(36481,81125,-7,'Center, Colorado 81125',26332,32473);
INSERT INTO "django_geo_db_zipcode" VALUES(36482,81126,-7,'Chama, Colorado 81126',26333,32474);
INSERT INTO "django_geo_db_zipcode" VALUES(36483,81127,-7,'Chimney Rock, Colorado 81127',26334,32475);
INSERT INTO "django_geo_db_zipcode" VALUES(36484,81128,-7,'Chromo, Colorado 81128',26335,32476);
INSERT INTO "django_geo_db_zipcode" VALUES(36485,81129,-7,'Conejos, Colorado 81129',26336,32477);
INSERT INTO "django_geo_db_zipcode" VALUES(36486,81130,-7,'Creede, Colorado 81130',26337,32478);
INSERT INTO "django_geo_db_zipcode" VALUES(36487,81131,-7,'Crestone, Colorado 81131',26338,32479);
INSERT INTO "django_geo_db_zipcode" VALUES(36488,81132,-7,'Del Norte, Colorado 81132',26339,32480);
INSERT INTO "django_geo_db_zipcode" VALUES(36489,81133,-7,'Fort Garland, Colorado 81133',26340,32481);
INSERT INTO "django_geo_db_zipcode" VALUES(36490,81134,-7,'Garcia, Colorado 81134',26341,32482);
INSERT INTO "django_geo_db_zipcode" VALUES(36491,81135,-7,'Homelake, Colorado 81135',26342,32483);
INSERT INTO "django_geo_db_zipcode" VALUES(36492,81136,-7,'Hooper, Colorado 81136',26343,32484);
INSERT INTO "django_geo_db_zipcode" VALUES(36493,81137,-7,'Ignacio, Colorado 81137',26344,32485);
INSERT INTO "django_geo_db_zipcode" VALUES(36494,81138,-7,'Jaroso, Colorado 81138',26345,32486);
INSERT INTO "django_geo_db_zipcode" VALUES(36495,81140,-7,'La Jara, Colorado 81140',26346,32487);
INSERT INTO "django_geo_db_zipcode" VALUES(36496,81141,-7,'Manassa, Colorado 81141',26347,32488);
INSERT INTO "django_geo_db_zipcode" VALUES(36497,81143,-7,'Moffat, Colorado 81143',26348,32489);
INSERT INTO "django_geo_db_zipcode" VALUES(36498,81144,-7,'Monte Vista, Colorado 81144',26349,32490);
INSERT INTO "django_geo_db_zipcode" VALUES(36499,81146,-7,'Mosca, Colorado 81146',26350,32491);
INSERT INTO "django_geo_db_zipcode" VALUES(36500,81147,-7,'Pagosa Springs, Colorado 81147',26351,32492);
INSERT INTO "django_geo_db_zipcode" VALUES(36501,81148,-7,'Romeo, Colorado 81148',26352,32493);
INSERT INTO "django_geo_db_zipcode" VALUES(36502,81149,-7,'Saguache, Colorado 81149',26353,32494);
INSERT INTO "django_geo_db_zipcode" VALUES(36503,81151,-7,'Sanford, Colorado 81151',26354,32495);
INSERT INTO "django_geo_db_zipcode" VALUES(36504,81152,-7,'San Luis, Colorado 81152',26355,32496);
INSERT INTO "django_geo_db_zipcode" VALUES(36505,81153,-7,'San Pablo, Colorado 81153',26356,32497);
INSERT INTO "django_geo_db_zipcode" VALUES(36506,81154,-7,'South Fork, Colorado 81154',26357,32498);
INSERT INTO "django_geo_db_zipcode" VALUES(36507,81155,-7,'Villa Grove, Colorado 81155',26358,32499);
INSERT INTO "django_geo_db_zipcode" VALUES(36508,81157,-7,'Pagosa Springs, Colorado 81157',26351,32500);
INSERT INTO "django_geo_db_zipcode" VALUES(36509,81201,-7,'Salida, Colorado 81201',26359,32501);
INSERT INTO "django_geo_db_zipcode" VALUES(36510,81210,-7,'Almont, Colorado 81210',26360,32502);
INSERT INTO "django_geo_db_zipcode" VALUES(36511,81211,-7,'Buena Vista, Colorado 81211',26361,32503);
INSERT INTO "django_geo_db_zipcode" VALUES(36512,81212,-7,'Canon City, Colorado 81212',26362,32504);
INSERT INTO "django_geo_db_zipcode" VALUES(36513,81215,-7,'Canon City, Colorado 81215',26362,32505);
INSERT INTO "django_geo_db_zipcode" VALUES(36514,81220,-7,'Cimarron, Colorado 81220',26363,32506);
INSERT INTO "django_geo_db_zipcode" VALUES(36515,81221,-7,'Coal Creek, Colorado 81221',26364,32507);
INSERT INTO "django_geo_db_zipcode" VALUES(36516,81222,-7,'Coaldale, Colorado 81222',26365,32508);
INSERT INTO "django_geo_db_zipcode" VALUES(36517,81223,-7,'Cotopaxi, Colorado 81223',26366,32509);
INSERT INTO "django_geo_db_zipcode" VALUES(36518,81224,-7,'Crested Butte, Colorado 81224',26367,32510);
INSERT INTO "django_geo_db_zipcode" VALUES(36519,81225,-7,'Crested Butte, Colorado 81225',26367,32511);
INSERT INTO "django_geo_db_zipcode" VALUES(36520,81226,-7,'Florence, Colorado 81226',26368,32512);
INSERT INTO "django_geo_db_zipcode" VALUES(36521,81227,-7,'Monarch, Colorado 81227',26369,32513);
INSERT INTO "django_geo_db_zipcode" VALUES(36522,81228,-7,'Granite, Colorado 81228',26370,32514);
INSERT INTO "django_geo_db_zipcode" VALUES(36523,81230,-7,'Gunnison, Colorado 81230',26371,32515);
INSERT INTO "django_geo_db_zipcode" VALUES(36524,81231,-7,'Gunnison, Colorado 81231',26371,32516);
INSERT INTO "django_geo_db_zipcode" VALUES(36525,81232,-7,'Hillside, Colorado 81232',26372,32517);
INSERT INTO "django_geo_db_zipcode" VALUES(36526,81233,-7,'Howard, Colorado 81233',26373,32518);
INSERT INTO "django_geo_db_zipcode" VALUES(36527,81235,-7,'Lake City, Colorado 81235',26374,32519);
INSERT INTO "django_geo_db_zipcode" VALUES(36528,81236,-7,'Nathrop, Colorado 81236',26375,32520);
INSERT INTO "django_geo_db_zipcode" VALUES(36529,81237,-7,'Ohio City, Colorado 81237',26376,32521);
INSERT INTO "django_geo_db_zipcode" VALUES(36530,81239,-7,'Parlin, Colorado 81239',26377,32522);
INSERT INTO "django_geo_db_zipcode" VALUES(36531,81240,-7,'Penrose, Colorado 81240',26378,32523);
INSERT INTO "django_geo_db_zipcode" VALUES(36532,81241,-7,'Pitkin, Colorado 81241',26379,32524);
INSERT INTO "django_geo_db_zipcode" VALUES(36533,81242,-7,'Poncha Springs, Colorado 81242',26380,32525);
INSERT INTO "django_geo_db_zipcode" VALUES(36534,81243,-7,'Powderhorn, Colorado 81243',26381,32526);
INSERT INTO "django_geo_db_zipcode" VALUES(36535,81244,-7,'Rockvale, Colorado 81244',26382,32527);
INSERT INTO "django_geo_db_zipcode" VALUES(36536,81246,-7,'Canon City, Colorado 81246',26362,32505);
INSERT INTO "django_geo_db_zipcode" VALUES(36537,81247,-7,'Gunnison, Colorado 81247',26371,32528);
INSERT INTO "django_geo_db_zipcode" VALUES(36538,81248,-7,'Sargents, Colorado 81248',26383,32529);
INSERT INTO "django_geo_db_zipcode" VALUES(36539,81251,-7,'Twin Lakes, Colorado 81251',26384,32530);
INSERT INTO "django_geo_db_zipcode" VALUES(36540,81252,-7,'Westcliffe, Colorado 81252',26385,32531);
INSERT INTO "django_geo_db_zipcode" VALUES(36541,81253,-7,'Wetmore, Colorado 81253',26386,32532);
INSERT INTO "django_geo_db_zipcode" VALUES(36542,81260,-7,'Basalt, Colorado 81260',26387,32533);
INSERT INTO "django_geo_db_zipcode" VALUES(36543,81290,-7,'Florence, Colorado 81290',26368,32534);
INSERT INTO "django_geo_db_zipcode" VALUES(36544,81301,-7,'Durango, Colorado 81301',26388,32535);
INSERT INTO "django_geo_db_zipcode" VALUES(36545,81302,-7,'Durango, Colorado 81302',26388,32536);
INSERT INTO "django_geo_db_zipcode" VALUES(36546,81303,-7,'Durango, Colorado 81303',26388,32537);
INSERT INTO "django_geo_db_zipcode" VALUES(36547,81310,-7,'Durango, Colorado 81310',26388,32538);
INSERT INTO "django_geo_db_zipcode" VALUES(36548,81320,-7,'Cahone, Colorado 81320',26389,32539);
INSERT INTO "django_geo_db_zipcode" VALUES(36549,81321,-7,'Cortez, Colorado 81321',26390,32540);
INSERT INTO "django_geo_db_zipcode" VALUES(36550,81323,-7,'Dolores, Colorado 81323',26391,32541);
INSERT INTO "django_geo_db_zipcode" VALUES(36551,81324,-7,'Dove Creek, Colorado 81324',26392,32542);
INSERT INTO "django_geo_db_zipcode" VALUES(36552,81325,-7,'Egnar, Colorado 81325',26393,32543);
INSERT INTO "django_geo_db_zipcode" VALUES(36553,81326,-7,'Hesperus, Colorado 81326',26394,32544);
INSERT INTO "django_geo_db_zipcode" VALUES(36554,81327,-7,'Lewis, Colorado 81327',26395,32545);
INSERT INTO "django_geo_db_zipcode" VALUES(36555,81328,-7,'Mancos, Colorado 81328',26396,32546);
INSERT INTO "django_geo_db_zipcode" VALUES(36556,81329,-7,'Marvel, Colorado 81329',26397,32547);
INSERT INTO "django_geo_db_zipcode" VALUES(36557,81330,-7,'Mesa Verde National Park, Colorado 81330',26398,32548);
INSERT INTO "django_geo_db_zipcode" VALUES(36558,81331,-7,'Pleasant View, Colorado 81331',26399,32549);
INSERT INTO "django_geo_db_zipcode" VALUES(36559,81332,-7,'Rico, Colorado 81332',26400,32550);
INSERT INTO "django_geo_db_zipcode" VALUES(36560,81334,-7,'Towaoc, Colorado 81334',26401,32551);
INSERT INTO "django_geo_db_zipcode" VALUES(36561,81335,-7,'Yellow Jacket, Colorado 81335',26402,32552);
INSERT INTO "django_geo_db_zipcode" VALUES(36562,81401,-7,'Montrose, Colorado 81401',26403,32553);
INSERT INTO "django_geo_db_zipcode" VALUES(36563,81402,-7,'Montrose, Colorado 81402',26403,32554);
INSERT INTO "django_geo_db_zipcode" VALUES(36564,81410,-7,'Austin, Colorado 81410',26404,32555);
INSERT INTO "django_geo_db_zipcode" VALUES(36565,81411,-7,'Bedrock, Colorado 81411',26405,32556);
INSERT INTO "django_geo_db_zipcode" VALUES(36566,81413,-7,'Cedaredge, Colorado 81413',26406,32557);
INSERT INTO "django_geo_db_zipcode" VALUES(36567,81414,-7,'Cory, Colorado 81414',26407,32558);
INSERT INTO "django_geo_db_zipcode" VALUES(36568,81415,-7,'Crawford, Colorado 81415',26408,32559);
INSERT INTO "django_geo_db_zipcode" VALUES(36569,81416,-7,'Delta, Colorado 81416',26409,32560);
INSERT INTO "django_geo_db_zipcode" VALUES(36570,81418,-7,'Eckert, Colorado 81418',26410,32561);
INSERT INTO "django_geo_db_zipcode" VALUES(36571,81419,-7,'Hotchkiss, Colorado 81419',26411,32562);
INSERT INTO "django_geo_db_zipcode" VALUES(36572,81420,-7,'Lazear, Colorado 81420',26412,32563);
INSERT INTO "django_geo_db_zipcode" VALUES(36573,81421,-7,'Maher, Colorado 81421',26413,32564);
INSERT INTO "django_geo_db_zipcode" VALUES(36574,81422,-7,'Naturita, Colorado 81422',26414,32565);
INSERT INTO "django_geo_db_zipcode" VALUES(36575,81423,-7,'Norwood, Colorado 81423',26415,32566);
INSERT INTO "django_geo_db_zipcode" VALUES(36576,81424,-7,'Nucla, Colorado 81424',26416,32567);
INSERT INTO "django_geo_db_zipcode" VALUES(36577,81425,-7,'Olathe, Colorado 81425',26417,32568);
INSERT INTO "django_geo_db_zipcode" VALUES(36578,81426,-7,'Ophir, Colorado 81426',26418,32569);
INSERT INTO "django_geo_db_zipcode" VALUES(36579,81427,-7,'Ouray, Colorado 81427',26419,32570);
INSERT INTO "django_geo_db_zipcode" VALUES(36580,81428,-7,'Paonia, Colorado 81428',26420,32571);
INSERT INTO "django_geo_db_zipcode" VALUES(36581,81429,-7,'Paradox, Colorado 81429',26421,32572);
INSERT INTO "django_geo_db_zipcode" VALUES(36582,81430,-7,'Placerville, Colorado 81430',26422,32573);
INSERT INTO "django_geo_db_zipcode" VALUES(36583,81431,-7,'Redvale, Colorado 81431',26423,32574);
INSERT INTO "django_geo_db_zipcode" VALUES(36584,81432,-7,'Ridgway, Colorado 81432',26424,32575);
INSERT INTO "django_geo_db_zipcode" VALUES(36585,81433,-7,'Silverton, Colorado 81433',26425,32576);
INSERT INTO "django_geo_db_zipcode" VALUES(36586,81434,-7,'Somerset, Colorado 81434',26426,32577);
INSERT INTO "django_geo_db_zipcode" VALUES(36587,81435,-7,'Telluride, Colorado 81435',26427,32578);
INSERT INTO "django_geo_db_zipcode" VALUES(36588,81501,-7,'Grand Junction, Colorado 81501',26428,32579);
INSERT INTO "django_geo_db_zipcode" VALUES(36589,81502,-7,'Grand Junction, Colorado 81502',26428,32580);
INSERT INTO "django_geo_db_zipcode" VALUES(36590,81503,-7,'Grand Junction, Colorado 81503',26428,32581);
INSERT INTO "django_geo_db_zipcode" VALUES(36591,81504,-7,'Grand Junction, Colorado 81504',26428,32582);
INSERT INTO "django_geo_db_zipcode" VALUES(36592,81505,-7,'Grand Junction, Colorado 81505',26428,32583);
INSERT INTO "django_geo_db_zipcode" VALUES(36593,81506,-7,'Grand Junction, Colorado 81506',26428,32584);
INSERT INTO "django_geo_db_zipcode" VALUES(36594,81516,-7,'Snowmass Village, Colorado 81516',26429,32585);
INSERT INTO "django_geo_db_zipcode" VALUES(36595,81520,-7,'Clifton, Colorado 81520',26430,32586);
INSERT INTO "django_geo_db_zipcode" VALUES(36596,81521,-7,'Fruita, Colorado 81521',26431,32587);
INSERT INTO "django_geo_db_zipcode" VALUES(36597,81522,-7,'Gateway, Colorado 81522',26432,32588);
INSERT INTO "django_geo_db_zipcode" VALUES(36598,81523,-7,'Glade Park, Colorado 81523',26433,32589);
INSERT INTO "django_geo_db_zipcode" VALUES(36599,81524,-7,'Loma, Colorado 81524',26434,32590);
INSERT INTO "django_geo_db_zipcode" VALUES(36600,81525,-7,'Mack, Colorado 81525',26435,32591);
INSERT INTO "django_geo_db_zipcode" VALUES(36601,81526,-7,'Palisade, Colorado 81526',26436,32592);
INSERT INTO "django_geo_db_zipcode" VALUES(36602,81527,-7,'Whitewater, Colorado 81527',26437,32593);
INSERT INTO "django_geo_db_zipcode" VALUES(36603,81601,-7,'Glenwood Springs, Colorado 81601',26438,32594);
INSERT INTO "django_geo_db_zipcode" VALUES(36604,81602,-7,'Glenwood Springs, Colorado 81602',26438,32595);
INSERT INTO "django_geo_db_zipcode" VALUES(36605,81610,-7,'Dinosaur, Colorado 81610',26439,32596);
INSERT INTO "django_geo_db_zipcode" VALUES(36606,81611,-7,'Aspen, Colorado 81611',26440,32597);
INSERT INTO "django_geo_db_zipcode" VALUES(36607,81612,-7,'Aspen, Colorado 81612',26440,32598);
INSERT INTO "django_geo_db_zipcode" VALUES(36608,81613,-7,'Snowmass Village, Colorado 81613',26429,32599);
INSERT INTO "django_geo_db_zipcode" VALUES(36609,81615,-7,'Snowmass Village, Colorado 81615',26429,32600);
INSERT INTO "django_geo_db_zipcode" VALUES(36610,81620,-7,'Avon, Colorado 81620',26441,32601);
INSERT INTO "django_geo_db_zipcode" VALUES(36611,81621,-7,'Basalt, Colorado 81621',26387,32602);
INSERT INTO "django_geo_db_zipcode" VALUES(36612,81623,-7,'Carbondale, Colorado 81623',26442,32603);
INSERT INTO "django_geo_db_zipcode" VALUES(36613,81624,-7,'Collbran, Colorado 81624',26443,32604);
INSERT INTO "django_geo_db_zipcode" VALUES(36614,81625,-7,'Craig, Colorado 81625',26444,32605);
INSERT INTO "django_geo_db_zipcode" VALUES(36615,81626,-7,'Craig, Colorado 81626',26444,32606);
INSERT INTO "django_geo_db_zipcode" VALUES(36616,81628,-7,'El Jebel, Colorado 81628',26445,32607);
INSERT INTO "django_geo_db_zipcode" VALUES(36617,81630,-7,'De Beque, Colorado 81630',26446,32608);
INSERT INTO "django_geo_db_zipcode" VALUES(36618,81631,-7,'Eagle, Colorado 81631',26447,32609);
INSERT INTO "django_geo_db_zipcode" VALUES(36619,81632,-7,'Edwards, Colorado 81632',26448,32610);
INSERT INTO "django_geo_db_zipcode" VALUES(36620,81633,-7,'Dinosaur, Colorado 81633',26439,32611);
INSERT INTO "django_geo_db_zipcode" VALUES(36621,81635,-7,'Parachute, Colorado 81635',26449,32612);
INSERT INTO "django_geo_db_zipcode" VALUES(36622,81636,-7,'Battlement Mesa, Colorado 81636',26450,32613);
INSERT INTO "django_geo_db_zipcode" VALUES(36623,81637,-7,'Gypsum, Colorado 81637',26451,32614);
INSERT INTO "django_geo_db_zipcode" VALUES(36624,81638,-7,'Hamilton, Colorado 81638',26452,32615);
INSERT INTO "django_geo_db_zipcode" VALUES(36625,81639,-7,'Hayden, Colorado 81639',26453,32616);
INSERT INTO "django_geo_db_zipcode" VALUES(36626,81640,-7,'Maybell, Colorado 81640',26454,32617);
INSERT INTO "django_geo_db_zipcode" VALUES(36627,81641,-7,'Meeker, Colorado 81641',26455,32618);
INSERT INTO "django_geo_db_zipcode" VALUES(36628,81642,-7,'Meredith, Colorado 81642',26456,32619);
INSERT INTO "django_geo_db_zipcode" VALUES(36629,81643,-7,'Mesa, Colorado 81643',26457,32620);
INSERT INTO "django_geo_db_zipcode" VALUES(36630,81645,-7,'Minturn, Colorado 81645',26458,32621);
INSERT INTO "django_geo_db_zipcode" VALUES(36631,81646,-7,'Molina, Colorado 81646',26459,32622);
INSERT INTO "django_geo_db_zipcode" VALUES(36632,81647,-7,'New Castle, Colorado 81647',26460,32623);
INSERT INTO "django_geo_db_zipcode" VALUES(36633,81648,-7,'Rangely, Colorado 81648',26461,32624);
INSERT INTO "django_geo_db_zipcode" VALUES(36634,81649,-7,'Red Cliff, Colorado 81649',26462,32625);
INSERT INTO "django_geo_db_zipcode" VALUES(36635,81650,-7,'Rifle, Colorado 81650',26463,32626);
INSERT INTO "django_geo_db_zipcode" VALUES(36636,81652,-7,'Silt, Colorado 81652',26464,32627);
INSERT INTO "django_geo_db_zipcode" VALUES(36637,81653,-7,'Slater, Colorado 81653',26465,32628);
INSERT INTO "django_geo_db_zipcode" VALUES(36638,81654,-7,'Snowmass, Colorado 81654',26466,32629);
INSERT INTO "django_geo_db_zipcode" VALUES(36639,81655,-7,'Wolcott, Colorado 81655',26467,32630);
INSERT INTO "django_geo_db_zipcode" VALUES(36640,81656,-7,'Woody Creek, Colorado 81656',26468,32631);
INSERT INTO "django_geo_db_zipcode" VALUES(36641,81657,-7,'Vail, Colorado 81657',26469,32632);
INSERT INTO "django_geo_db_zipcode" VALUES(36642,81658,-7,'Vail, Colorado 81658',26469,32633);
INSERT INTO "django_geo_db_zipcode" VALUES(36643,82001,-7,'Cheyenne, Wyoming 82001',26470,32634);
INSERT INTO "django_geo_db_zipcode" VALUES(36644,82002,-7,'Cheyenne, Wyoming 82002',26470,32635);
INSERT INTO "django_geo_db_zipcode" VALUES(36645,82003,-7,'Cheyenne, Wyoming 82003',26470,32636);
INSERT INTO "django_geo_db_zipcode" VALUES(36646,82005,-7,'Fe Warren AFB, Wyoming 82005',26471,32637);
INSERT INTO "django_geo_db_zipcode" VALUES(36647,82006,-7,'Cheyenne, Wyoming 82006',26470,32635);
INSERT INTO "django_geo_db_zipcode" VALUES(36648,82007,-7,'Cheyenne, Wyoming 82007',26470,32638);
INSERT INTO "django_geo_db_zipcode" VALUES(36649,82008,-7,'Cheyenne, Wyoming 82008',26470,32635);
INSERT INTO "django_geo_db_zipcode" VALUES(36650,82009,-7,'Cheyenne, Wyoming 82009',26470,32639);
INSERT INTO "django_geo_db_zipcode" VALUES(36651,82010,-7,'Cheyenne, Wyoming 82010',26470,32635);
INSERT INTO "django_geo_db_zipcode" VALUES(36652,82050,-7,'Albin, Wyoming 82050',26472,32640);
INSERT INTO "django_geo_db_zipcode" VALUES(36653,82051,-7,'Bosler, Wyoming 82051',26473,32641);
INSERT INTO "django_geo_db_zipcode" VALUES(36654,82052,-7,'Buford, Wyoming 82052',26474,32642);
INSERT INTO "django_geo_db_zipcode" VALUES(36655,82053,-7,'Burns, Wyoming 82053',26475,32643);
INSERT INTO "django_geo_db_zipcode" VALUES(36656,82054,-7,'Carpenter, Wyoming 82054',26476,32644);
INSERT INTO "django_geo_db_zipcode" VALUES(36657,82055,-7,'Centennial, Wyoming 82055',26477,32645);
INSERT INTO "django_geo_db_zipcode" VALUES(36658,82058,-7,'Garrett, Wyoming 82058',26478,32646);
INSERT INTO "django_geo_db_zipcode" VALUES(36659,82059,-7,'Granite Canon, Wyoming 82059',26479,32647);
INSERT INTO "django_geo_db_zipcode" VALUES(36660,82060,-7,'Hillsdale, Wyoming 82060',26480,32648);
INSERT INTO "django_geo_db_zipcode" VALUES(36661,82061,-7,'Horse Creek, Wyoming 82061',26481,32649);
INSERT INTO "django_geo_db_zipcode" VALUES(36662,82063,-7,'Jelm, Colorado 82063',26482,32650);
INSERT INTO "django_geo_db_zipcode" VALUES(36663,82070,-7,'Laramie, Wyoming 82070',26483,32651);
INSERT INTO "django_geo_db_zipcode" VALUES(36664,82071,-7,'Laramie, Wyoming 82071',26483,32652);
INSERT INTO "django_geo_db_zipcode" VALUES(36665,82072,-7,'Laramie, Wyoming 82072',26483,32653);
INSERT INTO "django_geo_db_zipcode" VALUES(36666,82073,-7,'Laramie, Wyoming 82073',26483,32654);
INSERT INTO "django_geo_db_zipcode" VALUES(36667,82081,-7,'Meriden, Wyoming 82081',26484,32655);
INSERT INTO "django_geo_db_zipcode" VALUES(36668,82082,-7,'Pine Bluffs, Nebraska 82082',26485,32656);
INSERT INTO "django_geo_db_zipcode" VALUES(36669,82083,-7,'Rock River, Wyoming 82083',26486,32657);
INSERT INTO "django_geo_db_zipcode" VALUES(36670,82084,-7,'Tie Siding, Wyoming 82084',26487,32658);
INSERT INTO "django_geo_db_zipcode" VALUES(36671,82190,-7,'Yellowstone National Park, Wyoming 82190',26488,32659);
INSERT INTO "django_geo_db_zipcode" VALUES(36672,82201,-7,'Wheatland, Wyoming 82201',26489,32660);
INSERT INTO "django_geo_db_zipcode" VALUES(36673,82210,-7,'Chugwater, Wyoming 82210',26490,32661);
INSERT INTO "django_geo_db_zipcode" VALUES(36674,82212,-7,'Fort Laramie, Wyoming 82212',26491,32662);
INSERT INTO "django_geo_db_zipcode" VALUES(36675,82213,-7,'Glendo, Wyoming 82213',26492,32663);
INSERT INTO "django_geo_db_zipcode" VALUES(36676,82214,-7,'Guernsey, Wyoming 82214',26493,32664);
INSERT INTO "django_geo_db_zipcode" VALUES(36677,82215,-7,'Hartville, Wyoming 82215',26494,32665);
INSERT INTO "django_geo_db_zipcode" VALUES(36678,82217,-7,'Hawk Springs, Wyoming 82217',26495,32666);
INSERT INTO "django_geo_db_zipcode" VALUES(36679,82218,-7,'Huntley, Wyoming 82218',26496,32667);
INSERT INTO "django_geo_db_zipcode" VALUES(36680,82219,-7,'Jay Em, Wyoming 82219',26497,32668);
INSERT INTO "django_geo_db_zipcode" VALUES(36681,82221,-7,'Lagrange, Wyoming 82221',26498,32669);
INSERT INTO "django_geo_db_zipcode" VALUES(36682,82222,-7,'Lance Creek, Wyoming 82222',26499,32670);
INSERT INTO "django_geo_db_zipcode" VALUES(36683,82223,-7,'Lingle, Wyoming 82223',26500,32671);
INSERT INTO "django_geo_db_zipcode" VALUES(36684,82224,-7,'Lost Springs, Wyoming 82224',26501,32672);
INSERT INTO "django_geo_db_zipcode" VALUES(36685,82225,-7,'Lusk, Wyoming 82225',26502,32673);
INSERT INTO "django_geo_db_zipcode" VALUES(36686,82226,-7,'Lusk, Wyoming 82226',26502,32674);
INSERT INTO "django_geo_db_zipcode" VALUES(36687,82227,-7,'Manville, Wyoming 82227',26503,32675);
INSERT INTO "django_geo_db_zipcode" VALUES(36688,82229,-7,'Shawnee, Wyoming 82229',26504,32676);
INSERT INTO "django_geo_db_zipcode" VALUES(36689,82240,-7,'Torrington, Wyoming 82240',26505,32677);
INSERT INTO "django_geo_db_zipcode" VALUES(36690,82242,-7,'Van Tassell, Wyoming 82242',26506,32678);
INSERT INTO "django_geo_db_zipcode" VALUES(36691,82243,-7,'Veteran, Wyoming 82243',26507,32679);
INSERT INTO "django_geo_db_zipcode" VALUES(36692,82244,-7,'Yoder, Wyoming 82244',26508,32680);
INSERT INTO "django_geo_db_zipcode" VALUES(36693,82301,-7,'Rawlins, Wyoming 82301',26509,32681);
INSERT INTO "django_geo_db_zipcode" VALUES(36694,82310,-7,'Jeffrey City, Wyoming 82310',26510,32682);
INSERT INTO "django_geo_db_zipcode" VALUES(36695,82321,-7,'Baggs, Wyoming 82321',26511,32683);
INSERT INTO "django_geo_db_zipcode" VALUES(36696,82322,-7,'Bairoil, Wyoming 82322',26512,32684);
INSERT INTO "django_geo_db_zipcode" VALUES(36697,82323,-7,'Dixon, Wyoming 82323',26513,32685);
INSERT INTO "django_geo_db_zipcode" VALUES(36698,82324,-7,'Elk Mountain, Wyoming 82324',26514,32686);
INSERT INTO "django_geo_db_zipcode" VALUES(36699,82325,-7,'Encampment, Wyoming 82325',26515,32687);
INSERT INTO "django_geo_db_zipcode" VALUES(36700,82327,-7,'Hanna, Wyoming 82327',26516,32688);
INSERT INTO "django_geo_db_zipcode" VALUES(36701,82329,-7,'Medicine Bow, Wyoming 82329',26517,32689);
INSERT INTO "django_geo_db_zipcode" VALUES(36702,82331,-7,'Saratoga, Wyoming 82331',26518,32690);
INSERT INTO "django_geo_db_zipcode" VALUES(36703,82332,-7,'Savery, Wyoming 82332',26519,32691);
INSERT INTO "django_geo_db_zipcode" VALUES(36704,82334,-7,'Sinclair, Wyoming 82334',26520,32692);
INSERT INTO "django_geo_db_zipcode" VALUES(36705,82335,-7,'Walcott, Wyoming 82335',26521,32693);
INSERT INTO "django_geo_db_zipcode" VALUES(36706,82336,-7,'Wamsutter, Wyoming 82336',26522,32694);
INSERT INTO "django_geo_db_zipcode" VALUES(36707,82354,-7,'Sinclair, Wyoming 82354',26520,32695);
INSERT INTO "django_geo_db_zipcode" VALUES(36708,82401,-7,'Worland, Wyoming 82401',26523,32696);
INSERT INTO "django_geo_db_zipcode" VALUES(36709,82410,-7,'Basin, Wyoming 82410',26524,32697);
INSERT INTO "django_geo_db_zipcode" VALUES(36710,82411,-7,'Burlington, Wyoming 82411',26525,32698);
INSERT INTO "django_geo_db_zipcode" VALUES(36711,82412,-7,'Byron, Wyoming 82412',26526,32699);
INSERT INTO "django_geo_db_zipcode" VALUES(36712,82414,-7,'Cody, Wyoming 82414',26527,32700);
INSERT INTO "django_geo_db_zipcode" VALUES(36713,82420,-7,'Cowley, Wyoming 82420',26528,32701);
INSERT INTO "django_geo_db_zipcode" VALUES(36714,82421,-7,'Deaver, Wyoming 82421',26529,32702);
INSERT INTO "django_geo_db_zipcode" VALUES(36715,82422,-7,'Emblem, Wyoming 82422',26530,32703);
INSERT INTO "django_geo_db_zipcode" VALUES(36716,82423,-7,'Frannie, Wyoming 82423',26531,32704);
INSERT INTO "django_geo_db_zipcode" VALUES(36717,82426,-7,'Greybull, Wyoming 82426',26532,32705);
INSERT INTO "django_geo_db_zipcode" VALUES(36718,82427,-7,'Hamilton Dome, Wyoming 82427',26533,32706);
INSERT INTO "django_geo_db_zipcode" VALUES(36719,82428,-7,'Hyattville, Wyoming 82428',26534,32707);
INSERT INTO "django_geo_db_zipcode" VALUES(36720,82430,-7,'Kirby, Wyoming 82430',26535,32708);
INSERT INTO "django_geo_db_zipcode" VALUES(36721,82431,-7,'Lovell, Wyoming 82431',26536,32709);
INSERT INTO "django_geo_db_zipcode" VALUES(36722,82432,-7,'Manderson, Wyoming 82432',26537,32710);
INSERT INTO "django_geo_db_zipcode" VALUES(36723,82433,-7,'Meeteetse, Wyoming 82433',26538,32711);
INSERT INTO "django_geo_db_zipcode" VALUES(36724,82434,-7,'Otto, Wyoming 82434',26539,32712);
INSERT INTO "django_geo_db_zipcode" VALUES(36725,82435,-7,'Powell, Wyoming 82435',26540,32713);
INSERT INTO "django_geo_db_zipcode" VALUES(36726,82440,-7,'Ralston, Wyoming 82440',26541,32714);
INSERT INTO "django_geo_db_zipcode" VALUES(36727,82441,-7,'Shell, Wyoming 82441',26542,32715);
INSERT INTO "django_geo_db_zipcode" VALUES(36728,82442,-7,'Ten Sleep, Wyoming 82442',26543,32716);
INSERT INTO "django_geo_db_zipcode" VALUES(36729,82443,-7,'Thermopolis, Wyoming 82443',26544,32717);
INSERT INTO "django_geo_db_zipcode" VALUES(36730,82450,-7,'Wapiti, Wyoming 82450',26545,32718);
INSERT INTO "django_geo_db_zipcode" VALUES(36731,82501,-7,'Riverton, Wyoming 82501',26546,32719);
INSERT INTO "django_geo_db_zipcode" VALUES(36732,82504,-7,'Vista West, Wyoming 82504',26547,32720);
INSERT INTO "django_geo_db_zipcode" VALUES(36733,82510,-7,'Arapahoe, Wyoming 82510',26548,32721);
INSERT INTO "django_geo_db_zipcode" VALUES(36734,82512,-7,'Crowheart, Wyoming 82512',26549,32722);
INSERT INTO "django_geo_db_zipcode" VALUES(36735,82513,-7,'Dubois, Wyoming 82513',26550,32723);
INSERT INTO "django_geo_db_zipcode" VALUES(36736,82514,-7,'Fort Washakie, Wyoming 82514',26551,32724);
INSERT INTO "django_geo_db_zipcode" VALUES(36737,82515,-7,'Hudson, Wyoming 82515',26552,32725);
INSERT INTO "django_geo_db_zipcode" VALUES(36738,82516,-7,'Kinnear, Wyoming 82516',26553,32726);
INSERT INTO "django_geo_db_zipcode" VALUES(36739,82520,-7,'Lander, Wyoming 82520',26554,32727);
INSERT INTO "django_geo_db_zipcode" VALUES(36740,82523,-7,'Pavillion, Wyoming 82523',26555,32728);
INSERT INTO "django_geo_db_zipcode" VALUES(36741,82524,-7,'Saint Stephens, Wyoming 82524',26556,32729);
INSERT INTO "django_geo_db_zipcode" VALUES(36742,82601,-7,'Casper, Wyoming 82601',26557,32730);
INSERT INTO "django_geo_db_zipcode" VALUES(36743,82602,-7,'Casper, Wyoming 82602',26557,32731);
INSERT INTO "django_geo_db_zipcode" VALUES(36744,82604,-7,'Casper, Wyoming 82604',26557,32732);
INSERT INTO "django_geo_db_zipcode" VALUES(36745,82605,-7,'Casper, Wyoming 82605',26557,32733);
INSERT INTO "django_geo_db_zipcode" VALUES(36746,82609,-7,'Casper, Wyoming 82609',26557,32734);
INSERT INTO "django_geo_db_zipcode" VALUES(36747,82615,-7,'Shirley Basin, Wyoming 82615',26558,32735);
INSERT INTO "django_geo_db_zipcode" VALUES(36748,82620,-7,'Alcova, Wyoming 82620',26559,32736);
INSERT INTO "django_geo_db_zipcode" VALUES(36749,82630,-7,'Arminto, Wyoming 82630',26560,32733);
INSERT INTO "django_geo_db_zipcode" VALUES(36750,82631,-7,'Bill, Wyoming 82631',26561,32737);
INSERT INTO "django_geo_db_zipcode" VALUES(36751,82633,-7,'Douglas, Wyoming 82633',26562,32738);
INSERT INTO "django_geo_db_zipcode" VALUES(36752,82635,-7,'Edgerton, Wyoming 82635',26563,32739);
INSERT INTO "django_geo_db_zipcode" VALUES(36753,82636,-7,'Evansville, Wyoming 82636',26564,32740);
INSERT INTO "django_geo_db_zipcode" VALUES(36754,82637,-7,'Glenrock, Wyoming 82637',26565,32741);
INSERT INTO "django_geo_db_zipcode" VALUES(36755,82638,-7,'Hiland, Wyoming 82638',26566,32733);
INSERT INTO "django_geo_db_zipcode" VALUES(36756,82639,-7,'Kaycee, Wyoming 82639',26567,32742);
INSERT INTO "django_geo_db_zipcode" VALUES(36757,82640,-7,'Linch, Wyoming 82640',26568,32743);
INSERT INTO "django_geo_db_zipcode" VALUES(36758,82642,-7,'Lysite, Wyoming 82642',26569,32744);
INSERT INTO "django_geo_db_zipcode" VALUES(36759,82643,-7,'Midwest, Wyoming 82643',26570,32745);
INSERT INTO "django_geo_db_zipcode" VALUES(36760,82644,-7,'Mills, Wyoming 82644',26571,32746);
INSERT INTO "django_geo_db_zipcode" VALUES(36761,82646,-7,'Natrona, Wyoming 82646',26572,32733);
INSERT INTO "django_geo_db_zipcode" VALUES(36762,82648,-7,'Powder River, Wyoming 82648',26573,32733);
INSERT INTO "django_geo_db_zipcode" VALUES(36763,82649,-7,'Shoshoni, Wyoming 82649',26574,32747);
INSERT INTO "django_geo_db_zipcode" VALUES(36764,82701,-7,'Newcastle, Wyoming 82701',26575,32748);
INSERT INTO "django_geo_db_zipcode" VALUES(36765,82703,-7,'Laramie, Wyoming 82703',26483,32749);
INSERT INTO "django_geo_db_zipcode" VALUES(36766,82710,-7,'Aladdin, Wyoming 82710',26576,32750);
INSERT INTO "django_geo_db_zipcode" VALUES(36767,82711,-7,'Alva, Wyoming 82711',26577,32751);
INSERT INTO "django_geo_db_zipcode" VALUES(36768,82712,-7,'Beulah, Wyoming 82712',26578,32752);
INSERT INTO "django_geo_db_zipcode" VALUES(36769,82713,-7,'Carlile, Wyoming 82713',26579,32753);
INSERT INTO "django_geo_db_zipcode" VALUES(36770,82714,-7,'Devils Tower, Wyoming 82714',26580,32754);
INSERT INTO "django_geo_db_zipcode" VALUES(36771,82715,-7,'Four Corners, Wyoming 82715',26581,32755);
INSERT INTO "django_geo_db_zipcode" VALUES(36772,82716,-7,'Gillette, Wyoming 82716',26582,32756);
INSERT INTO "django_geo_db_zipcode" VALUES(36773,82717,-7,'Gillette, Wyoming 82717',26582,32757);
INSERT INTO "django_geo_db_zipcode" VALUES(36774,82718,-7,'Gillette, Wyoming 82718',26582,32758);
INSERT INTO "django_geo_db_zipcode" VALUES(36775,82720,-7,'Hulett, Wyoming 82720',26583,32759);
INSERT INTO "django_geo_db_zipcode" VALUES(36776,82721,-7,'Moorcroft, Wyoming 82721',26584,32760);
INSERT INTO "django_geo_db_zipcode" VALUES(36777,82723,-7,'Osage, Wyoming 82723',26585,32761);
INSERT INTO "django_geo_db_zipcode" VALUES(36778,82725,-7,'Recluse, Wyoming 82725',26586,32762);
INSERT INTO "django_geo_db_zipcode" VALUES(36779,82727,-7,'Rozet, Wyoming 82727',26587,32763);
INSERT INTO "django_geo_db_zipcode" VALUES(36780,82729,-7,'Sundance, Wyoming 82729',26588,32764);
INSERT INTO "django_geo_db_zipcode" VALUES(36781,82730,-7,'Upton, Wyoming 82730',26589,32765);
INSERT INTO "django_geo_db_zipcode" VALUES(36782,82731,-7,'Weston, Wyoming 82731',26590,32766);
INSERT INTO "django_geo_db_zipcode" VALUES(36783,82732,-7,'Wright, Wyoming 82732',26591,32767);
INSERT INTO "django_geo_db_zipcode" VALUES(36784,82779,-7,'Sundance, Wyoming 82779',26588,32768);
INSERT INTO "django_geo_db_zipcode" VALUES(36785,82801,-7,'Sheridan, Wyoming 82801',26592,32769);
INSERT INTO "django_geo_db_zipcode" VALUES(36786,82831,-7,'Arvada, Wyoming 82831',26593,32770);
INSERT INTO "django_geo_db_zipcode" VALUES(36787,82832,-7,'Banner, Wyoming 82832',26594,32771);
INSERT INTO "django_geo_db_zipcode" VALUES(36788,82833,-7,'Big Horn, Wyoming 82833',26595,32772);
INSERT INTO "django_geo_db_zipcode" VALUES(36789,82834,-7,'Buffalo, Wyoming 82834',26596,32773);
INSERT INTO "django_geo_db_zipcode" VALUES(36790,82835,-7,'Clearmont, Wyoming 82835',26597,32774);
INSERT INTO "django_geo_db_zipcode" VALUES(36791,82836,-7,'Dayton, Wyoming 82836',26598,32775);
INSERT INTO "django_geo_db_zipcode" VALUES(36792,82837,-7,'Leiter, Wyoming 82837',26599,32776);
INSERT INTO "django_geo_db_zipcode" VALUES(36793,82838,-7,'Parkman, Wyoming 82838',26600,32777);
INSERT INTO "django_geo_db_zipcode" VALUES(36794,82839,-7,'Ranchester, Wyoming 82839',26601,32778);
INSERT INTO "django_geo_db_zipcode" VALUES(36795,82840,-7,'Saddlestring, Wyoming 82840',26602,32779);
INSERT INTO "django_geo_db_zipcode" VALUES(36796,82842,-7,'Story, Wyoming 82842',26603,32780);
INSERT INTO "django_geo_db_zipcode" VALUES(36797,82844,-7,'Wolf, Wyoming 82844',26604,32781);
INSERT INTO "django_geo_db_zipcode" VALUES(36798,82845,-7,'Wyarno, Wyoming 82845',26605,32782);
INSERT INTO "django_geo_db_zipcode" VALUES(36799,82901,-7,'Rock Springs, Wyoming 82901',26606,32783);
INSERT INTO "django_geo_db_zipcode" VALUES(36800,82902,-7,'Rock Springs, Wyoming 82902',26606,32784);
INSERT INTO "django_geo_db_zipcode" VALUES(36801,82922,-7,'Bondurant, Wyoming 82922',26607,32785);
INSERT INTO "django_geo_db_zipcode" VALUES(36802,82923,-7,'Boulder, Wyoming 82923',26608,32786);
INSERT INTO "django_geo_db_zipcode" VALUES(36803,82925,-7,'Cora, Wyoming 82925',26609,32787);
INSERT INTO "django_geo_db_zipcode" VALUES(36804,82929,-7,'Little America, Wyoming 82929',26610,32788);
INSERT INTO "django_geo_db_zipcode" VALUES(36805,82930,-7,'Evanston, Wyoming 82930',26611,32789);
INSERT INTO "django_geo_db_zipcode" VALUES(36806,82931,-7,'Evanston, Wyoming 82931',26611,32790);
INSERT INTO "django_geo_db_zipcode" VALUES(36807,82932,-7,'Farson, Wyoming 82932',26612,32791);
INSERT INTO "django_geo_db_zipcode" VALUES(36808,82933,-7,'Fort Bridger, Wyoming 82933',26613,32792);
INSERT INTO "django_geo_db_zipcode" VALUES(36809,82934,-7,'Granger, Wyoming 82934',26614,32793);
INSERT INTO "django_geo_db_zipcode" VALUES(36810,82935,-7,'Green River, Wyoming 82935',26615,32794);
INSERT INTO "django_geo_db_zipcode" VALUES(36811,82936,-7,'Lontetree, Wyoming 82936',26616,32795);
INSERT INTO "django_geo_db_zipcode" VALUES(36812,82937,-7,'Lyman, Wyoming 82937',26617,32796);
INSERT INTO "django_geo_db_zipcode" VALUES(36813,82938,-7,'McKinnon, Wyoming 82938',26618,32797);
INSERT INTO "django_geo_db_zipcode" VALUES(36814,82939,-7,'Mountain View, Wyoming 82939',26619,32798);
INSERT INTO "django_geo_db_zipcode" VALUES(36815,82941,-7,'Pinedale, Wyoming 82941',26620,32799);
INSERT INTO "django_geo_db_zipcode" VALUES(36816,82942,-7,'Point Of Rocks, Wyoming 82942',26621,32800);
INSERT INTO "django_geo_db_zipcode" VALUES(36817,82943,-7,'Reliance, Wyoming 82943',26622,32801);
INSERT INTO "django_geo_db_zipcode" VALUES(36818,82944,-7,'Robertson, Wyoming 82944',26623,32802);
INSERT INTO "django_geo_db_zipcode" VALUES(36819,82945,-7,'Superior, Wyoming 82945',26624,32803);
INSERT INTO "django_geo_db_zipcode" VALUES(36820,83001,-7,'Jackson, Wyoming 83001',26625,32804);
INSERT INTO "django_geo_db_zipcode" VALUES(36821,83002,-7,'Jackson, Wyoming 83002',26625,32805);
INSERT INTO "django_geo_db_zipcode" VALUES(36822,83011,-7,'Kelly, Wyoming 83011',26626,32806);
INSERT INTO "django_geo_db_zipcode" VALUES(36823,83012,-7,'Moose, Wyoming 83012',26627,32807);
INSERT INTO "django_geo_db_zipcode" VALUES(36824,83013,-7,'Moran, Wyoming 83013',26628,32808);
INSERT INTO "django_geo_db_zipcode" VALUES(36825,83014,-7,'Wilson, Wyoming 83014',26629,32809);
INSERT INTO "django_geo_db_zipcode" VALUES(36826,83025,-7,'Teton Village, Wyoming 83025',26630,32810);
INSERT INTO "django_geo_db_zipcode" VALUES(36827,83101,-7,'Kemmerer, Wyoming 83101',26631,32811);
INSERT INTO "django_geo_db_zipcode" VALUES(36828,83110,-7,'Afton, Wyoming 83110',26632,32812);
INSERT INTO "django_geo_db_zipcode" VALUES(36829,83111,-7,'Auburn, Wyoming 83111',26633,32813);
INSERT INTO "django_geo_db_zipcode" VALUES(36830,83112,-7,'Bedford, Wyoming 83112',26634,32814);
INSERT INTO "django_geo_db_zipcode" VALUES(36831,83113,-7,'Big Piney, Wyoming 83113',26635,32815);
INSERT INTO "django_geo_db_zipcode" VALUES(36832,83114,-7,'Cokeville, Wyoming 83114',26636,32816);
INSERT INTO "django_geo_db_zipcode" VALUES(36833,83115,-7,'Daniel, Wyoming 83115',26637,32817);
INSERT INTO "django_geo_db_zipcode" VALUES(36834,83116,-7,'Diamondville, Wyoming 83116',26638,32818);
INSERT INTO "django_geo_db_zipcode" VALUES(36835,83118,-7,'Etna, Wyoming 83118',26639,32819);
INSERT INTO "django_geo_db_zipcode" VALUES(36836,83119,-7,'Fairview, Wyoming 83119',26640,32820);
INSERT INTO "django_geo_db_zipcode" VALUES(36837,83120,-7,'Freedom, Idaho 83120',26641,32821);
INSERT INTO "django_geo_db_zipcode" VALUES(36838,83121,-7,'Frontier, Wyoming 83121',26642,32822);
INSERT INTO "django_geo_db_zipcode" VALUES(36839,83122,-7,'Grover, Wyoming 83122',26643,32823);
INSERT INTO "django_geo_db_zipcode" VALUES(36840,83123,-7,'La Barge, Wyoming 83123',26644,32824);
INSERT INTO "django_geo_db_zipcode" VALUES(36841,83124,-7,'Opal, Wyoming 83124',26645,32825);
INSERT INTO "django_geo_db_zipcode" VALUES(36842,83126,-7,'Smoot, Wyoming 83126',26646,32826);
INSERT INTO "django_geo_db_zipcode" VALUES(36843,83127,-7,'Thayne, Wyoming 83127',26647,32827);
INSERT INTO "django_geo_db_zipcode" VALUES(36844,83128,-7,'Alpine, Wyoming 83128',26648,32828);
INSERT INTO "django_geo_db_zipcode" VALUES(36845,83201,-7,'Pocatello, Idaho 83201',26649,32829);
INSERT INTO "django_geo_db_zipcode" VALUES(36846,83202,-7,'Pocatello, Idaho 83202',26649,32830);
INSERT INTO "django_geo_db_zipcode" VALUES(36847,83203,-7,'Fort Hall, Idaho 83203',26650,32831);
INSERT INTO "django_geo_db_zipcode" VALUES(36848,83204,-7,'Pocatello, Idaho 83204',26649,32832);
INSERT INTO "django_geo_db_zipcode" VALUES(36849,83205,-7,'Pocatello, Idaho 83205',26649,32833);
INSERT INTO "django_geo_db_zipcode" VALUES(36850,83206,-7,'Pocatello, Idaho 83206',26649,32834);
INSERT INTO "django_geo_db_zipcode" VALUES(36851,83209,-7,'Pocatello, Idaho 83209',26649,32834);
INSERT INTO "django_geo_db_zipcode" VALUES(36852,83210,-7,'Aberdeen, Idaho 83210',26651,32835);
INSERT INTO "django_geo_db_zipcode" VALUES(36853,83211,-7,'American Falls, Idaho 83211',26652,32836);
INSERT INTO "django_geo_db_zipcode" VALUES(36854,83212,-7,'Arbon, Idaho 83212',26653,32837);
INSERT INTO "django_geo_db_zipcode" VALUES(36855,83213,-7,'Arco, Idaho 83213',26654,32838);
INSERT INTO "django_geo_db_zipcode" VALUES(36856,83214,-7,'Arimo, Idaho 83214',26655,32839);
INSERT INTO "django_geo_db_zipcode" VALUES(36857,83215,-7,'Atomic City, Idaho 83215',26656,32840);
INSERT INTO "django_geo_db_zipcode" VALUES(36858,83217,-7,'Bancroft, Idaho 83217',26657,32841);
INSERT INTO "django_geo_db_zipcode" VALUES(36859,83218,-7,'Basalt, Idaho 83218',26658,32842);
INSERT INTO "django_geo_db_zipcode" VALUES(36860,83220,-7,'Bern, Idaho 83220',26659,32843);
INSERT INTO "django_geo_db_zipcode" VALUES(36861,83221,-7,'Blackfoot, Idaho 83221',26660,32844);
INSERT INTO "django_geo_db_zipcode" VALUES(36862,83223,-7,'Bloomington, Idaho 83223',26661,32845);
INSERT INTO "django_geo_db_zipcode" VALUES(36863,83226,-7,'Challis, Idaho 83226',26662,32846);
INSERT INTO "django_geo_db_zipcode" VALUES(36864,83227,-7,'Clayton, Idaho 83227',26663,32847);
INSERT INTO "django_geo_db_zipcode" VALUES(36865,83228,-7,'Clifton, Idaho 83228',26664,32848);
INSERT INTO "django_geo_db_zipcode" VALUES(36866,83229,-7,'Cobalt, Idaho 83229',26665,32849);
INSERT INTO "django_geo_db_zipcode" VALUES(36867,83230,-7,'Conda, Idaho 83230',26666,32850);
INSERT INTO "django_geo_db_zipcode" VALUES(36868,83232,-7,'Dayton, Idaho 83232',26667,32851);
INSERT INTO "django_geo_db_zipcode" VALUES(36869,83233,-7,'Dingle, Idaho 83233',26668,32852);
INSERT INTO "django_geo_db_zipcode" VALUES(36870,83234,-7,'Downey, Idaho 83234',26669,32853);
INSERT INTO "django_geo_db_zipcode" VALUES(36871,83235,-7,'Ellis, Idaho 83235',26670,32854);
INSERT INTO "django_geo_db_zipcode" VALUES(36872,83236,-7,'Firth, Idaho 83236',26671,32855);
INSERT INTO "django_geo_db_zipcode" VALUES(36873,83237,-7,'Franklin, Idaho 83237',26672,32856);
INSERT INTO "django_geo_db_zipcode" VALUES(36874,83238,-7,'Geneva, Idaho 83238',26673,32857);
INSERT INTO "django_geo_db_zipcode" VALUES(36875,83239,-7,'Georgetown, Idaho 83239',26674,32858);
INSERT INTO "django_geo_db_zipcode" VALUES(36876,83241,-7,'Grace, Idaho 83241',26675,32859);
INSERT INTO "django_geo_db_zipcode" VALUES(36877,83243,-7,'Holbrook, Idaho 83243',26676,32860);
INSERT INTO "django_geo_db_zipcode" VALUES(36878,83244,-7,'Howe, Idaho 83244',26677,32861);
INSERT INTO "django_geo_db_zipcode" VALUES(36879,83245,-7,'Inkom, Idaho 83245',26678,32862);
INSERT INTO "django_geo_db_zipcode" VALUES(36880,83246,-7,'Lava Hot Springs, Idaho 83246',26679,32863);
INSERT INTO "django_geo_db_zipcode" VALUES(36881,83250,-7,'McCammon, Idaho 83250',26680,32864);
INSERT INTO "django_geo_db_zipcode" VALUES(36882,83251,-7,'Mackay, Idaho 83251',26681,32865);
INSERT INTO "django_geo_db_zipcode" VALUES(36883,83252,-7,'Malad City, Idaho 83252',26682,32866);
INSERT INTO "django_geo_db_zipcode" VALUES(36884,83253,-7,'May, Idaho 83253',26683,32867);
INSERT INTO "django_geo_db_zipcode" VALUES(36885,83254,-7,'Montpelier, Idaho 83254',26684,32868);
INSERT INTO "django_geo_db_zipcode" VALUES(36886,83255,-7,'Moore, Idaho 83255',26685,32869);
INSERT INTO "django_geo_db_zipcode" VALUES(36887,83256,-7,'Moreland, Idaho 83256',26686,32870);
INSERT INTO "django_geo_db_zipcode" VALUES(36888,83261,-7,'Paris, Idaho 83261',26687,32871);
INSERT INTO "django_geo_db_zipcode" VALUES(36889,83262,-7,'Pingree, Idaho 83262',26688,32872);
INSERT INTO "django_geo_db_zipcode" VALUES(36890,83263,-7,'Preston, Idaho 83263',26689,32873);
INSERT INTO "django_geo_db_zipcode" VALUES(36891,83271,-7,'Rockland, Idaho 83271',26690,32874);
INSERT INTO "django_geo_db_zipcode" VALUES(36892,83272,-7,'Saint Charles, Idaho 83272',26691,32875);
INSERT INTO "django_geo_db_zipcode" VALUES(36893,83274,-7,'Shelley, Idaho 83274',26692,32876);
INSERT INTO "django_geo_db_zipcode" VALUES(36894,83276,-7,'Soda Springs, Idaho 83276',26693,32877);
INSERT INTO "django_geo_db_zipcode" VALUES(36895,83277,-7,'Springfield, Idaho 83277',26694,32878);
INSERT INTO "django_geo_db_zipcode" VALUES(36896,83278,-7,'Stanley, Idaho 83278',26695,32879);
INSERT INTO "django_geo_db_zipcode" VALUES(36897,83281,-7,'Swanlake, Idaho 83281',26696,32880);
INSERT INTO "django_geo_db_zipcode" VALUES(36898,83283,-7,'Thatcher, Idaho 83283',26697,32881);
INSERT INTO "django_geo_db_zipcode" VALUES(36899,83285,-7,'Wayan, Idaho 83285',26698,32882);
INSERT INTO "django_geo_db_zipcode" VALUES(36900,83286,-7,'Weston, Idaho 83286',26699,32883);
INSERT INTO "django_geo_db_zipcode" VALUES(36901,83287,-7,'Fish Haven, Idaho 83287',26700,32884);
INSERT INTO "django_geo_db_zipcode" VALUES(36902,83301,-7,'Twin Falls, Idaho 83301',26701,32885);
INSERT INTO "django_geo_db_zipcode" VALUES(36903,83302,-7,'Rogerson, Idaho 83302',26702,32886);
INSERT INTO "django_geo_db_zipcode" VALUES(36904,83303,-7,'Twin Falls, Idaho 83303',26701,32887);
INSERT INTO "django_geo_db_zipcode" VALUES(36905,83311,-7,'Albion, Idaho 83311',26703,32888);
INSERT INTO "django_geo_db_zipcode" VALUES(36906,83312,-7,'Almo, Idaho 83312',26704,32889);
INSERT INTO "django_geo_db_zipcode" VALUES(36907,83313,-7,'Bellevue, Idaho 83313',26705,32890);
INSERT INTO "django_geo_db_zipcode" VALUES(36908,83314,-7,'Bliss, Idaho 83314',26706,32891);
INSERT INTO "django_geo_db_zipcode" VALUES(36909,83316,-7,'Buhl, Idaho 83316',26707,32892);
INSERT INTO "django_geo_db_zipcode" VALUES(36910,83318,-7,'Burley, Idaho 83318',26708,32893);
INSERT INTO "django_geo_db_zipcode" VALUES(36911,83320,-7,'Carey, Idaho 83320',26709,32894);
INSERT INTO "django_geo_db_zipcode" VALUES(36912,83321,-7,'Castleford, Idaho 83321',26710,32895);
INSERT INTO "django_geo_db_zipcode" VALUES(36913,83322,-7,'Corral, Idaho 83322',26711,32896);
INSERT INTO "django_geo_db_zipcode" VALUES(36914,83323,-7,'Declo, Idaho 83323',26712,32897);
INSERT INTO "django_geo_db_zipcode" VALUES(36915,83324,-7,'Dietrich, Idaho 83324',26713,32898);
INSERT INTO "django_geo_db_zipcode" VALUES(36916,83325,-7,'Eden, Idaho 83325',26714,32899);
INSERT INTO "django_geo_db_zipcode" VALUES(36917,83327,-7,'Fairfield, Idaho 83327',26715,32900);
INSERT INTO "django_geo_db_zipcode" VALUES(36918,83328,-7,'Filer, Idaho 83328',26716,32901);
INSERT INTO "django_geo_db_zipcode" VALUES(36919,83330,-7,'Gooding, Idaho 83330',26717,32902);
INSERT INTO "django_geo_db_zipcode" VALUES(36920,83332,-7,'Hagerman, Idaho 83332',26718,32903);
INSERT INTO "django_geo_db_zipcode" VALUES(36921,83333,-7,'Hailey, Idaho 83333',26719,32904);
INSERT INTO "django_geo_db_zipcode" VALUES(36922,83334,-7,'Hansen, Idaho 83334',26720,32905);
INSERT INTO "django_geo_db_zipcode" VALUES(36923,83335,-7,'Hazelton, Idaho 83335',26721,32906);
INSERT INTO "django_geo_db_zipcode" VALUES(36924,83336,-7,'Heyburn, Idaho 83336',26722,32907);
INSERT INTO "django_geo_db_zipcode" VALUES(36925,83337,-7,'Hill City, Idaho 83337',26723,32908);
INSERT INTO "django_geo_db_zipcode" VALUES(36926,83338,-7,'Jerome, Idaho 83338',26724,32909);
INSERT INTO "django_geo_db_zipcode" VALUES(36927,83340,-7,'Ketchum, Idaho 83340',26725,32910);
INSERT INTO "django_geo_db_zipcode" VALUES(36928,83341,-7,'Kimberly, Idaho 83341',26726,32911);
INSERT INTO "django_geo_db_zipcode" VALUES(36929,83342,-7,'Malta, Idaho 83342',26727,32912);
INSERT INTO "django_geo_db_zipcode" VALUES(36930,83343,-7,'Minidoka, Idaho 83343',26728,32913);
INSERT INTO "django_geo_db_zipcode" VALUES(36931,83344,-7,'Murtaugh, Idaho 83344',26729,32914);
INSERT INTO "django_geo_db_zipcode" VALUES(36932,83346,-7,'Oakley, Idaho 83346',26730,32915);
INSERT INTO "django_geo_db_zipcode" VALUES(36933,83347,-7,'Paul, Idaho 83347',26731,32916);
INSERT INTO "django_geo_db_zipcode" VALUES(36934,83348,-7,'Picabo, Idaho 83348',26732,32917);
INSERT INTO "django_geo_db_zipcode" VALUES(36935,83349,-7,'Richfield, Idaho 83349',26733,32918);
INSERT INTO "django_geo_db_zipcode" VALUES(36936,83350,-7,'Rupert, Idaho 83350',26734,32919);
INSERT INTO "django_geo_db_zipcode" VALUES(36937,83352,-7,'Shoshone, Idaho 83352',26735,32920);
INSERT INTO "django_geo_db_zipcode" VALUES(36938,83353,-7,'Sun Valley, Idaho 83353',26736,32921);
INSERT INTO "django_geo_db_zipcode" VALUES(36939,83354,-7,'Sun Valley, Idaho 83354',26736,32922);
INSERT INTO "django_geo_db_zipcode" VALUES(36940,83355,-7,'Wendell, Idaho 83355',26737,32923);
INSERT INTO "django_geo_db_zipcode" VALUES(36941,83401,-7,'Idaho Falls, Idaho 83401',26738,32924);
INSERT INTO "django_geo_db_zipcode" VALUES(36942,83402,-7,'Idaho Falls, Idaho 83402',26738,32925);
INSERT INTO "django_geo_db_zipcode" VALUES(36943,83403,-7,'Idaho Falls, Idaho 83403',26738,32926);
INSERT INTO "django_geo_db_zipcode" VALUES(36944,83404,-7,'Idaho Falls, Idaho 83404',26738,32927);
INSERT INTO "django_geo_db_zipcode" VALUES(36945,83405,-7,'Idaho Falls, Idaho 83405',26738,32928);
INSERT INTO "django_geo_db_zipcode" VALUES(36946,83406,-7,'Idaho Falls, Idaho 83406',26738,32929);
INSERT INTO "django_geo_db_zipcode" VALUES(36947,83415,-7,'Idaho Falls, Idaho 83415',26738,32928);
INSERT INTO "django_geo_db_zipcode" VALUES(36948,83420,-7,'Ashton, Idaho 83420',26739,32930);
INSERT INTO "django_geo_db_zipcode" VALUES(36949,83421,-7,'Chester, Idaho 83421',26740,32931);
INSERT INTO "django_geo_db_zipcode" VALUES(36950,83422,-7,'Driggs, Idaho 83422',26741,32932);
INSERT INTO "django_geo_db_zipcode" VALUES(36951,83423,-7,'Dubois, Idaho 83423',26742,32933);
INSERT INTO "django_geo_db_zipcode" VALUES(36952,83424,-7,'Felt, Idaho 83424',26743,32934);
INSERT INTO "django_geo_db_zipcode" VALUES(36953,83425,-7,'Hamer, Idaho 83425',26744,32935);
INSERT INTO "django_geo_db_zipcode" VALUES(36954,83427,-7,'Iona, Idaho 83427',26745,32936);
INSERT INTO "django_geo_db_zipcode" VALUES(36955,83428,-7,'Irwin, Idaho 83428',26746,32937);
INSERT INTO "django_geo_db_zipcode" VALUES(36956,83429,-7,'Island Park, Idaho 83429',26747,32938);
INSERT INTO "django_geo_db_zipcode" VALUES(36957,83431,-7,'Lewisville, Idaho 83431',26748,32939);
INSERT INTO "django_geo_db_zipcode" VALUES(36958,83433,-7,'Macks Inn, Idaho 83433',26749,32940);
INSERT INTO "django_geo_db_zipcode" VALUES(36959,83434,-7,'Menan, Idaho 83434',26750,32941);
INSERT INTO "django_geo_db_zipcode" VALUES(36960,83435,-7,'Monteview, Idaho 83435',26751,32942);
INSERT INTO "django_geo_db_zipcode" VALUES(36961,83436,-7,'Newdale, Idaho 83436',26752,32943);
INSERT INTO "django_geo_db_zipcode" VALUES(36962,83438,-7,'Parker, Idaho 83438',26753,32944);
INSERT INTO "django_geo_db_zipcode" VALUES(36963,83440,-7,'Rexburg, Idaho 83440',26754,32945);
INSERT INTO "django_geo_db_zipcode" VALUES(36964,83441,-7,'Rexburg, Idaho 83441',26754,32946);
INSERT INTO "django_geo_db_zipcode" VALUES(36965,83442,-7,'Rigby, Idaho 83442',26755,32947);
INSERT INTO "django_geo_db_zipcode" VALUES(36966,83443,-7,'Ririe, Idaho 83443',26756,32948);
INSERT INTO "django_geo_db_zipcode" VALUES(36967,83444,-7,'Roberts, Idaho 83444',26757,32949);
INSERT INTO "django_geo_db_zipcode" VALUES(36968,83445,-7,'Saint Anthony, Idaho 83445',26758,32950);
INSERT INTO "django_geo_db_zipcode" VALUES(36969,83446,-7,'Spencer, Idaho 83446',26759,32951);
INSERT INTO "django_geo_db_zipcode" VALUES(36970,83447,-7,'Squirrel, Idaho 83447',26760,32944);
INSERT INTO "django_geo_db_zipcode" VALUES(36971,83448,-7,'Sugar City, Idaho 83448',26761,32952);
INSERT INTO "django_geo_db_zipcode" VALUES(36972,83449,-7,'Swan Valley, Idaho 83449',26762,32953);
INSERT INTO "django_geo_db_zipcode" VALUES(36973,83450,-7,'Terreton, Idaho 83450',26763,32954);
INSERT INTO "django_geo_db_zipcode" VALUES(36974,83451,-7,'Teton, Idaho 83451',26764,32955);
INSERT INTO "django_geo_db_zipcode" VALUES(36975,83452,-7,'Tetonia, Idaho 83452',26765,32956);
INSERT INTO "django_geo_db_zipcode" VALUES(36976,83454,-7,'Ucon, Idaho 83454',26766,32957);
INSERT INTO "django_geo_db_zipcode" VALUES(36977,83455,-7,'Victor, Idaho 83455',26767,32958);
INSERT INTO "django_geo_db_zipcode" VALUES(36978,83460,-7,'Rexburg, Idaho 83460',26754,32946);
INSERT INTO "django_geo_db_zipcode" VALUES(36979,83462,-7,'Carmen, Idaho 83462',26768,32959);
INSERT INTO "django_geo_db_zipcode" VALUES(36980,83463,-7,'Gibbonsville, Idaho 83463',26769,32960);
INSERT INTO "django_geo_db_zipcode" VALUES(36981,83464,-7,'Leadore, Idaho 83464',26770,32961);
INSERT INTO "django_geo_db_zipcode" VALUES(36982,83465,-7,'Lemhi, Idaho 83465',26771,32962);
INSERT INTO "django_geo_db_zipcode" VALUES(36983,83466,-7,'North Fork, Idaho 83466',26772,32963);
INSERT INTO "django_geo_db_zipcode" VALUES(36984,83467,-7,'Salmon, Idaho 83467',26773,32964);
INSERT INTO "django_geo_db_zipcode" VALUES(36985,83468,-7,'Tendoy, Idaho 83468',26774,32965);
INSERT INTO "django_geo_db_zipcode" VALUES(36986,83469,-7,'Shoup, Idaho 83469',26775,32966);
INSERT INTO "django_geo_db_zipcode" VALUES(36987,83501,-8,'Lewiston, Idaho 83501',26776,32967);
INSERT INTO "django_geo_db_zipcode" VALUES(36988,83520,-8,'Ahsahka, Idaho 83520',26777,32968);
INSERT INTO "django_geo_db_zipcode" VALUES(36989,83522,-8,'Cottonwood, Idaho 83522',26778,32969);
INSERT INTO "django_geo_db_zipcode" VALUES(36990,83523,-8,'Craigmont, Idaho 83523',26779,32970);
INSERT INTO "django_geo_db_zipcode" VALUES(36991,83524,-8,'Culdesac, Idaho 83524',26780,32971);
INSERT INTO "django_geo_db_zipcode" VALUES(36992,83525,-8,'Elk City, Idaho 83525',26781,32972);
INSERT INTO "django_geo_db_zipcode" VALUES(36993,83526,-8,'Ferdinand, Idaho 83526',26782,32973);
INSERT INTO "django_geo_db_zipcode" VALUES(36994,83530,-8,'Grangeville, Idaho 83530',26783,32974);
INSERT INTO "django_geo_db_zipcode" VALUES(36995,83531,-8,'Fenn, Idaho 83531',26784,32975);
INSERT INTO "django_geo_db_zipcode" VALUES(36996,83533,-8,'Greencreek, Idaho 83533',26785,32976);
INSERT INTO "django_geo_db_zipcode" VALUES(36997,83534,-8,'Culdesac, Idaho 83534',26780,32977);
INSERT INTO "django_geo_db_zipcode" VALUES(36998,83535,-8,'Juliaetta, Idaho 83535',26786,32978);
INSERT INTO "django_geo_db_zipcode" VALUES(36999,83536,-8,'Kamiah, Idaho 83536',26787,32979);
INSERT INTO "django_geo_db_zipcode" VALUES(37000,83537,-8,'Kendrick, Idaho 83537',26788,32980);
INSERT INTO "django_geo_db_zipcode" VALUES(37001,83539,-8,'Kooskia, Idaho 83539',26789,32981);
INSERT INTO "django_geo_db_zipcode" VALUES(37002,83540,-8,'Lapwai, Idaho 83540',26790,32982);
INSERT INTO "django_geo_db_zipcode" VALUES(37003,83541,-8,'Lenore, Idaho 83541',26791,32983);
INSERT INTO "django_geo_db_zipcode" VALUES(37004,83542,-8,'Lucile, Idaho 83542',26792,32984);
INSERT INTO "django_geo_db_zipcode" VALUES(37005,83543,-8,'Nezperce, Idaho 83543',26793,32985);
INSERT INTO "django_geo_db_zipcode" VALUES(37006,83544,-8,'Orofino, Idaho 83544',26794,32986);
INSERT INTO "django_geo_db_zipcode" VALUES(37007,83545,-8,'Peck, Idaho 83545',26795,32987);
INSERT INTO "django_geo_db_zipcode" VALUES(37008,83546,-8,'Pierce, Idaho 83546',26796,32988);
INSERT INTO "django_geo_db_zipcode" VALUES(37009,83547,-7,'Pollock, Idaho 83547',26797,32989);
INSERT INTO "django_geo_db_zipcode" VALUES(37010,83548,-8,'Reubens, Idaho 83548',26798,32990);
INSERT INTO "django_geo_db_zipcode" VALUES(37011,83549,-7,'Riggins, Idaho 83549',26799,32991);
INSERT INTO "django_geo_db_zipcode" VALUES(37012,83551,-8,'Spalding, Idaho 83551',26800,32992);
INSERT INTO "django_geo_db_zipcode" VALUES(37013,83552,-8,'Stites, Idaho 83552',26801,32993);
INSERT INTO "django_geo_db_zipcode" VALUES(37014,83553,-8,'Weippe, Idaho 83553',26802,32994);
INSERT INTO "django_geo_db_zipcode" VALUES(37015,83554,-8,'White Bird, Idaho 83554',26803,32995);
INSERT INTO "django_geo_db_zipcode" VALUES(37016,83555,-8,'Winchester, Idaho 83555',26804,32996);
INSERT INTO "django_geo_db_zipcode" VALUES(37017,83601,-7,'Atlanta, Idaho 83601',26805,32997);
INSERT INTO "django_geo_db_zipcode" VALUES(37018,83602,-7,'Banks, Idaho 83602',26806,32998);
INSERT INTO "django_geo_db_zipcode" VALUES(37019,83604,-7,'Bruneau, Idaho 83604',26807,32999);
INSERT INTO "django_geo_db_zipcode" VALUES(37020,83605,-7,'Caldwell, Idaho 83605',26808,33000);
INSERT INTO "django_geo_db_zipcode" VALUES(37021,83606,-7,'Caldwell, Idaho 83606',26808,33001);
INSERT INTO "django_geo_db_zipcode" VALUES(37022,83607,-7,'Caldwell, Idaho 83607',26808,33002);
INSERT INTO "django_geo_db_zipcode" VALUES(37023,83610,-7,'Cambridge, Idaho 83610',26809,33003);
INSERT INTO "django_geo_db_zipcode" VALUES(37024,83611,-7,'Cascade, Idaho 83611',26810,33004);
INSERT INTO "django_geo_db_zipcode" VALUES(37025,83612,-7,'Council, Idaho 83612',26811,33005);
INSERT INTO "django_geo_db_zipcode" VALUES(37026,83615,-7,'Donnelly, Idaho 83615',26812,33006);
INSERT INTO "django_geo_db_zipcode" VALUES(37027,83616,-7,'Eagle, Idaho 83616',26813,33007);
INSERT INTO "django_geo_db_zipcode" VALUES(37028,83617,-7,'Emmett, Idaho 83617',26814,33008);
INSERT INTO "django_geo_db_zipcode" VALUES(37029,83619,-7,'Fruitland, Idaho 83619',26815,33009);
INSERT INTO "django_geo_db_zipcode" VALUES(37030,83620,-7,'Fruitvale, Idaho 83620',26816,33010);
INSERT INTO "django_geo_db_zipcode" VALUES(37031,83622,-7,'Garden Valley, Idaho 83622',26817,33011);
INSERT INTO "django_geo_db_zipcode" VALUES(37032,83623,-7,'Glenns Ferry, Idaho 83623',26818,33012);
INSERT INTO "django_geo_db_zipcode" VALUES(37033,83624,-7,'Grand View, Idaho 83624',26819,33013);
INSERT INTO "django_geo_db_zipcode" VALUES(37034,83626,-7,'Greenleaf, Idaho 83626',26820,33014);
INSERT INTO "django_geo_db_zipcode" VALUES(37035,83627,-7,'Hammett, Idaho 83627',26821,33015);
INSERT INTO "django_geo_db_zipcode" VALUES(37036,83628,-7,'Homedale, Idaho 83628',26822,33016);
INSERT INTO "django_geo_db_zipcode" VALUES(37037,83629,-7,'Horseshoe Bend, Idaho 83629',26823,33017);
INSERT INTO "django_geo_db_zipcode" VALUES(37038,83630,-7,'Huston, Idaho 83630',26824,33018);
INSERT INTO "django_geo_db_zipcode" VALUES(37039,83631,-7,'Idaho City, Idaho 83631',26825,33019);
INSERT INTO "django_geo_db_zipcode" VALUES(37040,83632,-7,'Indian Valley, Idaho 83632',26826,33020);
INSERT INTO "django_geo_db_zipcode" VALUES(37041,83633,-7,'King Hill, Idaho 83633',26827,33021);
INSERT INTO "django_geo_db_zipcode" VALUES(37042,83634,-7,'Kuna, Idaho 83634',26828,33022);
INSERT INTO "django_geo_db_zipcode" VALUES(37043,83635,-7,'Lake Fork, Idaho 83635',26829,33023);
INSERT INTO "django_geo_db_zipcode" VALUES(37044,83636,-7,'Letha, Idaho 83636',26830,33024);
INSERT INTO "django_geo_db_zipcode" VALUES(37045,83637,-7,'Lowman, Idaho 83637',26831,33025);
INSERT INTO "django_geo_db_zipcode" VALUES(37046,83638,-7,'McCall, Idaho 83638',26832,33026);
INSERT INTO "django_geo_db_zipcode" VALUES(37047,83639,-7,'Marsing, Idaho 83639',26833,33027);
INSERT INTO "django_geo_db_zipcode" VALUES(37048,83641,-7,'Melba, Idaho 83641',26834,33028);
INSERT INTO "django_geo_db_zipcode" VALUES(37049,83642,-7,'Meridian, Idaho 83642',26835,33029);
INSERT INTO "django_geo_db_zipcode" VALUES(37050,83643,-7,'Mesa, Idaho 83643',26836,33030);
INSERT INTO "django_geo_db_zipcode" VALUES(37051,83644,-7,'Middleton, Idaho 83644',26837,33031);
INSERT INTO "django_geo_db_zipcode" VALUES(37052,83645,-7,'Midvale, Idaho 83645',26838,33032);
INSERT INTO "django_geo_db_zipcode" VALUES(37053,83647,-7,'Mountain Home, Idaho 83647',26839,33033);
INSERT INTO "django_geo_db_zipcode" VALUES(37054,83648,-7,'Mountain Home A F B, Idaho 83648',26840,33034);
INSERT INTO "django_geo_db_zipcode" VALUES(37055,83650,-7,'Murphy, Idaho 83650',26841,33035);
INSERT INTO "django_geo_db_zipcode" VALUES(37056,83651,-7,'Nampa, Idaho 83651',26842,33036);
INSERT INTO "django_geo_db_zipcode" VALUES(37057,83652,-7,'Nampa, Idaho 83652',26842,33037);
INSERT INTO "django_geo_db_zipcode" VALUES(37058,83653,-7,'Nampa, Idaho 83653',26842,33038);
INSERT INTO "django_geo_db_zipcode" VALUES(37059,83654,-7,'New Meadows, Idaho 83654',26843,33039);
INSERT INTO "django_geo_db_zipcode" VALUES(37060,83655,-7,'New Plymouth, Idaho 83655',26844,33040);
INSERT INTO "django_geo_db_zipcode" VALUES(37061,83656,-7,'Notus, Idaho 83656',26845,33041);
INSERT INTO "django_geo_db_zipcode" VALUES(37062,83657,-7,'Ola, Idaho 83657',26846,33042);
INSERT INTO "django_geo_db_zipcode" VALUES(37063,83660,-7,'Parma, Idaho 83660',26847,33043);
INSERT INTO "django_geo_db_zipcode" VALUES(37064,83661,-7,'Payette, Idaho 83661',26848,33044);
INSERT INTO "django_geo_db_zipcode" VALUES(37065,83666,-7,'Placerville, Idaho 83666',26849,33045);
INSERT INTO "django_geo_db_zipcode" VALUES(37066,83669,-7,'Star, Idaho 83669',26850,33046);
INSERT INTO "django_geo_db_zipcode" VALUES(37067,83670,-7,'Sweet, Idaho 83670',26851,33047);
INSERT INTO "django_geo_db_zipcode" VALUES(37068,83671,-7,'Warren, Idaho 83671',26852,33048);
INSERT INTO "django_geo_db_zipcode" VALUES(37069,83672,-7,'Weiser, Idaho 83672',26853,33049);
INSERT INTO "django_geo_db_zipcode" VALUES(37070,83676,-7,'Wilder, Idaho 83676',26854,33050);
INSERT INTO "django_geo_db_zipcode" VALUES(37071,83677,-7,'Yellow Pine, Idaho 83677',26855,33051);
INSERT INTO "django_geo_db_zipcode" VALUES(37072,83680,-7,'Meridian, Idaho 83680',26835,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37073,83686,-7,'Nampa, Idaho 83686',26842,33053);
INSERT INTO "django_geo_db_zipcode" VALUES(37074,83687,-7,'Nampa, Idaho 83687',26842,33054);
INSERT INTO "django_geo_db_zipcode" VALUES(37075,83701,-7,'Boise, Idaho 83701',26856,33055);
INSERT INTO "django_geo_db_zipcode" VALUES(37076,83702,-7,'Boise, Idaho 83702',26856,33056);
INSERT INTO "django_geo_db_zipcode" VALUES(37077,83703,-7,'Boise, Idaho 83703',26856,33057);
INSERT INTO "django_geo_db_zipcode" VALUES(37078,83704,-7,'Boise, Idaho 83704',26856,33058);
INSERT INTO "django_geo_db_zipcode" VALUES(37079,83705,-7,'Boise, Idaho 83705',26856,33059);
INSERT INTO "django_geo_db_zipcode" VALUES(37080,83706,-7,'Boise, Idaho 83706',26856,33060);
INSERT INTO "django_geo_db_zipcode" VALUES(37081,83707,-7,'Boise, Idaho 83707',26856,33061);
INSERT INTO "django_geo_db_zipcode" VALUES(37082,83708,-7,'Boise, Idaho 83708',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37083,83709,-7,'Boise, Idaho 83709',26856,33062);
INSERT INTO "django_geo_db_zipcode" VALUES(37084,83711,-7,'Boise, Idaho 83711',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37085,83712,-7,'Boise, Idaho 83712',26856,33063);
INSERT INTO "django_geo_db_zipcode" VALUES(37086,83713,-7,'Boise, Idaho 83713',26856,33064);
INSERT INTO "django_geo_db_zipcode" VALUES(37087,83714,-7,'Boise, Idaho 83714',26856,33065);
INSERT INTO "django_geo_db_zipcode" VALUES(37088,83715,-7,'Boise, Idaho 83715',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37089,83716,-7,'Boise, Idaho 83716',26856,33066);
INSERT INTO "django_geo_db_zipcode" VALUES(37090,83717,-7,'Boise, Idaho 83717',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37091,83719,-7,'Boise, Idaho 83719',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37092,83720,-7,'Boise, Idaho 83720',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37093,83721,-7,'Boise, Idaho 83721',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37094,83722,-7,'Boise, Idaho 83722',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37095,83723,-7,'Boise, Idaho 83723',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37096,83724,-7,'Boise, Idaho 83724',26856,33067);
INSERT INTO "django_geo_db_zipcode" VALUES(37097,83725,-7,'Boise, Idaho 83725',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37098,83726,-7,'Boise, Idaho 83726',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37099,83727,-7,'Boise, Idaho 83727',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37100,83728,-7,'Boise, Idaho 83728',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37101,83729,-7,'Boise, Idaho 83729',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37102,83730,-7,'Boise, Idaho 83730',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37103,83731,-7,'Boise, Idaho 83731',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37104,83732,-7,'Boise, Idaho 83732',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37105,83733,-7,'Boise, Idaho 83733',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37106,83735,-7,'Boise, Idaho 83735',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37107,83744,-7,'Boise, Idaho 83744',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37108,83756,-7,'Boise, Idaho 83756',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37109,83757,-7,'Boise, Idaho 83757',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37110,83788,-7,'Boise, Idaho 83788',26856,33068);
INSERT INTO "django_geo_db_zipcode" VALUES(37111,83799,-7,'Boise, Idaho 83799',26856,33052);
INSERT INTO "django_geo_db_zipcode" VALUES(37112,83801,-8,'Athol, Idaho 83801',26857,33069);
INSERT INTO "django_geo_db_zipcode" VALUES(37113,83802,-8,'Avery, Idaho 83802',26858,33070);
INSERT INTO "django_geo_db_zipcode" VALUES(37114,83803,-8,'Bayview, Idaho 83803',26859,33071);
INSERT INTO "django_geo_db_zipcode" VALUES(37115,83804,-8,'Blanchard, Idaho 83804',26860,33072);
INSERT INTO "django_geo_db_zipcode" VALUES(37116,83805,-8,'Bonners Ferry, Idaho 83805',26861,33073);
INSERT INTO "django_geo_db_zipcode" VALUES(37117,83806,-8,'Bovill, Idaho 83806',26862,33074);
INSERT INTO "django_geo_db_zipcode" VALUES(37118,83808,-8,'Calder, Idaho 83808',26863,33075);
INSERT INTO "django_geo_db_zipcode" VALUES(37119,83809,-8,'Careywood, Idaho 83809',26864,33076);
INSERT INTO "django_geo_db_zipcode" VALUES(37120,83810,-8,'Cataldo, Idaho 83810',26865,33077);
INSERT INTO "django_geo_db_zipcode" VALUES(37121,83811,-8,'Clark Fork, Idaho 83811',26866,33078);
INSERT INTO "django_geo_db_zipcode" VALUES(37122,83812,-8,'Clarkia, Idaho 83812',26867,33079);
INSERT INTO "django_geo_db_zipcode" VALUES(37123,83813,-8,'Cocolalla, Idaho 83813',26868,33080);
INSERT INTO "django_geo_db_zipcode" VALUES(37124,83814,-8,'Coeur D Alene, Idaho 83814',26869,33081);
INSERT INTO "django_geo_db_zipcode" VALUES(37125,83815,-8,'Coeur D Alene, Idaho 83815',26869,33082);
INSERT INTO "django_geo_db_zipcode" VALUES(37126,83816,-8,'Coeur D Alene, Idaho 83816',26869,33083);
INSERT INTO "django_geo_db_zipcode" VALUES(37127,83821,-8,'Coolin, Idaho 83821',26870,33084);
INSERT INTO "django_geo_db_zipcode" VALUES(37128,83822,-8,'Oldtown, Idaho 83822',26871,33085);
INSERT INTO "django_geo_db_zipcode" VALUES(37129,83823,-8,'Deary, Idaho 83823',26872,33086);
INSERT INTO "django_geo_db_zipcode" VALUES(37130,83824,-8,'Desmet, Idaho 83824',26873,33087);
INSERT INTO "django_geo_db_zipcode" VALUES(37131,83825,-8,'Dover, Idaho 83825',26874,33088);
INSERT INTO "django_geo_db_zipcode" VALUES(37132,83826,-8,'Eastport, Idaho 83826',26875,33089);
INSERT INTO "django_geo_db_zipcode" VALUES(37133,83827,-8,'Elk River, Idaho 83827',26876,33090);
INSERT INTO "django_geo_db_zipcode" VALUES(37134,83830,-8,'Fernwood, Idaho 83830',26877,33091);
INSERT INTO "django_geo_db_zipcode" VALUES(37135,83832,-8,'Genesee, Idaho 83832',26878,33092);
INSERT INTO "django_geo_db_zipcode" VALUES(37136,83833,-8,'Harrison, Idaho 83833',26879,33093);
INSERT INTO "django_geo_db_zipcode" VALUES(37137,83834,-8,'Harvard, Idaho 83834',26880,33094);
INSERT INTO "django_geo_db_zipcode" VALUES(37138,83835,-8,'Hayden, Idaho 83835',26881,33095);
INSERT INTO "django_geo_db_zipcode" VALUES(37139,83836,-8,'Hope, Idaho 83836',26882,33096);
INSERT INTO "django_geo_db_zipcode" VALUES(37140,83837,-8,'Kellogg, Idaho 83837',26883,33097);
INSERT INTO "django_geo_db_zipcode" VALUES(37141,83839,-8,'Kingston, Idaho 83839',26884,33098);
INSERT INTO "django_geo_db_zipcode" VALUES(37142,83840,-8,'Kootenai, Idaho 83840',26885,33099);
INSERT INTO "django_geo_db_zipcode" VALUES(37143,83841,-8,'Laclede, Idaho 83841',26886,33100);
INSERT INTO "django_geo_db_zipcode" VALUES(37144,83842,-8,'Medimont, Idaho 83842',26887,33101);
INSERT INTO "django_geo_db_zipcode" VALUES(37145,83843,-8,'Moscow, Idaho 83843',26888,33102);
INSERT INTO "django_geo_db_zipcode" VALUES(37146,83844,-8,'Moscow, Idaho 83844',26888,33103);
INSERT INTO "django_geo_db_zipcode" VALUES(37147,83845,-8,'Moyie Springs, Idaho 83845',26889,33104);
INSERT INTO "django_geo_db_zipcode" VALUES(37148,83846,-8,'Mullan, Idaho 83846',26890,33105);
INSERT INTO "django_geo_db_zipcode" VALUES(37149,83847,-8,'Naples, Idaho 83847',26891,33106);
INSERT INTO "django_geo_db_zipcode" VALUES(37150,83848,-8,'Nordman, Idaho 83848',26892,33107);
INSERT INTO "django_geo_db_zipcode" VALUES(37151,83849,-8,'Osburn, Idaho 83849',26893,33108);
INSERT INTO "django_geo_db_zipcode" VALUES(37152,83850,-8,'Pinehurst, Idaho 83850',26894,33109);
INSERT INTO "django_geo_db_zipcode" VALUES(37153,83851,-8,'Plummer, Idaho 83851',26895,33110);
INSERT INTO "django_geo_db_zipcode" VALUES(37154,83852,-8,'Ponderay, Idaho 83852',26896,33111);
INSERT INTO "django_geo_db_zipcode" VALUES(37155,83853,-8,'Porthill, Idaho 83853',26897,33112);
INSERT INTO "django_geo_db_zipcode" VALUES(37156,83854,-8,'Post Falls, Idaho 83854',26898,33113);
INSERT INTO "django_geo_db_zipcode" VALUES(37157,83855,-8,'Potlatch, Idaho 83855',26899,33114);
INSERT INTO "django_geo_db_zipcode" VALUES(37158,83856,-8,'Priest River, Idaho 83856',26900,33115);
INSERT INTO "django_geo_db_zipcode" VALUES(37159,83857,-8,'Princeton, Idaho 83857',26901,33116);
INSERT INTO "django_geo_db_zipcode" VALUES(37160,83858,-8,'Rathdrum, Idaho 83858',26902,33117);
INSERT INTO "django_geo_db_zipcode" VALUES(37161,83860,-8,'Sagle, Idaho 83860',26903,33118);
INSERT INTO "django_geo_db_zipcode" VALUES(37162,83861,-8,'Saint Maries, Idaho 83861',26904,33119);
INSERT INTO "django_geo_db_zipcode" VALUES(37163,83862,-8,'Samuels, Idaho 83862',26905,33088);
INSERT INTO "django_geo_db_zipcode" VALUES(37164,83864,-8,'Sandpoint, Idaho 83864',26906,33120);
INSERT INTO "django_geo_db_zipcode" VALUES(37165,83865,-8,'Colburn, Idaho 83865',26907,33121);
INSERT INTO "django_geo_db_zipcode" VALUES(37166,83866,-8,'Santa, Idaho 83866',26908,33122);
INSERT INTO "django_geo_db_zipcode" VALUES(37167,83867,-8,'Silverton, Idaho 83867',26909,33123);
INSERT INTO "django_geo_db_zipcode" VALUES(37168,83868,-8,'Smelterville, Idaho 83868',26910,33124);
INSERT INTO "django_geo_db_zipcode" VALUES(37169,83869,-8,'Spirit Lake, Idaho 83869',26911,33125);
INSERT INTO "django_geo_db_zipcode" VALUES(37170,83870,-8,'Tensed, Idaho 83870',26912,33126);
INSERT INTO "django_geo_db_zipcode" VALUES(37171,83871,-8,'Troy, Idaho 83871',26913,33127);
INSERT INTO "django_geo_db_zipcode" VALUES(37172,83872,-8,'Viola, Idaho 83872',26914,33128);
INSERT INTO "django_geo_db_zipcode" VALUES(37173,83873,-8,'Wallace, Idaho 83873',26915,33129);
INSERT INTO "django_geo_db_zipcode" VALUES(37174,83874,-8,'Murray, Idaho 83874',26916,33130);
INSERT INTO "django_geo_db_zipcode" VALUES(37175,83876,-8,'Worley, Idaho 83876',26917,33131);
INSERT INTO "django_geo_db_zipcode" VALUES(37176,83877,-8,'Post Falls, Idaho 83877',26898,33083);
INSERT INTO "django_geo_db_zipcode" VALUES(37177,83888,-8,'Sandpoint, Idaho 83888',26906,33088);
INSERT INTO "django_geo_db_zipcode" VALUES(37178,84001,-7,'Altamont, Utah 84001',26918,33132);
INSERT INTO "django_geo_db_zipcode" VALUES(37179,84002,-7,'Altonah, Utah 84002',26919,33133);
INSERT INTO "django_geo_db_zipcode" VALUES(37180,84003,-7,'American Fork, Utah 84003',26920,33134);
INSERT INTO "django_geo_db_zipcode" VALUES(37181,84004,-7,'Alpine, Utah 84004',26921,33135);
INSERT INTO "django_geo_db_zipcode" VALUES(37182,84006,-7,'Bingham Canyon, Utah 84006',26922,33136);
INSERT INTO "django_geo_db_zipcode" VALUES(37183,84007,-7,'Bluebell, Utah 84007',26923,33137);
INSERT INTO "django_geo_db_zipcode" VALUES(37184,84008,-7,'Bonanza, Utah 84008',26924,33138);
INSERT INTO "django_geo_db_zipcode" VALUES(37185,84010,-7,'Bountiful, Utah 84010',26925,33139);
INSERT INTO "django_geo_db_zipcode" VALUES(37186,84011,-7,'Bountiful, Utah 84011',26925,33140);
INSERT INTO "django_geo_db_zipcode" VALUES(37187,84013,-7,'Cedar Valley, Utah 84013',26926,33141);
INSERT INTO "django_geo_db_zipcode" VALUES(37188,84014,-7,'Centerville, Utah 84014',26927,33142);
INSERT INTO "django_geo_db_zipcode" VALUES(37189,84015,-7,'Clearfield, Utah 84015',26928,33143);
INSERT INTO "django_geo_db_zipcode" VALUES(37190,84016,-7,'Clearfield, Utah 84016',26928,33144);
INSERT INTO "django_geo_db_zipcode" VALUES(37191,84017,-7,'Coalville, Utah 84017',26929,33145);
INSERT INTO "django_geo_db_zipcode" VALUES(37192,84018,-7,'Croydon, Utah 84018',26930,33146);
INSERT INTO "django_geo_db_zipcode" VALUES(37193,84020,-7,'Draper, Utah 84020',26931,33147);
INSERT INTO "django_geo_db_zipcode" VALUES(37194,84021,-7,'Duchesne, Utah 84021',26932,33148);
INSERT INTO "django_geo_db_zipcode" VALUES(37195,84022,-7,'Dugway, Utah 84022',26933,33149);
INSERT INTO "django_geo_db_zipcode" VALUES(37196,84023,-7,'Dutch John, Utah 84023',26934,33150);
INSERT INTO "django_geo_db_zipcode" VALUES(37197,84024,-7,'Echo, Utah 84024',26935,33151);
INSERT INTO "django_geo_db_zipcode" VALUES(37198,84025,-7,'Farmington, Utah 84025',26936,33152);
INSERT INTO "django_geo_db_zipcode" VALUES(37199,84026,-7,'Fort Duchesne, Utah 84026',26937,33153);
INSERT INTO "django_geo_db_zipcode" VALUES(37200,84027,-7,'Fruitland, Utah 84027',26938,33154);
INSERT INTO "django_geo_db_zipcode" VALUES(37201,84028,-7,'Garden City, Utah 84028',26939,33155);
INSERT INTO "django_geo_db_zipcode" VALUES(37202,84029,-7,'Grantsville, Utah 84029',26940,33156);
INSERT INTO "django_geo_db_zipcode" VALUES(37203,84030,-7,'Gusher, Utah 84030',26941,33157);
INSERT INTO "django_geo_db_zipcode" VALUES(37204,84031,-7,'Hanna, Utah 84031',26942,33158);
INSERT INTO "django_geo_db_zipcode" VALUES(37205,84032,-7,'Heber City, Utah 84032',26943,33159);
INSERT INTO "django_geo_db_zipcode" VALUES(37206,84033,-7,'Henefer, Utah 84033',26944,33160);
INSERT INTO "django_geo_db_zipcode" VALUES(37207,84034,-7,'Ibapah, Utah 84034',26945,33161);
INSERT INTO "django_geo_db_zipcode" VALUES(37208,84035,-7,'Jensen, Utah 84035',26946,33162);
INSERT INTO "django_geo_db_zipcode" VALUES(37209,84036,-7,'Kamas, Utah 84036',26947,33163);
INSERT INTO "django_geo_db_zipcode" VALUES(37210,84037,-7,'Kaysville, Utah 84037',26948,33164);
INSERT INTO "django_geo_db_zipcode" VALUES(37211,84038,-7,'Laketown, Utah 84038',26949,33165);
INSERT INTO "django_geo_db_zipcode" VALUES(37212,84039,-7,'Lapoint, Utah 84039',26950,33166);
INSERT INTO "django_geo_db_zipcode" VALUES(37213,84040,-7,'Layton, Utah 84040',26951,33167);
INSERT INTO "django_geo_db_zipcode" VALUES(37214,84041,-7,'Layton, Utah 84041',26951,33168);
INSERT INTO "django_geo_db_zipcode" VALUES(37215,84042,-7,'Lindon, Utah 84042',26952,33169);
INSERT INTO "django_geo_db_zipcode" VALUES(37216,84043,-7,'Lehi, Utah 84043',26953,33170);
INSERT INTO "django_geo_db_zipcode" VALUES(37217,84044,-7,'Magna, Utah 84044',26954,33171);
INSERT INTO "django_geo_db_zipcode" VALUES(37218,84046,-7,'Manila, Utah 84046',26955,33172);
INSERT INTO "django_geo_db_zipcode" VALUES(37219,84047,-7,'Midvale, Utah 84047',26956,33173);
INSERT INTO "django_geo_db_zipcode" VALUES(37220,84049,-7,'Midway, Utah 84049',26957,33174);
INSERT INTO "django_geo_db_zipcode" VALUES(37221,84050,-7,'Morgan, Utah 84050',26958,33175);
INSERT INTO "django_geo_db_zipcode" VALUES(37222,84051,-7,'Mountain Home, Utah 84051',26959,33176);
INSERT INTO "django_geo_db_zipcode" VALUES(37223,84052,-7,'Myton, Utah 84052',26960,33177);
INSERT INTO "django_geo_db_zipcode" VALUES(37224,84053,-7,'Neola, Utah 84053',26961,33178);
INSERT INTO "django_geo_db_zipcode" VALUES(37225,84054,-7,'North Salt Lake, Utah 84054',26962,33179);
INSERT INTO "django_geo_db_zipcode" VALUES(37226,84055,-7,'Oakley, Utah 84055',26963,33180);
INSERT INTO "django_geo_db_zipcode" VALUES(37227,84056,-7,'Hill AFB, Utah 84056',26964,33181);
INSERT INTO "django_geo_db_zipcode" VALUES(37228,84057,-7,'Orem, Utah 84057',26965,33182);
INSERT INTO "django_geo_db_zipcode" VALUES(37229,84058,-7,'Orem, Utah 84058',26965,33183);
INSERT INTO "django_geo_db_zipcode" VALUES(37230,84059,-7,'Orem, Utah 84059',26965,33184);
INSERT INTO "django_geo_db_zipcode" VALUES(37231,84060,-7,'Park City, Utah 84060',26966,33185);
INSERT INTO "django_geo_db_zipcode" VALUES(37232,84061,-7,'Peoa, Utah 84061',26967,33186);
INSERT INTO "django_geo_db_zipcode" VALUES(37233,84062,-7,'Pleasant Grove, Utah 84062',26968,33187);
INSERT INTO "django_geo_db_zipcode" VALUES(37234,84063,-7,'Randlett, Utah 84063',26969,33188);
INSERT INTO "django_geo_db_zipcode" VALUES(37235,84064,-7,'Randolph, Utah 84064',26970,33189);
INSERT INTO "django_geo_db_zipcode" VALUES(37236,84065,-7,'Riverton, Utah 84065',26971,33190);
INSERT INTO "django_geo_db_zipcode" VALUES(37237,84066,-7,'Roosevelt, Utah 84066',26972,33191);
INSERT INTO "django_geo_db_zipcode" VALUES(37238,84067,-7,'Roy, Utah 84067',26973,33192);
INSERT INTO "django_geo_db_zipcode" VALUES(37239,84068,-7,'Park City, Utah 84068',26966,33193);
INSERT INTO "django_geo_db_zipcode" VALUES(37240,84069,-7,'Rush Valley, Utah 84069',26974,33194);
INSERT INTO "django_geo_db_zipcode" VALUES(37241,84070,-7,'Sandy, Utah 84070',26975,33195);
INSERT INTO "django_geo_db_zipcode" VALUES(37242,84071,-7,'Stockton, Utah 84071',26976,33196);
INSERT INTO "django_geo_db_zipcode" VALUES(37243,84072,-7,'Tabiona, Utah 84072',26977,33197);
INSERT INTO "django_geo_db_zipcode" VALUES(37244,84073,-7,'Talmage, Utah 84073',26978,33198);
INSERT INTO "django_geo_db_zipcode" VALUES(37245,84074,-7,'Tooele, Utah 84074',26979,33199);
INSERT INTO "django_geo_db_zipcode" VALUES(37246,84075,-7,'Syracuse, Utah 84075',26980,33200);
INSERT INTO "django_geo_db_zipcode" VALUES(37247,84076,-7,'Tridell, Utah 84076',26981,33201);
INSERT INTO "django_geo_db_zipcode" VALUES(37248,84078,-7,'Vernal, Utah 84078',26982,33202);
INSERT INTO "django_geo_db_zipcode" VALUES(37249,84079,-7,'Vernal, Utah 84079',26982,33157);
INSERT INTO "django_geo_db_zipcode" VALUES(37250,84080,-7,'Vernon, Utah 84080',26983,33203);
INSERT INTO "django_geo_db_zipcode" VALUES(37251,84082,-7,'Wallsburg, Utah 84082',26984,33204);
INSERT INTO "django_geo_db_zipcode" VALUES(37252,84083,-7,'Wendover, Utah 84083',26985,33205);
INSERT INTO "django_geo_db_zipcode" VALUES(37253,84084,-7,'West Jordan, Utah 84084',26986,33206);
INSERT INTO "django_geo_db_zipcode" VALUES(37254,84085,-7,'Whiterocks, Utah 84085',26987,33207);
INSERT INTO "django_geo_db_zipcode" VALUES(37255,84086,-7,'Woodruff, Utah 84086',26988,33208);
INSERT INTO "django_geo_db_zipcode" VALUES(37256,84087,-7,'Woods Cross, Utah 84087',26989,33209);
INSERT INTO "django_geo_db_zipcode" VALUES(37257,84088,-7,'West Jordan, Utah 84088',26986,33210);
INSERT INTO "django_geo_db_zipcode" VALUES(37258,84089,-7,'Clearfield, Utah 84089',26928,33140);
INSERT INTO "django_geo_db_zipcode" VALUES(37259,84090,-7,'Sandy, Utah 84090',26975,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37260,84091,-7,'Sandy, Utah 84091',26975,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37261,84092,-7,'Sandy, Utah 84092',26975,33212);
INSERT INTO "django_geo_db_zipcode" VALUES(37262,84093,-7,'Sandy, Utah 84093',26975,33213);
INSERT INTO "django_geo_db_zipcode" VALUES(37263,84094,-7,'Sandy, Utah 84094',26975,33214);
INSERT INTO "django_geo_db_zipcode" VALUES(37264,84095,-7,'South Jordan, Utah 84095',26990,33215);
INSERT INTO "django_geo_db_zipcode" VALUES(37265,84097,-7,'Orem, Utah 84097',26965,33216);
INSERT INTO "django_geo_db_zipcode" VALUES(37266,84098,-7,'Park City, Utah 84098',26966,33217);
INSERT INTO "django_geo_db_zipcode" VALUES(37267,84101,-7,'Salt Lake City, Utah 84101',26991,33218);
INSERT INTO "django_geo_db_zipcode" VALUES(37268,84102,-7,'Salt Lake City, Utah 84102',26991,33219);
INSERT INTO "django_geo_db_zipcode" VALUES(37269,84103,-7,'Salt Lake City, Utah 84103',26991,33220);
INSERT INTO "django_geo_db_zipcode" VALUES(37270,84104,-7,'Salt Lake City, Utah 84104',26991,33221);
INSERT INTO "django_geo_db_zipcode" VALUES(37271,84105,-7,'Salt Lake City, Utah 84105',26991,33222);
INSERT INTO "django_geo_db_zipcode" VALUES(37272,84106,-7,'Salt Lake City, Utah 84106',26991,33223);
INSERT INTO "django_geo_db_zipcode" VALUES(37273,84107,-7,'Salt Lake City, Utah 84107',26991,33224);
INSERT INTO "django_geo_db_zipcode" VALUES(37274,84108,-7,'Salt Lake City, Utah 84108',26991,33225);
INSERT INTO "django_geo_db_zipcode" VALUES(37275,84109,-7,'Salt Lake City, Utah 84109',26991,33226);
INSERT INTO "django_geo_db_zipcode" VALUES(37276,84110,-7,'Salt Lake City, Utah 84110',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37277,84111,-7,'Salt Lake City, Utah 84111',26991,33227);
INSERT INTO "django_geo_db_zipcode" VALUES(37278,84112,-7,'Salt Lake City, Utah 84112',26991,33228);
INSERT INTO "django_geo_db_zipcode" VALUES(37279,84113,-7,'Salt Lake City, Utah 84113',26991,33229);
INSERT INTO "django_geo_db_zipcode" VALUES(37280,84114,-7,'Salt Lake City, Utah 84114',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37281,84115,-7,'Salt Lake City, Utah 84115',26991,33230);
INSERT INTO "django_geo_db_zipcode" VALUES(37282,84116,-7,'Salt Lake City, Utah 84116',26991,33231);
INSERT INTO "django_geo_db_zipcode" VALUES(37283,84117,-7,'Salt Lake City, Utah 84117',26991,33232);
INSERT INTO "django_geo_db_zipcode" VALUES(37284,84118,-7,'Salt Lake City, Utah 84118',26991,33233);
INSERT INTO "django_geo_db_zipcode" VALUES(37285,84119,-7,'Salt Lake City, Utah 84119',26991,33234);
INSERT INTO "django_geo_db_zipcode" VALUES(37286,84120,-7,'Salt Lake City, Utah 84120',26991,33235);
INSERT INTO "django_geo_db_zipcode" VALUES(37287,84121,-7,'Salt Lake City, Utah 84121',26991,33236);
INSERT INTO "django_geo_db_zipcode" VALUES(37288,84122,-7,'Salt Lake City, Utah 84122',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37289,84123,-7,'Salt Lake City, Utah 84123',26991,33237);
INSERT INTO "django_geo_db_zipcode" VALUES(37290,84124,-7,'Salt Lake City, Utah 84124',26991,33238);
INSERT INTO "django_geo_db_zipcode" VALUES(37291,84125,-7,'Salt Lake City, Utah 84125',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37292,84126,-7,'Salt Lake City, Utah 84126',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37293,84127,-7,'Salt Lake City, Utah 84127',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37294,84128,-7,'Salt Lake City, Utah 84128',26991,33239);
INSERT INTO "django_geo_db_zipcode" VALUES(37295,84130,-7,'Salt Lake City, Utah 84130',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37296,84131,-7,'Salt Lake City, Utah 84131',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37297,84132,-7,'Salt Lake City, Utah 84132',26991,33240);
INSERT INTO "django_geo_db_zipcode" VALUES(37298,84133,-7,'Salt Lake City, Utah 84133',26991,33241);
INSERT INTO "django_geo_db_zipcode" VALUES(37299,84134,-7,'Salt Lake City, Utah 84134',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37300,84135,-7,'Salt Lake City, Utah 84135',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37301,84136,-7,'Salt Lake City, Utah 84136',26991,33242);
INSERT INTO "django_geo_db_zipcode" VALUES(37302,84137,-7,'Salt Lake City, Utah 84137',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37303,84138,-7,'Salt Lake City, Utah 84138',26991,33243);
INSERT INTO "django_geo_db_zipcode" VALUES(37304,84139,-7,'Salt Lake City, Utah 84139',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37305,84140,-7,'Salt Lake City, Utah 84140',26991,33244);
INSERT INTO "django_geo_db_zipcode" VALUES(37306,84141,-7,'Salt Lake City, Utah 84141',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37307,84142,-7,'Salt Lake City, Utah 84142',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37308,84143,-7,'Salt Lake City, Utah 84143',26991,33245);
INSERT INTO "django_geo_db_zipcode" VALUES(37309,84144,-7,'Salt Lake City, Utah 84144',26991,33246);
INSERT INTO "django_geo_db_zipcode" VALUES(37310,84145,-7,'Salt Lake City, Utah 84145',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37311,84147,-7,'Salt Lake City, Utah 84147',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37312,84148,-7,'Salt Lake City, Utah 84148',26991,33247);
INSERT INTO "django_geo_db_zipcode" VALUES(37313,84150,-7,'Salt Lake City, Utah 84150',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37314,84151,-7,'Salt Lake City, Utah 84151',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37315,84152,-7,'Salt Lake City, Utah 84152',26991,33248);
INSERT INTO "django_geo_db_zipcode" VALUES(37316,84153,-7,'Salt Lake City, Utah 84153',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37317,84157,-7,'Salt Lake City, Utah 84157',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37318,84158,-7,'Salt Lake City, Utah 84158',26991,33249);
INSERT INTO "django_geo_db_zipcode" VALUES(37319,84165,-7,'Salt Lake City, Utah 84165',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37320,84170,-7,'Salt Lake City, Utah 84170',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37321,84171,-7,'Salt Lake City, Utah 84171',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37322,84180,-7,'Salt Lake City, Utah 84180',26991,33250);
INSERT INTO "django_geo_db_zipcode" VALUES(37323,84184,-7,'Salt Lake City, Utah 84184',26991,33251);
INSERT INTO "django_geo_db_zipcode" VALUES(37324,84185,-7,'Salt Lake City, Utah 84185',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37325,84189,-7,'Salt Lake City, Utah 84189',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37326,84190,-7,'Salt Lake City, Utah 84190',26991,33211);
INSERT INTO "django_geo_db_zipcode" VALUES(37327,84199,-7,'Salt Lake City, Utah 84199',26991,33252);
INSERT INTO "django_geo_db_zipcode" VALUES(37328,84201,-7,'Ogden, Utah 84201',26992,33253);
INSERT INTO "django_geo_db_zipcode" VALUES(37329,84244,-7,'Ogden, Utah 84244',26992,33254);
INSERT INTO "django_geo_db_zipcode" VALUES(37330,84252,-7,'Green River, Utah 84252',26993,33255);
INSERT INTO "django_geo_db_zipcode" VALUES(37331,84301,-7,'Bear River City, Utah 84301',26994,33256);
INSERT INTO "django_geo_db_zipcode" VALUES(37332,84302,-7,'Brigham City, Utah 84302',26995,33257);
INSERT INTO "django_geo_db_zipcode" VALUES(37333,84304,-7,'Cache Junction, Utah 84304',26996,33258);
INSERT INTO "django_geo_db_zipcode" VALUES(37334,84305,-7,'Clarkston, Utah 84305',26997,33259);
INSERT INTO "django_geo_db_zipcode" VALUES(37335,84306,-7,'Collinston, Utah 84306',26998,33260);
INSERT INTO "django_geo_db_zipcode" VALUES(37336,84307,-7,'Corinne, Utah 84307',26999,33261);
INSERT INTO "django_geo_db_zipcode" VALUES(37337,84308,-7,'Cornish, Utah 84308',27000,33262);
INSERT INTO "django_geo_db_zipcode" VALUES(37338,84309,-7,'Deweyville, Utah 84309',27001,33263);
INSERT INTO "django_geo_db_zipcode" VALUES(37339,84310,-7,'Eden, Utah 84310',27002,33264);
INSERT INTO "django_geo_db_zipcode" VALUES(37340,84311,-7,'Fielding, Utah 84311',27003,33265);
INSERT INTO "django_geo_db_zipcode" VALUES(37341,84312,-7,'Garland, Utah 84312',27004,33266);
INSERT INTO "django_geo_db_zipcode" VALUES(37342,84313,-7,'Grouse Creek, Utah 84313',27005,33267);
INSERT INTO "django_geo_db_zipcode" VALUES(37343,84314,-7,'Honeyville, Utah 84314',27006,33268);
INSERT INTO "django_geo_db_zipcode" VALUES(37344,84315,-7,'Hooper, Utah 84315',27007,33269);
INSERT INTO "django_geo_db_zipcode" VALUES(37345,84316,-7,'Howell, Utah 84316',27008,33270);
INSERT INTO "django_geo_db_zipcode" VALUES(37346,84317,-7,'Huntsville, Utah 84317',27009,33271);
INSERT INTO "django_geo_db_zipcode" VALUES(37347,84318,-7,'Hyde Park, Utah 84318',27010,33272);
INSERT INTO "django_geo_db_zipcode" VALUES(37348,84319,-7,'Hyrum, Utah 84319',27011,33273);
INSERT INTO "django_geo_db_zipcode" VALUES(37349,84320,-7,'Lewiston, Utah 84320',27012,33274);
INSERT INTO "django_geo_db_zipcode" VALUES(37350,84321,-7,'Logan, Utah 84321',27013,33275);
INSERT INTO "django_geo_db_zipcode" VALUES(37351,84322,-7,'Logan, Utah 84322',27013,33276);
INSERT INTO "django_geo_db_zipcode" VALUES(37352,84323,-7,'Logan, Utah 84323',27013,33277);
INSERT INTO "django_geo_db_zipcode" VALUES(37353,84324,-7,'Mantua, Utah 84324',27014,33278);
INSERT INTO "django_geo_db_zipcode" VALUES(37354,84325,-7,'Mendon, Utah 84325',27015,33279);
INSERT INTO "django_geo_db_zipcode" VALUES(37355,84326,-7,'Millville, Utah 84326',27016,33280);
INSERT INTO "django_geo_db_zipcode" VALUES(37356,84327,-7,'Newton, Utah 84327',27017,33281);
INSERT INTO "django_geo_db_zipcode" VALUES(37357,84328,-7,'Paradise, Utah 84328',27018,33282);
INSERT INTO "django_geo_db_zipcode" VALUES(37358,84329,-7,'Park Valley, Utah 84329',27019,33283);
INSERT INTO "django_geo_db_zipcode" VALUES(37359,84330,-7,'Plymouth, Utah 84330',27020,33284);
INSERT INTO "django_geo_db_zipcode" VALUES(37360,84331,-7,'Portage, Utah 84331',27021,33285);
INSERT INTO "django_geo_db_zipcode" VALUES(37361,84332,-7,'Providence, Utah 84332',27022,33286);
INSERT INTO "django_geo_db_zipcode" VALUES(37362,84333,-7,'Richmond, Utah 84333',27023,33287);
INSERT INTO "django_geo_db_zipcode" VALUES(37363,84334,-7,'Riverside, Utah 84334',27024,33288);
INSERT INTO "django_geo_db_zipcode" VALUES(37364,84335,-7,'Smithfield, Utah 84335',27025,33289);
INSERT INTO "django_geo_db_zipcode" VALUES(37365,84336,-7,'Snowville, Utah 84336',27026,33290);
INSERT INTO "django_geo_db_zipcode" VALUES(37366,84337,-7,'Tremonton, Utah 84337',27027,33291);
INSERT INTO "django_geo_db_zipcode" VALUES(37367,84338,-7,'Trenton, Utah 84338',27028,33292);
INSERT INTO "django_geo_db_zipcode" VALUES(37368,84339,-7,'Wellsville, Utah 84339',27029,33293);
INSERT INTO "django_geo_db_zipcode" VALUES(37369,84340,-7,'Willard, Utah 84340',27030,33294);
INSERT INTO "django_geo_db_zipcode" VALUES(37370,84341,-7,'Logan, Utah 84341',27013,33295);
INSERT INTO "django_geo_db_zipcode" VALUES(37371,84346,-7,'South Willard, Utah 84346',27031,33296);
INSERT INTO "django_geo_db_zipcode" VALUES(37372,84401,-7,'Ogden, Utah 84401',26992,33297);
INSERT INTO "django_geo_db_zipcode" VALUES(37373,84402,-7,'Ogden, Utah 84402',26992,33254);
INSERT INTO "django_geo_db_zipcode" VALUES(37374,84403,-7,'Ogden, Utah 84403',26992,33298);
INSERT INTO "django_geo_db_zipcode" VALUES(37375,84404,-7,'Ogden, Utah 84404',26992,33299);
INSERT INTO "django_geo_db_zipcode" VALUES(37376,84405,-7,'Ogden, Utah 84405',26992,33300);
INSERT INTO "django_geo_db_zipcode" VALUES(37377,84407,-7,'Ogden, Utah 84407',26992,33301);
INSERT INTO "django_geo_db_zipcode" VALUES(37378,84408,-7,'Ogden, Utah 84408',26992,33302);
INSERT INTO "django_geo_db_zipcode" VALUES(37379,84409,-7,'Ogden, Utah 84409',26992,33254);
INSERT INTO "django_geo_db_zipcode" VALUES(37380,84412,-7,'Ogden, Utah 84412',26992,33254);
INSERT INTO "django_geo_db_zipcode" VALUES(37381,84414,-7,'Ogden, Utah 84414',26992,33303);
INSERT INTO "django_geo_db_zipcode" VALUES(37382,84415,-7,'Ogden, Utah 84415',26992,33254);
INSERT INTO "django_geo_db_zipcode" VALUES(37383,84501,-7,'Price, Utah 84501',27032,33304);
INSERT INTO "django_geo_db_zipcode" VALUES(37384,84510,-7,'Aneth, Utah 84510',27033,33305);
INSERT INTO "django_geo_db_zipcode" VALUES(37385,84511,-7,'Blanding, Utah 84511',27034,33306);
INSERT INTO "django_geo_db_zipcode" VALUES(37386,84512,-7,'Bluff, Utah 84512',27035,33307);
INSERT INTO "django_geo_db_zipcode" VALUES(37387,84513,-7,'Castle Dale, Utah 84513',27036,33308);
INSERT INTO "django_geo_db_zipcode" VALUES(37388,84515,-7,'Cisco, Utah 84515',27037,33309);
INSERT INTO "django_geo_db_zipcode" VALUES(37389,84516,-7,'Clawson, Utah 84516',27038,33310);
INSERT INTO "django_geo_db_zipcode" VALUES(37390,84518,-7,'Cleveland, Utah 84518',27039,33311);
INSERT INTO "django_geo_db_zipcode" VALUES(37391,84520,-7,'East Carbon, Utah 84520',27040,33312);
INSERT INTO "django_geo_db_zipcode" VALUES(37392,84521,-7,'Elmo, Utah 84521',27041,33313);
INSERT INTO "django_geo_db_zipcode" VALUES(37393,84522,-7,'Emery, Utah 84522',27042,33314);
INSERT INTO "django_geo_db_zipcode" VALUES(37394,84523,-7,'Ferron, Utah 84523',27043,33315);
INSERT INTO "django_geo_db_zipcode" VALUES(37395,84525,-7,'Green River, Utah 84525',26993,33316);
INSERT INTO "django_geo_db_zipcode" VALUES(37396,84526,-7,'Helper, Utah 84526',27044,33317);
INSERT INTO "django_geo_db_zipcode" VALUES(37397,84527,-7,'Hiawatha, Utah 84527',27045,33318);
INSERT INTO "django_geo_db_zipcode" VALUES(37398,84528,-7,'Huntington, Utah 84528',27046,33319);
INSERT INTO "django_geo_db_zipcode" VALUES(37399,84529,-7,'Kenilworth, Utah 84529',27047,33320);
INSERT INTO "django_geo_db_zipcode" VALUES(37400,84530,-7,'La Sal, Utah 84530',27048,33321);
INSERT INTO "django_geo_db_zipcode" VALUES(37401,84531,-7,'Mexican Hat, Utah 84531',27049,33322);
INSERT INTO "django_geo_db_zipcode" VALUES(37402,84532,-7,'Moab, Utah 84532',27050,33323);
INSERT INTO "django_geo_db_zipcode" VALUES(37403,84533,-7,'Lake Powell, Utah 84533',27051,33324);
INSERT INTO "django_geo_db_zipcode" VALUES(37404,84534,-7,'Montezuma Creek, Utah 84534',27052,33325);
INSERT INTO "django_geo_db_zipcode" VALUES(37405,84535,-7,'Monticello, Utah 84535',27053,33326);
INSERT INTO "django_geo_db_zipcode" VALUES(37406,84536,-7,'Monument Valley, Arizona 84536',27054,33327);
INSERT INTO "django_geo_db_zipcode" VALUES(37407,84537,-7,'Orangeville, Utah 84537',27055,33328);
INSERT INTO "django_geo_db_zipcode" VALUES(37408,84539,-7,'Sunnyside, Utah 84539',27056,33329);
INSERT INTO "django_geo_db_zipcode" VALUES(37409,84540,-7,'Thompson, Utah 84540',27057,33330);
INSERT INTO "django_geo_db_zipcode" VALUES(37410,84542,-7,'Wellington, Utah 84542',27058,33331);
INSERT INTO "django_geo_db_zipcode" VALUES(37411,84601,-7,'Provo, Utah 84601',27059,33332);
INSERT INTO "django_geo_db_zipcode" VALUES(37412,84602,-7,'Provo, Utah 84602',27059,33333);
INSERT INTO "django_geo_db_zipcode" VALUES(37413,84603,-7,'Provo, Utah 84603',27059,33334);
INSERT INTO "django_geo_db_zipcode" VALUES(37414,84604,-7,'Provo, Utah 84604',27059,33335);
INSERT INTO "django_geo_db_zipcode" VALUES(37415,84605,-7,'Provo, Utah 84605',27059,33184);
INSERT INTO "django_geo_db_zipcode" VALUES(37416,84606,-7,'Provo, Utah 84606',27059,33336);
INSERT INTO "django_geo_db_zipcode" VALUES(37417,84620,-7,'Aurora, Utah 84620',27060,33337);
INSERT INTO "django_geo_db_zipcode" VALUES(37418,84621,-7,'Axtell, Utah 84621',27061,33338);
INSERT INTO "django_geo_db_zipcode" VALUES(37419,84622,-7,'Centerfield, Utah 84622',27062,33339);
INSERT INTO "django_geo_db_zipcode" VALUES(37420,84623,-7,'Chester, Utah 84623',27063,33340);
INSERT INTO "django_geo_db_zipcode" VALUES(37421,84624,-7,'Delta, Utah 84624',27064,33341);
INSERT INTO "django_geo_db_zipcode" VALUES(37422,84626,-7,'Elberta, Utah 84626',27065,33342);
INSERT INTO "django_geo_db_zipcode" VALUES(37423,84627,-7,'Ephraim, Utah 84627',27066,33343);
INSERT INTO "django_geo_db_zipcode" VALUES(37424,84628,-7,'Eureka, Utah 84628',27067,33344);
INSERT INTO "django_geo_db_zipcode" VALUES(37425,84629,-7,'Fairview, Utah 84629',27068,33345);
INSERT INTO "django_geo_db_zipcode" VALUES(37426,84630,-7,'Fayette, Utah 84630',27069,33346);
INSERT INTO "django_geo_db_zipcode" VALUES(37427,84631,-7,'Fillmore, Utah 84631',27070,33347);
INSERT INTO "django_geo_db_zipcode" VALUES(37428,84632,-7,'Fountain Green, Utah 84632',27071,33348);
INSERT INTO "django_geo_db_zipcode" VALUES(37429,84633,-7,'Goshen, Utah 84633',27072,33349);
INSERT INTO "django_geo_db_zipcode" VALUES(37430,84634,-7,'Gunnison, Utah 84634',27073,33350);
INSERT INTO "django_geo_db_zipcode" VALUES(37431,84635,-7,'Hinckley, Utah 84635',27074,33351);
INSERT INTO "django_geo_db_zipcode" VALUES(37432,84636,-7,'Holden, Utah 84636',27075,33352);
INSERT INTO "django_geo_db_zipcode" VALUES(37433,84637,-7,'Kanosh, Utah 84637',27076,33353);
INSERT INTO "django_geo_db_zipcode" VALUES(37434,84638,-7,'Leamington, Utah 84638',27077,33354);
INSERT INTO "django_geo_db_zipcode" VALUES(37435,84639,-7,'Levan, Utah 84639',27078,33355);
INSERT INTO "django_geo_db_zipcode" VALUES(37436,84640,-7,'Lynndyl, Utah 84640',27079,33356);
INSERT INTO "django_geo_db_zipcode" VALUES(37437,84642,-7,'Manti, Utah 84642',27080,33357);
INSERT INTO "django_geo_db_zipcode" VALUES(37438,84643,-7,'Mayfield, Utah 84643',27081,33358);
INSERT INTO "django_geo_db_zipcode" VALUES(37439,84644,-7,'Meadow, Utah 84644',27082,33359);
INSERT INTO "django_geo_db_zipcode" VALUES(37440,84645,-7,'Mona, Utah 84645',27083,33360);
INSERT INTO "django_geo_db_zipcode" VALUES(37441,84646,-7,'Moroni, Utah 84646',27084,33361);
INSERT INTO "django_geo_db_zipcode" VALUES(37442,84647,-7,'Mount Pleasant, Utah 84647',27085,33362);
INSERT INTO "django_geo_db_zipcode" VALUES(37443,84648,-7,'Nephi, Utah 84648',27086,33363);
INSERT INTO "django_geo_db_zipcode" VALUES(37444,84649,-7,'Oak City, Utah 84649',27087,33364);
INSERT INTO "django_geo_db_zipcode" VALUES(37445,84650,-7,'Oasis, Utah 84650',27088,33365);
INSERT INTO "django_geo_db_zipcode" VALUES(37446,84651,-7,'Payson, Utah 84651',27089,33366);
INSERT INTO "django_geo_db_zipcode" VALUES(37447,84652,-7,'Redmond, Utah 84652',27090,33367);
INSERT INTO "django_geo_db_zipcode" VALUES(37448,84653,-7,'Salem, Utah 84653',27091,33368);
INSERT INTO "django_geo_db_zipcode" VALUES(37449,84654,-7,'Salina, Utah 84654',27092,33369);
INSERT INTO "django_geo_db_zipcode" VALUES(37450,84655,-7,'Santaquin, Utah 84655',27093,33370);
INSERT INTO "django_geo_db_zipcode" VALUES(37451,84656,-7,'Scipio, Utah 84656',27094,33371);
INSERT INTO "django_geo_db_zipcode" VALUES(37452,84657,-7,'Sigurd, Utah 84657',27095,33372);
INSERT INTO "django_geo_db_zipcode" VALUES(37453,84660,-7,'Spanish Fork, Utah 84660',27096,33373);
INSERT INTO "django_geo_db_zipcode" VALUES(37454,84662,-7,'Spring City, Utah 84662',27097,33374);
INSERT INTO "django_geo_db_zipcode" VALUES(37455,84663,-7,'Springville, Utah 84663',27098,33375);
INSERT INTO "django_geo_db_zipcode" VALUES(37456,84664,-7,'Mapleton, Utah 84664',27099,33376);
INSERT INTO "django_geo_db_zipcode" VALUES(37457,84665,-7,'Sterling, Utah 84665',27100,33377);
INSERT INTO "django_geo_db_zipcode" VALUES(37458,84667,-7,'Wales, Utah 84667',27101,33378);
INSERT INTO "django_geo_db_zipcode" VALUES(37459,84701,-7,'Richfield, Utah 84701',27102,33379);
INSERT INTO "django_geo_db_zipcode" VALUES(37460,84710,-7,'Alton, Utah 84710',27103,33380);
INSERT INTO "django_geo_db_zipcode" VALUES(37461,84711,-7,'Annabella, Utah 84711',27104,33381);
INSERT INTO "django_geo_db_zipcode" VALUES(37462,84712,-7,'Antimony, Utah 84712',27105,33382);
INSERT INTO "django_geo_db_zipcode" VALUES(37463,84713,-7,'Beaver, Utah 84713',27106,33383);
INSERT INTO "django_geo_db_zipcode" VALUES(37464,84714,-7,'Beryl, Utah 84714',27107,33384);
INSERT INTO "django_geo_db_zipcode" VALUES(37465,84715,-7,'Bicknell, Utah 84715',27108,33385);
INSERT INTO "django_geo_db_zipcode" VALUES(37466,84716,-7,'Boulder, Utah 84716',27109,33386);
INSERT INTO "django_geo_db_zipcode" VALUES(37467,84717,-7,'Bryce Canyon, Utah 84717',27110,33387);
INSERT INTO "django_geo_db_zipcode" VALUES(37468,84718,-7,'Cannonville, Utah 84718',27111,33388);
INSERT INTO "django_geo_db_zipcode" VALUES(37469,84719,-7,'Brian Head, Utah 84719',27112,33389);
INSERT INTO "django_geo_db_zipcode" VALUES(37470,84720,-7,'Cedar City, Utah 84720',27113,33390);
INSERT INTO "django_geo_db_zipcode" VALUES(37471,84721,-7,'Cedar City, Utah 84721',27113,33391);
INSERT INTO "django_geo_db_zipcode" VALUES(37472,84722,-7,'Central, Utah 84722',27114,33392);
INSERT INTO "django_geo_db_zipcode" VALUES(37473,84723,-7,'Circleville, Utah 84723',27115,33393);
INSERT INTO "django_geo_db_zipcode" VALUES(37474,84724,-7,'Elsinore, Utah 84724',27116,33394);
INSERT INTO "django_geo_db_zipcode" VALUES(37475,84725,-7,'Enterprise, Utah 84725',27117,33395);
INSERT INTO "django_geo_db_zipcode" VALUES(37476,84726,-7,'Escalante, Utah 84726',27118,33396);
INSERT INTO "django_geo_db_zipcode" VALUES(37477,84728,-7,'Garrison, Utah 84728',27119,33397);
INSERT INTO "django_geo_db_zipcode" VALUES(37478,84729,-7,'Glendale, Utah 84729',27120,33398);
INSERT INTO "django_geo_db_zipcode" VALUES(37479,84730,-7,'Glenwood, Utah 84730',27121,33399);
INSERT INTO "django_geo_db_zipcode" VALUES(37480,84731,-7,'Greenville, Utah 84731',27122,33400);
INSERT INTO "django_geo_db_zipcode" VALUES(37481,84732,-7,'Greenwich, Utah 84732',27123,33401);
INSERT INTO "django_geo_db_zipcode" VALUES(37482,84733,-7,'Gunlock, Utah 84733',27124,33402);
INSERT INTO "django_geo_db_zipcode" VALUES(37483,84734,-7,'Hanksville, Utah 84734',27125,33403);
INSERT INTO "django_geo_db_zipcode" VALUES(37484,84735,-7,'Hatch, Utah 84735',27126,33404);
INSERT INTO "django_geo_db_zipcode" VALUES(37485,84736,-7,'Henrieville, Utah 84736',27127,33405);
INSERT INTO "django_geo_db_zipcode" VALUES(37486,84737,-7,'Hurricane, Utah 84737',27128,33406);
INSERT INTO "django_geo_db_zipcode" VALUES(37487,84738,-7,'Ivins, Utah 84738',27129,33407);
INSERT INTO "django_geo_db_zipcode" VALUES(37488,84739,-7,'Joseph, Utah 84739',27130,33408);
INSERT INTO "django_geo_db_zipcode" VALUES(37489,84740,-7,'Junction, Utah 84740',27131,33409);
INSERT INTO "django_geo_db_zipcode" VALUES(37490,84741,-7,'Kanab, Utah 84741',27132,33410);
INSERT INTO "django_geo_db_zipcode" VALUES(37491,84742,-7,'Kanarraville, Utah 84742',27133,33411);
INSERT INTO "django_geo_db_zipcode" VALUES(37492,84743,-7,'Kingston, Utah 84743',27134,33412);
INSERT INTO "django_geo_db_zipcode" VALUES(37493,84744,-7,'Koosharem, Utah 84744',27135,33413);
INSERT INTO "django_geo_db_zipcode" VALUES(37494,84745,-7,'La Verkin, Utah 84745',27136,33414);
INSERT INTO "django_geo_db_zipcode" VALUES(37495,84746,-7,'Leeds, Utah 84746',27137,33415);
INSERT INTO "django_geo_db_zipcode" VALUES(37496,84747,-7,'Loa, Utah 84747',27138,33416);
INSERT INTO "django_geo_db_zipcode" VALUES(37497,84749,-7,'Lyman, Utah 84749',27139,33417);
INSERT INTO "django_geo_db_zipcode" VALUES(37498,84750,-7,'Marysvale, Utah 84750',27140,33418);
INSERT INTO "django_geo_db_zipcode" VALUES(37499,84751,-7,'Milford, Utah 84751',27141,33419);
INSERT INTO "django_geo_db_zipcode" VALUES(37500,84752,-7,'Minersville, Utah 84752',27142,33420);
INSERT INTO "django_geo_db_zipcode" VALUES(37501,84753,-7,'Modena, Utah 84753',27143,33421);
INSERT INTO "django_geo_db_zipcode" VALUES(37502,84754,-7,'Monroe, Utah 84754',27144,33422);
INSERT INTO "django_geo_db_zipcode" VALUES(37503,84755,-7,'Mount Carmel, Utah 84755',27145,33423);
INSERT INTO "django_geo_db_zipcode" VALUES(37504,84756,-7,'Newcastle, Utah 84756',27146,33424);
INSERT INTO "django_geo_db_zipcode" VALUES(37505,84757,-7,'New Harmony, Utah 84757',27147,33425);
INSERT INTO "django_geo_db_zipcode" VALUES(37506,84758,-7,'Orderville, Utah 84758',27148,33426);
INSERT INTO "django_geo_db_zipcode" VALUES(37507,84759,-7,'Panguitch, Utah 84759',27149,33427);
INSERT INTO "django_geo_db_zipcode" VALUES(37508,84760,-7,'Paragonah, Utah 84760',27150,33428);
INSERT INTO "django_geo_db_zipcode" VALUES(37509,84761,-7,'Parowan, Utah 84761',27151,33429);
INSERT INTO "django_geo_db_zipcode" VALUES(37510,84762,-7,'Duck Creek Village, Utah 84762',27152,33430);
INSERT INTO "django_geo_db_zipcode" VALUES(37511,84763,-7,'Rockville, Utah 84763',27153,33431);
INSERT INTO "django_geo_db_zipcode" VALUES(37512,84764,-7,'Bryce, Utah 84764',27154,33432);
INSERT INTO "django_geo_db_zipcode" VALUES(37513,84765,-7,'Santa Clara, Utah 84765',27155,33433);
INSERT INTO "django_geo_db_zipcode" VALUES(37514,84766,-7,'Sevier, Utah 84766',27156,33434);
INSERT INTO "django_geo_db_zipcode" VALUES(37515,84767,-7,'Springdale, Utah 84767',27157,33435);
INSERT INTO "django_geo_db_zipcode" VALUES(37516,84770,-7,'Saint George, Utah 84770',27158,33436);
INSERT INTO "django_geo_db_zipcode" VALUES(37517,84771,-7,'Saint George, Utah 84771',27158,33437);
INSERT INTO "django_geo_db_zipcode" VALUES(37518,84772,-7,'Summit, Utah 84772',27159,33438);
INSERT INTO "django_geo_db_zipcode" VALUES(37519,84773,-7,'Teasdale, Utah 84773',27160,33439);
INSERT INTO "django_geo_db_zipcode" VALUES(37520,84774,-7,'Toquerville, Utah 84774',27161,33440);
INSERT INTO "django_geo_db_zipcode" VALUES(37521,84775,-7,'Torrey, Utah 84775',27162,33441);
INSERT INTO "django_geo_db_zipcode" VALUES(37522,84776,-7,'Tropic, Utah 84776',27163,33442);
INSERT INTO "django_geo_db_zipcode" VALUES(37523,84779,-7,'Virgin, Utah 84779',27164,33443);
INSERT INTO "django_geo_db_zipcode" VALUES(37524,84780,-7,'Washington, Utah 84780',27165,33444);
INSERT INTO "django_geo_db_zipcode" VALUES(37525,84781,-7,'Pine Valley, Utah 84781',27166,33445);
INSERT INTO "django_geo_db_zipcode" VALUES(37526,84782,-7,'Veyo, Utah 84782',27167,33446);
INSERT INTO "django_geo_db_zipcode" VALUES(37527,84783,-7,'Dammeron Valley, Utah 84783',27168,33447);
INSERT INTO "django_geo_db_zipcode" VALUES(37528,84784,-7,'Hildale, Utah 84784',27169,33448);
INSERT INTO "django_geo_db_zipcode" VALUES(37529,84790,-7,'Saint George, Utah 84790',27158,33449);
INSERT INTO "django_geo_db_zipcode" VALUES(37530,84791,-7,'Saint George, Utah 84791',27158,33437);
INSERT INTO "django_geo_db_zipcode" VALUES(37531,84821,-7,'Logan, Utah 84821',27013,33450);
INSERT INTO "django_geo_db_zipcode" VALUES(37532,84910,-7,'North Salt Lake, Utah 84910',26962,33451);
INSERT INTO "django_geo_db_zipcode" VALUES(37533,84915,-7,'Clinton, Utah 84915',27170,33452);
INSERT INTO "django_geo_db_zipcode" VALUES(37534,84947,-7,'Lyman, Utah 84947',27139,33453);
INSERT INTO "django_geo_db_zipcode" VALUES(37535,85001,-7,'Phoenix, Arizona 85001',27171,33454);
INSERT INTO "django_geo_db_zipcode" VALUES(37536,85002,-7,'Phoenix, Arizona 85002',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37537,85003,-7,'Phoenix, Arizona 85003',27171,33456);
INSERT INTO "django_geo_db_zipcode" VALUES(37538,85004,-7,'Phoenix, Arizona 85004',27171,33457);
INSERT INTO "django_geo_db_zipcode" VALUES(37539,85005,-7,'Phoenix, Arizona 85005',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37540,85006,-7,'Phoenix, Arizona 85006',27171,33458);
INSERT INTO "django_geo_db_zipcode" VALUES(37541,85007,-7,'Phoenix, Arizona 85007',27171,33459);
INSERT INTO "django_geo_db_zipcode" VALUES(37542,85008,-7,'Phoenix, Arizona 85008',27171,33460);
INSERT INTO "django_geo_db_zipcode" VALUES(37543,85009,-7,'Phoenix, Arizona 85009',27171,33461);
INSERT INTO "django_geo_db_zipcode" VALUES(37544,85010,-7,'Phoenix, Arizona 85010',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37545,85011,-7,'Phoenix, Arizona 85011',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37546,85012,-7,'Phoenix, Arizona 85012',27171,33462);
INSERT INTO "django_geo_db_zipcode" VALUES(37547,85013,-7,'Phoenix, Arizona 85013',27171,33463);
INSERT INTO "django_geo_db_zipcode" VALUES(37548,85014,-7,'Phoenix, Arizona 85014',27171,33464);
INSERT INTO "django_geo_db_zipcode" VALUES(37549,85015,-7,'Phoenix, Arizona 85015',27171,33465);
INSERT INTO "django_geo_db_zipcode" VALUES(37550,85016,-7,'Phoenix, Arizona 85016',27171,33466);
INSERT INTO "django_geo_db_zipcode" VALUES(37551,85017,-7,'Phoenix, Arizona 85017',27171,33467);
INSERT INTO "django_geo_db_zipcode" VALUES(37552,85018,-7,'Phoenix, Arizona 85018',27171,33468);
INSERT INTO "django_geo_db_zipcode" VALUES(37553,85019,-7,'Phoenix, Arizona 85019',27171,33469);
INSERT INTO "django_geo_db_zipcode" VALUES(37554,85020,-7,'Phoenix, Arizona 85020',27171,33470);
INSERT INTO "django_geo_db_zipcode" VALUES(37555,85021,-7,'Phoenix, Arizona 85021',27171,33471);
INSERT INTO "django_geo_db_zipcode" VALUES(37556,85022,-7,'Phoenix, Arizona 85022',27171,33472);
INSERT INTO "django_geo_db_zipcode" VALUES(37557,85023,-7,'Phoenix, Arizona 85023',27171,33473);
INSERT INTO "django_geo_db_zipcode" VALUES(37558,85024,-7,'Phoenix, Arizona 85024',27171,33474);
INSERT INTO "django_geo_db_zipcode" VALUES(37559,85025,-7,'Phoenix, Arizona 85025',27171,33475);
INSERT INTO "django_geo_db_zipcode" VALUES(37560,85026,-7,'Phoenix, Arizona 85026',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37561,85027,-7,'Phoenix, Arizona 85027',27171,33476);
INSERT INTO "django_geo_db_zipcode" VALUES(37562,85028,-7,'Phoenix, Arizona 85028',27171,33477);
INSERT INTO "django_geo_db_zipcode" VALUES(37563,85029,-7,'Phoenix, Arizona 85029',27171,33478);
INSERT INTO "django_geo_db_zipcode" VALUES(37564,85030,-7,'Phoenix, Arizona 85030',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37565,85031,-7,'Phoenix, Arizona 85031',27171,33479);
INSERT INTO "django_geo_db_zipcode" VALUES(37566,85032,-7,'Phoenix, Arizona 85032',27171,33480);
INSERT INTO "django_geo_db_zipcode" VALUES(37567,85033,-7,'Phoenix, Arizona 85033',27171,33481);
INSERT INTO "django_geo_db_zipcode" VALUES(37568,85034,-7,'Phoenix, Arizona 85034',27171,33482);
INSERT INTO "django_geo_db_zipcode" VALUES(37569,85035,-7,'Phoenix, Arizona 85035',27171,33483);
INSERT INTO "django_geo_db_zipcode" VALUES(37570,85036,-7,'Phoenix, Arizona 85036',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37571,85037,-7,'Phoenix, Arizona 85037',27171,33484);
INSERT INTO "django_geo_db_zipcode" VALUES(37572,85038,-7,'Phoenix, Arizona 85038',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37573,85039,-7,'Phoenix, Arizona 85039',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37574,85040,-7,'Phoenix, Arizona 85040',27171,33485);
INSERT INTO "django_geo_db_zipcode" VALUES(37575,85041,-7,'Phoenix, Arizona 85041',27171,33486);
INSERT INTO "django_geo_db_zipcode" VALUES(37576,85042,-7,'Phoenix, Arizona 85042',27171,33487);
INSERT INTO "django_geo_db_zipcode" VALUES(37577,85043,-7,'Phoenix, Arizona 85043',27171,33488);
INSERT INTO "django_geo_db_zipcode" VALUES(37578,85044,-7,'Phoenix, Arizona 85044',27171,33489);
INSERT INTO "django_geo_db_zipcode" VALUES(37579,85045,-7,'Phoenix, Arizona 85045',27171,33490);
INSERT INTO "django_geo_db_zipcode" VALUES(37580,85046,-7,'Phoenix, Arizona 85046',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37581,85048,-7,'Phoenix, Arizona 85048',27171,33491);
INSERT INTO "django_geo_db_zipcode" VALUES(37582,85050,-7,'Phoenix, Arizona 85050',27171,33492);
INSERT INTO "django_geo_db_zipcode" VALUES(37583,85051,-7,'Phoenix, Arizona 85051',27171,33493);
INSERT INTO "django_geo_db_zipcode" VALUES(37584,85053,-7,'Phoenix, Arizona 85053',27171,33494);
INSERT INTO "django_geo_db_zipcode" VALUES(37585,85054,-7,'Phoenix, Arizona 85054',27171,33495);
INSERT INTO "django_geo_db_zipcode" VALUES(37586,85055,-7,'Phoenix, Arizona 85055',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37587,85060,-7,'Phoenix, Arizona 85060',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37588,85061,-7,'Phoenix, Arizona 85061',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37589,85062,-7,'Phoenix, Arizona 85062',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37590,85063,-7,'Phoenix, Arizona 85063',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37591,85064,-7,'Phoenix, Arizona 85064',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37592,85065,-7,'Phoenix, Arizona 85065',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37593,85066,-7,'Phoenix, Arizona 85066',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37594,85067,-7,'Phoenix, Arizona 85067',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37595,85068,-7,'Phoenix, Arizona 85068',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37596,85069,-7,'Phoenix, Arizona 85069',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37597,85070,-7,'Phoenix, Arizona 85070',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37598,85071,-7,'Phoenix, Arizona 85071',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37599,85072,-7,'Phoenix, Arizona 85072',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37600,85073,-7,'Phoenix, Arizona 85073',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37601,85074,-7,'Phoenix, Arizona 85074',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37602,85075,-7,'Phoenix, Arizona 85075',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37603,85076,-7,'Phoenix, Arizona 85076',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37604,85077,-7,'Phoenix, Arizona 85077',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37605,85078,-7,'Phoenix, Arizona 85078',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37606,85079,-7,'Phoenix, Arizona 85079',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37607,85080,-7,'Phoenix, Arizona 85080',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37608,85082,-7,'Phoenix, Arizona 85082',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37609,85085,-7,'Phoenix, Arizona 85085',27171,33496);
INSERT INTO "django_geo_db_zipcode" VALUES(37610,85086,-7,'Anthem, Arizona 85086',27172,33497);
INSERT INTO "django_geo_db_zipcode" VALUES(37611,85087,-7,'New River, Arizona 85087',27173,33498);
INSERT INTO "django_geo_db_zipcode" VALUES(37612,85089,-7,'New River, Arizona 85089',27173,33499);
INSERT INTO "django_geo_db_zipcode" VALUES(37613,85097,-7,'Phoenix, Arizona 85097',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37614,85098,-7,'Phoenix, Arizona 85098',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37615,85099,-7,'Phoenix, Arizona 85099',27171,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37616,85123,-7,'Mesa, Arizona 85123',27174,33500);
INSERT INTO "django_geo_db_zipcode" VALUES(37617,85200,-7,'Mesa, Arizona 85200',27174,33501);
INSERT INTO "django_geo_db_zipcode" VALUES(37618,85201,-7,'Mesa, Arizona 85201',27174,33502);
INSERT INTO "django_geo_db_zipcode" VALUES(37619,85202,-7,'Mesa, Arizona 85202',27174,33503);
INSERT INTO "django_geo_db_zipcode" VALUES(37620,85203,-7,'Mesa, Arizona 85203',27174,33504);
INSERT INTO "django_geo_db_zipcode" VALUES(37621,85204,-7,'Mesa, Arizona 85204',27174,33505);
INSERT INTO "django_geo_db_zipcode" VALUES(37622,85205,-7,'Mesa, Arizona 85205',27174,33506);
INSERT INTO "django_geo_db_zipcode" VALUES(37623,85206,-7,'Mesa, Arizona 85206',27174,33507);
INSERT INTO "django_geo_db_zipcode" VALUES(37624,85207,-7,'Mesa, Arizona 85207',27174,33508);
INSERT INTO "django_geo_db_zipcode" VALUES(37625,85208,-7,'Mesa, Arizona 85208',27174,33509);
INSERT INTO "django_geo_db_zipcode" VALUES(37626,85210,-7,'Mesa, Arizona 85210',27174,33510);
INSERT INTO "django_geo_db_zipcode" VALUES(37627,85211,-7,'Mesa, Arizona 85211',27174,33511);
INSERT INTO "django_geo_db_zipcode" VALUES(37628,85212,-7,'Mesa, Arizona 85212',27174,33512);
INSERT INTO "django_geo_db_zipcode" VALUES(37629,85213,-7,'Mesa, Arizona 85213',27174,33513);
INSERT INTO "django_geo_db_zipcode" VALUES(37630,85214,-7,'Mesa, Arizona 85214',27174,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37631,85215,-7,'Mesa, Arizona 85215',27174,33514);
INSERT INTO "django_geo_db_zipcode" VALUES(37632,85216,-7,'Mesa, Arizona 85216',27174,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37633,85217,-7,'Apache Junction, Arizona 85217',27175,33515);
INSERT INTO "django_geo_db_zipcode" VALUES(37634,85218,-7,'Gold Camp, Arizona 85218',27176,33516);
INSERT INTO "django_geo_db_zipcode" VALUES(37635,85219,-7,'Apache Junction, Arizona 85219',27175,33517);
INSERT INTO "django_geo_db_zipcode" VALUES(37636,85220,-7,'Apache Junction, Arizona 85220',27175,33518);
INSERT INTO "django_geo_db_zipcode" VALUES(37637,85221,-7,'Bapchule, Arizona 85221',27177,33519);
INSERT INTO "django_geo_db_zipcode" VALUES(37638,85222,-7,'Casa Grande, Arizona 85222',27178,33520);
INSERT INTO "django_geo_db_zipcode" VALUES(37639,85223,-7,'Arizona City, Arizona 85223',27179,33521);
INSERT INTO "django_geo_db_zipcode" VALUES(37640,85224,-7,'Chandler, Arizona 85224',27180,33522);
INSERT INTO "django_geo_db_zipcode" VALUES(37641,85225,-7,'Chandler, Arizona 85225',27180,33523);
INSERT INTO "django_geo_db_zipcode" VALUES(37642,85226,-7,'Chandler, Arizona 85226',27180,33524);
INSERT INTO "django_geo_db_zipcode" VALUES(37643,85227,-7,'Chandler Heights, Arizona 85227',27181,33525);
INSERT INTO "django_geo_db_zipcode" VALUES(37644,85228,-7,'Coolidge, Arizona 85228',27182,33526);
INSERT INTO "django_geo_db_zipcode" VALUES(37645,85230,-7,'Casa Grande, Arizona 85230',27178,33527);
INSERT INTO "django_geo_db_zipcode" VALUES(37646,85231,-7,'Eloy, Arizona 85231',27183,33528);
INSERT INTO "django_geo_db_zipcode" VALUES(37647,85232,-7,'Florence, Arizona 85232',27184,33529);
INSERT INTO "django_geo_db_zipcode" VALUES(37648,85233,-7,'Gilbert, Arizona 85233',27185,33530);
INSERT INTO "django_geo_db_zipcode" VALUES(37649,85234,-7,'Gilbert, Arizona 85234',27185,33531);
INSERT INTO "django_geo_db_zipcode" VALUES(37650,85235,-7,'Hayden, Arizona 85235',27186,33532);
INSERT INTO "django_geo_db_zipcode" VALUES(37651,85236,-7,'Higley, Arizona 85236',27187,33533);
INSERT INTO "django_geo_db_zipcode" VALUES(37652,85237,-7,'Kearny, Arizona 85237',27188,33534);
INSERT INTO "django_geo_db_zipcode" VALUES(37653,85239,-7,'Maricopa, Arizona 85239',27189,33535);
INSERT INTO "django_geo_db_zipcode" VALUES(37654,85240,-7,'Chandler, Arizona 85240',27180,33536);
INSERT INTO "django_geo_db_zipcode" VALUES(37655,85241,-7,'Picacho, Arizona 85241',27190,33537);
INSERT INTO "django_geo_db_zipcode" VALUES(37656,85242,-7,'Queen Creek, Arizona 85242',27191,33538);
INSERT INTO "django_geo_db_zipcode" VALUES(37657,85244,-7,'Chandler, Arizona 85244',27180,33539);
INSERT INTO "django_geo_db_zipcode" VALUES(37658,85245,-7,'Red Rock, Arizona 85245',27192,33540);
INSERT INTO "django_geo_db_zipcode" VALUES(37659,85246,-7,'Chandler, Arizona 85246',27180,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37660,85247,-7,'Sacaton, Arizona 85247',27193,33541);
INSERT INTO "django_geo_db_zipcode" VALUES(37661,85248,-7,'Chandler, Arizona 85248',27180,33542);
INSERT INTO "django_geo_db_zipcode" VALUES(37662,85249,-7,'Chandler, Arizona 85249',27180,33543);
INSERT INTO "django_geo_db_zipcode" VALUES(37663,85250,-7,'Scottsdale, Arizona 85250',27194,33544);
INSERT INTO "django_geo_db_zipcode" VALUES(37664,85251,-7,'Scottsdale, Arizona 85251',27194,33545);
INSERT INTO "django_geo_db_zipcode" VALUES(37665,85252,-7,'Scottsdale, Arizona 85252',27194,33546);
INSERT INTO "django_geo_db_zipcode" VALUES(37666,85253,-7,'Paradise Valley, Arizona 85253',27195,33547);
INSERT INTO "django_geo_db_zipcode" VALUES(37667,85254,-7,'Scottsdale, Arizona 85254',27194,33548);
INSERT INTO "django_geo_db_zipcode" VALUES(37668,85255,-7,'Scottsdale, Arizona 85255',27194,33549);
INSERT INTO "django_geo_db_zipcode" VALUES(37669,85256,-7,'Scottsdale, Arizona 85256',27194,33550);
INSERT INTO "django_geo_db_zipcode" VALUES(37670,85257,-7,'Scottsdale, Arizona 85257',27194,33551);
INSERT INTO "django_geo_db_zipcode" VALUES(37671,85258,-7,'Scottsdale, Arizona 85258',27194,33552);
INSERT INTO "django_geo_db_zipcode" VALUES(37672,85259,-7,'Scottsdale, Arizona 85259',27194,33553);
INSERT INTO "django_geo_db_zipcode" VALUES(37673,85260,-7,'Scottsdale, Arizona 85260',27194,33554);
INSERT INTO "django_geo_db_zipcode" VALUES(37674,85261,-7,'Scottsdale, Arizona 85261',27194,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37675,85262,-7,'Scottsdale, Arizona 85262',27194,33555);
INSERT INTO "django_geo_db_zipcode" VALUES(37676,85263,-7,'Rio Verde, Arizona 85263',27196,33556);
INSERT INTO "django_geo_db_zipcode" VALUES(37677,85264,-7,'Fort Mcdowell, Arizona 85264',27197,33557);
INSERT INTO "django_geo_db_zipcode" VALUES(37678,85266,-7,'Scottsdale, Arizona 85266',27194,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37679,85267,-7,'Scottsdale, Arizona 85267',27194,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37680,85268,-7,'Fountain Hills, Arizona 85268',27198,33558);
INSERT INTO "django_geo_db_zipcode" VALUES(37681,85269,-7,'Fountain Hills, Arizona 85269',27198,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37682,85271,-7,'Scottsdale, Arizona 85271',27194,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37683,85272,-7,'Stanfield, Arizona 85272',27199,33559);
INSERT INTO "django_geo_db_zipcode" VALUES(37684,85273,-7,'Superior, Arizona 85273',27200,33560);
INSERT INTO "django_geo_db_zipcode" VALUES(37685,85274,-7,'Mesa, Arizona 85274',27174,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37686,85275,-7,'Mesa, Arizona 85275',27174,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37687,85277,-7,'Mesa, Arizona 85277',27174,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37688,85278,-7,'Apache Junction, Arizona 85278',27175,33561);
INSERT INTO "django_geo_db_zipcode" VALUES(37689,85279,-7,'Florence, Arizona 85279',27184,33561);
INSERT INTO "django_geo_db_zipcode" VALUES(37690,85280,-7,'Tempe, Arizona 85280',27201,33562);
INSERT INTO "django_geo_db_zipcode" VALUES(37691,85281,-7,'Tempe, Arizona 85281',27201,33563);
INSERT INTO "django_geo_db_zipcode" VALUES(37692,85282,-7,'Tempe, Arizona 85282',27201,33564);
INSERT INTO "django_geo_db_zipcode" VALUES(37693,85283,-7,'Tempe, Arizona 85283',27201,33565);
INSERT INTO "django_geo_db_zipcode" VALUES(37694,85284,-7,'Tempe, Arizona 85284',27201,33566);
INSERT INTO "django_geo_db_zipcode" VALUES(37695,85285,-7,'Tempe, Arizona 85285',27201,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37696,85286,-7,'New River, Arizona 85286',27173,33567);
INSERT INTO "django_geo_db_zipcode" VALUES(37697,85287,-7,'Tempe, Arizona 85287',27201,33568);
INSERT INTO "django_geo_db_zipcode" VALUES(37698,85288,-7,'Scottsdale, Arizona 85288',27194,33569);
INSERT INTO "django_geo_db_zipcode" VALUES(37699,85289,-7,'Tempe, Arizona 85289',27201,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37700,85290,-7,'Tortilla Flat, Arizona 85290',27202,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37701,85291,-7,'Valley Farms, Arizona 85291',27203,33570);
INSERT INTO "django_geo_db_zipcode" VALUES(37702,85292,-7,'Winkelman, Arizona 85292',27204,33571);
INSERT INTO "django_geo_db_zipcode" VALUES(37703,85296,-7,'Gilbert, Arizona 85296',27185,33572);
INSERT INTO "django_geo_db_zipcode" VALUES(37704,85297,-7,'Gilbert, Arizona 85297',27185,33573);
INSERT INTO "django_geo_db_zipcode" VALUES(37705,85299,-7,'Gilbert, Arizona 85299',27185,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37706,85301,-7,'Glendale, Arizona 85301',27205,33574);
INSERT INTO "django_geo_db_zipcode" VALUES(37707,85302,-7,'Glendale, Arizona 85302',27205,33575);
INSERT INTO "django_geo_db_zipcode" VALUES(37708,85303,-7,'Glendale, Arizona 85303',27205,33576);
INSERT INTO "django_geo_db_zipcode" VALUES(37709,85304,-7,'Glendale, Arizona 85304',27205,33577);
INSERT INTO "django_geo_db_zipcode" VALUES(37710,85305,-7,'Glendale, Arizona 85305',27205,33578);
INSERT INTO "django_geo_db_zipcode" VALUES(37711,85306,-7,'Glendale, Arizona 85306',27205,33579);
INSERT INTO "django_geo_db_zipcode" VALUES(37712,85307,-7,'Glendale, Arizona 85307',27205,33580);
INSERT INTO "django_geo_db_zipcode" VALUES(37713,85308,-7,'Glendale, Arizona 85308',27205,33581);
INSERT INTO "django_geo_db_zipcode" VALUES(37714,85309,-7,'Luke AFB, Arizona 85309',27206,33582);
INSERT INTO "django_geo_db_zipcode" VALUES(37715,85310,-7,'Glendale, Arizona 85310',27205,33583);
INSERT INTO "django_geo_db_zipcode" VALUES(37716,85311,-7,'Glendale, Arizona 85311',27205,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37717,85312,-7,'Glendale, Arizona 85312',27205,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37718,85313,-7,'Glendale, Arizona 85313',27205,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37719,85317,-7,'Carefree, Arizona 85317',27207,33584);
INSERT INTO "django_geo_db_zipcode" VALUES(37720,85318,-7,'Glendale, Arizona 85318',27205,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37721,85320,-7,'Aguila, Arizona 85320',27208,33585);
INSERT INTO "django_geo_db_zipcode" VALUES(37722,85321,-7,'Ajo, Arizona 85321',27209,33586);
INSERT INTO "django_geo_db_zipcode" VALUES(37723,85322,-7,'Arlington, Arizona 85322',27210,33587);
INSERT INTO "django_geo_db_zipcode" VALUES(37724,85323,-7,'Avondale, Arizona 85323',27211,33588);
INSERT INTO "django_geo_db_zipcode" VALUES(37725,85324,-7,'Black Canyon City, Arizona 85324',27212,33589);
INSERT INTO "django_geo_db_zipcode" VALUES(37726,85325,-7,'Bouse, Arizona 85325',27213,33590);
INSERT INTO "django_geo_db_zipcode" VALUES(37727,85326,-7,'Buckeye, Arizona 85326',27214,33591);
INSERT INTO "django_geo_db_zipcode" VALUES(37728,85327,-7,'Cave Creek, Arizona 85327',27215,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37729,85328,-7,'Cibola, Arizona 85328',27216,33592);
INSERT INTO "django_geo_db_zipcode" VALUES(37730,85329,-7,'Cashion, Arizona 85329',27217,33593);
INSERT INTO "django_geo_db_zipcode" VALUES(37731,85330,-7,'Wickenburg, Arizona 85330',27218,33594);
INSERT INTO "django_geo_db_zipcode" VALUES(37732,85331,-7,'Cave Creek, Arizona 85331',27215,33595);
INSERT INTO "django_geo_db_zipcode" VALUES(37733,85332,-7,'Congress, Arizona 85332',27219,33596);
INSERT INTO "django_geo_db_zipcode" VALUES(37734,85333,-7,'Dateland, Arizona 85333',27220,33597);
INSERT INTO "django_geo_db_zipcode" VALUES(37735,85334,-7,'Ehrenberg, Arizona 85334',27221,33598);
INSERT INTO "django_geo_db_zipcode" VALUES(37736,85335,-7,'El Mirage, Arizona 85335',27222,33599);
INSERT INTO "django_geo_db_zipcode" VALUES(37737,85336,-7,'Gadsden, Arizona 85336',27223,33600);
INSERT INTO "django_geo_db_zipcode" VALUES(37738,85337,-7,'Gila Bend, Arizona 85337',27224,33601);
INSERT INTO "django_geo_db_zipcode" VALUES(37739,85338,-7,'Goodyear, Arizona 85338',27225,33602);
INSERT INTO "django_geo_db_zipcode" VALUES(37740,85339,-7,'Laveen, Arizona 85339',27226,33603);
INSERT INTO "django_geo_db_zipcode" VALUES(37741,85340,-7,'Litchfield Park, Arizona 85340',27227,33604);
INSERT INTO "django_geo_db_zipcode" VALUES(37742,85341,-7,'Lukeville, Arizona 85341',27228,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37743,85342,-7,'Morristown, Arizona 85342',27229,33606);
INSERT INTO "django_geo_db_zipcode" VALUES(37744,85343,-7,'Palo Verde, Arizona 85343',27230,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37745,85344,-7,'Parker, Arizona 85344',27231,33607);
INSERT INTO "django_geo_db_zipcode" VALUES(37746,85345,-7,'Peoria, Arizona 85345',27232,33608);
INSERT INTO "django_geo_db_zipcode" VALUES(37747,85346,-7,'Quartzsite, Arizona 85346',27233,33609);
INSERT INTO "django_geo_db_zipcode" VALUES(37748,85347,-7,'Roll, Arizona 85347',27234,33610);
INSERT INTO "django_geo_db_zipcode" VALUES(37749,85348,-7,'Salome, Arizona 85348',27235,33611);
INSERT INTO "django_geo_db_zipcode" VALUES(37750,85349,-7,'San Luis, Arizona 85349',27236,33612);
INSERT INTO "django_geo_db_zipcode" VALUES(37751,85350,-7,'Somerton, Arizona 85350',27237,33613);
INSERT INTO "django_geo_db_zipcode" VALUES(37752,85351,-7,'Sun City, Arizona 85351',27238,33614);
INSERT INTO "django_geo_db_zipcode" VALUES(37753,85352,-7,'Tacna, Arizona 85352',27239,33615);
INSERT INTO "django_geo_db_zipcode" VALUES(37754,85353,-7,'Tolleson, Arizona 85353',27240,33616);
INSERT INTO "django_geo_db_zipcode" VALUES(37755,85354,-7,'Tonopah, Arizona 85354',27241,33617);
INSERT INTO "django_geo_db_zipcode" VALUES(37756,85355,-7,'Waddell, Arizona 85355',27242,33618);
INSERT INTO "django_geo_db_zipcode" VALUES(37757,85356,-7,'Wellton, Arizona 85356',27243,33619);
INSERT INTO "django_geo_db_zipcode" VALUES(37758,85357,-7,'Wenden, Arizona 85357',27244,33620);
INSERT INTO "django_geo_db_zipcode" VALUES(37759,85358,-7,'Wickenburg, Arizona 85358',27218,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37760,85359,-7,'Quartzsite, Arizona 85359',27233,33621);
INSERT INTO "django_geo_db_zipcode" VALUES(37761,85360,-7,'Wikieup, Arizona 85360',27245,33622);
INSERT INTO "django_geo_db_zipcode" VALUES(37762,85361,-7,'Wittmann, Arizona 85361',27246,33623);
INSERT INTO "django_geo_db_zipcode" VALUES(37763,85362,-7,'Yarnell, Arizona 85362',27247,33624);
INSERT INTO "django_geo_db_zipcode" VALUES(37764,85363,-7,'Youngtown, Arizona 85363',27248,33625);
INSERT INTO "django_geo_db_zipcode" VALUES(37765,85364,-7,'Yuma, Arizona 85364',27249,33626);
INSERT INTO "django_geo_db_zipcode" VALUES(37766,85365,-7,'Yuma, Arizona 85365',27249,33627);
INSERT INTO "django_geo_db_zipcode" VALUES(37767,85366,-7,'Yuma, Arizona 85366',27249,33628);
INSERT INTO "django_geo_db_zipcode" VALUES(37768,85367,-7,'Yuma, Arizona 85367',27249,33629);
INSERT INTO "django_geo_db_zipcode" VALUES(37769,85369,-7,'Yuma, Arizona 85369',27249,33630);
INSERT INTO "django_geo_db_zipcode" VALUES(37770,85371,-7,'Poston, Arizona 85371',27250,33631);
INSERT INTO "django_geo_db_zipcode" VALUES(37771,85372,-7,'Sun City, Arizona 85372',27238,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37772,85373,-7,'Sun City, Arizona 85373',27238,33632);
INSERT INTO "django_geo_db_zipcode" VALUES(37773,85374,-7,'Surprise, Arizona 85374',27251,33633);
INSERT INTO "django_geo_db_zipcode" VALUES(37774,85375,-7,'Sun City West, Arizona 85375',27252,33634);
INSERT INTO "django_geo_db_zipcode" VALUES(37775,85376,-7,'Sun City West, Arizona 85376',27252,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37776,85377,-7,'Carefree, Arizona 85377',27207,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37777,85378,-7,'Surprise, Arizona 85378',27251,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37778,85379,-7,'Surprise, Arizona 85379',27251,33635);
INSERT INTO "django_geo_db_zipcode" VALUES(37779,85380,-7,'Peoria, Arizona 85380',27232,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37780,85381,-7,'Peoria, Arizona 85381',27232,33636);
INSERT INTO "django_geo_db_zipcode" VALUES(37781,85382,-7,'Peoria, Arizona 85382',27232,33637);
INSERT INTO "django_geo_db_zipcode" VALUES(37782,85383,-7,'Peoria, Arizona 85383',27232,33638);
INSERT INTO "django_geo_db_zipcode" VALUES(37783,85385,-7,'Peoria, Arizona 85385',27232,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37784,85387,-7,'Surprise, Arizona 85387',27251,33455);
INSERT INTO "django_geo_db_zipcode" VALUES(37785,85390,-7,'Wickenburg, Arizona 85390',27218,33639);
INSERT INTO "django_geo_db_zipcode" VALUES(37786,85395,-7,'Peoria, Arizona 85395',27232,33640);
INSERT INTO "django_geo_db_zipcode" VALUES(37787,85439,-7,'San Luis, Arizona 85439',27236,33641);
INSERT INTO "django_geo_db_zipcode" VALUES(37788,85501,-7,'Globe, Arizona 85501',27253,33642);
INSERT INTO "django_geo_db_zipcode" VALUES(37789,85502,-7,'Globe, Arizona 85502',27253,33643);
INSERT INTO "django_geo_db_zipcode" VALUES(37790,85522,-7,'Thatcher, Arizona 85522',27254,33644);
INSERT INTO "django_geo_db_zipcode" VALUES(37791,85530,-7,'Bylas, Arizona 85530',27255,33645);
INSERT INTO "django_geo_db_zipcode" VALUES(37792,85531,-7,'Central, Arizona 85531',27256,33646);
INSERT INTO "django_geo_db_zipcode" VALUES(37793,85532,-7,'Claypool, Arizona 85532',27257,33647);
INSERT INTO "django_geo_db_zipcode" VALUES(37794,85533,-7,'Clifton, Arizona 85533',27258,33648);
INSERT INTO "django_geo_db_zipcode" VALUES(37795,85534,-7,'Duncan, Arizona 85534',27259,33649);
INSERT INTO "django_geo_db_zipcode" VALUES(37796,85535,-7,'Eden, Arizona 85535',27260,33650);
INSERT INTO "django_geo_db_zipcode" VALUES(37797,85536,-7,'Fort Thomas, Arizona 85536',27261,33651);
INSERT INTO "django_geo_db_zipcode" VALUES(37798,85539,-7,'Miami, Arizona 85539',27262,33652);
INSERT INTO "django_geo_db_zipcode" VALUES(37799,85540,-7,'Morenci, Arizona 85540',27263,33653);
INSERT INTO "django_geo_db_zipcode" VALUES(37800,85541,-7,'Payson, Arizona 85541',27264,33654);
INSERT INTO "django_geo_db_zipcode" VALUES(37801,85542,-7,'Peridot, Arizona 85542',27265,33655);
INSERT INTO "django_geo_db_zipcode" VALUES(37802,85543,-7,'Pima, Arizona 85543',27266,33656);
INSERT INTO "django_geo_db_zipcode" VALUES(37803,85544,-7,'Pine, Arizona 85544',27267,33657);
INSERT INTO "django_geo_db_zipcode" VALUES(37804,85545,-7,'Roosevelt, Arizona 85545',27268,33658);
INSERT INTO "django_geo_db_zipcode" VALUES(37805,85546,-7,'Safford, Arizona 85546',27269,33659);
INSERT INTO "django_geo_db_zipcode" VALUES(37806,85547,-7,'Payson, Arizona 85547',27264,33660);
INSERT INTO "django_geo_db_zipcode" VALUES(37807,85548,-7,'Safford, Arizona 85548',27269,33661);
INSERT INTO "django_geo_db_zipcode" VALUES(37808,85550,-7,'San Carlos, Arizona 85550',27270,33662);
INSERT INTO "django_geo_db_zipcode" VALUES(37809,85551,-7,'Solomon, Arizona 85551',27271,33663);
INSERT INTO "django_geo_db_zipcode" VALUES(37810,85552,-7,'Thatcher, Arizona 85552',27254,33664);
INSERT INTO "django_geo_db_zipcode" VALUES(37811,85553,-7,'Tonto Basin, Arizona 85553',27272,33665);
INSERT INTO "django_geo_db_zipcode" VALUES(37812,85554,-7,'Young, Arizona 85554',27273,33666);
INSERT INTO "django_geo_db_zipcode" VALUES(37813,85601,-7,'Arivaca, Arizona 85601',27274,33667);
INSERT INTO "django_geo_db_zipcode" VALUES(37814,85602,-7,'Benson, Arizona 85602',27275,33668);
INSERT INTO "django_geo_db_zipcode" VALUES(37815,85603,-7,'Bisbee, Arizona 85603',27276,33669);
INSERT INTO "django_geo_db_zipcode" VALUES(37816,85605,-7,'Bowie, Arizona 85605',27277,33670);
INSERT INTO "django_geo_db_zipcode" VALUES(37817,85606,-7,'Cochise, Arizona 85606',27278,33671);
INSERT INTO "django_geo_db_zipcode" VALUES(37818,85607,-7,'Douglas, Arizona 85607',27279,33672);
INSERT INTO "django_geo_db_zipcode" VALUES(37819,85608,-7,'Douglas, Arizona 85608',27279,33673);
INSERT INTO "django_geo_db_zipcode" VALUES(37820,85609,-7,'Dragoon, Arizona 85609',27280,33674);
INSERT INTO "django_geo_db_zipcode" VALUES(37821,85610,-7,'Elfrida, Arizona 85610',27281,33675);
INSERT INTO "django_geo_db_zipcode" VALUES(37822,85611,-7,'Elgin, Arizona 85611',27282,33676);
INSERT INTO "django_geo_db_zipcode" VALUES(37823,85613,-7,'Fort Huachuca, Arizona 85613',27283,33677);
INSERT INTO "django_geo_db_zipcode" VALUES(37824,85614,-7,'Green Valley, Arizona 85614',27284,33678);
INSERT INTO "django_geo_db_zipcode" VALUES(37825,85615,-7,'Hereford, Arizona 85615',27285,33679);
INSERT INTO "django_geo_db_zipcode" VALUES(37826,85616,-7,'Huachuca City, Arizona 85616',27286,33680);
INSERT INTO "django_geo_db_zipcode" VALUES(37827,85617,-7,'McNeal, Arizona 85617',27287,33681);
INSERT INTO "django_geo_db_zipcode" VALUES(37828,85618,-7,'Mammoth, Arizona 85618',27288,33682);
INSERT INTO "django_geo_db_zipcode" VALUES(37829,85619,-7,'Mount Lemmon, Arizona 85619',27289,33683);
INSERT INTO "django_geo_db_zipcode" VALUES(37830,85620,-7,'Naco, Arizona 85620',27290,33684);
INSERT INTO "django_geo_db_zipcode" VALUES(37831,85621,-7,'Nogales, Arizona 85621',27291,33685);
INSERT INTO "django_geo_db_zipcode" VALUES(37832,85622,-7,'Green Valley, Arizona 85622',27284,33686);
INSERT INTO "django_geo_db_zipcode" VALUES(37833,85623,-7,'Oracle, Arizona 85623',27292,33687);
INSERT INTO "django_geo_db_zipcode" VALUES(37834,85624,-7,'Patagonia, Arizona 85624',27293,33688);
INSERT INTO "django_geo_db_zipcode" VALUES(37835,85625,-7,'Pearce, Arizona 85625',27294,33689);
INSERT INTO "django_geo_db_zipcode" VALUES(37836,85626,-7,'Pirtleville, Arizona 85626',27295,33690);
INSERT INTO "django_geo_db_zipcode" VALUES(37837,85627,-7,'Pomerene, Arizona 85627',27296,33691);
INSERT INTO "django_geo_db_zipcode" VALUES(37838,85628,-7,'Nogales, Arizona 85628',27291,33692);
INSERT INTO "django_geo_db_zipcode" VALUES(37839,85629,-7,'Sahuarita, Arizona 85629',27297,33693);
INSERT INTO "django_geo_db_zipcode" VALUES(37840,85630,-7,'Saint David, Arizona 85630',27298,33694);
INSERT INTO "django_geo_db_zipcode" VALUES(37841,85631,-7,'San Manuel, Arizona 85631',27299,33695);
INSERT INTO "django_geo_db_zipcode" VALUES(37842,85632,-7,'San Simon, Arizona 85632',27300,33696);
INSERT INTO "django_geo_db_zipcode" VALUES(37843,85633,-7,'Sasabe, Arizona 85633',27301,33697);
INSERT INTO "django_geo_db_zipcode" VALUES(37844,85634,-7,'Sells, Arizona 85634',27302,33698);
INSERT INTO "django_geo_db_zipcode" VALUES(37845,85635,-7,'Sierra Vista, Arizona 85635',27303,33699);
INSERT INTO "django_geo_db_zipcode" VALUES(37846,85636,-7,'Sierra Vista, Arizona 85636',27303,33700);
INSERT INTO "django_geo_db_zipcode" VALUES(37847,85637,-7,'Sonoita, Arizona 85637',27304,33701);
INSERT INTO "django_geo_db_zipcode" VALUES(37848,85638,-7,'Tombstone, Arizona 85638',27305,33702);
INSERT INTO "django_geo_db_zipcode" VALUES(37849,85639,-7,'Topawa, Arizona 85639',27306,33703);
INSERT INTO "django_geo_db_zipcode" VALUES(37850,85640,-7,'Tumacacori, Arizona 85640',27307,33704);
INSERT INTO "django_geo_db_zipcode" VALUES(37851,85641,-7,'Vail, Arizona 85641',27308,33705);
INSERT INTO "django_geo_db_zipcode" VALUES(37852,85643,-7,'Willcox, Arizona 85643',27309,33706);
INSERT INTO "django_geo_db_zipcode" VALUES(37853,85644,-7,'Willcox, Arizona 85644',27309,33707);
INSERT INTO "django_geo_db_zipcode" VALUES(37854,85645,-7,'Amado, Arizona 85645',27310,33708);
INSERT INTO "django_geo_db_zipcode" VALUES(37855,85646,-7,'Tubac, Arizona 85646',27311,33709);
INSERT INTO "django_geo_db_zipcode" VALUES(37856,85648,-7,'Rio Rico, Arizona 85648',27312,33710);
INSERT INTO "django_geo_db_zipcode" VALUES(37857,85650,-7,'Sierra Vista, Arizona 85650',27303,33711);
INSERT INTO "django_geo_db_zipcode" VALUES(37858,85652,-7,'Cortaro, Arizona 85652',27313,33712);
INSERT INTO "django_geo_db_zipcode" VALUES(37859,85653,-7,'Marana, Arizona 85653',27314,33713);
INSERT INTO "django_geo_db_zipcode" VALUES(37860,85654,-7,'Rillito, Arizona 85654',27315,33714);
INSERT INTO "django_geo_db_zipcode" VALUES(37861,85655,-7,'Douglas, Arizona 85655',27279,33715);
INSERT INTO "django_geo_db_zipcode" VALUES(37862,85662,-7,'Nogales, Arizona 85662',27291,33692);
INSERT INTO "django_geo_db_zipcode" VALUES(37863,85670,-7,'Fort Huachuca, Arizona 85670',27283,33715);
INSERT INTO "django_geo_db_zipcode" VALUES(37864,85671,-7,'Sierra Vista, Arizona 85671',27303,33715);
INSERT INTO "django_geo_db_zipcode" VALUES(37865,85701,-7,'Tucson, Arizona 85701',27316,33716);
INSERT INTO "django_geo_db_zipcode" VALUES(37866,85702,-7,'Tucson, Arizona 85702',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37867,85703,-7,'Tucson, Arizona 85703',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37868,85704,-7,'Tucson, Arizona 85704',27316,33717);
INSERT INTO "django_geo_db_zipcode" VALUES(37869,85705,-7,'Tucson, Arizona 85705',27316,33718);
INSERT INTO "django_geo_db_zipcode" VALUES(37870,85706,-7,'Tucson, Arizona 85706',27316,33719);
INSERT INTO "django_geo_db_zipcode" VALUES(37871,85707,-7,'Tucson, Arizona 85707',27316,33720);
INSERT INTO "django_geo_db_zipcode" VALUES(37872,85708,-7,'Tucson, Arizona 85708',27316,33721);
INSERT INTO "django_geo_db_zipcode" VALUES(37873,85709,-7,'Tucson, Arizona 85709',27316,33722);
INSERT INTO "django_geo_db_zipcode" VALUES(37874,85710,-7,'Tucson, Arizona 85710',27316,33723);
INSERT INTO "django_geo_db_zipcode" VALUES(37875,85711,-7,'Tucson, Arizona 85711',27316,33724);
INSERT INTO "django_geo_db_zipcode" VALUES(37876,85712,-7,'Tucson, Arizona 85712',27316,33725);
INSERT INTO "django_geo_db_zipcode" VALUES(37877,85713,-7,'Tucson, Arizona 85713',27316,33726);
INSERT INTO "django_geo_db_zipcode" VALUES(37878,85714,-7,'Tucson, Arizona 85714',27316,33727);
INSERT INTO "django_geo_db_zipcode" VALUES(37879,85715,-7,'Tucson, Arizona 85715',27316,33728);
INSERT INTO "django_geo_db_zipcode" VALUES(37880,85716,-7,'Tucson, Arizona 85716',27316,33729);
INSERT INTO "django_geo_db_zipcode" VALUES(37881,85717,-7,'Tucson, Arizona 85717',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37882,85718,-7,'Tucson, Arizona 85718',27316,33730);
INSERT INTO "django_geo_db_zipcode" VALUES(37883,85719,-7,'Tucson, Arizona 85719',27316,33731);
INSERT INTO "django_geo_db_zipcode" VALUES(37884,85720,-7,'Tucson, Arizona 85720',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37885,85721,-7,'Tucson, Arizona 85721',27316,33732);
INSERT INTO "django_geo_db_zipcode" VALUES(37886,85722,-7,'Tucson, Arizona 85722',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37887,85723,-7,'Tucson, Arizona 85723',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37888,85724,-7,'Tucson, Arizona 85724',27316,33733);
INSERT INTO "django_geo_db_zipcode" VALUES(37889,85725,-7,'Tucson, Arizona 85725',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37890,85726,-7,'Tucson, Arizona 85726',27316,33734);
INSERT INTO "django_geo_db_zipcode" VALUES(37891,85728,-7,'Tucson, Arizona 85728',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37892,85730,-7,'Tucson, Arizona 85730',27316,33735);
INSERT INTO "django_geo_db_zipcode" VALUES(37893,85731,-7,'Tucson, Arizona 85731',27316,33736);
INSERT INTO "django_geo_db_zipcode" VALUES(37894,85732,-7,'Tucson, Arizona 85732',27316,33737);
INSERT INTO "django_geo_db_zipcode" VALUES(37895,85733,-7,'Tucson, Arizona 85733',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37896,85734,-7,'Tucson, Arizona 85734',27316,33738);
INSERT INTO "django_geo_db_zipcode" VALUES(37897,85735,-7,'Tucson, Arizona 85735',27316,33739);
INSERT INTO "django_geo_db_zipcode" VALUES(37898,85736,-7,'Tucson, Arizona 85736',27316,33740);
INSERT INTO "django_geo_db_zipcode" VALUES(37899,85737,-7,'Tucson, Arizona 85737',27316,33741);
INSERT INTO "django_geo_db_zipcode" VALUES(37900,85738,-7,'Catalina, Arizona 85738',27317,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37901,85739,-7,'Tucson, Arizona 85739',27316,33742);
INSERT INTO "django_geo_db_zipcode" VALUES(37902,85740,-7,'Tucson, Arizona 85740',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37903,85741,-7,'Tucson, Arizona 85741',27316,33743);
INSERT INTO "django_geo_db_zipcode" VALUES(37904,85742,-7,'Tucson, Arizona 85742',27316,33744);
INSERT INTO "django_geo_db_zipcode" VALUES(37905,85743,-7,'Tucson, Arizona 85743',27316,33745);
INSERT INTO "django_geo_db_zipcode" VALUES(37906,85744,-7,'Tucson, Arizona 85744',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37907,85745,-7,'Tucson, Arizona 85745',27316,33746);
INSERT INTO "django_geo_db_zipcode" VALUES(37908,85746,-7,'Tucson, Arizona 85746',27316,33747);
INSERT INTO "django_geo_db_zipcode" VALUES(37909,85747,-7,'Tucson, Arizona 85747',27316,33748);
INSERT INTO "django_geo_db_zipcode" VALUES(37910,85748,-7,'Tucson, Arizona 85748',27316,33749);
INSERT INTO "django_geo_db_zipcode" VALUES(37911,85749,-7,'Tucson, Arizona 85749',27316,33750);
INSERT INTO "django_geo_db_zipcode" VALUES(37912,85750,-7,'Tucson, Arizona 85750',27316,33751);
INSERT INTO "django_geo_db_zipcode" VALUES(37913,85751,-7,'Tucson, Arizona 85751',27316,33752);
INSERT INTO "django_geo_db_zipcode" VALUES(37914,85752,-7,'Tucson, Arizona 85752',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37915,85754,-7,'Tucson, Arizona 85754',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37916,85775,-7,'Tucson, Arizona 85775',27316,33605);
INSERT INTO "django_geo_db_zipcode" VALUES(37917,85777,-7,'Tucson, Arizona 85777',27316,33753);
INSERT INTO "django_geo_db_zipcode" VALUES(37918,85807,-7,'New River, Arizona 85807',27173,33754);
INSERT INTO "django_geo_db_zipcode" VALUES(37919,85901,-7,'Show Low, Arizona 85901',27318,33755);
INSERT INTO "django_geo_db_zipcode" VALUES(37920,85902,-7,'Show Low, Arizona 85902',27318,33756);
INSERT INTO "django_geo_db_zipcode" VALUES(37921,85911,-7,'Cibecue, Arizona 85911',27319,33757);
INSERT INTO "django_geo_db_zipcode" VALUES(37922,85912,-7,'White Mountain Lake, Arizona 85912',27320,33758);
INSERT INTO "django_geo_db_zipcode" VALUES(37923,85920,-7,'Alpine, Arizona 85920',27321,33759);
INSERT INTO "django_geo_db_zipcode" VALUES(37924,85922,-7,'Blue, Arizona 85922',27322,33760);
INSERT INTO "django_geo_db_zipcode" VALUES(37925,85923,-7,'Clay Springs, Arizona 85923',27323,33761);
INSERT INTO "django_geo_db_zipcode" VALUES(37926,85924,-7,'Concho, Arizona 85924',27324,33762);
INSERT INTO "django_geo_db_zipcode" VALUES(37927,85925,-7,'Eagar, Arizona 85925',27325,33763);
INSERT INTO "django_geo_db_zipcode" VALUES(37928,85926,-7,'Fort Apache, Arizona 85926',27326,33764);
INSERT INTO "django_geo_db_zipcode" VALUES(37929,85927,-7,'Greer, Arizona 85927',27327,33765);
INSERT INTO "django_geo_db_zipcode" VALUES(37930,85928,-7,'Heber, Arizona 85928',27328,33766);
INSERT INTO "django_geo_db_zipcode" VALUES(37931,85929,-7,'Lakeside, Arizona 85929',27329,33767);
INSERT INTO "django_geo_db_zipcode" VALUES(37932,85930,-7,'Mcnary, Arizona 85930',27330,33768);
INSERT INTO "django_geo_db_zipcode" VALUES(37933,85931,-7,'Forest Lakes, Arizona 85931',27331,33769);
INSERT INTO "django_geo_db_zipcode" VALUES(37934,85932,-7,'Nutrioso, Arizona 85932',27332,33770);
INSERT INTO "django_geo_db_zipcode" VALUES(37935,85933,-7,'Overgaard, Arizona 85933',27333,33771);
INSERT INTO "django_geo_db_zipcode" VALUES(37936,85934,-7,'Pinedale, Arizona 85934',27334,33772);
INSERT INTO "django_geo_db_zipcode" VALUES(37937,85935,-7,'Pinetop, Arizona 85935',27335,33773);
INSERT INTO "django_geo_db_zipcode" VALUES(37938,85936,-7,'Saint Johns, Arizona 85936',27336,33774);
INSERT INTO "django_geo_db_zipcode" VALUES(37939,85937,-7,'Snowflake, Arizona 85937',27337,33775);
INSERT INTO "django_geo_db_zipcode" VALUES(37940,85938,-7,'Springerville, Arizona 85938',27338,33776);
INSERT INTO "django_geo_db_zipcode" VALUES(37941,85939,-7,'Taylor, Arizona 85939',27339,33777);
INSERT INTO "django_geo_db_zipcode" VALUES(37942,85940,-7,'Vernon, Arizona 85940',27340,33778);
INSERT INTO "django_geo_db_zipcode" VALUES(37943,85941,-7,'Whiteriver, Arizona 85941',27341,33779);
INSERT INTO "django_geo_db_zipcode" VALUES(37944,85942,-7,'Woodruff, Arizona 85942',27342,33780);
INSERT INTO "django_geo_db_zipcode" VALUES(37945,86001,-7,'Flagstaff, Arizona 86001',27343,33781);
INSERT INTO "django_geo_db_zipcode" VALUES(37946,86002,-7,'Flagstaff, Arizona 86002',27343,33782);
INSERT INTO "django_geo_db_zipcode" VALUES(37947,86003,-7,'Flagstaff, Arizona 86003',27343,33782);
INSERT INTO "django_geo_db_zipcode" VALUES(37948,86004,-7,'Flagstaff, Arizona 86004',27343,33783);
INSERT INTO "django_geo_db_zipcode" VALUES(37949,86011,-7,'Flagstaff, Arizona 86011',27343,33782);
INSERT INTO "django_geo_db_zipcode" VALUES(37950,86015,-7,'Bellemont, Arizona 86015',27344,33784);
INSERT INTO "django_geo_db_zipcode" VALUES(37951,86016,-7,'Gray Mountain, Arizona 86016',27345,33785);
INSERT INTO "django_geo_db_zipcode" VALUES(37952,86017,-7,'Munds Park, Arizona 86017',27346,33786);
INSERT INTO "django_geo_db_zipcode" VALUES(37953,86018,-7,'Parks, Arizona 86018',27347,33787);
INSERT INTO "django_geo_db_zipcode" VALUES(37954,86020,-7,'Cameron, Arizona 86020',27348,33788);
INSERT INTO "django_geo_db_zipcode" VALUES(37955,86021,-7,'Colorado City, Arizona 86021',27349,33789);
INSERT INTO "django_geo_db_zipcode" VALUES(37956,86022,-7,'Fredonia, Arizona 86022',27350,33790);
INSERT INTO "django_geo_db_zipcode" VALUES(37957,86023,-7,'Grand Canyon, Arizona 86023',27351,33791);
INSERT INTO "django_geo_db_zipcode" VALUES(37958,86024,-7,'Happy Jack, Arizona 86024',27352,33792);
INSERT INTO "django_geo_db_zipcode" VALUES(37959,86025,-7,'Holbrook, Arizona 86025',27353,33793);
INSERT INTO "django_geo_db_zipcode" VALUES(37960,86028,-7,'Petrified Forest Natl Pk, Arizona 86028',27354,33794);
INSERT INTO "django_geo_db_zipcode" VALUES(37961,86029,-7,'Sun Valley, Arizona 86029',27355,33795);
INSERT INTO "django_geo_db_zipcode" VALUES(37962,86030,-7,'Hotevilla, Arizona 86030',27356,33796);
INSERT INTO "django_geo_db_zipcode" VALUES(37963,86031,-7,'Indian Wells, Arizona 86031',27357,33797);
INSERT INTO "django_geo_db_zipcode" VALUES(37964,86032,-7,'Joseph City, Arizona 86032',27358,33798);
INSERT INTO "django_geo_db_zipcode" VALUES(37965,86033,-7,'Kayenta, Arizona 86033',27359,33799);
INSERT INTO "django_geo_db_zipcode" VALUES(37966,86034,-7,'Keams Canyon, Arizona 86034',27360,33800);
INSERT INTO "django_geo_db_zipcode" VALUES(37967,86035,-7,'Leupp, Arizona 86035',27361,33801);
INSERT INTO "django_geo_db_zipcode" VALUES(37968,86036,-7,'Marble Canyon, Arizona 86036',27362,33802);
INSERT INTO "django_geo_db_zipcode" VALUES(37969,86038,-7,'Mormon Lake, Arizona 86038',27363,33803);
INSERT INTO "django_geo_db_zipcode" VALUES(37970,86039,-7,'Kykotsmovi Village, Arizona 86039',27364,33804);
INSERT INTO "django_geo_db_zipcode" VALUES(37971,86040,-7,'Page, Arizona 86040',27365,33805);
INSERT INTO "django_geo_db_zipcode" VALUES(37972,86042,-7,'Polacca, Arizona 86042',27366,33806);
INSERT INTO "django_geo_db_zipcode" VALUES(37973,86043,-7,'Second Mesa, Arizona 86043',27367,33807);
INSERT INTO "django_geo_db_zipcode" VALUES(37974,86044,-7,'Tonalea, Arizona 86044',27368,33808);
INSERT INTO "django_geo_db_zipcode" VALUES(37975,86045,-7,'Tuba City, Arizona 86045',27369,33809);
INSERT INTO "django_geo_db_zipcode" VALUES(37976,86046,-7,'Williams, Arizona 86046',27370,33810);
INSERT INTO "django_geo_db_zipcode" VALUES(37977,86047,-7,'Winslow, Arizona 86047',27371,33811);
INSERT INTO "django_geo_db_zipcode" VALUES(37978,86052,-7,'North Rim, Arizona 86052',27372,33812);
INSERT INTO "django_geo_db_zipcode" VALUES(37979,86053,-7,'Kaibito, Arizona 86053',27373,33813);
INSERT INTO "django_geo_db_zipcode" VALUES(37980,86054,-7,'Shonto, Arizona 86054',27374,33814);
INSERT INTO "django_geo_db_zipcode" VALUES(37981,86231,-7,'Bagdad, Arizona 86231',27375,33815);
INSERT INTO "django_geo_db_zipcode" VALUES(37982,86301,-7,'Prescott, Arizona 86301',27376,33816);
INSERT INTO "django_geo_db_zipcode" VALUES(37983,86302,-7,'Prescott, Arizona 86302',27376,33817);
INSERT INTO "django_geo_db_zipcode" VALUES(37984,86303,-7,'Prescott, Arizona 86303',27376,33818);
INSERT INTO "django_geo_db_zipcode" VALUES(37985,86304,-7,'Prescott, Arizona 86304',27376,33819);
INSERT INTO "django_geo_db_zipcode" VALUES(37986,86305,-7,'Prescott, Arizona 86305',27376,33820);
INSERT INTO "django_geo_db_zipcode" VALUES(37987,86312,-7,'Prescott Valley, Arizona 86312',27377,33821);
INSERT INTO "django_geo_db_zipcode" VALUES(37988,86313,-7,'Prescott, Arizona 86313',27376,33822);
INSERT INTO "django_geo_db_zipcode" VALUES(37989,86314,-7,'Prescott Valley, Arizona 86314',27377,33823);
INSERT INTO "django_geo_db_zipcode" VALUES(37990,86320,-7,'Ash Fork, Arizona 86320',27378,33824);
INSERT INTO "django_geo_db_zipcode" VALUES(37991,86321,-7,'Bagdad, Arizona 86321',27375,33825);
INSERT INTO "django_geo_db_zipcode" VALUES(37992,86322,-7,'Camp Verde, Arizona 86322',27379,33826);
INSERT INTO "django_geo_db_zipcode" VALUES(37993,86323,-7,'Chino Valley, Arizona 86323',27380,33827);
INSERT INTO "django_geo_db_zipcode" VALUES(37994,86324,-7,'Clarkdale, Arizona 86324',27381,33828);
INSERT INTO "django_geo_db_zipcode" VALUES(37995,86325,-7,'Cornville, Arizona 86325',27382,33829);
INSERT INTO "django_geo_db_zipcode" VALUES(37996,86326,-7,'Cottonwood, Arizona 86326',27383,33830);
INSERT INTO "django_geo_db_zipcode" VALUES(37997,86327,-7,'Dewey, Arizona 86327',27384,33831);
INSERT INTO "django_geo_db_zipcode" VALUES(37998,86329,-7,'Humboldt, Arizona 86329',27385,33832);
INSERT INTO "django_geo_db_zipcode" VALUES(37999,86330,-7,'Iron Springs, Arizona 86330',27386,33822);
INSERT INTO "django_geo_db_zipcode" VALUES(38000,86331,-7,'Jerome, Arizona 86331',27387,33833);
INSERT INTO "django_geo_db_zipcode" VALUES(38001,86332,-7,'Kirkland, Arizona 86332',27388,33834);
INSERT INTO "django_geo_db_zipcode" VALUES(38002,86333,-7,'Mayer, Arizona 86333',27389,33835);
INSERT INTO "django_geo_db_zipcode" VALUES(38003,86334,-7,'Paulden, Arizona 86334',27390,33836);
INSERT INTO "django_geo_db_zipcode" VALUES(38004,86335,-7,'Rimrock, Arizona 86335',27391,33837);
INSERT INTO "django_geo_db_zipcode" VALUES(38005,86336,-7,'Sedona, Arizona 86336',27392,33838);
INSERT INTO "django_geo_db_zipcode" VALUES(38006,86337,-7,'Seligman, Arizona 86337',27393,33839);
INSERT INTO "django_geo_db_zipcode" VALUES(38007,86338,-7,'Skull Valley, Arizona 86338',27394,33840);
INSERT INTO "django_geo_db_zipcode" VALUES(38008,86339,-7,'Sedona, Arizona 86339',27392,33841);
INSERT INTO "django_geo_db_zipcode" VALUES(38009,86340,-7,'Sedona, Arizona 86340',27392,33822);
INSERT INTO "django_geo_db_zipcode" VALUES(38010,86341,-7,'Sedona, Arizona 86341',27392,33842);
INSERT INTO "django_geo_db_zipcode" VALUES(38011,86342,-7,'Lake Montezuma, Arizona 86342',27395,33843);
INSERT INTO "django_geo_db_zipcode" VALUES(38012,86343,-7,'Crown King, Arizona 86343',27396,33844);
INSERT INTO "django_geo_db_zipcode" VALUES(38013,86344,-7,'Paulden, Arizona 86344',27390,33845);
INSERT INTO "django_geo_db_zipcode" VALUES(38014,86351,-7,'Sedona, Arizona 86351',27392,33846);
INSERT INTO "django_geo_db_zipcode" VALUES(38015,86361,-7,'Bagdad, Arizona 86361',27375,33847);
INSERT INTO "django_geo_db_zipcode" VALUES(38016,86366,-7,'Cottonwood, Arizona 86366',27383,33848);
INSERT INTO "django_geo_db_zipcode" VALUES(38017,86401,-7,'Kingman, Arizona 86401',27397,33849);
INSERT INTO "django_geo_db_zipcode" VALUES(38018,86402,-7,'Kingman, Arizona 86402',27397,33850);
INSERT INTO "django_geo_db_zipcode" VALUES(38019,86403,-7,'Lake Havasu City, Arizona 86403',27398,33851);
INSERT INTO "django_geo_db_zipcode" VALUES(38020,86404,-7,'Lake Havasu City, Arizona 86404',27398,33852);
INSERT INTO "django_geo_db_zipcode" VALUES(38021,86405,-7,'Lake Havasu City, Arizona 86405',27398,33853);
INSERT INTO "django_geo_db_zipcode" VALUES(38022,86406,-7,'Lake Havasu City, Arizona 86406',27398,33854);
INSERT INTO "django_geo_db_zipcode" VALUES(38023,86411,-7,'Hackberry, Arizona 86411',27399,33853);
INSERT INTO "django_geo_db_zipcode" VALUES(38024,86412,-7,'Hualapai, Arizona 86412',27400,33855);
INSERT INTO "django_geo_db_zipcode" VALUES(38025,86413,-7,'Golden Valley, Arizona 86413',27401,33856);
INSERT INTO "django_geo_db_zipcode" VALUES(38026,86422,-7,'Bullhead City, Arizona 86422',27402,33857);
INSERT INTO "django_geo_db_zipcode" VALUES(38027,86426,-7,'Fort Mohave, Arizona 86426',27403,33858);
INSERT INTO "django_geo_db_zipcode" VALUES(38028,86427,-7,'Fort Mohave, Arizona 86427',27403,33859);
INSERT INTO "django_geo_db_zipcode" VALUES(38029,86429,-7,'Bullhead City, Arizona 86429',27402,33860);
INSERT INTO "django_geo_db_zipcode" VALUES(38030,86430,-7,'Bullhead City, Arizona 86430',27402,33861);
INSERT INTO "django_geo_db_zipcode" VALUES(38031,86431,-7,'Chloride, Arizona 86431',27404,33862);
INSERT INTO "django_geo_db_zipcode" VALUES(38032,86432,-7,'Littlefield, Arizona 86432',27405,33863);
INSERT INTO "django_geo_db_zipcode" VALUES(38033,86433,-7,'Oatman, Arizona 86433',27406,33864);
INSERT INTO "django_geo_db_zipcode" VALUES(38034,86434,-7,'Peach Springs, Arizona 86434',27407,33865);
INSERT INTO "django_geo_db_zipcode" VALUES(38035,86435,-7,'Supai, Arizona 86435',27408,33866);
INSERT INTO "django_geo_db_zipcode" VALUES(38036,86436,-7,'Topock, Arizona 86436',27409,33867);
INSERT INTO "django_geo_db_zipcode" VALUES(38037,86437,-7,'Valentine, Arizona 86437',27410,33868);
INSERT INTO "django_geo_db_zipcode" VALUES(38038,86438,-7,'Yucca, Arizona 86438',27411,33869);
INSERT INTO "django_geo_db_zipcode" VALUES(38039,86439,-7,'Bullhead City, Arizona 86439',27402,33870);
INSERT INTO "django_geo_db_zipcode" VALUES(38040,86440,-7,'Mohave Valley, Arizona 86440',27412,33871);
INSERT INTO "django_geo_db_zipcode" VALUES(38041,86441,-7,'Dolan Springs, Arizona 86441',27413,33872);
INSERT INTO "django_geo_db_zipcode" VALUES(38042,86442,-7,'Bullhead City, Arizona 86442',27402,33873);
INSERT INTO "django_geo_db_zipcode" VALUES(38043,86443,-7,'Temple Bar Marina, Arizona 86443',27414,33874);
INSERT INTO "django_geo_db_zipcode" VALUES(38044,86444,-7,'Meadview, Arizona 86444',27415,33875);
INSERT INTO "django_geo_db_zipcode" VALUES(38045,86445,-7,'Willow Beach, Arizona 86445',27416,33853);
INSERT INTO "django_geo_db_zipcode" VALUES(38046,86446,-7,'Mohave Valley, Arizona 86446',27412,33876);
INSERT INTO "django_geo_db_zipcode" VALUES(38047,86502,-7,'Chambers, Arizona 86502',27417,33877);
INSERT INTO "django_geo_db_zipcode" VALUES(38048,86503,-7,'Chinle, Arizona 86503',27418,33878);
INSERT INTO "django_geo_db_zipcode" VALUES(38049,86504,-7,'Fort Defiance, Arizona 86504',27419,33879);
INSERT INTO "django_geo_db_zipcode" VALUES(38050,86505,-7,'Ganado, Arizona 86505',27420,33880);
INSERT INTO "django_geo_db_zipcode" VALUES(38051,86506,-7,'Houck, Arizona 86506',27421,33881);
INSERT INTO "django_geo_db_zipcode" VALUES(38052,86507,-7,'Lukachukai, Arizona 86507',27422,33882);
INSERT INTO "django_geo_db_zipcode" VALUES(38053,86508,-7,'Lupton, Arizona 86508',27423,33883);
INSERT INTO "django_geo_db_zipcode" VALUES(38054,86510,-7,'Pinon, Arizona 86510',27424,33884);
INSERT INTO "django_geo_db_zipcode" VALUES(38055,86511,-7,'Saint Michaels, Arizona 86511',27425,33885);
INSERT INTO "django_geo_db_zipcode" VALUES(38056,86512,-7,'Sanders, Arizona 86512',27426,33886);
INSERT INTO "django_geo_db_zipcode" VALUES(38057,86514,-7,'Teec Nos Pos, Arizona 86514',27427,33887);
INSERT INTO "django_geo_db_zipcode" VALUES(38058,86515,-7,'Window Rock, Arizona 86515',27428,33888);
INSERT INTO "django_geo_db_zipcode" VALUES(38059,86520,-7,'Blue Gap, Arizona 86520',27429,33889);
INSERT INTO "django_geo_db_zipcode" VALUES(38060,86535,-7,'Dennehotso, Arizona 86535',27430,33890);
INSERT INTO "django_geo_db_zipcode" VALUES(38061,86538,-7,'Many Farms, Arizona 86538',27431,33891);
INSERT INTO "django_geo_db_zipcode" VALUES(38062,86540,-7,'Nazlini, Arizona 86540',27432,33892);
INSERT INTO "django_geo_db_zipcode" VALUES(38063,86544,-7,'Red Valley, Arizona 86544',27433,33893);
INSERT INTO "django_geo_db_zipcode" VALUES(38064,86545,-7,'Rock Point, Arizona 86545',27434,33894);
INSERT INTO "django_geo_db_zipcode" VALUES(38065,86547,-7,'Round Rock, Arizona 86547',27435,33895);
INSERT INTO "django_geo_db_zipcode" VALUES(38066,86549,-7,'Sawmill, Arizona 86549',27436,33896);
INSERT INTO "django_geo_db_zipcode" VALUES(38067,86551,-7,'Big Park, Arizona 86551',27437,33897);
INSERT INTO "django_geo_db_zipcode" VALUES(38068,86556,-7,'Tsaile, Arizona 86556',27438,33898);
INSERT INTO "django_geo_db_zipcode" VALUES(38069,86631,-7,'Jerome, Arizona 86631',27387,33899);
INSERT INTO "django_geo_db_zipcode" VALUES(38070,87001,-7,'Algodones, New Mexico 87001',27439,33900);
INSERT INTO "django_geo_db_zipcode" VALUES(38071,87002,-7,'Belen, New Mexico 87002',27440,33901);
INSERT INTO "django_geo_db_zipcode" VALUES(38072,87004,-7,'Bernalillo, New Mexico 87004',27441,33902);
INSERT INTO "django_geo_db_zipcode" VALUES(38073,87005,-7,'Bluewater, New Mexico 87005',27442,33903);
INSERT INTO "django_geo_db_zipcode" VALUES(38074,87006,-7,'Bosque, New Mexico 87006',27443,33904);
INSERT INTO "django_geo_db_zipcode" VALUES(38075,87007,-7,'Casa Blanca, New Mexico 87007',27444,33905);
INSERT INTO "django_geo_db_zipcode" VALUES(38076,87008,-7,'Cedar Crest, New Mexico 87008',27445,33906);
INSERT INTO "django_geo_db_zipcode" VALUES(38077,87009,-7,'Cedarvale, New Mexico 87009',27446,33907);
INSERT INTO "django_geo_db_zipcode" VALUES(38078,87010,-7,'Cerrillos, New Mexico 87010',27447,33908);
INSERT INTO "django_geo_db_zipcode" VALUES(38079,87011,-7,'Claunch, New Mexico 87011',27448,33909);
INSERT INTO "django_geo_db_zipcode" VALUES(38080,87012,-7,'Coyote, New Mexico 87012',27449,33910);
INSERT INTO "django_geo_db_zipcode" VALUES(38081,87013,-7,'Cuba, New Mexico 87013',27450,33911);
INSERT INTO "django_geo_db_zipcode" VALUES(38082,87014,-7,'Cubero, New Mexico 87014',27451,33912);
INSERT INTO "django_geo_db_zipcode" VALUES(38083,87015,-7,'Edgewood, New Mexico 87015',27452,33913);
INSERT INTO "django_geo_db_zipcode" VALUES(38084,87016,-7,'Estancia, New Mexico 87016',27453,33914);
INSERT INTO "django_geo_db_zipcode" VALUES(38085,87017,-7,'Gallina, New Mexico 87017',27454,33915);
INSERT INTO "django_geo_db_zipcode" VALUES(38086,87018,-7,'Counselor, New Mexico 87018',27455,33916);
INSERT INTO "django_geo_db_zipcode" VALUES(38087,87020,-7,'Grants, New Mexico 87020',27456,33917);
INSERT INTO "django_geo_db_zipcode" VALUES(38088,87021,-7,'Milan, New Mexico 87021',27457,33918);
INSERT INTO "django_geo_db_zipcode" VALUES(38089,87022,-7,'Isleta, New Mexico 87022',27458,33919);
INSERT INTO "django_geo_db_zipcode" VALUES(38090,87023,-7,'Jarales, New Mexico 87023',27459,33920);
INSERT INTO "django_geo_db_zipcode" VALUES(38091,87024,-7,'Jemez Pueblo, New Mexico 87024',27460,33921);
INSERT INTO "django_geo_db_zipcode" VALUES(38092,87025,-7,'Jemez Springs, New Mexico 87025',27461,33922);
INSERT INTO "django_geo_db_zipcode" VALUES(38093,87026,-7,'Laguna, New Mexico 87026',27462,33923);
INSERT INTO "django_geo_db_zipcode" VALUES(38094,87027,-7,'La Jara, New Mexico 87027',27463,33924);
INSERT INTO "django_geo_db_zipcode" VALUES(38095,87028,-7,'La Joya, New Mexico 87028',27464,33925);
INSERT INTO "django_geo_db_zipcode" VALUES(38096,87029,-7,'Lindrith, New Mexico 87029',27465,33926);
INSERT INTO "django_geo_db_zipcode" VALUES(38097,87031,-7,'Los Lunas, New Mexico 87031',27466,33927);
INSERT INTO "django_geo_db_zipcode" VALUES(38098,87032,-7,'McIntosh, New Mexico 87032',27467,33928);
INSERT INTO "django_geo_db_zipcode" VALUES(38099,87034,-7,'Pueblo Of Acoma, New Mexico 87034',27468,33929);
INSERT INTO "django_geo_db_zipcode" VALUES(38100,87035,-7,'Moriarty, New Mexico 87035',27469,33930);
INSERT INTO "django_geo_db_zipcode" VALUES(38101,87036,-7,'Mountainair, New Mexico 87036',27470,33931);
INSERT INTO "django_geo_db_zipcode" VALUES(38102,87037,-7,'Nageezi, New Mexico 87037',27471,33932);
INSERT INTO "django_geo_db_zipcode" VALUES(38103,87038,-7,'New Laguna, New Mexico 87038',27472,33933);
INSERT INTO "django_geo_db_zipcode" VALUES(38104,87040,-7,'Paguate, New Mexico 87040',27473,33934);
INSERT INTO "django_geo_db_zipcode" VALUES(38105,87041,-7,'Pena Blanca, New Mexico 87041',27474,33935);
INSERT INTO "django_geo_db_zipcode" VALUES(38106,87042,-7,'Peralta, New Mexico 87042',27475,33936);
INSERT INTO "django_geo_db_zipcode" VALUES(38107,87043,-7,'Placitas, New Mexico 87043',27476,33937);
INSERT INTO "django_geo_db_zipcode" VALUES(38108,87044,-7,'Ponderosa, New Mexico 87044',27477,33938);
INSERT INTO "django_geo_db_zipcode" VALUES(38109,87045,-7,'Prewitt, New Mexico 87045',27478,33939);
INSERT INTO "django_geo_db_zipcode" VALUES(38110,87046,-7,'Regina, New Mexico 87046',27479,33940);
INSERT INTO "django_geo_db_zipcode" VALUES(38111,87047,-7,'Sandia Park, New Mexico 87047',27480,33941);
INSERT INTO "django_geo_db_zipcode" VALUES(38112,87048,-7,'Corrales, New Mexico 87048',27481,33942);
INSERT INTO "django_geo_db_zipcode" VALUES(38113,87049,-7,'San Fidel, New Mexico 87049',27482,33943);
INSERT INTO "django_geo_db_zipcode" VALUES(38114,87051,-7,'San Rafael, New Mexico 87051',27483,33944);
INSERT INTO "django_geo_db_zipcode" VALUES(38115,87052,-7,'Santo Domingo Pueblo, New Mexico 87052',27484,33945);
INSERT INTO "django_geo_db_zipcode" VALUES(38116,87053,-7,'San Ysidro, New Mexico 87053',27485,33946);
INSERT INTO "django_geo_db_zipcode" VALUES(38117,87056,-7,'Stanley, New Mexico 87056',27486,33947);
INSERT INTO "django_geo_db_zipcode" VALUES(38118,87057,-7,'Tajique, New Mexico 87057',27487,33907);
INSERT INTO "django_geo_db_zipcode" VALUES(38119,87059,-7,'Tijeras, New Mexico 87059',27488,33948);
INSERT INTO "django_geo_db_zipcode" VALUES(38120,87060,-7,'Tome, New Mexico 87060',27489,33949);
INSERT INTO "django_geo_db_zipcode" VALUES(38121,87061,-7,'Torreon, New Mexico 87061',27490,33950);
INSERT INTO "django_geo_db_zipcode" VALUES(38122,87062,-7,'Veguita, New Mexico 87062',27491,33951);
INSERT INTO "django_geo_db_zipcode" VALUES(38123,87063,-7,'Willard, New Mexico 87063',27492,33952);
INSERT INTO "django_geo_db_zipcode" VALUES(38124,87064,-7,'Youngsville, New Mexico 87064',27493,33953);
INSERT INTO "django_geo_db_zipcode" VALUES(38125,87068,-7,'Bosque Farms, New Mexico 87068',27494,33954);
INSERT INTO "django_geo_db_zipcode" VALUES(38126,87070,-7,'Clines Corners, New Mexico 87070',27495,33955);
INSERT INTO "django_geo_db_zipcode" VALUES(38127,87072,-7,'Cochiti Pueblo, New Mexico 87072',27496,33956);
INSERT INTO "django_geo_db_zipcode" VALUES(38128,87083,-7,'Cochiti Lake, New Mexico 87083',27497,33957);
INSERT INTO "django_geo_db_zipcode" VALUES(38129,87101,-7,'Albuquerque, New Mexico 87101',27498,33958);
INSERT INTO "django_geo_db_zipcode" VALUES(38130,87102,-7,'Albuquerque, New Mexico 87102',27498,33959);
INSERT INTO "django_geo_db_zipcode" VALUES(38131,87103,-7,'Albuquerque, New Mexico 87103',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38132,87104,-7,'Albuquerque, New Mexico 87104',27498,33961);
INSERT INTO "django_geo_db_zipcode" VALUES(38133,87105,-7,'Albuquerque, New Mexico 87105',27498,33962);
INSERT INTO "django_geo_db_zipcode" VALUES(38134,87106,-7,'Albuquerque, New Mexico 87106',27498,33963);
INSERT INTO "django_geo_db_zipcode" VALUES(38135,87107,-7,'Albuquerque, New Mexico 87107',27498,33964);
INSERT INTO "django_geo_db_zipcode" VALUES(38136,87108,-7,'Albuquerque, New Mexico 87108',27498,33965);
INSERT INTO "django_geo_db_zipcode" VALUES(38137,87109,-7,'Albuquerque, New Mexico 87109',27498,33966);
INSERT INTO "django_geo_db_zipcode" VALUES(38138,87110,-7,'Albuquerque, New Mexico 87110',27498,33967);
INSERT INTO "django_geo_db_zipcode" VALUES(38139,87111,-7,'Albuquerque, New Mexico 87111',27498,33968);
INSERT INTO "django_geo_db_zipcode" VALUES(38140,87112,-7,'Albuquerque, New Mexico 87112',27498,33969);
INSERT INTO "django_geo_db_zipcode" VALUES(38141,87113,-7,'Albuquerque, New Mexico 87113',27498,33970);
INSERT INTO "django_geo_db_zipcode" VALUES(38142,87114,-7,'Albuquerque, New Mexico 87114',27498,33971);
INSERT INTO "django_geo_db_zipcode" VALUES(38143,87115,-7,'Albuquerque, New Mexico 87115',27498,33972);
INSERT INTO "django_geo_db_zipcode" VALUES(38144,87116,-7,'Albuquerque, New Mexico 87116',27498,33973);
INSERT INTO "django_geo_db_zipcode" VALUES(38145,87117,-7,'Kirtland AFB, New Mexico 87117',27499,33974);
INSERT INTO "django_geo_db_zipcode" VALUES(38146,87118,-7,'Albuquerque, New Mexico 87118',27498,33975);
INSERT INTO "django_geo_db_zipcode" VALUES(38147,87119,-7,'Albuquerque, New Mexico 87119',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38148,87120,-7,'Albuquerque, New Mexico 87120',27498,33976);
INSERT INTO "django_geo_db_zipcode" VALUES(38149,87121,-7,'Albuquerque, New Mexico 87121',27498,33977);
INSERT INTO "django_geo_db_zipcode" VALUES(38150,87122,-7,'Albuquerque, New Mexico 87122',27498,33978);
INSERT INTO "django_geo_db_zipcode" VALUES(38151,87123,-7,'Albuquerque, New Mexico 87123',27498,33979);
INSERT INTO "django_geo_db_zipcode" VALUES(38152,87124,-7,'Rio Rancho, New Mexico 87124',27500,33980);
INSERT INTO "django_geo_db_zipcode" VALUES(38153,87125,-7,'Albuquerque, New Mexico 87125',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38154,87131,-7,'Albuquerque, New Mexico 87131',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38155,87140,-7,'Albuquerque, New Mexico 87140',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38156,87144,-7,'Rio Rancho, New Mexico 87144',27500,33981);
INSERT INTO "django_geo_db_zipcode" VALUES(38157,87153,-7,'Albuquerque, New Mexico 87153',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38158,87154,-7,'Albuquerque, New Mexico 87154',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38159,87158,-7,'Albuquerque, New Mexico 87158',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38160,87174,-7,'Rio Rancho, New Mexico 87174',27500,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38161,87176,-7,'Albuquerque, New Mexico 87176',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38162,87180,-7,'Albuquerque, New Mexico 87180',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38163,87181,-7,'Albuquerque, New Mexico 87181',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38164,87184,-7,'Albuquerque, New Mexico 87184',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38165,87185,-7,'Albuquerque, New Mexico 87185',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38166,87187,-7,'Albuquerque, New Mexico 87187',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38167,87190,-7,'Albuquerque, New Mexico 87190',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38168,87191,-7,'Albuquerque, New Mexico 87191',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38169,87192,-7,'Albuquerque, New Mexico 87192',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38170,87193,-7,'Albuquerque, New Mexico 87193',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38171,87194,-7,'Albuquerque, New Mexico 87194',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38172,87195,-7,'Albuquerque, New Mexico 87195',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38173,87196,-7,'Albuquerque, New Mexico 87196',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38174,87197,-7,'Albuquerque, New Mexico 87197',27498,33982);
INSERT INTO "django_geo_db_zipcode" VALUES(38175,87198,-7,'Albuquerque, New Mexico 87198',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38176,87199,-7,'Albuquerque, New Mexico 87199',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38177,87201,-7,'Albuquerque, New Mexico 87201',27498,33960);
INSERT INTO "django_geo_db_zipcode" VALUES(38178,87301,-7,'Gallup, New Mexico 87301',27501,33983);
INSERT INTO "django_geo_db_zipcode" VALUES(38179,87302,-7,'Gallup, New Mexico 87302',27501,33984);
INSERT INTO "django_geo_db_zipcode" VALUES(38180,87305,-7,'Gallup, New Mexico 87305',27501,33985);
INSERT INTO "django_geo_db_zipcode" VALUES(38181,87310,-7,'Brimhall, New Mexico 87310',27502,33986);
INSERT INTO "django_geo_db_zipcode" VALUES(38182,87311,-7,'Church Rock, New Mexico 87311',27503,33987);
INSERT INTO "django_geo_db_zipcode" VALUES(38183,87312,-7,'Continental Divide, New Mexico 87312',27504,33988);
INSERT INTO "django_geo_db_zipcode" VALUES(38184,87313,-7,'Crownpoint, New Mexico 87313',27505,33989);
INSERT INTO "django_geo_db_zipcode" VALUES(38185,87315,-7,'Fence Lake, New Mexico 87315',27506,33990);
INSERT INTO "django_geo_db_zipcode" VALUES(38186,87316,-7,'Fort Wingate, New Mexico 87316',27507,33991);
INSERT INTO "django_geo_db_zipcode" VALUES(38187,87317,-7,'Gamerco, New Mexico 87317',27508,33992);
INSERT INTO "django_geo_db_zipcode" VALUES(38188,87319,-7,'Mentmore, New Mexico 87319',27509,33993);
INSERT INTO "django_geo_db_zipcode" VALUES(38189,87320,-7,'Mexican Springs, New Mexico 87320',27510,33994);
INSERT INTO "django_geo_db_zipcode" VALUES(38190,87321,-7,'Ramah, New Mexico 87321',27511,33995);
INSERT INTO "django_geo_db_zipcode" VALUES(38191,87322,-7,'Rehoboth, New Mexico 87322',27512,33996);
INSERT INTO "django_geo_db_zipcode" VALUES(38192,87323,-7,'Thoreau, New Mexico 87323',27513,33997);
INSERT INTO "django_geo_db_zipcode" VALUES(38193,87325,-7,'Tohatchi, New Mexico 87325',27514,33998);
INSERT INTO "django_geo_db_zipcode" VALUES(38194,87326,-7,'Vanderwagen, New Mexico 87326',27515,33999);
INSERT INTO "django_geo_db_zipcode" VALUES(38195,87327,-7,'Zuni, New Mexico 87327',27516,34000);
INSERT INTO "django_geo_db_zipcode" VALUES(38196,87328,-7,'Navajo, Arizona 87328',27517,34001);
INSERT INTO "django_geo_db_zipcode" VALUES(38197,87347,-7,'Jamestown, New Mexico 87347',27518,34002);
INSERT INTO "django_geo_db_zipcode" VALUES(38198,87357,-7,'Pinehill, New Mexico 87357',27519,34003);
INSERT INTO "django_geo_db_zipcode" VALUES(38199,87364,-7,'Sheep Springs, New Mexico 87364',27520,34004);
INSERT INTO "django_geo_db_zipcode" VALUES(38200,87365,-7,'Smith Lake, New Mexico 87365',27521,33984);
INSERT INTO "django_geo_db_zipcode" VALUES(38201,87375,-7,'Yatahey, New Mexico 87375',27522,34005);
INSERT INTO "django_geo_db_zipcode" VALUES(38202,87378,-7,'Navajo, New Mexico 87378',27523,34006);
INSERT INTO "django_geo_db_zipcode" VALUES(38203,87401,-7,'Farmington, New Mexico 87401',27524,34007);
INSERT INTO "django_geo_db_zipcode" VALUES(38204,87402,-7,'Farmington, New Mexico 87402',27524,34008);
INSERT INTO "django_geo_db_zipcode" VALUES(38205,87410,-7,'Aztec, New Mexico 87410',27525,34009);
INSERT INTO "django_geo_db_zipcode" VALUES(38206,87412,-7,'Blanco, New Mexico 87412',27526,34010);
INSERT INTO "django_geo_db_zipcode" VALUES(38207,87413,-7,'Bloomfield, New Mexico 87413',27527,34011);
INSERT INTO "django_geo_db_zipcode" VALUES(38208,87415,-7,'Flora Vista, New Mexico 87415',27528,34012);
INSERT INTO "django_geo_db_zipcode" VALUES(38209,87416,-7,'Fruitland, New Mexico 87416',27529,34013);
INSERT INTO "django_geo_db_zipcode" VALUES(38210,87417,-7,'Kirtland, New Mexico 87417',27530,34014);
INSERT INTO "django_geo_db_zipcode" VALUES(38211,87418,-7,'La Plata, New Mexico 87418',27531,34015);
INSERT INTO "django_geo_db_zipcode" VALUES(38212,87419,-7,'Navajo Dam, New Mexico 87419',27532,34016);
INSERT INTO "django_geo_db_zipcode" VALUES(38213,87420,-7,'Shiprock, New Mexico 87420',27533,34017);
INSERT INTO "django_geo_db_zipcode" VALUES(38214,87421,-7,'Waterflow, New Mexico 87421',27534,34018);
INSERT INTO "django_geo_db_zipcode" VALUES(38215,87455,-7,'Newcomb, New Mexico 87455',27535,34019);
INSERT INTO "django_geo_db_zipcode" VALUES(38216,87461,-7,'Sanostee, New Mexico 87461',27536,34020);
INSERT INTO "django_geo_db_zipcode" VALUES(38217,87499,-7,'Farmington, New Mexico 87499',27524,34021);
INSERT INTO "django_geo_db_zipcode" VALUES(38218,87501,-7,'Santa Fe, New Mexico 87501',27537,34022);
INSERT INTO "django_geo_db_zipcode" VALUES(38219,87502,-7,'Santa Fe, New Mexico 87502',27537,34023);
INSERT INTO "django_geo_db_zipcode" VALUES(38220,87503,-7,'Santa Fe, New Mexico 87503',27537,34024);
INSERT INTO "django_geo_db_zipcode" VALUES(38221,87504,-7,'Santa Fe, New Mexico 87504',27537,34025);
INSERT INTO "django_geo_db_zipcode" VALUES(38222,87505,-7,'Santa Fe, New Mexico 87505',27537,34026);
INSERT INTO "django_geo_db_zipcode" VALUES(38223,87506,-7,'Santa Fe, New Mexico 87506',27537,34027);
INSERT INTO "django_geo_db_zipcode" VALUES(38224,87507,-7,'Santa Fe, New Mexico 87507',27537,34028);
INSERT INTO "django_geo_db_zipcode" VALUES(38225,87508,-7,'Santa Fe, New Mexico 87508',27537,34029);
INSERT INTO "django_geo_db_zipcode" VALUES(38226,87509,-7,'Santa Fe, New Mexico 87509',27537,34024);
INSERT INTO "django_geo_db_zipcode" VALUES(38227,87510,-7,'Abiquiu, New Mexico 87510',27538,34030);
INSERT INTO "django_geo_db_zipcode" VALUES(38228,87511,-7,'Alcalde, New Mexico 87511',27539,34031);
INSERT INTO "django_geo_db_zipcode" VALUES(38229,87512,-7,'Amalia, New Mexico 87512',27540,34032);
INSERT INTO "django_geo_db_zipcode" VALUES(38230,87513,-7,'Arroyo Hondo, New Mexico 87513',27541,34033);
INSERT INTO "django_geo_db_zipcode" VALUES(38231,87514,-7,'Arroyo Seco, New Mexico 87514',27542,34034);
INSERT INTO "django_geo_db_zipcode" VALUES(38232,87515,-7,'Canjilon, New Mexico 87515',27543,34035);
INSERT INTO "django_geo_db_zipcode" VALUES(38233,87516,-7,'Canones, New Mexico 87516',27544,34036);
INSERT INTO "django_geo_db_zipcode" VALUES(38234,87517,-7,'Carson, New Mexico 87517',27545,34037);
INSERT INTO "django_geo_db_zipcode" VALUES(38235,87518,-7,'Cebolla, New Mexico 87518',27546,34038);
INSERT INTO "django_geo_db_zipcode" VALUES(38236,87519,-7,'Cerro, New Mexico 87519',27547,34039);
INSERT INTO "django_geo_db_zipcode" VALUES(38237,87520,-7,'Chama, New Mexico 87520',27548,34040);
INSERT INTO "django_geo_db_zipcode" VALUES(38238,87521,-7,'Chamisal, New Mexico 87521',27549,34041);
INSERT INTO "django_geo_db_zipcode" VALUES(38239,87522,-7,'Chimayo, New Mexico 87522',27550,34042);
INSERT INTO "django_geo_db_zipcode" VALUES(38240,87523,-7,'Cordova, New Mexico 87523',27551,34043);
INSERT INTO "django_geo_db_zipcode" VALUES(38241,87524,-7,'Costilla, New Mexico 87524',27552,34044);
INSERT INTO "django_geo_db_zipcode" VALUES(38242,87525,-7,'Taos Ski Valley, New Mexico 87525',27553,34045);
INSERT INTO "django_geo_db_zipcode" VALUES(38243,87527,-7,'Dixon, New Mexico 87527',27554,34046);
INSERT INTO "django_geo_db_zipcode" VALUES(38244,87528,-7,'Dulce, New Mexico 87528',27555,34047);
INSERT INTO "django_geo_db_zipcode" VALUES(38245,87529,-7,'El Prado, New Mexico 87529',27556,34048);
INSERT INTO "django_geo_db_zipcode" VALUES(38246,87530,-7,'El Rito, New Mexico 87530',27557,34049);
INSERT INTO "django_geo_db_zipcode" VALUES(38247,87531,-7,'Embudo, New Mexico 87531',27558,34050);
INSERT INTO "django_geo_db_zipcode" VALUES(38248,87532,-7,'Espanola, New Mexico 87532',27559,34051);
INSERT INTO "django_geo_db_zipcode" VALUES(38249,87533,-7,'Espanola, New Mexico 87533',27559,34052);
INSERT INTO "django_geo_db_zipcode" VALUES(38250,87535,-7,'Glorieta, New Mexico 87535',27560,34053);
INSERT INTO "django_geo_db_zipcode" VALUES(38251,87537,-7,'Hernandez, New Mexico 87537',27561,34054);
INSERT INTO "django_geo_db_zipcode" VALUES(38252,87538,-7,'Ilfeld, New Mexico 87538',27562,34055);
INSERT INTO "django_geo_db_zipcode" VALUES(38253,87539,-7,'La Madera, New Mexico 87539',27563,34056);
INSERT INTO "django_geo_db_zipcode" VALUES(38254,87540,-7,'Lamy, New Mexico 87540',27564,34057);
INSERT INTO "django_geo_db_zipcode" VALUES(38255,87543,-7,'Llano, New Mexico 87543',27565,34058);
INSERT INTO "django_geo_db_zipcode" VALUES(38256,87544,-7,'Los Alamos, New Mexico 87544',27566,34059);
INSERT INTO "django_geo_db_zipcode" VALUES(38257,87545,-7,'Los Alamos, New Mexico 87545',27566,34060);
INSERT INTO "django_geo_db_zipcode" VALUES(38258,87548,-7,'Medanales, New Mexico 87548',27567,34061);
INSERT INTO "django_geo_db_zipcode" VALUES(38259,87549,-7,'Ojo Caliente, New Mexico 87549',27568,34062);
INSERT INTO "django_geo_db_zipcode" VALUES(38260,87551,-7,'Los Ojos, New Mexico 87551',27569,34063);
INSERT INTO "django_geo_db_zipcode" VALUES(38261,87552,-7,'Pecos, New Mexico 87552',27570,34064);
INSERT INTO "django_geo_db_zipcode" VALUES(38262,87553,-7,'Penasco, New Mexico 87553',27571,34065);
INSERT INTO "django_geo_db_zipcode" VALUES(38263,87554,-7,'Petaca, New Mexico 87554',27572,34066);
INSERT INTO "django_geo_db_zipcode" VALUES(38264,87556,-7,'Questa, New Mexico 87556',27573,34067);
INSERT INTO "django_geo_db_zipcode" VALUES(38265,87557,-7,'Ranchos De Taos, New Mexico 87557',27574,34068);
INSERT INTO "django_geo_db_zipcode" VALUES(38266,87558,-7,'Red River, New Mexico 87558',27575,34069);
INSERT INTO "django_geo_db_zipcode" VALUES(38267,87560,-7,'Ribera, New Mexico 87560',27576,34070);
INSERT INTO "django_geo_db_zipcode" VALUES(38268,87562,-7,'Rowe, New Mexico 87562',27577,34071);
INSERT INTO "django_geo_db_zipcode" VALUES(38269,87564,-7,'San Cristobal, New Mexico 87564',27578,34072);
INSERT INTO "django_geo_db_zipcode" VALUES(38270,87565,-7,'San Jose, New Mexico 87565',27579,34073);
INSERT INTO "django_geo_db_zipcode" VALUES(38271,87566,-7,'San Juan Pueblo, New Mexico 87566',27580,34074);
INSERT INTO "django_geo_db_zipcode" VALUES(38272,87567,-7,'Santa Cruz, New Mexico 87567',27581,34075);
INSERT INTO "django_geo_db_zipcode" VALUES(38273,87569,-7,'Serafina, New Mexico 87569',27582,34076);
INSERT INTO "django_geo_db_zipcode" VALUES(38274,87571,-7,'Taos, New Mexico 87571',27583,34077);
INSERT INTO "django_geo_db_zipcode" VALUES(38275,87573,-7,'Tererro, New Mexico 87573',27584,34078);
INSERT INTO "django_geo_db_zipcode" VALUES(38276,87574,-7,'Tesuque, New Mexico 87574',27585,34079);
INSERT INTO "django_geo_db_zipcode" VALUES(38277,87575,-7,'Tierra Amarilla, New Mexico 87575',27586,34080);
INSERT INTO "django_geo_db_zipcode" VALUES(38278,87576,-7,'Trampas, New Mexico 87576',27587,34081);
INSERT INTO "django_geo_db_zipcode" VALUES(38279,87577,-7,'Tres Piedras, New Mexico 87577',27588,34082);
INSERT INTO "django_geo_db_zipcode" VALUES(38280,87578,-7,'Truchas, New Mexico 87578',27589,34083);
INSERT INTO "django_geo_db_zipcode" VALUES(38281,87579,-7,'Vadito, New Mexico 87579',27590,34084);
INSERT INTO "django_geo_db_zipcode" VALUES(38282,87580,-7,'Valdez, New Mexico 87580',27591,34085);
INSERT INTO "django_geo_db_zipcode" VALUES(38283,87581,-7,'Vallecitos, New Mexico 87581',27592,34086);
INSERT INTO "django_geo_db_zipcode" VALUES(38284,87582,-7,'Velarde, New Mexico 87582',27593,34087);
INSERT INTO "django_geo_db_zipcode" VALUES(38285,87583,-7,'Villanueva, New Mexico 87583',27594,34088);
INSERT INTO "django_geo_db_zipcode" VALUES(38286,87585,-7,'Santa Fe, New Mexico 87585',27537,34089);
INSERT INTO "django_geo_db_zipcode" VALUES(38287,87592,-7,'Santa Fe, New Mexico 87592',27537,34024);
INSERT INTO "django_geo_db_zipcode" VALUES(38288,87594,-7,'Santa Fe, New Mexico 87594',27537,34024);
INSERT INTO "django_geo_db_zipcode" VALUES(38289,87701,-7,'Las Vegas, New Mexico 87701',27595,34090);
INSERT INTO "django_geo_db_zipcode" VALUES(38290,87710,-7,'Angel Fire, New Mexico 87710',27596,34091);
INSERT INTO "django_geo_db_zipcode" VALUES(38291,87711,-7,'Anton Chico, New Mexico 87711',27597,34092);
INSERT INTO "django_geo_db_zipcode" VALUES(38292,87712,-7,'Buena Vista, New Mexico 87712',27598,34093);
INSERT INTO "django_geo_db_zipcode" VALUES(38293,87713,-7,'Chacon, New Mexico 87713',27599,34094);
INSERT INTO "django_geo_db_zipcode" VALUES(38294,87714,-7,'Cimarron, New Mexico 87714',27600,34095);
INSERT INTO "django_geo_db_zipcode" VALUES(38295,87715,-7,'Cleveland, New Mexico 87715',27601,34096);
INSERT INTO "django_geo_db_zipcode" VALUES(38296,87718,-7,'Eagle Nest, New Mexico 87718',27602,34097);
INSERT INTO "django_geo_db_zipcode" VALUES(38297,87722,-7,'Guadalupita, New Mexico 87722',27603,34098);
INSERT INTO "django_geo_db_zipcode" VALUES(38298,87723,-7,'Holman, New Mexico 87723',27604,34099);
INSERT INTO "django_geo_db_zipcode" VALUES(38299,87724,-7,'La Loma, New Mexico 87724',27605,34100);
INSERT INTO "django_geo_db_zipcode" VALUES(38300,87728,-7,'Maxwell, New Mexico 87728',27606,34101);
INSERT INTO "django_geo_db_zipcode" VALUES(38301,87729,-7,'Miami, New Mexico 87729',27607,34102);
INSERT INTO "django_geo_db_zipcode" VALUES(38302,87730,-7,'Mills, New Mexico 87730',27608,34103);
INSERT INTO "django_geo_db_zipcode" VALUES(38303,87731,-7,'Montezuma, New Mexico 87731',27609,34104);
INSERT INTO "django_geo_db_zipcode" VALUES(38304,87732,-7,'Mora, New Mexico 87732',27610,34105);
INSERT INTO "django_geo_db_zipcode" VALUES(38305,87733,-7,'Mosquero, New Mexico 87733',27611,34106);
INSERT INTO "django_geo_db_zipcode" VALUES(38306,87734,-7,'Ocate, New Mexico 87734',27612,34107);
INSERT INTO "django_geo_db_zipcode" VALUES(38307,87735,-7,'Ojo Feliz, New Mexico 87735',27613,34108);
INSERT INTO "django_geo_db_zipcode" VALUES(38308,87736,-7,'Rainsville, New Mexico 87736',27614,34109);
INSERT INTO "django_geo_db_zipcode" VALUES(38309,87740,-7,'Raton, New Mexico 87740',27615,34110);
INSERT INTO "django_geo_db_zipcode" VALUES(38310,87742,-7,'Rociada, New Mexico 87742',27616,34111);
INSERT INTO "django_geo_db_zipcode" VALUES(38311,87743,-7,'Roy, New Mexico 87743',27617,34112);
INSERT INTO "django_geo_db_zipcode" VALUES(38312,87745,-7,'Sapello, New Mexico 87745',27618,34113);
INSERT INTO "django_geo_db_zipcode" VALUES(38313,87746,-7,'Solano, New Mexico 87746',27619,34114);
INSERT INTO "django_geo_db_zipcode" VALUES(38314,87747,-7,'Springer, New Mexico 87747',27620,34115);
INSERT INTO "django_geo_db_zipcode" VALUES(38315,87749,-7,'Ute Park, New Mexico 87749',27621,34116);
INSERT INTO "django_geo_db_zipcode" VALUES(38316,87750,-7,'Valmora, New Mexico 87750',27622,34117);
INSERT INTO "django_geo_db_zipcode" VALUES(38317,87752,-7,'Wagon Mound, New Mexico 87752',27623,34118);
INSERT INTO "django_geo_db_zipcode" VALUES(38318,87753,-7,'Watrous, New Mexico 87753',27624,34119);
INSERT INTO "django_geo_db_zipcode" VALUES(38319,87801,-7,'Socorro, New Mexico 87801',27625,34120);
INSERT INTO "django_geo_db_zipcode" VALUES(38320,87820,-7,'Aragon, New Mexico 87820',27626,34121);
INSERT INTO "django_geo_db_zipcode" VALUES(38321,87821,-7,'Datil, New Mexico 87821',27627,34122);
INSERT INTO "django_geo_db_zipcode" VALUES(38322,87823,-7,'Lemitar, New Mexico 87823',27628,34123);
INSERT INTO "django_geo_db_zipcode" VALUES(38323,87824,-7,'Luna, New Mexico 87824',27629,34124);
INSERT INTO "django_geo_db_zipcode" VALUES(38324,87825,-7,'Magdalena, New Mexico 87825',27630,34125);
INSERT INTO "django_geo_db_zipcode" VALUES(38325,87827,-7,'Pie Town, New Mexico 87827',27631,34126);
INSERT INTO "django_geo_db_zipcode" VALUES(38326,87828,-7,'Polvadera, New Mexico 87828',27632,34127);
INSERT INTO "django_geo_db_zipcode" VALUES(38327,87829,-7,'Quemado, New Mexico 87829',27633,34128);
INSERT INTO "django_geo_db_zipcode" VALUES(38328,87830,-7,'Reserve, New Mexico 87830',27634,34129);
INSERT INTO "django_geo_db_zipcode" VALUES(38329,87831,-7,'San Acacia, New Mexico 87831',27635,34130);
INSERT INTO "django_geo_db_zipcode" VALUES(38330,87832,-7,'San Antonio, New Mexico 87832',27636,34131);
INSERT INTO "django_geo_db_zipcode" VALUES(38331,87901,-7,'Truth Or Consequences, New Mexico 87901',27637,34132);
INSERT INTO "django_geo_db_zipcode" VALUES(38332,87910,-7,'Truth or Consequences, New Mexico 87910',27638,34133);
INSERT INTO "django_geo_db_zipcode" VALUES(38333,87930,-7,'Arrey, New Mexico 87930',27639,34134);
INSERT INTO "django_geo_db_zipcode" VALUES(38334,87931,-7,'Caballo, New Mexico 87931',27640,34135);
INSERT INTO "django_geo_db_zipcode" VALUES(38335,87933,-7,'Derry, New Mexico 87933',27641,34136);
INSERT INTO "django_geo_db_zipcode" VALUES(38336,87935,-7,'Elephant Butte, New Mexico 87935',27642,34137);
INSERT INTO "django_geo_db_zipcode" VALUES(38337,87936,-7,'Garfield, New Mexico 87936',27643,34138);
INSERT INTO "django_geo_db_zipcode" VALUES(38338,87937,-7,'Hatch, New Mexico 87937',27644,34139);
INSERT INTO "django_geo_db_zipcode" VALUES(38339,87939,-7,'Monticello, New Mexico 87939',27645,34140);
INSERT INTO "django_geo_db_zipcode" VALUES(38340,87940,-7,'Rincon, New Mexico 87940',27646,34141);
INSERT INTO "django_geo_db_zipcode" VALUES(38341,87941,-7,'Salem, New Mexico 87941',27647,34142);
INSERT INTO "django_geo_db_zipcode" VALUES(38342,87942,-7,'Williamsburg, New Mexico 87942',27648,34143);
INSERT INTO "django_geo_db_zipcode" VALUES(38343,87943,-7,'Winston, New Mexico 87943',27649,34144);
INSERT INTO "django_geo_db_zipcode" VALUES(38344,87945,-7,'Williamsburg, New Mexico 87945',27648,34145);
INSERT INTO "django_geo_db_zipcode" VALUES(38345,88001,-7,'Las Cruces, New Mexico 88001',27650,34146);
INSERT INTO "django_geo_db_zipcode" VALUES(38346,88002,-7,'White Sands Missile Range, New Mexico 88002',27651,34147);
INSERT INTO "django_geo_db_zipcode" VALUES(38347,88003,-7,'Las Cruces, New Mexico 88003',27650,34148);
INSERT INTO "django_geo_db_zipcode" VALUES(38348,88004,-7,'Las Cruces, New Mexico 88004',27650,34149);
INSERT INTO "django_geo_db_zipcode" VALUES(38349,88005,-7,'Las Cruces, New Mexico 88005',27650,34150);
INSERT INTO "django_geo_db_zipcode" VALUES(38350,88006,-7,'Las Cruces, New Mexico 88006',27650,34151);
INSERT INTO "django_geo_db_zipcode" VALUES(38351,88007,-7,'Las Cruces, New Mexico 88007',27650,34152);
INSERT INTO "django_geo_db_zipcode" VALUES(38352,88008,-7,'Santa Teresa, New Mexico 88008',27652,34153);
INSERT INTO "django_geo_db_zipcode" VALUES(38353,88009,-7,'Playas, New Mexico 88009',27653,34154);
INSERT INTO "django_geo_db_zipcode" VALUES(38354,88011,-7,'Las Cruces, New Mexico 88011',27650,34155);
INSERT INTO "django_geo_db_zipcode" VALUES(38355,88012,-7,'Las Cruces, New Mexico 88012',27650,34156);
INSERT INTO "django_geo_db_zipcode" VALUES(38356,88018,-7,'Sunland Park, New Mexico 88018',27654,34157);
INSERT INTO "django_geo_db_zipcode" VALUES(38357,88020,-7,'Animas, New Mexico 88020',27655,34158);
INSERT INTO "django_geo_db_zipcode" VALUES(38358,88021,-7,'Anthony, New Mexico 88021',27656,34159);
INSERT INTO "django_geo_db_zipcode" VALUES(38359,88022,-7,'Arenas Valley, New Mexico 88022',27657,34160);
INSERT INTO "django_geo_db_zipcode" VALUES(38360,88023,-7,'Bayard, New Mexico 88023',27658,34161);
INSERT INTO "django_geo_db_zipcode" VALUES(38361,88024,-7,'Berino, New Mexico 88024',27659,34162);
INSERT INTO "django_geo_db_zipcode" VALUES(38362,88025,-7,'Buckhorn, New Mexico 88025',27660,34163);
INSERT INTO "django_geo_db_zipcode" VALUES(38363,88026,-7,'Santa Clara, New Mexico 88026',27661,34164);
INSERT INTO "django_geo_db_zipcode" VALUES(38364,88027,-7,'Chamberino, New Mexico 88027',27662,34165);
INSERT INTO "django_geo_db_zipcode" VALUES(38365,88028,-7,'Cliff, New Mexico 88028',27663,34166);
INSERT INTO "django_geo_db_zipcode" VALUES(38366,88029,-7,'Columbus, New Mexico 88029',27664,34167);
INSERT INTO "django_geo_db_zipcode" VALUES(38367,88030,-7,'Deming, New Mexico 88030',27665,34168);
INSERT INTO "django_geo_db_zipcode" VALUES(38368,88031,-7,'Deming, New Mexico 88031',27665,34169);
INSERT INTO "django_geo_db_zipcode" VALUES(38369,88032,-7,'Dona Ana, New Mexico 88032',27666,34170);
INSERT INTO "django_geo_db_zipcode" VALUES(38370,88033,-7,'Fairacres, New Mexico 88033',27667,34171);
INSERT INTO "django_geo_db_zipcode" VALUES(38371,88034,-7,'Faywood, New Mexico 88034',27668,34172);
INSERT INTO "django_geo_db_zipcode" VALUES(38372,88036,-7,'Fort Bayard, New Mexico 88036',27669,34173);
INSERT INTO "django_geo_db_zipcode" VALUES(38373,88038,-7,'Gila, New Mexico 88038',27670,34174);
INSERT INTO "django_geo_db_zipcode" VALUES(38374,88039,-7,'Glenwood, New Mexico 88039',27671,34175);
INSERT INTO "django_geo_db_zipcode" VALUES(38375,88040,-7,'Hachita, New Mexico 88040',27672,34176);
INSERT INTO "django_geo_db_zipcode" VALUES(38376,88041,-7,'Hanover, New Mexico 88041',27673,34177);
INSERT INTO "django_geo_db_zipcode" VALUES(38377,88042,-7,'Hillsboro, New Mexico 88042',27674,34178);
INSERT INTO "django_geo_db_zipcode" VALUES(38378,88043,-7,'Hurley, New Mexico 88043',27675,34179);
INSERT INTO "django_geo_db_zipcode" VALUES(38379,88044,-7,'La Mesa, New Mexico 88044',27676,34180);
INSERT INTO "django_geo_db_zipcode" VALUES(38380,88045,-7,'Lordsburg, New Mexico 88045',27677,34181);
INSERT INTO "django_geo_db_zipcode" VALUES(38381,88046,-7,'Mesilla, New Mexico 88046',27678,34182);
INSERT INTO "django_geo_db_zipcode" VALUES(38382,88047,-7,'Mesilla Park, New Mexico 88047',27679,34183);
INSERT INTO "django_geo_db_zipcode" VALUES(38383,88048,-7,'Mesquite, New Mexico 88048',27680,34184);
INSERT INTO "django_geo_db_zipcode" VALUES(38384,88049,-7,'Mimbres, New Mexico 88049',27681,34185);
INSERT INTO "django_geo_db_zipcode" VALUES(38385,88051,-7,'Mule Creek, New Mexico 88051',27682,34186);
INSERT INTO "django_geo_db_zipcode" VALUES(38386,88052,-7,'Organ, New Mexico 88052',27683,34187);
INSERT INTO "django_geo_db_zipcode" VALUES(38387,88053,-7,'Pinos Altos, New Mexico 88053',27684,34188);
INSERT INTO "django_geo_db_zipcode" VALUES(38388,88054,-7,'Radium Springs, New Mexico 88054',27685,34189);
INSERT INTO "django_geo_db_zipcode" VALUES(38389,88055,-7,'Redrock, New Mexico 88055',27686,34190);
INSERT INTO "django_geo_db_zipcode" VALUES(38390,88056,-7,'Rodeo, New Mexico 88056',27687,34191);
INSERT INTO "django_geo_db_zipcode" VALUES(38391,88058,-7,'San Miguel, New Mexico 88058',27688,34192);
INSERT INTO "django_geo_db_zipcode" VALUES(38392,88061,-7,'Silver City, New Mexico 88061',27689,34193);
INSERT INTO "django_geo_db_zipcode" VALUES(38393,88062,-7,'Silver City, New Mexico 88062',27689,34194);
INSERT INTO "django_geo_db_zipcode" VALUES(38394,88063,-7,'Sunland Park, New Mexico 88063',27654,34195);
INSERT INTO "django_geo_db_zipcode" VALUES(38395,88065,-7,'Tyrone, New Mexico 88065',27690,34196);
INSERT INTO "django_geo_db_zipcode" VALUES(38396,88072,-7,'Vado, New Mexico 88072',27691,34197);
INSERT INTO "django_geo_db_zipcode" VALUES(38397,88081,-7,'Chaparral, New Mexico 88081',27692,34198);
INSERT INTO "django_geo_db_zipcode" VALUES(38398,88085,-7,'Las Cruces, New Mexico 88085',27650,34199);
INSERT INTO "django_geo_db_zipcode" VALUES(38399,88100,-7,'Grady, New Mexico 88100',27693,34200);
INSERT INTO "django_geo_db_zipcode" VALUES(38400,88101,-7,'Clovis, New Mexico 88101',27694,34201);
INSERT INTO "django_geo_db_zipcode" VALUES(38401,88102,-7,'Clovis, New Mexico 88102',27694,34202);
INSERT INTO "django_geo_db_zipcode" VALUES(38402,88103,-7,'Cannon AFB, New Mexico 88103',27695,34203);
INSERT INTO "django_geo_db_zipcode" VALUES(38403,88112,-7,'Broadview, New Mexico 88112',27696,34204);
INSERT INTO "django_geo_db_zipcode" VALUES(38404,88113,-7,'Causey, New Mexico 88113',27697,34205);
INSERT INTO "django_geo_db_zipcode" VALUES(38405,88114,-7,'Crossroads, New Mexico 88114',27698,34206);
INSERT INTO "django_geo_db_zipcode" VALUES(38406,88115,-7,'Dora, New Mexico 88115',27699,34207);
INSERT INTO "django_geo_db_zipcode" VALUES(38407,88116,-7,'Elida, New Mexico 88116',27700,34208);
INSERT INTO "django_geo_db_zipcode" VALUES(38408,88118,-7,'Floyd, New Mexico 88118',27701,34209);
INSERT INTO "django_geo_db_zipcode" VALUES(38409,88119,-7,'Fort Sumner, New Mexico 88119',27702,34210);
INSERT INTO "django_geo_db_zipcode" VALUES(38410,88120,-7,'Grady, New Mexico 88120',27693,34211);
INSERT INTO "django_geo_db_zipcode" VALUES(38411,88121,-7,'House, New Mexico 88121',27703,34212);
INSERT INTO "django_geo_db_zipcode" VALUES(38412,88122,-7,'Kenna, New Mexico 88122',27704,34213);
INSERT INTO "django_geo_db_zipcode" VALUES(38413,88123,-7,'Lingo, New Mexico 88123',27705,34214);
INSERT INTO "django_geo_db_zipcode" VALUES(38414,88124,-7,'Melrose, New Mexico 88124',27706,34215);
INSERT INTO "django_geo_db_zipcode" VALUES(38415,88125,-7,'Milnesand, New Mexico 88125',27707,34216);
INSERT INTO "django_geo_db_zipcode" VALUES(38416,88126,-7,'Pep, New Mexico 88126',27708,34217);
INSERT INTO "django_geo_db_zipcode" VALUES(38417,88130,-7,'Portales, New Mexico 88130',27709,34218);
INSERT INTO "django_geo_db_zipcode" VALUES(38418,88132,-7,'Rogers, New Mexico 88132',27710,34219);
INSERT INTO "django_geo_db_zipcode" VALUES(38419,88133,-7,'Saint Vrain, New Mexico 88133',27711,34220);
INSERT INTO "django_geo_db_zipcode" VALUES(38420,88134,-7,'Taiban, New Mexico 88134',27712,34221);
INSERT INTO "django_geo_db_zipcode" VALUES(38421,88135,-7,'Texico, New Mexico 88135',27713,34222);
INSERT INTO "django_geo_db_zipcode" VALUES(38422,88136,-7,'Yeso, New Mexico 88136',27714,34223);
INSERT INTO "django_geo_db_zipcode" VALUES(38423,88201,-7,'Roswell, New Mexico 88201',27715,34224);
INSERT INTO "django_geo_db_zipcode" VALUES(38424,88202,-7,'Roswell, New Mexico 88202',27715,34225);
INSERT INTO "django_geo_db_zipcode" VALUES(38425,88203,-7,'Roswell, New Mexico 88203',27715,34226);
INSERT INTO "django_geo_db_zipcode" VALUES(38426,88210,-7,'Artesia, New Mexico 88210',27716,34227);
INSERT INTO "django_geo_db_zipcode" VALUES(38427,88211,-7,'Artesia, New Mexico 88211',27716,34228);
INSERT INTO "django_geo_db_zipcode" VALUES(38428,88213,-7,'Caprock, New Mexico 88213',27717,34229);
INSERT INTO "django_geo_db_zipcode" VALUES(38429,88220,-7,'Carlsbad, New Mexico 88220',27718,34230);
INSERT INTO "django_geo_db_zipcode" VALUES(38430,88221,-7,'Carlsbad, New Mexico 88221',27718,34231);
INSERT INTO "django_geo_db_zipcode" VALUES(38431,88230,-7,'Dexter, New Mexico 88230',27719,34232);
INSERT INTO "django_geo_db_zipcode" VALUES(38432,88231,-7,'Eunice, New Mexico 88231',27720,34233);
INSERT INTO "django_geo_db_zipcode" VALUES(38433,88232,-7,'Hagerman, New Mexico 88232',27721,34234);
INSERT INTO "django_geo_db_zipcode" VALUES(38434,88240,-7,'Hobbs, New Mexico 88240',27722,34235);
INSERT INTO "django_geo_db_zipcode" VALUES(38435,88241,-7,'Hobbs, New Mexico 88241',27722,34236);
INSERT INTO "django_geo_db_zipcode" VALUES(38436,88242,-7,'Hobbs, New Mexico 88242',27722,34237);
INSERT INTO "django_geo_db_zipcode" VALUES(38437,88244,-7,'Hobbs, New Mexico 88244',27722,34238);
INSERT INTO "django_geo_db_zipcode" VALUES(38438,88250,-7,'Hope, New Mexico 88250',27723,34239);
INSERT INTO "django_geo_db_zipcode" VALUES(38439,88252,-7,'Jal, New Mexico 88252',27724,34240);
INSERT INTO "django_geo_db_zipcode" VALUES(38440,88253,-7,'Lake Arthur, New Mexico 88253',27725,34241);
INSERT INTO "django_geo_db_zipcode" VALUES(38441,88254,-7,'Lakewood, New Mexico 88254',27726,34242);
INSERT INTO "django_geo_db_zipcode" VALUES(38442,88255,-7,'Loco Hills, New Mexico 88255',27727,34243);
INSERT INTO "django_geo_db_zipcode" VALUES(38443,88256,-7,'Loving, New Mexico 88256',27728,34244);
INSERT INTO "django_geo_db_zipcode" VALUES(38444,88260,-7,'Lovington, New Mexico 88260',27729,34245);
INSERT INTO "django_geo_db_zipcode" VALUES(38445,88262,-7,'McDonald, New Mexico 88262',27730,34246);
INSERT INTO "django_geo_db_zipcode" VALUES(38446,88263,-7,'Malaga, New Mexico 88263',27731,34247);
INSERT INTO "django_geo_db_zipcode" VALUES(38447,88264,-7,'Maljamar, New Mexico 88264',27732,34248);
INSERT INTO "django_geo_db_zipcode" VALUES(38448,88265,-7,'Monument, New Mexico 88265',27733,34249);
INSERT INTO "django_geo_db_zipcode" VALUES(38449,88267,-7,'Tatum, New Mexico 88267',27734,34250);
INSERT INTO "django_geo_db_zipcode" VALUES(38450,88268,-7,'Whites City, New Mexico 88268',27735,34251);
INSERT INTO "django_geo_db_zipcode" VALUES(38451,88301,-7,'Carrizozo, New Mexico 88301',27736,34252);
INSERT INTO "django_geo_db_zipcode" VALUES(38452,88310,-7,'Alamogordo, New Mexico 88310',27737,34253);
INSERT INTO "django_geo_db_zipcode" VALUES(38453,88311,-7,'Alamogordo, New Mexico 88311',27737,34254);
INSERT INTO "django_geo_db_zipcode" VALUES(38454,88312,-7,'Alto, New Mexico 88312',27738,34255);
INSERT INTO "django_geo_db_zipcode" VALUES(38455,88314,-7,'Bent, New Mexico 88314',27739,34256);
INSERT INTO "django_geo_db_zipcode" VALUES(38456,88315,-7,'Boles Acres, New Mexico 88315',27740,34257);
INSERT INTO "django_geo_db_zipcode" VALUES(38457,88316,-7,'Capitan, New Mexico 88316',27741,34258);
INSERT INTO "django_geo_db_zipcode" VALUES(38458,88317,-7,'Cloudcroft, New Mexico 88317',27742,34259);
INSERT INTO "django_geo_db_zipcode" VALUES(38459,88318,-7,'Corona, New Mexico 88318',27743,34260);
INSERT INTO "django_geo_db_zipcode" VALUES(38460,88321,-7,'Encino, New Mexico 88321',27744,34261);
INSERT INTO "django_geo_db_zipcode" VALUES(38461,88323,-7,'Fort Stanton, New Mexico 88323',27745,34262);
INSERT INTO "django_geo_db_zipcode" VALUES(38462,88324,-7,'Glencoe, New Mexico 88324',27746,34263);
INSERT INTO "django_geo_db_zipcode" VALUES(38463,88325,-7,'High Rolls Mountain Park, New Mexico 88325',27747,34264);
INSERT INTO "django_geo_db_zipcode" VALUES(38464,88330,-7,'Holloman Air Force Base, New Mexico 88330',27748,34265);
INSERT INTO "django_geo_db_zipcode" VALUES(38465,88332,-7,'La Luz, New Mexico 88332',27749,34266);
INSERT INTO "django_geo_db_zipcode" VALUES(38466,88336,-7,'Hondo, New Mexico 88336',27750,34267);
INSERT INTO "django_geo_db_zipcode" VALUES(38467,88337,-7,'La Luz, New Mexico 88337',27749,34268);
INSERT INTO "django_geo_db_zipcode" VALUES(38468,88338,-7,'Lincoln, New Mexico 88338',27751,34269);
INSERT INTO "django_geo_db_zipcode" VALUES(38469,88339,-7,'Mayhill, New Mexico 88339',27752,34270);
INSERT INTO "django_geo_db_zipcode" VALUES(38470,88340,-7,'Mescalero, New Mexico 88340',27753,34271);
INSERT INTO "django_geo_db_zipcode" VALUES(38471,88341,-7,'Nogal, New Mexico 88341',27754,34272);
INSERT INTO "django_geo_db_zipcode" VALUES(38472,88342,-7,'Orogrande, New Mexico 88342',27755,34273);
INSERT INTO "django_geo_db_zipcode" VALUES(38473,88343,-7,'Picacho, New Mexico 88343',27756,34274);
INSERT INTO "django_geo_db_zipcode" VALUES(38474,88344,-7,'Pinon, New Mexico 88344',27757,34275);
INSERT INTO "django_geo_db_zipcode" VALUES(38475,88345,-7,'Ruidoso, New Mexico 88345',27758,34276);
INSERT INTO "django_geo_db_zipcode" VALUES(38476,88346,-7,'Ruidoso Downs, New Mexico 88346',27759,34277);
INSERT INTO "django_geo_db_zipcode" VALUES(38477,88347,-7,'Sacramento, New Mexico 88347',27760,34278);
INSERT INTO "django_geo_db_zipcode" VALUES(38478,88348,-7,'San Patricio, New Mexico 88348',27761,34279);
INSERT INTO "django_geo_db_zipcode" VALUES(38479,88349,-7,'Sunspot, New Mexico 88349',27762,34280);
INSERT INTO "django_geo_db_zipcode" VALUES(38480,88350,-7,'Timberon, New Mexico 88350',27763,34281);
INSERT INTO "django_geo_db_zipcode" VALUES(38481,88351,-7,'Tinnie, New Mexico 88351',27764,34282);
INSERT INTO "django_geo_db_zipcode" VALUES(38482,88352,-7,'Tularosa, New Mexico 88352',27765,34283);
INSERT INTO "django_geo_db_zipcode" VALUES(38483,88353,-7,'Vaughn, New Mexico 88353',27766,34284);
INSERT INTO "django_geo_db_zipcode" VALUES(38484,88354,-7,'Weed, New Mexico 88354',27767,34285);
INSERT INTO "django_geo_db_zipcode" VALUES(38485,88355,-7,'Ruidoso, New Mexico 88355',27758,34286);
INSERT INTO "django_geo_db_zipcode" VALUES(38486,88401,-7,'Tucumcari, New Mexico 88401',27768,34287);
INSERT INTO "django_geo_db_zipcode" VALUES(38487,88410,-7,'Amistad, New Mexico 88410',27769,34288);
INSERT INTO "django_geo_db_zipcode" VALUES(38488,88411,-7,'Bard, New Mexico 88411',27770,34289);
INSERT INTO "django_geo_db_zipcode" VALUES(38489,88414,-7,'Capulin, New Mexico 88414',27771,34290);
INSERT INTO "django_geo_db_zipcode" VALUES(38490,88415,-7,'Clayton, New Mexico 88415',27772,34291);
INSERT INTO "django_geo_db_zipcode" VALUES(38491,88416,-7,'Conchas Dam, New Mexico 88416',27773,34292);
INSERT INTO "django_geo_db_zipcode" VALUES(38492,88417,-7,'Cuervo, New Mexico 88417',27774,34293);
INSERT INTO "django_geo_db_zipcode" VALUES(38493,88418,-7,'Des Moines, New Mexico 88418',27775,34294);
INSERT INTO "django_geo_db_zipcode" VALUES(38494,88419,-7,'Folsom, New Mexico 88419',27776,34295);
INSERT INTO "django_geo_db_zipcode" VALUES(38495,88421,-7,'Garita, New Mexico 88421',27777,34296);
INSERT INTO "django_geo_db_zipcode" VALUES(38496,88422,-7,'Gladstone, New Mexico 88422',27778,34297);
INSERT INTO "django_geo_db_zipcode" VALUES(38497,88424,-7,'Grenville, New Mexico 88424',27779,34298);
INSERT INTO "django_geo_db_zipcode" VALUES(38498,88426,-7,'Logan, New Mexico 88426',27780,34299);
INSERT INTO "django_geo_db_zipcode" VALUES(38499,88427,-7,'McAlister, New Mexico 88427',27781,34300);
INSERT INTO "django_geo_db_zipcode" VALUES(38500,88429,-7,'Mount Dora, New Mexico 88429',27782,34301);
INSERT INTO "django_geo_db_zipcode" VALUES(38501,88430,-7,'Nara Visa, New Mexico 88430',27783,34302);
INSERT INTO "django_geo_db_zipcode" VALUES(38502,88431,-7,'Newkirk, New Mexico 88431',27784,34303);
INSERT INTO "django_geo_db_zipcode" VALUES(38503,88433,-7,'Quay, New Mexico 88433',27785,34304);
INSERT INTO "django_geo_db_zipcode" VALUES(38504,88434,-7,'San Jon, New Mexico 88434',27786,34305);
INSERT INTO "django_geo_db_zipcode" VALUES(38505,88435,-7,'Santa Rosa, New Mexico 88435',27787,34306);
INSERT INTO "django_geo_db_zipcode" VALUES(38506,88436,-7,'Sedan, New Mexico 88436',27788,34307);
INSERT INTO "django_geo_db_zipcode" VALUES(38507,88437,-7,'Seneca, New Mexico 88437',27789,34308);
INSERT INTO "django_geo_db_zipcode" VALUES(38508,88439,-7,'Trementina, New Mexico 88439',27790,34055);
INSERT INTO "django_geo_db_zipcode" VALUES(38509,88441,-7,'Bell Ranch, New Mexico 88441',27791,34055);
INSERT INTO "django_geo_db_zipcode" VALUES(38510,88510,-7,'El Paso, Texas 88510',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38511,88511,-7,'El Paso, Texas 88511',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38512,88512,-7,'El Paso, Texas 88512',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38513,88513,-7,'El Paso, Texas 88513',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38514,88514,-7,'El Paso, Texas 88514',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38515,88515,-7,'El Paso, Texas 88515',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38516,88516,-7,'El Paso, Texas 88516',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38517,88517,-7,'El Paso, Texas 88517',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38518,88518,-7,'El Paso, Texas 88518',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38519,88519,-7,'El Paso, Texas 88519',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38520,88520,-7,'El Paso, Texas 88520',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38521,88521,-7,'El Paso, Texas 88521',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38522,88523,-7,'El Paso, Texas 88523',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38523,88524,-7,'El Paso, Texas 88524',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38524,88525,-7,'El Paso, Texas 88525',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38525,88526,-7,'El Paso, Texas 88526',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38526,88527,-7,'El Paso, Texas 88527',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38527,88528,-7,'El Paso, Texas 88528',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38528,88529,-7,'El Paso, Texas 88529',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38529,88530,-7,'El Paso, Texas 88530',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38530,88531,-7,'El Paso, Texas 88531',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38531,88532,-7,'El Paso, Texas 88532',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38532,88533,-7,'El Paso, Texas 88533',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38533,88534,-7,'El Paso, Texas 88534',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38534,88535,-7,'El Paso, Texas 88535',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38535,88536,-7,'El Paso, Texas 88536',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38536,88538,-7,'El Paso, Texas 88538',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38537,88539,-7,'El Paso, Texas 88539',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38538,88540,-7,'El Paso, Texas 88540',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38539,88541,-7,'El Paso, Texas 88541',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38540,88542,-7,'El Paso, Texas 88542',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38541,88543,-7,'El Paso, Texas 88543',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38542,88544,-7,'El Paso, Texas 88544',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38543,88545,-7,'El Paso, Texas 88545',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38544,88546,-7,'El Paso, Texas 88546',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38545,88547,-7,'El Paso, Texas 88547',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38546,88548,-7,'El Paso, Texas 88548',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38547,88549,-7,'El Paso, Texas 88549',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38548,88550,-7,'El Paso, Texas 88550',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38549,88553,-7,'El Paso, Texas 88553',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38550,88554,-7,'El Paso, Texas 88554',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38551,88555,-7,'El Paso, Texas 88555',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38552,88556,-7,'El Paso, Texas 88556',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38553,88557,-7,'El Paso, Texas 88557',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38554,88558,-7,'El Paso, Texas 88558',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38555,88559,-7,'El Paso, Texas 88559',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38556,88560,-7,'El Paso, Texas 88560',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38557,88561,-7,'El Paso, Texas 88561',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38558,88562,-7,'El Paso, Texas 88562',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38559,88563,-7,'El Paso, Texas 88563',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38560,88565,-7,'El Paso, Texas 88565',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38561,88566,-7,'El Paso, Texas 88566',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38562,88567,-7,'El Paso, Texas 88567',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38563,88568,-7,'El Paso, Texas 88568',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38564,88569,-7,'El Paso, Texas 88569',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38565,88570,-7,'El Paso, Texas 88570',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38566,88571,-7,'El Paso, Texas 88571',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38567,88572,-7,'El Paso, Texas 88572',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38568,88573,-7,'El Paso, Texas 88573',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38569,88574,-7,'El Paso, Texas 88574',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38570,88575,-7,'El Paso, Texas 88575',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38571,88576,-7,'El Paso, Texas 88576',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38572,88577,-7,'El Paso, Texas 88577',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38573,88578,-7,'El Paso, Texas 88578',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38574,88579,-7,'El Paso, Texas 88579',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38575,88580,-7,'El Paso, Texas 88580',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38576,88581,-7,'El Paso, Texas 88581',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38577,88582,-7,'El Paso, Texas 88582',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38578,88583,-7,'El Paso, Texas 88583',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38579,88584,-7,'El Paso, Texas 88584',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38580,88585,-7,'El Paso, Texas 88585',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38581,88586,-7,'El Paso, Texas 88586',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38582,88587,-7,'El Paso, Texas 88587',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38583,88588,-7,'El Paso, Texas 88588',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38584,88589,-7,'El Paso, Texas 88589',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38585,88590,-7,'El Paso, Texas 88590',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38586,88595,-7,'El Paso, Texas 88595',26059,32022);
INSERT INTO "django_geo_db_zipcode" VALUES(38587,88603,-7,'Roswell, New Mexico 88603',27715,34309);
INSERT INTO "django_geo_db_zipcode" VALUES(38588,88901,-8,'The Lakes, Nevada 88901',27792,34310);
INSERT INTO "django_geo_db_zipcode" VALUES(38589,88905,-8,'The Lakes, Nevada 88905',27792,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38590,89001,-8,'Alamo, Nevada 89001',27793,34312);
INSERT INTO "django_geo_db_zipcode" VALUES(38591,89003,-8,'Beatty, Nevada 89003',27794,34313);
INSERT INTO "django_geo_db_zipcode" VALUES(38592,89004,-8,'Blue Diamond, Nevada 89004',27795,34314);
INSERT INTO "django_geo_db_zipcode" VALUES(38593,89005,-8,'Boulder City, Nevada 89005',27796,34315);
INSERT INTO "django_geo_db_zipcode" VALUES(38594,89006,-8,'Boulder City, Nevada 89006',27796,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38595,89007,-8,'Bunkerville, Nevada 89007',27797,34316);
INSERT INTO "django_geo_db_zipcode" VALUES(38596,89008,-8,'Caliente, Nevada 89008',27798,34317);
INSERT INTO "django_geo_db_zipcode" VALUES(38597,89009,-8,'Henderson, Nevada 89009',27799,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38598,89010,-8,'Dyer, Nevada 89010',27800,34318);
INSERT INTO "django_geo_db_zipcode" VALUES(38599,89011,-8,'Henderson, Nevada 89011',27799,34319);
INSERT INTO "django_geo_db_zipcode" VALUES(38600,89012,-8,'Henderson, Nevada 89012',27799,34320);
INSERT INTO "django_geo_db_zipcode" VALUES(38601,89013,-8,'Goldfield, Nevada 89013',27801,34321);
INSERT INTO "django_geo_db_zipcode" VALUES(38602,89014,-8,'Henderson, Nevada 89014',27799,34322);
INSERT INTO "django_geo_db_zipcode" VALUES(38603,89015,-8,'Henderson, Nevada 89015',27799,34323);
INSERT INTO "django_geo_db_zipcode" VALUES(38604,89016,-8,'Henderson, Nevada 89016',27799,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38605,89017,-8,'Hiko, Nevada 89017',27802,34324);
INSERT INTO "django_geo_db_zipcode" VALUES(38606,89018,-8,'Indian Springs, Nevada 89018',27803,34325);
INSERT INTO "django_geo_db_zipcode" VALUES(38607,89019,-8,'Jean, Nevada 89019',27804,34326);
INSERT INTO "django_geo_db_zipcode" VALUES(38608,89020,-8,'Amargosa Valley, Nevada 89020',27805,34327);
INSERT INTO "django_geo_db_zipcode" VALUES(38609,89021,-8,'Logandale, Nevada 89021',27806,34328);
INSERT INTO "django_geo_db_zipcode" VALUES(38610,89022,-8,'Manhattan, Nevada 89022',27807,34329);
INSERT INTO "django_geo_db_zipcode" VALUES(38611,89023,-8,'Mercury, Nevada 89023',27808,34330);
INSERT INTO "django_geo_db_zipcode" VALUES(38612,89024,-7,'Mesquite, Arizona 89024',27809,34331);
INSERT INTO "django_geo_db_zipcode" VALUES(38613,89025,-8,'Moapa, Nevada 89025',27810,34332);
INSERT INTO "django_geo_db_zipcode" VALUES(38614,89026,-8,'Jean, Nevada 89026',27804,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38615,89027,-8,'Mesquite, Nevada 89027',27811,34333);
INSERT INTO "django_geo_db_zipcode" VALUES(38616,89028,-8,'Laughlin, Nevada 89028',27812,34334);
INSERT INTO "django_geo_db_zipcode" VALUES(38617,89029,-8,'Laughlin, Nevada 89029',27812,34335);
INSERT INTO "django_geo_db_zipcode" VALUES(38618,89030,-8,'North Las Vegas, Nevada 89030',27813,34336);
INSERT INTO "django_geo_db_zipcode" VALUES(38619,89031,-8,'North Las Vegas, Nevada 89031',27813,34337);
INSERT INTO "django_geo_db_zipcode" VALUES(38620,89032,-8,'North Las Vegas, Nevada 89032',27813,34338);
INSERT INTO "django_geo_db_zipcode" VALUES(38621,89033,-8,'North Las Vegas, Nevada 89033',27813,34339);
INSERT INTO "django_geo_db_zipcode" VALUES(38622,89036,-8,'North Las Vegas, Nevada 89036',27813,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38623,89039,-8,'Cal Nev Ari, Nevada 89039',27814,34340);
INSERT INTO "django_geo_db_zipcode" VALUES(38624,89040,-8,'Overton, Nevada 89040',27815,34341);
INSERT INTO "django_geo_db_zipcode" VALUES(38625,89041,-8,'Pahrump, Nevada 89041',27816,34342);
INSERT INTO "django_geo_db_zipcode" VALUES(38626,89042,-8,'Panaca, Nevada 89042',27817,34343);
INSERT INTO "django_geo_db_zipcode" VALUES(38627,89043,-8,'Pioche, Nevada 89043',27818,34344);
INSERT INTO "django_geo_db_zipcode" VALUES(38628,89045,-8,'Round Mountain, Nevada 89045',27819,34330);
INSERT INTO "django_geo_db_zipcode" VALUES(38629,89046,-8,'Searchlight, Nevada 89046',27820,34345);
INSERT INTO "django_geo_db_zipcode" VALUES(38630,89047,-8,'Silverpeak, Nevada 89047',27821,34346);
INSERT INTO "django_geo_db_zipcode" VALUES(38631,89048,-8,'Pahrump, Nevada 89048',27816,34347);
INSERT INTO "django_geo_db_zipcode" VALUES(38632,89049,-8,'Tonopah, Nevada 89049',27822,34348);
INSERT INTO "django_geo_db_zipcode" VALUES(38633,89052,-8,'Henderson, Nevada 89052',27799,34349);
INSERT INTO "django_geo_db_zipcode" VALUES(38634,89053,-8,'Henderson, Nevada 89053',27799,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38635,89060,-8,'Pahrump, Nevada 89060',27816,34350);
INSERT INTO "django_geo_db_zipcode" VALUES(38636,89061,-8,'Pahrump, Nevada 89061',27816,34351);
INSERT INTO "django_geo_db_zipcode" VALUES(38637,89070,-8,'Indian Springs, Nevada 89070',27803,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38638,89074,-8,'Henderson, Nevada 89074',27799,34352);
INSERT INTO "django_geo_db_zipcode" VALUES(38639,89081,-8,'Indian Springs, Nevada 89081',27803,34353);
INSERT INTO "django_geo_db_zipcode" VALUES(38640,89084,-8,'North Las Vegas, Nevada 89084',27813,34354);
INSERT INTO "django_geo_db_zipcode" VALUES(38641,89086,-8,'North Las Vegas, Nevada 89086',27813,34355);
INSERT INTO "django_geo_db_zipcode" VALUES(38642,89101,-8,'Las Vegas, Nevada 89101',27823,34356);
INSERT INTO "django_geo_db_zipcode" VALUES(38643,89102,-8,'Las Vegas, Nevada 89102',27823,34357);
INSERT INTO "django_geo_db_zipcode" VALUES(38644,89103,-8,'Las Vegas, Nevada 89103',27823,34358);
INSERT INTO "django_geo_db_zipcode" VALUES(38645,89104,-8,'Las Vegas, Nevada 89104',27823,34359);
INSERT INTO "django_geo_db_zipcode" VALUES(38646,89106,-8,'Las Vegas, Nevada 89106',27823,34360);
INSERT INTO "django_geo_db_zipcode" VALUES(38647,89107,-8,'Las Vegas, Nevada 89107',27823,34361);
INSERT INTO "django_geo_db_zipcode" VALUES(38648,89108,-8,'Las Vegas, Nevada 89108',27823,34362);
INSERT INTO "django_geo_db_zipcode" VALUES(38649,89109,-8,'Las Vegas, Nevada 89109',27823,34363);
INSERT INTO "django_geo_db_zipcode" VALUES(38650,89110,-8,'Las Vegas, Nevada 89110',27823,34364);
INSERT INTO "django_geo_db_zipcode" VALUES(38651,89111,-8,'Las Vegas, Nevada 89111',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38652,89112,-8,'Las Vegas, Nevada 89112',27823,34365);
INSERT INTO "django_geo_db_zipcode" VALUES(38653,89113,-8,'Las Vegas, Nevada 89113',27823,34366);
INSERT INTO "django_geo_db_zipcode" VALUES(38654,89114,-8,'Las Vegas, Nevada 89114',27823,34367);
INSERT INTO "django_geo_db_zipcode" VALUES(38655,89115,-8,'Las Vegas, Nevada 89115',27823,34368);
INSERT INTO "django_geo_db_zipcode" VALUES(38656,89116,-8,'Las Vegas, Nevada 89116',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38657,89117,-8,'Las Vegas, Nevada 89117',27823,34369);
INSERT INTO "django_geo_db_zipcode" VALUES(38658,89118,-8,'Las Vegas, Nevada 89118',27823,34370);
INSERT INTO "django_geo_db_zipcode" VALUES(38659,89119,-8,'Las Vegas, Nevada 89119',27823,34371);
INSERT INTO "django_geo_db_zipcode" VALUES(38660,89120,-8,'Las Vegas, Nevada 89120',27823,34372);
INSERT INTO "django_geo_db_zipcode" VALUES(38661,89121,-8,'Las Vegas, Nevada 89121',27823,34373);
INSERT INTO "django_geo_db_zipcode" VALUES(38662,89122,-8,'Las Vegas, Nevada 89122',27823,34374);
INSERT INTO "django_geo_db_zipcode" VALUES(38663,89123,-8,'Las Vegas, Nevada 89123',27823,34375);
INSERT INTO "django_geo_db_zipcode" VALUES(38664,89124,-8,'Las Vegas, Nevada 89124',27823,34376);
INSERT INTO "django_geo_db_zipcode" VALUES(38665,89125,-8,'Las Vegas, Nevada 89125',27823,34377);
INSERT INTO "django_geo_db_zipcode" VALUES(38666,89126,-8,'Las Vegas, Nevada 89126',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38667,89127,-8,'Las Vegas, Nevada 89127',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38668,89128,-8,'Las Vegas, Nevada 89128',27823,34378);
INSERT INTO "django_geo_db_zipcode" VALUES(38669,89129,-8,'Las Vegas, Nevada 89129',27823,34379);
INSERT INTO "django_geo_db_zipcode" VALUES(38670,89130,-8,'Las Vegas, Nevada 89130',27823,34380);
INSERT INTO "django_geo_db_zipcode" VALUES(38671,89131,-8,'Las Vegas, Nevada 89131',27823,34381);
INSERT INTO "django_geo_db_zipcode" VALUES(38672,89132,-8,'Las Vegas, Nevada 89132',27823,34382);
INSERT INTO "django_geo_db_zipcode" VALUES(38673,89133,-8,'Las Vegas, Nevada 89133',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38674,89134,-8,'Las Vegas, Nevada 89134',27823,34383);
INSERT INTO "django_geo_db_zipcode" VALUES(38675,89135,-8,'Las Vegas, Nevada 89135',27823,34384);
INSERT INTO "django_geo_db_zipcode" VALUES(38676,89136,-8,'Summerlin South, Nevada 89136',27824,34385);
INSERT INTO "django_geo_db_zipcode" VALUES(38677,89137,-8,'Las Vegas, Nevada 89137',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38678,89138,-8,'Las Vegas, Nevada 89138',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38679,89139,-8,'Las Vegas, Nevada 89139',27823,34386);
INSERT INTO "django_geo_db_zipcode" VALUES(38680,89141,-8,'Las Vegas, Nevada 89141',27823,34387);
INSERT INTO "django_geo_db_zipcode" VALUES(38681,89142,-8,'Las Vegas, Nevada 89142',27823,34388);
INSERT INTO "django_geo_db_zipcode" VALUES(38682,89143,-8,'Las Vegas, Nevada 89143',27823,34389);
INSERT INTO "django_geo_db_zipcode" VALUES(38683,89144,-8,'Las Vegas, Nevada 89144',27823,34390);
INSERT INTO "django_geo_db_zipcode" VALUES(38684,89145,-8,'Las Vegas, Nevada 89145',27823,34391);
INSERT INTO "django_geo_db_zipcode" VALUES(38685,89146,-8,'Las Vegas, Nevada 89146',27823,34392);
INSERT INTO "django_geo_db_zipcode" VALUES(38686,89147,-8,'Las Vegas, Nevada 89147',27823,34393);
INSERT INTO "django_geo_db_zipcode" VALUES(38687,89148,-8,'Las Vegas, Nevada 89148',27823,34394);
INSERT INTO "django_geo_db_zipcode" VALUES(38688,89149,-8,'Las Vegas, Nevada 89149',27823,34395);
INSERT INTO "django_geo_db_zipcode" VALUES(38689,89150,-8,'Las Vegas, Nevada 89150',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38690,89151,-8,'Las Vegas, Nevada 89151',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38691,89152,-8,'Las Vegas, Nevada 89152',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38692,89153,-8,'Las Vegas, Nevada 89153',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38693,89154,-8,'Las Vegas, Nevada 89154',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38694,89155,-8,'Las Vegas, Nevada 89155',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38695,89156,-8,'Las Vegas, Nevada 89156',27823,34396);
INSERT INTO "django_geo_db_zipcode" VALUES(38696,89158,-8,'Las Vegas, Nevada 89158',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38697,89159,-8,'Las Vegas, Nevada 89159',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38698,89160,-8,'Las Vegas, Nevada 89160',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38699,89163,-8,'The Lakes, Nevada 89163',27792,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38700,89164,-8,'Las Vegas, Nevada 89164',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38701,89170,-8,'Las Vegas, Nevada 89170',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38702,89173,-8,'Las Vegas, Nevada 89173',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38703,89177,-8,'Las Vegas, Nevada 89177',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38704,89180,-8,'Las Vegas, Nevada 89180',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38705,89185,-8,'Las Vegas, Nevada 89185',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38706,89191,-8,'Nellis AFB, Nevada 89191',27825,34397);
INSERT INTO "django_geo_db_zipcode" VALUES(38707,89193,-8,'Las Vegas, Nevada 89193',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38708,89195,-8,'Las Vegas, Nevada 89195',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38709,89199,-8,'Las Vegas, Nevada 89199',27823,34311);
INSERT INTO "django_geo_db_zipcode" VALUES(38710,89301,-8,'Ely, Nevada 89301',27826,34398);
INSERT INTO "django_geo_db_zipcode" VALUES(38711,89310,-8,'Austin, Nevada 89310',27827,34399);
INSERT INTO "django_geo_db_zipcode" VALUES(38712,89311,-8,'Baker, Nevada 89311',27828,34400);
INSERT INTO "django_geo_db_zipcode" VALUES(38713,89314,-8,'Duckwater, Nevada 89314',27829,34401);
INSERT INTO "django_geo_db_zipcode" VALUES(38714,89315,-8,'Ely, Nevada 89315',27826,34402);
INSERT INTO "django_geo_db_zipcode" VALUES(38715,89316,-8,'Eureka, Nevada 89316',27830,34403);
INSERT INTO "django_geo_db_zipcode" VALUES(38716,89317,-8,'Lund, Nevada 89317',27831,34404);
INSERT INTO "django_geo_db_zipcode" VALUES(38717,89318,-8,'McGill, Nevada 89318',27832,34405);
INSERT INTO "django_geo_db_zipcode" VALUES(38718,89319,-8,'Ruth, Nevada 89319',27833,34406);
INSERT INTO "django_geo_db_zipcode" VALUES(38719,89402,-8,'Crystal Bay, Nevada 89402',27834,34407);
INSERT INTO "django_geo_db_zipcode" VALUES(38720,89403,-8,'Dayton, Nevada 89403',27835,34408);
INSERT INTO "django_geo_db_zipcode" VALUES(38721,89404,-8,'Denio, Nevada 89404',27836,34409);
INSERT INTO "django_geo_db_zipcode" VALUES(38722,89405,-8,'Empire, Nevada 89405',27837,34410);
INSERT INTO "django_geo_db_zipcode" VALUES(38723,89406,-8,'Fallon, Nevada 89406',27838,34411);
INSERT INTO "django_geo_db_zipcode" VALUES(38724,89407,-8,'Fallon, Nevada 89407',27838,34412);
INSERT INTO "django_geo_db_zipcode" VALUES(38725,89408,-8,'Fernley, Nevada 89408',27839,34413);
INSERT INTO "django_geo_db_zipcode" VALUES(38726,89409,-8,'Gabbs, Nevada 89409',27840,34414);
INSERT INTO "django_geo_db_zipcode" VALUES(38727,89410,-8,'Gardnerville, Nevada 89410',27841,34415);
INSERT INTO "django_geo_db_zipcode" VALUES(38728,89411,-8,'Genoa, Nevada 89411',27842,34416);
INSERT INTO "django_geo_db_zipcode" VALUES(38729,89412,-8,'Gerlach, Nevada 89412',27843,34417);
INSERT INTO "django_geo_db_zipcode" VALUES(38730,89413,-8,'Glenbrook, Nevada 89413',27844,34418);
INSERT INTO "django_geo_db_zipcode" VALUES(38731,89414,-8,'Golconda, Nevada 89414',27845,34419);
INSERT INTO "django_geo_db_zipcode" VALUES(38732,89415,-8,'Hawthorne, Nevada 89415',27846,34420);
INSERT INTO "django_geo_db_zipcode" VALUES(38733,89418,-8,'Imlay, Nevada 89418',27847,34421);
INSERT INTO "django_geo_db_zipcode" VALUES(38734,89419,-8,'Lovelock, Nevada 89419',27848,34422);
INSERT INTO "django_geo_db_zipcode" VALUES(38735,89420,-8,'Luning, Nevada 89420',27849,34423);
INSERT INTO "django_geo_db_zipcode" VALUES(38736,89421,-8,'McDermitt, Nevada 89421',27850,34424);
INSERT INTO "django_geo_db_zipcode" VALUES(38737,89422,-8,'Mina, Nevada 89422',27851,34425);
INSERT INTO "django_geo_db_zipcode" VALUES(38738,89423,-8,'Minden, Nevada 89423',27852,34426);
INSERT INTO "django_geo_db_zipcode" VALUES(38739,89424,-8,'Nixon, Nevada 89424',27853,34427);
INSERT INTO "django_geo_db_zipcode" VALUES(38740,89425,-8,'Orovada, Nevada 89425',27854,34428);
INSERT INTO "django_geo_db_zipcode" VALUES(38741,89426,-8,'Paradise Valley, Nevada 89426',27855,34429);
INSERT INTO "django_geo_db_zipcode" VALUES(38742,89427,-8,'Schurz, Nevada 89427',27856,34430);
INSERT INTO "django_geo_db_zipcode" VALUES(38743,89428,-8,'Silver City, Nevada 89428',27857,34431);
INSERT INTO "django_geo_db_zipcode" VALUES(38744,89429,-8,'Silver Springs, Nevada 89429',27858,34432);
INSERT INTO "django_geo_db_zipcode" VALUES(38745,89430,-8,'Smith, Nevada 89430',27859,34433);
INSERT INTO "django_geo_db_zipcode" VALUES(38746,89431,-8,'Sparks, Nevada 89431',27860,34434);
INSERT INTO "django_geo_db_zipcode" VALUES(38747,89432,-8,'Sparks, Nevada 89432',27860,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38748,89433,-8,'Sun Valley, Nevada 89433',27861,34436);
INSERT INTO "django_geo_db_zipcode" VALUES(38749,89434,-8,'Sparks, Nevada 89434',27860,34437);
INSERT INTO "django_geo_db_zipcode" VALUES(38750,89435,-8,'Sparks, Nevada 89435',27860,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38751,89436,-8,'Sparks, Nevada 89436',27860,34438);
INSERT INTO "django_geo_db_zipcode" VALUES(38752,89438,-8,'Valmy, Nevada 89438',27862,34439);
INSERT INTO "django_geo_db_zipcode" VALUES(38753,89439,-8,'Verdi, California 89439',27863,34440);
INSERT INTO "django_geo_db_zipcode" VALUES(38754,89440,-8,'Virginia City, Nevada 89440',27864,34441);
INSERT INTO "django_geo_db_zipcode" VALUES(38755,89442,-8,'Wadsworth, Nevada 89442',27865,34442);
INSERT INTO "django_geo_db_zipcode" VALUES(38756,89444,-8,'Wellington, Nevada 89444',27866,34443);
INSERT INTO "django_geo_db_zipcode" VALUES(38757,89445,-8,'Winnemucca, Nevada 89445',27867,34444);
INSERT INTO "django_geo_db_zipcode" VALUES(38758,89446,-8,'Winnemucca, Nevada 89446',27867,34445);
INSERT INTO "django_geo_db_zipcode" VALUES(38759,89447,-8,'Yerington, Nevada 89447',27868,34446);
INSERT INTO "django_geo_db_zipcode" VALUES(38760,89448,-8,'Zephyr Cove, Nevada 89448',27869,34447);
INSERT INTO "django_geo_db_zipcode" VALUES(38761,89449,-8,'Stateline, Nevada 89449',27870,34448);
INSERT INTO "django_geo_db_zipcode" VALUES(38762,89450,-8,'Incline Village, Nevada 89450',27871,34449);
INSERT INTO "django_geo_db_zipcode" VALUES(38763,89451,-8,'Incline Village, Nevada 89451',27871,34450);
INSERT INTO "django_geo_db_zipcode" VALUES(38764,89452,-8,'Incline Village, Nevada 89452',27871,34451);
INSERT INTO "django_geo_db_zipcode" VALUES(38765,89460,-8,'Gardnerville Ranchos, Nevada 89460',27872,34452);
INSERT INTO "django_geo_db_zipcode" VALUES(38766,89496,-8,'Fallon, Nevada 89496',27838,34453);
INSERT INTO "django_geo_db_zipcode" VALUES(38767,89501,-8,'Reno, Nevada 89501',27873,34454);
INSERT INTO "django_geo_db_zipcode" VALUES(38768,89502,-8,'Reno, Nevada 89502',27873,34455);
INSERT INTO "django_geo_db_zipcode" VALUES(38769,89503,-8,'Reno, Nevada 89503',27873,34456);
INSERT INTO "django_geo_db_zipcode" VALUES(38770,89504,-8,'Reno, Nevada 89504',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38771,89505,-8,'Reno, Nevada 89505',27873,34457);
INSERT INTO "django_geo_db_zipcode" VALUES(38772,89506,-8,'Reno, Nevada 89506',27873,34458);
INSERT INTO "django_geo_db_zipcode" VALUES(38773,89507,-8,'Reno, Nevada 89507',27873,34459);
INSERT INTO "django_geo_db_zipcode" VALUES(38774,89509,-8,'Reno, Nevada 89509',27873,34460);
INSERT INTO "django_geo_db_zipcode" VALUES(38775,89510,-8,'Reno, Nevada 89510',27873,34461);
INSERT INTO "django_geo_db_zipcode" VALUES(38776,89511,-8,'Reno, Nevada 89511',27873,34462);
INSERT INTO "django_geo_db_zipcode" VALUES(38777,89512,-8,'Reno, Nevada 89512',27873,34463);
INSERT INTO "django_geo_db_zipcode" VALUES(38778,89513,-8,'Reno, Nevada 89513',27873,34464);
INSERT INTO "django_geo_db_zipcode" VALUES(38779,89515,-8,'Reno, Nevada 89515',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38780,89520,-8,'Reno, Nevada 89520',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38781,89521,-8,'Reno, Nevada 89521',27873,34465);
INSERT INTO "django_geo_db_zipcode" VALUES(38782,89523,-8,'Reno, Nevada 89523',27873,34466);
INSERT INTO "django_geo_db_zipcode" VALUES(38783,89533,-8,'Reno, Nevada 89533',27873,34467);
INSERT INTO "django_geo_db_zipcode" VALUES(38784,89557,-8,'Reno, Nevada 89557',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38785,89564,-8,'Reno, Nevada 89564',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38786,89570,-8,'Reno, Nevada 89570',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38787,89595,-8,'Reno, Nevada 89595',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38788,89599,-8,'Reno, Nevada 89599',27873,34435);
INSERT INTO "django_geo_db_zipcode" VALUES(38789,89701,-8,'Carson City, Nevada 89701',27874,34468);
INSERT INTO "django_geo_db_zipcode" VALUES(38790,89702,-8,'Carson City, Nevada 89702',27874,34469);
INSERT INTO "django_geo_db_zipcode" VALUES(38791,89703,-8,'Carson City, Nevada 89703',27874,34470);
INSERT INTO "django_geo_db_zipcode" VALUES(38792,89704,-8,'Washoe Valley, Nevada 89704',27875,34471);
INSERT INTO "django_geo_db_zipcode" VALUES(38793,89705,-8,'Carson City, Nevada 89705',27874,34472);
INSERT INTO "django_geo_db_zipcode" VALUES(38794,89706,-8,'Carson City, Nevada 89706',27874,34473);
INSERT INTO "django_geo_db_zipcode" VALUES(38795,89710,-8,'Carson City, Nevada 89710',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38796,89711,-8,'Carson City, Nevada 89711',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38797,89712,-8,'Carson City, Nevada 89712',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38798,89713,-8,'Carson City, Nevada 89713',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38799,89714,-8,'Carson City, Nevada 89714',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38800,89721,-8,'Carson City, Nevada 89721',27874,34474);
INSERT INTO "django_geo_db_zipcode" VALUES(38801,89779,-8,'Kingsbury, Nevada 89779',27876,34475);
INSERT INTO "django_geo_db_zipcode" VALUES(38802,89801,-8,'Elko, Nevada 89801',27877,34476);
INSERT INTO "django_geo_db_zipcode" VALUES(38803,89802,-8,'Elko, Nevada 89802',27877,34477);
INSERT INTO "django_geo_db_zipcode" VALUES(38804,89803,-8,'Elko, Nevada 89803',27877,34478);
INSERT INTO "django_geo_db_zipcode" VALUES(38805,89815,-8,'Spring Creek, Nevada 89815',27878,34479);
INSERT INTO "django_geo_db_zipcode" VALUES(38806,89820,-8,'Battle Mountain, Nevada 89820',27879,34480);
INSERT INTO "django_geo_db_zipcode" VALUES(38807,89821,-8,'Crescent Valley, Nevada 89821',27880,34481);
INSERT INTO "django_geo_db_zipcode" VALUES(38808,89822,-8,'Carlin, Nevada 89822',27881,34482);
INSERT INTO "django_geo_db_zipcode" VALUES(38809,89823,-8,'Deeth, Nevada 89823',27882,34483);
INSERT INTO "django_geo_db_zipcode" VALUES(38810,89824,-8,'Halleck, Nevada 89824',27883,34484);
INSERT INTO "django_geo_db_zipcode" VALUES(38811,89825,-8,'Jackpot, Nevada 89825',27884,34485);
INSERT INTO "django_geo_db_zipcode" VALUES(38812,89826,-8,'Jarbidge, Nevada 89826',27885,34486);
INSERT INTO "django_geo_db_zipcode" VALUES(38813,89828,-8,'Lamoille, Nevada 89828',27886,34487);
INSERT INTO "django_geo_db_zipcode" VALUES(38814,89830,-8,'Montello, Nevada 89830',27887,34488);
INSERT INTO "django_geo_db_zipcode" VALUES(38815,89831,-8,'Mountain City, Nevada 89831',27888,34489);
INSERT INTO "django_geo_db_zipcode" VALUES(38816,89832,-8,'Owyhee, Nevada 89832',27889,34490);
INSERT INTO "django_geo_db_zipcode" VALUES(38817,89833,-8,'Ruby Valley, Nevada 89833',27890,34491);
INSERT INTO "django_geo_db_zipcode" VALUES(38818,89834,-8,'Tuscarora, Nevada 89834',27891,34492);
INSERT INTO "django_geo_db_zipcode" VALUES(38819,89835,-8,'Wells, Nevada 89835',27892,34493);
INSERT INTO "django_geo_db_zipcode" VALUES(38820,89883,-8,'West Wendover, Nevada 89883',27893,34494);
INSERT INTO "django_geo_db_zipcode" VALUES(38821,89912,-8,'Gerlach-Empire, Nevada 89912',27894,34495);
INSERT INTO "django_geo_db_zipcode" VALUES(38822,90001,-8,'Los Angeles, California 90001',27895,34496);
INSERT INTO "django_geo_db_zipcode" VALUES(38823,90002,-8,'Los Angeles, California 90002',27895,34497);
INSERT INTO "django_geo_db_zipcode" VALUES(38824,90003,-8,'Los Angeles, California 90003',27895,34498);
INSERT INTO "django_geo_db_zipcode" VALUES(38825,90004,-8,'Los Angeles, California 90004',27895,34499);
INSERT INTO "django_geo_db_zipcode" VALUES(38826,90005,-8,'Los Angeles, California 90005',27895,34500);
INSERT INTO "django_geo_db_zipcode" VALUES(38827,90006,-8,'Los Angeles, California 90006',27895,34501);
INSERT INTO "django_geo_db_zipcode" VALUES(38828,90007,-8,'Los Angeles, California 90007',27895,34502);
INSERT INTO "django_geo_db_zipcode" VALUES(38829,90008,-8,'Los Angeles, California 90008',27895,34503);
INSERT INTO "django_geo_db_zipcode" VALUES(38830,90009,-8,'Los Angeles, California 90009',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38831,90010,-8,'Los Angeles, California 90010',27895,34505);
INSERT INTO "django_geo_db_zipcode" VALUES(38832,90011,-8,'Los Angeles, California 90011',27895,34506);
INSERT INTO "django_geo_db_zipcode" VALUES(38833,90012,-8,'Los Angeles, California 90012',27895,34507);
INSERT INTO "django_geo_db_zipcode" VALUES(38834,90013,-8,'Los Angeles, California 90013',27895,34508);
INSERT INTO "django_geo_db_zipcode" VALUES(38835,90014,-8,'Los Angeles, California 90014',27895,34509);
INSERT INTO "django_geo_db_zipcode" VALUES(38836,90015,-8,'Los Angeles, California 90015',27895,34510);
INSERT INTO "django_geo_db_zipcode" VALUES(38837,90016,-8,'Los Angeles, California 90016',27895,34511);
INSERT INTO "django_geo_db_zipcode" VALUES(38838,90017,-8,'Los Angeles, California 90017',27895,34512);
INSERT INTO "django_geo_db_zipcode" VALUES(38839,90018,-8,'Los Angeles, California 90018',27895,34513);
INSERT INTO "django_geo_db_zipcode" VALUES(38840,90019,-8,'Los Angeles, California 90019',27895,34514);
INSERT INTO "django_geo_db_zipcode" VALUES(38841,90020,-8,'Los Angeles, California 90020',27895,34515);
INSERT INTO "django_geo_db_zipcode" VALUES(38842,90021,-8,'Los Angeles, California 90021',27895,34516);
INSERT INTO "django_geo_db_zipcode" VALUES(38843,90022,-8,'Los Angeles, California 90022',27895,34517);
INSERT INTO "django_geo_db_zipcode" VALUES(38844,90023,-8,'Los Angeles, California 90023',27895,34518);
INSERT INTO "django_geo_db_zipcode" VALUES(38845,90024,-8,'Los Angeles, California 90024',27895,34519);
INSERT INTO "django_geo_db_zipcode" VALUES(38846,90025,-8,'Los Angeles, California 90025',27895,34520);
INSERT INTO "django_geo_db_zipcode" VALUES(38847,90026,-8,'Los Angeles, California 90026',27895,34521);
INSERT INTO "django_geo_db_zipcode" VALUES(38848,90027,-8,'Los Angeles, California 90027',27895,34522);
INSERT INTO "django_geo_db_zipcode" VALUES(38849,90028,-8,'Los Angeles, California 90028',27895,34523);
INSERT INTO "django_geo_db_zipcode" VALUES(38850,90029,-8,'Los Angeles, California 90029',27895,34524);
INSERT INTO "django_geo_db_zipcode" VALUES(38851,90030,-8,'Los Angeles, California 90030',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38852,90031,-8,'Los Angeles, California 90031',27895,34525);
INSERT INTO "django_geo_db_zipcode" VALUES(38853,90032,-8,'Los Angeles, California 90032',27895,34526);
INSERT INTO "django_geo_db_zipcode" VALUES(38854,90033,-8,'Los Angeles, California 90033',27895,34527);
INSERT INTO "django_geo_db_zipcode" VALUES(38855,90034,-8,'Los Angeles, California 90034',27895,34528);
INSERT INTO "django_geo_db_zipcode" VALUES(38856,90035,-8,'Los Angeles, California 90035',27895,34529);
INSERT INTO "django_geo_db_zipcode" VALUES(38857,90036,-8,'Los Angeles, California 90036',27895,34530);
INSERT INTO "django_geo_db_zipcode" VALUES(38858,90037,-8,'Los Angeles, California 90037',27895,34531);
INSERT INTO "django_geo_db_zipcode" VALUES(38859,90038,-8,'Los Angeles, California 90038',27895,34532);
INSERT INTO "django_geo_db_zipcode" VALUES(38860,90039,-8,'Los Angeles, California 90039',27895,34533);
INSERT INTO "django_geo_db_zipcode" VALUES(38861,90040,-8,'Los Angeles, California 90040',27895,34534);
INSERT INTO "django_geo_db_zipcode" VALUES(38862,90041,-8,'Los Angeles, California 90041',27895,34535);
INSERT INTO "django_geo_db_zipcode" VALUES(38863,90042,-8,'Los Angeles, California 90042',27895,34536);
INSERT INTO "django_geo_db_zipcode" VALUES(38864,90043,-8,'Los Angeles, California 90043',27895,34537);
INSERT INTO "django_geo_db_zipcode" VALUES(38865,90044,-8,'Los Angeles, California 90044',27895,34538);
INSERT INTO "django_geo_db_zipcode" VALUES(38866,90045,-8,'Los Angeles, California 90045',27895,34539);
INSERT INTO "django_geo_db_zipcode" VALUES(38867,90046,-8,'Los Angeles, California 90046',27895,34540);
INSERT INTO "django_geo_db_zipcode" VALUES(38868,90047,-8,'Los Angeles, California 90047',27895,34541);
INSERT INTO "django_geo_db_zipcode" VALUES(38869,90048,-8,'Los Angeles, California 90048',27895,34542);
INSERT INTO "django_geo_db_zipcode" VALUES(38870,90049,-8,'Los Angeles, California 90049',27895,34543);
INSERT INTO "django_geo_db_zipcode" VALUES(38871,90050,-8,'Los Angeles, California 90050',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38872,90051,-8,'Los Angeles, California 90051',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38873,90052,-8,'Los Angeles, California 90052',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38874,90053,-8,'Los Angeles, California 90053',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38875,90054,-8,'Los Angeles, California 90054',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38876,90055,-8,'Los Angeles, California 90055',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38877,90056,-8,'Los Angeles, California 90056',27895,34544);
INSERT INTO "django_geo_db_zipcode" VALUES(38878,90057,-8,'Los Angeles, California 90057',27895,34545);
INSERT INTO "django_geo_db_zipcode" VALUES(38879,90058,-8,'Los Angeles, California 90058',27895,34546);
INSERT INTO "django_geo_db_zipcode" VALUES(38880,90059,-8,'Los Angeles, California 90059',27895,34547);
INSERT INTO "django_geo_db_zipcode" VALUES(38881,90060,-8,'Los Angeles, California 90060',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38882,90061,-8,'Los Angeles, California 90061',27895,34548);
INSERT INTO "django_geo_db_zipcode" VALUES(38883,90062,-8,'Los Angeles, California 90062',27895,34549);
INSERT INTO "django_geo_db_zipcode" VALUES(38884,90063,-8,'Los Angeles, California 90063',27895,34550);
INSERT INTO "django_geo_db_zipcode" VALUES(38885,90064,-8,'Los Angeles, California 90064',27895,34551);
INSERT INTO "django_geo_db_zipcode" VALUES(38886,90065,-8,'Los Angeles, California 90065',27895,34552);
INSERT INTO "django_geo_db_zipcode" VALUES(38887,90066,-8,'Los Angeles, California 90066',27895,34553);
INSERT INTO "django_geo_db_zipcode" VALUES(38888,90067,-8,'Los Angeles, California 90067',27895,34554);
INSERT INTO "django_geo_db_zipcode" VALUES(38889,90068,-8,'Los Angeles, California 90068',27895,34555);
INSERT INTO "django_geo_db_zipcode" VALUES(38890,90069,-8,'West Hollywood, California 90069',27896,34556);
INSERT INTO "django_geo_db_zipcode" VALUES(38891,90070,-8,'Los Angeles, California 90070',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38892,90071,-8,'Los Angeles, California 90071',27895,34557);
INSERT INTO "django_geo_db_zipcode" VALUES(38893,90072,-8,'Los Angeles, California 90072',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38894,90073,-8,'Los Angeles, California 90073',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38895,90074,-8,'Los Angeles, California 90074',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38896,90075,-8,'Los Angeles, California 90075',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38897,90076,-8,'Los Angeles, California 90076',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38898,90077,-8,'Los Angeles, California 90077',27895,34558);
INSERT INTO "django_geo_db_zipcode" VALUES(38899,90078,-8,'Los Angeles, California 90078',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38900,90079,-8,'Los Angeles, California 90079',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38901,90080,-8,'Los Angeles, California 90080',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38902,90081,-8,'Los Angeles, California 90081',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38903,90082,-8,'Los Angeles, California 90082',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38904,90083,-8,'Los Angeles, California 90083',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38905,90084,-8,'Los Angeles, California 90084',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38906,90086,-8,'Los Angeles, California 90086',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38907,90087,-8,'Los Angeles, California 90087',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38908,90088,-8,'Los Angeles, California 90088',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38909,90089,-8,'Los Angeles, California 90089',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38910,90091,-8,'Los Angeles, California 90091',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38911,90093,-8,'Los Angeles, California 90093',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38912,90094,-8,'Los Angeles, California 90094',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38913,90095,-8,'Los Angeles, California 90095',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38914,90096,-8,'Los Angeles, California 90096',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38915,90097,-8,'Los Angeles, California 90097',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38916,90099,-8,'Los Angeles, California 90099',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38917,90101,-8,'Los Angeles, California 90101',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38918,90102,-8,'Los Angeles, California 90102',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38919,90103,-8,'Los Angeles, California 90103',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38920,90174,-8,'Los Angeles, California 90174',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38921,90185,-8,'Los Angeles, California 90185',27895,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38922,90201,-8,'Bell, California 90201',27897,34559);
INSERT INTO "django_geo_db_zipcode" VALUES(38923,90202,-8,'Bell Gardens, California 90202',27898,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38924,90204,-8,'Inglewood, California 90204',27899,34560);
INSERT INTO "django_geo_db_zipcode" VALUES(38925,90209,-8,'Beverly Hills, California 90209',27900,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38926,90210,-8,'Beverly Hills, California 90210',27900,34561);
INSERT INTO "django_geo_db_zipcode" VALUES(38927,90211,-8,'Beverly Hills, California 90211',27900,34562);
INSERT INTO "django_geo_db_zipcode" VALUES(38928,90212,-8,'Beverly Hills, California 90212',27900,34563);
INSERT INTO "django_geo_db_zipcode" VALUES(38929,90213,-8,'Beverly Hills, California 90213',27900,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38930,90220,-8,'Compton, California 90220',27901,34564);
INSERT INTO "django_geo_db_zipcode" VALUES(38931,90221,-8,'Compton, California 90221',27901,34565);
INSERT INTO "django_geo_db_zipcode" VALUES(38932,90222,-8,'Compton, California 90222',27901,34566);
INSERT INTO "django_geo_db_zipcode" VALUES(38933,90223,-8,'Compton, California 90223',27901,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38934,90224,-8,'Compton, California 90224',27901,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38935,90230,-8,'Culver City, California 90230',27902,34567);
INSERT INTO "django_geo_db_zipcode" VALUES(38936,90231,-8,'Culver City, California 90231',27902,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38937,90232,-8,'Culver City, California 90232',27902,34568);
INSERT INTO "django_geo_db_zipcode" VALUES(38938,90233,-8,'Culver City, California 90233',27902,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38939,90239,-8,'Downey, California 90239',27903,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38940,90240,-8,'Downey, California 90240',27903,34569);
INSERT INTO "django_geo_db_zipcode" VALUES(38941,90241,-8,'Downey, California 90241',27903,34570);
INSERT INTO "django_geo_db_zipcode" VALUES(38942,90242,-8,'Downey, California 90242',27903,34571);
INSERT INTO "django_geo_db_zipcode" VALUES(38943,90245,-8,'El Segundo, California 90245',27904,34572);
INSERT INTO "django_geo_db_zipcode" VALUES(38944,90247,-8,'Gardena, California 90247',27905,34573);
INSERT INTO "django_geo_db_zipcode" VALUES(38945,90248,-8,'Gardena, California 90248',27905,34574);
INSERT INTO "django_geo_db_zipcode" VALUES(38946,90249,-8,'Gardena, California 90249',27905,34575);
INSERT INTO "django_geo_db_zipcode" VALUES(38947,90250,-8,'Hawthorne, California 90250',27906,34576);
INSERT INTO "django_geo_db_zipcode" VALUES(38948,90251,-8,'Hawthorne, California 90251',27906,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38949,90254,-8,'Hermosa Beach, California 90254',27907,34577);
INSERT INTO "django_geo_db_zipcode" VALUES(38950,90255,-8,'Huntington Park, California 90255',27908,34578);
INSERT INTO "django_geo_db_zipcode" VALUES(38951,90260,-8,'Lawndale, California 90260',27909,34579);
INSERT INTO "django_geo_db_zipcode" VALUES(38952,90261,-8,'Lawndale, California 90261',27909,34580);
INSERT INTO "django_geo_db_zipcode" VALUES(38953,90262,-8,'Lynwood, California 90262',27910,34581);
INSERT INTO "django_geo_db_zipcode" VALUES(38954,90263,-8,'Malibu, California 90263',27911,34582);
INSERT INTO "django_geo_db_zipcode" VALUES(38955,90264,-8,'Malibu, California 90264',27911,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38956,90265,-8,'Malibu, California 90265',27911,34583);
INSERT INTO "django_geo_db_zipcode" VALUES(38957,90266,-8,'Manhattan Beach, California 90266',27912,34584);
INSERT INTO "django_geo_db_zipcode" VALUES(38958,90267,-8,'Manhattan Beach, California 90267',27912,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38959,90270,-8,'Maywood, California 90270',27913,34585);
INSERT INTO "django_geo_db_zipcode" VALUES(38960,90272,-8,'Pacific Palisades, California 90272',27914,34586);
INSERT INTO "django_geo_db_zipcode" VALUES(38961,90274,-8,'Palos Verdes Peninsula, California 90274',27915,34587);
INSERT INTO "django_geo_db_zipcode" VALUES(38962,90275,-8,'Rancho Palos Verdes, California 90275',27916,34588);
INSERT INTO "django_geo_db_zipcode" VALUES(38963,90276,-8,'Redondo Beach, California 90276',27917,34589);
INSERT INTO "django_geo_db_zipcode" VALUES(38964,90277,-8,'Redondo Beach, California 90277',27917,34590);
INSERT INTO "django_geo_db_zipcode" VALUES(38965,90278,-8,'Redondo Beach, California 90278',27917,34591);
INSERT INTO "django_geo_db_zipcode" VALUES(38966,90280,-8,'South Gate, California 90280',27918,34592);
INSERT INTO "django_geo_db_zipcode" VALUES(38967,90290,-8,'Topanga, California 90290',27919,34593);
INSERT INTO "django_geo_db_zipcode" VALUES(38968,90291,-8,'Venice, California 90291',27920,34594);
INSERT INTO "django_geo_db_zipcode" VALUES(38969,90292,-8,'Marina Del Rey, California 90292',27921,34595);
INSERT INTO "django_geo_db_zipcode" VALUES(38970,90293,-8,'Playa Del Rey, California 90293',27922,34596);
INSERT INTO "django_geo_db_zipcode" VALUES(38971,90294,-8,'Venice, California 90294',27920,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38972,90295,-8,'Marina Del Rey, California 90295',27921,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38973,90296,-8,'Playa Del Rey, California 90296',27922,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38974,90301,-8,'Inglewood, California 90301',27899,34597);
INSERT INTO "django_geo_db_zipcode" VALUES(38975,90302,-8,'Inglewood, California 90302',27899,34598);
INSERT INTO "django_geo_db_zipcode" VALUES(38976,90303,-8,'Inglewood, California 90303',27899,34599);
INSERT INTO "django_geo_db_zipcode" VALUES(38977,90304,-8,'Inglewood, California 90304',27899,34600);
INSERT INTO "django_geo_db_zipcode" VALUES(38978,90305,-8,'Inglewood, California 90305',27899,34601);
INSERT INTO "django_geo_db_zipcode" VALUES(38979,90306,-8,'Inglewood, California 90306',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38980,90307,-8,'Inglewood, California 90307',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38981,90308,-8,'Inglewood, California 90308',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38982,90309,-8,'Inglewood, California 90309',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38983,90310,-8,'Inglewood, California 90310',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38984,90311,-8,'Inglewood, California 90311',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38985,90312,-8,'Inglewood, California 90312',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38986,90313,-8,'Inglewood, California 90313',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38987,90397,-8,'Inglewood, California 90397',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38988,90398,-8,'Inglewood, California 90398',27899,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38989,90401,-8,'Santa Monica, California 90401',27923,34602);
INSERT INTO "django_geo_db_zipcode" VALUES(38990,90402,-8,'Santa Monica, California 90402',27923,34603);
INSERT INTO "django_geo_db_zipcode" VALUES(38991,90403,-8,'Santa Monica, California 90403',27923,34604);
INSERT INTO "django_geo_db_zipcode" VALUES(38992,90404,-8,'Santa Monica, California 90404',27923,34605);
INSERT INTO "django_geo_db_zipcode" VALUES(38993,90405,-8,'Santa Monica, California 90405',27923,34606);
INSERT INTO "django_geo_db_zipcode" VALUES(38994,90406,-8,'Santa Monica, California 90406',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38995,90407,-8,'Santa Monica, California 90407',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38996,90408,-8,'Santa Monica, California 90408',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38997,90409,-8,'Santa Monica, California 90409',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38998,90410,-8,'Santa Monica, California 90410',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(38999,90411,-8,'Santa Monica, California 90411',27923,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39000,90421,-8,'Santa Monica, California 90421',27923,34607);
INSERT INTO "django_geo_db_zipcode" VALUES(39001,90501,-8,'Torrance, California 90501',27924,34608);
INSERT INTO "django_geo_db_zipcode" VALUES(39002,90502,-8,'Torrance, California 90502',27924,34609);
INSERT INTO "django_geo_db_zipcode" VALUES(39003,90503,-8,'Torrance, California 90503',27924,34610);
INSERT INTO "django_geo_db_zipcode" VALUES(39004,90504,-8,'Torrance, California 90504',27924,34611);
INSERT INTO "django_geo_db_zipcode" VALUES(39005,90505,-8,'Torrance, California 90505',27924,34612);
INSERT INTO "django_geo_db_zipcode" VALUES(39006,90506,-8,'Torrance, California 90506',27924,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39007,90507,-8,'Torrance, California 90507',27924,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39008,90508,-8,'Torrance, California 90508',27924,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39009,90509,-8,'Torrance, California 90509',27924,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39010,90510,-8,'Torrance, California 90510',27924,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39011,90601,-8,'Whittier, California 90601',27925,34613);
INSERT INTO "django_geo_db_zipcode" VALUES(39012,90602,-8,'Whittier, California 90602',27925,34614);
INSERT INTO "django_geo_db_zipcode" VALUES(39013,90603,-8,'Whittier, California 90603',27925,34615);
INSERT INTO "django_geo_db_zipcode" VALUES(39014,90604,-8,'Whittier, California 90604',27925,34616);
INSERT INTO "django_geo_db_zipcode" VALUES(39015,90605,-8,'Whittier, California 90605',27925,34617);
INSERT INTO "django_geo_db_zipcode" VALUES(39016,90606,-8,'Whittier, California 90606',27925,34618);
INSERT INTO "django_geo_db_zipcode" VALUES(39017,90607,-8,'Whittier, California 90607',27925,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39018,90608,-8,'Whittier, California 90608',27925,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39019,90609,-8,'Whittier, California 90609',27925,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39020,90610,-8,'Whittier, California 90610',27925,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39021,90612,-8,'Whittier, California 90612',27925,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39022,90620,-8,'Buena Park, California 90620',27926,34619);
INSERT INTO "django_geo_db_zipcode" VALUES(39023,90621,-8,'Buena Park, California 90621',27926,34620);
INSERT INTO "django_geo_db_zipcode" VALUES(39024,90622,-8,'Buena Park, California 90622',27926,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39025,90623,-8,'La Palma, California 90623',27927,34622);
INSERT INTO "django_geo_db_zipcode" VALUES(39026,90624,-8,'Buena Park, California 90624',27926,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39027,90630,-8,'Cypress, California 90630',27928,34623);
INSERT INTO "django_geo_db_zipcode" VALUES(39028,90631,-8,'La Habra, California 90631',27929,34624);
INSERT INTO "django_geo_db_zipcode" VALUES(39029,90632,-8,'La Habra, California 90632',27929,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39030,90633,-8,'La Habra, California 90633',27929,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39031,90637,-8,'La Mirada, California 90637',27930,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39032,90638,-8,'La Mirada, California 90638',27930,34625);
INSERT INTO "django_geo_db_zipcode" VALUES(39033,90639,-8,'La Mirada, California 90639',27930,34626);
INSERT INTO "django_geo_db_zipcode" VALUES(39034,90640,-8,'Montebello, California 90640',27931,34627);
INSERT INTO "django_geo_db_zipcode" VALUES(39035,90650,-8,'Norwalk, California 90650',27932,34628);
INSERT INTO "django_geo_db_zipcode" VALUES(39036,90651,-8,'Norwalk, California 90651',27932,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39037,90652,-8,'Norwalk, California 90652',27932,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39038,90659,-8,'Norwalk, California 90659',27932,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39039,90660,-8,'Pico Rivera, California 90660',27933,34629);
INSERT INTO "django_geo_db_zipcode" VALUES(39040,90661,-8,'Pico Rivera, California 90661',27933,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39041,90662,-8,'Pico Rivera, California 90662',27933,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39042,90665,-8,'Pico Rivera, California 90665',27933,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39043,90670,-8,'Santa Fe Springs, California 90670',27934,34630);
INSERT INTO "django_geo_db_zipcode" VALUES(39044,90671,-8,'Santa Fe Springs, California 90671',27934,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39045,90680,-8,'Stanton, California 90680',27935,34631);
INSERT INTO "django_geo_db_zipcode" VALUES(39046,90701,-8,'Artesia, California 90701',27936,34632);
INSERT INTO "django_geo_db_zipcode" VALUES(39047,90702,-8,'Artesia, California 90702',27936,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39048,90703,-8,'Cerritos, California 90703',27937,34633);
INSERT INTO "django_geo_db_zipcode" VALUES(39049,90704,-8,'Avalon, California 90704',27938,34634);
INSERT INTO "django_geo_db_zipcode" VALUES(39050,90706,-8,'Bellflower, California 90706',27939,34635);
INSERT INTO "django_geo_db_zipcode" VALUES(39051,90707,-8,'Bellflower, California 90707',27939,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39052,90710,-8,'Harbor City, California 90710',27940,34636);
INSERT INTO "django_geo_db_zipcode" VALUES(39053,90711,-8,'Lakewood, California 90711',27941,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39054,90712,-8,'Lakewood, California 90712',27941,34637);
INSERT INTO "django_geo_db_zipcode" VALUES(39055,90713,-8,'Lakewood, California 90713',27941,34638);
INSERT INTO "django_geo_db_zipcode" VALUES(39056,90714,-8,'Lakewood, California 90714',27941,34639);
INSERT INTO "django_geo_db_zipcode" VALUES(39057,90715,-8,'Lakewood, California 90715',27941,34640);
INSERT INTO "django_geo_db_zipcode" VALUES(39058,90716,-8,'Hawaiian Gardens, California 90716',27942,34641);
INSERT INTO "django_geo_db_zipcode" VALUES(39059,90717,-8,'Lomita, California 90717',27943,34642);
INSERT INTO "django_geo_db_zipcode" VALUES(39060,90720,-8,'Los Alamitos, California 90720',27944,34643);
INSERT INTO "django_geo_db_zipcode" VALUES(39061,90721,-8,'Los Alamitos, California 90721',27944,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39062,90723,-8,'Paramount, California 90723',27945,34644);
INSERT INTO "django_geo_db_zipcode" VALUES(39063,90731,-8,'San Pedro, California 90731',27946,34645);
INSERT INTO "django_geo_db_zipcode" VALUES(39064,90732,-8,'San Pedro, California 90732',27946,34646);
INSERT INTO "django_geo_db_zipcode" VALUES(39065,90733,-8,'San Pedro, California 90733',27946,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39066,90734,-8,'San Pedro, California 90734',27946,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39067,90740,-8,'Seal Beach, California 90740',27947,34647);
INSERT INTO "django_geo_db_zipcode" VALUES(39068,90742,-8,'Sunset Beach, California 90742',27948,34648);
INSERT INTO "django_geo_db_zipcode" VALUES(39069,90743,-8,'Surfside, California 90743',27949,34649);
INSERT INTO "django_geo_db_zipcode" VALUES(39070,90744,-8,'Wilmington, California 90744',27950,34650);
INSERT INTO "django_geo_db_zipcode" VALUES(39071,90745,-8,'Carson, California 90745',27951,34651);
INSERT INTO "django_geo_db_zipcode" VALUES(39072,90746,-8,'Carson, California 90746',27951,34652);
INSERT INTO "django_geo_db_zipcode" VALUES(39073,90747,-8,'Carson, California 90747',27951,34653);
INSERT INTO "django_geo_db_zipcode" VALUES(39074,90748,-8,'Wilmington, California 90748',27950,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39075,90749,-8,'Carson, California 90749',27951,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39076,90755,-8,'Long Beach, California 90755',27952,34654);
INSERT INTO "django_geo_db_zipcode" VALUES(39077,90774,-8,'Los Angeles, California 90774',27895,34655);
INSERT INTO "django_geo_db_zipcode" VALUES(39078,90801,-8,'Long Beach, California 90801',27952,34656);
INSERT INTO "django_geo_db_zipcode" VALUES(39079,90802,-8,'Long Beach, California 90802',27952,34657);
INSERT INTO "django_geo_db_zipcode" VALUES(39080,90803,-8,'Long Beach, California 90803',27952,34658);
INSERT INTO "django_geo_db_zipcode" VALUES(39081,90804,-8,'Long Beach, California 90804',27952,34659);
INSERT INTO "django_geo_db_zipcode" VALUES(39082,90805,-8,'Long Beach, California 90805',27952,34660);
INSERT INTO "django_geo_db_zipcode" VALUES(39083,90806,-8,'Long Beach, California 90806',27952,34661);
INSERT INTO "django_geo_db_zipcode" VALUES(39084,90807,-8,'Long Beach, California 90807',27952,34662);
INSERT INTO "django_geo_db_zipcode" VALUES(39085,90808,-8,'Long Beach, California 90808',27952,34663);
INSERT INTO "django_geo_db_zipcode" VALUES(39086,90809,-8,'Long Beach, California 90809',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39087,90810,-8,'Long Beach, California 90810',27952,34664);
INSERT INTO "django_geo_db_zipcode" VALUES(39088,90813,-8,'Long Beach, California 90813',27952,34665);
INSERT INTO "django_geo_db_zipcode" VALUES(39089,90814,-8,'Long Beach, California 90814',27952,34666);
INSERT INTO "django_geo_db_zipcode" VALUES(39090,90815,-8,'Long Beach, California 90815',27952,34667);
INSERT INTO "django_geo_db_zipcode" VALUES(39091,90822,-8,'Long Beach, California 90822',27952,34668);
INSERT INTO "django_geo_db_zipcode" VALUES(39092,90831,-8,'Long Beach, California 90831',27952,34669);
INSERT INTO "django_geo_db_zipcode" VALUES(39093,90832,-8,'Long Beach, California 90832',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39094,90833,-8,'Long Beach, California 90833',27952,34669);
INSERT INTO "django_geo_db_zipcode" VALUES(39095,90834,-8,'Long Beach, California 90834',27952,34669);
INSERT INTO "django_geo_db_zipcode" VALUES(39096,90835,-8,'Long Beach, California 90835',27952,34669);
INSERT INTO "django_geo_db_zipcode" VALUES(39097,90840,-8,'Long Beach, California 90840',27952,34670);
INSERT INTO "django_geo_db_zipcode" VALUES(39098,90842,-8,'Long Beach, California 90842',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39099,90844,-8,'Long Beach, California 90844',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39100,90845,-8,'Long Beach, California 90845',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39101,90846,-8,'Long Beach, California 90846',27952,34671);
INSERT INTO "django_geo_db_zipcode" VALUES(39102,90847,-8,'Long Beach, California 90847',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39103,90848,-8,'Long Beach, California 90848',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39104,90853,-8,'Long Beach, California 90853',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39105,90879,-8,'Rancho Palos Verdes, California 90879',27916,34672);
INSERT INTO "django_geo_db_zipcode" VALUES(39106,90888,-8,'Long Beach, California 90888',27952,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39107,91001,-8,'Altadena, California 91001',27953,34673);
INSERT INTO "django_geo_db_zipcode" VALUES(39108,91003,-8,'Altadena, California 91003',27953,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39109,91006,-8,'Arcadia, California 91006',27954,34674);
INSERT INTO "django_geo_db_zipcode" VALUES(39110,91007,-8,'Arcadia, California 91007',27954,34675);
INSERT INTO "django_geo_db_zipcode" VALUES(39111,91009,-8,'Duarte, California 91009',27955,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39112,91010,-8,'Duarte, California 91010',27955,34676);
INSERT INTO "django_geo_db_zipcode" VALUES(39113,91011,-8,'La Canada Flintridge, California 91011',27956,34677);
INSERT INTO "django_geo_db_zipcode" VALUES(39114,91012,-8,'La Canada Flintridge, California 91012',27956,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39115,91016,-8,'Monrovia, California 91016',27957,34678);
INSERT INTO "django_geo_db_zipcode" VALUES(39116,91017,-8,'Monrovia, California 91017',27957,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39117,91020,-8,'Montrose, California 91020',27958,34679);
INSERT INTO "django_geo_db_zipcode" VALUES(39118,91021,-8,'Montrose, California 91021',27958,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39119,91023,-8,'Mount Wilson, California 91023',27959,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39120,91024,-8,'Sierra Madre, California 91024',27960,34680);
INSERT INTO "django_geo_db_zipcode" VALUES(39121,91025,-8,'Sierra Madre, California 91025',27960,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39122,91030,-8,'South Pasadena, California 91030',27961,34681);
INSERT INTO "django_geo_db_zipcode" VALUES(39123,91031,-8,'South Pasadena, California 91031',27961,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39124,91040,-8,'Sunland, California 91040',27962,34682);
INSERT INTO "django_geo_db_zipcode" VALUES(39125,91041,-8,'Sunland, California 91041',27962,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39126,91042,-8,'Tujunga, California 91042',27963,34683);
INSERT INTO "django_geo_db_zipcode" VALUES(39127,91043,-8,'Tujunga, California 91043',27963,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39128,91046,-8,'Verdugo City, California 91046',27964,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39129,91050,-8,'Pasadena, California 91050',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39130,91051,-8,'Pasadena, California 91051',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39131,91066,-8,'Arcadia, California 91066',27954,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39132,91077,-8,'Arcadia, California 91077',27954,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39133,91101,-8,'Pasadena, California 91101',27965,34684);
INSERT INTO "django_geo_db_zipcode" VALUES(39134,91102,-8,'Pasadena, California 91102',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39135,91103,-8,'Pasadena, California 91103',27965,34685);
INSERT INTO "django_geo_db_zipcode" VALUES(39136,91104,-8,'Pasadena, California 91104',27965,34686);
INSERT INTO "django_geo_db_zipcode" VALUES(39137,91105,-8,'Pasadena, California 91105',27965,34687);
INSERT INTO "django_geo_db_zipcode" VALUES(39138,91106,-8,'Pasadena, California 91106',27965,34688);
INSERT INTO "django_geo_db_zipcode" VALUES(39139,91107,-8,'Pasadena, California 91107',27965,34689);
INSERT INTO "django_geo_db_zipcode" VALUES(39140,91108,-8,'San Marino, California 91108',27966,34690);
INSERT INTO "django_geo_db_zipcode" VALUES(39141,91109,-8,'Pasadena, California 91109',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39142,91110,-8,'Pasadena, California 91110',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39143,91114,-8,'Pasadena, California 91114',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39144,91115,-8,'Pasadena, California 91115',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39145,91116,-8,'Pasadena, California 91116',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39146,91117,-8,'Pasadena, California 91117',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39147,91118,-8,'San Marino, California 91118',27966,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39148,91121,-8,'Pasadena, California 91121',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39149,91123,-8,'Pasadena, California 91123',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39150,91124,-8,'Pasadena, California 91124',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39151,91125,-8,'Pasadena, California 91125',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39152,91126,-8,'Pasadena, California 91126',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39153,91129,-8,'Pasadena, California 91129',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39154,91131,-8,'Pasadena, California 91131',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39155,91175,-8,'Pasadena, California 91175',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39156,91182,-8,'Pasadena, California 91182',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39157,91184,-8,'Pasadena, California 91184',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39158,91185,-8,'Pasadena, California 91185',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39159,91186,-8,'Pasadena, California 91186',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39160,91187,-8,'Pasadena, California 91187',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39161,91188,-8,'Pasadena, California 91188',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39162,91189,-8,'Pasadena, California 91189',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39163,91191,-8,'Pasadena, California 91191',27965,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39164,91201,-8,'Glendale, California 91201',27967,34691);
INSERT INTO "django_geo_db_zipcode" VALUES(39165,91202,-8,'Glendale, California 91202',27967,34692);
INSERT INTO "django_geo_db_zipcode" VALUES(39166,91203,-8,'Glendale, California 91203',27967,34693);
INSERT INTO "django_geo_db_zipcode" VALUES(39167,91204,-8,'Glendale, California 91204',27967,34694);
INSERT INTO "django_geo_db_zipcode" VALUES(39168,91205,-8,'Glendale, California 91205',27967,34695);
INSERT INTO "django_geo_db_zipcode" VALUES(39169,91206,-8,'Glendale, California 91206',27967,34696);
INSERT INTO "django_geo_db_zipcode" VALUES(39170,91207,-8,'Glendale, California 91207',27967,34697);
INSERT INTO "django_geo_db_zipcode" VALUES(39171,91208,-8,'Glendale, California 91208',27967,34698);
INSERT INTO "django_geo_db_zipcode" VALUES(39172,91209,-8,'Glendale, California 91209',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39173,91210,-8,'Glendale, California 91210',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39174,91214,-8,'La Crescenta, California 91214',27968,34699);
INSERT INTO "django_geo_db_zipcode" VALUES(39175,91221,-8,'Glendale, California 91221',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39176,91222,-8,'Glendale, California 91222',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39177,91224,-8,'La Crescenta, California 91224',27968,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39178,91225,-8,'Glendale, California 91225',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39179,91226,-8,'Glendale, California 91226',27967,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39180,91301,-8,'Agoura Hills, California 91301',27969,34700);
INSERT INTO "django_geo_db_zipcode" VALUES(39181,91302,-8,'Calabasas, California 91302',27970,34701);
INSERT INTO "django_geo_db_zipcode" VALUES(39182,91303,-8,'Canoga Park, California 91303',27971,34702);
INSERT INTO "django_geo_db_zipcode" VALUES(39183,91304,-8,'Canoga Park, California 91304',27971,34703);
INSERT INTO "django_geo_db_zipcode" VALUES(39184,91305,-8,'Canoga Park, California 91305',27971,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39185,91306,-8,'Winnetka, California 91306',27972,34704);
INSERT INTO "django_geo_db_zipcode" VALUES(39186,91307,-8,'West Hills, California 91307',27973,34705);
INSERT INTO "django_geo_db_zipcode" VALUES(39187,91308,-8,'West Hills, California 91308',27973,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39188,91309,-8,'Canoga Park, California 91309',27971,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39189,91310,-8,'Castaic, California 91310',27974,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39190,91311,-8,'Chatsworth, California 91311',27975,34706);
INSERT INTO "django_geo_db_zipcode" VALUES(39191,91312,-8,'Chatsworth, California 91312',27975,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39192,91313,-8,'Chatsworth, California 91313',27975,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39193,91316,-8,'Encino, California 91316',27976,34707);
INSERT INTO "django_geo_db_zipcode" VALUES(39194,91319,-8,'Newbury Park, California 91319',27977,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39195,91320,-8,'Newbury Park, California 91320',27977,34709);
INSERT INTO "django_geo_db_zipcode" VALUES(39196,91321,-8,'Newhall, California 91321',27978,34710);
INSERT INTO "django_geo_db_zipcode" VALUES(39197,91322,-8,'Newhall, California 91322',27978,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39198,91324,-8,'Northridge, California 91324',27979,34711);
INSERT INTO "django_geo_db_zipcode" VALUES(39199,91325,-8,'Northridge, California 91325',27979,34712);
INSERT INTO "django_geo_db_zipcode" VALUES(39200,91326,-8,'Northridge, California 91326',27979,34713);
INSERT INTO "django_geo_db_zipcode" VALUES(39201,91327,-8,'Northridge, California 91327',27979,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39202,91328,-8,'Northridge, California 91328',27979,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39203,91329,-8,'Northridge, California 91329',27979,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39204,91330,-8,'Northridge, California 91330',27979,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39205,91331,-8,'Pacoima, California 91331',27980,34714);
INSERT INTO "django_geo_db_zipcode" VALUES(39206,91333,-8,'Pacoima, California 91333',27980,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39207,91334,-8,'Pacoima, California 91334',27980,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39208,91335,-8,'Reseda, California 91335',27981,34715);
INSERT INTO "django_geo_db_zipcode" VALUES(39209,91337,-8,'Reseda, California 91337',27981,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39210,91340,-8,'San Fernando, California 91340',27982,34716);
INSERT INTO "django_geo_db_zipcode" VALUES(39211,91341,-8,'San Fernando, California 91341',27982,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39212,91342,-8,'Sylmar, California 91342',27983,34717);
INSERT INTO "django_geo_db_zipcode" VALUES(39213,91343,-8,'North Hills, California 91343',27984,34718);
INSERT INTO "django_geo_db_zipcode" VALUES(39214,91344,-8,'Granada Hills, California 91344',27985,34719);
INSERT INTO "django_geo_db_zipcode" VALUES(39215,91345,-8,'Mission Hills, California 91345',27986,34720);
INSERT INTO "django_geo_db_zipcode" VALUES(39216,91346,-8,'Mission Hills, California 91346',27986,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39217,91350,-8,'Santa Clarita, California 91350',27987,34721);
INSERT INTO "django_geo_db_zipcode" VALUES(39218,91351,-8,'Canyon Country, California 91351',27988,34722);
INSERT INTO "django_geo_db_zipcode" VALUES(39219,91352,-8,'Sun Valley, California 91352',27989,34723);
INSERT INTO "django_geo_db_zipcode" VALUES(39220,91353,-8,'Sun Valley, California 91353',27989,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39221,91354,-8,'Valencia, California 91354',27990,34724);
INSERT INTO "django_geo_db_zipcode" VALUES(39222,91355,-8,'Valencia, California 91355',27990,34725);
INSERT INTO "django_geo_db_zipcode" VALUES(39223,91356,-8,'Tarzana, California 91356',27991,34726);
INSERT INTO "django_geo_db_zipcode" VALUES(39224,91357,-8,'Tarzana, California 91357',27991,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39225,91358,-8,'Thousand Oaks, California 91358',27992,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39226,91359,-8,'Westlake Village, California 91359',27993,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39227,91360,-8,'Thousand Oaks, California 91360',27992,34727);
INSERT INTO "django_geo_db_zipcode" VALUES(39228,91361,-8,'Westlake Village, California 91361',27993,34728);
INSERT INTO "django_geo_db_zipcode" VALUES(39229,91362,-8,'Thousand Oaks, California 91362',27992,34729);
INSERT INTO "django_geo_db_zipcode" VALUES(39230,91363,-8,'Westlake Village, California 91363',27993,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39231,91364,-8,'Woodland Hills, California 91364',27994,34730);
INSERT INTO "django_geo_db_zipcode" VALUES(39232,91365,-8,'Woodland Hills, California 91365',27994,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39233,91367,-8,'Woodland Hills, California 91367',27994,34731);
INSERT INTO "django_geo_db_zipcode" VALUES(39234,91371,-8,'Woodland Hills, California 91371',27994,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39235,91372,-8,'Calabasas, California 91372',27970,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39236,91376,-8,'Agoura Hills, California 91376',27969,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39237,91377,-8,'Oak Park, California 91377',27995,34732);
INSERT INTO "django_geo_db_zipcode" VALUES(39238,91380,-8,'Santa Clarita, California 91380',27987,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39239,91381,-8,'Stevenson Ranch, California 91381',27996,34733);
INSERT INTO "django_geo_db_zipcode" VALUES(39240,91382,-8,'Santa Clarita, California 91382',27987,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39241,91383,-8,'Santa Clarita, California 91383',27987,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39242,91384,-8,'Castaic, California 91384',27974,34734);
INSERT INTO "django_geo_db_zipcode" VALUES(39243,91385,-8,'Valencia, California 91385',27990,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39244,91386,-8,'Canyon Country, California 91386',27988,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39245,91387,-8,'Santa Clarita, California 91387',27987,34735);
INSERT INTO "django_geo_db_zipcode" VALUES(39246,91388,-8,'Van Nuys, California 91388',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39247,91390,-8,'Santa Clarita, California 91390',27987,34736);
INSERT INTO "django_geo_db_zipcode" VALUES(39248,91392,-8,'Sylmar, California 91392',27983,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39249,91393,-8,'North Hills, California 91393',27984,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39250,91394,-8,'Granada Hills, California 91394',27985,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39251,91395,-8,'Mission Hills, California 91395',27986,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39252,91396,-8,'Winnetka, California 91396',27972,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39253,91399,-8,'Woodland Hills, California 91399',27994,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39254,91401,-8,'Van Nuys, California 91401',27997,34737);
INSERT INTO "django_geo_db_zipcode" VALUES(39255,91402,-8,'Panorama City, California 91402',27998,34738);
INSERT INTO "django_geo_db_zipcode" VALUES(39256,91403,-8,'Sherman Oaks, California 91403',27999,34739);
INSERT INTO "django_geo_db_zipcode" VALUES(39257,91404,-8,'Van Nuys, California 91404',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39258,91405,-8,'Van Nuys, California 91405',27997,34740);
INSERT INTO "django_geo_db_zipcode" VALUES(39259,91406,-8,'Van Nuys, California 91406',27997,34741);
INSERT INTO "django_geo_db_zipcode" VALUES(39260,91407,-8,'Van Nuys, California 91407',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39261,91408,-8,'Van Nuys, California 91408',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39262,91409,-8,'Van Nuys, California 91409',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39263,91410,-8,'Van Nuys, California 91410',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39264,91411,-8,'Van Nuys, California 91411',27997,34742);
INSERT INTO "django_geo_db_zipcode" VALUES(39265,91412,-8,'Panorama City, California 91412',27998,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39266,91413,-8,'Sherman Oaks, California 91413',27999,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39267,91416,-8,'Encino, California 91416',27976,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39268,91423,-8,'Sherman Oaks, California 91423',27999,34743);
INSERT INTO "django_geo_db_zipcode" VALUES(39269,91426,-8,'Encino, California 91426',27976,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39270,91436,-8,'Encino, California 91436',27976,34744);
INSERT INTO "django_geo_db_zipcode" VALUES(39271,91470,-8,'Van Nuys, California 91470',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39272,91482,-8,'Van Nuys, California 91482',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39273,91495,-8,'Sherman Oaks, California 91495',27999,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39274,91496,-8,'Van Nuys, California 91496',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39275,91497,-8,'Van Nuys, California 91497',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39276,91499,-8,'Van Nuys, California 91499',27997,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39277,91501,-8,'Burbank, California 91501',28000,34745);
INSERT INTO "django_geo_db_zipcode" VALUES(39278,91502,-8,'Burbank, California 91502',28000,34746);
INSERT INTO "django_geo_db_zipcode" VALUES(39279,91503,-8,'Burbank, California 91503',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39280,91504,-8,'Burbank, California 91504',28000,34747);
INSERT INTO "django_geo_db_zipcode" VALUES(39281,91505,-8,'Burbank, California 91505',28000,34748);
INSERT INTO "django_geo_db_zipcode" VALUES(39282,91506,-8,'Burbank, California 91506',28000,34749);
INSERT INTO "django_geo_db_zipcode" VALUES(39283,91507,-8,'Burbank, California 91507',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39284,91508,-8,'Burbank, California 91508',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39285,91510,-8,'Burbank, California 91510',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39286,91521,-8,'Burbank, California 91521',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39287,91522,-8,'Burbank, California 91522',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39288,91523,-8,'Burbank, California 91523',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39289,91526,-8,'Burbank, California 91526',28000,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39290,91601,-8,'North Hollywood, California 91601',28001,34750);
INSERT INTO "django_geo_db_zipcode" VALUES(39291,91602,-8,'North Hollywood, California 91602',28001,34751);
INSERT INTO "django_geo_db_zipcode" VALUES(39292,91603,-8,'North Hollywood, California 91603',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39293,91604,-8,'Studio City, California 91604',28002,34752);
INSERT INTO "django_geo_db_zipcode" VALUES(39294,91605,-8,'North Hollywood, California 91605',28001,34753);
INSERT INTO "django_geo_db_zipcode" VALUES(39295,91606,-8,'North Hollywood, California 91606',28001,34754);
INSERT INTO "django_geo_db_zipcode" VALUES(39296,91607,-8,'Valley Village, California 91607',28003,34755);
INSERT INTO "django_geo_db_zipcode" VALUES(39297,91608,-8,'Universal City, California 91608',28004,34756);
INSERT INTO "django_geo_db_zipcode" VALUES(39298,91609,-8,'North Hollywood, California 91609',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39299,91610,-8,'Toluca Lake, California 91610',28005,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39300,91611,-8,'North Hollywood, California 91611',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39301,91612,-8,'North Hollywood, California 91612',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39302,91614,-8,'Studio City, California 91614',28002,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39303,91615,-8,'North Hollywood, California 91615',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39304,91616,-8,'North Hollywood, California 91616',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39305,91617,-8,'Valley Village, California 91617',28003,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39306,91618,-8,'North Hollywood, California 91618',28001,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39307,91671,-8,'Los Angeles, California 91671',27895,34757);
INSERT INTO "django_geo_db_zipcode" VALUES(39308,91701,-8,'Alta Loma, California 91701',28006,34758);
INSERT INTO "django_geo_db_zipcode" VALUES(39309,91702,-8,'Azusa, California 91702',28007,34759);
INSERT INTO "django_geo_db_zipcode" VALUES(39310,91706,-8,'Baldwin Park, California 91706',28008,34760);
INSERT INTO "django_geo_db_zipcode" VALUES(39311,91708,-8,'Chino, California 91708',28009,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39312,91709,-8,'Chino Hills, California 91709',28010,34762);
INSERT INTO "django_geo_db_zipcode" VALUES(39313,91710,-8,'Chino, California 91710',28009,34763);
INSERT INTO "django_geo_db_zipcode" VALUES(39314,91711,-8,'Claremont, California 91711',28011,34764);
INSERT INTO "django_geo_db_zipcode" VALUES(39315,91714,-8,'City Of Industry, California 91714',28012,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39316,91715,-8,'City Of Industry, California 91715',28012,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39317,91716,-8,'City Of Industry, California 91716',28012,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39318,91718,-8,'Corona, California 91718',28013,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39319,91719,-8,'Corona, California 91719',28013,34766);
INSERT INTO "django_geo_db_zipcode" VALUES(39320,91720,-8,'Corona, California 91720',28013,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39321,91722,-8,'Covina, California 91722',28014,34767);
INSERT INTO "django_geo_db_zipcode" VALUES(39322,91723,-8,'Covina, California 91723',28014,34768);
INSERT INTO "django_geo_db_zipcode" VALUES(39323,91724,-8,'Covina, California 91724',28014,34769);
INSERT INTO "django_geo_db_zipcode" VALUES(39324,91729,-8,'Rancho Cucamonga, California 91729',28015,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39325,91730,-8,'Rancho Cucamonga, California 91730',28015,34770);
INSERT INTO "django_geo_db_zipcode" VALUES(39326,91731,-8,'El Monte, California 91731',28016,34771);
INSERT INTO "django_geo_db_zipcode" VALUES(39327,91732,-8,'El Monte, California 91732',28016,34772);
INSERT INTO "django_geo_db_zipcode" VALUES(39328,91733,-8,'South El Monte, California 91733',28017,34773);
INSERT INTO "django_geo_db_zipcode" VALUES(39329,91734,-8,'El Monte, California 91734',28016,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39330,91735,-8,'El Monte, California 91735',28016,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39331,91737,-8,'Alta Loma, California 91737',28006,34774);
INSERT INTO "django_geo_db_zipcode" VALUES(39332,91739,-8,'Rancho Cucamonga, California 91739',28015,34775);
INSERT INTO "django_geo_db_zipcode" VALUES(39333,91740,-8,'Glendora, California 91740',28018,34776);
INSERT INTO "django_geo_db_zipcode" VALUES(39334,91741,-8,'Glendora, California 91741',28018,34777);
INSERT INTO "django_geo_db_zipcode" VALUES(39335,91743,-8,'Guasti, California 91743',28019,34778);
INSERT INTO "django_geo_db_zipcode" VALUES(39336,91744,-8,'La Puente, California 91744',28020,34779);
INSERT INTO "django_geo_db_zipcode" VALUES(39337,91745,-8,'Hacienda Heights, California 91745',28021,34780);
INSERT INTO "django_geo_db_zipcode" VALUES(39338,91746,-8,'La Puente, California 91746',28020,34781);
INSERT INTO "django_geo_db_zipcode" VALUES(39339,91747,-8,'La Puente, California 91747',28020,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39340,91748,-8,'Rowland Heights, California 91748',28022,34782);
INSERT INTO "django_geo_db_zipcode" VALUES(39341,91749,-8,'La Puente, California 91749',28020,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39342,91750,-8,'La Verne, California 91750',28023,34783);
INSERT INTO "django_geo_db_zipcode" VALUES(39343,91752,-8,'Mira Loma, California 91752',28024,34784);
INSERT INTO "django_geo_db_zipcode" VALUES(39344,91754,-8,'Monterey Park, California 91754',28025,34785);
INSERT INTO "django_geo_db_zipcode" VALUES(39345,91755,-8,'Monterey Park, California 91755',28025,34786);
INSERT INTO "django_geo_db_zipcode" VALUES(39346,91756,-8,'Monterey Park, California 91756',28025,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39347,91758,-8,'Ontario, California 91758',28026,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39348,91759,-8,'Mt Baldy, California 91759',28027,34787);
INSERT INTO "django_geo_db_zipcode" VALUES(39349,91760,-8,'Norco, California 91760',28028,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39350,91761,-8,'Ontario, California 91761',28026,34788);
INSERT INTO "django_geo_db_zipcode" VALUES(39351,91762,-8,'Ontario, California 91762',28026,34789);
INSERT INTO "django_geo_db_zipcode" VALUES(39352,91763,-8,'Montclair, California 91763',28029,34790);
INSERT INTO "django_geo_db_zipcode" VALUES(39353,91764,-8,'Ontario, California 91764',28026,34791);
INSERT INTO "django_geo_db_zipcode" VALUES(39354,91765,-8,'Diamond Bar, California 91765',28030,34792);
INSERT INTO "django_geo_db_zipcode" VALUES(39355,91766,-8,'Pomona, California 91766',28031,34793);
INSERT INTO "django_geo_db_zipcode" VALUES(39356,91767,-8,'Pomona, California 91767',28031,34794);
INSERT INTO "django_geo_db_zipcode" VALUES(39357,91768,-8,'Pomona, California 91768',28031,34795);
INSERT INTO "django_geo_db_zipcode" VALUES(39358,91769,-8,'Pomona, California 91769',28031,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39359,91770,-8,'Rosemead, California 91770',28032,34796);
INSERT INTO "django_geo_db_zipcode" VALUES(39360,91771,-8,'Rosemead, California 91771',28032,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39361,91772,-8,'Rosemead, California 91772',28032,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39362,91773,-8,'San Dimas, California 91773',28033,34797);
INSERT INTO "django_geo_db_zipcode" VALUES(39363,91775,-8,'San Gabriel, California 91775',28034,34798);
INSERT INTO "django_geo_db_zipcode" VALUES(39364,91776,-8,'San Gabriel, California 91776',28034,34799);
INSERT INTO "django_geo_db_zipcode" VALUES(39365,91778,-8,'San Gabriel, California 91778',28034,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39366,91780,-8,'Temple City, California 91780',28035,34800);
INSERT INTO "django_geo_db_zipcode" VALUES(39367,91784,-8,'Upland, California 91784',28036,34801);
INSERT INTO "django_geo_db_zipcode" VALUES(39368,91785,-8,'Upland, California 91785',28036,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39369,91786,-8,'Upland, California 91786',28036,34802);
INSERT INTO "django_geo_db_zipcode" VALUES(39370,91788,-8,'Walnut, California 91788',28037,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39371,91789,-8,'Walnut, California 91789',28037,34803);
INSERT INTO "django_geo_db_zipcode" VALUES(39372,91790,-8,'West Covina, California 91790',28038,34804);
INSERT INTO "django_geo_db_zipcode" VALUES(39373,91791,-8,'West Covina, California 91791',28038,34805);
INSERT INTO "django_geo_db_zipcode" VALUES(39374,91792,-8,'West Covina, California 91792',28038,34806);
INSERT INTO "django_geo_db_zipcode" VALUES(39375,91793,-8,'West Covina, California 91793',28038,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39376,91795,-8,'Walnut, California 91795',28037,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39377,91797,-8,'Pomona, California 91797',28031,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39378,91798,-8,'Ontario, California 91798',28026,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39379,91799,-8,'Pomona, California 91799',28031,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39380,91801,-8,'Alhambra, California 91801',28039,34807);
INSERT INTO "django_geo_db_zipcode" VALUES(39381,91802,-8,'Alhambra, California 91802',28039,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39382,91803,-8,'Alhambra, California 91803',28039,34808);
INSERT INTO "django_geo_db_zipcode" VALUES(39383,91804,-8,'Alhambra, California 91804',28039,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39384,91841,-8,'Alhambra, California 91841',28039,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39385,91896,-8,'Alhambra, California 91896',28039,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39386,91899,-8,'Alhambra, California 91899',28039,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(39387,91901,-8,'Alpine, California 91901',28040,34809);
INSERT INTO "django_geo_db_zipcode" VALUES(39388,91902,-8,'Bonita, California 91902',28041,34810);
INSERT INTO "django_geo_db_zipcode" VALUES(39389,91903,-8,'Alpine, California 91903',28040,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39390,91905,-8,'Boulevard, California 91905',28042,34812);
INSERT INTO "django_geo_db_zipcode" VALUES(39391,91906,-8,'Campo, California 91906',28043,34813);
INSERT INTO "django_geo_db_zipcode" VALUES(39392,91908,-8,'Bonita, California 91908',28041,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39393,91909,-8,'Chula Vista, California 91909',28044,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39394,91910,-8,'Chula Vista, California 91910',28044,34814);
INSERT INTO "django_geo_db_zipcode" VALUES(39395,91911,-8,'Chula Vista, California 91911',28044,34815);
INSERT INTO "django_geo_db_zipcode" VALUES(39396,91912,-8,'Chula Vista, California 91912',28044,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39397,91913,-8,'Chula Vista, California 91913',28044,34816);
INSERT INTO "django_geo_db_zipcode" VALUES(39398,91914,-8,'Chula Vista, California 91914',28044,34817);
INSERT INTO "django_geo_db_zipcode" VALUES(39399,91915,-8,'Chula Vista, California 91915',28044,34818);
INSERT INTO "django_geo_db_zipcode" VALUES(39400,91916,-8,'Descanso, California 91916',28045,34819);
INSERT INTO "django_geo_db_zipcode" VALUES(39401,91917,-8,'Dulzura, California 91917',28046,34820);
INSERT INTO "django_geo_db_zipcode" VALUES(39402,91921,-8,'Chula Vista, California 91921',28044,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39403,91927,-8,'La Presa, California 91927',28047,34821);
INSERT INTO "django_geo_db_zipcode" VALUES(39404,91931,-8,'Guatay, California 91931',28048,34822);
INSERT INTO "django_geo_db_zipcode" VALUES(39405,91932,-8,'Imperial Beach, California 91932',28049,34823);
INSERT INTO "django_geo_db_zipcode" VALUES(39406,91933,-8,'Imperial Beach, California 91933',28049,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39407,91934,-8,'Jacumba, California 91934',28050,34824);
INSERT INTO "django_geo_db_zipcode" VALUES(39408,91935,-8,'Jamul, California 91935',28051,34825);
INSERT INTO "django_geo_db_zipcode" VALUES(39409,91941,-8,'La Mesa, California 91941',28052,34826);
INSERT INTO "django_geo_db_zipcode" VALUES(39410,91942,-8,'La Mesa, California 91942',28052,34827);
INSERT INTO "django_geo_db_zipcode" VALUES(39411,91943,-8,'La Mesa, California 91943',28052,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39412,91944,-8,'La Mesa, California 91944',28052,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39413,91945,-8,'Lemon Grove, California 91945',28053,34828);
INSERT INTO "django_geo_db_zipcode" VALUES(39414,91946,-8,'Lemon Grove, California 91946',28053,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39415,91947,-8,'Lincoln Acres, California 91947',28054,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39416,91948,-8,'Mount Laguna, California 91948',28055,34829);
INSERT INTO "django_geo_db_zipcode" VALUES(39417,91950,-8,'National City, California 91950',28056,34830);
INSERT INTO "django_geo_db_zipcode" VALUES(39418,91951,-8,'National City, California 91951',28056,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39419,91962,-8,'Pine Valley, California 91962',28057,34831);
INSERT INTO "django_geo_db_zipcode" VALUES(39420,91963,-8,'Potrero, California 91963',28058,34832);
INSERT INTO "django_geo_db_zipcode" VALUES(39421,91976,-8,'Spring Valley, California 91976',28059,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39422,91977,-8,'Spring Valley, California 91977',28059,34833);
INSERT INTO "django_geo_db_zipcode" VALUES(39423,91978,-8,'Spring Valley, California 91978',28059,34834);
INSERT INTO "django_geo_db_zipcode" VALUES(39424,91979,-8,'Spring Valley, California 91979',28059,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39425,91980,-8,'Tecate, California 91980',28060,34835);
INSERT INTO "django_geo_db_zipcode" VALUES(39426,91987,-8,'Tecate, California 91987',28060,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39427,91990,-8,'Potrero, California 91990',28058,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39428,92002,-8,'Carlsbad, California 92002',28061,34836);
INSERT INTO "django_geo_db_zipcode" VALUES(39429,92003,-8,'Bonsall, California 92003',28062,34837);
INSERT INTO "django_geo_db_zipcode" VALUES(39430,92004,-8,'Borrego Springs, California 92004',28063,34838);
INSERT INTO "django_geo_db_zipcode" VALUES(39431,92007,-8,'Cardiff By The Sea, California 92007',28064,34839);
INSERT INTO "django_geo_db_zipcode" VALUES(39432,92008,-8,'Carlsbad, California 92008',28061,34840);
INSERT INTO "django_geo_db_zipcode" VALUES(39433,92009,-8,'Carlsbad, California 92009',28061,34841);
INSERT INTO "django_geo_db_zipcode" VALUES(39434,92013,-8,'Carlsbad, California 92013',28061,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39435,92014,-8,'Del Mar, California 92014',28065,34842);
INSERT INTO "django_geo_db_zipcode" VALUES(39436,92018,-8,'Carlsbad, California 92018',28061,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39437,92019,-8,'El Cajon, California 92019',28066,34843);
INSERT INTO "django_geo_db_zipcode" VALUES(39438,92020,-8,'El Cajon, California 92020',28066,34844);
INSERT INTO "django_geo_db_zipcode" VALUES(39439,92021,-8,'El Cajon, California 92021',28066,34845);
INSERT INTO "django_geo_db_zipcode" VALUES(39440,92022,-8,'El Cajon, California 92022',28066,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39441,92023,-8,'Encinitas, California 92023',28067,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39442,92024,-8,'Encinitas, California 92024',28067,34846);
INSERT INTO "django_geo_db_zipcode" VALUES(39443,92025,-8,'Escondido, California 92025',28068,34847);
INSERT INTO "django_geo_db_zipcode" VALUES(39444,92026,-8,'Escondido, California 92026',28068,34848);
INSERT INTO "django_geo_db_zipcode" VALUES(39445,92027,-8,'Escondido, California 92027',28068,34849);
INSERT INTO "django_geo_db_zipcode" VALUES(39446,92028,-8,'Fallbrook, California 92028',28069,34850);
INSERT INTO "django_geo_db_zipcode" VALUES(39447,92029,-8,'Escondido, California 92029',28068,34851);
INSERT INTO "django_geo_db_zipcode" VALUES(39448,92030,-8,'Escondido, California 92030',28068,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39449,92031,-8,'Adelanto, California 92031',28070,34852);
INSERT INTO "django_geo_db_zipcode" VALUES(39450,92033,-8,'Escondido, California 92033',28068,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39451,92036,-8,'Julian, California 92036',28071,34853);
INSERT INTO "django_geo_db_zipcode" VALUES(39452,92037,-8,'La Jolla, California 92037',28072,34854);
INSERT INTO "django_geo_db_zipcode" VALUES(39453,92038,-8,'La Jolla, California 92038',28072,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39454,92039,-8,'La Jolla, California 92039',28072,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39455,92040,-8,'Lakeside, California 92040',28073,34855);
INSERT INTO "django_geo_db_zipcode" VALUES(39456,92046,-8,'Escondido, California 92046',28068,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39457,92049,-8,'Oceanside, California 92049',28074,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39458,92051,-8,'Oceanside, California 92051',28074,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39459,92052,-8,'Oceanside, California 92052',28074,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39460,92054,-8,'Oceanside, California 92054',28074,34856);
INSERT INTO "django_geo_db_zipcode" VALUES(39461,92055,-8,'Camp Pendleton, California 92055',28075,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39462,92056,-8,'Oceanside, California 92056',28074,34857);
INSERT INTO "django_geo_db_zipcode" VALUES(39463,92057,-8,'Oceanside, California 92057',28074,34858);
INSERT INTO "django_geo_db_zipcode" VALUES(39464,92058,-8,'Oceanside, California 92058',28074,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39465,92059,-8,'Pala, California 92059',28076,34859);
INSERT INTO "django_geo_db_zipcode" VALUES(39466,92060,-8,'Palomar Mountain, California 92060',28077,34860);
INSERT INTO "django_geo_db_zipcode" VALUES(39467,92061,-8,'Pauma Valley, California 92061',28078,34861);
INSERT INTO "django_geo_db_zipcode" VALUES(39468,92064,-8,'Poway, California 92064',28079,34862);
INSERT INTO "django_geo_db_zipcode" VALUES(39469,92065,-8,'Ramona, California 92065',28080,34863);
INSERT INTO "django_geo_db_zipcode" VALUES(39470,92066,-8,'Ranchita, California 92066',28081,34864);
INSERT INTO "django_geo_db_zipcode" VALUES(39471,92067,-8,'Rancho Santa Fe, California 92067',28082,34865);
INSERT INTO "django_geo_db_zipcode" VALUES(39472,92068,-8,'San Luis Rey, California 92068',28083,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39473,92069,-8,'San Marcos, California 92069',28084,34866);
INSERT INTO "django_geo_db_zipcode" VALUES(39474,92070,-8,'Santa Ysabel, California 92070',28085,34867);
INSERT INTO "django_geo_db_zipcode" VALUES(39475,92071,-8,'Santee, California 92071',28086,34868);
INSERT INTO "django_geo_db_zipcode" VALUES(39476,92072,-8,'Santee, California 92072',28086,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39477,92074,-8,'Poway, California 92074',28079,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39478,92075,-8,'Solana Beach, California 92075',28087,34869);
INSERT INTO "django_geo_db_zipcode" VALUES(39479,92078,-8,'San Marcos, California 92078',28084,34870);
INSERT INTO "django_geo_db_zipcode" VALUES(39480,92079,-8,'San Marcos, California 92079',28084,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39481,92082,-8,'Valley Center, California 92082',28088,34871);
INSERT INTO "django_geo_db_zipcode" VALUES(39482,92083,-8,'Vista, California 92083',28089,34872);
INSERT INTO "django_geo_db_zipcode" VALUES(39483,92084,-8,'Vista, California 92084',28089,34873);
INSERT INTO "django_geo_db_zipcode" VALUES(39484,92085,-8,'Vista, California 92085',28089,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39485,92086,-8,'Warner Springs, California 92086',28090,34874);
INSERT INTO "django_geo_db_zipcode" VALUES(39486,92088,-8,'Fallbrook, California 92088',28069,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39487,92090,-8,'El Cajon, California 92090',28066,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39488,92091,-8,'Rancho Santa Fe, California 92091',28082,34875);
INSERT INTO "django_geo_db_zipcode" VALUES(39489,92092,-8,'La Jolla, California 92092',28072,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39490,92093,-8,'La Jolla, California 92093',28072,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39491,92096,-8,'San Marcos, California 92096',28084,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39492,92101,-8,'San Diego, California 92101',28091,34876);
INSERT INTO "django_geo_db_zipcode" VALUES(39493,92102,-8,'San Diego, California 92102',28091,34877);
INSERT INTO "django_geo_db_zipcode" VALUES(39494,92103,-8,'San Diego, California 92103',28091,34878);
INSERT INTO "django_geo_db_zipcode" VALUES(39495,92104,-8,'San Diego, California 92104',28091,34879);
INSERT INTO "django_geo_db_zipcode" VALUES(39496,92105,-8,'San Diego, California 92105',28091,34880);
INSERT INTO "django_geo_db_zipcode" VALUES(39497,92106,-8,'San Diego, California 92106',28091,34881);
INSERT INTO "django_geo_db_zipcode" VALUES(39498,92107,-8,'San Diego, California 92107',28091,34882);
INSERT INTO "django_geo_db_zipcode" VALUES(39499,92108,-8,'San Diego, California 92108',28091,34883);
INSERT INTO "django_geo_db_zipcode" VALUES(39500,92109,-8,'San Diego, California 92109',28091,34884);
INSERT INTO "django_geo_db_zipcode" VALUES(39501,92110,-8,'San Diego, California 92110',28091,34885);
INSERT INTO "django_geo_db_zipcode" VALUES(39502,92111,-8,'San Diego, California 92111',28091,34886);
INSERT INTO "django_geo_db_zipcode" VALUES(39503,92112,-8,'San Diego, California 92112',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39504,92113,-8,'San Diego, California 92113',28091,34887);
INSERT INTO "django_geo_db_zipcode" VALUES(39505,92114,-8,'San Diego, California 92114',28091,34888);
INSERT INTO "django_geo_db_zipcode" VALUES(39506,92115,-8,'San Diego, California 92115',28091,34889);
INSERT INTO "django_geo_db_zipcode" VALUES(39507,92116,-8,'San Diego, California 92116',28091,34890);
INSERT INTO "django_geo_db_zipcode" VALUES(39508,92117,-8,'San Diego, California 92117',28091,34891);
INSERT INTO "django_geo_db_zipcode" VALUES(39509,92118,-8,'Coronado, California 92118',28092,34892);
INSERT INTO "django_geo_db_zipcode" VALUES(39510,92119,-8,'San Diego, California 92119',28091,34893);
INSERT INTO "django_geo_db_zipcode" VALUES(39511,92120,-8,'San Diego, California 92120',28091,34894);
INSERT INTO "django_geo_db_zipcode" VALUES(39512,92121,-8,'San Diego, California 92121',28091,34895);
INSERT INTO "django_geo_db_zipcode" VALUES(39513,92122,-8,'San Diego, California 92122',28091,34896);
INSERT INTO "django_geo_db_zipcode" VALUES(39514,92123,-8,'San Diego, California 92123',28091,34897);
INSERT INTO "django_geo_db_zipcode" VALUES(39515,92124,-8,'San Diego, California 92124',28091,34898);
INSERT INTO "django_geo_db_zipcode" VALUES(39516,92126,-8,'San Diego, California 92126',28091,34899);
INSERT INTO "django_geo_db_zipcode" VALUES(39517,92127,-8,'San Diego, California 92127',28091,34900);
INSERT INTO "django_geo_db_zipcode" VALUES(39518,92128,-8,'San Diego, California 92128',28091,34901);
INSERT INTO "django_geo_db_zipcode" VALUES(39519,92129,-8,'San Diego, California 92129',28091,34902);
INSERT INTO "django_geo_db_zipcode" VALUES(39520,92130,-8,'San Diego, California 92130',28091,34903);
INSERT INTO "django_geo_db_zipcode" VALUES(39521,92131,-8,'San Diego, California 92131',28091,34904);
INSERT INTO "django_geo_db_zipcode" VALUES(39522,92132,-7,'San Diego, California 92132',28091,34905);
INSERT INTO "django_geo_db_zipcode" VALUES(39523,92133,-8,'San Diego, California 92133',28091,34906);
INSERT INTO "django_geo_db_zipcode" VALUES(39524,92134,-8,'San Diego, California 92134',28091,34907);
INSERT INTO "django_geo_db_zipcode" VALUES(39525,92135,-8,'San Diego, California 92135',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39526,92136,-8,'San Diego, California 92136',28091,34908);
INSERT INTO "django_geo_db_zipcode" VALUES(39527,92137,-8,'San Diego, California 92137',28091,34909);
INSERT INTO "django_geo_db_zipcode" VALUES(39528,92138,-8,'San Diego, California 92138',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39529,92139,-8,'San Diego, California 92139',28091,34910);
INSERT INTO "django_geo_db_zipcode" VALUES(39530,92140,-8,'San Diego, California 92140',28091,34911);
INSERT INTO "django_geo_db_zipcode" VALUES(39531,92142,-8,'San Diego, California 92142',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39532,92143,-8,'San Ysidro, California 92143',28093,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39533,92145,-8,'San Diego, California 92145',28091,34912);
INSERT INTO "django_geo_db_zipcode" VALUES(39534,92147,-8,'San Diego, California 92147',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39535,92149,-8,'San Diego, California 92149',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39536,92150,-8,'San Diego, California 92150',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39537,92152,-8,'San Diego, California 92152',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39538,92153,-8,'San Diego, California 92153',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39539,92154,-8,'San Diego, California 92154',28091,34913);
INSERT INTO "django_geo_db_zipcode" VALUES(39540,92155,-8,'San Diego, California 92155',28091,34914);
INSERT INTO "django_geo_db_zipcode" VALUES(39541,92158,-8,'San Diego, California 92158',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39542,92159,-8,'San Diego, California 92159',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39543,92160,-8,'San Diego, California 92160',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39544,92161,-8,'San Diego, California 92161',28091,34915);
INSERT INTO "django_geo_db_zipcode" VALUES(39545,92162,-8,'San Diego, California 92162',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39546,92163,-8,'San Diego, California 92163',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39547,92164,-8,'San Diego, California 92164',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39548,92165,-8,'San Diego, California 92165',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39549,92166,-8,'San Diego, California 92166',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39550,92167,-8,'San Diego, California 92167',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39551,92168,-8,'San Diego, California 92168',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39552,92169,-8,'San Diego, California 92169',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39553,92170,-8,'San Diego, California 92170',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39554,92171,-8,'San Diego, California 92171',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39555,92172,-8,'San Diego, California 92172',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39556,92173,-8,'San Ysidro, California 92173',28093,34916);
INSERT INTO "django_geo_db_zipcode" VALUES(39557,92174,-8,'San Diego, California 92174',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39558,92175,-8,'San Diego, California 92175',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39559,92176,-8,'San Diego, California 92176',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39560,92177,-8,'San Diego, California 92177',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39561,92178,-8,'Coronado, California 92178',28092,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39562,92179,-8,'San Diego, California 92179',28091,34917);
INSERT INTO "django_geo_db_zipcode" VALUES(39563,92182,-8,'San Diego, California 92182',28091,34918);
INSERT INTO "django_geo_db_zipcode" VALUES(39564,92184,-8,'San Diego, California 92184',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39565,92186,-8,'San Diego, California 92186',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39566,92187,-8,'San Diego, California 92187',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39567,92190,-8,'San Diego, California 92190',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39568,92191,-8,'San Diego, California 92191',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39569,92192,-8,'San Diego, California 92192',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39570,92193,-8,'San Diego, California 92193',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39571,92194,-8,'San Diego, California 92194',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39572,92195,-8,'San Diego, California 92195',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39573,92196,-8,'San Diego, California 92196',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39574,92197,-8,'San Diego, California 92197',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39575,92198,-8,'San Diego, California 92198',28091,34811);
INSERT INTO "django_geo_db_zipcode" VALUES(39576,92199,-8,'San Diego, California 92199',28091,34919);
INSERT INTO "django_geo_db_zipcode" VALUES(39577,92201,-8,'Indio, California 92201',28094,34920);
INSERT INTO "django_geo_db_zipcode" VALUES(39578,92202,-8,'Indio, California 92202',28094,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39579,92203,-8,'Indio, California 92203',28094,34921);
INSERT INTO "django_geo_db_zipcode" VALUES(39580,92210,-8,'Indian Wells, California 92210',28095,34922);
INSERT INTO "django_geo_db_zipcode" VALUES(39581,92211,-8,'Palm Desert, California 92211',28096,34923);
INSERT INTO "django_geo_db_zipcode" VALUES(39582,92220,-8,'Banning, California 92220',28097,34924);
INSERT INTO "django_geo_db_zipcode" VALUES(39583,92222,-8,'Bard, California 92222',28098,34925);
INSERT INTO "django_geo_db_zipcode" VALUES(39584,92223,-8,'Beaumont, California 92223',28099,34926);
INSERT INTO "django_geo_db_zipcode" VALUES(39585,92225,-8,'Blythe, California 92225',28100,34927);
INSERT INTO "django_geo_db_zipcode" VALUES(39586,92226,-8,'Blythe, California 92226',28100,34928);
INSERT INTO "django_geo_db_zipcode" VALUES(39587,92227,-8,'Brawley, California 92227',28101,34929);
INSERT INTO "django_geo_db_zipcode" VALUES(39588,92230,-8,'Cabazon, California 92230',28102,34930);
INSERT INTO "django_geo_db_zipcode" VALUES(39589,92231,-8,'Calexico, California 92231',28103,34931);
INSERT INTO "django_geo_db_zipcode" VALUES(39590,92232,-8,'Calexico, California 92232',28103,34932);
INSERT INTO "django_geo_db_zipcode" VALUES(39591,92233,-8,'Calipatria, California 92233',28104,34933);
INSERT INTO "django_geo_db_zipcode" VALUES(39592,92234,-8,'Cathedral City, California 92234',28105,34934);
INSERT INTO "django_geo_db_zipcode" VALUES(39593,92235,-8,'Cathedral City, California 92235',28105,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39594,92236,-8,'Coachella, California 92236',28106,34935);
INSERT INTO "django_geo_db_zipcode" VALUES(39595,92239,-8,'Desert Center, California 92239',28107,34936);
INSERT INTO "django_geo_db_zipcode" VALUES(39596,92240,-8,'Desert Hot Springs, California 92240',28108,34937);
INSERT INTO "django_geo_db_zipcode" VALUES(39597,92241,-8,'Desert Hot Springs, California 92241',28108,34938);
INSERT INTO "django_geo_db_zipcode" VALUES(39598,92242,-8,'Earp, California 92242',28109,34939);
INSERT INTO "django_geo_db_zipcode" VALUES(39599,92243,-8,'El Centro, California 92243',28110,34940);
INSERT INTO "django_geo_db_zipcode" VALUES(39600,92244,-8,'El Centro, California 92244',28110,34941);
INSERT INTO "django_geo_db_zipcode" VALUES(39601,92249,-8,'Heber, California 92249',28111,34942);
INSERT INTO "django_geo_db_zipcode" VALUES(39602,92250,-8,'Holtville, California 92250',28112,34943);
INSERT INTO "django_geo_db_zipcode" VALUES(39603,92251,-8,'Imperial, California 92251',28113,34944);
INSERT INTO "django_geo_db_zipcode" VALUES(39604,92252,-8,'Joshua Tree, California 92252',28114,34945);
INSERT INTO "django_geo_db_zipcode" VALUES(39605,92253,-8,'La Quinta, California 92253',28115,34946);
INSERT INTO "django_geo_db_zipcode" VALUES(39606,92254,-8,'Mecca, California 92254',28116,34947);
INSERT INTO "django_geo_db_zipcode" VALUES(39607,92255,-8,'Palm Desert, California 92255',28096,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39608,92256,-8,'Morongo Valley, California 92256',28117,34948);
INSERT INTO "django_geo_db_zipcode" VALUES(39609,92257,-8,'Niland, California 92257',28118,34949);
INSERT INTO "django_geo_db_zipcode" VALUES(39610,92258,-8,'North Palm Springs, California 92258',28119,34950);
INSERT INTO "django_geo_db_zipcode" VALUES(39611,92259,-8,'Ocotillo, California 92259',28120,34951);
INSERT INTO "django_geo_db_zipcode" VALUES(39612,92260,-8,'Palm Desert, California 92260',28096,34952);
INSERT INTO "django_geo_db_zipcode" VALUES(39613,92261,-8,'Palm Desert, California 92261',28096,34953);
INSERT INTO "django_geo_db_zipcode" VALUES(39614,92262,-8,'Palm Springs, California 92262',28121,34954);
INSERT INTO "django_geo_db_zipcode" VALUES(39615,92263,-8,'Palm Springs, California 92263',28121,34955);
INSERT INTO "django_geo_db_zipcode" VALUES(39616,92264,-8,'Palm Springs, California 92264',28121,34956);
INSERT INTO "django_geo_db_zipcode" VALUES(39617,92266,-8,'Palo Verde, California 92266',28122,34957);
INSERT INTO "django_geo_db_zipcode" VALUES(39618,92267,-8,'Parker Dam, California 92267',28123,34958);
INSERT INTO "django_geo_db_zipcode" VALUES(39619,92268,-8,'Pioneertown, California 92268',28124,34959);
INSERT INTO "django_geo_db_zipcode" VALUES(39620,92270,-8,'Rancho Mirage, California 92270',28125,34960);
INSERT INTO "django_geo_db_zipcode" VALUES(39621,92271,-8,'Rancho Mirage, California 92271',28125,34961);
INSERT INTO "django_geo_db_zipcode" VALUES(39622,92273,-8,'Seeley, California 92273',28126,34962);
INSERT INTO "django_geo_db_zipcode" VALUES(39623,92274,-8,'Thermal, California 92274',28127,34963);
INSERT INTO "django_geo_db_zipcode" VALUES(39624,92275,-8,'Salton City, California 92275',28128,34964);
INSERT INTO "django_geo_db_zipcode" VALUES(39625,92276,-8,'Thousand Palms, California 92276',28129,34965);
INSERT INTO "django_geo_db_zipcode" VALUES(39626,92277,-8,'Twentynine Palms, California 92277',28130,34966);
INSERT INTO "django_geo_db_zipcode" VALUES(39627,92278,-8,'Twentynine Palms, California 92278',28130,34967);
INSERT INTO "django_geo_db_zipcode" VALUES(39628,92280,-8,'Vidal, California 92280',28131,34968);
INSERT INTO "django_geo_db_zipcode" VALUES(39629,92281,-8,'Westmorland, California 92281',28132,34969);
INSERT INTO "django_geo_db_zipcode" VALUES(39630,92282,-8,'White Water, California 92282',28133,34970);
INSERT INTO "django_geo_db_zipcode" VALUES(39631,92283,-8,'Winterhaven, California 92283',28134,34971);
INSERT INTO "django_geo_db_zipcode" VALUES(39632,92284,-8,'Yucca Valley, California 92284',28135,34972);
INSERT INTO "django_geo_db_zipcode" VALUES(39633,92285,-8,'Landers, California 92285',28136,34973);
INSERT INTO "django_geo_db_zipcode" VALUES(39634,92286,-8,'Yucca Valley, California 92286',28135,34974);
INSERT INTO "django_geo_db_zipcode" VALUES(39635,92292,-8,'Palm Springs, California 92292',28121,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39636,92301,-8,'Adelanto, California 92301',28070,34975);
INSERT INTO "django_geo_db_zipcode" VALUES(39637,92304,-8,'Amboy, California 92304',28137,34976);
INSERT INTO "django_geo_db_zipcode" VALUES(39638,92305,-8,'Angelus Oaks, California 92305',28138,34977);
INSERT INTO "django_geo_db_zipcode" VALUES(39639,92307,-8,'Apple Valley, California 92307',28139,34978);
INSERT INTO "django_geo_db_zipcode" VALUES(39640,92308,-8,'Apple Valley, California 92308',28139,34979);
INSERT INTO "django_geo_db_zipcode" VALUES(39641,92309,-8,'Baker, California 92309',28140,34980);
INSERT INTO "django_geo_db_zipcode" VALUES(39642,92310,-8,'Fort Irwin, California 92310',28141,34981);
INSERT INTO "django_geo_db_zipcode" VALUES(39643,92311,-8,'Barstow, California 92311',28142,34982);
INSERT INTO "django_geo_db_zipcode" VALUES(39644,92312,-8,'Barstow, California 92312',28142,34983);
INSERT INTO "django_geo_db_zipcode" VALUES(39645,92313,-8,'Grand Terrace, California 92313',28143,34984);
INSERT INTO "django_geo_db_zipcode" VALUES(39646,92314,-8,'Big Bear City, California 92314',28144,34985);
INSERT INTO "django_geo_db_zipcode" VALUES(39647,92315,-8,'Big Bear Lake, California 92315',28145,34986);
INSERT INTO "django_geo_db_zipcode" VALUES(39648,92316,-8,'Bloomington, California 92316',28146,34987);
INSERT INTO "django_geo_db_zipcode" VALUES(39649,92317,-8,'Blue Jay, California 92317',28147,34988);
INSERT INTO "django_geo_db_zipcode" VALUES(39650,92318,-8,'Bryn Mawr, California 92318',28148,34989);
INSERT INTO "django_geo_db_zipcode" VALUES(39651,92320,-8,'Calimesa, California 92320',28149,34990);
INSERT INTO "django_geo_db_zipcode" VALUES(39652,92321,-8,'Cedar Glen, California 92321',28150,34991);
INSERT INTO "django_geo_db_zipcode" VALUES(39653,92322,-8,'Cedarpines Park, California 92322',28151,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39654,92323,-8,'Cima, California 92323',28152,34992);
INSERT INTO "django_geo_db_zipcode" VALUES(39655,92324,-8,'Colton, California 92324',28153,34993);
INSERT INTO "django_geo_db_zipcode" VALUES(39656,92325,-8,'Crestline, California 92325',28154,34994);
INSERT INTO "django_geo_db_zipcode" VALUES(39657,92326,-8,'Crest Park, California 92326',28155,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39658,92327,-8,'Daggett, California 92327',28156,34995);
INSERT INTO "django_geo_db_zipcode" VALUES(39659,92328,-8,'Death Valley, California 92328',28157,34996);
INSERT INTO "django_geo_db_zipcode" VALUES(39660,92329,-8,'Phelan, California 92329',28158,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39661,92332,-8,'Essex, California 92332',28159,34997);
INSERT INTO "django_geo_db_zipcode" VALUES(39662,92333,-8,'Fawnskin, California 92333',28160,34998);
INSERT INTO "django_geo_db_zipcode" VALUES(39663,92334,-8,'Fontana, California 92334',28161,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39664,92335,-8,'Fontana, California 92335',28161,34999);
INSERT INTO "django_geo_db_zipcode" VALUES(39665,92336,-8,'Fontana, California 92336',28161,35000);
INSERT INTO "django_geo_db_zipcode" VALUES(39666,92337,-8,'Fontana, California 92337',28161,35001);
INSERT INTO "django_geo_db_zipcode" VALUES(39667,92338,-8,'Ludlow, California 92338',28162,35002);
INSERT INTO "django_geo_db_zipcode" VALUES(39668,92339,-8,'Forest Falls, California 92339',28163,35003);
INSERT INTO "django_geo_db_zipcode" VALUES(39669,92340,-8,'Hesperia, California 92340',28164,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39670,92341,-8,'Green Valley Lake, California 92341',28165,35004);
INSERT INTO "django_geo_db_zipcode" VALUES(39671,92342,-8,'Helendale, California 92342',28166,35005);
INSERT INTO "django_geo_db_zipcode" VALUES(39672,92345,-8,'Hesperia, California 92345',28164,35006);
INSERT INTO "django_geo_db_zipcode" VALUES(39673,92346,-8,'Highland, California 92346',28167,35007);
INSERT INTO "django_geo_db_zipcode" VALUES(39674,92347,-8,'Hinkley, California 92347',28168,35008);
INSERT INTO "django_geo_db_zipcode" VALUES(39675,92350,-8,'Loma Linda, California 92350',28169,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39676,92352,-8,'Lake Arrowhead, California 92352',28170,35009);
INSERT INTO "django_geo_db_zipcode" VALUES(39677,92354,-8,'Loma Linda, California 92354',28169,35010);
INSERT INTO "django_geo_db_zipcode" VALUES(39678,92356,-8,'Lucerne Valley, California 92356',28171,35011);
INSERT INTO "django_geo_db_zipcode" VALUES(39679,92357,-8,'Loma Linda, California 92357',28169,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39680,92358,-8,'Lytle Creek, California 92358',28172,35012);
INSERT INTO "django_geo_db_zipcode" VALUES(39681,92359,-8,'Mentone, California 92359',28173,35013);
INSERT INTO "django_geo_db_zipcode" VALUES(39682,92363,-8,'Needles, California 92363',28174,35014);
INSERT INTO "django_geo_db_zipcode" VALUES(39683,92364,-8,'Nipton, California 92364',28175,35015);
INSERT INTO "django_geo_db_zipcode" VALUES(39684,92365,-8,'Newberry Springs, California 92365',28176,35016);
INSERT INTO "django_geo_db_zipcode" VALUES(39685,92366,-8,'Mountain Pass, California 92366',28177,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39686,92368,-8,'Oro Grande, California 92368',28178,35017);
INSERT INTO "django_geo_db_zipcode" VALUES(39687,92369,-8,'Patton, California 92369',28179,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39688,92371,-8,'Phelan, California 92371',28158,35018);
INSERT INTO "django_geo_db_zipcode" VALUES(39689,92372,-8,'Pinon Hills, California 92372',28180,35019);
INSERT INTO "django_geo_db_zipcode" VALUES(39690,92373,-8,'Redlands, California 92373',28181,35020);
INSERT INTO "django_geo_db_zipcode" VALUES(39691,92374,-8,'Redlands, California 92374',28181,35021);
INSERT INTO "django_geo_db_zipcode" VALUES(39692,92375,-8,'Redlands, California 92375',28181,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39693,92376,-8,'Rialto, California 92376',28182,35022);
INSERT INTO "django_geo_db_zipcode" VALUES(39694,92377,-8,'Rialto, California 92377',28182,35023);
INSERT INTO "django_geo_db_zipcode" VALUES(39695,92378,-8,'Rimforest, California 92378',28183,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39696,92382,-8,'Running Springs, California 92382',28184,35024);
INSERT INTO "django_geo_db_zipcode" VALUES(39697,92384,-8,'Shoshone, California 92384',28185,35025);
INSERT INTO "django_geo_db_zipcode" VALUES(39698,92385,-8,'Skyforest, California 92385',28186,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39699,92386,-8,'Sugarloaf, California 92386',28187,35026);
INSERT INTO "django_geo_db_zipcode" VALUES(39700,92389,-8,'Tecopa, California 92389',28188,35027);
INSERT INTO "django_geo_db_zipcode" VALUES(39701,92391,-8,'Twin Peaks, California 92391',28189,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39702,92392,-8,'Victorville, California 92392',28190,35028);
INSERT INTO "django_geo_db_zipcode" VALUES(39703,92393,-8,'Victorville, California 92393',28190,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39704,92394,-8,'Victorville, California 92394',28190,35029);
INSERT INTO "django_geo_db_zipcode" VALUES(39705,92396,-8,'Winchester, California 92396',28191,35030);
INSERT INTO "django_geo_db_zipcode" VALUES(39706,92397,-8,'Wrightwood, California 92397',28192,35031);
INSERT INTO "django_geo_db_zipcode" VALUES(39707,92398,-8,'Yermo, California 92398',28193,35032);
INSERT INTO "django_geo_db_zipcode" VALUES(39708,92399,-8,'Yucaipa, California 92399',28194,35033);
INSERT INTO "django_geo_db_zipcode" VALUES(39709,92401,-8,'San Bernardino, California 92401',28195,35034);
INSERT INTO "django_geo_db_zipcode" VALUES(39710,92402,-8,'San Bernardino, California 92402',28195,35035);
INSERT INTO "django_geo_db_zipcode" VALUES(39711,92403,-8,'San Bernardino, California 92403',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39712,92404,-8,'San Bernardino, California 92404',28195,35036);
INSERT INTO "django_geo_db_zipcode" VALUES(39713,92405,-8,'San Bernardino, California 92405',28195,35037);
INSERT INTO "django_geo_db_zipcode" VALUES(39714,92406,-8,'San Bernardino, California 92406',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39715,92407,-8,'San Bernardino, California 92407',28195,35038);
INSERT INTO "django_geo_db_zipcode" VALUES(39716,92408,-8,'San Bernardino, California 92408',28195,35039);
INSERT INTO "django_geo_db_zipcode" VALUES(39717,92410,-8,'San Bernardino, California 92410',28195,35040);
INSERT INTO "django_geo_db_zipcode" VALUES(39718,92411,-8,'San Bernardino, California 92411',28195,35041);
INSERT INTO "django_geo_db_zipcode" VALUES(39719,92412,-8,'San Bernardino, California 92412',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39720,92413,-8,'San Bernardino, California 92413',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39721,92414,-8,'San Bernardino, California 92414',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39722,92415,-8,'San Bernardino, California 92415',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39723,92416,-8,'San Bernardino, California 92416',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39724,92418,-8,'San Bernardino, California 92418',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39725,92420,-8,'San Bernardino, California 92420',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39726,92423,-8,'San Bernardino, California 92423',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39727,92424,-8,'San Bernardino, California 92424',28195,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(39728,92427,-8,'San Bernardino, California 92427',28195,35042);
INSERT INTO "django_geo_db_zipcode" VALUES(39729,92501,-8,'Riverside, California 92501',28196,35043);
INSERT INTO "django_geo_db_zipcode" VALUES(39730,92502,-8,'Riverside, California 92502',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39731,92503,-8,'Riverside, California 92503',28196,35044);
INSERT INTO "django_geo_db_zipcode" VALUES(39732,92504,-8,'Riverside, California 92504',28196,35045);
INSERT INTO "django_geo_db_zipcode" VALUES(39733,92505,-8,'Riverside, California 92505',28196,35046);
INSERT INTO "django_geo_db_zipcode" VALUES(39734,92506,-8,'Riverside, California 92506',28196,35047);
INSERT INTO "django_geo_db_zipcode" VALUES(39735,92507,-8,'Riverside, California 92507',28196,35048);
INSERT INTO "django_geo_db_zipcode" VALUES(39736,92508,-8,'Riverside, California 92508',28196,35049);
INSERT INTO "django_geo_db_zipcode" VALUES(39737,92509,-8,'Riverside, California 92509',28196,35050);
INSERT INTO "django_geo_db_zipcode" VALUES(39738,92513,-8,'Riverside, California 92513',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39739,92514,-8,'Riverside, California 92514',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39740,92515,-8,'Riverside, California 92515',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39741,92516,-8,'Riverside, California 92516',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39742,92517,-8,'Riverside, California 92517',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39743,92518,-8,'March Air Force Base, California 92518',28197,35051);
INSERT INTO "django_geo_db_zipcode" VALUES(39744,92519,-8,'Riverside, California 92519',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39745,92521,-8,'Riverside, California 92521',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39746,92522,-8,'Riverside, California 92522',28196,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39747,92530,-8,'Lake Elsinore, California 92530',28198,35052);
INSERT INTO "django_geo_db_zipcode" VALUES(39748,92531,-8,'Lake Elsinore, California 92531',28198,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39749,92532,-8,'Lake Elsinore, California 92532',28198,35053);
INSERT INTO "django_geo_db_zipcode" VALUES(39750,92536,-8,'Aguanga, California 92536',28199,35054);
INSERT INTO "django_geo_db_zipcode" VALUES(39751,92539,-8,'Anza, California 92539',28200,35055);
INSERT INTO "django_geo_db_zipcode" VALUES(39752,92543,-8,'Hemet, California 92543',28201,35056);
INSERT INTO "django_geo_db_zipcode" VALUES(39753,92544,-8,'Hemet, California 92544',28201,35057);
INSERT INTO "django_geo_db_zipcode" VALUES(39754,92545,-8,'Hemet, California 92545',28201,35058);
INSERT INTO "django_geo_db_zipcode" VALUES(39755,92546,-8,'Hemet, California 92546',28201,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39756,92548,-8,'Homeland, California 92548',28202,35059);
INSERT INTO "django_geo_db_zipcode" VALUES(39757,92549,-8,'Idyllwild, California 92549',28203,35060);
INSERT INTO "django_geo_db_zipcode" VALUES(39758,92551,-8,'Moreno Valley, California 92551',28204,35061);
INSERT INTO "django_geo_db_zipcode" VALUES(39759,92552,-8,'Moreno Valley, California 92552',28204,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39760,92553,-8,'Moreno Valley, California 92553',28204,35062);
INSERT INTO "django_geo_db_zipcode" VALUES(39761,92554,-8,'Moreno Valley, California 92554',28204,35063);
INSERT INTO "django_geo_db_zipcode" VALUES(39762,92555,-8,'Moreno Valley, California 92555',28204,35064);
INSERT INTO "django_geo_db_zipcode" VALUES(39763,92556,-8,'Moreno Valley, California 92556',28204,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39764,92557,-8,'Moreno Valley, California 92557',28204,35065);
INSERT INTO "django_geo_db_zipcode" VALUES(39765,92561,-8,'Mountain Center, California 92561',28205,35066);
INSERT INTO "django_geo_db_zipcode" VALUES(39766,92562,-8,'Murrieta, California 92562',28206,35067);
INSERT INTO "django_geo_db_zipcode" VALUES(39767,92563,-8,'Murrieta, California 92563',28206,35068);
INSERT INTO "django_geo_db_zipcode" VALUES(39768,92564,-8,'Murrieta, California 92564',28206,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39769,92567,-8,'Nuevo, California 92567',28207,35069);
INSERT INTO "django_geo_db_zipcode" VALUES(39770,92570,-8,'Perris, California 92570',28208,35070);
INSERT INTO "django_geo_db_zipcode" VALUES(39771,92571,-8,'Perris, California 92571',28208,35071);
INSERT INTO "django_geo_db_zipcode" VALUES(39772,92572,-8,'Perris, California 92572',28208,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39773,92581,-8,'San Jacinto, California 92581',28209,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39774,92582,-8,'San Jacinto, California 92582',28209,35072);
INSERT INTO "django_geo_db_zipcode" VALUES(39775,92583,-8,'San Jacinto, California 92583',28209,35073);
INSERT INTO "django_geo_db_zipcode" VALUES(39776,92584,-8,'Menifee, California 92584',28210,35074);
INSERT INTO "django_geo_db_zipcode" VALUES(39777,92585,-8,'Sun City, California 92585',28211,35075);
INSERT INTO "django_geo_db_zipcode" VALUES(39778,92586,-8,'Sun City, California 92586',28211,35076);
INSERT INTO "django_geo_db_zipcode" VALUES(39779,92587,-8,'Sun City, California 92587',28211,35077);
INSERT INTO "django_geo_db_zipcode" VALUES(39780,92589,-8,'Temecula, California 92589',28212,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39781,92590,-8,'Temecula, California 92590',28212,35078);
INSERT INTO "django_geo_db_zipcode" VALUES(39782,92591,-8,'Temecula, California 92591',28212,35079);
INSERT INTO "django_geo_db_zipcode" VALUES(39783,92592,-8,'Temecula, California 92592',28212,35080);
INSERT INTO "django_geo_db_zipcode" VALUES(39784,92593,-8,'Temecula, California 92593',28212,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39785,92595,-8,'Wildomar, California 92595',28213,35081);
INSERT INTO "django_geo_db_zipcode" VALUES(39786,92596,-8,'Winchester, California 92596',28191,35082);
INSERT INTO "django_geo_db_zipcode" VALUES(39787,92599,-8,'Perris, California 92599',28208,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39788,92602,-8,'Irvine, California 92602',28214,35083);
INSERT INTO "django_geo_db_zipcode" VALUES(39789,92603,-8,'Irvine, California 92603',28214,35084);
INSERT INTO "django_geo_db_zipcode" VALUES(39790,92604,-8,'Irvine, California 92604',28214,35085);
INSERT INTO "django_geo_db_zipcode" VALUES(39791,92605,-8,'Huntington Beach, California 92605',28215,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39792,92606,-8,'Irvine, California 92606',28214,35086);
INSERT INTO "django_geo_db_zipcode" VALUES(39793,92607,-8,'Laguna Niguel, California 92607',28216,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39794,92610,-8,'Foothill Ranch, California 92610',28217,35087);
INSERT INTO "django_geo_db_zipcode" VALUES(39795,92612,-8,'Irvine, California 92612',28214,35088);
INSERT INTO "django_geo_db_zipcode" VALUES(39796,92614,-8,'Irvine, California 92614',28214,35089);
INSERT INTO "django_geo_db_zipcode" VALUES(39797,92615,-8,'Huntington Beach, California 92615',28215,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39798,92616,-8,'Irvine, California 92616',28214,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39799,92618,-8,'Irvine, California 92618',28214,35090);
INSERT INTO "django_geo_db_zipcode" VALUES(39800,92619,-8,'Irvine, California 92619',28214,35091);
INSERT INTO "django_geo_db_zipcode" VALUES(39801,92620,-8,'Irvine, California 92620',28214,35092);
INSERT INTO "django_geo_db_zipcode" VALUES(39802,92623,-8,'Irvine, California 92623',28214,35093);
INSERT INTO "django_geo_db_zipcode" VALUES(39803,92624,-8,'Capistrano Beach, California 92624',28218,35094);
INSERT INTO "django_geo_db_zipcode" VALUES(39804,92625,-8,'Corona Del Mar, California 92625',28219,35095);
INSERT INTO "django_geo_db_zipcode" VALUES(39805,92626,-8,'Costa Mesa, California 92626',28220,35096);
INSERT INTO "django_geo_db_zipcode" VALUES(39806,92627,-8,'Costa Mesa, California 92627',28220,35097);
INSERT INTO "django_geo_db_zipcode" VALUES(39807,92628,-8,'Costa Mesa, California 92628',28220,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39808,92629,-8,'Dana Point, California 92629',28221,35098);
INSERT INTO "django_geo_db_zipcode" VALUES(39809,92630,-8,'Lake Forest, California 92630',28222,35099);
INSERT INTO "django_geo_db_zipcode" VALUES(39810,92635,-8,'Laguna Hills, California 92635',28223,35100);
INSERT INTO "django_geo_db_zipcode" VALUES(39811,92646,-8,'Huntington Beach, California 92646',28215,35101);
INSERT INTO "django_geo_db_zipcode" VALUES(39812,92647,-8,'Huntington Beach, California 92647',28215,35102);
INSERT INTO "django_geo_db_zipcode" VALUES(39813,92648,-8,'Huntington Beach, California 92648',28215,35103);
INSERT INTO "django_geo_db_zipcode" VALUES(39814,92649,-8,'Huntington Beach, California 92649',28215,35104);
INSERT INTO "django_geo_db_zipcode" VALUES(39815,92650,-8,'East Irvine, California 92650',28224,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39816,92651,-8,'Laguna Beach, California 92651',28225,35105);
INSERT INTO "django_geo_db_zipcode" VALUES(39817,92652,-8,'Laguna Beach, California 92652',28225,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39818,92653,-8,'Laguna Hills, California 92653',28223,35106);
INSERT INTO "django_geo_db_zipcode" VALUES(39819,92654,-8,'Laguna Hills, California 92654',28223,35107);
INSERT INTO "django_geo_db_zipcode" VALUES(39820,92655,-8,'Midway City, California 92655',28226,35108);
INSERT INTO "django_geo_db_zipcode" VALUES(39821,92656,-8,'Aliso Viejo, California 92656',28227,35109);
INSERT INTO "django_geo_db_zipcode" VALUES(39822,92657,-8,'Newport Coast, California 92657',28228,35110);
INSERT INTO "django_geo_db_zipcode" VALUES(39823,92658,-8,'Newport Beach, California 92658',28229,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39824,92659,-8,'Newport Beach, California 92659',28229,35111);
INSERT INTO "django_geo_db_zipcode" VALUES(39825,92660,-8,'Newport Beach, California 92660',28229,35112);
INSERT INTO "django_geo_db_zipcode" VALUES(39826,92661,-8,'Newport Beach, California 92661',28229,35113);
INSERT INTO "django_geo_db_zipcode" VALUES(39827,92662,-7,'Newport Beach, California 92662',28229,35114);
INSERT INTO "django_geo_db_zipcode" VALUES(39828,92663,-8,'Newport Beach, California 92663',28229,35115);
INSERT INTO "django_geo_db_zipcode" VALUES(39829,92670,-8,'Placentia, California 92670',28230,35116);
INSERT INTO "django_geo_db_zipcode" VALUES(39830,92672,-8,'San Clemente, California 92672',28231,35117);
INSERT INTO "django_geo_db_zipcode" VALUES(39831,92673,-8,'San Clemente, California 92673',28231,35118);
INSERT INTO "django_geo_db_zipcode" VALUES(39832,92674,-8,'San Clemente, California 92674',28231,35119);
INSERT INTO "django_geo_db_zipcode" VALUES(39833,92675,-8,'San Juan Capistrano, California 92675',28232,35120);
INSERT INTO "django_geo_db_zipcode" VALUES(39834,92676,-8,'Silverado, California 92676',28233,35121);
INSERT INTO "django_geo_db_zipcode" VALUES(39835,92677,-8,'Laguna Niguel, California 92677',28216,35122);
INSERT INTO "django_geo_db_zipcode" VALUES(39836,92678,-8,'Trabuco Canyon, California 92678',28234,35123);
INSERT INTO "django_geo_db_zipcode" VALUES(39837,92679,-8,'Trabuco Canyon, California 92679',28234,35124);
INSERT INTO "django_geo_db_zipcode" VALUES(39838,92680,-8,'Garden Grove, California 92680',28235,35125);
INSERT INTO "django_geo_db_zipcode" VALUES(39839,92683,-8,'Westminster, California 92683',28236,35126);
INSERT INTO "django_geo_db_zipcode" VALUES(39840,92684,-8,'Westminster, California 92684',28236,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39841,92685,-8,'Westminster, California 92685',28236,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39842,92688,-8,'Rancho Santa Margarita, California 92688',28237,35127);
INSERT INTO "django_geo_db_zipcode" VALUES(39843,92690,-8,'Mission Viejo, California 92690',28238,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39844,92691,-8,'Mission Viejo, California 92691',28238,35128);
INSERT INTO "django_geo_db_zipcode" VALUES(39845,92692,-8,'Mission Viejo, California 92692',28238,35129);
INSERT INTO "django_geo_db_zipcode" VALUES(39846,92693,-8,'San Juan Capistrano, California 92693',28232,35130);
INSERT INTO "django_geo_db_zipcode" VALUES(39847,92694,-8,'Ladera Ranch, California 92694',28239,35131);
INSERT INTO "django_geo_db_zipcode" VALUES(39848,92697,-8,'Irvine, California 92697',28214,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39849,92698,-8,'Aliso Viejo, California 92698',28227,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39850,92701,-8,'Santa Ana, California 92701',28240,35132);
INSERT INTO "django_geo_db_zipcode" VALUES(39851,92702,-8,'Santa Ana, California 92702',28240,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39852,92703,-8,'Santa Ana, California 92703',28240,35133);
INSERT INTO "django_geo_db_zipcode" VALUES(39853,92704,-8,'Santa Ana, California 92704',28240,35134);
INSERT INTO "django_geo_db_zipcode" VALUES(39854,92705,-8,'Santa Ana, California 92705',28240,35135);
INSERT INTO "django_geo_db_zipcode" VALUES(39855,92706,-8,'Santa Ana, California 92706',28240,35136);
INSERT INTO "django_geo_db_zipcode" VALUES(39856,92707,-8,'Santa Ana, California 92707',28240,35137);
INSERT INTO "django_geo_db_zipcode" VALUES(39857,92708,-8,'Fountain Valley, California 92708',28241,35138);
INSERT INTO "django_geo_db_zipcode" VALUES(39858,92709,-8,'Irvine, California 92709',28214,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39859,92710,-8,'Irvine, California 92710',28214,35139);
INSERT INTO "django_geo_db_zipcode" VALUES(39860,92711,-8,'Santa Ana, California 92711',28240,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39861,92712,-8,'Santa Ana, California 92712',28240,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39862,92728,-8,'Fountain Valley, California 92728',28241,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39863,92735,-8,'Santa Ana, California 92735',28240,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39864,92780,-8,'Tustin, California 92780',28242,35140);
INSERT INTO "django_geo_db_zipcode" VALUES(39865,92781,-8,'Tustin, California 92781',28242,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39866,92782,-8,'Tustin, California 92782',28242,35141);
INSERT INTO "django_geo_db_zipcode" VALUES(39867,92799,-8,'Santa Ana, California 92799',28240,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39868,92801,-8,'Anaheim, California 92801',28243,35142);
INSERT INTO "django_geo_db_zipcode" VALUES(39869,92802,-8,'Anaheim, California 92802',28243,35143);
INSERT INTO "django_geo_db_zipcode" VALUES(39870,92803,-8,'Anaheim, California 92803',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39871,92804,-8,'Anaheim, California 92804',28243,35144);
INSERT INTO "django_geo_db_zipcode" VALUES(39872,92805,-8,'Anaheim, California 92805',28243,35145);
INSERT INTO "django_geo_db_zipcode" VALUES(39873,92806,-8,'Anaheim, California 92806',28243,35146);
INSERT INTO "django_geo_db_zipcode" VALUES(39874,92807,-8,'Anaheim, California 92807',28243,35147);
INSERT INTO "django_geo_db_zipcode" VALUES(39875,92808,-8,'Anaheim, California 92808',28243,35148);
INSERT INTO "django_geo_db_zipcode" VALUES(39876,92811,-8,'Atwood, California 92811',28244,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39877,92812,-8,'Anaheim, California 92812',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39878,92814,-8,'Anaheim, California 92814',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39879,92815,-8,'Anaheim, California 92815',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39880,92816,-8,'Anaheim, California 92816',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39881,92817,-8,'Anaheim, California 92817',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39882,92821,-8,'Brea, California 92821',28245,35149);
INSERT INTO "django_geo_db_zipcode" VALUES(39883,92822,-8,'Brea, California 92822',28245,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39884,92823,-8,'Brea, California 92823',28245,35150);
INSERT INTO "django_geo_db_zipcode" VALUES(39885,92825,-8,'Anaheim, California 92825',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39886,92831,-8,'Fullerton, California 92831',28246,35151);
INSERT INTO "django_geo_db_zipcode" VALUES(39887,92832,-8,'Fullerton, California 92832',28246,35152);
INSERT INTO "django_geo_db_zipcode" VALUES(39888,92833,-8,'Fullerton, California 92833',28246,35153);
INSERT INTO "django_geo_db_zipcode" VALUES(39889,92834,-8,'Fullerton, California 92834',28246,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39890,92835,-8,'Fullerton, California 92835',28246,35154);
INSERT INTO "django_geo_db_zipcode" VALUES(39891,92836,-8,'Fullerton, California 92836',28246,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39892,92837,-8,'Fullerton, California 92837',28246,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39893,92838,-8,'Fullerton, California 92838',28246,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39894,92840,-8,'Garden Grove, California 92840',28235,35155);
INSERT INTO "django_geo_db_zipcode" VALUES(39895,92841,-8,'Garden Grove, California 92841',28235,35156);
INSERT INTO "django_geo_db_zipcode" VALUES(39896,92842,-8,'Garden Grove, California 92842',28235,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39897,92843,-8,'Garden Grove, California 92843',28235,35157);
INSERT INTO "django_geo_db_zipcode" VALUES(39898,92844,-8,'Garden Grove, California 92844',28235,35158);
INSERT INTO "django_geo_db_zipcode" VALUES(39899,92845,-8,'Garden Grove, California 92845',28235,35159);
INSERT INTO "django_geo_db_zipcode" VALUES(39900,92846,-8,'Garden Grove, California 92846',28235,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39901,92850,-8,'Anaheim, California 92850',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39902,92856,-8,'Orange, California 92856',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39903,92857,-8,'Orange, California 92857',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39904,92859,-8,'Orange, California 92859',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39905,92860,-8,'Norco, California 92860',28028,35160);
INSERT INTO "django_geo_db_zipcode" VALUES(39906,92861,-8,'Villa Park, California 92861',28248,35161);
INSERT INTO "django_geo_db_zipcode" VALUES(39907,92862,-8,'Orange, California 92862',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39908,92863,-8,'Orange, California 92863',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39909,92864,-8,'Orange, California 92864',28247,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39910,92865,-8,'Orange, California 92865',28247,35162);
INSERT INTO "django_geo_db_zipcode" VALUES(39911,92866,-8,'Orange, California 92866',28247,35163);
INSERT INTO "django_geo_db_zipcode" VALUES(39912,92867,-8,'Orange, California 92867',28247,35164);
INSERT INTO "django_geo_db_zipcode" VALUES(39913,92868,-8,'Orange, California 92868',28247,35165);
INSERT INTO "django_geo_db_zipcode" VALUES(39914,92869,-8,'Orange, California 92869',28247,35166);
INSERT INTO "django_geo_db_zipcode" VALUES(39915,92870,-8,'Placentia, California 92870',28230,35167);
INSERT INTO "django_geo_db_zipcode" VALUES(39916,92871,-8,'Placentia, California 92871',28230,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39917,92877,-8,'Corona, California 92877',28013,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39918,92878,-8,'Corona, California 92878',28013,34765);
INSERT INTO "django_geo_db_zipcode" VALUES(39919,92879,-8,'Corona, California 92879',28013,35168);
INSERT INTO "django_geo_db_zipcode" VALUES(39920,92880,-8,'Corona, California 92880',28013,35169);
INSERT INTO "django_geo_db_zipcode" VALUES(39921,92881,-8,'Corona, California 92881',28013,35170);
INSERT INTO "django_geo_db_zipcode" VALUES(39922,92882,-8,'Corona, California 92882',28013,35171);
INSERT INTO "django_geo_db_zipcode" VALUES(39923,92883,-8,'Corona, California 92883',28013,35172);
INSERT INTO "django_geo_db_zipcode" VALUES(39924,92885,-8,'Yorba Linda, California 92885',28249,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39925,92886,-8,'Yorba Linda, California 92886',28249,35173);
INSERT INTO "django_geo_db_zipcode" VALUES(39926,92887,-8,'Yorba Linda, California 92887',28249,35174);
INSERT INTO "django_geo_db_zipcode" VALUES(39927,92899,-8,'Anaheim, California 92899',28243,34621);
INSERT INTO "django_geo_db_zipcode" VALUES(39928,93001,-8,'Ventura, California 93001',28250,35175);
INSERT INTO "django_geo_db_zipcode" VALUES(39929,93002,-8,'Ventura, California 93002',28250,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39930,93003,-8,'Ventura, California 93003',28250,35176);
INSERT INTO "django_geo_db_zipcode" VALUES(39931,93004,-8,'Ventura, California 93004',28250,35177);
INSERT INTO "django_geo_db_zipcode" VALUES(39932,93005,-8,'Ventura, California 93005',28250,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39933,93006,-8,'Ventura, California 93006',28250,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39934,93007,-8,'Ventura, California 93007',28250,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39935,93009,-8,'Ventura, California 93009',28250,35178);
INSERT INTO "django_geo_db_zipcode" VALUES(39936,93010,-8,'Camarillo, California 93010',28251,35179);
INSERT INTO "django_geo_db_zipcode" VALUES(39937,93011,-8,'Camarillo, California 93011',28251,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39938,93012,-8,'Camarillo, California 93012',28251,35180);
INSERT INTO "django_geo_db_zipcode" VALUES(39939,93013,-8,'Carpinteria, California 93013',28252,35181);
INSERT INTO "django_geo_db_zipcode" VALUES(39940,93014,-8,'Carpinteria, California 93014',28252,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39941,93015,-8,'Fillmore, California 93015',28253,35183);
INSERT INTO "django_geo_db_zipcode" VALUES(39942,93016,-8,'Fillmore, California 93016',28253,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39943,93020,-8,'Moorpark, California 93020',28254,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39944,93021,-8,'Moorpark, California 93021',28254,35184);
INSERT INTO "django_geo_db_zipcode" VALUES(39945,93022,-8,'Oak View, California 93022',28255,35185);
INSERT INTO "django_geo_db_zipcode" VALUES(39946,93023,-8,'Ojai, California 93023',28256,35186);
INSERT INTO "django_geo_db_zipcode" VALUES(39947,93024,-8,'Ojai, California 93024',28256,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39948,93030,-8,'Oxnard, California 93030',28257,35187);
INSERT INTO "django_geo_db_zipcode" VALUES(39949,93031,-8,'Oxnard, California 93031',28257,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39950,93032,-8,'Oxnard, California 93032',28257,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39951,93033,-8,'Oxnard, California 93033',28257,35188);
INSERT INTO "django_geo_db_zipcode" VALUES(39952,93034,-8,'Oxnard, California 93034',28257,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39953,93035,-8,'Oxnard, California 93035',28257,35189);
INSERT INTO "django_geo_db_zipcode" VALUES(39954,93036,-8,'Oxnard, California 93036',28257,35190);
INSERT INTO "django_geo_db_zipcode" VALUES(39955,93040,-8,'Piru, California 93040',28258,35191);
INSERT INTO "django_geo_db_zipcode" VALUES(39956,93041,-8,'Port Hueneme, California 93041',28259,35192);
INSERT INTO "django_geo_db_zipcode" VALUES(39957,93042,-8,'Point Mugu Nawc, California 93042',28260,35193);
INSERT INTO "django_geo_db_zipcode" VALUES(39958,93043,-8,'Port Hueneme Cbc Base, California 93043',28261,35194);
INSERT INTO "django_geo_db_zipcode" VALUES(39959,93044,-8,'Port Hueneme, California 93044',28259,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39960,93060,-8,'Santa Paula, California 93060',28262,35195);
INSERT INTO "django_geo_db_zipcode" VALUES(39961,93061,-8,'Santa Paula, California 93061',28262,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39962,93062,-8,'Simi Valley, California 93062',28263,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39963,93063,-8,'Simi Valley, California 93063',28263,35196);
INSERT INTO "django_geo_db_zipcode" VALUES(39964,93064,-8,'Brandeis, California 93064',28264,35197);
INSERT INTO "django_geo_db_zipcode" VALUES(39965,93065,-8,'Simi Valley, California 93065',28263,35198);
INSERT INTO "django_geo_db_zipcode" VALUES(39966,93066,-8,'Somis, California 93066',28265,35199);
INSERT INTO "django_geo_db_zipcode" VALUES(39967,93067,-8,'Summerland, California 93067',28266,35200);
INSERT INTO "django_geo_db_zipcode" VALUES(39968,93093,-8,'Simi Valley, California 93093',28263,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39969,93094,-8,'Simi Valley, California 93094',28263,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39970,93099,-8,'Simi Valley, California 93099',28263,34708);
INSERT INTO "django_geo_db_zipcode" VALUES(39971,93101,-8,'Santa Barbara, California 93101',28267,35201);
INSERT INTO "django_geo_db_zipcode" VALUES(39972,93102,-8,'Santa Barbara, California 93102',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39973,93103,-8,'Santa Barbara, California 93103',28267,35202);
INSERT INTO "django_geo_db_zipcode" VALUES(39974,93105,-8,'Santa Barbara, California 93105',28267,35203);
INSERT INTO "django_geo_db_zipcode" VALUES(39975,93106,-8,'Santa Barbara, California 93106',28267,35204);
INSERT INTO "django_geo_db_zipcode" VALUES(39976,93107,-8,'Santa Barbara, California 93107',28267,35205);
INSERT INTO "django_geo_db_zipcode" VALUES(39977,93108,-8,'Santa Barbara, California 93108',28267,35206);
INSERT INTO "django_geo_db_zipcode" VALUES(39978,93109,-8,'Santa Barbara, California 93109',28267,35207);
INSERT INTO "django_geo_db_zipcode" VALUES(39979,93110,-8,'Santa Barbara, California 93110',28267,35208);
INSERT INTO "django_geo_db_zipcode" VALUES(39980,93111,-8,'Santa Barbara, California 93111',28267,35209);
INSERT INTO "django_geo_db_zipcode" VALUES(39981,93116,-8,'Goleta, California 93116',28268,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39982,93117,-8,'Goleta, California 93117',28268,35210);
INSERT INTO "django_geo_db_zipcode" VALUES(39983,93118,-8,'Goleta, California 93118',28268,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39984,93120,-8,'Santa Barbara, California 93120',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39985,93121,-8,'Santa Barbara, California 93121',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39986,93130,-8,'Santa Barbara, California 93130',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39987,93140,-8,'Santa Barbara, California 93140',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39988,93150,-8,'Santa Barbara, California 93150',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39989,93160,-8,'Santa Barbara, California 93160',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39990,93190,-8,'Santa Barbara, California 93190',28267,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39991,93199,-8,'Goleta, California 93199',28268,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(39992,93201,-8,'Alpaugh, California 93201',28269,35211);
INSERT INTO "django_geo_db_zipcode" VALUES(39993,93202,-8,'Armona, California 93202',28270,35212);
INSERT INTO "django_geo_db_zipcode" VALUES(39994,93203,-8,'Arvin, California 93203',28271,35213);
INSERT INTO "django_geo_db_zipcode" VALUES(39995,93204,-8,'Avenal, California 93204',28272,35214);
INSERT INTO "django_geo_db_zipcode" VALUES(39996,93205,-8,'Bodfish, California 93205',28273,35215);
INSERT INTO "django_geo_db_zipcode" VALUES(39997,93206,-8,'Buttonwillow, California 93206',28274,35216);
INSERT INTO "django_geo_db_zipcode" VALUES(39998,93207,-8,'California Hot Springs, California 93207',28275,35217);
INSERT INTO "django_geo_db_zipcode" VALUES(39999,93208,-8,'Camp Nelson, California 93208',28276,35218);
INSERT INTO "django_geo_db_zipcode" VALUES(40000,93210,-8,'Coalinga, California 93210',28277,35219);
INSERT INTO "django_geo_db_zipcode" VALUES(40001,93212,-8,'Corcoran, California 93212',28278,35220);
INSERT INTO "django_geo_db_zipcode" VALUES(40002,93215,-8,'Delano, California 93215',28279,35221);
INSERT INTO "django_geo_db_zipcode" VALUES(40003,93216,-8,'Delano, California 93216',28279,35222);
INSERT INTO "django_geo_db_zipcode" VALUES(40004,93217,-8,'Earlimart, California 93217',28280,35223);
INSERT INTO "django_geo_db_zipcode" VALUES(40005,93218,-8,'Ducor, California 93218',28281,35224);
INSERT INTO "django_geo_db_zipcode" VALUES(40006,93219,-8,'Earlimart, California 93219',28280,35225);
INSERT INTO "django_geo_db_zipcode" VALUES(40007,93220,-8,'Edison, California 93220',28282,35226);
INSERT INTO "django_geo_db_zipcode" VALUES(40008,93221,-8,'Exeter, California 93221',28283,35227);
INSERT INTO "django_geo_db_zipcode" VALUES(40009,93222,-8,'Frazier Park, California 93222',28284,35228);
INSERT INTO "django_geo_db_zipcode" VALUES(40010,93223,-8,'Farmersville, California 93223',28285,35229);
INSERT INTO "django_geo_db_zipcode" VALUES(40011,93224,-8,'Fellows, California 93224',28286,35230);
INSERT INTO "django_geo_db_zipcode" VALUES(40012,93225,-8,'Frazier Park, California 93225',28284,35231);
INSERT INTO "django_geo_db_zipcode" VALUES(40013,93226,-8,'Glennville, California 93226',28287,35232);
INSERT INTO "django_geo_db_zipcode" VALUES(40014,93227,-8,'Goshen, California 93227',28288,35233);
INSERT INTO "django_geo_db_zipcode" VALUES(40015,93230,-8,'Hanford, California 93230',28289,35234);
INSERT INTO "django_geo_db_zipcode" VALUES(40016,93231,-8,'Hanford, California 93231',28289,35235);
INSERT INTO "django_geo_db_zipcode" VALUES(40017,93232,-8,'Hanford, California 93232',28289,35235);
INSERT INTO "django_geo_db_zipcode" VALUES(40018,93234,-8,'Huron, California 93234',28290,35236);
INSERT INTO "django_geo_db_zipcode" VALUES(40019,93235,-8,'Ivanhoe, California 93235',28291,35237);
INSERT INTO "django_geo_db_zipcode" VALUES(40020,93237,-8,'Kaweah, California 93237',28292,35238);
INSERT INTO "django_geo_db_zipcode" VALUES(40021,93238,-8,'Kernville, California 93238',28293,35239);
INSERT INTO "django_geo_db_zipcode" VALUES(40022,93239,-8,'Kettleman City, California 93239',28294,35240);
INSERT INTO "django_geo_db_zipcode" VALUES(40023,93240,-8,'Lake Isabella, California 93240',28295,35241);
INSERT INTO "django_geo_db_zipcode" VALUES(40024,93241,-8,'Lamont, California 93241',28296,35242);
INSERT INTO "django_geo_db_zipcode" VALUES(40025,93242,-8,'Laton, California 93242',28297,35243);
INSERT INTO "django_geo_db_zipcode" VALUES(40026,93243,-8,'Lebec, California 93243',28298,35244);
INSERT INTO "django_geo_db_zipcode" VALUES(40027,93244,-8,'Lemon Cove, California 93244',28299,35245);
INSERT INTO "django_geo_db_zipcode" VALUES(40028,93245,-8,'Lemoore, California 93245',28300,35246);
INSERT INTO "django_geo_db_zipcode" VALUES(40029,93246,-8,'Lemoore, California 93246',28300,35235);
INSERT INTO "django_geo_db_zipcode" VALUES(40030,93247,-8,'Lindsay, California 93247',28301,35247);
INSERT INTO "django_geo_db_zipcode" VALUES(40031,93249,-8,'Lost Hills, California 93249',28302,35248);
INSERT INTO "django_geo_db_zipcode" VALUES(40032,93250,-8,'McFarland, California 93250',28303,35249);
INSERT INTO "django_geo_db_zipcode" VALUES(40033,93251,-8,'McKittrick, California 93251',28304,35250);
INSERT INTO "django_geo_db_zipcode" VALUES(40034,93252,-8,'Maricopa, California 93252',28305,35251);
INSERT INTO "django_geo_db_zipcode" VALUES(40035,93254,-8,'New Cuyama, California 93254',28306,35252);
INSERT INTO "django_geo_db_zipcode" VALUES(40036,93255,-8,'Onyx, California 93255',28307,35253);
INSERT INTO "django_geo_db_zipcode" VALUES(40037,93256,-8,'Pixley, California 93256',28308,35254);
INSERT INTO "django_geo_db_zipcode" VALUES(40038,93257,-8,'Porterville, California 93257',28309,35255);
INSERT INTO "django_geo_db_zipcode" VALUES(40039,93258,-8,'Porterville, California 93258',28309,35256);
INSERT INTO "django_geo_db_zipcode" VALUES(40040,93260,-8,'Posey, California 93260',28310,35257);
INSERT INTO "django_geo_db_zipcode" VALUES(40041,93261,-8,'Richgrove, California 93261',28311,35258);
INSERT INTO "django_geo_db_zipcode" VALUES(40042,93262,-8,'Sequoia National Park, California 93262',28312,35259);
INSERT INTO "django_geo_db_zipcode" VALUES(40043,93263,-8,'Shafter, California 93263',28313,35260);
INSERT INTO "django_geo_db_zipcode" VALUES(40044,93265,-8,'Springville, California 93265',28314,35261);
INSERT INTO "django_geo_db_zipcode" VALUES(40045,93266,-8,'Stratford, California 93266',28315,35262);
INSERT INTO "django_geo_db_zipcode" VALUES(40046,93267,-8,'Strathmore, California 93267',28316,35263);
INSERT INTO "django_geo_db_zipcode" VALUES(40047,93268,-8,'Taft, California 93268',28317,35264);
INSERT INTO "django_geo_db_zipcode" VALUES(40048,93270,-8,'Terra Bella, California 93270',28318,35265);
INSERT INTO "django_geo_db_zipcode" VALUES(40049,93271,-8,'Three Rivers, California 93271',28319,35266);
INSERT INTO "django_geo_db_zipcode" VALUES(40050,93272,-8,'Tipton, California 93272',28320,35267);
INSERT INTO "django_geo_db_zipcode" VALUES(40051,93274,-8,'Tulare, California 93274',28321,35268);
INSERT INTO "django_geo_db_zipcode" VALUES(40052,93275,-8,'Tulare, California 93275',28321,35269);
INSERT INTO "django_geo_db_zipcode" VALUES(40053,93276,-8,'Tupman, California 93276',28322,35270);
INSERT INTO "django_geo_db_zipcode" VALUES(40054,93277,-8,'Visalia, California 93277',28323,35271);
INSERT INTO "django_geo_db_zipcode" VALUES(40055,93278,-8,'Visalia, California 93278',28323,35272);
INSERT INTO "django_geo_db_zipcode" VALUES(40056,93279,-8,'Visalia, California 93279',28323,35273);
INSERT INTO "django_geo_db_zipcode" VALUES(40057,93280,-8,'Wasco, California 93280',28324,35274);
INSERT INTO "django_geo_db_zipcode" VALUES(40058,93282,-8,'Waukena, California 93282',28325,35275);
INSERT INTO "django_geo_db_zipcode" VALUES(40059,93283,-8,'Weldon, California 93283',28326,35276);
INSERT INTO "django_geo_db_zipcode" VALUES(40060,93285,-8,'Wofford Heights, California 93285',28327,35277);
INSERT INTO "django_geo_db_zipcode" VALUES(40061,93286,-8,'Woodlake, California 93286',28328,35278);
INSERT INTO "django_geo_db_zipcode" VALUES(40062,93287,-8,'Woody, California 93287',28329,35279);
INSERT INTO "django_geo_db_zipcode" VALUES(40063,93291,-8,'Visalia, California 93291',28323,35280);
INSERT INTO "django_geo_db_zipcode" VALUES(40064,93292,-8,'Visalia, California 93292',28323,35281);
INSERT INTO "django_geo_db_zipcode" VALUES(40065,93301,-8,'Bakersfield, California 93301',28330,35282);
INSERT INTO "django_geo_db_zipcode" VALUES(40066,93302,-8,'Bakersfield, California 93302',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40067,93303,-8,'Bakersfield, California 93303',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40068,93304,-8,'Bakersfield, California 93304',28330,35284);
INSERT INTO "django_geo_db_zipcode" VALUES(40069,93305,-8,'Bakersfield, California 93305',28330,35285);
INSERT INTO "django_geo_db_zipcode" VALUES(40070,93306,-8,'Bakersfield, California 93306',28330,35286);
INSERT INTO "django_geo_db_zipcode" VALUES(40071,93307,-8,'Bakersfield, California 93307',28330,35287);
INSERT INTO "django_geo_db_zipcode" VALUES(40072,93308,-8,'Bakersfield, California 93308',28330,35288);
INSERT INTO "django_geo_db_zipcode" VALUES(40073,93309,-8,'Bakersfield, California 93309',28330,35289);
INSERT INTO "django_geo_db_zipcode" VALUES(40074,93311,-8,'Bakersfield, California 93311',28330,35290);
INSERT INTO "django_geo_db_zipcode" VALUES(40075,93312,-8,'Bakersfield, California 93312',28330,35291);
INSERT INTO "django_geo_db_zipcode" VALUES(40076,93313,-8,'Bakersfield, California 93313',28330,35292);
INSERT INTO "django_geo_db_zipcode" VALUES(40077,93325,-8,'Lake of the Woods, California 93325',28331,35293);
INSERT INTO "django_geo_db_zipcode" VALUES(40078,93380,-8,'Bakersfield, California 93380',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40079,93381,-8,'Bakersfield, California 93381',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40080,93382,-8,'Bakersfield, California 93382',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40081,93383,-8,'Bakersfield, California 93383',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40082,93384,-8,'Bakersfield, California 93384',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40083,93385,-8,'Bakersfield, California 93385',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40084,93386,-8,'Bakersfield, California 93386',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40085,93387,-8,'Bakersfield, California 93387',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40086,93388,-8,'Bakersfield, California 93388',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40087,93389,-8,'Bakersfield, California 93389',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40088,93390,-8,'Bakersfield, California 93390',28330,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40089,93401,-8,'San Luis Obispo, California 93401',28332,35294);
INSERT INTO "django_geo_db_zipcode" VALUES(40090,93402,-8,'Los Osos, California 93402',28333,35295);
INSERT INTO "django_geo_db_zipcode" VALUES(40091,93403,-8,'San Luis Obispo, California 93403',28332,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40092,93405,-8,'San Luis Obispo, California 93405',28332,35297);
INSERT INTO "django_geo_db_zipcode" VALUES(40093,93406,-8,'San Luis Obispo, California 93406',28332,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40094,93407,-8,'San Luis Obispo, California 93407',28332,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40095,93408,-8,'San Luis Obispo, California 93408',28332,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40096,93409,-8,'San Luis Obispo, California 93409',28332,35298);
INSERT INTO "django_geo_db_zipcode" VALUES(40097,93410,-8,'San Luis Obispo, California 93410',28332,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40098,93412,-8,'Los Osos, California 93412',28333,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40099,93420,-8,'Arroyo Grande, California 93420',28334,35299);
INSERT INTO "django_geo_db_zipcode" VALUES(40100,93421,-8,'Arroyo Grande, California 93421',28334,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40101,93422,-8,'Atascadero, California 93422',28335,35300);
INSERT INTO "django_geo_db_zipcode" VALUES(40102,93423,-8,'Atascadero, California 93423',28335,35301);
INSERT INTO "django_geo_db_zipcode" VALUES(40103,93424,-8,'Avila Beach, California 93424',28336,35302);
INSERT INTO "django_geo_db_zipcode" VALUES(40104,93426,-8,'Bradley, California 93426',28337,35303);
INSERT INTO "django_geo_db_zipcode" VALUES(40105,93427,-8,'Buellton, California 93427',28338,35304);
INSERT INTO "django_geo_db_zipcode" VALUES(40106,93428,-8,'Cambria, California 93428',28339,35305);
INSERT INTO "django_geo_db_zipcode" VALUES(40107,93429,-8,'Casmalia, California 93429',28340,35306);
INSERT INTO "django_geo_db_zipcode" VALUES(40108,93430,-8,'Cayucos, California 93430',28341,35307);
INSERT INTO "django_geo_db_zipcode" VALUES(40109,93432,-8,'Creston, California 93432',28342,35308);
INSERT INTO "django_geo_db_zipcode" VALUES(40110,93433,-8,'Grover Beach, California 93433',28343,35309);
INSERT INTO "django_geo_db_zipcode" VALUES(40111,93434,-8,'Guadalupe, California 93434',28344,35310);
INSERT INTO "django_geo_db_zipcode" VALUES(40112,93435,-8,'Harmony, California 93435',28345,35311);
INSERT INTO "django_geo_db_zipcode" VALUES(40113,93436,-8,'Lompoc, California 93436',28346,35312);
INSERT INTO "django_geo_db_zipcode" VALUES(40114,93437,-8,'Lompoc, California 93437',28346,35313);
INSERT INTO "django_geo_db_zipcode" VALUES(40115,93438,-8,'Lompoc, California 93438',28346,35182);
INSERT INTO "django_geo_db_zipcode" VALUES(40116,93440,-8,'Los Alamos, California 93440',28347,35314);
INSERT INTO "django_geo_db_zipcode" VALUES(40117,93441,-8,'Los Olivos, California 93441',28348,35315);
INSERT INTO "django_geo_db_zipcode" VALUES(40118,93442,-8,'Morro Bay, California 93442',28349,35316);
INSERT INTO "django_geo_db_zipcode" VALUES(40119,93443,-8,'Morro Bay, California 93443',28349,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40120,93444,-8,'Nipomo, California 93444',28350,35317);
INSERT INTO "django_geo_db_zipcode" VALUES(40121,93445,-8,'Oceano, California 93445',28351,35318);
INSERT INTO "django_geo_db_zipcode" VALUES(40122,93446,-8,'Paso Robles, California 93446',28352,35319);
INSERT INTO "django_geo_db_zipcode" VALUES(40123,93447,-8,'Paso Robles, California 93447',28352,35320);
INSERT INTO "django_geo_db_zipcode" VALUES(40124,93448,-8,'Pismo Beach, California 93448',28353,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40125,93449,-8,'Pismo Beach, California 93449',28353,35321);
INSERT INTO "django_geo_db_zipcode" VALUES(40126,93450,-8,'San Ardo, California 93450',28354,35322);
INSERT INTO "django_geo_db_zipcode" VALUES(40127,93451,-8,'San Miguel, California 93451',28355,35323);
INSERT INTO "django_geo_db_zipcode" VALUES(40128,93452,-8,'San Simeon, California 93452',28356,35324);
INSERT INTO "django_geo_db_zipcode" VALUES(40129,93453,-8,'Santa Margarita, California 93453',28357,35325);
INSERT INTO "django_geo_db_zipcode" VALUES(40130,93454,-8,'Santa Maria, California 93454',28358,35326);
INSERT INTO "django_geo_db_zipcode" VALUES(40131,93455,-8,'Santa Maria, California 93455',28358,35327);
INSERT INTO "django_geo_db_zipcode" VALUES(40132,93456,-8,'Santa Maria, California 93456',28358,35328);
INSERT INTO "django_geo_db_zipcode" VALUES(40133,93457,-8,'Santa Maria, California 93457',28358,35329);
INSERT INTO "django_geo_db_zipcode" VALUES(40134,93458,-8,'Santa Maria, California 93458',28358,35330);
INSERT INTO "django_geo_db_zipcode" VALUES(40135,93460,-8,'Santa Ynez, California 93460',28359,35331);
INSERT INTO "django_geo_db_zipcode" VALUES(40136,93461,-8,'Shandon, California 93461',28360,35332);
INSERT INTO "django_geo_db_zipcode" VALUES(40137,93463,-8,'Solvang, California 93463',28361,35333);
INSERT INTO "django_geo_db_zipcode" VALUES(40138,93464,-8,'Solvang, California 93464',28361,35334);
INSERT INTO "django_geo_db_zipcode" VALUES(40139,93465,-8,'Templeton, California 93465',28362,35335);
INSERT INTO "django_geo_db_zipcode" VALUES(40140,93483,-8,'Grover Beach, California 93483',28343,35296);
INSERT INTO "django_geo_db_zipcode" VALUES(40141,93492,-8,'Morro Bay, California 93492',28349,35336);
INSERT INTO "django_geo_db_zipcode" VALUES(40142,93501,-8,'Mojave, California 93501',28363,35337);
INSERT INTO "django_geo_db_zipcode" VALUES(40143,93502,-8,'Mojave, California 93502',28363,35338);
INSERT INTO "django_geo_db_zipcode" VALUES(40144,93504,-8,'California City, California 93504',28364,35339);
INSERT INTO "django_geo_db_zipcode" VALUES(40145,93505,-8,'California City, California 93505',28364,35340);
INSERT INTO "django_geo_db_zipcode" VALUES(40146,93510,-8,'Acton, California 93510',28365,35341);
INSERT INTO "django_geo_db_zipcode" VALUES(40147,93512,-8,'Benton, California 93512',28366,35342);
INSERT INTO "django_geo_db_zipcode" VALUES(40148,93513,-8,'Big Pine, California 93513',28367,35343);
INSERT INTO "django_geo_db_zipcode" VALUES(40149,93514,-8,'Bishop, California 93514',28368,35344);
INSERT INTO "django_geo_db_zipcode" VALUES(40150,93515,-8,'Bishop, California 93515',28368,35345);
INSERT INTO "django_geo_db_zipcode" VALUES(40151,93516,-8,'Boron, California 93516',28369,35346);
INSERT INTO "django_geo_db_zipcode" VALUES(40152,93517,-8,'Bridgeport, California 93517',28370,35347);
INSERT INTO "django_geo_db_zipcode" VALUES(40153,93518,-8,'Caliente, California 93518',28371,35348);
INSERT INTO "django_geo_db_zipcode" VALUES(40154,93519,-8,'Cantil, California 93519',28372,35349);
INSERT INTO "django_geo_db_zipcode" VALUES(40155,93522,-8,'Darwin, California 93522',28373,35350);
INSERT INTO "django_geo_db_zipcode" VALUES(40156,93523,-8,'Edwards, California 93523',28374,35351);
INSERT INTO "django_geo_db_zipcode" VALUES(40157,93524,-8,'Edwards, California 93524',28374,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40158,93526,-8,'Independence, California 93526',28375,35352);
INSERT INTO "django_geo_db_zipcode" VALUES(40159,93527,-8,'Inyokern, California 93527',28376,35353);
INSERT INTO "django_geo_db_zipcode" VALUES(40160,93528,-8,'Johannesburg, California 93528',28377,35354);
INSERT INTO "django_geo_db_zipcode" VALUES(40161,93529,-8,'June Lake, California 93529',28378,35355);
INSERT INTO "django_geo_db_zipcode" VALUES(40162,93530,-8,'Keeler, California 93530',28379,35356);
INSERT INTO "django_geo_db_zipcode" VALUES(40163,93531,-8,'Keene, California 93531',28380,35357);
INSERT INTO "django_geo_db_zipcode" VALUES(40164,93532,-8,'Lake Hughes, California 93532',28381,35358);
INSERT INTO "django_geo_db_zipcode" VALUES(40165,93534,-8,'Lancaster, California 93534',28382,35359);
INSERT INTO "django_geo_db_zipcode" VALUES(40166,93535,-8,'Lancaster, California 93535',28382,35360);
INSERT INTO "django_geo_db_zipcode" VALUES(40167,93536,-8,'Lancaster, California 93536',28382,35361);
INSERT INTO "django_geo_db_zipcode" VALUES(40168,93539,-8,'Lancaster, California 93539',28382,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(40169,93540,-8,'Lake Isabella, California 93540',28295,35362);
INSERT INTO "django_geo_db_zipcode" VALUES(40170,93541,-8,'Lee Vining, California 93541',28383,35363);
INSERT INTO "django_geo_db_zipcode" VALUES(40171,93542,-8,'Little Lake, California 93542',28384,35345);
INSERT INTO "django_geo_db_zipcode" VALUES(40172,93543,-8,'Littlerock, California 93543',28385,35364);
INSERT INTO "django_geo_db_zipcode" VALUES(40173,93544,-8,'Llano, California 93544',28386,35365);
INSERT INTO "django_geo_db_zipcode" VALUES(40174,93545,-8,'Lone Pine, California 93545',28387,35366);
INSERT INTO "django_geo_db_zipcode" VALUES(40175,93546,-8,'Mammoth Lakes, California 93546',28388,35367);
INSERT INTO "django_geo_db_zipcode" VALUES(40176,93549,-8,'Olancha, California 93549',28389,35368);
INSERT INTO "django_geo_db_zipcode" VALUES(40177,93550,-8,'Palmdale, California 93550',28390,35369);
INSERT INTO "django_geo_db_zipcode" VALUES(40178,93551,-8,'Palmdale, California 93551',28390,35370);
INSERT INTO "django_geo_db_zipcode" VALUES(40179,93552,-8,'Palmdale, California 93552',28390,35371);
INSERT INTO "django_geo_db_zipcode" VALUES(40180,93553,-8,'Pearblossom, California 93553',28391,35372);
INSERT INTO "django_geo_db_zipcode" VALUES(40181,93554,-8,'Randsburg, California 93554',28392,35373);
INSERT INTO "django_geo_db_zipcode" VALUES(40182,93555,-8,'Ridgecrest, California 93555',28393,35374);
INSERT INTO "django_geo_db_zipcode" VALUES(40183,93556,-8,'Ridgecrest, California 93556',28393,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40184,93558,-8,'Red Mountain, California 93558',28394,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(40185,93560,-8,'Rosamond, California 93560',28395,35375);
INSERT INTO "django_geo_db_zipcode" VALUES(40186,93561,-8,'Tehachapi, California 93561',28396,35376);
INSERT INTO "django_geo_db_zipcode" VALUES(40187,93562,-8,'Trona, California 93562',28397,35377);
INSERT INTO "django_geo_db_zipcode" VALUES(40188,93563,-8,'Valyermo, California 93563',28398,35378);
INSERT INTO "django_geo_db_zipcode" VALUES(40189,93564,-8,'Rosamond, California 93564',28395,35379);
INSERT INTO "django_geo_db_zipcode" VALUES(40190,93581,-8,'Tehachapi, California 93581',28396,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40191,93584,-8,'Lancaster, California 93584',28382,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(40192,93586,-8,'Lancaster, California 93586',28382,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(40193,93590,-8,'Palmdale, California 93590',28390,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(40194,93591,-8,'Palmdale, California 93591',28390,35380);
INSERT INTO "django_geo_db_zipcode" VALUES(40195,93592,-8,'Trona, California 93592',28397,34761);
INSERT INTO "django_geo_db_zipcode" VALUES(40196,93596,-8,'Boron, California 93596',28369,35283);
INSERT INTO "django_geo_db_zipcode" VALUES(40197,93599,-8,'Palmdale, California 93599',28390,34504);
INSERT INTO "django_geo_db_zipcode" VALUES(40198,93601,-8,'Ahwahnee, California 93601',28399,35381);
INSERT INTO "django_geo_db_zipcode" VALUES(40199,93602,-8,'Auberry, California 93602',28400,35382);
INSERT INTO "django_geo_db_zipcode" VALUES(40200,93603,-8,'Badger, California 93603',28401,35383);
INSERT INTO "django_geo_db_zipcode" VALUES(40201,93604,-8,'Bass Lake, California 93604',28402,35384);
INSERT INTO "django_geo_db_zipcode" VALUES(40202,93605,-8,'Big Creek, California 93605',28403,35385);
INSERT INTO "django_geo_db_zipcode" VALUES(40203,93606,-8,'Biola, California 93606',28404,35386);
INSERT INTO "django_geo_db_zipcode" VALUES(40204,93607,-8,'Burrel, California 93607',28405,35387);
INSERT INTO "django_geo_db_zipcode" VALUES(40205,93608,-8,'Cantua Creek, California 93608',28406,35388);
INSERT INTO "django_geo_db_zipcode" VALUES(40206,93609,-8,'Caruthers, California 93609',28407,35389);
INSERT INTO "django_geo_db_zipcode" VALUES(40207,93610,-8,'Chowchilla, California 93610',28408,35390);
INSERT INTO "django_geo_db_zipcode" VALUES(40208,93611,-8,'Clovis, California 93611',28409,35391);
INSERT INTO "django_geo_db_zipcode" VALUES(40209,93612,-8,'Clovis, California 93612',28409,35392);
INSERT INTO "django_geo_db_zipcode" VALUES(40210,93613,-8,'Clovis, California 93613',28409,35393);
INSERT INTO "django_geo_db_zipcode" VALUES(40211,93614,-8,'Coarsegold, California 93614',28410,35394);
INSERT INTO "django_geo_db_zipcode" VALUES(40212,93615,-8,'Cutler, California 93615',28411,35395);
INSERT INTO "django_geo_db_zipcode" VALUES(40213,93616,-8,'Del Rey, California 93616',28412,35396);
INSERT INTO "django_geo_db_zipcode" VALUES(40214,93618,-8,'Dinuba, California 93618',28413,35397);
INSERT INTO "django_geo_db_zipcode" VALUES(40215,93620,-8,'Dos Palos, California 93620',28414,35398);
INSERT INTO "django_geo_db_zipcode" VALUES(40216,93621,-8,'Dunlap, California 93621',28415,35399);
INSERT INTO "django_geo_db_zipcode" VALUES(40217,93622,-8,'Firebaugh, California 93622',28416,35400);
INSERT INTO "django_geo_db_zipcode" VALUES(40218,93623,-8,'Fish Camp, California 93623',28417,35401);
INSERT INTO "django_geo_db_zipcode" VALUES(40219,93624,-8,'Five Points, California 93624',28418,35402);
INSERT INTO "django_geo_db_zipcode" VALUES(40220,93625,-8,'Fowler, California 93625',28419,35403);
INSERT INTO "django_geo_db_zipcode" VALUES(40221,93626,-8,'Friant, California 93626',28420,35404);
INSERT INTO "django_geo_db_zipcode" VALUES(40222,93627,-8,'Helm, California 93627',28421,35405);
INSERT INTO "django_geo_db_zipcode" VALUES(40223,93628,-8,'Hume, California 93628',28422,35406);
INSERT INTO "django_geo_db_zipcode" VALUES(40224,93630,-8,'Kerman, California 93630',28423,35407);
INSERT INTO "django_geo_db_zipcode" VALUES(40225,93631,-8,'Kingsburg, California 93631',28424,35408);
INSERT INTO "django_geo_db_zipcode" VALUES(40226,93633,-8,'Kings Canyon National Pk, California 93633',28425,35409);
INSERT INTO "django_geo_db_zipcode" VALUES(40227,93634,-8,'Lakeshore, California 93634',28426,35410);
INSERT INTO "django_geo_db_zipcode" VALUES(40228,93635,-8,'Los Banos, California 93635',28427,35411);
INSERT INTO "django_geo_db_zipcode" VALUES(40229,93637,-8,'Madera, California 93637',28428,35412);
INSERT INTO "django_geo_db_zipcode" VALUES(40230,93638,-8,'Madera, California 93638',28428,35413);
INSERT INTO "django_geo_db_zipcode" VALUES(40231,93639,-8,'Madera, California 93639',28428,35414);
INSERT INTO "django_geo_db_zipcode" VALUES(40232,93640,-8,'Mendota, California 93640',28429,35415);
INSERT INTO "django_geo_db_zipcode" VALUES(40233,93641,-8,'Miramonte, California 93641',28430,35416);
INSERT INTO "django_geo_db_zipcode" VALUES(40234,93642,-8,'Mono Hot Springs, California 93642',28431,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40235,93643,-8,'North Fork, California 93643',28432,35418);
INSERT INTO "django_geo_db_zipcode" VALUES(40236,93644,-8,'Oakhurst, California 93644',28433,35419);
INSERT INTO "django_geo_db_zipcode" VALUES(40237,93645,-8,'O Neals, California 93645',28434,35420);
INSERT INTO "django_geo_db_zipcode" VALUES(40238,93646,-8,'Orange Cove, California 93646',28435,35421);
INSERT INTO "django_geo_db_zipcode" VALUES(40239,93647,-8,'Orosi, California 93647',28436,35422);
INSERT INTO "django_geo_db_zipcode" VALUES(40240,93648,-8,'Parlier, California 93648',28437,35423);
INSERT INTO "django_geo_db_zipcode" VALUES(40241,93649,-8,'Piedra, California 93649',28438,35424);
INSERT INTO "django_geo_db_zipcode" VALUES(40242,93650,-8,'Fresno, California 93650',28439,35425);
INSERT INTO "django_geo_db_zipcode" VALUES(40243,93651,-8,'Prather, California 93651',28440,35426);
INSERT INTO "django_geo_db_zipcode" VALUES(40244,93652,-8,'Raisin, California 93652',28441,35427);
INSERT INTO "django_geo_db_zipcode" VALUES(40245,93653,-8,'Raymond, California 93653',28442,35428);
INSERT INTO "django_geo_db_zipcode" VALUES(40246,93654,-8,'Reedley, California 93654',28443,35429);
INSERT INTO "django_geo_db_zipcode" VALUES(40247,93656,-8,'Riverdale, California 93656',28444,35430);
INSERT INTO "django_geo_db_zipcode" VALUES(40248,93657,-8,'Sanger, California 93657',28445,35431);
INSERT INTO "django_geo_db_zipcode" VALUES(40249,93660,-8,'San Joaquin, California 93660',28446,35432);
INSERT INTO "django_geo_db_zipcode" VALUES(40250,93661,-8,'Santa Rita Park, California 93661',28447,35433);
INSERT INTO "django_geo_db_zipcode" VALUES(40251,93662,-8,'Selma, California 93662',28448,35434);
INSERT INTO "django_geo_db_zipcode" VALUES(40252,93664,-8,'Shaver Lake, California 93664',28449,35435);
INSERT INTO "django_geo_db_zipcode" VALUES(40253,93665,-8,'South Dos Palos, California 93665',28450,35436);
INSERT INTO "django_geo_db_zipcode" VALUES(40254,93666,-8,'Sultana, California 93666',28451,35437);
INSERT INTO "django_geo_db_zipcode" VALUES(40255,93667,-8,'Tollhouse, California 93667',28452,35438);
INSERT INTO "django_geo_db_zipcode" VALUES(40256,93668,-8,'Tranquillity, California 93668',28453,35439);
INSERT INTO "django_geo_db_zipcode" VALUES(40257,93669,-8,'Wishon, California 93669',28454,35440);
INSERT INTO "django_geo_db_zipcode" VALUES(40258,93670,-8,'Yettem, California 93670',28455,35441);
INSERT INTO "django_geo_db_zipcode" VALUES(40259,93673,-8,'Traver, California 93673',28456,35442);
INSERT INTO "django_geo_db_zipcode" VALUES(40260,93675,-8,'Squaw Valley, California 93675',28457,35443);
INSERT INTO "django_geo_db_zipcode" VALUES(40261,93688,-8,'Tranquillity, California 93688',28453,35444);
INSERT INTO "django_geo_db_zipcode" VALUES(40262,93701,-8,'Fresno, California 93701',28439,35445);
INSERT INTO "django_geo_db_zipcode" VALUES(40263,93702,-8,'Fresno, California 93702',28439,35446);
INSERT INTO "django_geo_db_zipcode" VALUES(40264,93703,-8,'Fresno, California 93703',28439,35447);
INSERT INTO "django_geo_db_zipcode" VALUES(40265,93704,-8,'Fresno, California 93704',28439,35448);
INSERT INTO "django_geo_db_zipcode" VALUES(40266,93705,-8,'Fresno, California 93705',28439,35449);
INSERT INTO "django_geo_db_zipcode" VALUES(40267,93706,-8,'Fresno, California 93706',28439,35450);
INSERT INTO "django_geo_db_zipcode" VALUES(40268,93707,-8,'Fresno, California 93707',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40269,93708,-8,'Fresno, California 93708',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40270,93709,-8,'Fresno, California 93709',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40271,93710,-8,'Fresno, California 93710',28439,35451);
INSERT INTO "django_geo_db_zipcode" VALUES(40272,93711,-8,'Fresno, California 93711',28439,35452);
INSERT INTO "django_geo_db_zipcode" VALUES(40273,93712,-8,'Fresno, California 93712',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40274,93714,-8,'Fresno, California 93714',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40275,93715,-8,'Fresno, California 93715',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40276,93716,-8,'Fresno, California 93716',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40277,93717,-8,'Fresno, California 93717',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40278,93718,-8,'Fresno, California 93718',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40279,93720,-8,'Fresno, California 93720',28439,35453);
INSERT INTO "django_geo_db_zipcode" VALUES(40280,93721,-8,'Fresno, California 93721',28439,35454);
INSERT INTO "django_geo_db_zipcode" VALUES(40281,93722,-8,'Fresno, California 93722',28439,35455);
INSERT INTO "django_geo_db_zipcode" VALUES(40282,93724,-8,'Fresno, California 93724',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40283,93725,-8,'Fresno, California 93725',28439,35456);
INSERT INTO "django_geo_db_zipcode" VALUES(40284,93726,-8,'Fresno, California 93726',28439,35457);
INSERT INTO "django_geo_db_zipcode" VALUES(40285,93727,-8,'Fresno, California 93727',28439,35458);
INSERT INTO "django_geo_db_zipcode" VALUES(40286,93728,-8,'Fresno, California 93728',28439,35459);
INSERT INTO "django_geo_db_zipcode" VALUES(40287,93729,-8,'Fresno, California 93729',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40288,93740,-8,'Fresno, California 93740',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40289,93741,-8,'Fresno, California 93741',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40290,93744,-8,'Fresno, California 93744',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40291,93745,-8,'Fresno, California 93745',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40292,93747,-8,'Fresno, California 93747',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40293,93750,-8,'Fresno, California 93750',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40294,93755,-8,'Fresno, California 93755',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40295,93759,-8,'Fresno, California 93759',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40296,93760,-8,'Fresno, California 93760',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40297,93761,-8,'Fresno, California 93761',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40298,93762,-8,'Fresno, California 93762',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40299,93764,-8,'Fresno, California 93764',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40300,93765,-8,'Fresno, California 93765',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40301,93771,-8,'Fresno, California 93771',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40302,93772,-8,'Fresno, California 93772',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40303,93773,-8,'Fresno, California 93773',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40304,93774,-8,'Fresno, California 93774',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40305,93775,-8,'Fresno, California 93775',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40306,93776,-8,'Fresno, California 93776',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40307,93777,-8,'Fresno, California 93777',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40308,93778,-8,'Fresno, California 93778',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40309,93779,-8,'Fresno, California 93779',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40310,93780,-8,'Fresno, California 93780',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40311,93782,-8,'Fresno, California 93782',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40312,93784,-8,'Fresno, California 93784',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40313,93786,-8,'Fresno, California 93786',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40314,93790,-8,'Fresno, California 93790',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40315,93791,-8,'Fresno, California 93791',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40316,93792,-8,'Fresno, California 93792',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40317,93793,-8,'Fresno, California 93793',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40318,93794,-8,'Fresno, California 93794',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40319,93825,-8,'Wofford Heights, California 93825',28327,35460);
INSERT INTO "django_geo_db_zipcode" VALUES(40320,93844,-8,'Fresno, California 93844',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40321,93888,-8,'Fresno, California 93888',28439,35417);
INSERT INTO "django_geo_db_zipcode" VALUES(40322,93901,-8,'Salinas, California 93901',28458,35461);
INSERT INTO "django_geo_db_zipcode" VALUES(40323,93902,-8,'Salinas, California 93902',28458,35462);
INSERT INTO "django_geo_db_zipcode" VALUES(40324,93905,-8,'Salinas, California 93905',28458,35463);
INSERT INTO "django_geo_db_zipcode" VALUES(40325,93906,-8,'Salinas, California 93906',28458,35464);
INSERT INTO "django_geo_db_zipcode" VALUES(40326,93907,-8,'Salinas, California 93907',28458,35465);
INSERT INTO "django_geo_db_zipcode" VALUES(40327,93908,-8,'Salinas, California 93908',28458,35466);
INSERT INTO "django_geo_db_zipcode" VALUES(40328,93912,-8,'Salinas, California 93912',28458,35462);
INSERT INTO "django_geo_db_zipcode" VALUES(40329,93915,-8,'Salinas, California 93915',28458,35462);
INSERT INTO "django_geo_db_zipcode" VALUES(40330,93920,-8,'Big Sur, California 93920',28459,35467);
INSERT INTO "django_geo_db_zipcode" VALUES(40331,93921,-8,'Carmel, California 93921',28460,35468);
INSERT INTO "django_geo_db_zipcode" VALUES(40332,93922,-8,'Carmel, California 93922',28460,35469);
INSERT INTO "django_geo_db_zipcode" VALUES(40333,93923,-8,'Carmel, California 93923',28460,35470);
INSERT INTO "django_geo_db_zipcode" VALUES(40334,93924,-8,'Carmel Valley, California 93924',28461,35471);
INSERT INTO "django_geo_db_zipcode" VALUES(40335,93925,-8,'Chualar, California 93925',28462,35472);
INSERT INTO "django_geo_db_zipcode" VALUES(40336,93926,-8,'Gonzales, California 93926',28463,35473);
INSERT INTO "django_geo_db_zipcode" VALUES(40337,93927,-8,'Greenfield, California 93927',28464,35474);
INSERT INTO "django_geo_db_zipcode" VALUES(40338,93928,-8,'Jolon, California 93928',28465,35475);
INSERT INTO "django_geo_db_zipcode" VALUES(40339,93930,-8,'King City, California 93930',28466,35476);
INSERT INTO "django_geo_db_zipcode" VALUES(40340,93932,-8,'Lockwood, California 93932',28467,35477);
INSERT INTO "django_geo_db_zipcode" VALUES(40341,93933,-8,'Marina, California 93933',28468,35478);
INSERT INTO "django_geo_db_zipcode" VALUES(40342,93940,-8,'Monterey, California 93940',28469,35479);
INSERT INTO "django_geo_db_zipcode" VALUES(40343,93942,-8,'Monterey, California 93942',28469,35462);
INSERT INTO "django_geo_db_zipcode" VALUES(40344,93943,-8,'Monterey, California 93943',28469,35462);
INSERT INTO "django_geo_db_zipcode" VALUES(40345,93944,-8,'Monterey, California 93944',28469,35480);
INSERT INTO "django_geo_db_zipcode" VALUES(40346,93950,-8,'Pacific Grove, California 93950',28470,35481);
INSERT INTO "django_geo_db_zipcode" VALUES(40347,93953,-8,'Pebble Beach, California 93953',28471,35482);
INSERT INTO "django_geo_db_zipcode" VALUES(40348,93954,-8,'San Lucas, California 93954',28472,35483);
INSERT INTO "django_geo_db_zipcode" VALUES(40349,93955,-8,'Seaside, California 93955',28473,35484);
INSERT INTO "django_geo_db_zipcode" VALUES(40350,93960,-8,'Soledad, California 93960',28474,35485);
INSERT INTO "django_geo_db_zipcode" VALUES(40351,93962,-8,'Spreckels, California 93962',28475,35486);
INSERT INTO "django_geo_db_zipcode" VALUES(40352,94002,-8,'Belmont, California 94002',28476,35487);
INSERT INTO "django_geo_db_zipcode" VALUES(40353,94003,-8,'Belmont, California 94003',28476,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40354,94005,-8,'Brisbane, California 94005',28477,35489);
INSERT INTO "django_geo_db_zipcode" VALUES(40355,94010,-8,'Burlingame, California 94010',28478,35490);
INSERT INTO "django_geo_db_zipcode" VALUES(40356,94011,-8,'Burlingame, California 94011',28478,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40357,94012,-8,'Burlingame, California 94012',28478,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40358,94014,-8,'Daly City, California 94014',28479,35491);
INSERT INTO "django_geo_db_zipcode" VALUES(40359,94015,-8,'Daly City, California 94015',28479,35492);
INSERT INTO "django_geo_db_zipcode" VALUES(40360,94016,-8,'Daly City, California 94016',28479,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40361,94017,-8,'Daly City, California 94017',28479,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40362,94018,-8,'El Granada, California 94018',28480,35493);
INSERT INTO "django_geo_db_zipcode" VALUES(40363,94019,-8,'Half Moon Bay, California 94019',28481,35494);
INSERT INTO "django_geo_db_zipcode" VALUES(40364,94020,-8,'La Honda, California 94020',28482,35495);
INSERT INTO "django_geo_db_zipcode" VALUES(40365,94021,-8,'Loma Mar, California 94021',28483,35496);
INSERT INTO "django_geo_db_zipcode" VALUES(40366,94022,-8,'Los Altos, California 94022',28484,35497);
INSERT INTO "django_geo_db_zipcode" VALUES(40367,94023,-8,'Los Altos, California 94023',28484,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40368,94024,-8,'Los Altos, California 94024',28484,35499);
INSERT INTO "django_geo_db_zipcode" VALUES(40369,94025,-8,'Menlo Park, California 94025',28485,35500);
INSERT INTO "django_geo_db_zipcode" VALUES(40370,94026,-8,'Menlo Park, California 94026',28485,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40371,94027,-8,'Atherton, California 94027',28486,35501);
INSERT INTO "django_geo_db_zipcode" VALUES(40372,94028,-8,'Portola Valley, California 94028',28487,35502);
INSERT INTO "django_geo_db_zipcode" VALUES(40373,94029,-8,'Menlo Park, California 94029',28485,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40374,94030,-8,'Millbrae, California 94030',28488,35503);
INSERT INTO "django_geo_db_zipcode" VALUES(40375,94031,-8,'Millbrae, California 94031',28488,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40376,94035,-8,'Mountain View, California 94035',28489,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40377,94037,-8,'Montara, California 94037',28490,35504);
INSERT INTO "django_geo_db_zipcode" VALUES(40378,94038,-8,'Moss Beach, California 94038',28491,35505);
INSERT INTO "django_geo_db_zipcode" VALUES(40379,94039,-8,'Mountain View, California 94039',28489,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40380,94040,-8,'Mountain View, California 94040',28489,35506);
INSERT INTO "django_geo_db_zipcode" VALUES(40381,94041,-8,'Mountain View, California 94041',28489,35507);
INSERT INTO "django_geo_db_zipcode" VALUES(40382,94042,-8,'Mountain View, California 94042',28489,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40383,94043,-8,'Mountain View, California 94043',28489,35508);
INSERT INTO "django_geo_db_zipcode" VALUES(40384,94044,-8,'Pacifica, California 94044',28492,35509);
INSERT INTO "django_geo_db_zipcode" VALUES(40385,94045,-8,'Pacifica, California 94045',28492,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40386,94059,-8,'Redwood City, California 94059',28493,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40387,94060,-8,'Pescadero, California 94060',28494,35510);
INSERT INTO "django_geo_db_zipcode" VALUES(40388,94061,-8,'Redwood City, California 94061',28493,35511);
INSERT INTO "django_geo_db_zipcode" VALUES(40389,94062,-8,'Redwood City, California 94062',28493,35512);
INSERT INTO "django_geo_db_zipcode" VALUES(40390,94063,-8,'Redwood City, California 94063',28493,35513);
INSERT INTO "django_geo_db_zipcode" VALUES(40391,94064,-8,'Redwood City, California 94064',28493,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40392,94065,-8,'Redwood City, California 94065',28493,35514);
INSERT INTO "django_geo_db_zipcode" VALUES(40393,94066,-8,'San Bruno, California 94066',28495,35515);
INSERT INTO "django_geo_db_zipcode" VALUES(40394,94067,-8,'San Bruno, California 94067',28495,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40395,94070,-8,'San Carlos, California 94070',28496,35516);
INSERT INTO "django_geo_db_zipcode" VALUES(40396,94071,-8,'San Carlos, California 94071',28496,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40397,94074,-8,'San Gregorio, California 94074',28497,35517);
INSERT INTO "django_geo_db_zipcode" VALUES(40398,94080,-8,'South San Francisco, California 94080',28498,35518);
INSERT INTO "django_geo_db_zipcode" VALUES(40399,94083,-8,'South San Francisco, California 94083',28498,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40400,94085,-8,'Sunnyvale, California 94085',28499,35519);
INSERT INTO "django_geo_db_zipcode" VALUES(40401,94086,-8,'Sunnyvale, California 94086',28499,35520);
INSERT INTO "django_geo_db_zipcode" VALUES(40402,94087,-8,'Sunnyvale, California 94087',28499,35521);
INSERT INTO "django_geo_db_zipcode" VALUES(40403,94088,-8,'Sunnyvale, California 94088',28499,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40404,94089,-8,'Sunnyvale, California 94089',28499,35522);
INSERT INTO "django_geo_db_zipcode" VALUES(40405,94090,-8,'Sunnyvale, California 94090',28499,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40406,94096,-8,'San Bruno, California 94096',28495,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40407,94098,-8,'San Bruno, California 94098',28495,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40408,94099,-8,'South San Francisco, California 94099',28498,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40409,94101,-8,'San Francisco, California 94101',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40410,94102,-8,'San Francisco, California 94102',28500,35524);
INSERT INTO "django_geo_db_zipcode" VALUES(40411,94103,-8,'San Francisco, California 94103',28500,35525);
INSERT INTO "django_geo_db_zipcode" VALUES(40412,94104,-8,'San Francisco, California 94104',28500,35526);
INSERT INTO "django_geo_db_zipcode" VALUES(40413,94105,-8,'San Francisco, California 94105',28500,35527);
INSERT INTO "django_geo_db_zipcode" VALUES(40414,94106,-8,'San Francisco, California 94106',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40415,94107,-8,'San Francisco, California 94107',28500,35528);
INSERT INTO "django_geo_db_zipcode" VALUES(40416,94108,-8,'San Francisco, California 94108',28500,35529);
INSERT INTO "django_geo_db_zipcode" VALUES(40417,94109,-8,'San Francisco, California 94109',28500,35530);
INSERT INTO "django_geo_db_zipcode" VALUES(40418,94110,-8,'San Francisco, California 94110',28500,35531);
INSERT INTO "django_geo_db_zipcode" VALUES(40419,94111,-8,'San Francisco, California 94111',28500,35532);
INSERT INTO "django_geo_db_zipcode" VALUES(40420,94112,-8,'San Francisco, California 94112',28500,35533);
INSERT INTO "django_geo_db_zipcode" VALUES(40421,94114,-8,'San Francisco, California 94114',28500,35534);
INSERT INTO "django_geo_db_zipcode" VALUES(40422,94115,-8,'San Francisco, California 94115',28500,35535);
INSERT INTO "django_geo_db_zipcode" VALUES(40423,94116,-8,'San Francisco, California 94116',28500,35536);
INSERT INTO "django_geo_db_zipcode" VALUES(40424,94117,-8,'San Francisco, California 94117',28500,35537);
INSERT INTO "django_geo_db_zipcode" VALUES(40425,94118,-8,'San Francisco, California 94118',28500,35538);
INSERT INTO "django_geo_db_zipcode" VALUES(40426,94119,-8,'San Francisco, California 94119',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40427,94120,-8,'San Francisco, California 94120',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40428,94121,-8,'San Francisco, California 94121',28500,35539);
INSERT INTO "django_geo_db_zipcode" VALUES(40429,94122,-8,'San Francisco, California 94122',28500,35540);
INSERT INTO "django_geo_db_zipcode" VALUES(40430,94123,-8,'San Francisco, California 94123',28500,35541);
INSERT INTO "django_geo_db_zipcode" VALUES(40431,94124,-8,'San Francisco, California 94124',28500,35542);
INSERT INTO "django_geo_db_zipcode" VALUES(40432,94125,-8,'San Francisco, California 94125',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40433,94126,-8,'San Francisco, California 94126',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40434,94127,-8,'San Francisco, California 94127',28500,35543);
INSERT INTO "django_geo_db_zipcode" VALUES(40435,94128,-8,'San Francisco, California 94128',28500,35544);
INSERT INTO "django_geo_db_zipcode" VALUES(40436,94129,-8,'San Francisco, California 94129',28500,35545);
INSERT INTO "django_geo_db_zipcode" VALUES(40437,94130,-8,'San Francisco, California 94130',28500,35546);
INSERT INTO "django_geo_db_zipcode" VALUES(40438,94131,-8,'San Francisco, California 94131',28500,35547);
INSERT INTO "django_geo_db_zipcode" VALUES(40439,94132,-8,'San Francisco, California 94132',28500,35548);
INSERT INTO "django_geo_db_zipcode" VALUES(40440,94133,-8,'San Francisco, California 94133',28500,35549);
INSERT INTO "django_geo_db_zipcode" VALUES(40441,94134,-8,'San Francisco, California 94134',28500,35550);
INSERT INTO "django_geo_db_zipcode" VALUES(40442,94135,-8,'San Francisco, California 94135',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40443,94136,-8,'San Francisco, California 94136',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40444,94137,-8,'San Francisco, California 94137',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40445,94138,-8,'San Francisco, California 94138',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40446,94139,-8,'San Francisco, California 94139',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40447,94140,-8,'San Francisco, California 94140',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40448,94141,-8,'San Francisco, California 94141',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40449,94142,-8,'San Francisco, California 94142',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40450,94143,-8,'San Francisco, California 94143',28500,35551);
INSERT INTO "django_geo_db_zipcode" VALUES(40451,94144,-8,'San Francisco, California 94144',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40452,94145,-8,'San Francisco, California 94145',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40453,94146,-8,'San Francisco, California 94146',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40454,94147,-8,'San Francisco, California 94147',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40455,94150,-8,'San Francisco, California 94150',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40456,94151,-8,'San Francisco, California 94151',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40457,94152,-8,'San Francisco, California 94152',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40458,94153,-8,'San Francisco, California 94153',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40459,94154,-8,'San Francisco, California 94154',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40460,94155,-8,'San Francisco, California 94155',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40461,94156,-8,'San Francisco, California 94156',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40462,94157,-8,'San Francisco, California 94157',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40463,94159,-8,'San Francisco, California 94159',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40464,94160,-8,'San Francisco, California 94160',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40465,94161,-8,'San Francisco, California 94161',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40466,94162,-8,'San Francisco, California 94162',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40467,94163,-8,'San Francisco, California 94163',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40468,94164,-8,'San Francisco, California 94164',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40469,94165,-8,'San Francisco, California 94165',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40470,94166,-8,'San Francisco, California 94166',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40471,94167,-8,'San Francisco, California 94167',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40472,94168,-8,'San Francisco, California 94168',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40473,94169,-8,'San Francisco, California 94169',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40474,94170,-8,'San Francisco, California 94170',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40475,94171,-8,'San Francisco, California 94171',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40476,94172,-8,'San Francisco, California 94172',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40477,94175,-8,'San Francisco, California 94175',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40478,94177,-8,'San Francisco, California 94177',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40479,94188,-8,'San Francisco, California 94188',28500,35523);
INSERT INTO "django_geo_db_zipcode" VALUES(40480,94203,-8,'Sacramento, California 94203',28501,35552);
INSERT INTO "django_geo_db_zipcode" VALUES(40481,94204,-8,'Sacramento, California 94204',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40482,94205,-8,'Sacramento, California 94205',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40483,94206,-8,'Sacramento, California 94206',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40484,94207,-8,'Sacramento, California 94207',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40485,94208,-8,'Sacramento, California 94208',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40486,94209,-8,'Sacramento, California 94209',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40487,94211,-8,'Sacramento, California 94211',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40488,94229,-8,'Sacramento, California 94229',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40489,94230,-8,'Sacramento, California 94230',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40490,94232,-8,'Sacramento, California 94232',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40491,94234,-8,'Sacramento, California 94234',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40492,94235,-8,'Sacramento, California 94235',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40493,94236,-8,'Sacramento, California 94236',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40494,94237,-8,'Sacramento, California 94237',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40495,94239,-8,'Sacramento, California 94239',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40496,94240,-8,'Sacramento, California 94240',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40497,94243,-8,'Sacramento, California 94243',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40498,94244,-8,'Sacramento, California 94244',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40499,94245,-8,'Sacramento, California 94245',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40500,94246,-8,'Sacramento, California 94246',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40501,94247,-8,'Sacramento, California 94247',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40502,94248,-8,'Sacramento, California 94248',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40503,94249,-8,'Sacramento, California 94249',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40504,94250,-8,'Sacramento, California 94250',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40505,94252,-8,'Sacramento, California 94252',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40506,94253,-8,'Sacramento, California 94253',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40507,94254,-8,'Sacramento, California 94254',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40508,94256,-8,'Sacramento, California 94256',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40509,94257,-8,'Sacramento, California 94257',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40510,94258,-8,'Sacramento, California 94258',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40511,94259,-8,'Sacramento, California 94259',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40512,94261,-8,'Sacramento, California 94261',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40513,94262,-8,'Sacramento, California 94262',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40514,94263,-8,'Sacramento, California 94263',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40515,94267,-8,'Sacramento, California 94267',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40516,94268,-8,'Sacramento, California 94268',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40517,94269,-8,'Sacramento, California 94269',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40518,94271,-8,'Sacramento, California 94271',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40519,94273,-8,'Sacramento, California 94273',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40520,94274,-8,'Sacramento, California 94274',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40521,94277,-8,'Sacramento, California 94277',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40522,94278,-8,'Sacramento, California 94278',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40523,94279,-8,'Sacramento, California 94279',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40524,94280,-8,'Sacramento, California 94280',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40525,94282,-8,'Sacramento, California 94282',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40526,94283,-8,'Sacramento, California 94283',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40527,94284,-8,'Sacramento, California 94284',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40528,94285,-8,'Sacramento, California 94285',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40529,94286,-8,'Sacramento, California 94286',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40530,94287,-8,'Sacramento, California 94287',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40531,94288,-8,'Sacramento, California 94288',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40532,94289,-8,'Sacramento, California 94289',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40533,94290,-8,'Sacramento, California 94290',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40534,94291,-8,'Sacramento, California 94291',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40535,94293,-8,'Sacramento, California 94293',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40536,94294,-8,'Sacramento, California 94294',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40537,94295,-8,'Sacramento, California 94295',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40538,94296,-8,'Sacramento, California 94296',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40539,94297,-8,'Sacramento, California 94297',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40540,94298,-8,'Sacramento, California 94298',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40541,94299,-8,'Sacramento, California 94299',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(40542,94301,-8,'Palo Alto, California 94301',28502,35554);
INSERT INTO "django_geo_db_zipcode" VALUES(40543,94302,-8,'Palo Alto, California 94302',28502,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40544,94303,-8,'Palo Alto, California 94303',28502,35555);
INSERT INTO "django_geo_db_zipcode" VALUES(40545,94304,-8,'Palo Alto, California 94304',28502,35556);
INSERT INTO "django_geo_db_zipcode" VALUES(40546,94305,-8,'Stanford, California 94305',28503,35557);
INSERT INTO "django_geo_db_zipcode" VALUES(40547,94306,-8,'Palo Alto, California 94306',28502,35558);
INSERT INTO "django_geo_db_zipcode" VALUES(40548,94307,-8,'Palo Alto, California 94307',28502,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40549,94308,-8,'Palo Alto, California 94308',28502,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40550,94309,-8,'Palo Alto, California 94309',28502,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40551,94310,-8,'Palo Alto, California 94310',28502,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40552,94401,-8,'San Mateo, California 94401',28504,35559);
INSERT INTO "django_geo_db_zipcode" VALUES(40553,94402,-8,'San Mateo, California 94402',28504,35560);
INSERT INTO "django_geo_db_zipcode" VALUES(40554,94403,-8,'San Mateo, California 94403',28504,35561);
INSERT INTO "django_geo_db_zipcode" VALUES(40555,94404,-8,'San Mateo, California 94404',28504,35562);
INSERT INTO "django_geo_db_zipcode" VALUES(40556,94405,-8,'San Mateo, California 94405',28504,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40557,94406,-8,'San Mateo, California 94406',28504,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40558,94407,-8,'San Mateo, California 94407',28504,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40559,94408,-8,'San Mateo, California 94408',28504,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40560,94409,-8,'San Mateo, California 94409',28504,35488);
INSERT INTO "django_geo_db_zipcode" VALUES(40561,94420,-8,'Foster City, California 94420',28505,35563);
INSERT INTO "django_geo_db_zipcode" VALUES(40562,94497,-8,'San Mateo, California 94497',28504,35564);
INSERT INTO "django_geo_db_zipcode" VALUES(40563,94501,-8,'Alameda, California 94501',28506,35565);
INSERT INTO "django_geo_db_zipcode" VALUES(40564,94502,-8,'Alameda, California 94502',28506,35566);
INSERT INTO "django_geo_db_zipcode" VALUES(40565,94503,-8,'American Canyon, California 94503',28507,35567);
INSERT INTO "django_geo_db_zipcode" VALUES(40566,94506,-8,'Danville, California 94506',28508,35568);
INSERT INTO "django_geo_db_zipcode" VALUES(40567,94507,-8,'Alamo, California 94507',28509,35569);
INSERT INTO "django_geo_db_zipcode" VALUES(40568,94508,-8,'Angwin, California 94508',28510,35570);
INSERT INTO "django_geo_db_zipcode" VALUES(40569,94509,-8,'Antioch, California 94509',28511,35571);
INSERT INTO "django_geo_db_zipcode" VALUES(40570,94510,-8,'Benicia, California 94510',28512,35572);
INSERT INTO "django_geo_db_zipcode" VALUES(40571,94511,-8,'Bethel Island, California 94511',28513,35573);
INSERT INTO "django_geo_db_zipcode" VALUES(40572,94512,-8,'Birds Landing, California 94512',28514,35574);
INSERT INTO "django_geo_db_zipcode" VALUES(40573,94513,-8,'Brentwood, California 94513',28515,35575);
INSERT INTO "django_geo_db_zipcode" VALUES(40574,94514,-8,'Byron, California 94514',28516,35576);
INSERT INTO "django_geo_db_zipcode" VALUES(40575,94515,-8,'Calistoga, California 94515',28517,35577);
INSERT INTO "django_geo_db_zipcode" VALUES(40576,94516,-8,'Canyon, California 94516',28518,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40577,94517,-8,'Clayton, California 94517',28519,35579);
INSERT INTO "django_geo_db_zipcode" VALUES(40578,94518,-8,'Concord, California 94518',28520,35580);
INSERT INTO "django_geo_db_zipcode" VALUES(40579,94519,-8,'Concord, California 94519',28520,35581);
INSERT INTO "django_geo_db_zipcode" VALUES(40580,94520,-8,'Concord, California 94520',28520,35582);
INSERT INTO "django_geo_db_zipcode" VALUES(40581,94521,-8,'Concord, California 94521',28520,35583);
INSERT INTO "django_geo_db_zipcode" VALUES(40582,94522,-8,'Concord, California 94522',28520,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40583,94523,-8,'Pleasant Hill, California 94523',28521,35584);
INSERT INTO "django_geo_db_zipcode" VALUES(40584,94524,-8,'Concord, California 94524',28520,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40585,94525,-8,'Crockett, California 94525',28522,35585);
INSERT INTO "django_geo_db_zipcode" VALUES(40586,94526,-8,'Danville, California 94526',28508,35586);
INSERT INTO "django_geo_db_zipcode" VALUES(40587,94527,-8,'Concord, California 94527',28520,35587);
INSERT INTO "django_geo_db_zipcode" VALUES(40588,94528,-8,'Diablo, California 94528',28523,35588);
INSERT INTO "django_geo_db_zipcode" VALUES(40589,94529,-8,'Concord, California 94529',28520,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40590,94530,-8,'El Cerrito, California 94530',28524,35589);
INSERT INTO "django_geo_db_zipcode" VALUES(40591,94531,-8,'Antioch, California 94531',28511,35590);
INSERT INTO "django_geo_db_zipcode" VALUES(40592,94533,-8,'Fairfield, California 94533',28525,35591);
INSERT INTO "django_geo_db_zipcode" VALUES(40593,94534,-8,'Fairfield, California 94534',28525,35592);
INSERT INTO "django_geo_db_zipcode" VALUES(40594,94535,-8,'Travis AFB, California 94535',28526,35593);
INSERT INTO "django_geo_db_zipcode" VALUES(40595,94536,-8,'Fremont, California 94536',28527,35594);
INSERT INTO "django_geo_db_zipcode" VALUES(40596,94537,-8,'Fremont, California 94537',28527,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40597,94538,-8,'Fremont, California 94538',28527,35596);
INSERT INTO "django_geo_db_zipcode" VALUES(40598,94539,-8,'Fremont, California 94539',28527,35597);
INSERT INTO "django_geo_db_zipcode" VALUES(40599,94540,-8,'Hayward, California 94540',28528,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40600,94541,-8,'Hayward, California 94541',28528,35598);
INSERT INTO "django_geo_db_zipcode" VALUES(40601,94542,-8,'Hayward, California 94542',28528,35599);
INSERT INTO "django_geo_db_zipcode" VALUES(40602,94543,-8,'Hayward, California 94543',28528,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40603,94544,-8,'Hayward, California 94544',28528,35600);
INSERT INTO "django_geo_db_zipcode" VALUES(40604,94545,-8,'Hayward, California 94545',28528,35601);
INSERT INTO "django_geo_db_zipcode" VALUES(40605,94546,-8,'Castro Valley, California 94546',28529,35602);
INSERT INTO "django_geo_db_zipcode" VALUES(40606,94547,-8,'Hercules, California 94547',28530,35603);
INSERT INTO "django_geo_db_zipcode" VALUES(40607,94548,-8,'Knightsen, California 94548',28531,35604);
INSERT INTO "django_geo_db_zipcode" VALUES(40608,94549,-8,'Lafayette, California 94549',28532,35605);
INSERT INTO "django_geo_db_zipcode" VALUES(40609,94550,-8,'Livermore, California 94550',28533,35606);
INSERT INTO "django_geo_db_zipcode" VALUES(40610,94551,-8,'Livermore, California 94551',28533,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40611,94552,-8,'Castro Valley, California 94552',28529,35607);
INSERT INTO "django_geo_db_zipcode" VALUES(40612,94553,-8,'Martinez, California 94553',28534,35608);
INSERT INTO "django_geo_db_zipcode" VALUES(40613,94555,-8,'Fremont, California 94555',28527,35609);
INSERT INTO "django_geo_db_zipcode" VALUES(40614,94556,-8,'Moraga, California 94556',28535,35610);
INSERT INTO "django_geo_db_zipcode" VALUES(40615,94557,-8,'Hayward, California 94557',28528,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40616,94558,-8,'Napa, California 94558',28536,35611);
INSERT INTO "django_geo_db_zipcode" VALUES(40617,94559,-8,'Napa, California 94559',28536,35612);
INSERT INTO "django_geo_db_zipcode" VALUES(40618,94560,-8,'Newark, California 94560',28537,35613);
INSERT INTO "django_geo_db_zipcode" VALUES(40619,94561,-8,'Oakley, California 94561',28538,35614);
INSERT INTO "django_geo_db_zipcode" VALUES(40620,94562,-8,'Oakville, California 94562',28539,35615);
INSERT INTO "django_geo_db_zipcode" VALUES(40621,94563,-8,'Orinda, California 94563',28540,35616);
INSERT INTO "django_geo_db_zipcode" VALUES(40622,94564,-8,'Pinole, California 94564',28541,35617);
INSERT INTO "django_geo_db_zipcode" VALUES(40623,94565,-8,'Pittsburg, California 94565',28542,35618);
INSERT INTO "django_geo_db_zipcode" VALUES(40624,94566,-8,'Pleasanton, California 94566',28543,35619);
INSERT INTO "django_geo_db_zipcode" VALUES(40625,94567,-8,'Pope Valley, California 94567',28544,35620);
INSERT INTO "django_geo_db_zipcode" VALUES(40626,94568,-8,'Dublin, California 94568',28545,35621);
INSERT INTO "django_geo_db_zipcode" VALUES(40627,94569,-8,'Port Costa, California 94569',28546,35622);
INSERT INTO "django_geo_db_zipcode" VALUES(40628,94570,-8,'Moraga, California 94570',28535,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40629,94571,-8,'Rio Vista, California 94571',28547,35623);
INSERT INTO "django_geo_db_zipcode" VALUES(40630,94572,-8,'Rodeo, California 94572',28548,35624);
INSERT INTO "django_geo_db_zipcode" VALUES(40631,94573,-8,'Rutherford, California 94573',28549,35625);
INSERT INTO "django_geo_db_zipcode" VALUES(40632,94574,-8,'Saint Helena, California 94574',28550,35626);
INSERT INTO "django_geo_db_zipcode" VALUES(40633,94575,-8,'Moraga, California 94575',28535,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40634,94576,-8,'Deer Park, California 94576',28551,35627);
INSERT INTO "django_geo_db_zipcode" VALUES(40635,94577,-8,'San Leandro, California 94577',28552,35628);
INSERT INTO "django_geo_db_zipcode" VALUES(40636,94578,-8,'San Leandro, California 94578',28552,35629);
INSERT INTO "django_geo_db_zipcode" VALUES(40637,94579,-8,'San Leandro, California 94579',28552,35630);
INSERT INTO "django_geo_db_zipcode" VALUES(40638,94580,-8,'San Lorenzo, California 94580',28553,35631);
INSERT INTO "django_geo_db_zipcode" VALUES(40639,94581,-8,'Napa, California 94581',28536,35632);
INSERT INTO "django_geo_db_zipcode" VALUES(40640,94583,-8,'San Ramon, California 94583',28554,35633);
INSERT INTO "django_geo_db_zipcode" VALUES(40641,94585,-8,'Suisun City, California 94585',28555,35634);
INSERT INTO "django_geo_db_zipcode" VALUES(40642,94586,-8,'Sunol, California 94586',28556,35635);
INSERT INTO "django_geo_db_zipcode" VALUES(40643,94587,-8,'Union City, California 94587',28557,35636);
INSERT INTO "django_geo_db_zipcode" VALUES(40644,94588,-8,'Pleasanton, California 94588',28543,35637);
INSERT INTO "django_geo_db_zipcode" VALUES(40645,94589,-8,'Vallejo, California 94589',28558,35638);
INSERT INTO "django_geo_db_zipcode" VALUES(40646,94590,-8,'Vallejo, California 94590',28558,35639);
INSERT INTO "django_geo_db_zipcode" VALUES(40647,94591,-8,'Vallejo, California 94591',28558,35640);
INSERT INTO "django_geo_db_zipcode" VALUES(40648,94592,-8,'Vallejo, California 94592',28558,35641);
INSERT INTO "django_geo_db_zipcode" VALUES(40649,94595,-8,'Walnut Creek, California 94595',28559,35642);
INSERT INTO "django_geo_db_zipcode" VALUES(40650,94596,-8,'Walnut Creek, California 94596',28559,35643);
INSERT INTO "django_geo_db_zipcode" VALUES(40651,94597,-8,'Walnut Creek, California 94597',28559,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40652,94598,-8,'Walnut Creek, California 94598',28559,35644);
INSERT INTO "django_geo_db_zipcode" VALUES(40653,94599,-8,'Yountville, California 94599',28560,35645);
INSERT INTO "django_geo_db_zipcode" VALUES(40654,94601,-8,'Oakland, California 94601',28561,35646);
INSERT INTO "django_geo_db_zipcode" VALUES(40655,94602,-8,'Oakland, California 94602',28561,35647);
INSERT INTO "django_geo_db_zipcode" VALUES(40656,94603,-8,'Oakland, California 94603',28561,35648);
INSERT INTO "django_geo_db_zipcode" VALUES(40657,94604,-8,'Oakland, California 94604',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40658,94605,-8,'Oakland, California 94605',28561,35649);
INSERT INTO "django_geo_db_zipcode" VALUES(40659,94606,-8,'Oakland, California 94606',28561,35650);
INSERT INTO "django_geo_db_zipcode" VALUES(40660,94607,-8,'Oakland, California 94607',28561,35651);
INSERT INTO "django_geo_db_zipcode" VALUES(40661,94608,-8,'Emeryville, California 94608',28562,35652);
INSERT INTO "django_geo_db_zipcode" VALUES(40662,94609,-8,'Oakland, California 94609',28561,35653);
INSERT INTO "django_geo_db_zipcode" VALUES(40663,94610,-8,'Oakland, California 94610',28561,35654);
INSERT INTO "django_geo_db_zipcode" VALUES(40664,94611,-8,'Oakland, California 94611',28561,35655);
INSERT INTO "django_geo_db_zipcode" VALUES(40665,94612,-8,'Oakland, California 94612',28561,35656);
INSERT INTO "django_geo_db_zipcode" VALUES(40666,94613,-8,'Oakland, California 94613',28561,35657);
INSERT INTO "django_geo_db_zipcode" VALUES(40667,94614,-8,'Oakland, California 94614',28561,35658);
INSERT INTO "django_geo_db_zipcode" VALUES(40668,94615,-8,'Oakland, California 94615',28561,35659);
INSERT INTO "django_geo_db_zipcode" VALUES(40669,94617,-8,'Oakland, California 94617',28561,35660);
INSERT INTO "django_geo_db_zipcode" VALUES(40670,94618,-8,'Oakland, California 94618',28561,35661);
INSERT INTO "django_geo_db_zipcode" VALUES(40671,94619,-8,'Oakland, California 94619',28561,35662);
INSERT INTO "django_geo_db_zipcode" VALUES(40672,94620,-8,'Piedmont, California 94620',28563,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40673,94621,-8,'Oakland, California 94621',28561,35663);
INSERT INTO "django_geo_db_zipcode" VALUES(40674,94623,-8,'Oakland, California 94623',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40675,94624,-8,'Oakland, California 94624',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40676,94625,-8,'Oakland, California 94625',28561,35664);
INSERT INTO "django_geo_db_zipcode" VALUES(40677,94626,-8,'Oakland, California 94626',28561,35665);
INSERT INTO "django_geo_db_zipcode" VALUES(40678,94627,-8,'Oakland, California 94627',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40679,94643,-8,'Oakland, California 94643',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40680,94649,-8,'Oakland, California 94649',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40681,94659,-8,'Oakland, California 94659',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40682,94660,-8,'Oakland, California 94660',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40683,94661,-8,'Oakland, California 94661',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40684,94662,-8,'Emeryville, California 94662',28562,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40685,94666,-8,'Oakland, California 94666',28561,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40686,94701,-8,'Berkeley, California 94701',28564,35666);
INSERT INTO "django_geo_db_zipcode" VALUES(40687,94702,-8,'Berkeley, California 94702',28564,35667);
INSERT INTO "django_geo_db_zipcode" VALUES(40688,94703,-8,'Berkeley, California 94703',28564,35668);
INSERT INTO "django_geo_db_zipcode" VALUES(40689,94704,-8,'Berkeley, California 94704',28564,35669);
INSERT INTO "django_geo_db_zipcode" VALUES(40690,94705,-8,'Berkeley, California 94705',28564,35670);
INSERT INTO "django_geo_db_zipcode" VALUES(40691,94706,-8,'Albany, California 94706',28565,35671);
INSERT INTO "django_geo_db_zipcode" VALUES(40692,94707,-8,'Berkeley, California 94707',28564,35672);
INSERT INTO "django_geo_db_zipcode" VALUES(40693,94708,-8,'Berkeley, California 94708',28564,35673);
INSERT INTO "django_geo_db_zipcode" VALUES(40694,94709,-8,'Berkeley, California 94709',28564,35674);
INSERT INTO "django_geo_db_zipcode" VALUES(40695,94710,-8,'Berkeley, California 94710',28564,35675);
INSERT INTO "django_geo_db_zipcode" VALUES(40696,94712,-8,'Berkeley, California 94712',28564,35595);
INSERT INTO "django_geo_db_zipcode" VALUES(40697,94720,-8,'Berkeley, California 94720',28564,35676);
INSERT INTO "django_geo_db_zipcode" VALUES(40698,94801,-8,'Richmond, California 94801',28566,35677);
INSERT INTO "django_geo_db_zipcode" VALUES(40699,94802,-8,'Richmond, California 94802',28566,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40700,94803,-8,'El Sobrante, California 94803',28567,35678);
INSERT INTO "django_geo_db_zipcode" VALUES(40701,94804,-8,'Richmond, California 94804',28566,35679);
INSERT INTO "django_geo_db_zipcode" VALUES(40702,94805,-8,'Richmond, California 94805',28566,35680);
INSERT INTO "django_geo_db_zipcode" VALUES(40703,94806,-8,'San Pablo, California 94806',28568,35681);
INSERT INTO "django_geo_db_zipcode" VALUES(40704,94807,-8,'Richmond, California 94807',28566,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40705,94808,-8,'Richmond, California 94808',28566,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40706,94820,-8,'El Sobrante, California 94820',28567,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40707,94850,-8,'Richmond, California 94850',28566,35578);
INSERT INTO "django_geo_db_zipcode" VALUES(40708,94901,-8,'San Rafael, California 94901',28569,35682);
INSERT INTO "django_geo_db_zipcode" VALUES(40709,94903,-8,'San Rafael, California 94903',28569,35683);
INSERT INTO "django_geo_db_zipcode" VALUES(40710,94904,-8,'Greenbrae, California 94904',28570,35684);
INSERT INTO "django_geo_db_zipcode" VALUES(40711,94912,-8,'San Rafael, California 94912',28569,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40712,94913,-8,'San Rafael, California 94913',28569,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40713,94914,-8,'Kentfield, California 94914',28571,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40714,94915,-8,'San Rafael, California 94915',28569,35686);
INSERT INTO "django_geo_db_zipcode" VALUES(40715,94920,-8,'Belvedere Tiburon, California 94920',28572,35687);
INSERT INTO "django_geo_db_zipcode" VALUES(40716,94922,-8,'Bodega, California 94922',28573,35688);
INSERT INTO "django_geo_db_zipcode" VALUES(40717,94923,-8,'Bodega Bay, California 94923',28574,35689);
INSERT INTO "django_geo_db_zipcode" VALUES(40718,94924,-8,'Bolinas, California 94924',28575,35690);
INSERT INTO "django_geo_db_zipcode" VALUES(40719,94925,-8,'Corte Madera, California 94925',28576,35691);
INSERT INTO "django_geo_db_zipcode" VALUES(40720,94926,-8,'Cotati, California 94926',28577,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(40721,94927,-8,'Rohnert Park, California 94927',28578,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(40722,94928,-8,'Rohnert Park, California 94928',28578,35693);
INSERT INTO "django_geo_db_zipcode" VALUES(40723,94929,-8,'Dillon Beach, California 94929',28579,35694);
INSERT INTO "django_geo_db_zipcode" VALUES(40724,94930,-8,'Fairfax, California 94930',28580,35695);
INSERT INTO "django_geo_db_zipcode" VALUES(40725,94931,-8,'Cotati, California 94931',28577,35696);
INSERT INTO "django_geo_db_zipcode" VALUES(40726,94933,-8,'Forest Knolls, California 94933',28581,35697);
INSERT INTO "django_geo_db_zipcode" VALUES(40727,94937,-8,'Inverness, California 94937',28582,35698);
INSERT INTO "django_geo_db_zipcode" VALUES(40728,94938,-8,'Lagunitas, California 94938',28583,35699);
INSERT INTO "django_geo_db_zipcode" VALUES(40729,94939,-8,'Larkspur, California 94939',28584,35700);
INSERT INTO "django_geo_db_zipcode" VALUES(40730,94940,-8,'Marshall, California 94940',28585,35701);
INSERT INTO "django_geo_db_zipcode" VALUES(40731,94941,-8,'Mill Valley, California 94941',28586,35702);
INSERT INTO "django_geo_db_zipcode" VALUES(40732,94942,-8,'Mill Valley, California 94942',28586,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40733,94945,-8,'Novato, California 94945',28587,35703);
INSERT INTO "django_geo_db_zipcode" VALUES(40734,94946,-8,'Nicasio, California 94946',28588,35704);
INSERT INTO "django_geo_db_zipcode" VALUES(40735,94947,-8,'Novato, California 94947',28587,35705);
INSERT INTO "django_geo_db_zipcode" VALUES(40736,94948,-8,'Novato, California 94948',28587,35706);
INSERT INTO "django_geo_db_zipcode" VALUES(40737,94949,-8,'Novato, California 94949',28587,35707);
INSERT INTO "django_geo_db_zipcode" VALUES(40738,94950,-8,'Olema, California 94950',28589,35708);
INSERT INTO "django_geo_db_zipcode" VALUES(40739,94951,-8,'Penngrove, California 94951',28590,35709);
INSERT INTO "django_geo_db_zipcode" VALUES(40740,94952,-8,'Petaluma, California 94952',28591,35710);
INSERT INTO "django_geo_db_zipcode" VALUES(40741,94953,-8,'Petaluma, California 94953',28591,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(40742,94954,-8,'Petaluma, California 94954',28591,35711);
INSERT INTO "django_geo_db_zipcode" VALUES(40743,94955,-8,'Petaluma, California 94955',28591,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(40744,94956,-8,'Point Reyes Station, California 94956',28592,35712);
INSERT INTO "django_geo_db_zipcode" VALUES(40745,94957,-8,'Ross, California 94957',28593,35713);
INSERT INTO "django_geo_db_zipcode" VALUES(40746,94960,-8,'San Anselmo, California 94960',28594,35714);
INSERT INTO "django_geo_db_zipcode" VALUES(40747,94963,-8,'San Geronimo, California 94963',28595,35715);
INSERT INTO "django_geo_db_zipcode" VALUES(40748,94964,-8,'San Quentin, California 94964',28596,35716);
INSERT INTO "django_geo_db_zipcode" VALUES(40749,94965,-8,'Sausalito, California 94965',28597,35717);
INSERT INTO "django_geo_db_zipcode" VALUES(40750,94966,-8,'Sausalito, California 94966',28597,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40751,94970,-8,'Stinson Beach, California 94970',28598,35718);
INSERT INTO "django_geo_db_zipcode" VALUES(40752,94971,-8,'Tomales, California 94971',28599,35719);
INSERT INTO "django_geo_db_zipcode" VALUES(40753,94972,-8,'Valley Ford, California 94972',28600,35720);
INSERT INTO "django_geo_db_zipcode" VALUES(40754,94973,-8,'Woodacre, California 94973',28601,35721);
INSERT INTO "django_geo_db_zipcode" VALUES(40755,94974,-8,'San Quentin, California 94974',28596,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40756,94975,-8,'Petaluma, California 94975',28591,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(40757,94976,-8,'Corte Madera, California 94976',28576,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40758,94977,-8,'Larkspur, California 94977',28584,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40759,94978,-8,'Fairfax, California 94978',28580,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40760,94979,-8,'San Anselmo, California 94979',28594,35685);
INSERT INTO "django_geo_db_zipcode" VALUES(40761,94991,-8,'San Rafael, California 94991',28569,35722);
INSERT INTO "django_geo_db_zipcode" VALUES(40762,94998,-8,'Novato, California 94998',28587,35723);
INSERT INTO "django_geo_db_zipcode" VALUES(40763,94999,-8,'Petaluma, California 94999',28591,35724);
INSERT INTO "django_geo_db_zipcode" VALUES(40764,95001,-8,'Aptos, California 95001',28602,35725);
INSERT INTO "django_geo_db_zipcode" VALUES(40765,95002,-8,'Alviso, California 95002',28603,35726);
INSERT INTO "django_geo_db_zipcode" VALUES(40766,95003,-8,'Aptos, California 95003',28602,35727);
INSERT INTO "django_geo_db_zipcode" VALUES(40767,95004,-8,'Aromas, California 95004',28604,35728);
INSERT INTO "django_geo_db_zipcode" VALUES(40768,95005,-8,'Ben Lomond, California 95005',28605,35729);
INSERT INTO "django_geo_db_zipcode" VALUES(40769,95006,-8,'Boulder Creek, California 95006',28606,35730);
INSERT INTO "django_geo_db_zipcode" VALUES(40770,95007,-8,'Brookdale, California 95007',28607,35731);
INSERT INTO "django_geo_db_zipcode" VALUES(40771,95008,-8,'Campbell, California 95008',28608,35732);
INSERT INTO "django_geo_db_zipcode" VALUES(40772,95009,-8,'Campbell, California 95009',28608,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40773,95010,-8,'Capitola, California 95010',28609,35733);
INSERT INTO "django_geo_db_zipcode" VALUES(40774,95011,-8,'Campbell, California 95011',28608,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40775,95012,-8,'Castroville, California 95012',28610,35734);
INSERT INTO "django_geo_db_zipcode" VALUES(40776,95013,-8,'Coyote, California 95013',28611,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40777,95014,-8,'Cupertino, California 95014',28612,35735);
INSERT INTO "django_geo_db_zipcode" VALUES(40778,95015,-8,'Cupertino, California 95015',28612,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40779,95017,-8,'Davenport, California 95017',28613,35736);
INSERT INTO "django_geo_db_zipcode" VALUES(40780,95018,-8,'Felton, California 95018',28614,35737);
INSERT INTO "django_geo_db_zipcode" VALUES(40781,95019,-8,'Freedom, California 95019',28615,35738);
INSERT INTO "django_geo_db_zipcode" VALUES(40782,95020,-8,'Gilroy, California 95020',28616,35739);
INSERT INTO "django_geo_db_zipcode" VALUES(40783,95021,-8,'Gilroy, California 95021',28616,35740);
INSERT INTO "django_geo_db_zipcode" VALUES(40784,95022,-8,'Palo Alto, California 95022',28502,35741);
INSERT INTO "django_geo_db_zipcode" VALUES(40785,95023,-8,'Hollister, California 95023',28617,35742);
INSERT INTO "django_geo_db_zipcode" VALUES(40786,95024,-8,'Hollister, California 95024',28617,35743);
INSERT INTO "django_geo_db_zipcode" VALUES(40787,95026,-8,'Holy City, California 95026',28618,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40788,95030,-8,'Los Gatos, California 95030',28619,35744);
INSERT INTO "django_geo_db_zipcode" VALUES(40789,95031,-8,'Los Gatos, California 95031',28619,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40790,95032,-8,'Los Gatos, California 95032',28619,35745);
INSERT INTO "django_geo_db_zipcode" VALUES(40791,95033,-8,'Los Gatos, California 95033',28619,35746);
INSERT INTO "django_geo_db_zipcode" VALUES(40792,95035,-8,'Milpitas, California 95035',28620,35747);
INSERT INTO "django_geo_db_zipcode" VALUES(40793,95036,-8,'Milpitas, California 95036',28620,35748);
INSERT INTO "django_geo_db_zipcode" VALUES(40794,95037,-8,'Morgan Hill, California 95037',28621,35749);
INSERT INTO "django_geo_db_zipcode" VALUES(40795,95038,-8,'Morgan Hill, California 95038',28621,35750);
INSERT INTO "django_geo_db_zipcode" VALUES(40796,95039,-8,'Moss Landing, California 95039',28622,35751);
INSERT INTO "django_geo_db_zipcode" VALUES(40797,95041,-8,'Mount Hermon, California 95041',28623,35752);
INSERT INTO "django_geo_db_zipcode" VALUES(40798,95042,-8,'New Almaden, California 95042',28624,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40799,95043,-8,'Paicines, California 95043',28625,35753);
INSERT INTO "django_geo_db_zipcode" VALUES(40800,95044,-8,'Redwood Estates, California 95044',28626,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40801,95045,-8,'San Juan Bautista, California 95045',28627,35754);
INSERT INTO "django_geo_db_zipcode" VALUES(40802,95046,-8,'San Martin, California 95046',28628,35755);
INSERT INTO "django_geo_db_zipcode" VALUES(40803,95050,-8,'Santa Clara, California 95050',28629,35756);
INSERT INTO "django_geo_db_zipcode" VALUES(40804,95051,-8,'Santa Clara, California 95051',28629,35757);
INSERT INTO "django_geo_db_zipcode" VALUES(40805,95052,-8,'Santa Clara, California 95052',28629,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40806,95053,-8,'Santa Clara, California 95053',28629,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40807,95054,-8,'Santa Clara, California 95054',28629,35758);
INSERT INTO "django_geo_db_zipcode" VALUES(40808,95055,-8,'Santa Clara, California 95055',28629,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40809,95056,-8,'Santa Clara, California 95056',28629,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40810,95060,-8,'Santa Cruz, California 95060',28630,35759);
INSERT INTO "django_geo_db_zipcode" VALUES(40811,95061,-8,'Santa Cruz, California 95061',28630,35760);
INSERT INTO "django_geo_db_zipcode" VALUES(40812,95062,-8,'Santa Cruz, California 95062',28630,35761);
INSERT INTO "django_geo_db_zipcode" VALUES(40813,95063,-8,'Santa Cruz, California 95063',28630,35762);
INSERT INTO "django_geo_db_zipcode" VALUES(40814,95064,-8,'Santa Cruz, California 95064',28630,35763);
INSERT INTO "django_geo_db_zipcode" VALUES(40815,95065,-8,'Santa Cruz, California 95065',28630,35764);
INSERT INTO "django_geo_db_zipcode" VALUES(40816,95066,-8,'Scotts Valley, California 95066',28631,35765);
INSERT INTO "django_geo_db_zipcode" VALUES(40817,95067,-8,'Scotts Valley, California 95067',28631,35725);
INSERT INTO "django_geo_db_zipcode" VALUES(40818,95070,-8,'Saratoga, California 95070',28632,35766);
INSERT INTO "django_geo_db_zipcode" VALUES(40819,95071,-8,'Saratoga, California 95071',28632,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40820,95073,-8,'Soquel, California 95073',28633,35767);
INSERT INTO "django_geo_db_zipcode" VALUES(40821,95075,-8,'Tres Pinos, California 95075',28634,35768);
INSERT INTO "django_geo_db_zipcode" VALUES(40822,95076,-8,'Watsonville, California 95076',28635,35769);
INSERT INTO "django_geo_db_zipcode" VALUES(40823,95077,-8,'Watsonville, California 95077',28635,35725);
INSERT INTO "django_geo_db_zipcode" VALUES(40824,95101,-8,'San Jose, California 95101',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40825,95102,-8,'San Jose, California 95102',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40826,95103,-8,'San Jose, California 95103',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40827,95106,-8,'San Jose, California 95106',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40828,95108,-8,'San Jose, California 95108',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40829,95109,-8,'San Jose, California 95109',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40830,95110,-8,'San Jose, California 95110',28636,35770);
INSERT INTO "django_geo_db_zipcode" VALUES(40831,95111,-8,'San Jose, California 95111',28636,35771);
INSERT INTO "django_geo_db_zipcode" VALUES(40832,95112,-8,'San Jose, California 95112',28636,35772);
INSERT INTO "django_geo_db_zipcode" VALUES(40833,95113,-8,'San Jose, California 95113',28636,35773);
INSERT INTO "django_geo_db_zipcode" VALUES(40834,95114,-8,'San Jose, California 95114',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40835,95115,-8,'San Jose, California 95115',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40836,95116,-8,'San Jose, California 95116',28636,35774);
INSERT INTO "django_geo_db_zipcode" VALUES(40837,95117,-8,'San Jose, California 95117',28636,35775);
INSERT INTO "django_geo_db_zipcode" VALUES(40838,95118,-8,'San Jose, California 95118',28636,35776);
INSERT INTO "django_geo_db_zipcode" VALUES(40839,95119,-8,'San Jose, California 95119',28636,35777);
INSERT INTO "django_geo_db_zipcode" VALUES(40840,95120,-8,'San Jose, California 95120',28636,35778);
INSERT INTO "django_geo_db_zipcode" VALUES(40841,95121,-8,'San Jose, California 95121',28636,35779);
INSERT INTO "django_geo_db_zipcode" VALUES(40842,95122,-8,'San Jose, California 95122',28636,35780);
INSERT INTO "django_geo_db_zipcode" VALUES(40843,95123,-8,'San Jose, California 95123',28636,35781);
INSERT INTO "django_geo_db_zipcode" VALUES(40844,95124,-8,'San Jose, California 95124',28636,35782);
INSERT INTO "django_geo_db_zipcode" VALUES(40845,95125,-8,'San Jose, California 95125',28636,35783);
INSERT INTO "django_geo_db_zipcode" VALUES(40846,95126,-8,'San Jose, California 95126',28636,35784);
INSERT INTO "django_geo_db_zipcode" VALUES(40847,95127,-8,'San Jose, California 95127',28636,35785);
INSERT INTO "django_geo_db_zipcode" VALUES(40848,95128,-8,'San Jose, California 95128',28636,35786);
INSERT INTO "django_geo_db_zipcode" VALUES(40849,95129,-8,'San Jose, California 95129',28636,35787);
INSERT INTO "django_geo_db_zipcode" VALUES(40850,95130,-8,'San Jose, California 95130',28636,35788);
INSERT INTO "django_geo_db_zipcode" VALUES(40851,95131,-8,'San Jose, California 95131',28636,35789);
INSERT INTO "django_geo_db_zipcode" VALUES(40852,95132,-8,'San Jose, California 95132',28636,35790);
INSERT INTO "django_geo_db_zipcode" VALUES(40853,95133,-8,'San Jose, California 95133',28636,35791);
INSERT INTO "django_geo_db_zipcode" VALUES(40854,95134,-8,'San Jose, California 95134',28636,35792);
INSERT INTO "django_geo_db_zipcode" VALUES(40855,95135,-8,'San Jose, California 95135',28636,35793);
INSERT INTO "django_geo_db_zipcode" VALUES(40856,95136,-8,'San Jose, California 95136',28636,35794);
INSERT INTO "django_geo_db_zipcode" VALUES(40857,95137,-8,'San Jose, California 95137',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40858,95138,-8,'San Jose, California 95138',28636,35795);
INSERT INTO "django_geo_db_zipcode" VALUES(40859,95139,-8,'San Jose, California 95139',28636,35796);
INSERT INTO "django_geo_db_zipcode" VALUES(40860,95140,-8,'Mount Hamilton, California 95140',28637,35797);
INSERT INTO "django_geo_db_zipcode" VALUES(40861,95141,-8,'San Jose, California 95141',28636,35798);
INSERT INTO "django_geo_db_zipcode" VALUES(40862,95142,-8,'San Jose, California 95142',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40863,95148,-8,'San Jose, California 95148',28636,35799);
INSERT INTO "django_geo_db_zipcode" VALUES(40864,95150,-8,'San Jose, California 95150',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40865,95151,-8,'San Jose, California 95151',28636,35800);
INSERT INTO "django_geo_db_zipcode" VALUES(40866,95152,-8,'San Jose, California 95152',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40867,95153,-8,'San Jose, California 95153',28636,35801);
INSERT INTO "django_geo_db_zipcode" VALUES(40868,95154,-8,'San Jose, California 95154',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40869,95155,-8,'San Jose, California 95155',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40870,95156,-8,'San Jose, California 95156',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40871,95157,-8,'San Jose, California 95157',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40872,95158,-8,'San Jose, California 95158',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40873,95159,-8,'San Jose, California 95159',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40874,95160,-8,'San Jose, California 95160',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40875,95161,-8,'San Jose, California 95161',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40876,95164,-8,'San Jose, California 95164',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40877,95170,-8,'San Jose, California 95170',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40878,95171,-8,'San Jose, California 95171',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40879,95172,-8,'San Jose, California 95172',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40880,95173,-8,'San Jose, California 95173',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40881,95190,-8,'San Jose, California 95190',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40882,95191,-8,'San Jose, California 95191',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40883,95192,-8,'San Jose, California 95192',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40884,95193,-8,'San Jose, California 95193',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40885,95194,-8,'San Jose, California 95194',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40886,95196,-8,'San Jose, California 95196',28636,35498);
INSERT INTO "django_geo_db_zipcode" VALUES(40887,95201,-8,'Stockton, California 95201',28638,35802);
INSERT INTO "django_geo_db_zipcode" VALUES(40888,95202,-8,'Stockton, California 95202',28638,35803);
INSERT INTO "django_geo_db_zipcode" VALUES(40889,95203,-8,'Stockton, California 95203',28638,35804);
INSERT INTO "django_geo_db_zipcode" VALUES(40890,95204,-8,'Stockton, California 95204',28638,35805);
INSERT INTO "django_geo_db_zipcode" VALUES(40891,95205,-8,'Stockton, California 95205',28638,35806);
INSERT INTO "django_geo_db_zipcode" VALUES(40892,95206,-8,'Stockton, California 95206',28638,35807);
INSERT INTO "django_geo_db_zipcode" VALUES(40893,95207,-8,'Stockton, California 95207',28638,35808);
INSERT INTO "django_geo_db_zipcode" VALUES(40894,95208,-8,'Stockton, California 95208',28638,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40895,95209,-8,'Stockton, California 95209',28638,35810);
INSERT INTO "django_geo_db_zipcode" VALUES(40896,95210,-8,'Stockton, California 95210',28638,35811);
INSERT INTO "django_geo_db_zipcode" VALUES(40897,95211,-8,'Stockton, California 95211',28638,35812);
INSERT INTO "django_geo_db_zipcode" VALUES(40898,95212,-8,'Stockton, California 95212',28638,35813);
INSERT INTO "django_geo_db_zipcode" VALUES(40899,95213,-8,'Stockton, California 95213',28638,35814);
INSERT INTO "django_geo_db_zipcode" VALUES(40900,95215,-8,'Stockton, California 95215',28638,35815);
INSERT INTO "django_geo_db_zipcode" VALUES(40901,95219,-8,'Stockton, California 95219',28638,35816);
INSERT INTO "django_geo_db_zipcode" VALUES(40902,95220,-8,'Acampo, California 95220',28639,35817);
INSERT INTO "django_geo_db_zipcode" VALUES(40903,95221,-8,'Altaville, California 95221',28640,35818);
INSERT INTO "django_geo_db_zipcode" VALUES(40904,95222,-8,'Angels Camp, California 95222',28641,35819);
INSERT INTO "django_geo_db_zipcode" VALUES(40905,95223,-8,'Arnold, California 95223',28642,35820);
INSERT INTO "django_geo_db_zipcode" VALUES(40906,95224,-8,'Avery, California 95224',28643,35821);
INSERT INTO "django_geo_db_zipcode" VALUES(40907,95225,-8,'Burson, California 95225',28644,35822);
INSERT INTO "django_geo_db_zipcode" VALUES(40908,95226,-8,'Campo Seco, California 95226',28645,35823);
INSERT INTO "django_geo_db_zipcode" VALUES(40909,95227,-8,'Clements, California 95227',28646,35824);
INSERT INTO "django_geo_db_zipcode" VALUES(40910,95228,-8,'Copperopolis, California 95228',28647,35825);
INSERT INTO "django_geo_db_zipcode" VALUES(40911,95229,-8,'Douglas Flat, California 95229',28648,35826);
INSERT INTO "django_geo_db_zipcode" VALUES(40912,95230,-8,'Farmington, California 95230',28649,35827);
INSERT INTO "django_geo_db_zipcode" VALUES(40913,95231,-8,'French Camp, California 95231',28650,35828);
INSERT INTO "django_geo_db_zipcode" VALUES(40914,95232,-8,'Glencoe, California 95232',28651,35829);
INSERT INTO "django_geo_db_zipcode" VALUES(40915,95233,-8,'Hathaway Pines, California 95233',28652,35830);
INSERT INTO "django_geo_db_zipcode" VALUES(40916,95234,-8,'Holt, California 95234',28653,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40917,95236,-8,'Linden, California 95236',28654,35831);
INSERT INTO "django_geo_db_zipcode" VALUES(40918,95237,-8,'Lockeford, California 95237',28655,35832);
INSERT INTO "django_geo_db_zipcode" VALUES(40919,95240,-8,'Lodi, California 95240',28656,35833);
INSERT INTO "django_geo_db_zipcode" VALUES(40920,95241,-8,'Lodi, California 95241',28656,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40921,95242,-8,'Lodi, California 95242',28656,35834);
INSERT INTO "django_geo_db_zipcode" VALUES(40922,95245,-8,'Mokelumne Hill, California 95245',28657,35835);
INSERT INTO "django_geo_db_zipcode" VALUES(40923,95246,-8,'Mountain Ranch, California 95246',28658,35836);
INSERT INTO "django_geo_db_zipcode" VALUES(40924,95247,-8,'Murphys, California 95247',28659,35837);
INSERT INTO "django_geo_db_zipcode" VALUES(40925,95248,-8,'Rail Road Flat, California 95248',28660,35838);
INSERT INTO "django_geo_db_zipcode" VALUES(40926,95249,-8,'San Andreas, California 95249',28661,35839);
INSERT INTO "django_geo_db_zipcode" VALUES(40927,95250,-8,'Sheep Ranch, California 95250',28662,35840);
INSERT INTO "django_geo_db_zipcode" VALUES(40928,95251,-8,'Vallecito, California 95251',28663,35841);
INSERT INTO "django_geo_db_zipcode" VALUES(40929,95252,-8,'Valley Springs, California 95252',28664,35842);
INSERT INTO "django_geo_db_zipcode" VALUES(40930,95253,-8,'Victor, California 95253',28665,35843);
INSERT INTO "django_geo_db_zipcode" VALUES(40931,95254,-8,'Wallace, California 95254',28666,35844);
INSERT INTO "django_geo_db_zipcode" VALUES(40932,95255,-8,'West Point, California 95255',28667,35845);
INSERT INTO "django_geo_db_zipcode" VALUES(40933,95257,-8,'Wilseyville, California 95257',28668,35846);
INSERT INTO "django_geo_db_zipcode" VALUES(40934,95258,-8,'Woodbridge, California 95258',28669,35847);
INSERT INTO "django_geo_db_zipcode" VALUES(40935,95267,-8,'Stockton, California 95267',28638,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40936,95269,-8,'Stockton, California 95269',28638,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40937,95290,-8,'Stockton, California 95290',28638,35848);
INSERT INTO "django_geo_db_zipcode" VALUES(40938,95296,-8,'Lyoth, California 95296',28670,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40939,95297,-8,'Stockton, California 95297',28638,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40940,95298,-8,'Stockton, California 95298',28638,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40941,95301,-8,'Atwater, California 95301',28671,35849);
INSERT INTO "django_geo_db_zipcode" VALUES(40942,95303,-8,'Ballico, California 95303',28672,35850);
INSERT INTO "django_geo_db_zipcode" VALUES(40943,95304,-8,'Banta, California 95304',28673,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(40944,95305,-8,'Big Oak Flat, California 95305',28674,35851);
INSERT INTO "django_geo_db_zipcode" VALUES(40945,95306,-8,'Catheys Valley, California 95306',28675,35852);
INSERT INTO "django_geo_db_zipcode" VALUES(40946,95307,-8,'Ceres, California 95307',28676,35853);
INSERT INTO "django_geo_db_zipcode" VALUES(40947,95309,-8,'Chinese Camp, California 95309',28677,35854);
INSERT INTO "django_geo_db_zipcode" VALUES(40948,95310,-8,'Columbia, California 95310',28678,35855);
INSERT INTO "django_geo_db_zipcode" VALUES(40949,95311,-8,'Coulterville, California 95311',28679,35856);
INSERT INTO "django_geo_db_zipcode" VALUES(40950,95312,-8,'Cressey, California 95312',28680,35857);
INSERT INTO "django_geo_db_zipcode" VALUES(40951,95313,-8,'Crows Landing, California 95313',28681,35858);
INSERT INTO "django_geo_db_zipcode" VALUES(40952,95314,-8,'Dardanelle, California 95314',28682,35859);
INSERT INTO "django_geo_db_zipcode" VALUES(40953,95315,-8,'Delhi, California 95315',28683,35860);
INSERT INTO "django_geo_db_zipcode" VALUES(40954,95316,-8,'Denair, California 95316',28684,35861);
INSERT INTO "django_geo_db_zipcode" VALUES(40955,95317,-8,'El Nido, California 95317',28685,35862);
INSERT INTO "django_geo_db_zipcode" VALUES(40956,95318,-8,'El Portal, California 95318',28686,35863);
INSERT INTO "django_geo_db_zipcode" VALUES(40957,95319,-8,'Empire, California 95319',28687,35864);
INSERT INTO "django_geo_db_zipcode" VALUES(40958,95320,-8,'Escalon, California 95320',28688,35865);
INSERT INTO "django_geo_db_zipcode" VALUES(40959,95321,-8,'Groveland, California 95321',28689,35866);
INSERT INTO "django_geo_db_zipcode" VALUES(40960,95322,-8,'Gustine, California 95322',28690,35867);
INSERT INTO "django_geo_db_zipcode" VALUES(40961,95323,-8,'Hickman, California 95323',28691,35868);
INSERT INTO "django_geo_db_zipcode" VALUES(40962,95324,-8,'Hilmar, California 95324',28692,35869);
INSERT INTO "django_geo_db_zipcode" VALUES(40963,95325,-8,'Hornitos, California 95325',28693,35870);
INSERT INTO "django_geo_db_zipcode" VALUES(40964,95326,-8,'Hughson, California 95326',28694,35871);
INSERT INTO "django_geo_db_zipcode" VALUES(40965,95327,-8,'Jamestown, California 95327',28695,35872);
INSERT INTO "django_geo_db_zipcode" VALUES(40966,95328,-8,'Keyes, California 95328',28696,35873);
INSERT INTO "django_geo_db_zipcode" VALUES(40967,95329,-8,'La Grange, California 95329',28697,35874);
INSERT INTO "django_geo_db_zipcode" VALUES(40968,95330,-8,'Lathrop, California 95330',28698,35875);
INSERT INTO "django_geo_db_zipcode" VALUES(40969,95333,-8,'Le Grand, California 95333',28699,35876);
INSERT INTO "django_geo_db_zipcode" VALUES(40970,95334,-8,'Livingston, California 95334',28700,35877);
INSERT INTO "django_geo_db_zipcode" VALUES(40971,95335,-8,'Long Barn, California 95335',28701,35878);
INSERT INTO "django_geo_db_zipcode" VALUES(40972,95336,-8,'Manteca, California 95336',28702,35879);
INSERT INTO "django_geo_db_zipcode" VALUES(40973,95337,-8,'Manteca, California 95337',28702,35880);
INSERT INTO "django_geo_db_zipcode" VALUES(40974,95338,-8,'Mariposa, California 95338',28703,35881);
INSERT INTO "django_geo_db_zipcode" VALUES(40975,95340,-8,'Merced, California 95340',28704,35882);
INSERT INTO "django_geo_db_zipcode" VALUES(40976,95341,-8,'Merced, California 95341',28704,35433);
INSERT INTO "django_geo_db_zipcode" VALUES(40977,95342,-8,'Atwater, California 95342',28671,35883);
INSERT INTO "django_geo_db_zipcode" VALUES(40978,95343,-8,'Merced, California 95343',28704,35433);
INSERT INTO "django_geo_db_zipcode" VALUES(40979,95344,-8,'Merced, California 95344',28704,35884);
INSERT INTO "django_geo_db_zipcode" VALUES(40980,95345,-8,'Midpines, California 95345',28705,35885);
INSERT INTO "django_geo_db_zipcode" VALUES(40981,95346,-8,'Mi Wuk Village, California 95346',28706,35886);
INSERT INTO "django_geo_db_zipcode" VALUES(40982,95347,-8,'Moccasin, California 95347',28707,35887);
INSERT INTO "django_geo_db_zipcode" VALUES(40983,95348,-8,'Merced, California 95348',28704,35888);
INSERT INTO "django_geo_db_zipcode" VALUES(40984,95350,-8,'Modesto, California 95350',28708,35889);
INSERT INTO "django_geo_db_zipcode" VALUES(40985,95351,-8,'Modesto, California 95351',28708,35890);
INSERT INTO "django_geo_db_zipcode" VALUES(40986,95352,-8,'Modesto, California 95352',28708,35891);
INSERT INTO "django_geo_db_zipcode" VALUES(40987,95353,-8,'Modesto, California 95353',28708,35891);
INSERT INTO "django_geo_db_zipcode" VALUES(40988,95354,-8,'Modesto, California 95354',28708,35892);
INSERT INTO "django_geo_db_zipcode" VALUES(40989,95355,-8,'Modesto, California 95355',28708,35893);
INSERT INTO "django_geo_db_zipcode" VALUES(40990,95356,-8,'Modesto, California 95356',28708,35894);
INSERT INTO "django_geo_db_zipcode" VALUES(40991,95357,-8,'Modesto, California 95357',28708,35895);
INSERT INTO "django_geo_db_zipcode" VALUES(40992,95358,-8,'Modesto, California 95358',28708,35896);
INSERT INTO "django_geo_db_zipcode" VALUES(40993,95360,-8,'Newman, California 95360',28709,35897);
INSERT INTO "django_geo_db_zipcode" VALUES(40994,95361,-8,'Oakdale, California 95361',28710,35898);
INSERT INTO "django_geo_db_zipcode" VALUES(40995,95363,-8,'Patterson, California 95363',28711,35899);
INSERT INTO "django_geo_db_zipcode" VALUES(40996,95364,-8,'Pinecrest, California 95364',28712,35900);
INSERT INTO "django_geo_db_zipcode" VALUES(40997,95365,-8,'Planada, California 95365',28713,35901);
INSERT INTO "django_geo_db_zipcode" VALUES(40998,95366,-8,'Ripon, California 95366',28714,35902);
INSERT INTO "django_geo_db_zipcode" VALUES(40999,95367,-8,'Riverbank, California 95367',28715,35903);
INSERT INTO "django_geo_db_zipcode" VALUES(41000,95368,-8,'Salida, California 95368',28716,35904);
INSERT INTO "django_geo_db_zipcode" VALUES(41001,95369,-8,'Snelling, California 95369',28717,35905);
INSERT INTO "django_geo_db_zipcode" VALUES(41002,95370,-8,'Sonora, California 95370',28718,35906);
INSERT INTO "django_geo_db_zipcode" VALUES(41003,95372,-8,'Soulsbyville, California 95372',28719,35907);
INSERT INTO "django_geo_db_zipcode" VALUES(41004,95373,-8,'Standard, California 95373',28720,35908);
INSERT INTO "django_geo_db_zipcode" VALUES(41005,95374,-8,'Stevinson, California 95374',28721,35909);
INSERT INTO "django_geo_db_zipcode" VALUES(41006,95375,-8,'Strawberry, California 95375',28722,35910);
INSERT INTO "django_geo_db_zipcode" VALUES(41007,95376,-8,'Tracy, California 95376',28723,35911);
INSERT INTO "django_geo_db_zipcode" VALUES(41008,95377,-8,'Tracy, California 95377',28723,35912);
INSERT INTO "django_geo_db_zipcode" VALUES(41009,95378,-8,'Tracy, California 95378',28723,35809);
INSERT INTO "django_geo_db_zipcode" VALUES(41010,95379,-8,'Tuolumne, California 95379',28724,35913);
INSERT INTO "django_geo_db_zipcode" VALUES(41011,95380,-8,'Turlock, California 95380',28725,35914);
INSERT INTO "django_geo_db_zipcode" VALUES(41012,95381,-8,'Turlock, California 95381',28725,35891);
INSERT INTO "django_geo_db_zipcode" VALUES(41013,95382,-8,'Turlock, California 95382',28725,35915);
INSERT INTO "django_geo_db_zipcode" VALUES(41014,95383,-8,'Twain Harte, California 95383',28726,35916);
INSERT INTO "django_geo_db_zipcode" VALUES(41015,95385,-8,'Vernalis, California 95385',28727,35917);
INSERT INTO "django_geo_db_zipcode" VALUES(41016,95386,-8,'Waterford, California 95386',28728,35918);
INSERT INTO "django_geo_db_zipcode" VALUES(41017,95387,-8,'Westley, California 95387',28729,35919);
INSERT INTO "django_geo_db_zipcode" VALUES(41018,95388,-8,'Winton, California 95388',28730,35920);
INSERT INTO "django_geo_db_zipcode" VALUES(41019,95389,-8,'Yosemite National Park, California 95389',28731,35921);
INSERT INTO "django_geo_db_zipcode" VALUES(41020,95390,-8,'Riverbank, California 95390',28715,35891);
INSERT INTO "django_geo_db_zipcode" VALUES(41021,95397,-8,'Modesto, California 95397',28708,35891);
INSERT INTO "django_geo_db_zipcode" VALUES(41022,95401,-8,'Santa Rosa, California 95401',28732,35922);
INSERT INTO "django_geo_db_zipcode" VALUES(41023,95402,-8,'Santa Rosa, California 95402',28732,35923);
INSERT INTO "django_geo_db_zipcode" VALUES(41024,95403,-8,'Santa Rosa, California 95403',28732,35924);
INSERT INTO "django_geo_db_zipcode" VALUES(41025,95404,-8,'Santa Rosa, California 95404',28732,35925);
INSERT INTO "django_geo_db_zipcode" VALUES(41026,95405,-8,'Santa Rosa, California 95405',28732,35926);
INSERT INTO "django_geo_db_zipcode" VALUES(41027,95406,-8,'Santa Rosa, California 95406',28732,35927);
INSERT INTO "django_geo_db_zipcode" VALUES(41028,95407,-8,'Santa Rosa, California 95407',28732,35928);
INSERT INTO "django_geo_db_zipcode" VALUES(41029,95408,-8,'Santa Rosa, California 95408',28732,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(41030,95409,-8,'Santa Rosa, California 95409',28732,35929);
INSERT INTO "django_geo_db_zipcode" VALUES(41031,95410,-8,'Albion, California 95410',28733,35930);
INSERT INTO "django_geo_db_zipcode" VALUES(41032,95412,-8,'Annapolis, California 95412',28734,35931);
INSERT INTO "django_geo_db_zipcode" VALUES(41033,95415,-8,'Boonville, California 95415',28735,35932);
INSERT INTO "django_geo_db_zipcode" VALUES(41034,95416,-8,'Boyes Hot Springs, California 95416',28736,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(41035,95417,-8,'Branscomb, California 95417',28737,35933);
INSERT INTO "django_geo_db_zipcode" VALUES(41036,95418,-8,'Calpella, California 95418',28738,35934);
INSERT INTO "django_geo_db_zipcode" VALUES(41037,95419,-8,'Camp Meeker, California 95419',28739,35935);
INSERT INTO "django_geo_db_zipcode" VALUES(41038,95420,-8,'Caspar, California 95420',28740,35936);
INSERT INTO "django_geo_db_zipcode" VALUES(41039,95421,-8,'Cazadero, California 95421',28741,35937);
INSERT INTO "django_geo_db_zipcode" VALUES(41040,95422,-8,'Clearlake, California 95422',28742,35938);
INSERT INTO "django_geo_db_zipcode" VALUES(41041,95423,-8,'Clearlake Oaks, California 95423',28743,35939);
INSERT INTO "django_geo_db_zipcode" VALUES(41042,95424,-8,'Clearlake Park, California 95424',28744,35940);
INSERT INTO "django_geo_db_zipcode" VALUES(41043,95425,-8,'Cloverdale, California 95425',28745,35941);
INSERT INTO "django_geo_db_zipcode" VALUES(41044,95426,-8,'Cobb, California 95426',28746,35942);
INSERT INTO "django_geo_db_zipcode" VALUES(41045,95427,-8,'Comptche, California 95427',28747,35943);
INSERT INTO "django_geo_db_zipcode" VALUES(41046,95428,-8,'Covelo, California 95428',28748,35944);
INSERT INTO "django_geo_db_zipcode" VALUES(41047,95429,-8,'Dos Rios, California 95429',28749,35945);
INSERT INTO "django_geo_db_zipcode" VALUES(41048,95430,-8,'Duncans Mills, California 95430',28750,35946);
INSERT INTO "django_geo_db_zipcode" VALUES(41049,95431,-8,'Eldridge, California 95431',28751,35947);
INSERT INTO "django_geo_db_zipcode" VALUES(41050,95432,-8,'Elk, California 95432',28752,35948);
INSERT INTO "django_geo_db_zipcode" VALUES(41051,95433,-8,'El Verano, California 95433',28753,35949);
INSERT INTO "django_geo_db_zipcode" VALUES(41052,95435,-8,'Finley, California 95435',28754,35950);
INSERT INTO "django_geo_db_zipcode" VALUES(41053,95436,-8,'Forestville, California 95436',28755,35951);
INSERT INTO "django_geo_db_zipcode" VALUES(41054,95437,-8,'Fort Bragg, California 95437',28756,35952);
INSERT INTO "django_geo_db_zipcode" VALUES(41055,95439,-8,'Fulton, California 95439',28757,35953);
INSERT INTO "django_geo_db_zipcode" VALUES(41056,95441,-8,'Geyserville, California 95441',28758,35954);
INSERT INTO "django_geo_db_zipcode" VALUES(41057,95442,-8,'Glen Ellen, California 95442',28759,35955);
INSERT INTO "django_geo_db_zipcode" VALUES(41058,95443,-8,'Glenhaven, California 95443',28760,35956);
INSERT INTO "django_geo_db_zipcode" VALUES(41059,95444,-8,'Graton, California 95444',28761,35957);
INSERT INTO "django_geo_db_zipcode" VALUES(41060,95445,-8,'Gualala, California 95445',28762,35958);
INSERT INTO "django_geo_db_zipcode" VALUES(41061,95446,-8,'Guerneville, California 95446',28763,35959);
INSERT INTO "django_geo_db_zipcode" VALUES(41062,95448,-8,'Healdsburg, California 95448',28764,35960);
INSERT INTO "django_geo_db_zipcode" VALUES(41063,95449,-8,'Hopland, California 95449',28765,35961);
INSERT INTO "django_geo_db_zipcode" VALUES(41064,95450,-8,'Jenner, California 95450',28766,35962);
INSERT INTO "django_geo_db_zipcode" VALUES(41065,95451,-8,'Kelseyville, California 95451',28767,35963);
INSERT INTO "django_geo_db_zipcode" VALUES(41066,95452,-8,'Kenwood, California 95452',28768,35964);
INSERT INTO "django_geo_db_zipcode" VALUES(41067,95453,-8,'Lakeport, California 95453',28769,35965);
INSERT INTO "django_geo_db_zipcode" VALUES(41068,95454,-8,'Laytonville, California 95454',28770,35966);
INSERT INTO "django_geo_db_zipcode" VALUES(41069,95456,-8,'Littleriver, California 95456',28771,35967);
INSERT INTO "django_geo_db_zipcode" VALUES(41070,95457,-8,'Lower Lake, California 95457',28772,35968);
INSERT INTO "django_geo_db_zipcode" VALUES(41071,95458,-8,'Lucerne, California 95458',28773,35969);
INSERT INTO "django_geo_db_zipcode" VALUES(41072,95459,-8,'Manchester, California 95459',28774,35970);
INSERT INTO "django_geo_db_zipcode" VALUES(41073,95460,-8,'Mendocino, California 95460',28775,35971);
INSERT INTO "django_geo_db_zipcode" VALUES(41074,95461,-8,'Middletown, California 95461',28776,35972);
INSERT INTO "django_geo_db_zipcode" VALUES(41075,95462,-8,'Monte Rio, California 95462',28777,35973);
INSERT INTO "django_geo_db_zipcode" VALUES(41076,95463,-8,'Navarro, California 95463',28778,35974);
INSERT INTO "django_geo_db_zipcode" VALUES(41077,95464,-8,'Nice, California 95464',28779,35975);
INSERT INTO "django_geo_db_zipcode" VALUES(41078,95465,-8,'Occidental, California 95465',28780,35976);
INSERT INTO "django_geo_db_zipcode" VALUES(41079,95466,-8,'Philo, California 95466',28781,35977);
INSERT INTO "django_geo_db_zipcode" VALUES(41080,95468,-8,'Point Arena, California 95468',28782,35978);
INSERT INTO "django_geo_db_zipcode" VALUES(41081,95469,-8,'Potter Valley, California 95469',28783,35979);
INSERT INTO "django_geo_db_zipcode" VALUES(41082,95470,-8,'Redwood Valley, California 95470',28784,35980);
INSERT INTO "django_geo_db_zipcode" VALUES(41083,95471,-8,'Rio Nido, California 95471',28785,35981);
INSERT INTO "django_geo_db_zipcode" VALUES(41084,95472,-8,'Sebastopol, California 95472',28786,35982);
INSERT INTO "django_geo_db_zipcode" VALUES(41085,95473,-8,'Sebastopol, California 95473',28786,35983);
INSERT INTO "django_geo_db_zipcode" VALUES(41086,95476,-8,'Sonoma, California 95476',28787,35984);
INSERT INTO "django_geo_db_zipcode" VALUES(41087,95480,-8,'Stewarts Point, California 95480',28788,35985);
INSERT INTO "django_geo_db_zipcode" VALUES(41088,95481,-8,'Talmage, California 95481',28789,35986);
INSERT INTO "django_geo_db_zipcode" VALUES(41089,95482,-8,'Ukiah, California 95482',28790,35987);
INSERT INTO "django_geo_db_zipcode" VALUES(41090,95485,-8,'Upper Lake, California 95485',28791,35988);
INSERT INTO "django_geo_db_zipcode" VALUES(41091,95486,-8,'Villa Grande, California 95486',28792,35989);
INSERT INTO "django_geo_db_zipcode" VALUES(41092,95487,-8,'Vineburg, California 95487',28793,35692);
INSERT INTO "django_geo_db_zipcode" VALUES(41093,95488,-8,'Westport, California 95488',28794,35990);
INSERT INTO "django_geo_db_zipcode" VALUES(41094,95490,-8,'Willits, California 95490',28795,35991);
INSERT INTO "django_geo_db_zipcode" VALUES(41095,95492,-8,'Windsor, California 95492',28796,35992);
INSERT INTO "django_geo_db_zipcode" VALUES(41096,95493,-8,'Witter Springs, California 95493',28797,35993);
INSERT INTO "django_geo_db_zipcode" VALUES(41097,95494,-8,'Yorkville, California 95494',28798,35994);
INSERT INTO "django_geo_db_zipcode" VALUES(41098,95497,-8,'The Sea Ranch, California 95497',28799,35995);
INSERT INTO "django_geo_db_zipcode" VALUES(41099,95501,-8,'Eureka, California 95501',28800,35996);
INSERT INTO "django_geo_db_zipcode" VALUES(41100,95502,-8,'Eureka, California 95502',28800,35997);
INSERT INTO "django_geo_db_zipcode" VALUES(41101,95503,-8,'Eureka, California 95503',28800,35998);
INSERT INTO "django_geo_db_zipcode" VALUES(41102,95511,-8,'Alderpoint, California 95511',28801,35999);
INSERT INTO "django_geo_db_zipcode" VALUES(41103,95514,-8,'Blocksburg, California 95514',28802,36000);
INSERT INTO "django_geo_db_zipcode" VALUES(41104,95517,-8,'Diamond Springs, California 95517',28803,36001);
INSERT INTO "django_geo_db_zipcode" VALUES(41105,95518,-8,'Arcata, California 95518',28804,36002);
INSERT INTO "django_geo_db_zipcode" VALUES(41106,95519,-8,'Mckinleyville, California 95519',28805,36003);
INSERT INTO "django_geo_db_zipcode" VALUES(41107,95521,-8,'Arcata, California 95521',28804,36004);
INSERT INTO "django_geo_db_zipcode" VALUES(41108,95522,-8,'Arcata, California 95522',28804,36005);
INSERT INTO "django_geo_db_zipcode" VALUES(41109,95524,-8,'Bayside, California 95524',28806,36006);
INSERT INTO "django_geo_db_zipcode" VALUES(41110,95525,-8,'Blue Lake, California 95525',28807,36007);
INSERT INTO "django_geo_db_zipcode" VALUES(41111,95526,-8,'Bridgeville, California 95526',28808,36008);
INSERT INTO "django_geo_db_zipcode" VALUES(41112,95527,-8,'Burnt Ranch, California 95527',28809,36009);
INSERT INTO "django_geo_db_zipcode" VALUES(41113,95528,-8,'Carlotta, California 95528',28810,36010);
INSERT INTO "django_geo_db_zipcode" VALUES(41114,95531,-8,'Crescent City, California 95531',28811,36011);
INSERT INTO "django_geo_db_zipcode" VALUES(41115,95532,-8,'Crescent City, California 95532',28811,36012);
INSERT INTO "django_geo_db_zipcode" VALUES(41116,95534,-8,'Cutten, California 95534',28812,36013);
INSERT INTO "django_geo_db_zipcode" VALUES(41117,95536,-8,'Ferndale, California 95536',28813,36014);
INSERT INTO "django_geo_db_zipcode" VALUES(41118,95537,-8,'Fields Landing, California 95537',28814,36015);
INSERT INTO "django_geo_db_zipcode" VALUES(41119,95538,-8,'Fort Dick, California 95538',28815,36016);
INSERT INTO "django_geo_db_zipcode" VALUES(41120,95540,-8,'Fortuna, California 95540',28816,36017);
INSERT INTO "django_geo_db_zipcode" VALUES(41121,95542,-8,'Garberville, California 95542',28817,36018);
INSERT INTO "django_geo_db_zipcode" VALUES(41122,95543,-8,'Gasquet, California 95543',28818,36019);
INSERT INTO "django_geo_db_zipcode" VALUES(41123,95545,-8,'Honeydew, California 95545',28819,36020);
INSERT INTO "django_geo_db_zipcode" VALUES(41124,95546,-8,'Hoopa, California 95546',28820,36021);
INSERT INTO "django_geo_db_zipcode" VALUES(41125,95547,-8,'Hydesville, California 95547',28821,36022);
INSERT INTO "django_geo_db_zipcode" VALUES(41126,95548,-8,'Klamath, California 95548',28822,36023);
INSERT INTO "django_geo_db_zipcode" VALUES(41127,95549,-8,'Kneeland, California 95549',28823,36024);
INSERT INTO "django_geo_db_zipcode" VALUES(41128,95550,-8,'Korbel, California 95550',28824,36025);
INSERT INTO "django_geo_db_zipcode" VALUES(41129,95551,-8,'Loleta, California 95551',28825,36026);
INSERT INTO "django_geo_db_zipcode" VALUES(41130,95552,-8,'Mad River, California 95552',28826,36027);
INSERT INTO "django_geo_db_zipcode" VALUES(41131,95553,-8,'Miranda, California 95553',28827,36028);
INSERT INTO "django_geo_db_zipcode" VALUES(41132,95554,-8,'Myers Flat, California 95554',28828,36029);
INSERT INTO "django_geo_db_zipcode" VALUES(41133,95555,-8,'Orick, California 95555',28829,36030);
INSERT INTO "django_geo_db_zipcode" VALUES(41134,95556,-8,'Orleans, California 95556',28830,36031);
INSERT INTO "django_geo_db_zipcode" VALUES(41135,95558,-8,'Petrolia, California 95558',28831,36032);
INSERT INTO "django_geo_db_zipcode" VALUES(41136,95559,-8,'Phillipsville, California 95559',28832,36033);
INSERT INTO "django_geo_db_zipcode" VALUES(41137,95560,-8,'Redway, California 95560',28833,36034);
INSERT INTO "django_geo_db_zipcode" VALUES(41138,95562,-8,'Rio Dell, California 95562',28834,36035);
INSERT INTO "django_geo_db_zipcode" VALUES(41139,95563,-8,'Salyer, California 95563',28835,36036);
INSERT INTO "django_geo_db_zipcode" VALUES(41140,95564,-8,'Samoa, California 95564',28836,36037);
INSERT INTO "django_geo_db_zipcode" VALUES(41141,95565,-8,'Scotia, California 95565',28837,36038);
INSERT INTO "django_geo_db_zipcode" VALUES(41142,95567,-8,'Smith River, California 95567',28838,36039);
INSERT INTO "django_geo_db_zipcode" VALUES(41143,95568,-8,'Somes Bar, California 95568',28839,36040);
INSERT INTO "django_geo_db_zipcode" VALUES(41144,95569,-8,'Redcrest, California 95569',28840,36041);
INSERT INTO "django_geo_db_zipcode" VALUES(41145,95570,-8,'Trinidad, California 95570',28841,36042);
INSERT INTO "django_geo_db_zipcode" VALUES(41146,95571,-8,'Weott, California 95571',28842,36043);
INSERT INTO "django_geo_db_zipcode" VALUES(41147,95573,-8,'Willow Creek, California 95573',28843,36044);
INSERT INTO "django_geo_db_zipcode" VALUES(41148,95585,-8,'Leggett, California 95585',28844,36045);
INSERT INTO "django_geo_db_zipcode" VALUES(41149,95587,-8,'Piercy, California 95587',28845,36046);
INSERT INTO "django_geo_db_zipcode" VALUES(41150,95589,-8,'Whitethorn, California 95589',28846,36047);
INSERT INTO "django_geo_db_zipcode" VALUES(41151,95592,-8,'Vallejo, California 95592',28558,36048);
INSERT INTO "django_geo_db_zipcode" VALUES(41152,95595,-8,'Zenia, California 95595',28847,36049);
INSERT INTO "django_geo_db_zipcode" VALUES(41153,95601,-8,'Amador City, California 95601',28848,36050);
INSERT INTO "django_geo_db_zipcode" VALUES(41154,95602,-8,'Auburn, California 95602',28849,36051);
INSERT INTO "django_geo_db_zipcode" VALUES(41155,95603,-8,'Auburn, California 95603',28849,36052);
INSERT INTO "django_geo_db_zipcode" VALUES(41156,95604,-8,'Auburn, California 95604',28849,36053);
INSERT INTO "django_geo_db_zipcode" VALUES(41157,95605,-8,'West Sacramento, California 95605',28850,36054);
INSERT INTO "django_geo_db_zipcode" VALUES(41158,95606,-8,'Brooks, California 95606',28851,36055);
INSERT INTO "django_geo_db_zipcode" VALUES(41159,95607,-8,'Capay, California 95607',28852,36056);
INSERT INTO "django_geo_db_zipcode" VALUES(41160,95608,-8,'Carmichael, California 95608',28853,36057);
INSERT INTO "django_geo_db_zipcode" VALUES(41161,95609,-8,'Carmichael, California 95609',28853,36058);
INSERT INTO "django_geo_db_zipcode" VALUES(41162,95610,-8,'Citrus Heights, California 95610',28854,36059);
INSERT INTO "django_geo_db_zipcode" VALUES(41163,95611,-8,'Citrus Heights, California 95611',28854,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41164,95612,-8,'Clarksburg, California 95612',28855,36060);
INSERT INTO "django_geo_db_zipcode" VALUES(41165,95613,-8,'Coloma, California 95613',28856,36061);
INSERT INTO "django_geo_db_zipcode" VALUES(41166,95614,-8,'Cool, California 95614',28857,36062);
INSERT INTO "django_geo_db_zipcode" VALUES(41167,95615,-8,'Courtland, California 95615',28858,36063);
INSERT INTO "django_geo_db_zipcode" VALUES(41168,95616,-8,'Davis, California 95616',28859,36064);
INSERT INTO "django_geo_db_zipcode" VALUES(41169,95617,-8,'Davis, California 95617',28859,36065);
INSERT INTO "django_geo_db_zipcode" VALUES(41170,95618,-8,'El Macero, California 95618',28860,36066);
INSERT INTO "django_geo_db_zipcode" VALUES(41171,95619,-8,'Diamond Springs, California 95619',28803,36067);
INSERT INTO "django_geo_db_zipcode" VALUES(41172,95620,-8,'Dixon, California 95620',28861,36068);
INSERT INTO "django_geo_db_zipcode" VALUES(41173,95621,-8,'Citrus Heights, California 95621',28854,36069);
INSERT INTO "django_geo_db_zipcode" VALUES(41174,95623,-8,'El Dorado, California 95623',28862,36070);
INSERT INTO "django_geo_db_zipcode" VALUES(41175,95624,-8,'Elk Grove, California 95624',28863,36071);
INSERT INTO "django_geo_db_zipcode" VALUES(41176,95625,-8,'Elmira, California 95625',28864,36072);
INSERT INTO "django_geo_db_zipcode" VALUES(41177,95626,-8,'Elverta, California 95626',28865,36073);
INSERT INTO "django_geo_db_zipcode" VALUES(41178,95627,-8,'Esparto, California 95627',28866,36074);
INSERT INTO "django_geo_db_zipcode" VALUES(41179,95628,-8,'Fair Oaks, California 95628',28867,36075);
INSERT INTO "django_geo_db_zipcode" VALUES(41180,95629,-8,'Fiddletown, California 95629',28868,36076);
INSERT INTO "django_geo_db_zipcode" VALUES(41181,95630,-8,'Folsom, California 95630',28869,36077);
INSERT INTO "django_geo_db_zipcode" VALUES(41182,95631,-8,'Foresthill, California 95631',28870,36078);
INSERT INTO "django_geo_db_zipcode" VALUES(41183,95632,-8,'Galt, California 95632',28871,36079);
INSERT INTO "django_geo_db_zipcode" VALUES(41184,95633,-8,'Garden Valley, California 95633',28872,36080);
INSERT INTO "django_geo_db_zipcode" VALUES(41185,95634,-8,'Georgetown, California 95634',28873,36081);
INSERT INTO "django_geo_db_zipcode" VALUES(41186,95635,-8,'Greenwood, California 95635',28874,36082);
INSERT INTO "django_geo_db_zipcode" VALUES(41187,95636,-8,'Grizzly Flats, California 95636',28875,36083);
INSERT INTO "django_geo_db_zipcode" VALUES(41188,95637,-8,'Guinda, California 95637',28876,36084);
INSERT INTO "django_geo_db_zipcode" VALUES(41189,95638,-8,'Herald, California 95638',28877,36085);
INSERT INTO "django_geo_db_zipcode" VALUES(41190,95639,-8,'Hood, California 95639',28878,36086);
INSERT INTO "django_geo_db_zipcode" VALUES(41191,95640,-8,'Ione, California 95640',28879,36087);
INSERT INTO "django_geo_db_zipcode" VALUES(41192,95641,-8,'Isleton, California 95641',28880,36088);
INSERT INTO "django_geo_db_zipcode" VALUES(41193,95642,-8,'Jackson, California 95642',28881,36089);
INSERT INTO "django_geo_db_zipcode" VALUES(41194,95644,-8,'Kit Carson, California 95644',28882,36090);
INSERT INTO "django_geo_db_zipcode" VALUES(41195,95645,-8,'Knights Landing, California 95645',28883,36091);
INSERT INTO "django_geo_db_zipcode" VALUES(41196,95646,-8,'Kirkwood, California 95646',28884,36092);
INSERT INTO "django_geo_db_zipcode" VALUES(41197,95648,-8,'Lincoln, California 95648',28885,36093);
INSERT INTO "django_geo_db_zipcode" VALUES(41198,95650,-8,'Loomis, California 95650',28886,36094);
INSERT INTO "django_geo_db_zipcode" VALUES(41199,95651,-8,'Lotus, California 95651',28887,36095);
INSERT INTO "django_geo_db_zipcode" VALUES(41200,95652,-8,'Mcclellan AFB, California 95652',28888,36096);
INSERT INTO "django_geo_db_zipcode" VALUES(41201,95653,-8,'Madison, California 95653',28889,36097);
INSERT INTO "django_geo_db_zipcode" VALUES(41202,95654,-8,'Martell, California 95654',28890,36090);
INSERT INTO "django_geo_db_zipcode" VALUES(41203,95655,-8,'Mather, California 95655',28891,36098);
INSERT INTO "django_geo_db_zipcode" VALUES(41204,95656,-8,'Mount Aukum, California 95656',28892,36099);
INSERT INTO "django_geo_db_zipcode" VALUES(41205,95658,-8,'Newcastle, California 95658',28893,36100);
INSERT INTO "django_geo_db_zipcode" VALUES(41206,95659,-8,'Nicolaus, California 95659',28894,36101);
INSERT INTO "django_geo_db_zipcode" VALUES(41207,95660,-8,'North Highlands, California 95660',28895,36102);
INSERT INTO "django_geo_db_zipcode" VALUES(41208,95661,-8,'Roseville, California 95661',28896,36103);
INSERT INTO "django_geo_db_zipcode" VALUES(41209,95662,-8,'Orangevale, California 95662',28897,36104);
INSERT INTO "django_geo_db_zipcode" VALUES(41210,95663,-8,'Penryn, California 95663',28898,36105);
INSERT INTO "django_geo_db_zipcode" VALUES(41211,95664,-8,'Pilot Hill, California 95664',28899,36106);
INSERT INTO "django_geo_db_zipcode" VALUES(41212,95665,-8,'Pine Grove, California 95665',28900,36107);
INSERT INTO "django_geo_db_zipcode" VALUES(41213,95666,-8,'Pioneer, California 95666',28901,36108);
INSERT INTO "django_geo_db_zipcode" VALUES(41214,95667,-8,'Placerville, California 95667',28902,36109);
INSERT INTO "django_geo_db_zipcode" VALUES(41215,95668,-8,'Pleasant Grove, California 95668',28903,36110);
INSERT INTO "django_geo_db_zipcode" VALUES(41216,95669,-8,'Plymouth, California 95669',28904,36111);
INSERT INTO "django_geo_db_zipcode" VALUES(41217,95670,-8,'Rancho Cordova, California 95670',28905,36112);
INSERT INTO "django_geo_db_zipcode" VALUES(41218,95671,-8,'Represa, California 95671',28906,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41219,95672,-8,'Rescue, California 95672',28907,36113);
INSERT INTO "django_geo_db_zipcode" VALUES(41220,95673,-8,'Rio Linda, California 95673',28908,36114);
INSERT INTO "django_geo_db_zipcode" VALUES(41221,95674,-8,'Rio Oso, California 95674',28909,36115);
INSERT INTO "django_geo_db_zipcode" VALUES(41222,95675,-8,'River Pines, California 95675',28910,36116);
INSERT INTO "django_geo_db_zipcode" VALUES(41223,95676,-8,'Robbins, California 95676',28911,36117);
INSERT INTO "django_geo_db_zipcode" VALUES(41224,95677,-8,'Rocklin, California 95677',28912,36118);
INSERT INTO "django_geo_db_zipcode" VALUES(41225,95678,-8,'Roseville, California 95678',28896,36119);
INSERT INTO "django_geo_db_zipcode" VALUES(41226,95679,-8,'Rumsey, California 95679',28913,36120);
INSERT INTO "django_geo_db_zipcode" VALUES(41227,95680,-8,'Ryde, California 95680',28914,36121);
INSERT INTO "django_geo_db_zipcode" VALUES(41228,95681,-8,'Sheridan, California 95681',28915,36122);
INSERT INTO "django_geo_db_zipcode" VALUES(41229,95682,-8,'Shingle Springs, California 95682',28916,36123);
INSERT INTO "django_geo_db_zipcode" VALUES(41230,95683,-8,'Sloughhouse, California 95683',28917,36124);
INSERT INTO "django_geo_db_zipcode" VALUES(41231,95684,-8,'Somerset, California 95684',28918,36125);
INSERT INTO "django_geo_db_zipcode" VALUES(41232,95685,-8,'Sutter Creek, California 95685',28919,36126);
INSERT INTO "django_geo_db_zipcode" VALUES(41233,95686,-8,'Thornton, California 95686',28920,36127);
INSERT INTO "django_geo_db_zipcode" VALUES(41234,95687,-8,'Vacaville, California 95687',28921,36128);
INSERT INTO "django_geo_db_zipcode" VALUES(41235,95688,-8,'Vacaville, California 95688',28921,36129);
INSERT INTO "django_geo_db_zipcode" VALUES(41236,95689,-8,'Volcano, California 95689',28922,36130);
INSERT INTO "django_geo_db_zipcode" VALUES(41237,95690,-8,'Walnut Grove, California 95690',28923,36131);
INSERT INTO "django_geo_db_zipcode" VALUES(41238,95691,-8,'West Sacramento, California 95691',28850,36132);
INSERT INTO "django_geo_db_zipcode" VALUES(41239,95692,-8,'Wheatland, California 95692',28924,36133);
INSERT INTO "django_geo_db_zipcode" VALUES(41240,95693,-8,'Wilton, California 95693',28925,36134);
INSERT INTO "django_geo_db_zipcode" VALUES(41241,95694,-8,'Winters, California 95694',28926,36135);
INSERT INTO "django_geo_db_zipcode" VALUES(41242,95695,-8,'Woodland, California 95695',28927,36136);
INSERT INTO "django_geo_db_zipcode" VALUES(41243,95696,-8,'Vacaville, California 95696',28921,36137);
INSERT INTO "django_geo_db_zipcode" VALUES(41244,95697,-8,'Yolo, California 95697',28928,36138);
INSERT INTO "django_geo_db_zipcode" VALUES(41245,95698,-8,'Zamora, California 95698',28929,36139);
INSERT INTO "django_geo_db_zipcode" VALUES(41246,95699,-8,'Drytown, California 95699',28930,36140);
INSERT INTO "django_geo_db_zipcode" VALUES(41247,95701,-8,'Alta, California 95701',28931,36141);
INSERT INTO "django_geo_db_zipcode" VALUES(41248,95703,-8,'Applegate, California 95703',28932,36142);
INSERT INTO "django_geo_db_zipcode" VALUES(41249,95709,-8,'Camino, California 95709',28933,36143);
INSERT INTO "django_geo_db_zipcode" VALUES(41250,95712,-8,'Chicago Park, California 95712',28934,36144);
INSERT INTO "django_geo_db_zipcode" VALUES(41251,95713,-8,'Colfax, California 95713',28935,36145);
INSERT INTO "django_geo_db_zipcode" VALUES(41252,95714,-8,'Dutch Flat, California 95714',28936,36146);
INSERT INTO "django_geo_db_zipcode" VALUES(41253,95715,-8,'Emigrant Gap, California 95715',28937,36147);
INSERT INTO "django_geo_db_zipcode" VALUES(41254,95717,-8,'Gold Run, California 95717',28938,36148);
INSERT INTO "django_geo_db_zipcode" VALUES(41255,95720,-8,'Kyburz, California 95720',28939,36149);
INSERT INTO "django_geo_db_zipcode" VALUES(41256,95721,-8,'Echo Lake, California 95721',28940,36150);
INSERT INTO "django_geo_db_zipcode" VALUES(41257,95722,-8,'Meadow Vista, California 95722',28941,36151);
INSERT INTO "django_geo_db_zipcode" VALUES(41258,95724,-8,'Norden, California 95724',28942,36152);
INSERT INTO "django_geo_db_zipcode" VALUES(41259,95726,-8,'Pollock Pines, California 95726',28943,36153);
INSERT INTO "django_geo_db_zipcode" VALUES(41260,95728,-8,'Soda Springs, California 95728',28944,36154);
INSERT INTO "django_geo_db_zipcode" VALUES(41261,95735,-8,'Twin Bridges, California 95735',28945,36155);
INSERT INTO "django_geo_db_zipcode" VALUES(41262,95736,-8,'Weimar, California 95736',28946,36156);
INSERT INTO "django_geo_db_zipcode" VALUES(41263,95741,-8,'Rancho Cordova, California 95741',28905,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41264,95742,-8,'Rancho Cordova, California 95742',28905,36157);
INSERT INTO "django_geo_db_zipcode" VALUES(41265,95743,-8,'Rancho Cordova, California 95743',28905,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41266,95746,-8,'Granite Bay, California 95746',28947,36158);
INSERT INTO "django_geo_db_zipcode" VALUES(41267,95747,-8,'Roseville, California 95747',28896,36159);
INSERT INTO "django_geo_db_zipcode" VALUES(41268,95749,-8,'San Andreas, California 95749',28661,36160);
INSERT INTO "django_geo_db_zipcode" VALUES(41269,95758,-8,'Elk Grove, California 95758',28863,36161);
INSERT INTO "django_geo_db_zipcode" VALUES(41270,95759,-8,'Elk Grove, California 95759',28863,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41271,95762,-8,'El Dorado Hills, California 95762',28948,36162);
INSERT INTO "django_geo_db_zipcode" VALUES(41272,95763,-8,'Folsom, California 95763',28869,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41273,95765,-8,'Rocklin, California 95765',28912,36163);
INSERT INTO "django_geo_db_zipcode" VALUES(41274,95771,-8,'Spring Garden, California 95771',28949,36164);
INSERT INTO "django_geo_db_zipcode" VALUES(41275,95776,-8,'Woodland, California 95776',28927,36165);
INSERT INTO "django_geo_db_zipcode" VALUES(41276,95798,-8,'West Sacramento, California 95798',28850,36065);
INSERT INTO "django_geo_db_zipcode" VALUES(41277,95799,-8,'West Sacramento, California 95799',28850,36065);
INSERT INTO "django_geo_db_zipcode" VALUES(41278,95812,-8,'Sacramento, California 95812',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41279,95813,-8,'Sacramento, California 95813',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41280,95814,-8,'Sacramento, California 95814',28501,36166);
INSERT INTO "django_geo_db_zipcode" VALUES(41281,95815,-8,'Sacramento, California 95815',28501,36167);
INSERT INTO "django_geo_db_zipcode" VALUES(41282,95816,-8,'Sacramento, California 95816',28501,36168);
INSERT INTO "django_geo_db_zipcode" VALUES(41283,95817,-8,'Sacramento, California 95817',28501,36169);
INSERT INTO "django_geo_db_zipcode" VALUES(41284,95818,-8,'Sacramento, California 95818',28501,36170);
INSERT INTO "django_geo_db_zipcode" VALUES(41285,95819,-8,'Sacramento, California 95819',28501,36171);
INSERT INTO "django_geo_db_zipcode" VALUES(41286,95820,-8,'Sacramento, California 95820',28501,36172);
INSERT INTO "django_geo_db_zipcode" VALUES(41287,95821,-8,'Sacramento, California 95821',28501,36173);
INSERT INTO "django_geo_db_zipcode" VALUES(41288,95822,-8,'Sacramento, California 95822',28501,36174);
INSERT INTO "django_geo_db_zipcode" VALUES(41289,95823,-8,'Sacramento, California 95823',28501,36175);
INSERT INTO "django_geo_db_zipcode" VALUES(41290,95824,-8,'Sacramento, California 95824',28501,36176);
INSERT INTO "django_geo_db_zipcode" VALUES(41291,95825,-8,'Sacramento, California 95825',28501,36177);
INSERT INTO "django_geo_db_zipcode" VALUES(41292,95826,-8,'Sacramento, California 95826',28501,36178);
INSERT INTO "django_geo_db_zipcode" VALUES(41293,95827,-8,'Sacramento, California 95827',28501,36179);
INSERT INTO "django_geo_db_zipcode" VALUES(41294,95828,-8,'Sacramento, California 95828',28501,36180);
INSERT INTO "django_geo_db_zipcode" VALUES(41295,95829,-8,'Sacramento, California 95829',28501,36181);
INSERT INTO "django_geo_db_zipcode" VALUES(41296,95830,-8,'Sacramento, California 95830',28501,36182);
INSERT INTO "django_geo_db_zipcode" VALUES(41297,95831,-8,'Sacramento, California 95831',28501,36183);
INSERT INTO "django_geo_db_zipcode" VALUES(41298,95832,-8,'Sacramento, California 95832',28501,36184);
INSERT INTO "django_geo_db_zipcode" VALUES(41299,95833,-8,'Sacramento, California 95833',28501,36185);
INSERT INTO "django_geo_db_zipcode" VALUES(41300,95834,-8,'Sacramento, California 95834',28501,36186);
INSERT INTO "django_geo_db_zipcode" VALUES(41301,95835,-8,'Sacramento, California 95835',28501,36187);
INSERT INTO "django_geo_db_zipcode" VALUES(41302,95836,-8,'Sacramento, California 95836',28501,36188);
INSERT INTO "django_geo_db_zipcode" VALUES(41303,95837,-8,'Sacramento, California 95837',28501,36189);
INSERT INTO "django_geo_db_zipcode" VALUES(41304,95838,-8,'Sacramento, California 95838',28501,36190);
INSERT INTO "django_geo_db_zipcode" VALUES(41305,95840,-8,'Sacramento, California 95840',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41306,95841,-8,'Sacramento, California 95841',28501,36191);
INSERT INTO "django_geo_db_zipcode" VALUES(41307,95842,-8,'Sacramento, California 95842',28501,36192);
INSERT INTO "django_geo_db_zipcode" VALUES(41308,95843,-8,'Antelope, California 95843',28950,36193);
INSERT INTO "django_geo_db_zipcode" VALUES(41309,95851,-8,'Sacramento, California 95851',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41310,95852,-8,'Sacramento, California 95852',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41311,95853,-8,'Sacramento, California 95853',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41312,95857,-8,'Sacramento, California 95857',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41313,95860,-8,'Sacramento, California 95860',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41314,95864,-8,'Sacramento, California 95864',28501,36194);
INSERT INTO "django_geo_db_zipcode" VALUES(41315,95865,-8,'Sacramento, California 95865',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41316,95866,-8,'Sacramento, California 95866',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41317,95867,-8,'Sacramento, California 95867',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41318,95873,-8,'Sacramento, California 95873',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41319,95887,-8,'Sacramento, California 95887',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41320,95894,-8,'Sacramento, California 95894',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41321,95899,-8,'Sacramento, California 95899',28501,35553);
INSERT INTO "django_geo_db_zipcode" VALUES(41322,95901,-8,'Marysville, California 95901',28951,36195);
INSERT INTO "django_geo_db_zipcode" VALUES(41323,95903,-8,'Beale AFB, California 95903',28952,36196);
INSERT INTO "django_geo_db_zipcode" VALUES(41324,95910,-8,'Alleghany, California 95910',28953,36197);
INSERT INTO "django_geo_db_zipcode" VALUES(41325,95912,-8,'Arbuckle, California 95912',28954,36198);
INSERT INTO "django_geo_db_zipcode" VALUES(41326,95913,-8,'Artois, California 95913',28955,36199);
INSERT INTO "django_geo_db_zipcode" VALUES(41327,95914,-8,'Bangor, California 95914',28956,36200);
INSERT INTO "django_geo_db_zipcode" VALUES(41328,95915,-8,'Belden, California 95915',28957,36201);
INSERT INTO "django_geo_db_zipcode" VALUES(41329,95916,-8,'Berry Creek, California 95916',28958,36202);
INSERT INTO "django_geo_db_zipcode" VALUES(41330,95917,-8,'Biggs, California 95917',28959,36203);
INSERT INTO "django_geo_db_zipcode" VALUES(41331,95918,-8,'Browns Valley, California 95918',28960,36204);
INSERT INTO "django_geo_db_zipcode" VALUES(41332,95919,-8,'Brownsville, California 95919',28961,36205);
INSERT INTO "django_geo_db_zipcode" VALUES(41333,95920,-8,'Butte City, California 95920',28962,36206);
INSERT INTO "django_geo_db_zipcode" VALUES(41334,95922,-8,'Camptonville, California 95922',28963,36207);
INSERT INTO "django_geo_db_zipcode" VALUES(41335,95923,-8,'Canyondam, California 95923',28964,36208);
INSERT INTO "django_geo_db_zipcode" VALUES(41336,95924,-8,'Cedar Ridge, California 95924',28965,36152);
INSERT INTO "django_geo_db_zipcode" VALUES(41337,95925,-8,'Challenge, California 95925',28966,36209);
INSERT INTO "django_geo_db_zipcode" VALUES(41338,95926,-8,'Chico, California 95926',28967,36210);
INSERT INTO "django_geo_db_zipcode" VALUES(41339,95927,-8,'Chico, California 95927',28967,36211);
INSERT INTO "django_geo_db_zipcode" VALUES(41340,95928,-8,'Chico, California 95928',28967,36212);
INSERT INTO "django_geo_db_zipcode" VALUES(41341,95929,-8,'Chico, California 95929',28967,36213);
INSERT INTO "django_geo_db_zipcode" VALUES(41342,95930,-8,'Clipper Mills, California 95930',28968,36214);
INSERT INTO "django_geo_db_zipcode" VALUES(41343,95931,-8,'College City, California 95931',28969,36215);
INSERT INTO "django_geo_db_zipcode" VALUES(41344,95932,-8,'Colusa, California 95932',28970,36216);
INSERT INTO "django_geo_db_zipcode" VALUES(41345,95934,-8,'Crescent Mills, California 95934',28971,36217);
INSERT INTO "django_geo_db_zipcode" VALUES(41346,95935,-8,'Dobbins, California 95935',28972,36218);
INSERT INTO "django_geo_db_zipcode" VALUES(41347,95936,-8,'Downieville, California 95936',28973,36219);
INSERT INTO "django_geo_db_zipcode" VALUES(41348,95937,-8,'Dunnigan, California 95937',28974,36220);
INSERT INTO "django_geo_db_zipcode" VALUES(41349,95938,-8,'Durham, California 95938',28975,36221);
INSERT INTO "django_geo_db_zipcode" VALUES(41350,95939,-8,'Elk Creek, California 95939',28976,36222);
INSERT INTO "django_geo_db_zipcode" VALUES(41351,95940,-8,'Feather Falls, California 95940',28977,36223);
INSERT INTO "django_geo_db_zipcode" VALUES(41352,95941,-8,'Forbestown, California 95941',28978,36224);
INSERT INTO "django_geo_db_zipcode" VALUES(41353,95942,-8,'Forest Ranch, California 95942',28979,36225);
INSERT INTO "django_geo_db_zipcode" VALUES(41354,95943,-8,'Glenn, California 95943',28980,36226);
INSERT INTO "django_geo_db_zipcode" VALUES(41355,95944,-8,'Goodyears Bar, California 95944',28981,36227);
INSERT INTO "django_geo_db_zipcode" VALUES(41356,95945,-8,'Grass Valley, California 95945',28982,36228);
INSERT INTO "django_geo_db_zipcode" VALUES(41357,95946,-8,'Penn Valley, California 95946',28983,36229);
INSERT INTO "django_geo_db_zipcode" VALUES(41358,95947,-8,'Greenville, California 95947',28984,36230);
INSERT INTO "django_geo_db_zipcode" VALUES(41359,95948,-8,'Gridley, California 95948',28985,36231);
INSERT INTO "django_geo_db_zipcode" VALUES(41360,95949,-8,'Grass Valley, California 95949',28982,36232);
INSERT INTO "django_geo_db_zipcode" VALUES(41361,95950,-8,'Grimes, California 95950',28986,36233);
INSERT INTO "django_geo_db_zipcode" VALUES(41362,95951,-8,'Hamilton City, California 95951',28987,36234);
INSERT INTO "django_geo_db_zipcode" VALUES(41363,95953,-8,'Live Oak, California 95953',28988,36235);
INSERT INTO "django_geo_db_zipcode" VALUES(41364,95954,-8,'Magalia, California 95954',28989,36236);
INSERT INTO "django_geo_db_zipcode" VALUES(41365,95955,-8,'Maxwell, California 95955',28990,36237);
INSERT INTO "django_geo_db_zipcode" VALUES(41366,95956,-8,'Meadow Valley, California 95956',28991,36238);
INSERT INTO "django_geo_db_zipcode" VALUES(41367,95957,-8,'Meridian, California 95957',28992,36239);
INSERT INTO "django_geo_db_zipcode" VALUES(41368,95958,-8,'Nelson, California 95958',28993,36240);
INSERT INTO "django_geo_db_zipcode" VALUES(41369,95959,-8,'Nevada City, California 95959',28994,36241);
INSERT INTO "django_geo_db_zipcode" VALUES(41370,95960,-8,'North San Juan, California 95960',28995,36242);
INSERT INTO "django_geo_db_zipcode" VALUES(41371,95961,-8,'Olivehurst, California 95961',28996,36243);
INSERT INTO "django_geo_db_zipcode" VALUES(41372,95962,-8,'Oregon House, California 95962',28997,36244);
INSERT INTO "django_geo_db_zipcode" VALUES(41373,95963,-8,'Orland, California 95963',28998,36245);
INSERT INTO "django_geo_db_zipcode" VALUES(41374,95965,-8,'Oroville, California 95965',28999,36246);
INSERT INTO "django_geo_db_zipcode" VALUES(41375,95966,-8,'Oroville, California 95966',28999,36247);
INSERT INTO "django_geo_db_zipcode" VALUES(41376,95967,-8,'Paradise, California 95967',29000,36248);
INSERT INTO "django_geo_db_zipcode" VALUES(41377,95968,-8,'Palermo, California 95968',29001,36249);
INSERT INTO "django_geo_db_zipcode" VALUES(41378,95969,-8,'Paradise, California 95969',29000,36250);
INSERT INTO "django_geo_db_zipcode" VALUES(41379,95970,-8,'Princeton, California 95970',29002,36251);
INSERT INTO "django_geo_db_zipcode" VALUES(41380,95971,-8,'Quincy, California 95971',29003,36252);
INSERT INTO "django_geo_db_zipcode" VALUES(41381,95972,-8,'Rackerby, California 95972',29004,36253);
INSERT INTO "django_geo_db_zipcode" VALUES(41382,95973,-8,'Chico, California 95973',28967,36254);
INSERT INTO "django_geo_db_zipcode" VALUES(41383,95974,-8,'Richvale, California 95974',29005,36255);
INSERT INTO "django_geo_db_zipcode" VALUES(41384,95975,-8,'Rough And Ready, California 95975',29006,36256);
INSERT INTO "django_geo_db_zipcode" VALUES(41385,95976,-8,'Chico, California 95976',28967,36248);
INSERT INTO "django_geo_db_zipcode" VALUES(41386,95977,-8,'Smartville, California 95977',29007,36257);
INSERT INTO "django_geo_db_zipcode" VALUES(41387,95978,-8,'Stirling City, California 95978',29008,36258);
INSERT INTO "django_geo_db_zipcode" VALUES(41388,95979,-8,'Stonyford, California 95979',29009,36259);
INSERT INTO "django_geo_db_zipcode" VALUES(41389,95980,-8,'Storrie, California 95980',29010,36260);
INSERT INTO "django_geo_db_zipcode" VALUES(41390,95981,-8,'Strawberry Valley, California 95981',29011,36261);
INSERT INTO "django_geo_db_zipcode" VALUES(41391,95982,-8,'Sutter, California 95982',29012,36262);
INSERT INTO "django_geo_db_zipcode" VALUES(41392,95983,-8,'Taylorsville, California 95983',29013,36263);
INSERT INTO "django_geo_db_zipcode" VALUES(41393,95984,-8,'Twain, California 95984',29014,36264);
INSERT INTO "django_geo_db_zipcode" VALUES(41394,95986,-8,'Washington, California 95986',29015,36265);
INSERT INTO "django_geo_db_zipcode" VALUES(41395,95987,-8,'Williams, California 95987',29016,36266);
INSERT INTO "django_geo_db_zipcode" VALUES(41396,95988,-8,'Willows, California 95988',29017,36267);
INSERT INTO "django_geo_db_zipcode" VALUES(41397,95991,-8,'Yuba City, California 95991',29018,36268);
INSERT INTO "django_geo_db_zipcode" VALUES(41398,95992,-8,'Yuba City, California 95992',29018,36269);
INSERT INTO "django_geo_db_zipcode" VALUES(41399,95993,-8,'Yuba City, California 95993',29018,36270);
INSERT INTO "django_geo_db_zipcode" VALUES(41400,96001,-8,'Redding, California 96001',29019,36271);
INSERT INTO "django_geo_db_zipcode" VALUES(41401,96002,-8,'Redding, California 96002',29019,36272);
INSERT INTO "django_geo_db_zipcode" VALUES(41402,96003,-8,'Redding, California 96003',29019,36273);
INSERT INTO "django_geo_db_zipcode" VALUES(41403,96006,-8,'Adin, California 96006',29020,36274);
INSERT INTO "django_geo_db_zipcode" VALUES(41404,96007,-8,'Anderson, California 96007',29021,36275);
INSERT INTO "django_geo_db_zipcode" VALUES(41405,96008,-8,'Bella Vista, California 96008',29022,36276);
INSERT INTO "django_geo_db_zipcode" VALUES(41406,96009,-8,'Bieber, California 96009',29023,36277);
INSERT INTO "django_geo_db_zipcode" VALUES(41407,96010,-8,'Big Bar, California 96010',29024,36278);
INSERT INTO "django_geo_db_zipcode" VALUES(41408,96011,-8,'Big Bend, California 96011',29025,36279);
INSERT INTO "django_geo_db_zipcode" VALUES(41409,96013,-8,'Burney, California 96013',29026,36280);
INSERT INTO "django_geo_db_zipcode" VALUES(41410,96014,-8,'Callahan, California 96014',29027,36281);
INSERT INTO "django_geo_db_zipcode" VALUES(41411,96015,-8,'Canby, California 96015',29028,36282);
INSERT INTO "django_geo_db_zipcode" VALUES(41412,96016,-8,'Cassel, California 96016',29029,36283);
INSERT INTO "django_geo_db_zipcode" VALUES(41413,96017,-8,'Castella, California 96017',29030,36284);
INSERT INTO "django_geo_db_zipcode" VALUES(41414,96019,-8,'Shasta Lake, California 96019',29031,36285);
INSERT INTO "django_geo_db_zipcode" VALUES(41415,96020,-8,'Chester, California 96020',29032,36286);
INSERT INTO "django_geo_db_zipcode" VALUES(41416,96021,-8,'Corning, California 96021',29033,36287);
INSERT INTO "django_geo_db_zipcode" VALUES(41417,96022,-8,'Cottonwood, California 96022',29034,36288);
INSERT INTO "django_geo_db_zipcode" VALUES(41418,96023,-8,'Dorris, California 96023',29035,36289);
INSERT INTO "django_geo_db_zipcode" VALUES(41419,96024,-8,'Douglas City, California 96024',29036,36290);
INSERT INTO "django_geo_db_zipcode" VALUES(41420,96025,-8,'Dunsmuir, California 96025',29037,36291);
INSERT INTO "django_geo_db_zipcode" VALUES(41421,96027,-8,'Etna, California 96027',29038,36292);
INSERT INTO "django_geo_db_zipcode" VALUES(41422,96028,-8,'Fall River Mills, California 96028',29039,36293);
INSERT INTO "django_geo_db_zipcode" VALUES(41423,96029,-8,'Flournoy, California 96029',29040,36294);
INSERT INTO "django_geo_db_zipcode" VALUES(41424,96031,-8,'Forks Of Salmon, California 96031',29041,36295);
INSERT INTO "django_geo_db_zipcode" VALUES(41425,96032,-8,'Fort Jones, California 96032',29042,36296);
INSERT INTO "django_geo_db_zipcode" VALUES(41426,96033,-8,'French Gulch, California 96033',29043,36297);
INSERT INTO "django_geo_db_zipcode" VALUES(41427,96034,-8,'Gazelle, California 96034',29044,36298);
INSERT INTO "django_geo_db_zipcode" VALUES(41428,96035,-8,'Gerber, California 96035',29045,36299);
INSERT INTO "django_geo_db_zipcode" VALUES(41429,96037,-8,'Greenview, California 96037',29046,36300);
INSERT INTO "django_geo_db_zipcode" VALUES(41430,96038,-8,'Grenada, California 96038',29047,36301);
INSERT INTO "django_geo_db_zipcode" VALUES(41431,96039,-8,'Happy Camp, California 96039',29048,36302);
INSERT INTO "django_geo_db_zipcode" VALUES(41432,96040,-8,'Hat Creek, California 96040',29049,36303);
INSERT INTO "django_geo_db_zipcode" VALUES(41433,96041,-8,'Hayfork, California 96041',29050,36304);
INSERT INTO "django_geo_db_zipcode" VALUES(41434,96044,-8,'Hornbrook, California 96044',29051,36305);
INSERT INTO "django_geo_db_zipcode" VALUES(41435,96046,-8,'Hyampom, California 96046',29052,36306);
INSERT INTO "django_geo_db_zipcode" VALUES(41436,96047,-8,'Igo, California 96047',29053,36307);
INSERT INTO "django_geo_db_zipcode" VALUES(41437,96048,-8,'Junction City, California 96048',29054,36308);
INSERT INTO "django_geo_db_zipcode" VALUES(41438,96049,-8,'Redding, California 96049',29019,36309);
INSERT INTO "django_geo_db_zipcode" VALUES(41439,96050,-8,'Klamath River, California 96050',29055,36310);
INSERT INTO "django_geo_db_zipcode" VALUES(41440,96051,-8,'Lakehead, California 96051',29056,36311);
INSERT INTO "django_geo_db_zipcode" VALUES(41441,96052,-8,'Lewiston, California 96052',29057,36312);
INSERT INTO "django_geo_db_zipcode" VALUES(41442,96053,-8,'Mcarthur, California 96053',29058,36313);
INSERT INTO "django_geo_db_zipcode" VALUES(41443,96054,-8,'Lookout, California 96054',29059,36314);
INSERT INTO "django_geo_db_zipcode" VALUES(41444,96055,-8,'Los Molinos, California 96055',29060,36315);
INSERT INTO "django_geo_db_zipcode" VALUES(41445,96056,-8,'Mcarthur, California 96056',29058,36316);
INSERT INTO "django_geo_db_zipcode" VALUES(41446,96057,-8,'Mccloud, California 96057',29061,36317);
INSERT INTO "django_geo_db_zipcode" VALUES(41447,96058,-8,'Macdoel, California 96058',29062,36318);
INSERT INTO "django_geo_db_zipcode" VALUES(41448,96059,-8,'Manton, California 96059',29063,36319);
INSERT INTO "django_geo_db_zipcode" VALUES(41449,96061,-8,'Mill Creek, California 96061',29064,36320);
INSERT INTO "django_geo_db_zipcode" VALUES(41450,96062,-8,'Millville, California 96062',29065,36321);
INSERT INTO "django_geo_db_zipcode" VALUES(41451,96063,-8,'Mineral, California 96063',29066,36322);
INSERT INTO "django_geo_db_zipcode" VALUES(41452,96064,-8,'Montague, California 96064',29067,36323);
INSERT INTO "django_geo_db_zipcode" VALUES(41453,96065,-8,'Montgomery Creek, California 96065',29068,36324);
INSERT INTO "django_geo_db_zipcode" VALUES(41454,96067,-8,'Mount Shasta, California 96067',29069,36325);
INSERT INTO "django_geo_db_zipcode" VALUES(41455,96068,-8,'Nubieber, California 96068',29070,36326);
INSERT INTO "django_geo_db_zipcode" VALUES(41456,96069,-8,'Oak Run, California 96069',29071,36327);
INSERT INTO "django_geo_db_zipcode" VALUES(41457,96070,-8,'Obrien, California 96070',29072,36328);
INSERT INTO "django_geo_db_zipcode" VALUES(41458,96071,-8,'Old Station, California 96071',29073,36329);
INSERT INTO "django_geo_db_zipcode" VALUES(41459,96073,-8,'Palo Cedro, California 96073',29074,36330);
INSERT INTO "django_geo_db_zipcode" VALUES(41460,96074,-8,'Paskenta, California 96074',29075,36331);
INSERT INTO "django_geo_db_zipcode" VALUES(41461,96075,-8,'Paynes Creek, California 96075',29076,36332);
INSERT INTO "django_geo_db_zipcode" VALUES(41462,96076,-8,'Platina, California 96076',29077,36333);
INSERT INTO "django_geo_db_zipcode" VALUES(41463,96078,-8,'Proberta, California 96078',29078,36334);
INSERT INTO "django_geo_db_zipcode" VALUES(41464,96079,-8,'Shasta Lake, California 96079',29031,36335);
INSERT INTO "django_geo_db_zipcode" VALUES(41465,96080,-8,'Red Bluff, California 96080',29079,36336);
INSERT INTO "django_geo_db_zipcode" VALUES(41466,96084,-8,'Round Mountain, California 96084',29080,36337);
INSERT INTO "django_geo_db_zipcode" VALUES(41467,96085,-8,'Scott Bar, California 96085',29081,36338);
INSERT INTO "django_geo_db_zipcode" VALUES(41468,96086,-8,'Seiad Valley, California 96086',29082,36339);
INSERT INTO "django_geo_db_zipcode" VALUES(41469,96087,-8,'Shasta, California 96087',29083,36340);
INSERT INTO "django_geo_db_zipcode" VALUES(41470,96088,-8,'Shingletown, California 96088',29084,36341);
INSERT INTO "django_geo_db_zipcode" VALUES(41471,96089,-8,'Shasta Lake, California 96089',29031,36342);
INSERT INTO "django_geo_db_zipcode" VALUES(41472,96090,-8,'Tehama, California 96090',29085,36343);
INSERT INTO "django_geo_db_zipcode" VALUES(41473,96091,-8,'Trinity Center, California 96091',29086,36344);
INSERT INTO "django_geo_db_zipcode" VALUES(41474,96092,-8,'Vina, California 96092',29087,36345);
INSERT INTO "django_geo_db_zipcode" VALUES(41475,96093,-8,'Weaverville, California 96093',29088,36346);
INSERT INTO "django_geo_db_zipcode" VALUES(41476,96094,-8,'Weed, California 96094',29089,36347);
INSERT INTO "django_geo_db_zipcode" VALUES(41477,96095,-8,'Whiskeytown, California 96095',29090,36348);
INSERT INTO "django_geo_db_zipcode" VALUES(41478,96096,-8,'Whitmore, California 96096',29091,36349);
INSERT INTO "django_geo_db_zipcode" VALUES(41479,96097,-8,'Yreka, California 96097',29092,36350);
INSERT INTO "django_geo_db_zipcode" VALUES(41480,96099,-8,'Redding, California 96099',29019,36351);
INSERT INTO "django_geo_db_zipcode" VALUES(41481,96101,-8,'Alturas, California 96101',29093,36352);
INSERT INTO "django_geo_db_zipcode" VALUES(41482,96103,-8,'Blairsden-Graeagle, California 96103',29094,36353);
INSERT INTO "django_geo_db_zipcode" VALUES(41483,96104,-8,'Cedarville, California 96104',29095,36354);
INSERT INTO "django_geo_db_zipcode" VALUES(41484,96105,-8,'Chilcoot, California 96105',29096,36355);
INSERT INTO "django_geo_db_zipcode" VALUES(41485,96106,-8,'Clio, California 96106',29097,36356);
INSERT INTO "django_geo_db_zipcode" VALUES(41486,96107,-8,'Coleville, California 96107',29098,36357);
INSERT INTO "django_geo_db_zipcode" VALUES(41487,96108,-8,'Davis Creek, California 96108',29099,36358);
INSERT INTO "django_geo_db_zipcode" VALUES(41488,96109,-8,'Doyle, California 96109',29100,36359);
INSERT INTO "django_geo_db_zipcode" VALUES(41489,96110,-8,'Eagleville, California 96110',29101,36360);
INSERT INTO "django_geo_db_zipcode" VALUES(41490,96111,-8,'Floriston, California 96111',29102,36361);
INSERT INTO "django_geo_db_zipcode" VALUES(41491,96112,-8,'Fort Bidwell, California 96112',29103,36362);
INSERT INTO "django_geo_db_zipcode" VALUES(41492,96113,-8,'Herlong, California 96113',29104,36363);
INSERT INTO "django_geo_db_zipcode" VALUES(41493,96114,-8,'Janesville, California 96114',29105,36364);
INSERT INTO "django_geo_db_zipcode" VALUES(41494,96115,-8,'Lake City, California 96115',29106,36365);
INSERT INTO "django_geo_db_zipcode" VALUES(41495,96116,-8,'Likely, California 96116',29107,36366);
INSERT INTO "django_geo_db_zipcode" VALUES(41496,96117,-8,'Litchfield, California 96117',29108,36367);
INSERT INTO "django_geo_db_zipcode" VALUES(41497,96118,-8,'Loyalton, California 96118',29109,36368);
INSERT INTO "django_geo_db_zipcode" VALUES(41498,96119,-8,'Madeline, California 96119',29110,36369);
INSERT INTO "django_geo_db_zipcode" VALUES(41499,96120,-8,'Markleeville, California 96120',29111,36370);
INSERT INTO "django_geo_db_zipcode" VALUES(41500,96121,-8,'Milford, California 96121',29112,36371);
INSERT INTO "django_geo_db_zipcode" VALUES(41501,96122,-8,'Portola, California 96122',29113,36372);
INSERT INTO "django_geo_db_zipcode" VALUES(41502,96123,-8,'Ravendale, California 96123',29114,36373);
INSERT INTO "django_geo_db_zipcode" VALUES(41503,96124,-8,'Calpine, California 96124',29115,36374);
INSERT INTO "django_geo_db_zipcode" VALUES(41504,96125,-8,'Sierra City, California 96125',29116,36375);
INSERT INTO "django_geo_db_zipcode" VALUES(41505,96126,-8,'Sierraville, California 96126',29117,36376);
INSERT INTO "django_geo_db_zipcode" VALUES(41506,96127,-8,'Susanville, California 96127',29118,36313);
INSERT INTO "django_geo_db_zipcode" VALUES(41507,96128,-8,'Standish, California 96128',29119,36377);
INSERT INTO "django_geo_db_zipcode" VALUES(41508,96129,-8,'Beckwourth, California 96129',29120,36378);
INSERT INTO "django_geo_db_zipcode" VALUES(41509,96130,-8,'Susanville, California 96130',29118,36379);
INSERT INTO "django_geo_db_zipcode" VALUES(41510,96132,-8,'Termo, California 96132',29121,36380);
INSERT INTO "django_geo_db_zipcode" VALUES(41511,96133,-8,'Topaz, California 96133',29122,36381);
INSERT INTO "django_geo_db_zipcode" VALUES(41512,96134,-8,'Tulelake, California 96134',29123,36382);
INSERT INTO "django_geo_db_zipcode" VALUES(41513,96135,-8,'Vinton, California 96135',29124,36383);
INSERT INTO "django_geo_db_zipcode" VALUES(41514,96136,-8,'Wendel, California 96136',29125,36384);
INSERT INTO "django_geo_db_zipcode" VALUES(41515,96137,-8,'Westwood, California 96137',29126,36385);
INSERT INTO "django_geo_db_zipcode" VALUES(41516,96140,-8,'Carnelian Bay, California 96140',29127,36386);
INSERT INTO "django_geo_db_zipcode" VALUES(41517,96141,-8,'Homewood, California 96141',29128,36387);
INSERT INTO "django_geo_db_zipcode" VALUES(41518,96142,-8,'Tahoma, California 96142',29129,36388);
INSERT INTO "django_geo_db_zipcode" VALUES(41519,96143,-8,'Kings Beach, California 96143',29130,36389);
INSERT INTO "django_geo_db_zipcode" VALUES(41520,96145,-8,'Tahoe City, California 96145',29131,36390);
INSERT INTO "django_geo_db_zipcode" VALUES(41521,96146,-8,'Olympic Valley, California 96146',29132,36391);
INSERT INTO "django_geo_db_zipcode" VALUES(41522,96148,-8,'Tahoe Vista, California 96148',29133,36392);
INSERT INTO "django_geo_db_zipcode" VALUES(41523,96150,-8,'South Lake Tahoe, California 96150',29134,36393);
INSERT INTO "django_geo_db_zipcode" VALUES(41524,96151,-8,'South Lake Tahoe, California 96151',29134,36394);
INSERT INTO "django_geo_db_zipcode" VALUES(41525,96152,-8,'South Lake Tahoe, California 96152',29134,36395);
INSERT INTO "django_geo_db_zipcode" VALUES(41526,96154,-8,'South Lake Tahoe, California 96154',29134,36396);
INSERT INTO "django_geo_db_zipcode" VALUES(41527,96155,-8,'South Lake Tahoe, California 96155',29134,36397);
INSERT INTO "django_geo_db_zipcode" VALUES(41528,96156,-8,'South Lake Tahoe, California 96156',29134,36398);
INSERT INTO "django_geo_db_zipcode" VALUES(41529,96157,-8,'South Lake Tahoe, California 96157',29134,36399);
INSERT INTO "django_geo_db_zipcode" VALUES(41530,96158,-8,'South Lake Tahoe, California 96158',29134,36400);
INSERT INTO "django_geo_db_zipcode" VALUES(41531,96160,-8,'Truckee, California 96160',29135,36401);
INSERT INTO "django_geo_db_zipcode" VALUES(41532,96161,-8,'Truckee, California 96161',29135,36402);
INSERT INTO "django_geo_db_zipcode" VALUES(41533,96162,-8,'Truckee, California 96162',29135,36152);
INSERT INTO "django_geo_db_zipcode" VALUES(41534,96163,-8,'Truckee, California 96163',29135,36403);
INSERT INTO "django_geo_db_zipcode" VALUES(41535,96222,-8,'Cottonwood, California 96222',29034,36404);
INSERT INTO "django_geo_db_zipcode" VALUES(41536,96371,-10,'Kawela Bay, Hawaii 96371',29136,36405);
INSERT INTO "django_geo_db_zipcode" VALUES(41537,96373,-10,'Hawaiian Ocean View, Hawaii 96373',29137,36406);
INSERT INTO "django_geo_db_zipcode" VALUES(41538,96385,-10,'Volcano, Hawaii 96385',29138,36407);
INSERT INTO "django_geo_db_zipcode" VALUES(41539,96477,-10,'Kaneohe, Hawaii 96477',29139,36408);
INSERT INTO "django_geo_db_zipcode" VALUES(41540,96701,-10,'Aiea, Hawaii 96701',29140,36409);
INSERT INTO "django_geo_db_zipcode" VALUES(41541,96703,-10,'Anahola, Hawaii 96703',29141,36410);
INSERT INTO "django_geo_db_zipcode" VALUES(41542,96704,-10,'Captain Cook, Hawaii 96704',29142,36411);
INSERT INTO "django_geo_db_zipcode" VALUES(41543,96705,-10,'Eleele, Hawaii 96705',29143,36412);
INSERT INTO "django_geo_db_zipcode" VALUES(41544,96706,-10,'Ewa Beach, Hawaii 96706',29144,36413);
INSERT INTO "django_geo_db_zipcode" VALUES(41545,96707,-10,'Kapolei, Hawaii 96707',29145,36414);
INSERT INTO "django_geo_db_zipcode" VALUES(41546,96708,-10,'Haiku, Hawaii 96708',29146,36415);
INSERT INTO "django_geo_db_zipcode" VALUES(41547,96709,-10,'Kapolei, Hawaii 96709',29145,36416);
INSERT INTO "django_geo_db_zipcode" VALUES(41548,96710,-10,'Hakalau, Hawaii 96710',29147,36417);
INSERT INTO "django_geo_db_zipcode" VALUES(41549,96712,-10,'Haleiwa, Hawaii 96712',29148,36418);
INSERT INTO "django_geo_db_zipcode" VALUES(41550,96713,-10,'Hana, Hawaii 96713',29149,36419);
INSERT INTO "django_geo_db_zipcode" VALUES(41551,96714,-10,'Hanalei, Hawaii 96714',29150,36420);
INSERT INTO "django_geo_db_zipcode" VALUES(41552,96715,-10,'Hanamaulu, Hawaii 96715',29151,36421);
INSERT INTO "django_geo_db_zipcode" VALUES(41553,96716,-10,'Hanapepe, Hawaii 96716',29152,36422);
INSERT INTO "django_geo_db_zipcode" VALUES(41554,96717,-10,'Hauula, Hawaii 96717',29153,36423);
INSERT INTO "django_geo_db_zipcode" VALUES(41555,96718,-10,'Hawaii National Park, Hawaii 96718',29154,36424);
INSERT INTO "django_geo_db_zipcode" VALUES(41556,96719,-10,'Hawi, Hawaii 96719',29155,36425);
INSERT INTO "django_geo_db_zipcode" VALUES(41557,96720,-10,'Hilo, Hawaii 96720',29156,36426);
INSERT INTO "django_geo_db_zipcode" VALUES(41558,96721,-10,'Hilo, Hawaii 96721',29156,36427);
INSERT INTO "django_geo_db_zipcode" VALUES(41559,96722,-10,'Princeville, Hawaii 96722',29157,36428);
INSERT INTO "django_geo_db_zipcode" VALUES(41560,96725,-10,'Holualoa, Hawaii 96725',29158,36429);
INSERT INTO "django_geo_db_zipcode" VALUES(41561,96726,-10,'Honaunau, Hawaii 96726',29159,36430);
INSERT INTO "django_geo_db_zipcode" VALUES(41562,96727,-10,'Honokaa, Hawaii 96727',29160,36431);
INSERT INTO "django_geo_db_zipcode" VALUES(41563,96728,-10,'Honomu, Hawaii 96728',29161,36432);
INSERT INTO "django_geo_db_zipcode" VALUES(41564,96729,-10,'Hoolehua, Hawaii 96729',29162,36433);
INSERT INTO "django_geo_db_zipcode" VALUES(41565,96730,-10,'Kaaawa, Hawaii 96730',29163,36434);
INSERT INTO "django_geo_db_zipcode" VALUES(41566,96731,-10,'Kahuku, Hawaii 96731',29164,36435);
INSERT INTO "django_geo_db_zipcode" VALUES(41567,96732,-10,'Kahului, Hawaii 96732',29165,36436);
INSERT INTO "django_geo_db_zipcode" VALUES(41568,96733,-10,'Kahului, Hawaii 96733',29165,36437);
INSERT INTO "django_geo_db_zipcode" VALUES(41569,96734,-10,'Kailua, Hawaii 96734',29166,36438);
INSERT INTO "django_geo_db_zipcode" VALUES(41570,96737,-10,'Ocean View, Hawaii 96737',29167,36439);
INSERT INTO "django_geo_db_zipcode" VALUES(41571,96738,-10,'Waikoloa, Hawaii 96738',29168,36440);
INSERT INTO "django_geo_db_zipcode" VALUES(41572,96739,-10,'Keauhou, Hawaii 96739',29169,36427);
INSERT INTO "django_geo_db_zipcode" VALUES(41573,96740,-10,'Kailua Kona, Hawaii 96740',29170,36441);
INSERT INTO "django_geo_db_zipcode" VALUES(41574,96741,-10,'Kalaheo, Hawaii 96741',29171,36442);
INSERT INTO "django_geo_db_zipcode" VALUES(41575,96742,-10,'Kalaupapa, Hawaii 96742',29172,36443);
INSERT INTO "django_geo_db_zipcode" VALUES(41576,96743,-10,'Kamuela, Hawaii 96743',29173,36444);
INSERT INTO "django_geo_db_zipcode" VALUES(41577,96744,-10,'Kaneohe, Hawaii 96744',29139,36445);
INSERT INTO "django_geo_db_zipcode" VALUES(41578,96745,-10,'Kailua Kona, Hawaii 96745',29170,36427);
INSERT INTO "django_geo_db_zipcode" VALUES(41579,96746,-10,'Kapaa, Hawaii 96746',29174,36446);
INSERT INTO "django_geo_db_zipcode" VALUES(41580,96747,-10,'Kaumakani, Hawaii 96747',29175,36447);
INSERT INTO "django_geo_db_zipcode" VALUES(41581,96748,-10,'Kaunakakai, Hawaii 96748',29176,36448);
INSERT INTO "django_geo_db_zipcode" VALUES(41582,96749,-10,'Keaau, Hawaii 96749',29177,36449);
INSERT INTO "django_geo_db_zipcode" VALUES(41583,96750,-10,'Kealakekua, Hawaii 96750',29178,36450);
INSERT INTO "django_geo_db_zipcode" VALUES(41584,96751,-10,'Kealia, Hawaii 96751',29179,36451);
INSERT INTO "django_geo_db_zipcode" VALUES(41585,96752,-10,'Kekaha, Hawaii 96752',29180,36452);
INSERT INTO "django_geo_db_zipcode" VALUES(41586,96753,-10,'Kihei, Hawaii 96753',29181,36453);
INSERT INTO "django_geo_db_zipcode" VALUES(41587,96754,-10,'Kilauea, Hawaii 96754',29182,36454);
INSERT INTO "django_geo_db_zipcode" VALUES(41588,96755,-10,'Kapaau, Hawaii 96755',29183,36455);
INSERT INTO "django_geo_db_zipcode" VALUES(41589,96756,-10,'Koloa, Hawaii 96756',29184,36456);
INSERT INTO "django_geo_db_zipcode" VALUES(41590,96757,-10,'Kualapuu, Hawaii 96757',29185,36457);
INSERT INTO "django_geo_db_zipcode" VALUES(41591,96759,-10,'Kunia, Hawaii 96759',29186,36458);
INSERT INTO "django_geo_db_zipcode" VALUES(41592,96760,-10,'Kurtistown, Hawaii 96760',29187,36459);
INSERT INTO "django_geo_db_zipcode" VALUES(41593,96761,-10,'Lahaina, Hawaii 96761',29188,36460);
INSERT INTO "django_geo_db_zipcode" VALUES(41594,96762,-10,'Laie, Hawaii 96762',29189,36461);
INSERT INTO "django_geo_db_zipcode" VALUES(41595,96763,-10,'Lanai City, Hawaii 96763',29190,36462);
INSERT INTO "django_geo_db_zipcode" VALUES(41596,96764,-10,'Laupahoehoe, Hawaii 96764',29191,36463);
INSERT INTO "django_geo_db_zipcode" VALUES(41597,96765,-10,'Lawai, Hawaii 96765',29192,36464);
INSERT INTO "django_geo_db_zipcode" VALUES(41598,96766,-10,'Lihue, Hawaii 96766',29193,36465);
INSERT INTO "django_geo_db_zipcode" VALUES(41599,96767,-10,'Lahaina, Hawaii 96767',29188,36437);
INSERT INTO "django_geo_db_zipcode" VALUES(41600,96768,-10,'Makawao, Hawaii 96768',29194,36466);
INSERT INTO "django_geo_db_zipcode" VALUES(41601,96769,-10,'Makaweli, Hawaii 96769',29195,36467);
INSERT INTO "django_geo_db_zipcode" VALUES(41602,96770,-10,'Maunaloa, Hawaii 96770',29196,36468);
INSERT INTO "django_geo_db_zipcode" VALUES(41603,96771,-10,'Mountain View, Hawaii 96771',29197,36469);
INSERT INTO "django_geo_db_zipcode" VALUES(41604,96772,-10,'Naalehu, Hawaii 96772',29198,36470);
INSERT INTO "django_geo_db_zipcode" VALUES(41605,96773,-10,'Ninole, Hawaii 96773',29199,36471);
INSERT INTO "django_geo_db_zipcode" VALUES(41606,96774,-10,'Ookala, Hawaii 96774',29200,36472);
INSERT INTO "django_geo_db_zipcode" VALUES(41607,96775,-10,'Paauhau, Hawaii 96775',29201,36427);
INSERT INTO "django_geo_db_zipcode" VALUES(41608,96776,-10,'Paauilo, Hawaii 96776',29202,36473);
INSERT INTO "django_geo_db_zipcode" VALUES(41609,96777,-10,'Pahala, Hawaii 96777',29203,36474);
INSERT INTO "django_geo_db_zipcode" VALUES(41610,96778,-10,'Pahoa, Hawaii 96778',29204,36475);
INSERT INTO "django_geo_db_zipcode" VALUES(41611,96779,-10,'Paia, Hawaii 96779',29205,36476);
INSERT INTO "django_geo_db_zipcode" VALUES(41612,96780,-10,'Papaaloa, Hawaii 96780',29206,36477);
INSERT INTO "django_geo_db_zipcode" VALUES(41613,96781,-10,'Papaikou, Hawaii 96781',29207,36478);
INSERT INTO "django_geo_db_zipcode" VALUES(41614,96782,-10,'Pearl City, Hawaii 96782',29208,36479);
INSERT INTO "django_geo_db_zipcode" VALUES(41615,96783,-10,'Pepeekeo, Hawaii 96783',29209,36480);
INSERT INTO "django_geo_db_zipcode" VALUES(41616,96784,-10,'Puunene, Hawaii 96784',29210,36437);
INSERT INTO "django_geo_db_zipcode" VALUES(41617,96785,-10,'Volcano, Hawaii 96785',29138,36481);
INSERT INTO "django_geo_db_zipcode" VALUES(41618,96786,-10,'Wahiawa, Hawaii 96786',29211,36482);
INSERT INTO "django_geo_db_zipcode" VALUES(41619,96788,-10,'Pukalani, Hawaii 96788',29212,36483);
INSERT INTO "django_geo_db_zipcode" VALUES(41620,96789,-10,'Mililani, Hawaii 96789',29213,36484);
INSERT INTO "django_geo_db_zipcode" VALUES(41621,96790,-10,'Kula, Hawaii 96790',29214,36485);
INSERT INTO "django_geo_db_zipcode" VALUES(41622,96791,-10,'Waialua, Hawaii 96791',29215,36486);
INSERT INTO "django_geo_db_zipcode" VALUES(41623,96792,-10,'Waianae, Hawaii 96792',29216,36487);
INSERT INTO "django_geo_db_zipcode" VALUES(41624,96793,-10,'Wailuku, Hawaii 96793',29217,36488);
INSERT INTO "django_geo_db_zipcode" VALUES(41625,96795,-10,'Waimanalo, Hawaii 96795',29218,36489);
INSERT INTO "django_geo_db_zipcode" VALUES(41626,96796,-10,'Waimea, Hawaii 96796',29219,36490);
INSERT INTO "django_geo_db_zipcode" VALUES(41627,96797,-10,'Waipahu, Hawaii 96797',29220,36491);
INSERT INTO "django_geo_db_zipcode" VALUES(41628,96799,-10,'Pago Pago, American Samoa 96799',29221,239);
INSERT INTO "django_geo_db_zipcode" VALUES(41629,96801,-10,'Honolulu, Hawaii 96801',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41630,96802,-10,'Honolulu, Hawaii 96802',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41631,96803,-10,'Honolulu, Hawaii 96803',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41632,96804,-10,'Honolulu, Hawaii 96804',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41633,96805,-10,'Honolulu, Hawaii 96805',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41634,96806,-10,'Honolulu, Hawaii 96806',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41635,96807,-10,'Honolulu, Hawaii 96807',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41636,96808,-10,'Honolulu, Hawaii 96808',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41637,96809,-10,'Honolulu, Hawaii 96809',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41638,96810,-10,'Honolulu, Hawaii 96810',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41639,96811,-10,'Honolulu, Hawaii 96811',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41640,96812,-10,'Honolulu, Hawaii 96812',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41641,96813,-10,'Honolulu, Hawaii 96813',29222,36493);
INSERT INTO "django_geo_db_zipcode" VALUES(41642,96814,-10,'Honolulu, Hawaii 96814',29222,36494);
INSERT INTO "django_geo_db_zipcode" VALUES(41643,96815,-10,'Honolulu, Hawaii 96815',29222,36495);
INSERT INTO "django_geo_db_zipcode" VALUES(41644,96816,-10,'Honolulu, Hawaii 96816',29222,36496);
INSERT INTO "django_geo_db_zipcode" VALUES(41645,96817,-10,'Honolulu, Hawaii 96817',29222,36497);
INSERT INTO "django_geo_db_zipcode" VALUES(41646,96818,-10,'Honolulu, Hawaii 96818',29222,36498);
INSERT INTO "django_geo_db_zipcode" VALUES(41647,96819,-10,'Honolulu, Hawaii 96819',29222,36499);
INSERT INTO "django_geo_db_zipcode" VALUES(41648,96820,-10,'Honolulu, Hawaii 96820',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41649,96821,-10,'Honolulu, Hawaii 96821',29222,36500);
INSERT INTO "django_geo_db_zipcode" VALUES(41650,96822,-10,'Honolulu, Hawaii 96822',29222,36501);
INSERT INTO "django_geo_db_zipcode" VALUES(41651,96823,-10,'Honolulu, Hawaii 96823',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41652,96824,-10,'Honolulu, Hawaii 96824',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41653,96825,-10,'Honolulu, Hawaii 96825',29222,36502);
INSERT INTO "django_geo_db_zipcode" VALUES(41654,96826,-10,'Honolulu, Hawaii 96826',29222,36503);
INSERT INTO "django_geo_db_zipcode" VALUES(41655,96827,-10,'Honolulu, Hawaii 96827',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41656,96828,-10,'Honolulu, Hawaii 96828',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41657,96830,-10,'Honolulu, Hawaii 96830',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41658,96835,-10,'Honolulu, Hawaii 96835',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41659,96836,-10,'Honolulu, Hawaii 96836',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41660,96837,-10,'Honolulu, Hawaii 96837',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41661,96838,-10,'Honolulu, Hawaii 96838',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41662,96839,-10,'Honolulu, Hawaii 96839',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41663,96840,-10,'Honolulu, Hawaii 96840',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41664,96841,-10,'Honolulu, Hawaii 96841',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41665,96842,-10,'Honolulu, Hawaii 96842',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41666,96843,-10,'Honolulu, Hawaii 96843',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41667,96844,-10,'Honolulu, Hawaii 96844',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41668,96845,-10,'Honolulu, Hawaii 96845',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41669,96846,-10,'Honolulu, Hawaii 96846',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41670,96847,-10,'Honolulu, Hawaii 96847',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41671,96848,-10,'Honolulu, Hawaii 96848',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41672,96849,-10,'Honolulu, Hawaii 96849',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41673,96850,-10,'Honolulu, Hawaii 96850',29222,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41674,96853,-10,'Hickam AFB, Hawaii 96853',29223,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41675,96854,-10,'Wheeler Army Airfield, Hawaii 96854',29224,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41676,96857,-10,'Schofield Barracks, Hawaii 96857',29225,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41677,96858,-10,'Fort Shafter, Hawaii 96858',29226,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41678,96859,-10,'Tripler Army Medical Ctr, Hawaii 96859',29227,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41679,96860,-10,'Pearl Harbor, Hawaii 96860',29228,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41680,96861,-10,'Camp H M Smith, Hawaii 96861',29229,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41681,96862,-10,'Barbers Point N A S, Hawaii 96862',29230,36504);
INSERT INTO "django_geo_db_zipcode" VALUES(41682,96863,-10,'M C B H Kaneohe Bay, Hawaii 96863',29231,36505);
INSERT INTO "django_geo_db_zipcode" VALUES(41683,96885,-10,'Volcano, Hawaii 96885',29138,36506);
INSERT INTO "django_geo_db_zipcode" VALUES(41684,96898,-10,'Wake Island, Hawaii 96898',29232,36492);
INSERT INTO "django_geo_db_zipcode" VALUES(41685,97001,-8,'Antelope, Oregon 97001',29233,36507);
INSERT INTO "django_geo_db_zipcode" VALUES(41686,97002,-8,'Aurora, Oregon 97002',29234,36508);
INSERT INTO "django_geo_db_zipcode" VALUES(41687,97004,-8,'Beavercreek, Oregon 97004',29235,36509);
INSERT INTO "django_geo_db_zipcode" VALUES(41688,97005,-8,'Beaverton, Oregon 97005',29236,36510);
INSERT INTO "django_geo_db_zipcode" VALUES(41689,97006,-8,'Beaverton, Oregon 97006',29236,36511);
INSERT INTO "django_geo_db_zipcode" VALUES(41690,97007,-8,'Beaverton, Oregon 97007',29236,36512);
INSERT INTO "django_geo_db_zipcode" VALUES(41691,97008,-8,'Beaverton, Oregon 97008',29236,36513);
INSERT INTO "django_geo_db_zipcode" VALUES(41692,97009,-8,'Boring, Oregon 97009',29237,36514);
INSERT INTO "django_geo_db_zipcode" VALUES(41693,97010,-8,'Bridal Veil, Oregon 97010',29238,36515);
INSERT INTO "django_geo_db_zipcode" VALUES(41694,97011,-8,'Brightwood, Oregon 97011',29239,36516);
INSERT INTO "django_geo_db_zipcode" VALUES(41695,97013,-8,'Canby, Oregon 97013',29240,36517);
INSERT INTO "django_geo_db_zipcode" VALUES(41696,97014,-8,'Cascade Locks, Oregon 97014',29241,36518);
INSERT INTO "django_geo_db_zipcode" VALUES(41697,97015,-8,'Clackamas, Oregon 97015',29242,36519);
INSERT INTO "django_geo_db_zipcode" VALUES(41698,97016,-8,'Clatskanie, Oregon 97016',29243,36520);
INSERT INTO "django_geo_db_zipcode" VALUES(41699,97017,-8,'Colton, Oregon 97017',29244,36521);
INSERT INTO "django_geo_db_zipcode" VALUES(41700,97018,-8,'Columbia City, Oregon 97018',29245,36522);
INSERT INTO "django_geo_db_zipcode" VALUES(41701,97019,-8,'Corbett, Oregon 97019',29246,36523);
INSERT INTO "django_geo_db_zipcode" VALUES(41702,97020,-8,'Donald, Oregon 97020',29247,36524);
INSERT INTO "django_geo_db_zipcode" VALUES(41703,97021,-8,'Dufur, Oregon 97021',29248,36525);
INSERT INTO "django_geo_db_zipcode" VALUES(41704,97022,-8,'Eagle Creek, Oregon 97022',29249,36526);
INSERT INTO "django_geo_db_zipcode" VALUES(41705,97023,-8,'Estacada, Oregon 97023',29250,36527);
INSERT INTO "django_geo_db_zipcode" VALUES(41706,97024,-8,'Fairview, Oregon 97024',29251,36528);
INSERT INTO "django_geo_db_zipcode" VALUES(41707,97026,-8,'Gervais, Oregon 97026',29252,36529);
INSERT INTO "django_geo_db_zipcode" VALUES(41708,97027,-8,'Gladstone, Oregon 97027',29253,36530);
INSERT INTO "django_geo_db_zipcode" VALUES(41709,97028,-8,'Government Camp, Oregon 97028',29254,36531);
INSERT INTO "django_geo_db_zipcode" VALUES(41710,97029,-8,'Grass Valley, Oregon 97029',29255,36532);
INSERT INTO "django_geo_db_zipcode" VALUES(41711,97030,-8,'Gresham, Oregon 97030',29256,36533);
INSERT INTO "django_geo_db_zipcode" VALUES(41712,97031,-8,'Hood River, Oregon 97031',29257,36534);
INSERT INTO "django_geo_db_zipcode" VALUES(41713,97032,-8,'Hubbard, Oregon 97032',29258,36535);
INSERT INTO "django_geo_db_zipcode" VALUES(41714,97033,-8,'Kent, Oregon 97033',29259,36536);
INSERT INTO "django_geo_db_zipcode" VALUES(41715,97034,-8,'Lake Oswego, Oregon 97034',29260,36537);
INSERT INTO "django_geo_db_zipcode" VALUES(41716,97035,-8,'Lake Oswego, Oregon 97035',29260,36538);
INSERT INTO "django_geo_db_zipcode" VALUES(41717,97036,-8,'Marylhurst, Oregon 97036',29261,36539);
INSERT INTO "django_geo_db_zipcode" VALUES(41718,97037,-8,'Maupin, Oregon 97037',29262,36540);
INSERT INTO "django_geo_db_zipcode" VALUES(41719,97038,-8,'Molalla, Oregon 97038',29263,36541);
INSERT INTO "django_geo_db_zipcode" VALUES(41720,97039,-8,'Moro, Oregon 97039',29264,36542);
INSERT INTO "django_geo_db_zipcode" VALUES(41721,97040,-8,'Mosier, Oregon 97040',29265,36543);
INSERT INTO "django_geo_db_zipcode" VALUES(41722,97041,-8,'Mount Hood Parkdale, Oregon 97041',29266,36544);
INSERT INTO "django_geo_db_zipcode" VALUES(41723,97042,-8,'Mulino, Oregon 97042',29267,36545);
INSERT INTO "django_geo_db_zipcode" VALUES(41724,97044,-8,'Odell, Oregon 97044',29268,36546);
INSERT INTO "django_geo_db_zipcode" VALUES(41725,97045,-8,'Oregon City, Oregon 97045',29269,36547);
INSERT INTO "django_geo_db_zipcode" VALUES(41726,97048,-8,'Rainier, Oregon 97048',29270,36548);
INSERT INTO "django_geo_db_zipcode" VALUES(41727,97049,-8,'Rhododendron, Oregon 97049',29271,36549);
INSERT INTO "django_geo_db_zipcode" VALUES(41728,97050,-8,'Rufus, Oregon 97050',29272,36550);
INSERT INTO "django_geo_db_zipcode" VALUES(41729,97051,-8,'Saint Helens, Oregon 97051',29273,36551);
INSERT INTO "django_geo_db_zipcode" VALUES(41730,97053,-8,'Warren, Oregon 97053',29274,36552);
INSERT INTO "django_geo_db_zipcode" VALUES(41731,97054,-8,'Deer Island, Oregon 97054',29275,36553);
INSERT INTO "django_geo_db_zipcode" VALUES(41732,97055,-8,'Sandy, Oregon 97055',29276,36554);
INSERT INTO "django_geo_db_zipcode" VALUES(41733,97056,-8,'Scappoose, Oregon 97056',29277,36555);
INSERT INTO "django_geo_db_zipcode" VALUES(41734,97057,-8,'Shaniko, Oregon 97057',29278,36556);
INSERT INTO "django_geo_db_zipcode" VALUES(41735,97058,-8,'The Dalles, Oregon 97058',29279,36557);
INSERT INTO "django_geo_db_zipcode" VALUES(41736,97060,-8,'Troutdale, Oregon 97060',29280,36558);
INSERT INTO "django_geo_db_zipcode" VALUES(41737,97062,-8,'Tualatin, Oregon 97062',29281,36559);
INSERT INTO "django_geo_db_zipcode" VALUES(41738,97063,-8,'Tygh Valley, Oregon 97063',29282,36560);
INSERT INTO "django_geo_db_zipcode" VALUES(41739,97064,-8,'Vernonia, Oregon 97064',29283,36561);
INSERT INTO "django_geo_db_zipcode" VALUES(41740,97065,-8,'Wasco, Oregon 97065',29284,36562);
INSERT INTO "django_geo_db_zipcode" VALUES(41741,97067,-8,'Welches, Oregon 97067',29285,36563);
INSERT INTO "django_geo_db_zipcode" VALUES(41742,97068,-8,'West Linn, Oregon 97068',29286,36564);
INSERT INTO "django_geo_db_zipcode" VALUES(41743,97070,-8,'Wilsonville, Oregon 97070',29287,36565);
INSERT INTO "django_geo_db_zipcode" VALUES(41744,97071,-8,'Woodburn, Oregon 97071',29288,36566);
INSERT INTO "django_geo_db_zipcode" VALUES(41745,97075,-8,'Beaverton, Oregon 97075',29236,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41746,97076,-8,'Beaverton, Oregon 97076',29236,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41747,97077,-8,'Beaverton, Oregon 97077',29236,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41748,97078,-8,'Beaverton, Oregon 97078',29236,36568);
INSERT INTO "django_geo_db_zipcode" VALUES(41749,97080,-8,'Gresham, Oregon 97080',29256,36569);
INSERT INTO "django_geo_db_zipcode" VALUES(41750,97101,-8,'Amity, Oregon 97101',29289,36570);
INSERT INTO "django_geo_db_zipcode" VALUES(41751,97102,-8,'Arch Cape, Oregon 97102',29290,36571);
INSERT INTO "django_geo_db_zipcode" VALUES(41752,97103,-8,'Astoria, Oregon 97103',29291,36572);
INSERT INTO "django_geo_db_zipcode" VALUES(41753,97104,-8,'Hillsboro, Oregon 97104',29292,36573);
INSERT INTO "django_geo_db_zipcode" VALUES(41754,97106,-8,'Banks, Oregon 97106',29293,36574);
INSERT INTO "django_geo_db_zipcode" VALUES(41755,97107,-8,'Bay City, Oregon 97107',29294,36575);
INSERT INTO "django_geo_db_zipcode" VALUES(41756,97108,-8,'Beaver, Oregon 97108',29295,36576);
INSERT INTO "django_geo_db_zipcode" VALUES(41757,97109,-8,'Buxton, Oregon 97109',29296,36577);
INSERT INTO "django_geo_db_zipcode" VALUES(41758,97110,-8,'Cannon Beach, Oregon 97110',29297,36578);
INSERT INTO "django_geo_db_zipcode" VALUES(41759,97111,-8,'Carlton, Oregon 97111',29298,36579);
INSERT INTO "django_geo_db_zipcode" VALUES(41760,97112,-8,'Cloverdale, Oregon 97112',29299,36580);
INSERT INTO "django_geo_db_zipcode" VALUES(41761,97113,-8,'Cornelius, Oregon 97113',29300,36581);
INSERT INTO "django_geo_db_zipcode" VALUES(41762,97114,-8,'Dayton, Oregon 97114',29301,36582);
INSERT INTO "django_geo_db_zipcode" VALUES(41763,97115,-8,'Dundee, Oregon 97115',29302,36583);
INSERT INTO "django_geo_db_zipcode" VALUES(41764,97116,-8,'Forest Grove, Oregon 97116',29303,36584);
INSERT INTO "django_geo_db_zipcode" VALUES(41765,97117,-8,'Gales Creek, Oregon 97117',29304,36585);
INSERT INTO "django_geo_db_zipcode" VALUES(41766,97118,-8,'Garibaldi, Oregon 97118',29305,36586);
INSERT INTO "django_geo_db_zipcode" VALUES(41767,97119,-8,'Gaston, Oregon 97119',29306,36587);
INSERT INTO "django_geo_db_zipcode" VALUES(41768,97121,-8,'Hammond, Oregon 97121',29307,36588);
INSERT INTO "django_geo_db_zipcode" VALUES(41769,97122,-8,'Hebo, Oregon 97122',29308,36589);
INSERT INTO "django_geo_db_zipcode" VALUES(41770,97123,-8,'Hillsboro, Oregon 97123',29292,36590);
INSERT INTO "django_geo_db_zipcode" VALUES(41771,97124,-8,'Hillsboro, Oregon 97124',29292,36591);
INSERT INTO "django_geo_db_zipcode" VALUES(41772,97125,-8,'Manning, Oregon 97125',29309,36592);
INSERT INTO "django_geo_db_zipcode" VALUES(41773,97127,-8,'Lafayette, Oregon 97127',29310,36593);
INSERT INTO "django_geo_db_zipcode" VALUES(41774,97128,-8,'Mcminnville, Oregon 97128',29311,36594);
INSERT INTO "django_geo_db_zipcode" VALUES(41775,97130,-8,'Manzanita, Oregon 97130',29312,36595);
INSERT INTO "django_geo_db_zipcode" VALUES(41776,97131,-8,'Nehalem, Oregon 97131',29313,36596);
INSERT INTO "django_geo_db_zipcode" VALUES(41777,97132,-8,'Newberg, Oregon 97132',29314,36597);
INSERT INTO "django_geo_db_zipcode" VALUES(41778,97133,-8,'North Plains, Oregon 97133',29315,36598);
INSERT INTO "django_geo_db_zipcode" VALUES(41779,97134,-8,'Oceanside, Oregon 97134',29316,36599);
INSERT INTO "django_geo_db_zipcode" VALUES(41780,97135,-8,'Pacific City, Oregon 97135',29317,36600);
INSERT INTO "django_geo_db_zipcode" VALUES(41781,97136,-8,'Rockaway Beach, Oregon 97136',29318,36601);
INSERT INTO "django_geo_db_zipcode" VALUES(41782,97137,-8,'Saint Paul, Oregon 97137',29319,36602);
INSERT INTO "django_geo_db_zipcode" VALUES(41783,97138,-8,'Seaside, Oregon 97138',29320,36603);
INSERT INTO "django_geo_db_zipcode" VALUES(41784,97140,-8,'Sherwood, Oregon 97140',29321,36604);
INSERT INTO "django_geo_db_zipcode" VALUES(41785,97141,-8,'Tillamook, Oregon 97141',29322,36605);
INSERT INTO "django_geo_db_zipcode" VALUES(41786,97143,-8,'Netarts, Oregon 97143',29323,36606);
INSERT INTO "django_geo_db_zipcode" VALUES(41787,97144,-8,'Timber, Oregon 97144',29324,36607);
INSERT INTO "django_geo_db_zipcode" VALUES(41788,97145,-8,'Tolovana Park, Oregon 97145',29325,36608);
INSERT INTO "django_geo_db_zipcode" VALUES(41789,97146,-8,'Warrenton, Oregon 97146',29326,36609);
INSERT INTO "django_geo_db_zipcode" VALUES(41790,97147,-8,'Wheeler, Oregon 97147',29327,36610);
INSERT INTO "django_geo_db_zipcode" VALUES(41791,97148,-8,'Yamhill, Oregon 97148',29328,36611);
INSERT INTO "django_geo_db_zipcode" VALUES(41792,97149,-8,'Neskowin, Oregon 97149',29329,36612);
INSERT INTO "django_geo_db_zipcode" VALUES(41793,97180,-8,'Sherwood, Oregon 97180',29321,36613);
INSERT INTO "django_geo_db_zipcode" VALUES(41794,97201,-8,'Portland, Oregon 97201',29330,36614);
INSERT INTO "django_geo_db_zipcode" VALUES(41795,97202,-8,'Portland, Oregon 97202',29330,36615);
INSERT INTO "django_geo_db_zipcode" VALUES(41796,97203,-8,'Portland, Oregon 97203',29330,36616);
INSERT INTO "django_geo_db_zipcode" VALUES(41797,97204,-8,'Portland, Oregon 97204',29330,36617);
INSERT INTO "django_geo_db_zipcode" VALUES(41798,97205,-8,'Portland, Oregon 97205',29330,36618);
INSERT INTO "django_geo_db_zipcode" VALUES(41799,97206,-8,'Portland, Oregon 97206',29330,36619);
INSERT INTO "django_geo_db_zipcode" VALUES(41800,97207,-8,'Portland, Oregon 97207',29330,36620);
INSERT INTO "django_geo_db_zipcode" VALUES(41801,97208,-8,'Portland, Oregon 97208',29330,36621);
INSERT INTO "django_geo_db_zipcode" VALUES(41802,97209,-8,'Portland, Oregon 97209',29330,36622);
INSERT INTO "django_geo_db_zipcode" VALUES(41803,97210,-8,'Portland, Oregon 97210',29330,36623);
INSERT INTO "django_geo_db_zipcode" VALUES(41804,97211,-8,'Portland, Oregon 97211',29330,36624);
INSERT INTO "django_geo_db_zipcode" VALUES(41805,97212,-8,'Portland, Oregon 97212',29330,36625);
INSERT INTO "django_geo_db_zipcode" VALUES(41806,97213,-8,'Portland, Oregon 97213',29330,36626);
INSERT INTO "django_geo_db_zipcode" VALUES(41807,97214,-8,'Portland, Oregon 97214',29330,36627);
INSERT INTO "django_geo_db_zipcode" VALUES(41808,97215,-8,'Portland, Oregon 97215',29330,36628);
INSERT INTO "django_geo_db_zipcode" VALUES(41809,97216,-8,'Portland, Oregon 97216',29330,36629);
INSERT INTO "django_geo_db_zipcode" VALUES(41810,97217,-8,'Portland, Oregon 97217',29330,36630);
INSERT INTO "django_geo_db_zipcode" VALUES(41811,97218,-8,'Portland, Oregon 97218',29330,36631);
INSERT INTO "django_geo_db_zipcode" VALUES(41812,97219,-8,'Portland, Oregon 97219',29330,36632);
INSERT INTO "django_geo_db_zipcode" VALUES(41813,97220,-8,'Portland, Oregon 97220',29330,36633);
INSERT INTO "django_geo_db_zipcode" VALUES(41814,97221,-8,'Portland, Oregon 97221',29330,36634);
INSERT INTO "django_geo_db_zipcode" VALUES(41815,97222,-8,'Portland, Oregon 97222',29330,36635);
INSERT INTO "django_geo_db_zipcode" VALUES(41816,97223,-8,'Portland, Oregon 97223',29330,36636);
INSERT INTO "django_geo_db_zipcode" VALUES(41817,97224,-8,'Portland, Oregon 97224',29330,36637);
INSERT INTO "django_geo_db_zipcode" VALUES(41818,97225,-8,'Portland, Oregon 97225',29330,36638);
INSERT INTO "django_geo_db_zipcode" VALUES(41819,97226,-8,'Raleigh Hills, Oregon 97226',29331,36639);
INSERT INTO "django_geo_db_zipcode" VALUES(41820,97227,-8,'Portland, Oregon 97227',29330,36640);
INSERT INTO "django_geo_db_zipcode" VALUES(41821,97228,-8,'Portland, Oregon 97228',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41822,97229,-8,'Portland, Oregon 97229',29330,36642);
INSERT INTO "django_geo_db_zipcode" VALUES(41823,97230,-8,'Portland, Oregon 97230',29330,36643);
INSERT INTO "django_geo_db_zipcode" VALUES(41824,97231,-8,'Portland, Oregon 97231',29330,36644);
INSERT INTO "django_geo_db_zipcode" VALUES(41825,97232,-8,'Portland, Oregon 97232',29330,36645);
INSERT INTO "django_geo_db_zipcode" VALUES(41826,97233,-8,'Portland, Oregon 97233',29330,36646);
INSERT INTO "django_geo_db_zipcode" VALUES(41827,97236,-8,'Portland, Oregon 97236',29330,36647);
INSERT INTO "django_geo_db_zipcode" VALUES(41828,97238,-8,'Portland, Oregon 97238',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41829,97239,-8,'Portland, Oregon 97239',29330,36648);
INSERT INTO "django_geo_db_zipcode" VALUES(41830,97240,-8,'Portland, Oregon 97240',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41831,97242,-8,'Portland, Oregon 97242',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41832,97251,-8,'Portland, Oregon 97251',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41833,97253,-8,'Portland, Oregon 97253',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41834,97254,-8,'Portland, Oregon 97254',29330,36649);
INSERT INTO "django_geo_db_zipcode" VALUES(41835,97255,-8,'Portland, Oregon 97255',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41836,97256,-8,'Portland, Oregon 97256',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41837,97257,-8,'Grants Pass, Oregon 97257',29332,36650);
INSERT INTO "django_geo_db_zipcode" VALUES(41838,97258,-8,'Portland, Oregon 97258',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41839,97259,-8,'Portland, Oregon 97259',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41840,97264,-8,'Chiloquin, Oregon 97264',29333,36651);
INSERT INTO "django_geo_db_zipcode" VALUES(41841,97266,-8,'Portland, Oregon 97266',29330,36652);
INSERT INTO "django_geo_db_zipcode" VALUES(41842,97267,-8,'Portland, Oregon 97267',29330,36653);
INSERT INTO "django_geo_db_zipcode" VALUES(41843,97268,-8,'Portland, Oregon 97268',29330,36539);
INSERT INTO "django_geo_db_zipcode" VALUES(41844,97269,-8,'Portland, Oregon 97269',29330,36539);
INSERT INTO "django_geo_db_zipcode" VALUES(41845,97271,-8,'Portland, Oregon 97271',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41846,97272,-8,'Portland, Oregon 97272',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41847,97280,-8,'Portland, Oregon 97280',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41848,97281,-8,'Portland, Oregon 97281',29330,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41849,97282,-8,'Portland, Oregon 97282',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41850,97283,-8,'Portland, Oregon 97283',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41851,97286,-8,'Portland, Oregon 97286',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41852,97290,-8,'Portland, Oregon 97290',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41853,97291,-8,'Portland, Oregon 97291',29330,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41854,97292,-8,'Portland, Oregon 97292',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41855,97293,-8,'Portland, Oregon 97293',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41856,97294,-8,'Portland, Oregon 97294',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41857,97296,-8,'Portland, Oregon 97296',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41858,97298,-8,'Portland, Oregon 97298',29330,36567);
INSERT INTO "django_geo_db_zipcode" VALUES(41859,97299,-8,'Portland, Oregon 97299',29330,36641);
INSERT INTO "django_geo_db_zipcode" VALUES(41860,97301,-8,'Salem, Oregon 97301',29334,36654);
INSERT INTO "django_geo_db_zipcode" VALUES(41861,97302,-8,'Salem, Oregon 97302',29334,36655);
INSERT INTO "django_geo_db_zipcode" VALUES(41862,97303,-8,'Salem, Oregon 97303',29334,36656);
INSERT INTO "django_geo_db_zipcode" VALUES(41863,97304,-8,'Salem, Oregon 97304',29334,36657);
INSERT INTO "django_geo_db_zipcode" VALUES(41864,97305,-8,'Salem, Oregon 97305',29334,36658);
INSERT INTO "django_geo_db_zipcode" VALUES(41865,97306,-8,'Salem, Oregon 97306',29334,36659);
INSERT INTO "django_geo_db_zipcode" VALUES(41866,97307,-8,'Keizer, Oregon 97307',29335,36660);
INSERT INTO "django_geo_db_zipcode" VALUES(41867,97308,-8,'Salem, Oregon 97308',29334,36660);
INSERT INTO "django_geo_db_zipcode" VALUES(41868,97309,-8,'Salem, Oregon 97309',29334,36660);
INSERT INTO "django_geo_db_zipcode" VALUES(41869,97310,-8,'Salem, Oregon 97310',29334,36661);
INSERT INTO "django_geo_db_zipcode" VALUES(41870,97311,-8,'Salem, Oregon 97311',29334,36662);
INSERT INTO "django_geo_db_zipcode" VALUES(41871,97312,-8,'Salem, Oregon 97312',29334,36663);
INSERT INTO "django_geo_db_zipcode" VALUES(41872,97313,-8,'Salem, Oregon 97313',29334,36664);
INSERT INTO "django_geo_db_zipcode" VALUES(41873,97314,-8,'Salem, Oregon 97314',29334,36665);
INSERT INTO "django_geo_db_zipcode" VALUES(41874,97321,-8,'Albany, Oregon 97321',29336,36666);
INSERT INTO "django_geo_db_zipcode" VALUES(41875,97322,-8,'Albany, Oregon 97322',29336,36667);
INSERT INTO "django_geo_db_zipcode" VALUES(41876,97324,-8,'Alsea, Oregon 97324',29337,36668);
INSERT INTO "django_geo_db_zipcode" VALUES(41877,97325,-8,'Aumsville, Oregon 97325',29338,36669);
INSERT INTO "django_geo_db_zipcode" VALUES(41878,97326,-8,'Blodgett, Oregon 97326',29339,36670);
INSERT INTO "django_geo_db_zipcode" VALUES(41879,97327,-8,'Brownsville, Oregon 97327',29340,36671);
INSERT INTO "django_geo_db_zipcode" VALUES(41880,97329,-8,'Cascadia, Oregon 97329',29341,36672);
INSERT INTO "django_geo_db_zipcode" VALUES(41881,97330,-8,'Corvallis, Oregon 97330',29342,36673);
INSERT INTO "django_geo_db_zipcode" VALUES(41882,97331,-8,'Corvallis, Oregon 97331',29342,36674);
INSERT INTO "django_geo_db_zipcode" VALUES(41883,97333,-8,'Corvallis, Oregon 97333',29342,36675);
INSERT INTO "django_geo_db_zipcode" VALUES(41884,97335,-8,'Crabtree, Oregon 97335',29343,36676);
INSERT INTO "django_geo_db_zipcode" VALUES(41885,97336,-8,'Crawfordsville, Oregon 97336',29344,36677);
INSERT INTO "django_geo_db_zipcode" VALUES(41886,97338,-8,'Dallas, Oregon 97338',29345,36678);
INSERT INTO "django_geo_db_zipcode" VALUES(41887,97339,-8,'Corvallis, Oregon 97339',29342,36679);
INSERT INTO "django_geo_db_zipcode" VALUES(41888,97341,-8,'Depoe Bay, Oregon 97341',29346,36680);
INSERT INTO "django_geo_db_zipcode" VALUES(41889,97342,-8,'Detroit, Oregon 97342',29347,36681);
INSERT INTO "django_geo_db_zipcode" VALUES(41890,97343,-8,'Eddyville, Oregon 97343',29348,36682);
INSERT INTO "django_geo_db_zipcode" VALUES(41891,97344,-8,'Falls City, Oregon 97344',29349,36683);
INSERT INTO "django_geo_db_zipcode" VALUES(41892,97345,-8,'Foster, Oregon 97345',29350,36684);
INSERT INTO "django_geo_db_zipcode" VALUES(41893,97346,-8,'Gates, Oregon 97346',29351,36685);
INSERT INTO "django_geo_db_zipcode" VALUES(41894,97347,-8,'Grand Ronde, Oregon 97347',29352,36686);
INSERT INTO "django_geo_db_zipcode" VALUES(41895,97348,-8,'Halsey, Oregon 97348',29353,36687);
INSERT INTO "django_geo_db_zipcode" VALUES(41896,97350,-8,'Idanha, Oregon 97350',29354,36688);
INSERT INTO "django_geo_db_zipcode" VALUES(41897,97351,-8,'Independence, Oregon 97351',29355,36689);
INSERT INTO "django_geo_db_zipcode" VALUES(41898,97352,-8,'Jefferson, Oregon 97352',29356,36690);
INSERT INTO "django_geo_db_zipcode" VALUES(41899,97355,-8,'Lebanon, Oregon 97355',29357,36691);
INSERT INTO "django_geo_db_zipcode" VALUES(41900,97357,-8,'Logsden, Oregon 97357',29358,36692);
INSERT INTO "django_geo_db_zipcode" VALUES(41901,97358,-8,'Lyons, Oregon 97358',29359,36693);
INSERT INTO "django_geo_db_zipcode" VALUES(41902,97359,-8,'Marion, Oregon 97359',29360,36660);
INSERT INTO "django_geo_db_zipcode" VALUES(41903,97360,-8,'Mill City, Oregon 97360',29361,36694);
INSERT INTO "django_geo_db_zipcode" VALUES(41904,97361,-8,'Monmouth, Oregon 97361',29362,36695);
INSERT INTO "django_geo_db_zipcode" VALUES(41905,97362,-8,'Mount Angel, Oregon 97362',29363,36696);
INSERT INTO "django_geo_db_zipcode" VALUES(41906,97364,-8,'Neotsu, Oregon 97364',29364,36697);
INSERT INTO "django_geo_db_zipcode" VALUES(41907,97365,-8,'Newport, Oregon 97365',29365,36698);
INSERT INTO "django_geo_db_zipcode" VALUES(41908,97366,-8,'South Beach, Oregon 97366',29366,36699);
INSERT INTO "django_geo_db_zipcode" VALUES(41909,97367,-8,'Lincoln City, Oregon 97367',29367,36700);
INSERT INTO "django_geo_db_zipcode" VALUES(41910,97368,-8,'Otis, Oregon 97368',29368,36701);
INSERT INTO "django_geo_db_zipcode" VALUES(41911,97369,-8,'Otter Rock, Oregon 97369',29369,36702);
INSERT INTO "django_geo_db_zipcode" VALUES(41912,97370,-8,'Philomath, Oregon 97370',29370,36703);
INSERT INTO "django_geo_db_zipcode" VALUES(41913,97371,-8,'Rickreall, Oregon 97371',29371,36704);
INSERT INTO "django_geo_db_zipcode" VALUES(41914,97372,-8,'Rose Lodge, Oregon 97372',29372,36705);
INSERT INTO "django_geo_db_zipcode" VALUES(41915,97373,-8,'Saint Benedict, Oregon 97373',29373,36660);
INSERT INTO "django_geo_db_zipcode" VALUES(41916,97374,-8,'Scio, Oregon 97374',29374,36706);
INSERT INTO "django_geo_db_zipcode" VALUES(41917,97375,-8,'Scotts Mills, Oregon 97375',29375,36707);
INSERT INTO "django_geo_db_zipcode" VALUES(41918,97376,-8,'Seal Rock, Oregon 97376',29376,36708);
INSERT INTO "django_geo_db_zipcode" VALUES(41919,97377,-8,'Shedd, Oregon 97377',29377,36709);
INSERT INTO "django_geo_db_zipcode" VALUES(41920,97378,-8,'Sheridan, Oregon 97378',29378,36710);
INSERT INTO "django_geo_db_zipcode" VALUES(41921,97380,-8,'Siletz, Oregon 97380',29379,36711);
INSERT INTO "django_geo_db_zipcode" VALUES(41922,97381,-8,'Silverton, Oregon 97381',29380,36712);
INSERT INTO "django_geo_db_zipcode" VALUES(41923,97383,-8,'Stayton, Oregon 97383',29381,36713);
INSERT INTO "django_geo_db_zipcode" VALUES(41924,97384,-8,'Mehama, Oregon 97384',29382,36714);
INSERT INTO "django_geo_db_zipcode" VALUES(41925,97385,-8,'Sublimity, Oregon 97385',29383,36715);
INSERT INTO "django_geo_db_zipcode" VALUES(41926,97386,-8,'Sweet Home, Oregon 97386',29384,36716);
INSERT INTO "django_geo_db_zipcode" VALUES(41927,97388,-8,'Gleneden Beach, Oregon 97388',29385,36717);
INSERT INTO "django_geo_db_zipcode" VALUES(41928,97389,-8,'Tangent, Oregon 97389',29386,36718);
INSERT INTO "django_geo_db_zipcode" VALUES(41929,97390,-8,'Tidewater, Oregon 97390',29387,36719);
INSERT INTO "django_geo_db_zipcode" VALUES(41930,97391,-8,'Toledo, Oregon 97391',29388,36720);
INSERT INTO "django_geo_db_zipcode" VALUES(41931,97392,-8,'Turner, Oregon 97392',29389,36721);
INSERT INTO "django_geo_db_zipcode" VALUES(41932,97394,-8,'Waldport, Oregon 97394',29390,36722);
INSERT INTO "django_geo_db_zipcode" VALUES(41933,97396,-8,'Willamina, Oregon 97396',29391,36723);
INSERT INTO "django_geo_db_zipcode" VALUES(41934,97401,-8,'Eugene, Oregon 97401',29392,36724);
INSERT INTO "django_geo_db_zipcode" VALUES(41935,97402,-8,'Eugene, Oregon 97402',29392,36725);
INSERT INTO "django_geo_db_zipcode" VALUES(41936,97403,-8,'Eugene, Oregon 97403',29392,36726);
INSERT INTO "django_geo_db_zipcode" VALUES(41937,97404,-8,'Eugene, Oregon 97404',29392,36727);
INSERT INTO "django_geo_db_zipcode" VALUES(41938,97405,-8,'Eugene, Oregon 97405',29392,36728);
INSERT INTO "django_geo_db_zipcode" VALUES(41939,97406,-8,'Agness, Oregon 97406',29393,36729);
INSERT INTO "django_geo_db_zipcode" VALUES(41940,97407,-8,'Allegany, Oregon 97407',29394,36730);
INSERT INTO "django_geo_db_zipcode" VALUES(41941,97408,-8,'Eugene, Oregon 97408',29392,36731);
INSERT INTO "django_geo_db_zipcode" VALUES(41942,97409,-8,'Alvadore, Oregon 97409',29395,36732);
INSERT INTO "django_geo_db_zipcode" VALUES(41943,97410,-8,'Azalea, Oregon 97410',29396,36733);
INSERT INTO "django_geo_db_zipcode" VALUES(41944,97411,-8,'Bandon, Oregon 97411',29397,36734);
INSERT INTO "django_geo_db_zipcode" VALUES(41945,97412,-8,'Blachly, Oregon 97412',29398,36735);
INSERT INTO "django_geo_db_zipcode" VALUES(41946,97413,-8,'Blue River, Oregon 97413',29399,36736);
INSERT INTO "django_geo_db_zipcode" VALUES(41947,97414,-8,'Broadbent, Oregon 97414',29400,36737);
INSERT INTO "django_geo_db_zipcode" VALUES(41948,97415,-8,'Brookings, Oregon 97415',29401,36738);
INSERT INTO "django_geo_db_zipcode" VALUES(41949,97416,-8,'Camas Valley, Oregon 97416',29402,36739);
INSERT INTO "django_geo_db_zipcode" VALUES(41950,97417,-8,'Canyonville, Oregon 97417',29403,36740);
INSERT INTO "django_geo_db_zipcode" VALUES(41951,97419,-8,'Cheshire, Oregon 97419',29404,36741);
INSERT INTO "django_geo_db_zipcode" VALUES(41952,97420,-8,'Coos Bay, Oregon 97420',29405,36742);
INSERT INTO "django_geo_db_zipcode" VALUES(41953,97423,-8,'Coquille, Oregon 97423',29406,36743);
INSERT INTO "django_geo_db_zipcode" VALUES(41954,97424,-8,'Cottage Grove, Oregon 97424',29407,36744);
INSERT INTO "django_geo_db_zipcode" VALUES(41955,97425,-8,'Crescent Lake, Oregon 97425',29408,36745);
INSERT INTO "django_geo_db_zipcode" VALUES(41956,97426,-8,'Creswell, Oregon 97426',29409,36746);
INSERT INTO "django_geo_db_zipcode" VALUES(41957,97427,-8,'Culp Creek, Oregon 97427',29410,36747);
INSERT INTO "django_geo_db_zipcode" VALUES(41958,97428,-8,'Curtin, Oregon 97428',29411,36748);
INSERT INTO "django_geo_db_zipcode" VALUES(41959,97429,-8,'Days Creek, Oregon 97429',29412,36749);
INSERT INTO "django_geo_db_zipcode" VALUES(41960,97430,-8,'Deadwood, Oregon 97430',29413,36750);
INSERT INTO "django_geo_db_zipcode" VALUES(41961,97431,-8,'Dexter, Oregon 97431',29414,36751);
INSERT INTO "django_geo_db_zipcode" VALUES(41962,97432,-8,'Dillard, Oregon 97432',29415,36752);
INSERT INTO "django_geo_db_zipcode" VALUES(41963,97434,-8,'Dorena, Oregon 97434',29416,36753);
INSERT INTO "django_geo_db_zipcode" VALUES(41964,97435,-8,'Drain, Oregon 97435',29417,36754);
INSERT INTO "django_geo_db_zipcode" VALUES(41965,97436,-8,'Elkton, Oregon 97436',29418,36755);
INSERT INTO "django_geo_db_zipcode" VALUES(41966,97437,-8,'Elmira, Oregon 97437',29419,36756);
INSERT INTO "django_geo_db_zipcode" VALUES(41967,97438,-8,'Fall Creek, Oregon 97438',29420,36757);
INSERT INTO "django_geo_db_zipcode" VALUES(41968,97439,-8,'Florence, Oregon 97439',29421,36758);
INSERT INTO "django_geo_db_zipcode" VALUES(41969,97440,-8,'Eugene, Oregon 97440',29392,36759);
INSERT INTO "django_geo_db_zipcode" VALUES(41970,97441,-8,'Gardiner, Oregon 97441',29422,36760);
INSERT INTO "django_geo_db_zipcode" VALUES(41971,97442,-8,'Glendale, Oregon 97442',29423,36761);
INSERT INTO "django_geo_db_zipcode" VALUES(41972,97443,-8,'Glide, Oregon 97443',29424,36762);
INSERT INTO "django_geo_db_zipcode" VALUES(41973,97444,-8,'Gold Beach, Oregon 97444',29425,36763);
INSERT INTO "django_geo_db_zipcode" VALUES(41974,97446,-8,'Harrisburg, Oregon 97446',29426,36764);
INSERT INTO "django_geo_db_zipcode" VALUES(41975,97447,-8,'Idleyld Park, Oregon 97447',29427,36765);
INSERT INTO "django_geo_db_zipcode" VALUES(41976,97448,-8,'Junction City, Oregon 97448',29428,36766);
INSERT INTO "django_geo_db_zipcode" VALUES(41977,97449,-8,'Lakeside, Oregon 97449',29429,36767);
INSERT INTO "django_geo_db_zipcode" VALUES(41978,97450,-8,'Langlois, Oregon 97450',29430,36768);
INSERT INTO "django_geo_db_zipcode" VALUES(41979,97451,-8,'Lorane, Oregon 97451',29431,36769);
INSERT INTO "django_geo_db_zipcode" VALUES(41980,97452,-8,'Lowell, Oregon 97452',29432,36770);
INSERT INTO "django_geo_db_zipcode" VALUES(41981,97453,-8,'Mapleton, Oregon 97453',29433,36771);
INSERT INTO "django_geo_db_zipcode" VALUES(41982,97454,-8,'Marcola, Oregon 97454',29434,36772);
INSERT INTO "django_geo_db_zipcode" VALUES(41983,97455,-8,'Pleasant Hill, Oregon 97455',29435,36773);
INSERT INTO "django_geo_db_zipcode" VALUES(41984,97456,-8,'Monroe, Oregon 97456',29436,36774);
INSERT INTO "django_geo_db_zipcode" VALUES(41985,97457,-8,'Myrtle Creek, Oregon 97457',29437,36775);
INSERT INTO "django_geo_db_zipcode" VALUES(41986,97458,-8,'Myrtle Point, Oregon 97458',29438,36776);
INSERT INTO "django_geo_db_zipcode" VALUES(41987,97459,-8,'North Bend, Oregon 97459',29439,36777);
INSERT INTO "django_geo_db_zipcode" VALUES(41988,97460,-8,'Norway, Oregon 97460',29440,36778);
INSERT INTO "django_geo_db_zipcode" VALUES(41989,97461,-8,'Noti, Oregon 97461',29441,36779);
INSERT INTO "django_geo_db_zipcode" VALUES(41990,97462,-8,'Oakland, Oregon 97462',29442,36780);
INSERT INTO "django_geo_db_zipcode" VALUES(41991,97463,-8,'Oakridge, Oregon 97463',29443,36781);
INSERT INTO "django_geo_db_zipcode" VALUES(41992,97464,-8,'Ophir, Oregon 97464',29444,36782);
INSERT INTO "django_geo_db_zipcode" VALUES(41993,97465,-8,'Port Orford, Oregon 97465',29445,36783);
INSERT INTO "django_geo_db_zipcode" VALUES(41994,97466,-8,'Powers, Oregon 97466',29446,36784);
INSERT INTO "django_geo_db_zipcode" VALUES(41995,97467,-8,'Reedsport, Oregon 97467',29447,36785);
INSERT INTO "django_geo_db_zipcode" VALUES(41996,97468,-8,'Remote, Oregon 97468',29448,36778);
INSERT INTO "django_geo_db_zipcode" VALUES(41997,97469,-8,'Riddle, Oregon 97469',29449,36786);
INSERT INTO "django_geo_db_zipcode" VALUES(41998,97470,-8,'Roseburg, Oregon 97470',29450,36787);
INSERT INTO "django_geo_db_zipcode" VALUES(41999,97472,-8,'Saginaw, Oregon 97472',29451,36759);
INSERT INTO "django_geo_db_zipcode" VALUES(42000,97473,-8,'Scottsburg, Oregon 97473',29452,36788);
INSERT INTO "django_geo_db_zipcode" VALUES(42001,97476,-8,'Sixes, Oregon 97476',29453,36789);
INSERT INTO "django_geo_db_zipcode" VALUES(42002,97477,-8,'Springfield, Oregon 97477',29454,36790);
INSERT INTO "django_geo_db_zipcode" VALUES(42003,97478,-8,'Springfield, Oregon 97478',29454,36791);
INSERT INTO "django_geo_db_zipcode" VALUES(42004,97479,-8,'Sutherlin, Oregon 97479',29455,36792);
INSERT INTO "django_geo_db_zipcode" VALUES(42005,97480,-8,'Swisshome, Oregon 97480',29456,36793);
INSERT INTO "django_geo_db_zipcode" VALUES(42006,97481,-8,'Tenmile, Oregon 97481',29457,36794);
INSERT INTO "django_geo_db_zipcode" VALUES(42007,97482,-8,'Thurston, Oregon 97482',29458,36759);
INSERT INTO "django_geo_db_zipcode" VALUES(42008,97484,-8,'Tiller, Oregon 97484',29459,36795);
INSERT INTO "django_geo_db_zipcode" VALUES(42009,97486,-8,'Umpqua, Oregon 97486',29460,36796);
INSERT INTO "django_geo_db_zipcode" VALUES(42010,97487,-8,'Veneta, Oregon 97487',29461,36797);
INSERT INTO "django_geo_db_zipcode" VALUES(42011,97488,-8,'Vida, Oregon 97488',29462,36798);
INSERT INTO "django_geo_db_zipcode" VALUES(42012,97489,-8,'Walterville, Oregon 97489',29463,36799);
INSERT INTO "django_geo_db_zipcode" VALUES(42013,97490,-8,'Walton, Oregon 97490',29464,36800);
INSERT INTO "django_geo_db_zipcode" VALUES(42014,97491,-8,'Wedderburn, Oregon 97491',29465,36801);
INSERT INTO "django_geo_db_zipcode" VALUES(42015,97492,-8,'Westfir, Oregon 97492',29466,36802);
INSERT INTO "django_geo_db_zipcode" VALUES(42016,97493,-8,'Westlake, Oregon 97493',29467,36803);
INSERT INTO "django_geo_db_zipcode" VALUES(42017,97494,-8,'Wilbur, Oregon 97494',29468,36804);
INSERT INTO "django_geo_db_zipcode" VALUES(42018,97495,-8,'Winchester, Oregon 97495',29469,36805);
INSERT INTO "django_geo_db_zipcode" VALUES(42019,97496,-8,'Winston, Oregon 97496',29470,36806);
INSERT INTO "django_geo_db_zipcode" VALUES(42020,97497,-8,'Wolf Creek, Oregon 97497',29471,36807);
INSERT INTO "django_geo_db_zipcode" VALUES(42021,97498,-8,'Yachats, Oregon 97498',29472,36808);
INSERT INTO "django_geo_db_zipcode" VALUES(42022,97499,-8,'Yoncalla, Oregon 97499',29473,36809);
INSERT INTO "django_geo_db_zipcode" VALUES(42023,97501,-8,'Medford, Oregon 97501',29474,36810);
INSERT INTO "django_geo_db_zipcode" VALUES(42024,97502,-8,'Central Point, Oregon 97502',29475,36811);
INSERT INTO "django_geo_db_zipcode" VALUES(42025,97503,-8,'White City, Oregon 97503',29476,36812);
INSERT INTO "django_geo_db_zipcode" VALUES(42026,97504,-8,'Medford, Oregon 97504',29474,36813);
INSERT INTO "django_geo_db_zipcode" VALUES(42027,97520,-8,'Ashland, Oregon 97520',29477,36814);
INSERT INTO "django_geo_db_zipcode" VALUES(42028,97522,-8,'Butte Falls, Oregon 97522',29478,36815);
INSERT INTO "django_geo_db_zipcode" VALUES(42029,97523,-8,'Cave Junction, Oregon 97523',29479,36816);
INSERT INTO "django_geo_db_zipcode" VALUES(42030,97524,-8,'Eagle Point, Oregon 97524',29480,36817);
INSERT INTO "django_geo_db_zipcode" VALUES(42031,97525,-8,'Gold Hill, Oregon 97525',29481,36818);
INSERT INTO "django_geo_db_zipcode" VALUES(42032,97526,-8,'Grants Pass, Oregon 97526',29332,36819);
INSERT INTO "django_geo_db_zipcode" VALUES(42033,97527,-8,'Grants Pass, Oregon 97527',29332,36820);
INSERT INTO "django_geo_db_zipcode" VALUES(42034,97528,-8,'Grants Pass, Oregon 97528',29332,36821);
INSERT INTO "django_geo_db_zipcode" VALUES(42035,97530,-8,'Jacksonville, Oregon 97530',29482,36822);
INSERT INTO "django_geo_db_zipcode" VALUES(42036,97531,-8,'Kerby, Oregon 97531',29483,36823);
INSERT INTO "django_geo_db_zipcode" VALUES(42037,97532,-8,'Merlin, Oregon 97532',29484,36824);
INSERT INTO "django_geo_db_zipcode" VALUES(42038,97533,-8,'Murphy, Oregon 97533',29485,36825);
INSERT INTO "django_geo_db_zipcode" VALUES(42039,97534,-8,'O Brien, Oregon 97534',29486,36826);
INSERT INTO "django_geo_db_zipcode" VALUES(42040,97535,-8,'Phoenix, Oregon 97535',29487,36827);
INSERT INTO "django_geo_db_zipcode" VALUES(42041,97536,-8,'Prospect, Oregon 97536',29488,36828);
INSERT INTO "django_geo_db_zipcode" VALUES(42042,97537,-8,'Rogue River, Oregon 97537',29489,36829);
INSERT INTO "django_geo_db_zipcode" VALUES(42043,97538,-8,'Selma, Oregon 97538',29490,36830);
INSERT INTO "django_geo_db_zipcode" VALUES(42044,97539,-8,'Shady Cove, Oregon 97539',29491,36831);
INSERT INTO "django_geo_db_zipcode" VALUES(42045,97540,-8,'Talent, Oregon 97540',29492,36832);
INSERT INTO "django_geo_db_zipcode" VALUES(42046,97541,-8,'Trail, Oregon 97541',29493,36833);
INSERT INTO "django_geo_db_zipcode" VALUES(42047,97543,-8,'Wilderville, Oregon 97543',29494,36834);
INSERT INTO "django_geo_db_zipcode" VALUES(42048,97544,-8,'Williams, Oregon 97544',29495,36835);
INSERT INTO "django_geo_db_zipcode" VALUES(42049,97567,-8,'Lincoln City, Oregon 97567',29367,36836);
INSERT INTO "django_geo_db_zipcode" VALUES(42050,97587,-8,'Lostine, Oregon 97587',29496,36837);
INSERT INTO "django_geo_db_zipcode" VALUES(42051,97601,-8,'Klamath Falls, Oregon 97601',29497,36838);
INSERT INTO "django_geo_db_zipcode" VALUES(42052,97602,-8,'Klamath Falls, Oregon 97602',29497,36839);
INSERT INTO "django_geo_db_zipcode" VALUES(42053,97603,-8,'Klamath Falls, Oregon 97603',29497,36840);
INSERT INTO "django_geo_db_zipcode" VALUES(42054,97604,-8,'Crater Lake, Oregon 97604',29498,36841);
INSERT INTO "django_geo_db_zipcode" VALUES(42055,97620,-8,'Adel, Oregon 97620',29499,36842);
INSERT INTO "django_geo_db_zipcode" VALUES(42056,97621,-8,'Beatty, Oregon 97621',29500,36843);
INSERT INTO "django_geo_db_zipcode" VALUES(42057,97622,-8,'Bly, Oregon 97622',29501,36844);
INSERT INTO "django_geo_db_zipcode" VALUES(42058,97623,-8,'Bonanza, Oregon 97623',29502,36845);
INSERT INTO "django_geo_db_zipcode" VALUES(42059,97624,-8,'Chiloquin, Oregon 97624',29333,36846);
INSERT INTO "django_geo_db_zipcode" VALUES(42060,97625,-8,'Dairy, Oregon 97625',29503,36847);
INSERT INTO "django_geo_db_zipcode" VALUES(42061,97626,-8,'Fort Klamath, Oregon 97626',29504,36848);
INSERT INTO "django_geo_db_zipcode" VALUES(42062,97627,-8,'Keno, Oregon 97627',29505,36849);
INSERT INTO "django_geo_db_zipcode" VALUES(42063,97630,-8,'Lakeview, Oregon 97630',29506,36850);
INSERT INTO "django_geo_db_zipcode" VALUES(42064,97631,-8,'Monmouth, Oregon 97631',29362,36851);
INSERT INTO "django_geo_db_zipcode" VALUES(42065,97632,-8,'Malin, Oregon 97632',29507,36852);
INSERT INTO "django_geo_db_zipcode" VALUES(42066,97633,-8,'Merrill, Oregon 97633',29508,36853);
INSERT INTO "django_geo_db_zipcode" VALUES(42067,97634,-8,'Midland, Oregon 97634',29509,36854);
INSERT INTO "django_geo_db_zipcode" VALUES(42068,97635,-8,'New Pine Creek, California 97635',29510,36855);
INSERT INTO "django_geo_db_zipcode" VALUES(42069,97636,-8,'Paisley, Oregon 97636',29511,36856);
INSERT INTO "django_geo_db_zipcode" VALUES(42070,97637,-8,'Plush, Oregon 97637',29512,36857);
INSERT INTO "django_geo_db_zipcode" VALUES(42071,97638,-8,'Silver Lake, Oregon 97638',29513,36858);
INSERT INTO "django_geo_db_zipcode" VALUES(42072,97639,-8,'Sprague River, Oregon 97639',29514,36859);
INSERT INTO "django_geo_db_zipcode" VALUES(42073,97640,-8,'Summer Lake, Oregon 97640',29515,36860);
INSERT INTO "django_geo_db_zipcode" VALUES(42074,97641,-8,'Christmas Valley, Oregon 97641',29516,36861);
INSERT INTO "django_geo_db_zipcode" VALUES(42075,97701,-8,'Bend, Oregon 97701',29517,36862);
INSERT INTO "django_geo_db_zipcode" VALUES(42076,97702,-8,'Bend, Oregon 97702',29517,36863);
INSERT INTO "django_geo_db_zipcode" VALUES(42077,97707,-8,'Bend, Oregon 97707',29517,36864);
INSERT INTO "django_geo_db_zipcode" VALUES(42078,97708,-8,'Bend, Oregon 97708',29517,36865);
INSERT INTO "django_geo_db_zipcode" VALUES(42079,97709,-8,'Bend, Oregon 97709',29517,36865);
INSERT INTO "django_geo_db_zipcode" VALUES(42080,97710,-8,'Fields, Oregon 97710',29518,36866);
INSERT INTO "django_geo_db_zipcode" VALUES(42081,97711,-8,'Ashwood, Oregon 97711',29519,36867);
INSERT INTO "django_geo_db_zipcode" VALUES(42082,97712,-8,'Brothers, Oregon 97712',29520,36868);
INSERT INTO "django_geo_db_zipcode" VALUES(42083,97720,-8,'Burns, Oregon 97720',29521,36869);
INSERT INTO "django_geo_db_zipcode" VALUES(42084,97721,-8,'Princeton, Oregon 97721',29522,36870);
INSERT INTO "django_geo_db_zipcode" VALUES(42085,97722,-8,'Diamond, Oregon 97722',29523,36871);
INSERT INTO "django_geo_db_zipcode" VALUES(42086,97730,-8,'Camp Sherman, Oregon 97730',29524,36872);
INSERT INTO "django_geo_db_zipcode" VALUES(42087,97731,-8,'Chemult, Oregon 97731',29525,36873);
INSERT INTO "django_geo_db_zipcode" VALUES(42088,97732,-8,'Crane, Oregon 97732',29526,36874);
INSERT INTO "django_geo_db_zipcode" VALUES(42089,97733,-8,'Crescent, Oregon 97733',29527,36875);
INSERT INTO "django_geo_db_zipcode" VALUES(42090,97734,-8,'Culver, Oregon 97734',29528,36876);
INSERT INTO "django_geo_db_zipcode" VALUES(42091,97735,-8,'Fort Rock, Oregon 97735',29529,36877);
INSERT INTO "django_geo_db_zipcode" VALUES(42092,97736,-8,'Frenchglen, Oregon 97736',29530,36878);
INSERT INTO "django_geo_db_zipcode" VALUES(42093,97737,-8,'Gilchrist, Oregon 97737',29531,36879);
INSERT INTO "django_geo_db_zipcode" VALUES(42094,97738,-8,'Hines, Oregon 97738',29532,36880);
INSERT INTO "django_geo_db_zipcode" VALUES(42095,97739,-8,'La Pine, Oregon 97739',29533,36881);
INSERT INTO "django_geo_db_zipcode" VALUES(42096,97740,-8,'Lawen, Oregon 97740',29534,36882);
INSERT INTO "django_geo_db_zipcode" VALUES(42097,97741,-8,'Madras, Oregon 97741',29535,36883);
INSERT INTO "django_geo_db_zipcode" VALUES(42098,97750,-8,'Mitchell, Oregon 97750',29536,36884);
INSERT INTO "django_geo_db_zipcode" VALUES(42099,97751,-8,'Paulina, Oregon 97751',29537,36885);
INSERT INTO "django_geo_db_zipcode" VALUES(42100,97752,-8,'Post, Oregon 97752',29538,36886);
INSERT INTO "django_geo_db_zipcode" VALUES(42101,97753,-8,'Powell Butte, Oregon 97753',29539,36887);
INSERT INTO "django_geo_db_zipcode" VALUES(42102,97754,-8,'Prineville, Oregon 97754',29540,36888);
INSERT INTO "django_geo_db_zipcode" VALUES(42103,97756,-8,'Redmond, Oregon 97756',29541,36889);
INSERT INTO "django_geo_db_zipcode" VALUES(42104,97758,-8,'Riley, Oregon 97758',29542,36890);
INSERT INTO "django_geo_db_zipcode" VALUES(42105,97759,-8,'Sisters, Oregon 97759',29543,36891);
INSERT INTO "django_geo_db_zipcode" VALUES(42106,97760,-8,'Terrebonne, Oregon 97760',29544,36892);
INSERT INTO "django_geo_db_zipcode" VALUES(42107,97761,-8,'Warm Springs, Oregon 97761',29545,36893);
INSERT INTO "django_geo_db_zipcode" VALUES(42108,97795,-8,'Roseburg North, Oregon 97795',29546,36894);
INSERT INTO "django_geo_db_zipcode" VALUES(42109,97801,-8,'Pendleton, Oregon 97801',29547,36895);
INSERT INTO "django_geo_db_zipcode" VALUES(42110,97810,-8,'Adams, Oregon 97810',29548,36896);
INSERT INTO "django_geo_db_zipcode" VALUES(42111,97812,-8,'Arlington, Oregon 97812',29549,36897);
INSERT INTO "django_geo_db_zipcode" VALUES(42112,97813,-8,'Athena, Oregon 97813',29550,36898);
INSERT INTO "django_geo_db_zipcode" VALUES(42113,97814,-8,'Baker City, Oregon 97814',29551,36899);
INSERT INTO "django_geo_db_zipcode" VALUES(42114,97817,-8,'Bates, Oregon 97817',29552,36900);
INSERT INTO "django_geo_db_zipcode" VALUES(42115,97818,-8,'Boardman, Oregon 97818',29553,36901);
INSERT INTO "django_geo_db_zipcode" VALUES(42116,97819,-8,'Bridgeport, Oregon 97819',29554,36902);
INSERT INTO "django_geo_db_zipcode" VALUES(42117,97820,-8,'Canyon City, Oregon 97820',29555,36903);
INSERT INTO "django_geo_db_zipcode" VALUES(42118,97821,-8,'Cayuse, Oregon 97821',29556,36904);
INSERT INTO "django_geo_db_zipcode" VALUES(42119,97823,-8,'Condon, Oregon 97823',29557,36905);
INSERT INTO "django_geo_db_zipcode" VALUES(42120,97824,-8,'Cove, Oregon 97824',29558,36906);
INSERT INTO "django_geo_db_zipcode" VALUES(42121,97825,-8,'Dayville, Oregon 97825',29559,36907);
INSERT INTO "django_geo_db_zipcode" VALUES(42122,97826,-8,'Echo, Oregon 97826',29560,36908);
INSERT INTO "django_geo_db_zipcode" VALUES(42123,97827,-8,'Elgin, Oregon 97827',29561,36909);
INSERT INTO "django_geo_db_zipcode" VALUES(42124,97828,-8,'Enterprise, Oregon 97828',29562,36910);
INSERT INTO "django_geo_db_zipcode" VALUES(42125,97830,-8,'Fossil, Oregon 97830',29563,36911);
INSERT INTO "django_geo_db_zipcode" VALUES(42126,97831,-8,'Fox, Oregon 97831',29564,36912);
INSERT INTO "django_geo_db_zipcode" VALUES(42127,97833,-8,'Haines, Oregon 97833',29565,36913);
INSERT INTO "django_geo_db_zipcode" VALUES(42128,97834,-8,'Halfway, Oregon 97834',29566,36914);
INSERT INTO "django_geo_db_zipcode" VALUES(42129,97835,-8,'Helix, Oregon 97835',29567,36915);
INSERT INTO "django_geo_db_zipcode" VALUES(42130,97836,-8,'Heppner, Oregon 97836',29568,36916);
INSERT INTO "django_geo_db_zipcode" VALUES(42131,97837,-8,'Hereford, Oregon 97837',29569,36917);
INSERT INTO "django_geo_db_zipcode" VALUES(42132,97838,-8,'Hermiston, Oregon 97838',29570,36918);
INSERT INTO "django_geo_db_zipcode" VALUES(42133,97839,-8,'Lexington, Oregon 97839',29571,36919);
INSERT INTO "django_geo_db_zipcode" VALUES(42134,97840,-8,'Oxbow, Oregon 97840',29572,36920);
INSERT INTO "django_geo_db_zipcode" VALUES(42135,97841,-8,'Imbler, Oregon 97841',29573,36921);
INSERT INTO "django_geo_db_zipcode" VALUES(42136,97842,-8,'Imnaha, Oregon 97842',29574,36922);
INSERT INTO "django_geo_db_zipcode" VALUES(42137,97843,-8,'Ione, Oregon 97843',29575,36923);
INSERT INTO "django_geo_db_zipcode" VALUES(42138,97844,-8,'Irrigon, Oregon 97844',29576,36924);
INSERT INTO "django_geo_db_zipcode" VALUES(42139,97845,-8,'John Day, Oregon 97845',29577,36925);
INSERT INTO "django_geo_db_zipcode" VALUES(42140,97846,-8,'Joseph, Oregon 97846',29578,36926);
INSERT INTO "django_geo_db_zipcode" VALUES(42141,97848,-8,'Kimberly, Oregon 97848',29579,36927);
INSERT INTO "django_geo_db_zipcode" VALUES(42142,97850,-8,'La Grande, Oregon 97850',29580,36928);
INSERT INTO "django_geo_db_zipcode" VALUES(42143,97856,-8,'Long Creek, Oregon 97856',29581,36929);
INSERT INTO "django_geo_db_zipcode" VALUES(42144,97857,-8,'Lostine, Oregon 97857',29496,36930);
INSERT INTO "django_geo_db_zipcode" VALUES(42145,97859,-8,'Meacham, Oregon 97859',29582,36931);
INSERT INTO "django_geo_db_zipcode" VALUES(42146,97861,-8,'Mikkalo, Oregon 97861',29583,36932);
INSERT INTO "django_geo_db_zipcode" VALUES(42147,97862,-8,'Milton Freewater, Oregon 97862',29584,36933);
INSERT INTO "django_geo_db_zipcode" VALUES(42148,97864,-8,'Monument, Oregon 97864',29585,36934);
INSERT INTO "django_geo_db_zipcode" VALUES(42149,97865,-8,'Mount Vernon, Oregon 97865',29586,36935);
INSERT INTO "django_geo_db_zipcode" VALUES(42150,97867,-8,'North Powder, Oregon 97867',29587,36936);
INSERT INTO "django_geo_db_zipcode" VALUES(42151,97868,-8,'Pilot Rock, Oregon 97868',29588,36937);
INSERT INTO "django_geo_db_zipcode" VALUES(42152,97869,-8,'Prairie City, Oregon 97869',29589,36938);
INSERT INTO "django_geo_db_zipcode" VALUES(42153,97870,-8,'Richland, Oregon 97870',29590,36939);
INSERT INTO "django_geo_db_zipcode" VALUES(42154,97872,-8,'Ritter, Oregon 97872',29591,36940);
INSERT INTO "django_geo_db_zipcode" VALUES(42155,97873,-8,'Seneca, Oregon 97873',29592,36941);
INSERT INTO "django_geo_db_zipcode" VALUES(42156,97874,-8,'Spray, Oregon 97874',29593,36942);
INSERT INTO "django_geo_db_zipcode" VALUES(42157,97875,-8,'Stanfield, Oregon 97875',29594,36943);
INSERT INTO "django_geo_db_zipcode" VALUES(42158,97876,-8,'Summerville, Oregon 97876',29595,36944);
INSERT INTO "django_geo_db_zipcode" VALUES(42159,97877,-8,'Sumpter, Oregon 97877',29596,36945);
INSERT INTO "django_geo_db_zipcode" VALUES(42160,97880,-8,'Ukiah, Oregon 97880',29597,36946);
INSERT INTO "django_geo_db_zipcode" VALUES(42161,97882,-8,'Umatilla, Oregon 97882',29598,36947);
INSERT INTO "django_geo_db_zipcode" VALUES(42162,97883,-8,'Union, Oregon 97883',29599,36948);
INSERT INTO "django_geo_db_zipcode" VALUES(42163,97884,-8,'Unity, Oregon 97884',29600,36949);
INSERT INTO "django_geo_db_zipcode" VALUES(42164,97885,-8,'Wallowa, Oregon 97885',29601,36950);
INSERT INTO "django_geo_db_zipcode" VALUES(42165,97886,-8,'Weston, Oregon 97886',29602,36951);
INSERT INTO "django_geo_db_zipcode" VALUES(42166,97901,-7,'Adrian, Oregon 97901',29603,36952);
INSERT INTO "django_geo_db_zipcode" VALUES(42167,97902,-7,'Arock, Oregon 97902',29604,36953);
INSERT INTO "django_geo_db_zipcode" VALUES(42168,97903,-7,'Brogan, Oregon 97903',29605,36954);
INSERT INTO "django_geo_db_zipcode" VALUES(42169,97904,-8,'Drewsey, Oregon 97904',29606,36955);
INSERT INTO "django_geo_db_zipcode" VALUES(42170,97905,-8,'Durkee, Oregon 97905',29607,36956);
INSERT INTO "django_geo_db_zipcode" VALUES(42171,97906,-7,'Harper, Oregon 97906',29608,36957);
INSERT INTO "django_geo_db_zipcode" VALUES(42172,97907,-8,'Huntington, Oregon 97907',29609,36958);
INSERT INTO "django_geo_db_zipcode" VALUES(42173,97908,-7,'Ironside, Oregon 97908',29610,36959);
INSERT INTO "django_geo_db_zipcode" VALUES(42174,97909,-7,'Jamieson, Oregon 97909',29611,36960);
INSERT INTO "django_geo_db_zipcode" VALUES(42175,97910,-7,'Jordan Valley, Idaho 97910',29612,36961);
INSERT INTO "django_geo_db_zipcode" VALUES(42176,97911,-7,'Juntura, Oregon 97911',29613,36962);
INSERT INTO "django_geo_db_zipcode" VALUES(42177,97913,-7,'Nyssa, Idaho 97913',29614,36963);
INSERT INTO "django_geo_db_zipcode" VALUES(42178,97914,-7,'Ontario, Oregon 97914',29615,36964);
INSERT INTO "django_geo_db_zipcode" VALUES(42179,97917,-7,'Riverside, Oregon 97917',29616,36965);
INSERT INTO "django_geo_db_zipcode" VALUES(42180,97918,-7,'Vale, Oregon 97918',29617,36966);
INSERT INTO "django_geo_db_zipcode" VALUES(42181,97920,-7,'Westfall, Oregon 97920',29618,36967);
INSERT INTO "django_geo_db_zipcode" VALUES(42182,98001,-8,'Auburn, Washington 98001',29619,36968);
INSERT INTO "django_geo_db_zipcode" VALUES(42183,98002,-8,'Auburn, Washington 98002',29619,36969);
INSERT INTO "django_geo_db_zipcode" VALUES(42184,98003,-8,'Federal Way, Washington 98003',29620,36970);
INSERT INTO "django_geo_db_zipcode" VALUES(42185,98004,-8,'Bellevue, Washington 98004',29621,36971);
INSERT INTO "django_geo_db_zipcode" VALUES(42186,98005,-8,'Bellevue, Washington 98005',29621,36972);
INSERT INTO "django_geo_db_zipcode" VALUES(42187,98006,-8,'Bellevue, Washington 98006',29621,36973);
INSERT INTO "django_geo_db_zipcode" VALUES(42188,98007,-8,'Bellevue, Washington 98007',29621,36974);
INSERT INTO "django_geo_db_zipcode" VALUES(42189,98008,-8,'Bellevue, Washington 98008',29621,36975);
INSERT INTO "django_geo_db_zipcode" VALUES(42190,98009,-8,'Bellevue, Washington 98009',29621,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42191,98010,-8,'Black Diamond, Washington 98010',29622,36977);
INSERT INTO "django_geo_db_zipcode" VALUES(42192,98011,-8,'Bothell, Washington 98011',29623,36978);
INSERT INTO "django_geo_db_zipcode" VALUES(42193,98012,-8,'Bothell, Washington 98012',29623,36979);
INSERT INTO "django_geo_db_zipcode" VALUES(42194,98013,-8,'Burton, Washington 98013',29624,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42195,98014,-8,'Carnation, Washington 98014',29625,36980);
INSERT INTO "django_geo_db_zipcode" VALUES(42196,98015,-8,'Bellevue, Washington 98015',29621,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42197,98019,-8,'Duvall, Washington 98019',29626,36981);
INSERT INTO "django_geo_db_zipcode" VALUES(42198,98020,-8,'Edmonds, Washington 98020',29627,36982);
INSERT INTO "django_geo_db_zipcode" VALUES(42199,98021,-8,'Bothell, Washington 98021',29623,36983);
INSERT INTO "django_geo_db_zipcode" VALUES(42200,98022,-8,'Enumclaw, Washington 98022',29628,36984);
INSERT INTO "django_geo_db_zipcode" VALUES(42201,98023,-8,'Federal Way, Washington 98023',29620,36985);
INSERT INTO "django_geo_db_zipcode" VALUES(42202,98024,-8,'Fall City, Washington 98024',29629,36986);
INSERT INTO "django_geo_db_zipcode" VALUES(42203,98025,-8,'Hobart, Washington 98025',29630,36987);
INSERT INTO "django_geo_db_zipcode" VALUES(42204,98026,-8,'Edmonds, Washington 98026',29627,36988);
INSERT INTO "django_geo_db_zipcode" VALUES(42205,98027,-8,'Issaquah, Washington 98027',29631,36989);
INSERT INTO "django_geo_db_zipcode" VALUES(42206,98028,-8,'Kenmore, Washington 98028',29632,36990);
INSERT INTO "django_geo_db_zipcode" VALUES(42207,98029,-8,'Issaquah, Washington 98029',29631,36991);
INSERT INTO "django_geo_db_zipcode" VALUES(42208,98030,-8,'Kent, Washington 98030',29633,36992);
INSERT INTO "django_geo_db_zipcode" VALUES(42209,98031,-8,'Kent, Washington 98031',29633,36993);
INSERT INTO "django_geo_db_zipcode" VALUES(42210,98032,-8,'Kent, Washington 98032',29633,36994);
INSERT INTO "django_geo_db_zipcode" VALUES(42211,98033,-8,'Kirkland, Washington 98033',29634,36995);
INSERT INTO "django_geo_db_zipcode" VALUES(42212,98034,-8,'Kirkland, Washington 98034',29634,36996);
INSERT INTO "django_geo_db_zipcode" VALUES(42213,98035,-8,'Kent, Washington 98035',29633,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42214,98036,-8,'Lynnwood, Washington 98036',29635,36997);
INSERT INTO "django_geo_db_zipcode" VALUES(42215,98037,-8,'Lynnwood, Washington 98037',29635,36998);
INSERT INTO "django_geo_db_zipcode" VALUES(42216,98038,-8,'Maple Valley, Washington 98038',29636,36999);
INSERT INTO "django_geo_db_zipcode" VALUES(42217,98039,-8,'Medina, Washington 98039',29637,37000);
INSERT INTO "django_geo_db_zipcode" VALUES(42218,98040,-8,'Mercer Island, Washington 98040',29638,37001);
INSERT INTO "django_geo_db_zipcode" VALUES(42219,98041,-8,'Bothell, Washington 98041',29623,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42220,98042,-8,'Kent, Washington 98042',29633,37002);
INSERT INTO "django_geo_db_zipcode" VALUES(42221,98043,-8,'Mountlake Terrace, Washington 98043',29639,37003);
INSERT INTO "django_geo_db_zipcode" VALUES(42222,98045,-8,'North Bend, Washington 98045',29640,37004);
INSERT INTO "django_geo_db_zipcode" VALUES(42223,98046,-8,'Lynnwood, Washington 98046',29635,37005);
INSERT INTO "django_geo_db_zipcode" VALUES(42224,98047,-8,'Pacific, Washington 98047',29641,37006);
INSERT INTO "django_geo_db_zipcode" VALUES(42225,98050,-8,'Preston, Washington 98050',29642,37007);
INSERT INTO "django_geo_db_zipcode" VALUES(42226,98051,-8,'Ravensdale, Washington 98051',29643,37008);
INSERT INTO "django_geo_db_zipcode" VALUES(42227,98052,-8,'Redmond, Washington 98052',29644,37009);
INSERT INTO "django_geo_db_zipcode" VALUES(42228,98053,-8,'Redmond, Washington 98053',29644,37010);
INSERT INTO "django_geo_db_zipcode" VALUES(42229,98054,-8,'Redondo, Washington 98054',29645,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42230,98055,-8,'Renton, Washington 98055',29646,37011);
INSERT INTO "django_geo_db_zipcode" VALUES(42231,98056,-8,'Renton, Washington 98056',29646,37012);
INSERT INTO "django_geo_db_zipcode" VALUES(42232,98057,-8,'Renton, Washington 98057',29646,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42233,98058,-8,'Renton, Washington 98058',29646,37013);
INSERT INTO "django_geo_db_zipcode" VALUES(42234,98059,-8,'Renton, Washington 98059',29646,37014);
INSERT INTO "django_geo_db_zipcode" VALUES(42235,98060,-8,'Seattle, Washington 98060',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42236,98061,-8,'Rollingbay, Washington 98061',29648,37015);
INSERT INTO "django_geo_db_zipcode" VALUES(42237,98062,-8,'Seahurst, Washington 98062',29649,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42238,98063,-8,'Federal Way, Washington 98063',29620,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42239,98064,-8,'Kent, Washington 98064',29633,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42240,98065,-8,'Snoqualmie, Washington 98065',29650,37016);
INSERT INTO "django_geo_db_zipcode" VALUES(42241,98067,-8,'Bellevue, Washington 98067',29621,37017);
INSERT INTO "django_geo_db_zipcode" VALUES(42242,98068,-8,'Snoqualmie Pass, Washington 98068',29651,37018);
INSERT INTO "django_geo_db_zipcode" VALUES(42243,98070,-8,'Vashon, Washington 98070',29652,37019);
INSERT INTO "django_geo_db_zipcode" VALUES(42244,98071,-8,'Auburn, Washington 98071',29619,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42245,98072,-8,'Woodinville, Washington 98072',29653,37020);
INSERT INTO "django_geo_db_zipcode" VALUES(42246,98073,-8,'Redmond, Washington 98073',29644,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42247,98074,-8,'Sammamish, Washington 98074',29654,37021);
INSERT INTO "django_geo_db_zipcode" VALUES(42248,98075,-8,'Sammamish, Washington 98075',29654,37022);
INSERT INTO "django_geo_db_zipcode" VALUES(42249,98082,-8,'Bothell, Washington 98082',29623,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42250,98083,-8,'Kirkland, Washington 98083',29634,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42251,98092,-8,'Auburn, Washington 98092',29619,37023);
INSERT INTO "django_geo_db_zipcode" VALUES(42252,98093,-8,'Federal Way, Washington 98093',29620,37024);
INSERT INTO "django_geo_db_zipcode" VALUES(42253,98101,-8,'Seattle, Washington 98101',29647,37025);
INSERT INTO "django_geo_db_zipcode" VALUES(42254,98102,-8,'Seattle, Washington 98102',29647,37026);
INSERT INTO "django_geo_db_zipcode" VALUES(42255,98103,-8,'Seattle, Washington 98103',29647,37027);
INSERT INTO "django_geo_db_zipcode" VALUES(42256,98104,-8,'Seattle, Washington 98104',29647,37028);
INSERT INTO "django_geo_db_zipcode" VALUES(42257,98105,-8,'Seattle, Washington 98105',29647,37029);
INSERT INTO "django_geo_db_zipcode" VALUES(42258,98106,-8,'Seattle, Washington 98106',29647,37030);
INSERT INTO "django_geo_db_zipcode" VALUES(42259,98107,-8,'Seattle, Washington 98107',29647,37031);
INSERT INTO "django_geo_db_zipcode" VALUES(42260,98108,-8,'Seattle, Washington 98108',29647,37032);
INSERT INTO "django_geo_db_zipcode" VALUES(42261,98109,-8,'Seattle, Washington 98109',29647,37033);
INSERT INTO "django_geo_db_zipcode" VALUES(42262,98110,-8,'Bainbridge Island, Washington 98110',29655,37034);
INSERT INTO "django_geo_db_zipcode" VALUES(42263,98111,-8,'Seattle, Washington 98111',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42264,98112,-8,'Seattle, Washington 98112',29647,37035);
INSERT INTO "django_geo_db_zipcode" VALUES(42265,98113,-8,'Shoreline, Washington 98113',29656,37036);
INSERT INTO "django_geo_db_zipcode" VALUES(42266,98114,-8,'Seattle, Washington 98114',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42267,98115,-8,'Seattle, Washington 98115',29647,37037);
INSERT INTO "django_geo_db_zipcode" VALUES(42268,98116,-8,'Seattle, Washington 98116',29647,37038);
INSERT INTO "django_geo_db_zipcode" VALUES(42269,98117,-8,'Seattle, Washington 98117',29647,37039);
INSERT INTO "django_geo_db_zipcode" VALUES(42270,98118,-8,'Seattle, Washington 98118',29647,37040);
INSERT INTO "django_geo_db_zipcode" VALUES(42271,98119,-8,'Seattle, Washington 98119',29647,37041);
INSERT INTO "django_geo_db_zipcode" VALUES(42272,98121,-8,'Seattle, Washington 98121',29647,37042);
INSERT INTO "django_geo_db_zipcode" VALUES(42273,98122,-8,'Seattle, Washington 98122',29647,37043);
INSERT INTO "django_geo_db_zipcode" VALUES(42274,98124,-8,'Seattle, Washington 98124',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42275,98125,-8,'Seattle, Washington 98125',29647,37044);
INSERT INTO "django_geo_db_zipcode" VALUES(42276,98126,-8,'Seattle, Washington 98126',29647,37045);
INSERT INTO "django_geo_db_zipcode" VALUES(42277,98129,-8,'Seattle, Washington 98129',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42278,98130,-8,'Seattle, Washington 98130',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42279,98131,-8,'Seattle, Washington 98131',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42280,98132,-8,'Seattle, Washington 98132',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42281,98133,-8,'Seattle, Washington 98133',29647,37046);
INSERT INTO "django_geo_db_zipcode" VALUES(42282,98134,-8,'Seattle, Washington 98134',29647,37047);
INSERT INTO "django_geo_db_zipcode" VALUES(42283,98136,-8,'Seattle, Washington 98136',29647,37048);
INSERT INTO "django_geo_db_zipcode" VALUES(42284,98138,-8,'Seattle, Washington 98138',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42285,98140,-8,'Seattle, Washington 98140',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42286,98144,-8,'Seattle, Washington 98144',29647,37049);
INSERT INTO "django_geo_db_zipcode" VALUES(42287,98145,-8,'Seattle, Washington 98145',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42288,98146,-8,'Seattle, Washington 98146',29647,37050);
INSERT INTO "django_geo_db_zipcode" VALUES(42289,98148,-8,'Seattle, Washington 98148',29647,37051);
INSERT INTO "django_geo_db_zipcode" VALUES(42290,98150,-8,'Seattle, Washington 98150',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42291,98151,-8,'Seattle, Washington 98151',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42292,98154,-8,'Seattle, Washington 98154',29647,37052);
INSERT INTO "django_geo_db_zipcode" VALUES(42293,98155,-8,'Seattle, Washington 98155',29647,37053);
INSERT INTO "django_geo_db_zipcode" VALUES(42294,98158,-8,'Seattle, Washington 98158',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42295,98160,-8,'Seattle, Washington 98160',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42296,98161,-8,'Seattle, Washington 98161',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42297,98164,-8,'Seattle, Washington 98164',29647,37054);
INSERT INTO "django_geo_db_zipcode" VALUES(42298,98166,-8,'Seattle, Washington 98166',29647,37055);
INSERT INTO "django_geo_db_zipcode" VALUES(42299,98168,-8,'Seattle, Washington 98168',29647,37056);
INSERT INTO "django_geo_db_zipcode" VALUES(42300,98171,-8,'Seattle, Washington 98171',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42301,98174,-8,'Seattle, Washington 98174',29647,37057);
INSERT INTO "django_geo_db_zipcode" VALUES(42302,98177,-8,'Seattle, Washington 98177',29647,37058);
INSERT INTO "django_geo_db_zipcode" VALUES(42303,98178,-8,'Seattle, Washington 98178',29647,37059);
INSERT INTO "django_geo_db_zipcode" VALUES(42304,98181,-8,'Seattle, Washington 98181',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42305,98184,-8,'Seattle, Washington 98184',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42306,98185,-8,'Seattle, Washington 98185',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42307,98188,-8,'Seattle, Washington 98188',29647,37060);
INSERT INTO "django_geo_db_zipcode" VALUES(42308,98190,-8,'Seattle, Washington 98190',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42309,98191,-8,'Seattle, Washington 98191',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42310,98195,-8,'Seattle, Washington 98195',29647,36976);
INSERT INTO "django_geo_db_zipcode" VALUES(42311,98198,-8,'Seattle, Washington 98198',29647,37061);
INSERT INTO "django_geo_db_zipcode" VALUES(42312,98199,-8,'Seattle, Washington 98199',29647,37062);
INSERT INTO "django_geo_db_zipcode" VALUES(42313,98201,-8,'Everett, Washington 98201',29657,37063);
INSERT INTO "django_geo_db_zipcode" VALUES(42314,98203,-8,'Everett, Washington 98203',29657,37064);
INSERT INTO "django_geo_db_zipcode" VALUES(42315,98204,-8,'Everett, Washington 98204',29657,37065);
INSERT INTO "django_geo_db_zipcode" VALUES(42316,98205,-8,'Everett, Washington 98205',29657,37066);
INSERT INTO "django_geo_db_zipcode" VALUES(42317,98206,-8,'Everett, Washington 98206',29657,37067);
INSERT INTO "django_geo_db_zipcode" VALUES(42318,98207,-8,'Everett, Washington 98207',29657,37005);
INSERT INTO "django_geo_db_zipcode" VALUES(42319,98208,-8,'Everett, Washington 98208',29657,37068);
INSERT INTO "django_geo_db_zipcode" VALUES(42320,98220,-8,'Acme, Washington 98220',29658,37069);
INSERT INTO "django_geo_db_zipcode" VALUES(42321,98221,-8,'Anacortes, Washington 98221',29659,37070);
INSERT INTO "django_geo_db_zipcode" VALUES(42322,98222,-8,'Blakely Island, Washington 98222',29660,37071);
INSERT INTO "django_geo_db_zipcode" VALUES(42323,98223,-8,'Arlington, Washington 98223',29661,37072);
INSERT INTO "django_geo_db_zipcode" VALUES(42324,98224,-8,'Baring, Washington 98224',29662,37073);
INSERT INTO "django_geo_db_zipcode" VALUES(42325,98225,-8,'Bellingham, Washington 98225',29663,37074);
INSERT INTO "django_geo_db_zipcode" VALUES(42326,98226,-8,'Bellingham, Washington 98226',29663,37075);
INSERT INTO "django_geo_db_zipcode" VALUES(42327,98227,-8,'Bellingham, Washington 98227',29663,37076);
INSERT INTO "django_geo_db_zipcode" VALUES(42328,98228,-8,'Bellingham, Washington 98228',29663,37076);
INSERT INTO "django_geo_db_zipcode" VALUES(42329,98229,-8,'Bellingham, Washington 98229',29663,37077);
INSERT INTO "django_geo_db_zipcode" VALUES(42330,98230,-8,'Blaine, Washington 98230',29664,37078);
INSERT INTO "django_geo_db_zipcode" VALUES(42331,98231,-8,'Blaine, Washington 98231',29664,37076);
INSERT INTO "django_geo_db_zipcode" VALUES(42332,98232,-8,'Bow, Washington 98232',29665,37079);
INSERT INTO "django_geo_db_zipcode" VALUES(42333,98233,-8,'Burlington, Washington 98233',29666,37080);
INSERT INTO "django_geo_db_zipcode" VALUES(42334,98235,-8,'Clearlake, Washington 98235',29667,37081);
INSERT INTO "django_geo_db_zipcode" VALUES(42335,98236,-8,'Clinton, Washington 98236',29668,37082);
INSERT INTO "django_geo_db_zipcode" VALUES(42336,98237,-8,'Concrete, Washington 98237',29669,37083);
INSERT INTO "django_geo_db_zipcode" VALUES(42337,98238,-8,'Conway, Washington 98238',29670,37084);
INSERT INTO "django_geo_db_zipcode" VALUES(42338,98239,-8,'Coupeville, Washington 98239',29671,37085);
INSERT INTO "django_geo_db_zipcode" VALUES(42339,98240,-8,'Custer, Washington 98240',29672,37086);
INSERT INTO "django_geo_db_zipcode" VALUES(42340,98241,-8,'Darrington, Washington 98241',29673,37087);
INSERT INTO "django_geo_db_zipcode" VALUES(42341,98243,-8,'Deer Harbor, Washington 98243',29674,37088);
INSERT INTO "django_geo_db_zipcode" VALUES(42342,98244,-8,'Deming, Washington 98244',29675,37089);
INSERT INTO "django_geo_db_zipcode" VALUES(42343,98245,-8,'Eastsound, Washington 98245',29676,37090);
INSERT INTO "django_geo_db_zipcode" VALUES(42344,98246,-8,'Bow, Washington 98246',29665,37091);
INSERT INTO "django_geo_db_zipcode" VALUES(42345,98247,-8,'Everson, Washington 98247',29677,37092);
INSERT INTO "django_geo_db_zipcode" VALUES(42346,98248,-8,'Ferndale, Washington 98248',29678,37093);
INSERT INTO "django_geo_db_zipcode" VALUES(42347,98249,-8,'Freeland, Washington 98249',29679,37094);
INSERT INTO "django_geo_db_zipcode" VALUES(42348,98250,-8,'Friday Harbor, Washington 98250',29680,37095);
INSERT INTO "django_geo_db_zipcode" VALUES(42349,98251,-8,'Gold Bar, Washington 98251',29681,37096);
INSERT INTO "django_geo_db_zipcode" VALUES(42350,98252,-8,'Granite Falls, Washington 98252',29682,37097);
INSERT INTO "django_geo_db_zipcode" VALUES(42351,98253,-8,'Greenbank, Washington 98253',29683,37098);
INSERT INTO "django_geo_db_zipcode" VALUES(42352,98255,-8,'Hamilton, Washington 98255',29684,37099);
INSERT INTO "django_geo_db_zipcode" VALUES(42353,98256,-8,'Index, Washington 98256',29685,37100);
INSERT INTO "django_geo_db_zipcode" VALUES(42354,98257,-8,'La Conner, Washington 98257',29686,37101);
INSERT INTO "django_geo_db_zipcode" VALUES(42355,98258,-8,'Lake Stevens, Washington 98258',29687,37102);
INSERT INTO "django_geo_db_zipcode" VALUES(42356,98259,-8,'North Lakewood, Washington 98259',29688,37005);
INSERT INTO "django_geo_db_zipcode" VALUES(42357,98260,-8,'Langley, Washington 98260',29689,37103);
INSERT INTO "django_geo_db_zipcode" VALUES(42358,98261,-8,'Lopez Island, Washington 98261',29690,37104);
INSERT INTO "django_geo_db_zipcode" VALUES(42359,98262,-8,'Lummi Island, Washington 98262',29691,37105);
INSERT INTO "django_geo_db_zipcode" VALUES(42360,98263,-8,'Lyman, Washington 98263',29692,37106);
INSERT INTO "django_geo_db_zipcode" VALUES(42361,98264,-8,'Lynden, Washington 98264',29693,37107);
INSERT INTO "django_geo_db_zipcode" VALUES(42362,98266,-8,'Maple Falls, Washington 98266',29694,37108);
INSERT INTO "django_geo_db_zipcode" VALUES(42363,98267,-8,'Marblemount, Washington 98267',29695,37109);
INSERT INTO "django_geo_db_zipcode" VALUES(42364,98270,-8,'Marysville, Washington 98270',29696,37110);
INSERT INTO "django_geo_db_zipcode" VALUES(42365,98271,-8,'Marysville, Washington 98271',29696,37111);
INSERT INTO "django_geo_db_zipcode" VALUES(42366,98272,-8,'Monroe, Washington 98272',29697,37112);
INSERT INTO "django_geo_db_zipcode" VALUES(42367,98273,-8,'Mount Vernon, Washington 98273',29698,37113);
INSERT INTO "django_geo_db_zipcode" VALUES(42368,98274,-8,'Mount Vernon, Washington 98274',29698,37114);
INSERT INTO "django_geo_db_zipcode" VALUES(42369,98275,-8,'Mukilteo, Washington 98275',29699,37115);
INSERT INTO "django_geo_db_zipcode" VALUES(42370,98276,-8,'Nooksack, Washington 98276',29700,37116);
INSERT INTO "django_geo_db_zipcode" VALUES(42371,98277,-8,'Oak Harbor, Washington 98277',29701,37117);
INSERT INTO "django_geo_db_zipcode" VALUES(42372,98278,-8,'Oak Harbor, Washington 98278',29701,37118);
INSERT INTO "django_geo_db_zipcode" VALUES(42373,98279,-8,'Olga, Washington 98279',29702,37119);
INSERT INTO "django_geo_db_zipcode" VALUES(42374,98280,-8,'Orcas, Washington 98280',29703,37120);
INSERT INTO "django_geo_db_zipcode" VALUES(42375,98281,-8,'Point Roberts, Washington 98281',29704,37121);
INSERT INTO "django_geo_db_zipcode" VALUES(42376,98282,-8,'Camano, Washington 98282',29705,37122);
INSERT INTO "django_geo_db_zipcode" VALUES(42377,98283,-8,'Rockport, Washington 98283',29706,37123);
INSERT INTO "django_geo_db_zipcode" VALUES(42378,98284,-8,'Sedro Woolley, Washington 98284',29707,37124);
INSERT INTO "django_geo_db_zipcode" VALUES(42379,98286,-8,'Shaw Island, Washington 98286',29708,37125);
INSERT INTO "django_geo_db_zipcode" VALUES(42380,98287,-8,'Silvana, Washington 98287',29709,37005);
INSERT INTO "django_geo_db_zipcode" VALUES(42381,98288,-8,'Skykomish, Washington 98288',29710,37126);
INSERT INTO "django_geo_db_zipcode" VALUES(42382,98290,-8,'Snohomish, Washington 98290',29711,37127);
INSERT INTO "django_geo_db_zipcode" VALUES(42383,98291,-8,'Snohomish, Washington 98291',29711,37128);
INSERT INTO "django_geo_db_zipcode" VALUES(42384,98292,-8,'Stanwood, Washington 98292',29712,37129);
INSERT INTO "django_geo_db_zipcode" VALUES(42385,98293,-8,'Startup, Washington 98293',29713,37130);
INSERT INTO "django_geo_db_zipcode" VALUES(42386,98294,-8,'Sultan, Washington 98294',29714,37131);
INSERT INTO "django_geo_db_zipcode" VALUES(42387,98295,-8,'Sumas, Washington 98295',29715,37132);
INSERT INTO "django_geo_db_zipcode" VALUES(42388,98296,-8,'Snohomish, Washington 98296',29711,37133);
INSERT INTO "django_geo_db_zipcode" VALUES(42389,98297,-8,'Waldron, Washington 98297',29716,37134);
INSERT INTO "django_geo_db_zipcode" VALUES(42390,98303,-8,'Anderson Island, Washington 98303',29717,37135);
INSERT INTO "django_geo_db_zipcode" VALUES(42391,98304,-8,'Ashford, Washington 98304',29718,37136);
INSERT INTO "django_geo_db_zipcode" VALUES(42392,98305,-8,'Beaver, Washington 98305',29719,37137);
INSERT INTO "django_geo_db_zipcode" VALUES(42393,98310,-8,'Bremerton, Washington 98310',29720,37138);
INSERT INTO "django_geo_db_zipcode" VALUES(42394,98311,-8,'Bremerton, Washington 98311',29720,37139);
INSERT INTO "django_geo_db_zipcode" VALUES(42395,98312,-8,'Bremerton, Washington 98312',29720,37140);
INSERT INTO "django_geo_db_zipcode" VALUES(42396,98314,-8,'Bremerton, Washington 98314',29720,37141);
INSERT INTO "django_geo_db_zipcode" VALUES(42397,98315,-8,'Silverdale, Washington 98315',29721,37142);
INSERT INTO "django_geo_db_zipcode" VALUES(42398,98319,-8,'Duvall, Washington 98319',29626,37143);
INSERT INTO "django_geo_db_zipcode" VALUES(42399,98320,-8,'Brinnon, Washington 98320',29722,37144);
INSERT INTO "django_geo_db_zipcode" VALUES(42400,98321,-8,'Buckley, Washington 98321',29723,37145);
INSERT INTO "django_geo_db_zipcode" VALUES(42401,98322,-8,'Burley, Washington 98322',29724,37146);
INSERT INTO "django_geo_db_zipcode" VALUES(42402,98323,-8,'Carbonado, Washington 98323',29725,37147);
INSERT INTO "django_geo_db_zipcode" VALUES(42403,98324,-8,'Carlsborg, Washington 98324',29726,37148);
INSERT INTO "django_geo_db_zipcode" VALUES(42404,98325,-8,'Chimacum, Washington 98325',29727,37149);
INSERT INTO "django_geo_db_zipcode" VALUES(42405,98326,-8,'Clallam Bay, Washington 98326',29728,37150);
INSERT INTO "django_geo_db_zipcode" VALUES(42406,98327,-8,'Dupont, Washington 98327',29729,37151);
INSERT INTO "django_geo_db_zipcode" VALUES(42407,98328,-8,'Eatonville, Washington 98328',29730,37152);
INSERT INTO "django_geo_db_zipcode" VALUES(42408,98329,-8,'Gig Harbor, Washington 98329',29731,37153);
INSERT INTO "django_geo_db_zipcode" VALUES(42409,98330,-8,'Elbe, Washington 98330',29732,37154);
INSERT INTO "django_geo_db_zipcode" VALUES(42410,98331,-8,'Forks, Washington 98331',29733,37155);
INSERT INTO "django_geo_db_zipcode" VALUES(42411,98332,-8,'Gig Harbor, Washington 98332',29731,37156);
INSERT INTO "django_geo_db_zipcode" VALUES(42412,98333,-8,'Fox Island, Washington 98333',29734,37157);
INSERT INTO "django_geo_db_zipcode" VALUES(42413,98335,-8,'Gig Harbor, Washington 98335',29731,37158);
INSERT INTO "django_geo_db_zipcode" VALUES(42414,98336,-8,'Glenoma, Washington 98336',29735,37159);
INSERT INTO "django_geo_db_zipcode" VALUES(42415,98337,-8,'Bremerton, Washington 98337',29720,37160);
INSERT INTO "django_geo_db_zipcode" VALUES(42416,98338,-8,'Graham, Washington 98338',29736,37161);
INSERT INTO "django_geo_db_zipcode" VALUES(42417,98339,-8,'Port Hadlock, Washington 98339',29737,37162);
INSERT INTO "django_geo_db_zipcode" VALUES(42418,98340,-8,'Hansville, Washington 98340',29738,37163);
INSERT INTO "django_geo_db_zipcode" VALUES(42419,98342,-8,'Indianola, Washington 98342',29739,37164);
INSERT INTO "django_geo_db_zipcode" VALUES(42420,98343,-8,'Joyce, Washington 98343',29740,37148);
INSERT INTO "django_geo_db_zipcode" VALUES(42421,98344,-8,'Kapowsin, Washington 98344',29741,37165);
INSERT INTO "django_geo_db_zipcode" VALUES(42422,98345,-8,'Keyport, Washington 98345',29742,37166);
INSERT INTO "django_geo_db_zipcode" VALUES(42423,98346,-8,'Kingston, Washington 98346',29743,37167);
INSERT INTO "django_geo_db_zipcode" VALUES(42424,98348,-8,'La Grande, Washington 98348',29744,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42425,98349,-8,'Lakebay, Washington 98349',29745,37169);
INSERT INTO "django_geo_db_zipcode" VALUES(42426,98350,-8,'La Push, Washington 98350',29746,37170);
INSERT INTO "django_geo_db_zipcode" VALUES(42427,98351,-8,'Longbranch, Washington 98351',29747,37171);
INSERT INTO "django_geo_db_zipcode" VALUES(42428,98352,-8,'Sumner, Washington 98352',29748,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42429,98353,-8,'Manchester, Washington 98353',29749,37172);
INSERT INTO "django_geo_db_zipcode" VALUES(42430,98354,-8,'Milton, Washington 98354',29750,37173);
INSERT INTO "django_geo_db_zipcode" VALUES(42431,98355,-8,'Mineral, Washington 98355',29751,37174);
INSERT INTO "django_geo_db_zipcode" VALUES(42432,98356,-8,'Morton, Washington 98356',29752,37175);
INSERT INTO "django_geo_db_zipcode" VALUES(42433,98357,-8,'Neah Bay, Washington 98357',29753,37176);
INSERT INTO "django_geo_db_zipcode" VALUES(42434,98358,-8,'Nordland, Washington 98358',29754,37177);
INSERT INTO "django_geo_db_zipcode" VALUES(42435,98359,-8,'Olalla, Washington 98359',29755,37178);
INSERT INTO "django_geo_db_zipcode" VALUES(42436,98360,-8,'Orting, Washington 98360',29756,37179);
INSERT INTO "django_geo_db_zipcode" VALUES(42437,98361,-8,'Packwood, Washington 98361',29757,37180);
INSERT INTO "django_geo_db_zipcode" VALUES(42438,98362,-8,'Port Angeles, Washington 98362',29758,37181);
INSERT INTO "django_geo_db_zipcode" VALUES(42439,98363,-8,'Port Angeles, Washington 98363',29758,37182);
INSERT INTO "django_geo_db_zipcode" VALUES(42440,98364,-8,'Port Gamble, Washington 98364',29759,37183);
INSERT INTO "django_geo_db_zipcode" VALUES(42441,98365,-8,'Port Ludlow, Washington 98365',29760,37184);
INSERT INTO "django_geo_db_zipcode" VALUES(42442,98366,-8,'Port Orchard, Washington 98366',29761,37185);
INSERT INTO "django_geo_db_zipcode" VALUES(42443,98367,-8,'Port Orchard, Washington 98367',29761,37186);
INSERT INTO "django_geo_db_zipcode" VALUES(42444,98368,-8,'Port Townsend, Washington 98368',29762,37187);
INSERT INTO "django_geo_db_zipcode" VALUES(42445,98370,-8,'Poulsbo, Washington 98370',29763,37188);
INSERT INTO "django_geo_db_zipcode" VALUES(42446,98371,-8,'Puyallup, Washington 98371',29764,37189);
INSERT INTO "django_geo_db_zipcode" VALUES(42447,98372,-8,'Puyallup, Washington 98372',29764,37190);
INSERT INTO "django_geo_db_zipcode" VALUES(42448,98373,-8,'Puyallup, Washington 98373',29764,37191);
INSERT INTO "django_geo_db_zipcode" VALUES(42449,98374,-8,'Puyallup, Washington 98374',29764,37192);
INSERT INTO "django_geo_db_zipcode" VALUES(42450,98375,-8,'Puyallup, Washington 98375',29764,37193);
INSERT INTO "django_geo_db_zipcode" VALUES(42451,98376,-8,'Quilcene, Washington 98376',29765,37194);
INSERT INTO "django_geo_db_zipcode" VALUES(42452,98377,-8,'Randle, Washington 98377',29766,37195);
INSERT INTO "django_geo_db_zipcode" VALUES(42453,98378,-8,'Retsil, Washington 98378',29767,37146);
INSERT INTO "django_geo_db_zipcode" VALUES(42454,98380,-8,'Seabeck, Washington 98380',29768,37196);
INSERT INTO "django_geo_db_zipcode" VALUES(42455,98381,-8,'Sekiu, Washington 98381',29769,37197);
INSERT INTO "django_geo_db_zipcode" VALUES(42456,98382,-8,'Sequim, Washington 98382',29770,37198);
INSERT INTO "django_geo_db_zipcode" VALUES(42457,98383,-8,'Silverdale, Washington 98383',29721,37199);
INSERT INTO "django_geo_db_zipcode" VALUES(42458,98384,-8,'South Colby, Washington 98384',29771,37200);
INSERT INTO "django_geo_db_zipcode" VALUES(42459,98385,-8,'South Prairie, Washington 98385',29772,37201);
INSERT INTO "django_geo_db_zipcode" VALUES(42460,98386,-8,'Southworth, Washington 98386',29773,37202);
INSERT INTO "django_geo_db_zipcode" VALUES(42461,98387,-8,'Spanaway, Washington 98387',29774,37203);
INSERT INTO "django_geo_db_zipcode" VALUES(42462,98388,-8,'Steilacoom, Washington 98388',29775,37204);
INSERT INTO "django_geo_db_zipcode" VALUES(42463,98389,-8,'South Prairie, Washington 98389',29772,37205);
INSERT INTO "django_geo_db_zipcode" VALUES(42464,98390,-8,'Sumner, Washington 98390',29748,37206);
INSERT INTO "django_geo_db_zipcode" VALUES(42465,98392,-8,'Suquamish, Washington 98392',29776,37207);
INSERT INTO "django_geo_db_zipcode" VALUES(42466,98393,-8,'Tracyton, Washington 98393',29777,37208);
INSERT INTO "django_geo_db_zipcode" VALUES(42467,98394,-8,'Vaughn, Washington 98394',29778,37209);
INSERT INTO "django_geo_db_zipcode" VALUES(42468,98395,-8,'Wauna, Washington 98395',29779,37210);
INSERT INTO "django_geo_db_zipcode" VALUES(42469,98396,-8,'Wilkeson, Washington 98396',29780,37211);
INSERT INTO "django_geo_db_zipcode" VALUES(42470,98397,-8,'Longmire, Washington 98397',29781,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42471,98398,-8,'Paradise Inn, Washington 98398',29782,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42472,98401,-8,'Tacoma, Washington 98401',29783,37212);
INSERT INTO "django_geo_db_zipcode" VALUES(42473,98402,-8,'Tacoma, Washington 98402',29783,37213);
INSERT INTO "django_geo_db_zipcode" VALUES(42474,98403,-8,'Tacoma, Washington 98403',29783,37214);
INSERT INTO "django_geo_db_zipcode" VALUES(42475,98404,-8,'Tacoma, Washington 98404',29783,37215);
INSERT INTO "django_geo_db_zipcode" VALUES(42476,98405,-8,'Tacoma, Washington 98405',29783,37216);
INSERT INTO "django_geo_db_zipcode" VALUES(42477,98406,-8,'Tacoma, Washington 98406',29783,37217);
INSERT INTO "django_geo_db_zipcode" VALUES(42478,98407,-8,'Tacoma, Washington 98407',29783,37218);
INSERT INTO "django_geo_db_zipcode" VALUES(42479,98408,-8,'Tacoma, Washington 98408',29783,37219);
INSERT INTO "django_geo_db_zipcode" VALUES(42480,98409,-8,'Tacoma, Washington 98409',29783,37220);
INSERT INTO "django_geo_db_zipcode" VALUES(42481,98411,-8,'Tacoma, Washington 98411',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42482,98412,-8,'Tacoma, Washington 98412',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42483,98413,-8,'Tacoma, Washington 98413',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42484,98415,-8,'Tacoma, Washington 98415',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42485,98416,-8,'Tacoma, Washington 98416',29783,37221);
INSERT INTO "django_geo_db_zipcode" VALUES(42486,98418,-8,'Tacoma, Washington 98418',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42487,98421,-8,'Tacoma, Washington 98421',29783,37222);
INSERT INTO "django_geo_db_zipcode" VALUES(42488,98422,-8,'Tacoma, Washington 98422',29783,37223);
INSERT INTO "django_geo_db_zipcode" VALUES(42489,98424,-8,'Tacoma, Washington 98424',29783,37224);
INSERT INTO "django_geo_db_zipcode" VALUES(42490,98430,-8,'Camp Murray, Washington 98430',29784,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42491,98431,-8,'Tacoma, Washington 98431',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42492,98433,-8,'Tacoma, Washington 98433',29783,37225);
INSERT INTO "django_geo_db_zipcode" VALUES(42493,98434,-8,'Tacoma, Washington 98434',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42494,98438,-8,'Tacoma, Washington 98438',29783,37226);
INSERT INTO "django_geo_db_zipcode" VALUES(42495,98439,-8,'Lakewood, Washington 98439',29785,37227);
INSERT INTO "django_geo_db_zipcode" VALUES(42496,98442,-8,'Tacoma, Washington 98442',29783,37228);
INSERT INTO "django_geo_db_zipcode" VALUES(42497,98443,-8,'Tacoma, Washington 98443',29783,37229);
INSERT INTO "django_geo_db_zipcode" VALUES(42498,98444,-8,'Tacoma, Washington 98444',29783,37230);
INSERT INTO "django_geo_db_zipcode" VALUES(42499,98445,-8,'Tacoma, Washington 98445',29783,37231);
INSERT INTO "django_geo_db_zipcode" VALUES(42500,98446,-8,'Tacoma, Washington 98446',29783,37232);
INSERT INTO "django_geo_db_zipcode" VALUES(42501,98447,-8,'Tacoma, Washington 98447',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42502,98448,-8,'Parkland, Washington 98448',29786,37233);
INSERT INTO "django_geo_db_zipcode" VALUES(42503,98450,-8,'Tacoma, Washington 98450',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42504,98455,-8,'Tacoma, Washington 98455',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42505,98460,-8,'Tacoma, Washington 98460',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42506,98464,-8,'Tacoma, Washington 98464',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42507,98465,-8,'Tacoma, Washington 98465',29783,37234);
INSERT INTO "django_geo_db_zipcode" VALUES(42508,98466,-8,'Tacoma, Washington 98466',29783,37235);
INSERT INTO "django_geo_db_zipcode" VALUES(42509,98467,-8,'University Place, Washington 98467',29787,37236);
INSERT INTO "django_geo_db_zipcode" VALUES(42510,98468,-8,'Oakville, Washington 98468',29788,37237);
INSERT INTO "django_geo_db_zipcode" VALUES(42511,98471,-8,'Tacoma, Washington 98471',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42512,98477,-8,'Tacoma, Washington 98477',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42513,98481,-8,'Tacoma, Washington 98481',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42514,98485,-8,'South Prairie, Washington 98485',29772,37238);
INSERT INTO "django_geo_db_zipcode" VALUES(42515,98492,-8,'Lakewood, Washington 98492',29785,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42516,98493,-8,'Tacoma, Washington 98493',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42517,98494,-8,'Tacoma, Washington 98494',29783,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42518,98497,-8,'Lakewood, Washington 98497',29785,37168);
INSERT INTO "django_geo_db_zipcode" VALUES(42519,98498,-8,'Lakewood, Washington 98498',29785,37239);
INSERT INTO "django_geo_db_zipcode" VALUES(42520,98499,-8,'Lakewood, Washington 98499',29785,37240);
INSERT INTO "django_geo_db_zipcode" VALUES(42521,98500,-8,'Tumwater, Washington 98500',29789,37241);
INSERT INTO "django_geo_db_zipcode" VALUES(42522,98501,-8,'Olympia, Washington 98501',29790,37242);
INSERT INTO "django_geo_db_zipcode" VALUES(42523,98502,-8,'Olympia, Washington 98502',29790,37243);
INSERT INTO "django_geo_db_zipcode" VALUES(42524,98503,-8,'Lacey, Washington 98503',29791,37244);
INSERT INTO "django_geo_db_zipcode" VALUES(42525,98504,-8,'Olympia, Washington 98504',29790,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42526,98505,-8,'Olympia, Washington 98505',29790,37246);
INSERT INTO "django_geo_db_zipcode" VALUES(42527,98506,-8,'Olympia, Washington 98506',29790,37247);
INSERT INTO "django_geo_db_zipcode" VALUES(42528,98507,-8,'Olympia, Washington 98507',29790,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42529,98508,-8,'Olympia, Washington 98508',29790,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42530,98509,-8,'Lacey, Washington 98509',29791,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42531,98512,-8,'Olympia, Washington 98512',29790,37248);
INSERT INTO "django_geo_db_zipcode" VALUES(42532,98513,-8,'Olympia, Washington 98513',29790,37249);
INSERT INTO "django_geo_db_zipcode" VALUES(42533,98516,-8,'Olympia, Washington 98516',29790,37250);
INSERT INTO "django_geo_db_zipcode" VALUES(42534,98520,-8,'Aberdeen, Washington 98520',29792,37251);
INSERT INTO "django_geo_db_zipcode" VALUES(42535,98522,-8,'Adna, Washington 98522',29793,37252);
INSERT INTO "django_geo_db_zipcode" VALUES(42536,98524,-8,'Allyn, Washington 98524',29794,37253);
INSERT INTO "django_geo_db_zipcode" VALUES(42537,98526,-8,'Amanda Park, Washington 98526',29795,37254);
INSERT INTO "django_geo_db_zipcode" VALUES(42538,98527,-8,'Bay Center, Washington 98527',29796,37255);
INSERT INTO "django_geo_db_zipcode" VALUES(42539,98528,-8,'Belfair, Washington 98528',29797,37256);
INSERT INTO "django_geo_db_zipcode" VALUES(42540,98530,-8,'Bucoda, Washington 98530',29798,37257);
INSERT INTO "django_geo_db_zipcode" VALUES(42541,98531,-8,'Centralia, Washington 98531',29799,37258);
INSERT INTO "django_geo_db_zipcode" VALUES(42542,98532,-8,'Chehalis, Washington 98532',29800,37259);
INSERT INTO "django_geo_db_zipcode" VALUES(42543,98533,-8,'Cinebar, Washington 98533',29801,37260);
INSERT INTO "django_geo_db_zipcode" VALUES(42544,98535,-8,'Copalis Beach, Washington 98535',29802,37261);
INSERT INTO "django_geo_db_zipcode" VALUES(42545,98536,-8,'Copalis Crossing, Washington 98536',29803,37262);
INSERT INTO "django_geo_db_zipcode" VALUES(42546,98537,-8,'Cosmopolis, Washington 98537',29804,37263);
INSERT INTO "django_geo_db_zipcode" VALUES(42547,98538,-8,'Curtis, Washington 98538',29805,37264);
INSERT INTO "django_geo_db_zipcode" VALUES(42548,98539,-8,'Doty, Washington 98539',29806,37265);
INSERT INTO "django_geo_db_zipcode" VALUES(42549,98540,-8,'East Olympia, Washington 98540',29807,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42550,98541,-8,'Elma, Washington 98541',29808,37266);
INSERT INTO "django_geo_db_zipcode" VALUES(42551,98542,-8,'Ethel, Washington 98542',29809,37267);
INSERT INTO "django_geo_db_zipcode" VALUES(42552,98544,-8,'Galvin, Washington 98544',29810,37268);
INSERT INTO "django_geo_db_zipcode" VALUES(42553,98546,-8,'Grapeview, Washington 98546',29811,37269);
INSERT INTO "django_geo_db_zipcode" VALUES(42554,98547,-8,'Grayland, Washington 98547',29812,37270);
INSERT INTO "django_geo_db_zipcode" VALUES(42555,98548,-8,'Hoodsport, Washington 98548',29813,37271);
INSERT INTO "django_geo_db_zipcode" VALUES(42556,98550,-8,'Hoquiam, Washington 98550',29814,37272);
INSERT INTO "django_geo_db_zipcode" VALUES(42557,98552,-8,'Humptulips, Washington 98552',29815,37273);
INSERT INTO "django_geo_db_zipcode" VALUES(42558,98554,-8,'Lebam, Washington 98554',29816,37274);
INSERT INTO "django_geo_db_zipcode" VALUES(42559,98555,-8,'Lilliwaup, Washington 98555',29817,37275);
INSERT INTO "django_geo_db_zipcode" VALUES(42560,98556,-8,'Littlerock, Washington 98556',29818,37276);
INSERT INTO "django_geo_db_zipcode" VALUES(42561,98557,-8,'Mccleary, Washington 98557',29819,37277);
INSERT INTO "django_geo_db_zipcode" VALUES(42562,98558,-8,'Mckenna, Washington 98558',29820,37278);
INSERT INTO "django_geo_db_zipcode" VALUES(42563,98559,-8,'Malone, Washington 98559',29821,37279);
INSERT INTO "django_geo_db_zipcode" VALUES(42564,98560,-8,'Matlock, Washington 98560',29822,37280);
INSERT INTO "django_geo_db_zipcode" VALUES(42565,98561,-8,'Menlo, Washington 98561',29823,37281);
INSERT INTO "django_geo_db_zipcode" VALUES(42566,98562,-8,'Moclips, Washington 98562',29824,37282);
INSERT INTO "django_geo_db_zipcode" VALUES(42567,98563,-8,'Montesano, Washington 98563',29825,37283);
INSERT INTO "django_geo_db_zipcode" VALUES(42568,98564,-8,'Mossyrock, Washington 98564',29826,37284);
INSERT INTO "django_geo_db_zipcode" VALUES(42569,98565,-8,'Napavine, Washington 98565',29827,37285);
INSERT INTO "django_geo_db_zipcode" VALUES(42570,98566,-8,'Neilton, Washington 98566',29828,37286);
INSERT INTO "django_geo_db_zipcode" VALUES(42571,98568,-8,'Oakville, Washington 98568',29788,37287);
INSERT INTO "django_geo_db_zipcode" VALUES(42572,98569,-8,'Ocean Shores, Washington 98569',29829,37288);
INSERT INTO "django_geo_db_zipcode" VALUES(42573,98570,-8,'Onalaska, Washington 98570',29830,37289);
INSERT INTO "django_geo_db_zipcode" VALUES(42574,98571,-8,'Pacific Beach, Washington 98571',29831,37290);
INSERT INTO "django_geo_db_zipcode" VALUES(42575,98572,-8,'Pe Ell, Washington 98572',29832,37291);
INSERT INTO "django_geo_db_zipcode" VALUES(42576,98575,-8,'Quinault, Washington 98575',29833,37292);
INSERT INTO "django_geo_db_zipcode" VALUES(42577,98576,-8,'Rainier, Washington 98576',29834,37293);
INSERT INTO "django_geo_db_zipcode" VALUES(42578,98577,-8,'Raymond, Washington 98577',29835,37294);
INSERT INTO "django_geo_db_zipcode" VALUES(42579,98579,-8,'Rochester, Washington 98579',29836,37295);
INSERT INTO "django_geo_db_zipcode" VALUES(42580,98580,-8,'Roy, Washington 98580',29837,37296);
INSERT INTO "django_geo_db_zipcode" VALUES(42581,98581,-8,'Ryderwood, Washington 98581',29838,37297);
INSERT INTO "django_geo_db_zipcode" VALUES(42582,98582,-8,'Salkum, Washington 98582',29839,37298);
INSERT INTO "django_geo_db_zipcode" VALUES(42583,98583,-8,'Satsop, Washington 98583',29840,37299);
INSERT INTO "django_geo_db_zipcode" VALUES(42584,98584,-8,'Shelton, Washington 98584',29841,37300);
INSERT INTO "django_geo_db_zipcode" VALUES(42585,98585,-8,'Silver Creek, Washington 98585',29842,37301);
INSERT INTO "django_geo_db_zipcode" VALUES(42586,98586,-8,'South Bend, Washington 98586',29843,37302);
INSERT INTO "django_geo_db_zipcode" VALUES(42587,98587,-8,'Taholah, Washington 98587',29844,37303);
INSERT INTO "django_geo_db_zipcode" VALUES(42588,98588,-8,'Tahuya, Washington 98588',29845,37304);
INSERT INTO "django_geo_db_zipcode" VALUES(42589,98589,-8,'Tenino, Washington 98589',29846,37305);
INSERT INTO "django_geo_db_zipcode" VALUES(42590,98590,-8,'Tokeland, Washington 98590',29847,37306);
INSERT INTO "django_geo_db_zipcode" VALUES(42591,98591,-8,'Toledo, Washington 98591',29848,37307);
INSERT INTO "django_geo_db_zipcode" VALUES(42592,98592,-8,'Union, Washington 98592',29849,37308);
INSERT INTO "django_geo_db_zipcode" VALUES(42593,98593,-8,'Vader, Washington 98593',29850,37309);
INSERT INTO "django_geo_db_zipcode" VALUES(42594,98595,-8,'Westport, Washington 98595',29851,37310);
INSERT INTO "django_geo_db_zipcode" VALUES(42595,98596,-8,'Winlock, Washington 98596',29852,37311);
INSERT INTO "django_geo_db_zipcode" VALUES(42596,98597,-8,'Yelm, Washington 98597',29853,37312);
INSERT INTO "django_geo_db_zipcode" VALUES(42597,98599,-8,'Olympia, Washington 98599',29790,37245);
INSERT INTO "django_geo_db_zipcode" VALUES(42598,98601,-8,'Amboy, Washington 98601',29854,37313);
INSERT INTO "django_geo_db_zipcode" VALUES(42599,98602,-8,'Appleton, Washington 98602',29855,37314);
INSERT INTO "django_geo_db_zipcode" VALUES(42600,98603,-8,'Ariel, Washington 98603',29856,37315);
INSERT INTO "django_geo_db_zipcode" VALUES(42601,98604,-8,'Battle Ground, Washington 98604',29857,37316);
INSERT INTO "django_geo_db_zipcode" VALUES(42602,98605,-8,'Bingen, Washington 98605',29858,37317);
INSERT INTO "django_geo_db_zipcode" VALUES(42603,98606,-8,'Brush Prairie, Washington 98606',29859,37318);
INSERT INTO "django_geo_db_zipcode" VALUES(42604,98607,-8,'Camas, Washington 98607',29860,37319);
INSERT INTO "django_geo_db_zipcode" VALUES(42605,98609,-8,'Carrolls, Washington 98609',29861,37320);
INSERT INTO "django_geo_db_zipcode" VALUES(42606,98610,-8,'Carson, Washington 98610',29862,37321);
INSERT INTO "django_geo_db_zipcode" VALUES(42607,98611,-8,'Castle Rock, Washington 98611',29863,37322);
INSERT INTO "django_geo_db_zipcode" VALUES(42608,98612,-8,'Cathlamet, Washington 98612',29864,37323);
INSERT INTO "django_geo_db_zipcode" VALUES(42609,98613,-8,'Centerville, Washington 98613',29865,37324);
INSERT INTO "django_geo_db_zipcode" VALUES(42610,98614,-8,'Chinook, Washington 98614',29866,37325);
INSERT INTO "django_geo_db_zipcode" VALUES(42611,98616,-8,'Cougar, Washington 98616',29867,37326);
INSERT INTO "django_geo_db_zipcode" VALUES(42612,98617,-8,'Dallesport, Washington 98617',29868,37327);
INSERT INTO "django_geo_db_zipcode" VALUES(42613,98619,-8,'Glenwood, Washington 98619',29869,37328);
INSERT INTO "django_geo_db_zipcode" VALUES(42614,98620,-8,'Goldendale, Washington 98620',29870,37329);
INSERT INTO "django_geo_db_zipcode" VALUES(42615,98621,-8,'Grays River, Washington 98621',29871,37330);
INSERT INTO "django_geo_db_zipcode" VALUES(42616,98622,-8,'Heisson, Washington 98622',29872,37331);
INSERT INTO "django_geo_db_zipcode" VALUES(42617,98623,-8,'Husum, Washington 98623',29873,37332);
INSERT INTO "django_geo_db_zipcode" VALUES(42618,98624,-8,'Ilwaco, Washington 98624',29874,37333);
INSERT INTO "django_geo_db_zipcode" VALUES(42619,98625,-8,'Kalama, Washington 98625',29875,37334);
INSERT INTO "django_geo_db_zipcode" VALUES(42620,98626,-8,'Kelso, Washington 98626',29876,37335);
INSERT INTO "django_geo_db_zipcode" VALUES(42621,98628,-8,'Klickitat, Washington 98628',29877,37336);
INSERT INTO "django_geo_db_zipcode" VALUES(42622,98629,-8,'La Center, Washington 98629',29878,37337);
INSERT INTO "django_geo_db_zipcode" VALUES(42623,98631,-8,'Long Beach, Washington 98631',29879,37338);
INSERT INTO "django_geo_db_zipcode" VALUES(42624,98632,-8,'Longview, Washington 98632',29880,37339);
INSERT INTO "django_geo_db_zipcode" VALUES(42625,98635,-8,'Lyle, Washington 98635',29881,37340);
INSERT INTO "django_geo_db_zipcode" VALUES(42626,98637,-8,'Nahcotta, Washington 98637',29882,37281);
INSERT INTO "django_geo_db_zipcode" VALUES(42627,98638,-8,'Naselle, Washington 98638',29883,37341);
INSERT INTO "django_geo_db_zipcode" VALUES(42628,98639,-8,'North Bonneville, Washington 98639',29884,37342);
INSERT INTO "django_geo_db_zipcode" VALUES(42629,98640,-8,'Ocean Park, Washington 98640',29885,37343);
INSERT INTO "django_geo_db_zipcode" VALUES(42630,98641,-8,'Oysterville, Washington 98641',29886,37344);
INSERT INTO "django_geo_db_zipcode" VALUES(42631,98642,-8,'Ridgefield, Washington 98642',29887,37345);
INSERT INTO "django_geo_db_zipcode" VALUES(42632,98643,-8,'Rosburg, Washington 98643',29888,37346);
INSERT INTO "django_geo_db_zipcode" VALUES(42633,98644,-8,'Seaview, Washington 98644',29889,37347);
INSERT INTO "django_geo_db_zipcode" VALUES(42634,98645,-8,'Silverlake, Washington 98645',29890,37348);
INSERT INTO "django_geo_db_zipcode" VALUES(42635,98647,-8,'Skamokawa, Washington 98647',29891,37349);
INSERT INTO "django_geo_db_zipcode" VALUES(42636,98648,-8,'Stevenson, Washington 98648',29892,37350);
INSERT INTO "django_geo_db_zipcode" VALUES(42637,98649,-8,'Toutle, Washington 98649',29893,37351);
INSERT INTO "django_geo_db_zipcode" VALUES(42638,98650,-8,'Trout Lake, Washington 98650',29894,37352);
INSERT INTO "django_geo_db_zipcode" VALUES(42639,98651,-8,'Underwood, Washington 98651',29895,37353);
INSERT INTO "django_geo_db_zipcode" VALUES(42640,98653,-8,'Lyle, Washington 98653',29881,37354);
INSERT INTO "django_geo_db_zipcode" VALUES(42641,98655,-8,'Hazel Dell North, Washington 98655',29896,37355);
INSERT INTO "django_geo_db_zipcode" VALUES(42642,98660,-8,'Vancouver, Washington 98660',29897,37356);
INSERT INTO "django_geo_db_zipcode" VALUES(42643,98661,-8,'Vancouver, Washington 98661',29897,37357);
INSERT INTO "django_geo_db_zipcode" VALUES(42644,98662,-8,'Vancouver, Washington 98662',29897,37358);
INSERT INTO "django_geo_db_zipcode" VALUES(42645,98663,-8,'Vancouver, Washington 98663',29897,37359);
INSERT INTO "django_geo_db_zipcode" VALUES(42646,98664,-8,'Vancouver, Washington 98664',29897,37360);
INSERT INTO "django_geo_db_zipcode" VALUES(42647,98665,-8,'Vancouver, Washington 98665',29897,37361);
INSERT INTO "django_geo_db_zipcode" VALUES(42648,98666,-8,'Vancouver, Washington 98666',29897,37331);
INSERT INTO "django_geo_db_zipcode" VALUES(42649,98667,-8,'Vancouver, Washington 98667',29897,37331);
INSERT INTO "django_geo_db_zipcode" VALUES(42650,98668,-8,'Vancouver, Washington 98668',29897,37331);
INSERT INTO "django_geo_db_zipcode" VALUES(42651,98670,-8,'Wahkiacus, Washington 98670',29898,37362);
INSERT INTO "django_geo_db_zipcode" VALUES(42652,98671,-8,'Washougal, Washington 98671',29899,37363);
INSERT INTO "django_geo_db_zipcode" VALUES(42653,98672,-8,'White Salmon, Washington 98672',29900,37364);
INSERT INTO "django_geo_db_zipcode" VALUES(42654,98673,-8,'Wishram, Washington 98673',29901,37365);
INSERT INTO "django_geo_db_zipcode" VALUES(42655,98674,-8,'Woodland, Washington 98674',29902,37366);
INSERT INTO "django_geo_db_zipcode" VALUES(42656,98675,-8,'Yacolt, Washington 98675',29903,37367);
INSERT INTO "django_geo_db_zipcode" VALUES(42657,98682,-8,'Vancouver, Washington 98682',29897,37368);
INSERT INTO "django_geo_db_zipcode" VALUES(42658,98683,-8,'Vancouver, Washington 98683',29897,37369);
INSERT INTO "django_geo_db_zipcode" VALUES(42659,98684,-8,'Vancouver, Washington 98684',29897,37370);
INSERT INTO "django_geo_db_zipcode" VALUES(42660,98685,-8,'Vancouver, Washington 98685',29897,37371);
INSERT INTO "django_geo_db_zipcode" VALUES(42661,98686,-8,'Vancouver, Washington 98686',29897,37372);
INSERT INTO "django_geo_db_zipcode" VALUES(42662,98687,-8,'Vancouver, Washington 98687',29897,37331);
INSERT INTO "django_geo_db_zipcode" VALUES(42663,98731,-8,'Waller, Washington 98731',29904,37373);
INSERT INTO "django_geo_db_zipcode" VALUES(42664,98801,-8,'Wenatchee, Washington 98801',29905,37374);
INSERT INTO "django_geo_db_zipcode" VALUES(42665,98802,-8,'East Wenatchee, Washington 98802',29906,37375);
INSERT INTO "django_geo_db_zipcode" VALUES(42666,98807,-8,'Wenatchee, Washington 98807',29905,37376);
INSERT INTO "django_geo_db_zipcode" VALUES(42667,98811,-8,'Ardenvoir, Washington 98811',29907,37377);
INSERT INTO "django_geo_db_zipcode" VALUES(42668,98812,-8,'Brewster, Washington 98812',29908,37378);
INSERT INTO "django_geo_db_zipcode" VALUES(42669,98813,-8,'Bridgeport, Washington 98813',29909,37379);
INSERT INTO "django_geo_db_zipcode" VALUES(42670,98814,-8,'Carlton, Washington 98814',29910,37380);
INSERT INTO "django_geo_db_zipcode" VALUES(42671,98815,-8,'Cashmere, Washington 98815',29911,37381);
INSERT INTO "django_geo_db_zipcode" VALUES(42672,98816,-8,'Chelan, Washington 98816',29912,37382);
INSERT INTO "django_geo_db_zipcode" VALUES(42673,98817,-8,'Chelan Falls, Washington 98817',29913,37383);
INSERT INTO "django_geo_db_zipcode" VALUES(42674,98819,-8,'Conconully, Washington 98819',29914,37384);
INSERT INTO "django_geo_db_zipcode" VALUES(42675,98821,-8,'Dryden, Washington 98821',29915,37385);
INSERT INTO "django_geo_db_zipcode" VALUES(42676,98822,-8,'Entiat, Washington 98822',29916,37386);
INSERT INTO "django_geo_db_zipcode" VALUES(42677,98823,-8,'Ephrata, Washington 98823',29917,37387);
INSERT INTO "django_geo_db_zipcode" VALUES(42678,98824,-8,'George, Washington 98824',29918,37388);
INSERT INTO "django_geo_db_zipcode" VALUES(42679,98826,-8,'Leavenworth, Washington 98826',29919,37389);
INSERT INTO "django_geo_db_zipcode" VALUES(42680,98827,-8,'Loomis, Washington 98827',29920,37390);
INSERT INTO "django_geo_db_zipcode" VALUES(42681,98828,-8,'Malaga, Washington 98828',29921,37391);
INSERT INTO "django_geo_db_zipcode" VALUES(42682,98829,-8,'Malott, Washington 98829',29922,37392);
INSERT INTO "django_geo_db_zipcode" VALUES(42683,98830,-8,'Mansfield, Washington 98830',29923,37393);
INSERT INTO "django_geo_db_zipcode" VALUES(42684,98831,-8,'Manson, Washington 98831',29924,37394);
INSERT INTO "django_geo_db_zipcode" VALUES(42685,98832,-8,'Marlin, Washington 98832',29925,37395);
INSERT INTO "django_geo_db_zipcode" VALUES(42686,98833,-8,'Mazama, Washington 98833',29926,37396);
INSERT INTO "django_geo_db_zipcode" VALUES(42687,98834,-8,'Methow, Washington 98834',29927,37397);
INSERT INTO "django_geo_db_zipcode" VALUES(42688,98836,-8,'Monitor, Washington 98836',29928,37398);
INSERT INTO "django_geo_db_zipcode" VALUES(42689,98837,-8,'Moses Lake, Washington 98837',29929,37399);
INSERT INTO "django_geo_db_zipcode" VALUES(42690,98840,-8,'Okanogan, Washington 98840',29930,37400);
INSERT INTO "django_geo_db_zipcode" VALUES(42691,98841,-8,'Omak, Washington 98841',29931,37401);
INSERT INTO "django_geo_db_zipcode" VALUES(42692,98843,-8,'Orondo, Washington 98843',29932,37402);
INSERT INTO "django_geo_db_zipcode" VALUES(42693,98844,-8,'Oroville, Washington 98844',29933,37403);
INSERT INTO "django_geo_db_zipcode" VALUES(42694,98845,-8,'Palisades, Washington 98845',29934,37404);
INSERT INTO "django_geo_db_zipcode" VALUES(42695,98846,-8,'Pateros, Washington 98846',29935,37405);
INSERT INTO "django_geo_db_zipcode" VALUES(42696,98847,-8,'Peshastin, Washington 98847',29936,37406);
INSERT INTO "django_geo_db_zipcode" VALUES(42697,98848,-8,'Quincy, Washington 98848',29937,37407);
INSERT INTO "django_geo_db_zipcode" VALUES(42698,98849,-8,'Riverside, Washington 98849',29938,37408);
INSERT INTO "django_geo_db_zipcode" VALUES(42699,98850,-8,'Rock Island, Washington 98850',29939,37409);
INSERT INTO "django_geo_db_zipcode" VALUES(42700,98851,-8,'Soap Lake, Washington 98851',29940,37410);
INSERT INTO "django_geo_db_zipcode" VALUES(42701,98852,-8,'Stehekin, Washington 98852',29941,37411);
INSERT INTO "django_geo_db_zipcode" VALUES(42702,98853,-8,'Stratford, Washington 98853',29942,37412);
INSERT INTO "django_geo_db_zipcode" VALUES(42703,98855,-8,'Tonasket, Washington 98855',29943,37413);
INSERT INTO "django_geo_db_zipcode" VALUES(42704,98856,-8,'Twisp, Washington 98856',29944,37414);
INSERT INTO "django_geo_db_zipcode" VALUES(42705,98857,-8,'Warden, Washington 98857',29945,37415);
INSERT INTO "django_geo_db_zipcode" VALUES(42706,98858,-8,'Waterville, Washington 98858',29946,37416);
INSERT INTO "django_geo_db_zipcode" VALUES(42707,98859,-8,'Wauconda, Washington 98859',29947,37417);
INSERT INTO "django_geo_db_zipcode" VALUES(42708,98860,-8,'Wilson Creek, Washington 98860',29948,37418);
INSERT INTO "django_geo_db_zipcode" VALUES(42709,98862,-8,'Winthrop, Washington 98862',29949,37419);
INSERT INTO "django_geo_db_zipcode" VALUES(42710,98901,-8,'Yakima, Washington 98901',29950,37420);
INSERT INTO "django_geo_db_zipcode" VALUES(42711,98902,-8,'Yakima, Washington 98902',29950,37421);
INSERT INTO "django_geo_db_zipcode" VALUES(42712,98903,-8,'Yakima, Washington 98903',29950,37422);
INSERT INTO "django_geo_db_zipcode" VALUES(42713,98904,-8,'Yakima, Washington 98904',29950,37423);
INSERT INTO "django_geo_db_zipcode" VALUES(42714,98907,-8,'Yakima, Washington 98907',29950,37424);
INSERT INTO "django_geo_db_zipcode" VALUES(42715,98908,-8,'Yakima, Washington 98908',29950,37425);
INSERT INTO "django_geo_db_zipcode" VALUES(42716,98909,-8,'Yakima, Washington 98909',29950,37426);
INSERT INTO "django_geo_db_zipcode" VALUES(42717,98920,-8,'Brownstown, Washington 98920',29951,37423);
INSERT INTO "django_geo_db_zipcode" VALUES(42718,98921,-8,'Buena, Washington 98921',29952,37427);
INSERT INTO "django_geo_db_zipcode" VALUES(42719,98922,-8,'Cle Elum, Washington 98922',29953,37428);
INSERT INTO "django_geo_db_zipcode" VALUES(42720,98923,-8,'Cowiche, Washington 98923',29954,37429);
INSERT INTO "django_geo_db_zipcode" VALUES(42721,98925,-8,'Easton, Washington 98925',29955,37430);
INSERT INTO "django_geo_db_zipcode" VALUES(42722,98926,-8,'Ellensburg, Washington 98926',29956,37431);
INSERT INTO "django_geo_db_zipcode" VALUES(42723,98929,-8,'Goose Prairie, Washington 98929',29957,37432);
INSERT INTO "django_geo_db_zipcode" VALUES(42724,98930,-8,'Grandview, Washington 98930',29958,37433);
INSERT INTO "django_geo_db_zipcode" VALUES(42725,98932,-8,'Granger, Washington 98932',29959,37434);
INSERT INTO "django_geo_db_zipcode" VALUES(42726,98933,-8,'Harrah, Washington 98933',29960,37435);
INSERT INTO "django_geo_db_zipcode" VALUES(42727,98934,-8,'Kittitas, Washington 98934',29961,37436);
INSERT INTO "django_geo_db_zipcode" VALUES(42728,98935,-8,'Mabton, Washington 98935',29962,37437);
INSERT INTO "django_geo_db_zipcode" VALUES(42729,98936,-8,'Moxee, Washington 98936',29963,37438);
INSERT INTO "django_geo_db_zipcode" VALUES(42730,98937,-8,'Naches, Washington 98937',29964,37439);
INSERT INTO "django_geo_db_zipcode" VALUES(42731,98938,-8,'Outlook, Washington 98938',29965,37440);
INSERT INTO "django_geo_db_zipcode" VALUES(42732,98939,-8,'Parker, Washington 98939',29966,37423);
INSERT INTO "django_geo_db_zipcode" VALUES(42733,98940,-8,'Ronald, Washington 98940',29967,37441);
INSERT INTO "django_geo_db_zipcode" VALUES(42734,98941,-8,'Roslyn, Washington 98941',29968,37442);
INSERT INTO "django_geo_db_zipcode" VALUES(42735,98942,-8,'Selah, Washington 98942',29969,37443);
INSERT INTO "django_geo_db_zipcode" VALUES(42736,98943,-8,'South Cle Elum, Washington 98943',29970,37444);
INSERT INTO "django_geo_db_zipcode" VALUES(42737,98944,-8,'Sunnyside, Washington 98944',29971,37445);
INSERT INTO "django_geo_db_zipcode" VALUES(42738,98946,-8,'Thorp, Washington 98946',29972,37446);
INSERT INTO "django_geo_db_zipcode" VALUES(42739,98947,-8,'Tieton, Washington 98947',29973,37447);
INSERT INTO "django_geo_db_zipcode" VALUES(42740,98948,-8,'Toppenish, Washington 98948',29974,37448);
INSERT INTO "django_geo_db_zipcode" VALUES(42741,98950,-8,'Vantage, Washington 98950',29975,37449);
INSERT INTO "django_geo_db_zipcode" VALUES(42742,98951,-8,'Wapato, Washington 98951',29976,37450);
INSERT INTO "django_geo_db_zipcode" VALUES(42743,98952,-8,'White Swan, Washington 98952',29977,37451);
INSERT INTO "django_geo_db_zipcode" VALUES(42744,98953,-8,'Zillah, Washington 98953',29978,37452);
INSERT INTO "django_geo_db_zipcode" VALUES(42745,98991,-8,'Roslyn, Washington 98991',29968,37453);
INSERT INTO "django_geo_db_zipcode" VALUES(42746,99001,-8,'Airway Heights, Washington 99001',29979,37454);
INSERT INTO "django_geo_db_zipcode" VALUES(42747,99003,-8,'Chattaroy, Washington 99003',29980,37455);
INSERT INTO "django_geo_db_zipcode" VALUES(42748,99004,-8,'Cheney, Washington 99004',29981,37456);
INSERT INTO "django_geo_db_zipcode" VALUES(42749,99005,-8,'Colbert, Washington 99005',29982,37457);
INSERT INTO "django_geo_db_zipcode" VALUES(42750,99006,-8,'Deer Park, Washington 99006',29983,37458);
INSERT INTO "django_geo_db_zipcode" VALUES(42751,99008,-8,'Edwall, Washington 99008',29984,37459);
INSERT INTO "django_geo_db_zipcode" VALUES(42752,99009,-8,'Elk, Washington 99009',29985,37460);
INSERT INTO "django_geo_db_zipcode" VALUES(42753,99011,-8,'Fairchild Air Force Base, Washington 99011',29986,37461);
INSERT INTO "django_geo_db_zipcode" VALUES(42754,99012,-8,'Fairfield, Washington 99012',29987,37462);
INSERT INTO "django_geo_db_zipcode" VALUES(42755,99013,-8,'Ford, Washington 99013',29988,37463);
INSERT INTO "django_geo_db_zipcode" VALUES(42756,99014,-8,'Four Lakes, Washington 99014',29989,37464);
INSERT INTO "django_geo_db_zipcode" VALUES(42757,99015,-8,'Freeman, Washington 99015',29990,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42758,99016,-8,'Greenacres, Washington 99016',29991,37466);
INSERT INTO "django_geo_db_zipcode" VALUES(42759,99017,-8,'Lamont, Washington 99017',29992,37467);
INSERT INTO "django_geo_db_zipcode" VALUES(42760,99018,-8,'Latah, Washington 99018',29993,37468);
INSERT INTO "django_geo_db_zipcode" VALUES(42761,99019,-8,'Liberty Lake, Washington 99019',29994,37469);
INSERT INTO "django_geo_db_zipcode" VALUES(42762,99020,-8,'Marshall, Washington 99020',29995,37470);
INSERT INTO "django_geo_db_zipcode" VALUES(42763,99021,-8,'Mead, Washington 99021',29996,37471);
INSERT INTO "django_geo_db_zipcode" VALUES(42764,99022,-8,'Medical Lake, Washington 99022',29997,37472);
INSERT INTO "django_geo_db_zipcode" VALUES(42765,99023,-8,'Mica, Washington 99023',29998,37473);
INSERT INTO "django_geo_db_zipcode" VALUES(42766,99025,-8,'Newman Lake, Washington 99025',29999,37474);
INSERT INTO "django_geo_db_zipcode" VALUES(42767,99026,-8,'Nine Mile Falls, Washington 99026',30000,37475);
INSERT INTO "django_geo_db_zipcode" VALUES(42768,99027,-8,'Otis Orchards, Washington 99027',30001,37476);
INSERT INTO "django_geo_db_zipcode" VALUES(42769,99029,-8,'Reardan, Washington 99029',30002,37477);
INSERT INTO "django_geo_db_zipcode" VALUES(42770,99030,-8,'Rockford, Washington 99030',30003,37478);
INSERT INTO "django_geo_db_zipcode" VALUES(42771,99031,-8,'Spangle, Washington 99031',30004,37479);
INSERT INTO "django_geo_db_zipcode" VALUES(42772,99032,-8,'Sprague, Washington 99032',30005,37480);
INSERT INTO "django_geo_db_zipcode" VALUES(42773,99033,-8,'Tekoa, Washington 99033',30006,37481);
INSERT INTO "django_geo_db_zipcode" VALUES(42774,99034,-8,'Tumtum, Washington 99034',30007,37482);
INSERT INTO "django_geo_db_zipcode" VALUES(42775,99036,-8,'Valleyford, Washington 99036',30008,37483);
INSERT INTO "django_geo_db_zipcode" VALUES(42776,99037,-8,'Veradale, Washington 99037',30009,37484);
INSERT INTO "django_geo_db_zipcode" VALUES(42777,99039,-8,'Waverly, Washington 99039',30010,37485);
INSERT INTO "django_geo_db_zipcode" VALUES(42778,99040,-8,'Wellpinit, Washington 99040',30011,37486);
INSERT INTO "django_geo_db_zipcode" VALUES(42779,99066,-8,'Deer Park, Washington 99066',29983,37487);
INSERT INTO "django_geo_db_zipcode" VALUES(42780,99101,-8,'Addy, Washington 99101',30012,37488);
INSERT INTO "django_geo_db_zipcode" VALUES(42781,99102,-8,'Albion, Washington 99102',30013,37489);
INSERT INTO "django_geo_db_zipcode" VALUES(42782,99103,-8,'Almira, Washington 99103',30014,37490);
INSERT INTO "django_geo_db_zipcode" VALUES(42783,99104,-8,'Belmont, Washington 99104',30015,37491);
INSERT INTO "django_geo_db_zipcode" VALUES(42784,99105,-8,'Benge, Washington 99105',30016,37492);
INSERT INTO "django_geo_db_zipcode" VALUES(42785,99107,-8,'Boyds, Washington 99107',30017,37493);
INSERT INTO "django_geo_db_zipcode" VALUES(42786,99109,-8,'Chewelah, Washington 99109',30018,37494);
INSERT INTO "django_geo_db_zipcode" VALUES(42787,99110,-8,'Clayton, Washington 99110',30019,37495);
INSERT INTO "django_geo_db_zipcode" VALUES(42788,99111,-8,'Colfax, Washington 99111',30020,37496);
INSERT INTO "django_geo_db_zipcode" VALUES(42789,99113,-8,'Colton, Washington 99113',30021,37497);
INSERT INTO "django_geo_db_zipcode" VALUES(42790,99114,-8,'Colville, Washington 99114',30022,37498);
INSERT INTO "django_geo_db_zipcode" VALUES(42791,99115,-8,'Coulee City, Washington 99115',30023,37499);
INSERT INTO "django_geo_db_zipcode" VALUES(42792,99116,-8,'Coulee Dam, Washington 99116',30024,37500);
INSERT INTO "django_geo_db_zipcode" VALUES(42793,99117,-8,'Creston, Washington 99117',30025,37501);
INSERT INTO "django_geo_db_zipcode" VALUES(42794,99118,-8,'Curlew, Washington 99118',30026,37502);
INSERT INTO "django_geo_db_zipcode" VALUES(42795,99119,-8,'Cusick, Washington 99119',30027,37503);
INSERT INTO "django_geo_db_zipcode" VALUES(42796,99121,-8,'Danville, Washington 99121',30028,37504);
INSERT INTO "django_geo_db_zipcode" VALUES(42797,99122,-8,'Davenport, Washington 99122',30029,37505);
INSERT INTO "django_geo_db_zipcode" VALUES(42798,99123,-8,'Electric City, Washington 99123',30030,37506);
INSERT INTO "django_geo_db_zipcode" VALUES(42799,99124,-8,'Elmer City, Washington 99124',30031,37507);
INSERT INTO "django_geo_db_zipcode" VALUES(42800,99125,-8,'Endicott, Washington 99125',30032,37508);
INSERT INTO "django_geo_db_zipcode" VALUES(42801,99126,-8,'Evans, Washington 99126',30033,37509);
INSERT INTO "django_geo_db_zipcode" VALUES(42802,99127,-8,'Saint John, Washington 99127',30034,37510);
INSERT INTO "django_geo_db_zipcode" VALUES(42803,99128,-8,'Farmington, Idaho 99128',30035,37511);
INSERT INTO "django_geo_db_zipcode" VALUES(42804,99129,-8,'Fruitland, Washington 99129',30036,37512);
INSERT INTO "django_geo_db_zipcode" VALUES(42805,99130,-8,'Garfield, Washington 99130',30037,37513);
INSERT INTO "django_geo_db_zipcode" VALUES(42806,99131,-8,'Gifford, Washington 99131',30038,37514);
INSERT INTO "django_geo_db_zipcode" VALUES(42807,99133,-8,'Grand Coulee, Washington 99133',30039,37515);
INSERT INTO "django_geo_db_zipcode" VALUES(42808,99134,-8,'Harrington, Washington 99134',30040,37516);
INSERT INTO "django_geo_db_zipcode" VALUES(42809,99135,-8,'Hartline, Washington 99135',30041,37517);
INSERT INTO "django_geo_db_zipcode" VALUES(42810,99136,-8,'Hay, Washington 99136',30042,37518);
INSERT INTO "django_geo_db_zipcode" VALUES(42811,99137,-8,'Hunters, Washington 99137',30043,37519);
INSERT INTO "django_geo_db_zipcode" VALUES(42812,99138,-8,'Inchelium, Washington 99138',30044,37520);
INSERT INTO "django_geo_db_zipcode" VALUES(42813,99139,-8,'Ione, Washington 99139',30045,37521);
INSERT INTO "django_geo_db_zipcode" VALUES(42814,99140,-8,'Keller, Washington 99140',30046,37522);
INSERT INTO "django_geo_db_zipcode" VALUES(42815,99141,-8,'Kettle Falls, Washington 99141',30047,37523);
INSERT INTO "django_geo_db_zipcode" VALUES(42816,99143,-8,'Lacrosse, Washington 99143',30048,37524);
INSERT INTO "django_geo_db_zipcode" VALUES(42817,99144,-8,'Lamona, Washington 99144',30049,37525);
INSERT INTO "django_geo_db_zipcode" VALUES(42818,99146,-8,'Laurier, Washington 99146',30050,37526);
INSERT INTO "django_geo_db_zipcode" VALUES(42819,99147,-8,'Lincoln, Washington 99147',30051,37525);
INSERT INTO "django_geo_db_zipcode" VALUES(42820,99148,-8,'Loon Lake, Washington 99148',30052,37527);
INSERT INTO "django_geo_db_zipcode" VALUES(42821,99149,-8,'Malden, Washington 99149',30053,37528);
INSERT INTO "django_geo_db_zipcode" VALUES(42822,99150,-8,'Malo, Washington 99150',30054,37529);
INSERT INTO "django_geo_db_zipcode" VALUES(42823,99151,-8,'Marcus, Washington 99151',30055,37530);
INSERT INTO "django_geo_db_zipcode" VALUES(42824,99152,-8,'Metaline, Washington 99152',30056,37531);
INSERT INTO "django_geo_db_zipcode" VALUES(42825,99153,-8,'Metaline Falls, Washington 99153',30057,37532);
INSERT INTO "django_geo_db_zipcode" VALUES(42826,99154,-8,'Mohler, Washington 99154',30058,37533);
INSERT INTO "django_geo_db_zipcode" VALUES(42827,99155,-8,'Nespelem, Washington 99155',30059,37534);
INSERT INTO "django_geo_db_zipcode" VALUES(42828,99156,-8,'Newport, Washington 99156',30060,37535);
INSERT INTO "django_geo_db_zipcode" VALUES(42829,99157,-8,'Northport, Washington 99157',30061,37536);
INSERT INTO "django_geo_db_zipcode" VALUES(42830,99158,-8,'Oakesdale, Washington 99158',30062,37537);
INSERT INTO "django_geo_db_zipcode" VALUES(42831,99159,-8,'Odessa, Washington 99159',30063,37538);
INSERT INTO "django_geo_db_zipcode" VALUES(42832,99160,-8,'Orient, Washington 99160',30064,37539);
INSERT INTO "django_geo_db_zipcode" VALUES(42833,99161,-8,'Palouse, Washington 99161',30065,37540);
INSERT INTO "django_geo_db_zipcode" VALUES(42834,99163,-8,'Pullman, Washington 99163',30066,37541);
INSERT INTO "django_geo_db_zipcode" VALUES(42835,99164,-8,'Pullman, Washington 99164',30066,37510);
INSERT INTO "django_geo_db_zipcode" VALUES(42836,99165,-8,'Pullman, Washington 99165',30066,37510);
INSERT INTO "django_geo_db_zipcode" VALUES(42837,99166,-8,'Republic, Washington 99166',30067,37542);
INSERT INTO "django_geo_db_zipcode" VALUES(42838,99167,-8,'Rice, Washington 99167',30068,37543);
INSERT INTO "django_geo_db_zipcode" VALUES(42839,99169,-8,'Ritzville, Washington 99169',30069,37544);
INSERT INTO "django_geo_db_zipcode" VALUES(42840,99170,-8,'Rosalia, Washington 99170',30070,37545);
INSERT INTO "django_geo_db_zipcode" VALUES(42841,99171,-8,'Saint John, Washington 99171',30034,37546);
INSERT INTO "django_geo_db_zipcode" VALUES(42842,99173,-8,'Springdale, Washington 99173',30071,37547);
INSERT INTO "django_geo_db_zipcode" VALUES(42843,99174,-8,'Steptoe, Washington 99174',30072,37510);
INSERT INTO "django_geo_db_zipcode" VALUES(42844,99176,-8,'Thornton, Washington 99176',30073,37548);
INSERT INTO "django_geo_db_zipcode" VALUES(42845,99179,-8,'Uniontown, Washington 99179',30074,37549);
INSERT INTO "django_geo_db_zipcode" VALUES(42846,99180,-8,'Usk, Washington 99180',30075,37550);
INSERT INTO "django_geo_db_zipcode" VALUES(42847,99181,-8,'Valley, Washington 99181',30076,37551);
INSERT INTO "django_geo_db_zipcode" VALUES(42848,99185,-8,'Wilbur, Washington 99185',30077,37552);
INSERT INTO "django_geo_db_zipcode" VALUES(42849,99201,-8,'Spokane, Washington 99201',30078,37553);
INSERT INTO "django_geo_db_zipcode" VALUES(42850,99202,-8,'Spokane, Washington 99202',30078,37554);
INSERT INTO "django_geo_db_zipcode" VALUES(42851,99203,-8,'Spokane, Washington 99203',30078,37555);
INSERT INTO "django_geo_db_zipcode" VALUES(42852,99204,-8,'Spokane, Washington 99204',30078,37556);
INSERT INTO "django_geo_db_zipcode" VALUES(42853,99205,-8,'Spokane, Washington 99205',30078,37557);
INSERT INTO "django_geo_db_zipcode" VALUES(42854,99206,-8,'Spokane, Washington 99206',30078,37558);
INSERT INTO "django_geo_db_zipcode" VALUES(42855,99207,-8,'Spokane, Washington 99207',30078,37559);
INSERT INTO "django_geo_db_zipcode" VALUES(42856,99208,-8,'Spokane, Washington 99208',30078,37560);
INSERT INTO "django_geo_db_zipcode" VALUES(42857,99209,-8,'Spokane, Washington 99209',30078,37561);
INSERT INTO "django_geo_db_zipcode" VALUES(42858,99210,-8,'Spokane, Washington 99210',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42859,99211,-8,'Spokane, Washington 99211',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42860,99212,-8,'Spokane, Washington 99212',30078,37562);
INSERT INTO "django_geo_db_zipcode" VALUES(42861,99213,-8,'Spokane, Washington 99213',30078,37563);
INSERT INTO "django_geo_db_zipcode" VALUES(42862,99214,-8,'Spokane, Washington 99214',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42863,99215,-8,'Spokane, Washington 99215',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42864,99216,-8,'Spokane, Washington 99216',30078,37564);
INSERT INTO "django_geo_db_zipcode" VALUES(42865,99217,-8,'Spokane, Washington 99217',30078,37565);
INSERT INTO "django_geo_db_zipcode" VALUES(42866,99218,-8,'Spokane, Washington 99218',30078,37566);
INSERT INTO "django_geo_db_zipcode" VALUES(42867,99219,-8,'Spokane, Washington 99219',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42868,99220,-8,'Spokane, Washington 99220',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42869,99223,-8,'Spokane, Washington 99223',30078,37567);
INSERT INTO "django_geo_db_zipcode" VALUES(42870,99224,-8,'Spokane, Washington 99224',30078,37568);
INSERT INTO "django_geo_db_zipcode" VALUES(42871,99228,-8,'Spokane, Washington 99228',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42872,99251,-8,'Spokane, Washington 99251',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42873,99252,-8,'Spokane, Washington 99252',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42874,99256,-8,'Spokane, Washington 99256',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42875,99258,-8,'Spokane, Washington 99258',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42876,99260,-8,'Spokane, Washington 99260',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42877,99299,-8,'Spokane, Washington 99299',30078,37465);
INSERT INTO "django_geo_db_zipcode" VALUES(42878,99301,-8,'Pasco, Washington 99301',30079,37569);
INSERT INTO "django_geo_db_zipcode" VALUES(42879,99302,-8,'Pasco, Washington 99302',30079,37570);
INSERT INTO "django_geo_db_zipcode" VALUES(42880,99309,-8,'Mattawa, Washington 99309',30080,37571);
INSERT INTO "django_geo_db_zipcode" VALUES(42881,99319,-8,'Desert Aire, Washington 99319',30081,37572);
INSERT INTO "django_geo_db_zipcode" VALUES(42882,99320,-8,'Benton City, Washington 99320',30082,37573);
INSERT INTO "django_geo_db_zipcode" VALUES(42883,99321,-8,'Beverly, Washington 99321',30083,37574);
INSERT INTO "django_geo_db_zipcode" VALUES(42884,99322,-8,'Bickleton, Washington 99322',30084,37575);
INSERT INTO "django_geo_db_zipcode" VALUES(42885,99323,-8,'Burbank, Washington 99323',30085,37576);
INSERT INTO "django_geo_db_zipcode" VALUES(42886,99324,-8,'College Place, Washington 99324',30086,37577);
INSERT INTO "django_geo_db_zipcode" VALUES(42887,99326,-8,'Connell, Washington 99326',30087,37578);
INSERT INTO "django_geo_db_zipcode" VALUES(42888,99327,-8,'Cunningham, Washington 99327',30088,37579);
INSERT INTO "django_geo_db_zipcode" VALUES(42889,99328,-8,'Dayton, Washington 99328',30089,37580);
INSERT INTO "django_geo_db_zipcode" VALUES(42890,99329,-8,'Dixie, Washington 99329',30090,37581);
INSERT INTO "django_geo_db_zipcode" VALUES(42891,99330,-8,'Eltopia, Washington 99330',30091,37582);
INSERT INTO "django_geo_db_zipcode" VALUES(42892,99332,-8,'Hatton, Washington 99332',30092,37583);
INSERT INTO "django_geo_db_zipcode" VALUES(42893,99333,-8,'Hooper, Washington 99333',30093,37510);
INSERT INTO "django_geo_db_zipcode" VALUES(42894,99335,-8,'Kahlotus, Washington 99335',30094,37584);
INSERT INTO "django_geo_db_zipcode" VALUES(42895,99336,-8,'Kennewick, Washington 99336',30095,37585);
INSERT INTO "django_geo_db_zipcode" VALUES(42896,99337,-8,'Kennewick, Washington 99337',30095,37586);
INSERT INTO "django_geo_db_zipcode" VALUES(42897,99338,-8,'Kennewick, Washington 99338',30095,37587);
INSERT INTO "django_geo_db_zipcode" VALUES(42898,99341,-8,'Lind, Washington 99341',30096,37588);
INSERT INTO "django_geo_db_zipcode" VALUES(42899,99343,-8,'Mesa, Washington 99343',30097,37589);
INSERT INTO "django_geo_db_zipcode" VALUES(42900,99344,-8,'Othello, Washington 99344',30098,37590);
INSERT INTO "django_geo_db_zipcode" VALUES(42901,99345,-8,'Paterson, Washington 99345',30099,37591);
INSERT INTO "django_geo_db_zipcode" VALUES(42902,99346,-8,'Plymouth, Washington 99346',30100,37592);
INSERT INTO "django_geo_db_zipcode" VALUES(42903,99347,-8,'Pomeroy, Washington 99347',30101,37593);
INSERT INTO "django_geo_db_zipcode" VALUES(42904,99348,-8,'Prescott, Washington 99348',30102,37594);
INSERT INTO "django_geo_db_zipcode" VALUES(42905,99349,-8,'Mattawa, Washington 99349',30080,37595);
INSERT INTO "django_geo_db_zipcode" VALUES(42906,99350,-8,'Prosser, Washington 99350',30103,37596);
INSERT INTO "django_geo_db_zipcode" VALUES(42907,99352,-8,'Richland, Washington 99352',30104,37597);
INSERT INTO "django_geo_db_zipcode" VALUES(42908,99353,-8,'West Richland, Washington 99353',30105,37598);
INSERT INTO "django_geo_db_zipcode" VALUES(42909,99356,-8,'Roosevelt, Washington 99356',30106,37599);
INSERT INTO "django_geo_db_zipcode" VALUES(42910,99357,-8,'Royal City, Washington 99357',30107,37600);
INSERT INTO "django_geo_db_zipcode" VALUES(42911,99359,-8,'Starbuck, Washington 99359',30108,37601);
INSERT INTO "django_geo_db_zipcode" VALUES(42912,99360,-8,'Touchet, Washington 99360',30109,37602);
INSERT INTO "django_geo_db_zipcode" VALUES(42913,99361,-8,'Waitsburg, Washington 99361',30110,37603);
INSERT INTO "django_geo_db_zipcode" VALUES(42914,99362,-8,'Walla Walla, Oregon 99362',30111,37604);
INSERT INTO "django_geo_db_zipcode" VALUES(42915,99363,-8,'Wallula, Washington 99363',30112,37605);
INSERT INTO "django_geo_db_zipcode" VALUES(42916,99371,-8,'Washtucna, Washington 99371',30113,37606);
INSERT INTO "django_geo_db_zipcode" VALUES(42917,99401,-8,'Anatone, Washington 99401',30114,37607);
INSERT INTO "django_geo_db_zipcode" VALUES(42918,99402,-8,'Asotin, Washington 99402',30115,37608);
INSERT INTO "django_geo_db_zipcode" VALUES(42919,99403,-8,'Clarkston, Washington 99403',30116,37609);
INSERT INTO "django_geo_db_zipcode" VALUES(42920,99501,-9,'Anchorage, Alaska 99501',30117,37610);
INSERT INTO "django_geo_db_zipcode" VALUES(42921,99502,-9,'Anchorage, Alaska 99502',30117,37611);
INSERT INTO "django_geo_db_zipcode" VALUES(42922,99503,-9,'Anchorage, Alaska 99503',30117,37612);
INSERT INTO "django_geo_db_zipcode" VALUES(42923,99504,-9,'Anchorage, Alaska 99504',30117,37613);
INSERT INTO "django_geo_db_zipcode" VALUES(42924,99505,-9,'Fort Richardson, Alaska 99505',30118,37614);
INSERT INTO "django_geo_db_zipcode" VALUES(42925,99506,-9,'Elmendorf AFB, Alaska 99506',30119,37615);
INSERT INTO "django_geo_db_zipcode" VALUES(42926,99507,-9,'Anchorage, Alaska 99507',30117,37616);
INSERT INTO "django_geo_db_zipcode" VALUES(42927,99508,-9,'Anchorage, Alaska 99508',30117,37617);
INSERT INTO "django_geo_db_zipcode" VALUES(42928,99509,-9,'Anchorage, Alaska 99509',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42929,99510,-9,'Anchorage, Alaska 99510',30117,37619);
INSERT INTO "django_geo_db_zipcode" VALUES(42930,99511,-9,'Anchorage, Alaska 99511',30117,37620);
INSERT INTO "django_geo_db_zipcode" VALUES(42931,99512,-9,'Anchorage, Alaska 99512',30117,37621);
INSERT INTO "django_geo_db_zipcode" VALUES(42932,99513,-9,'Anchorage, Alaska 99513',30117,37622);
INSERT INTO "django_geo_db_zipcode" VALUES(42933,99514,-9,'Anchorage, Alaska 99514',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42934,99515,-9,'Anchorage, Alaska 99515',30117,37623);
INSERT INTO "django_geo_db_zipcode" VALUES(42935,99516,-9,'Anchorage, Alaska 99516',30117,37624);
INSERT INTO "django_geo_db_zipcode" VALUES(42936,99517,-9,'Anchorage, Alaska 99517',30117,37625);
INSERT INTO "django_geo_db_zipcode" VALUES(42937,99518,-9,'Anchorage, Alaska 99518',30117,37626);
INSERT INTO "django_geo_db_zipcode" VALUES(42938,99519,-9,'Anchorage, Alaska 99519',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42939,99520,-9,'Anchorage, Alaska 99520',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42940,99521,-9,'Anchorage, Alaska 99521',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42941,99522,-9,'Anchorage, Alaska 99522',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42942,99523,-9,'Anchorage, Alaska 99523',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42943,99524,-9,'Anchorage, Alaska 99524',30117,37618);
INSERT INTO "django_geo_db_zipcode" VALUES(42944,99536,-8,'Kennewick, Washington 99536',30095,37627);
INSERT INTO "django_geo_db_zipcode" VALUES(42945,99540,-9,'Indian, Alaska 99540',30120,37628);
INSERT INTO "django_geo_db_zipcode" VALUES(42946,99546,-10,'Adak, Alaska 99546',30121,37629);
INSERT INTO "django_geo_db_zipcode" VALUES(42947,99547,-10,'Atka, Alaska 99547',30122,37630);
INSERT INTO "django_geo_db_zipcode" VALUES(42948,99548,-9,'Chignik Lake, Alaska 99548',30123,37631);
INSERT INTO "django_geo_db_zipcode" VALUES(42949,99549,-9,'Port Heiden, Alaska 99549',30124,37632);
INSERT INTO "django_geo_db_zipcode" VALUES(42950,99550,-9,'Port Lions, Alaska 99550',30125,37633);
INSERT INTO "django_geo_db_zipcode" VALUES(42951,99551,-9,'Akiachak, Alaska 99551',30126,37634);
INSERT INTO "django_geo_db_zipcode" VALUES(42952,99552,-9,'Akiak, Alaska 99552',30127,37635);
INSERT INTO "django_geo_db_zipcode" VALUES(42953,99553,-9,'Akutan, Alaska 99553',30128,37636);
INSERT INTO "django_geo_db_zipcode" VALUES(42954,99554,-9,'Alakanuk, Alaska 99554',30129,37637);
INSERT INTO "django_geo_db_zipcode" VALUES(42955,99555,-9,'Aleknagik, Alaska 99555',30130,37638);
INSERT INTO "django_geo_db_zipcode" VALUES(42956,99556,-9,'Anchor Point, Alaska 99556',30131,37639);
INSERT INTO "django_geo_db_zipcode" VALUES(42957,99557,-9,'Aniak, Alaska 99557',30132,37640);
INSERT INTO "django_geo_db_zipcode" VALUES(42958,99558,-9,'Anvik, Alaska 99558',30133,37641);
INSERT INTO "django_geo_db_zipcode" VALUES(42959,99559,-9,'Bethel, Alaska 99559',30134,37642);
INSERT INTO "django_geo_db_zipcode" VALUES(42960,99561,-9,'Chefornak, Alaska 99561',30135,37643);
INSERT INTO "django_geo_db_zipcode" VALUES(42961,99563,-9,'Chevak, Alaska 99563',30136,37644);
INSERT INTO "django_geo_db_zipcode" VALUES(42962,99564,-9,'Chignik, Alaska 99564',30137,37645);
INSERT INTO "django_geo_db_zipcode" VALUES(42963,99565,-9,'Chignik Lagoon, Alaska 99565',30138,37646);
INSERT INTO "django_geo_db_zipcode" VALUES(42964,99566,-9,'Chitina, Alaska 99566',30139,37647);
INSERT INTO "django_geo_db_zipcode" VALUES(42965,99567,-9,'Chugiak, Alaska 99567',30140,37648);
INSERT INTO "django_geo_db_zipcode" VALUES(42966,99568,-9,'Clam Gulch, Alaska 99568',30141,37649);
INSERT INTO "django_geo_db_zipcode" VALUES(42967,99569,-9,'Clarks Point, Alaska 99569',30142,37650);
INSERT INTO "django_geo_db_zipcode" VALUES(42968,99571,-9,'Cold Bay, Alaska 99571',30143,37651);
INSERT INTO "django_geo_db_zipcode" VALUES(42969,99572,-9,'Cooper Landing, Alaska 99572',30144,37652);
INSERT INTO "django_geo_db_zipcode" VALUES(42970,99573,-9,'Copper Center, Alaska 99573',30145,37653);
INSERT INTO "django_geo_db_zipcode" VALUES(42971,99574,-9,'Cordova, Alaska 99574',30146,37654);
INSERT INTO "django_geo_db_zipcode" VALUES(42972,99575,-9,'Crooked Creek, Alaska 99575',30147,37655);
INSERT INTO "django_geo_db_zipcode" VALUES(42973,99576,-9,'Dillingham, Alaska 99576',30148,37656);
INSERT INTO "django_geo_db_zipcode" VALUES(42974,99577,-9,'Eagle River, Alaska 99577',30149,37657);
INSERT INTO "django_geo_db_zipcode" VALUES(42975,99578,-9,'Eek, Alaska 99578',30150,37658);
INSERT INTO "django_geo_db_zipcode" VALUES(42976,99579,-9,'Egegik, Alaska 99579',30151,37659);
INSERT INTO "django_geo_db_zipcode" VALUES(42977,99580,-9,'Ekwok, Alaska 99580',30152,37660);
INSERT INTO "django_geo_db_zipcode" VALUES(42978,99581,-9,'Emmonak, Alaska 99581',30153,37661);
INSERT INTO "django_geo_db_zipcode" VALUES(42979,99583,-9,'False Pass, Alaska 99583',30154,37662);
INSERT INTO "django_geo_db_zipcode" VALUES(42980,99584,-9,'Flat, Alaska 99584',30155,37663);
INSERT INTO "django_geo_db_zipcode" VALUES(42981,99585,-9,'Marshall, Alaska 99585',30156,37664);
INSERT INTO "django_geo_db_zipcode" VALUES(42982,99586,-9,'Gakona, Alaska 99586',30157,37665);
INSERT INTO "django_geo_db_zipcode" VALUES(42983,99587,-9,'Girdwood, Alaska 99587',30158,37666);
INSERT INTO "django_geo_db_zipcode" VALUES(42984,99588,-9,'Glennallen, Alaska 99588',30159,37667);
INSERT INTO "django_geo_db_zipcode" VALUES(42985,99589,-9,'Goodnews Bay, Alaska 99589',30160,37668);
INSERT INTO "django_geo_db_zipcode" VALUES(42986,99590,-9,'Grayling, Alaska 99590',30161,37669);
INSERT INTO "django_geo_db_zipcode" VALUES(42987,99591,-10,'Saint George Island, Alaska 99591',30162,37670);
INSERT INTO "django_geo_db_zipcode" VALUES(42988,99599,-9,'Anchorage, Alaska 99599',30117,37671);
INSERT INTO "django_geo_db_zipcode" VALUES(42989,99602,-9,'Holy Cross, Alaska 99602',30163,37672);
INSERT INTO "django_geo_db_zipcode" VALUES(42990,99603,-9,'Homer, Alaska 99603',30164,37673);
INSERT INTO "django_geo_db_zipcode" VALUES(42991,99604,-9,'Hooper Bay, Alaska 99604',30165,37674);
INSERT INTO "django_geo_db_zipcode" VALUES(42992,99605,-9,'Hope, Alaska 99605',30166,37675);
INSERT INTO "django_geo_db_zipcode" VALUES(42993,99606,-9,'Iliamna, Alaska 99606',30167,37676);
INSERT INTO "django_geo_db_zipcode" VALUES(42994,99607,-9,'Kalskag, Alaska 99607',30168,37677);
INSERT INTO "django_geo_db_zipcode" VALUES(42995,99608,-9,'Karluk, Alaska 99608',30169,37678);
INSERT INTO "django_geo_db_zipcode" VALUES(42996,99609,-9,'Kasigluk, Alaska 99609',30170,37679);
INSERT INTO "django_geo_db_zipcode" VALUES(42997,99610,-9,'Kasilof, Alaska 99610',30171,37680);
INSERT INTO "django_geo_db_zipcode" VALUES(42998,99611,-9,'Kenai, Alaska 99611',30172,37681);
INSERT INTO "django_geo_db_zipcode" VALUES(42999,99612,-9,'King Cove, Alaska 99612',30173,37682);
INSERT INTO "django_geo_db_zipcode" VALUES(43000,99613,-9,'King Salmon, Alaska 99613',30174,37683);
INSERT INTO "django_geo_db_zipcode" VALUES(43001,99614,-9,'Kipnuk, Alaska 99614',30175,37684);
INSERT INTO "django_geo_db_zipcode" VALUES(43002,99615,-9,'Kodiak, Alaska 99615',30176,37685);
INSERT INTO "django_geo_db_zipcode" VALUES(43003,99619,-9,'Kodiak, Alaska 99619',30176,37686);
INSERT INTO "django_geo_db_zipcode" VALUES(43004,99620,-9,'Kotlik, Alaska 99620',30177,37687);
INSERT INTO "django_geo_db_zipcode" VALUES(43005,99621,-9,'Kwethluk, Alaska 99621',30178,37688);
INSERT INTO "django_geo_db_zipcode" VALUES(43006,99622,-9,'Kwigillingok, Alaska 99622',30179,37689);
INSERT INTO "django_geo_db_zipcode" VALUES(43007,99624,-9,'Larsen Bay, Alaska 99624',30180,37690);
INSERT INTO "django_geo_db_zipcode" VALUES(43008,99625,-9,'Levelock, Alaska 99625',30181,37691);
INSERT INTO "django_geo_db_zipcode" VALUES(43009,99626,-9,'Lower Kalskag, Alaska 99626',30182,37692);
INSERT INTO "django_geo_db_zipcode" VALUES(43010,99627,-9,'McGrath, Alaska 99627',30183,37693);
INSERT INTO "django_geo_db_zipcode" VALUES(43011,99628,-9,'Manokotak, Alaska 99628',30184,37694);
INSERT INTO "django_geo_db_zipcode" VALUES(43012,99630,-9,'Mekoryuk, Alaska 99630',30185,37695);
INSERT INTO "django_geo_db_zipcode" VALUES(43013,99631,-9,'Moose Pass, Alaska 99631',30186,37696);
INSERT INTO "django_geo_db_zipcode" VALUES(43014,99632,-9,'Mountain Village, Alaska 99632',30187,37697);
INSERT INTO "django_geo_db_zipcode" VALUES(43015,99633,-9,'Naknek, Alaska 99633',30188,37698);
INSERT INTO "django_geo_db_zipcode" VALUES(43016,99634,-9,'Napakiak, Alaska 99634',30189,37699);
INSERT INTO "django_geo_db_zipcode" VALUES(43017,99635,-9,'Nikiski, Alaska 99635',30190,37700);
INSERT INTO "django_geo_db_zipcode" VALUES(43018,99636,-9,'New Stuyahok, Alaska 99636',30191,37701);
INSERT INTO "django_geo_db_zipcode" VALUES(43019,99637,-9,'Toksook Bay, Alaska 99637',30192,37702);
INSERT INTO "django_geo_db_zipcode" VALUES(43020,99638,-10,'Nikolski, Alaska 99638',30193,37703);
INSERT INTO "django_geo_db_zipcode" VALUES(43021,99639,-9,'Ninilchik, Alaska 99639',30194,37704);
INSERT INTO "django_geo_db_zipcode" VALUES(43022,99640,-9,'Nondalton, Alaska 99640',30195,37705);
INSERT INTO "django_geo_db_zipcode" VALUES(43023,99641,-9,'Nunapitchuk, Alaska 99641',30196,37706);
INSERT INTO "django_geo_db_zipcode" VALUES(43024,99643,-9,'Old Harbor, Alaska 99643',30197,37707);
INSERT INTO "django_geo_db_zipcode" VALUES(43025,99644,-9,'Ouzinkie, Alaska 99644',30198,37708);
INSERT INTO "django_geo_db_zipcode" VALUES(43026,99645,-9,'Palmer, Alaska 99645',30199,37709);
INSERT INTO "django_geo_db_zipcode" VALUES(43027,99646,-9,'Palmer, Alaska 99646',30199,37710);
INSERT INTO "django_geo_db_zipcode" VALUES(43028,99647,-9,'Pedro Bay, Alaska 99647',30200,37711);
INSERT INTO "django_geo_db_zipcode" VALUES(43029,99648,-9,'Perryville, Alaska 99648',30201,37712);
INSERT INTO "django_geo_db_zipcode" VALUES(43030,99649,-9,'Pilot Point, Alaska 99649',30202,37713);
INSERT INTO "django_geo_db_zipcode" VALUES(43031,99650,-9,'Pilot Station, Alaska 99650',30203,37714);
INSERT INTO "django_geo_db_zipcode" VALUES(43032,99651,-9,'Platinum, Alaska 99651',30204,37715);
INSERT INTO "django_geo_db_zipcode" VALUES(43033,99652,-9,'Big Lake, Alaska 99652',30205,37716);
INSERT INTO "django_geo_db_zipcode" VALUES(43034,99653,-9,'Port Alsworth, Alaska 99653',30206,37717);
INSERT INTO "django_geo_db_zipcode" VALUES(43035,99654,-9,'Wasilla, Alaska 99654',30207,37718);
INSERT INTO "django_geo_db_zipcode" VALUES(43036,99655,-9,'Quinhagak, Alaska 99655',30208,37719);
INSERT INTO "django_geo_db_zipcode" VALUES(43037,99656,-9,'Red Devil, Alaska 99656',30209,37720);
INSERT INTO "django_geo_db_zipcode" VALUES(43038,99657,-9,'Russian Mission, Alaska 99657',30210,37721);
INSERT INTO "django_geo_db_zipcode" VALUES(43039,99658,-9,'Saint Marys, Alaska 99658',30211,37722);
INSERT INTO "django_geo_db_zipcode" VALUES(43040,99659,-9,'Saint Michael, Alaska 99659',30212,37723);
INSERT INTO "django_geo_db_zipcode" VALUES(43041,99660,-10,'Saint Paul Island, Alaska 99660',30213,37724);
INSERT INTO "django_geo_db_zipcode" VALUES(43042,99661,-9,'Sand Point, Alaska 99661',30214,37725);
INSERT INTO "django_geo_db_zipcode" VALUES(43043,99662,-9,'Scammon Bay, Alaska 99662',30215,37726);
INSERT INTO "django_geo_db_zipcode" VALUES(43044,99663,-9,'Seldovia, Alaska 99663',30216,37727);
INSERT INTO "django_geo_db_zipcode" VALUES(43045,99664,-9,'Seward, Alaska 99664',30217,37728);
INSERT INTO "django_geo_db_zipcode" VALUES(43046,99665,-9,'Shageluk, Alaska 99665',30218,37729);
INSERT INTO "django_geo_db_zipcode" VALUES(43047,99666,-9,'Sheldon Point, Alaska 99666',30219,37730);
INSERT INTO "django_geo_db_zipcode" VALUES(43048,99667,-9,'Skwentna, Alaska 99667',30220,37731);
INSERT INTO "django_geo_db_zipcode" VALUES(43049,99668,-9,'Sleetmute, Alaska 99668',30221,37732);
INSERT INTO "django_geo_db_zipcode" VALUES(43050,99669,-9,'Soldotna, Alaska 99669',30222,37733);
INSERT INTO "django_geo_db_zipcode" VALUES(43051,99670,-9,'South Naknek, Alaska 99670',30223,37734);
INSERT INTO "django_geo_db_zipcode" VALUES(43052,99671,-9,'Stebbins, Alaska 99671',30224,37735);
INSERT INTO "django_geo_db_zipcode" VALUES(43053,99672,-9,'Sterling, Alaska 99672',30225,37736);
INSERT INTO "django_geo_db_zipcode" VALUES(43054,99674,-9,'Sutton, Alaska 99674',30226,37737);
INSERT INTO "django_geo_db_zipcode" VALUES(43055,99675,-9,'Takotna, Alaska 99675',30227,37738);
INSERT INTO "django_geo_db_zipcode" VALUES(43056,99676,-9,'Talkeetna, Alaska 99676',30228,37739);
INSERT INTO "django_geo_db_zipcode" VALUES(43057,99677,-9,'Tatitlek, Alaska 99677',30229,37740);
INSERT INTO "django_geo_db_zipcode" VALUES(43058,99678,-9,'Togiak, Alaska 99678',30230,37741);
INSERT INTO "django_geo_db_zipcode" VALUES(43059,99679,-9,'Tuluksak, Alaska 99679',30231,37742);
INSERT INTO "django_geo_db_zipcode" VALUES(43060,99680,-9,'Tuntutuliak, Alaska 99680',30232,37743);
INSERT INTO "django_geo_db_zipcode" VALUES(43061,99681,-9,'Tununak, Alaska 99681',30233,37744);
INSERT INTO "django_geo_db_zipcode" VALUES(43062,99682,-9,'Tyonek, Alaska 99682',30234,37745);
INSERT INTO "django_geo_db_zipcode" VALUES(43063,99683,-9,'Trapper Creek, Alaska 99683',30235,37746);
INSERT INTO "django_geo_db_zipcode" VALUES(43064,99684,-9,'Unalakleet, Alaska 99684',30236,37747);
INSERT INTO "django_geo_db_zipcode" VALUES(43065,99685,-10,'Unalaska, Alaska 99685',30237,37748);
INSERT INTO "django_geo_db_zipcode" VALUES(43066,99686,-9,'Valdez, Alaska 99686',30238,37749);
INSERT INTO "django_geo_db_zipcode" VALUES(43067,99687,-9,'Wasilla, Alaska 99687',30207,37750);
INSERT INTO "django_geo_db_zipcode" VALUES(43068,99688,-9,'Willow, Alaska 99688',30239,37751);
INSERT INTO "django_geo_db_zipcode" VALUES(43069,99689,-9,'Yakutat, Alaska 99689',30240,37752);
INSERT INTO "django_geo_db_zipcode" VALUES(43070,99690,-9,'Nightmute, Alaska 99690',30241,37753);
INSERT INTO "django_geo_db_zipcode" VALUES(43071,99691,-9,'Nikolai, Alaska 99691',30242,37754);
INSERT INTO "django_geo_db_zipcode" VALUES(43072,99692,-10,'Dutch Harbor, Alaska 99692',30243,37755);
INSERT INTO "django_geo_db_zipcode" VALUES(43073,99693,-9,'Whittier, Alaska 99693',30244,37756);
INSERT INTO "django_geo_db_zipcode" VALUES(43074,99694,-9,'Houston, Alaska 99694',30245,37757);
INSERT INTO "django_geo_db_zipcode" VALUES(43075,99695,-9,'Anchorage, Alaska 99695',30117,37758);
INSERT INTO "django_geo_db_zipcode" VALUES(43076,99697,-9,'Kodiak, Alaska 99697',30176,37759);
INSERT INTO "django_geo_db_zipcode" VALUES(43077,99699,-9,'Funny River, Alaska 99699',30246,37760);
INSERT INTO "django_geo_db_zipcode" VALUES(43078,99701,-9,'Fairbanks, Alaska 99701',30247,37761);
INSERT INTO "django_geo_db_zipcode" VALUES(43079,99702,-9,'Eielson AFB, Alaska 99702',30248,37762);
INSERT INTO "django_geo_db_zipcode" VALUES(43080,99703,-9,'Fort Wainwright, Alaska 99703',30249,37763);
INSERT INTO "django_geo_db_zipcode" VALUES(43081,99704,-9,'Clear, Alaska 99704',30250,37764);
INSERT INTO "django_geo_db_zipcode" VALUES(43082,99705,-9,'North Pole, Alaska 99705',30251,37765);
INSERT INTO "django_geo_db_zipcode" VALUES(43083,99706,-9,'Fairbanks, Alaska 99706',30247,37766);
INSERT INTO "django_geo_db_zipcode" VALUES(43084,99707,-9,'Fairbanks, Alaska 99707',30247,37767);
INSERT INTO "django_geo_db_zipcode" VALUES(43085,99708,-9,'Fairbanks, Alaska 99708',30247,37768);
INSERT INTO "django_geo_db_zipcode" VALUES(43086,99709,-9,'Fairbanks, Alaska 99709',30247,37769);
INSERT INTO "django_geo_db_zipcode" VALUES(43087,99710,-9,'Fairbanks, Alaska 99710',30247,37770);
INSERT INTO "django_geo_db_zipcode" VALUES(43088,99711,-9,'Fairbanks, Alaska 99711',30247,37771);
INSERT INTO "django_geo_db_zipcode" VALUES(43089,99712,-9,'Fairbanks, Alaska 99712',30247,37772);
INSERT INTO "django_geo_db_zipcode" VALUES(43090,99714,-9,'Salcha, Alaska 99714',30252,37773);
INSERT INTO "django_geo_db_zipcode" VALUES(43091,99716,-9,'Two Rivers, Alaska 99716',30253,37774);
INSERT INTO "django_geo_db_zipcode" VALUES(43092,99720,-9,'Allakaket, Alaska 99720',30254,37775);
INSERT INTO "django_geo_db_zipcode" VALUES(43093,99721,-9,'Anaktuvuk Pass, Alaska 99721',30255,37776);
INSERT INTO "django_geo_db_zipcode" VALUES(43094,99722,-9,'Arctic Village, Alaska 99722',30256,37777);
INSERT INTO "django_geo_db_zipcode" VALUES(43095,99723,-9,'Barrow, Alaska 99723',30257,37778);
INSERT INTO "django_geo_db_zipcode" VALUES(43096,99724,-9,'Beaver, Alaska 99724',30258,37779);
INSERT INTO "django_geo_db_zipcode" VALUES(43097,99725,-9,'Ester, Alaska 99725',30259,37780);
INSERT INTO "django_geo_db_zipcode" VALUES(43098,99726,-9,'Bettles Field, Alaska 99726',30260,37781);
INSERT INTO "django_geo_db_zipcode" VALUES(43099,99727,-9,'Buckland, Alaska 99727',30261,37782);
INSERT INTO "django_geo_db_zipcode" VALUES(43100,99729,-9,'Cantwell, Alaska 99729',30262,37783);
INSERT INTO "django_geo_db_zipcode" VALUES(43101,99730,-9,'Central, Alaska 99730',30263,37784);
INSERT INTO "django_geo_db_zipcode" VALUES(43102,99732,-9,'Chicken, Alaska 99732',30264,37785);
INSERT INTO "django_geo_db_zipcode" VALUES(43103,99733,-9,'Circle, Alaska 99733',30265,37786);
INSERT INTO "django_geo_db_zipcode" VALUES(43104,99734,-9,'Prudhoe Bay, Alaska 99734',30266,37787);
INSERT INTO "django_geo_db_zipcode" VALUES(43105,99736,-9,'Deering, Alaska 99736',30267,37788);
INSERT INTO "django_geo_db_zipcode" VALUES(43106,99737,-9,'Delta Junction, Alaska 99737',30268,37789);
INSERT INTO "django_geo_db_zipcode" VALUES(43107,99738,-9,'Eagle, Alaska 99738',30269,37790);
INSERT INTO "django_geo_db_zipcode" VALUES(43108,99739,-9,'Elim, Alaska 99739',30270,37791);
INSERT INTO "django_geo_db_zipcode" VALUES(43109,99740,-9,'Fort Yukon, Alaska 99740',30271,37792);
INSERT INTO "django_geo_db_zipcode" VALUES(43110,99741,-9,'Galena, Alaska 99741',30272,37793);
INSERT INTO "django_geo_db_zipcode" VALUES(43111,99742,-9,'Gambell, Alaska 99742',30273,37794);
INSERT INTO "django_geo_db_zipcode" VALUES(43112,99743,-9,'Healy, Alaska 99743',30274,37795);
INSERT INTO "django_geo_db_zipcode" VALUES(43113,99744,-9,'Anderson, Alaska 99744',30275,37796);
INSERT INTO "django_geo_db_zipcode" VALUES(43114,99745,-9,'Hughes, Alaska 99745',30276,37797);
INSERT INTO "django_geo_db_zipcode" VALUES(43115,99746,-9,'Huslia, Alaska 99746',30277,37798);
INSERT INTO "django_geo_db_zipcode" VALUES(43116,99747,-9,'Kaktovik, Alaska 99747',30278,37799);
INSERT INTO "django_geo_db_zipcode" VALUES(43117,99748,-9,'Kaltag, Alaska 99748',30279,37800);
INSERT INTO "django_geo_db_zipcode" VALUES(43118,99749,-9,'Kiana, Alaska 99749',30280,37801);
INSERT INTO "django_geo_db_zipcode" VALUES(43119,99750,-9,'Kivalina, Alaska 99750',30281,37802);
INSERT INTO "django_geo_db_zipcode" VALUES(43120,99751,-9,'Kobuk, Alaska 99751',30282,37803);
INSERT INTO "django_geo_db_zipcode" VALUES(43121,99752,-9,'Kotzebue, Alaska 99752',30283,37804);
INSERT INTO "django_geo_db_zipcode" VALUES(43122,99753,-9,'Koyuk, Alaska 99753',30284,37805);
INSERT INTO "django_geo_db_zipcode" VALUES(43123,99754,-9,'Koyukuk, Alaska 99754',30285,37806);
INSERT INTO "django_geo_db_zipcode" VALUES(43124,99755,-9,'Denali National Park, Alaska 99755',30286,37807);
INSERT INTO "django_geo_db_zipcode" VALUES(43125,99756,-9,'Manley Hot Springs, Alaska 99756',30287,37808);
INSERT INTO "django_geo_db_zipcode" VALUES(43126,99757,-9,'Lake Minchumina, Alaska 99757',30288,37809);
INSERT INTO "django_geo_db_zipcode" VALUES(43127,99758,-9,'Minto, Alaska 99758',30289,37810);
INSERT INTO "django_geo_db_zipcode" VALUES(43128,99759,-9,'Point Lay, Alaska 99759',30290,37811);
INSERT INTO "django_geo_db_zipcode" VALUES(43129,99760,-9,'Nenana, Alaska 99760',30291,37812);
INSERT INTO "django_geo_db_zipcode" VALUES(43130,99761,-9,'Noatak, Alaska 99761',30292,37813);
INSERT INTO "django_geo_db_zipcode" VALUES(43131,99762,-9,'Nome, Alaska 99762',30293,37814);
INSERT INTO "django_geo_db_zipcode" VALUES(43132,99763,-9,'Noorvik, Alaska 99763',30294,37815);
INSERT INTO "django_geo_db_zipcode" VALUES(43133,99764,-9,'Northway, Alaska 99764',30295,37816);
INSERT INTO "django_geo_db_zipcode" VALUES(43134,99765,-9,'Nulato, Alaska 99765',30296,37817);
INSERT INTO "django_geo_db_zipcode" VALUES(43135,99766,-9,'Point Hope, Alaska 99766',30297,37818);
INSERT INTO "django_geo_db_zipcode" VALUES(43136,99767,-9,'Rampart, Alaska 99767',30298,37819);
INSERT INTO "django_geo_db_zipcode" VALUES(43137,99768,-9,'Ruby, Alaska 99768',30299,37820);
INSERT INTO "django_geo_db_zipcode" VALUES(43138,99769,-9,'Savoonga, Alaska 99769',30300,37821);
INSERT INTO "django_geo_db_zipcode" VALUES(43139,99770,-9,'Selawik, Alaska 99770',30301,37822);
INSERT INTO "django_geo_db_zipcode" VALUES(43140,99771,-9,'Shaktoolik, Alaska 99771',30302,37823);
INSERT INTO "django_geo_db_zipcode" VALUES(43141,99772,-9,'Shishmaref, Alaska 99772',30303,37824);
INSERT INTO "django_geo_db_zipcode" VALUES(43142,99773,-9,'Shungnak, Alaska 99773',30304,37825);
INSERT INTO "django_geo_db_zipcode" VALUES(43143,99774,-9,'Stevens Village, Alaska 99774',30305,37826);
INSERT INTO "django_geo_db_zipcode" VALUES(43144,99775,-9,'Fairbanks, Alaska 99775',30247,37827);
INSERT INTO "django_geo_db_zipcode" VALUES(43145,99776,-9,'Tanacross, Alaska 99776',30306,37828);
INSERT INTO "django_geo_db_zipcode" VALUES(43146,99777,-9,'Tanana, Alaska 99777',30307,37829);
INSERT INTO "django_geo_db_zipcode" VALUES(43147,99778,-9,'Teller, Alaska 99778',30308,37830);
INSERT INTO "django_geo_db_zipcode" VALUES(43148,99779,-9,'Tetlin, Alaska 99779',30309,37831);
INSERT INTO "django_geo_db_zipcode" VALUES(43149,99780,-9,'Tok, Alaska 99780',30310,37832);
INSERT INTO "django_geo_db_zipcode" VALUES(43150,99781,-9,'Venetie, Alaska 99781',30311,37833);
INSERT INTO "django_geo_db_zipcode" VALUES(43151,99782,-9,'Wainwright, Alaska 99782',30312,37834);
INSERT INTO "django_geo_db_zipcode" VALUES(43152,99783,-9,'Wales, Alaska 99783',30313,37835);
INSERT INTO "django_geo_db_zipcode" VALUES(43153,99784,-9,'White Mountain, Alaska 99784',30314,37836);
INSERT INTO "django_geo_db_zipcode" VALUES(43154,99785,-9,'Brevig Mission, Alaska 99785',30315,37837);
INSERT INTO "django_geo_db_zipcode" VALUES(43155,99786,-9,'Ambler, Alaska 99786',30316,37838);
INSERT INTO "django_geo_db_zipcode" VALUES(43156,99788,-9,'Chalkyitsik, Alaska 99788',30317,37839);
INSERT INTO "django_geo_db_zipcode" VALUES(43157,99789,-9,'Nuiqsut, Alaska 99789',30318,37840);
INSERT INTO "django_geo_db_zipcode" VALUES(43158,99790,-9,'Fairbanks, Alaska 99790',30247,37841);
INSERT INTO "django_geo_db_zipcode" VALUES(43159,99791,-9,'Atqasuk, Alaska 99791',30319,37842);
INSERT INTO "django_geo_db_zipcode" VALUES(43160,99801,-9,'Juneau, Alaska 99801',30320,37843);
INSERT INTO "django_geo_db_zipcode" VALUES(43161,99802,-9,'Juneau, Alaska 99802',30320,37844);
INSERT INTO "django_geo_db_zipcode" VALUES(43162,99803,-9,'Juneau, Alaska 99803',30320,37845);
INSERT INTO "django_geo_db_zipcode" VALUES(43163,99811,-9,'Juneau, Alaska 99811',30320,37846);
INSERT INTO "django_geo_db_zipcode" VALUES(43164,99820,-9,'Angoon, Alaska 99820',30321,37847);
INSERT INTO "django_geo_db_zipcode" VALUES(43165,99821,-9,'Auke Bay, Alaska 99821',30322,37848);
INSERT INTO "django_geo_db_zipcode" VALUES(43166,99824,-9,'Douglas, Alaska 99824',30323,37849);
INSERT INTO "django_geo_db_zipcode" VALUES(43167,99825,-9,'Elfin Cove, Alaska 99825',30324,37850);
INSERT INTO "django_geo_db_zipcode" VALUES(43168,99826,-9,'Gustavus, Alaska 99826',30325,37851);
INSERT INTO "django_geo_db_zipcode" VALUES(43169,99827,-9,'Haines, Alaska 99827',30326,37852);
INSERT INTO "django_geo_db_zipcode" VALUES(43170,99829,-9,'Hoonah, Alaska 99829',30327,37853);
INSERT INTO "django_geo_db_zipcode" VALUES(43171,99830,-9,'Kake, Alaska 99830',30328,37854);
INSERT INTO "django_geo_db_zipcode" VALUES(43172,99832,-9,'Pelican, Alaska 99832',30329,37855);
INSERT INTO "django_geo_db_zipcode" VALUES(43173,99833,-9,'Petersburg, Alaska 99833',30330,37856);
INSERT INTO "django_geo_db_zipcode" VALUES(43174,99835,-9,'Sitka, Alaska 99835',30331,37857);
INSERT INTO "django_geo_db_zipcode" VALUES(43175,99836,-9,'Port Alexander, Alaska 99836',30332,37858);
INSERT INTO "django_geo_db_zipcode" VALUES(43176,99840,-9,'Skagway, Alaska 99840',30333,37859);
INSERT INTO "django_geo_db_zipcode" VALUES(43177,99841,-9,'Tenakee Springs, Alaska 99841',30334,37860);
INSERT INTO "django_geo_db_zipcode" VALUES(43178,99850,-9,'Juneau, Alaska 99850',30320,37861);
INSERT INTO "django_geo_db_zipcode" VALUES(43179,99901,-9,'Ketchikan, Alaska 99901',30335,37862);
INSERT INTO "django_geo_db_zipcode" VALUES(43180,99903,-9,'Meyers Chuck, Alaska 99903',30336,37863);
INSERT INTO "django_geo_db_zipcode" VALUES(43181,99918,-9,'Coffman Cove, Alaska 99918',30337,37864);
INSERT INTO "django_geo_db_zipcode" VALUES(43182,99919,-9,'Thorne Bay, Alaska 99919',30338,37865);
INSERT INTO "django_geo_db_zipcode" VALUES(43183,99921,-9,'Craig, Alaska 99921',30339,37866);
INSERT INTO "django_geo_db_zipcode" VALUES(43184,99922,-9,'Hydaburg, Alaska 99922',30340,37867);
INSERT INTO "django_geo_db_zipcode" VALUES(43185,99923,-9,'Hyder, Alaska 99923',30341,37868);
INSERT INTO "django_geo_db_zipcode" VALUES(43186,99925,-9,'Klawock, Alaska 99925',30342,37869);
INSERT INTO "django_geo_db_zipcode" VALUES(43187,99926,-9,'Metlakatla, Alaska 99926',30343,37870);
INSERT INTO "django_geo_db_zipcode" VALUES(43188,99927,-9,'Point Baker, Alaska 99927',30344,37871);
INSERT INTO "django_geo_db_zipcode" VALUES(43189,99928,-9,'Ward Cove, Alaska 99928',30345,37872);
INSERT INTO "django_geo_db_zipcode" VALUES(43190,99929,-9,'Wrangell, Alaska 99929',30346,37873);
INSERT INTO "django_geo_db_zipcode" VALUES(43191,99950,-9,'Ketchikan, Alaska 99950',30335,37874);
CREATE INDEX "django_geo_db_zipcode_c7141997" ON "django_geo_db_zipcode" ("city_id");
CREATE INDEX "django_geo_db_zipcode_c2ff64a1" ON "django_geo_db_zipcode" ("geocoordinate_id");
COMMIT;
