PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE "django_geo_db_city" ("city_id" integer NOT NULL PRIMARY KEY AUTOINCREMENT, "name" varchar(50) NOT NULL, "generated_name" varchar(50) NULL, "geocoordinate_id" integer NOT NULL REFERENCES "django_geo_db_geocoordinate" ("geocoordinate_id"), "state_id" integer NOT NULL REFERENCES "django_geo_db_state" ("state_id"), UNIQUE ("state_id", "name"));
INSERT INTO "django_geo_db_city" VALUES(1,'Portsmouth','Portsmouth, New Hampshire',294,29);
INSERT INTO "django_geo_db_city" VALUES(2,'Holtsville','Holtsville, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(3,'Adjuntas','Adjuntas, Puero Rico',296,47);
INSERT INTO "django_geo_db_city" VALUES(4,'Aguada','Aguada, Puero Rico',297,47);
INSERT INTO "django_geo_db_city" VALUES(5,'Aguadilla','Aguadilla, Puero Rico',298,47);
INSERT INTO "django_geo_db_city" VALUES(6,'Maricao','Maricao, Puero Rico',301,47);
INSERT INTO "django_geo_db_city" VALUES(7,'Aguas Buenas','Aguas Buenas, Puero Rico',302,47);
INSERT INTO "django_geo_db_city" VALUES(8,'Aibonito','Aibonito, Puero Rico',303,47);
INSERT INTO "django_geo_db_city" VALUES(9,'Anasco','Anasco, Puero Rico',304,47);
INSERT INTO "django_geo_db_city" VALUES(10,'Angeles','Angeles, Puero Rico',305,47);
INSERT INTO "django_geo_db_city" VALUES(11,'Arecibo','Arecibo, Puero Rico',306,47);
INSERT INTO "django_geo_db_city" VALUES(12,'Arroyo','Arroyo, Puero Rico',309,47);
INSERT INTO "django_geo_db_city" VALUES(13,'Bajadero','Bajadero, Puero Rico',310,47);
INSERT INTO "django_geo_db_city" VALUES(14,'Barceloneta','Barceloneta, Puero Rico',311,47);
INSERT INTO "django_geo_db_city" VALUES(15,'Barranquitas','Barranquitas, Puero Rico',312,47);
INSERT INTO "django_geo_db_city" VALUES(16,'Boqueron','Boqueron, Puero Rico',313,47);
INSERT INTO "django_geo_db_city" VALUES(17,'Cabo Rojo','Cabo Rojo, Puero Rico',314,47);
INSERT INTO "django_geo_db_city" VALUES(18,'Penuelas','Penuelas, Puero Rico',315,47);
INSERT INTO "django_geo_db_city" VALUES(19,'Caguas','Caguas, Puero Rico',316,47);
INSERT INTO "django_geo_db_city" VALUES(20,'Camuy','Camuy, Puero Rico',318,47);
INSERT INTO "django_geo_db_city" VALUES(21,'Castaner','Castaner, Puero Rico',319,47);
INSERT INTO "django_geo_db_city" VALUES(22,'Cayey','Cayey, Puero Rico',320,47);
INSERT INTO "django_geo_db_city" VALUES(23,'Ceiba','Ceiba, Puero Rico',322,47);
INSERT INTO "django_geo_db_city" VALUES(24,'Rosario','Rosario, Puero Rico',323,47);
INSERT INTO "django_geo_db_city" VALUES(25,'Sabana Grande','Sabana Grande, Puero Rico',324,47);
INSERT INTO "django_geo_db_city" VALUES(26,'Ciales','Ciales, Puero Rico',325,47);
INSERT INTO "django_geo_db_city" VALUES(27,'Cidra','Cidra, Puero Rico',326,47);
INSERT INTO "django_geo_db_city" VALUES(28,'Coamo','Coamo, Puero Rico',327,47);
INSERT INTO "django_geo_db_city" VALUES(29,'Utuado','Utuado, Puero Rico',328,47);
INSERT INTO "django_geo_db_city" VALUES(30,'Corozal','Corozal, Puero Rico',329,47);
INSERT INTO "django_geo_db_city" VALUES(31,'Coto Laurel','Coto Laurel, Puero Rico',330,47);
INSERT INTO "django_geo_db_city" VALUES(32,'Culebra','Culebra, Puero Rico',331,47);
INSERT INTO "django_geo_db_city" VALUES(33,'Dorado','Dorado, Puero Rico',332,47);
INSERT INTO "django_geo_db_city" VALUES(34,'Ensenada','Ensenada, Puero Rico',333,47);
INSERT INTO "django_geo_db_city" VALUES(35,'Fajardo','Fajardo, Puero Rico',334,47);
INSERT INTO "django_geo_db_city" VALUES(36,'Florida','Florida, Puero Rico',335,47);
INSERT INTO "django_geo_db_city" VALUES(37,'Garrochales','Garrochales, Puero Rico',336,47);
INSERT INTO "django_geo_db_city" VALUES(38,'Guanica','Guanica, Puero Rico',337,47);
INSERT INTO "django_geo_db_city" VALUES(39,'Jobos','Jobos, Puero Rico',338,47);
INSERT INTO "django_geo_db_city" VALUES(40,'Olimpo','Olimpo, Puero Rico',339,47);
INSERT INTO "django_geo_db_city" VALUES(41,'Guayanilla','Guayanilla, Puero Rico',340,47);
INSERT INTO "django_geo_db_city" VALUES(42,'Gurabo','Gurabo, Puero Rico',341,47);
INSERT INTO "django_geo_db_city" VALUES(43,'Hatillo','Hatillo, Puero Rico',342,47);
INSERT INTO "django_geo_db_city" VALUES(44,'Hormigueros','Hormigueros, Puero Rico',343,47);
INSERT INTO "django_geo_db_city" VALUES(45,'Humacao','Humacao, Puero Rico',344,47);
INSERT INTO "django_geo_db_city" VALUES(46,'Isabela','Isabela, Puero Rico',345,47);
INSERT INTO "django_geo_db_city" VALUES(47,'Jayuya','Jayuya, Puero Rico',346,47);
INSERT INTO "django_geo_db_city" VALUES(48,'Ponce','Ponce, Puero Rico',347,47);
INSERT INTO "django_geo_db_city" VALUES(49,'Juncos','Juncos, Puero Rico',348,47);
INSERT INTO "django_geo_db_city" VALUES(50,'Lajas','Lajas, Puero Rico',349,47);
INSERT INTO "django_geo_db_city" VALUES(51,'Lares','Lares, Puero Rico',350,47);
INSERT INTO "django_geo_db_city" VALUES(52,'Las Marias','Las Marias, Puero Rico',351,47);
INSERT INTO "django_geo_db_city" VALUES(53,'Las Piedras','Las Piedras, Puero Rico',352,47);
INSERT INTO "django_geo_db_city" VALUES(54,'Manati','Manati, Puero Rico',353,47);
INSERT INTO "django_geo_db_city" VALUES(55,'Moca','Moca, Puero Rico',354,47);
INSERT INTO "django_geo_db_city" VALUES(56,'Rincon','Rincon, Puero Rico',355,47);
INSERT INTO "django_geo_db_city" VALUES(57,'Quebradillas','Quebradillas, Puero Rico',356,47);
INSERT INTO "django_geo_db_city" VALUES(58,'Mayaguez','Mayaguez, Puero Rico',357,47);
INSERT INTO "django_geo_db_city" VALUES(59,'San German','San German, Puero Rico',360,47);
INSERT INTO "django_geo_db_city" VALUES(60,'San Sebastian','San Sebastian, Puero Rico',361,47);
INSERT INTO "django_geo_db_city" VALUES(61,'Morovis','Morovis, Puero Rico',362,47);
INSERT INTO "django_geo_db_city" VALUES(62,'Sabana Hoyos','Sabana Hoyos, Puero Rico',363,47);
INSERT INTO "django_geo_db_city" VALUES(63,'San Antonio','San Antonio, Puero Rico',364,47);
INSERT INTO "django_geo_db_city" VALUES(64,'Vega Alta','Vega Alta, Puero Rico',365,47);
INSERT INTO "django_geo_db_city" VALUES(65,'Vega Baja','Vega Baja, Puero Rico',366,47);
INSERT INTO "django_geo_db_city" VALUES(66,'Yauco','Yauco, Puero Rico',368,47);
INSERT INTO "django_geo_db_city" VALUES(67,'Aguirre','Aguirre, Puero Rico',370,47);
INSERT INTO "django_geo_db_city" VALUES(68,'Maunabo','Maunabo, Puero Rico',372,47);
INSERT INTO "django_geo_db_city" VALUES(69,'Mercedita','Mercedita, Puero Rico',374,47);
INSERT INTO "django_geo_db_city" VALUES(70,'Naguabo','Naguabo, Puero Rico',377,47);
INSERT INTO "django_geo_db_city" VALUES(71,'Naranjito','Naranjito, Puero Rico',378,47);
INSERT INTO "django_geo_db_city" VALUES(72,'Orocovis','Orocovis, Puero Rico',379,47);
INSERT INTO "django_geo_db_city" VALUES(73,'Palmer','Palmer, Puero Rico',380,47);
INSERT INTO "django_geo_db_city" VALUES(74,'Patillas','Patillas, Puero Rico',381,47);
INSERT INTO "django_geo_db_city" VALUES(75,'Canovanas','Canovanas, Puero Rico',385,47);
INSERT INTO "django_geo_db_city" VALUES(76,'Puerto Real','Puerto Real, Puero Rico',396,47);
INSERT INTO "django_geo_db_city" VALUES(77,'Punta Santiago','Punta Santiago, Puero Rico',397,47);
INSERT INTO "django_geo_db_city" VALUES(78,'Roosevelt Roads','Roosevelt Roads, Puero Rico',398,47);
INSERT INTO "django_geo_db_city" VALUES(79,'Rio Blanco','Rio Blanco, Puero Rico',399,47);
INSERT INTO "django_geo_db_city" VALUES(80,'Rio Grande','Rio Grande, Puero Rico',400,47);
INSERT INTO "django_geo_db_city" VALUES(81,'Lluveras','Lluveras, Puero Rico',401,47);
INSERT INTO "django_geo_db_city" VALUES(82,'Salinas','Salinas, Puero Rico',403,47);
INSERT INTO "django_geo_db_city" VALUES(83,'San Lorenzo','San Lorenzo, Puero Rico',405,47);
INSERT INTO "django_geo_db_city" VALUES(84,'Santa Isabel','Santa Isabel, Puero Rico',406,47);
INSERT INTO "django_geo_db_city" VALUES(85,'Monserrate','Monserrate, Puero Rico',409,47);
INSERT INTO "django_geo_db_city" VALUES(86,'Vieques','Vieques, Puero Rico',411,47);
INSERT INTO "django_geo_db_city" VALUES(87,'Villalba','Villalba, Puero Rico',412,47);
INSERT INTO "django_geo_db_city" VALUES(88,'Yabucoa','Yabucoa, Puero Rico',413,47);
INSERT INTO "django_geo_db_city" VALUES(89,'Loiza','Loiza, Puero Rico',417,47);
INSERT INTO "django_geo_db_city" VALUES(90,'Luquillo','Luquillo, Puero Rico',418,47);
INSERT INTO "django_geo_db_city" VALUES(91,'Comerio','Comerio, Puero Rico',423,47);
INSERT INTO "django_geo_db_city" VALUES(92,'Guayama','Guayama, Puero Rico',425,47);
INSERT INTO "django_geo_db_city" VALUES(93,'La Plata','La Plata, Puero Rico',427,47);
INSERT INTO "django_geo_db_city" VALUES(94,'Juana Diaz','Juana Diaz, Puero Rico',431,47);
INSERT INTO "django_geo_db_city" VALUES(95,'St Thomas','St Thomas, Saint Thomas',432,55);
INSERT INTO "django_geo_db_city" VALUES(96,'Christiansted','Christiansted, Saint Thomas',433,55);
INSERT INTO "django_geo_db_city" VALUES(97,'St John','St John, Saint Thomas',434,55);
INSERT INTO "django_geo_db_city" VALUES(98,'Frederiksted','Frederiksted, Saint Thomas',433,55);
INSERT INTO "django_geo_db_city" VALUES(99,'Kingshill','Kingshill, Saint Thomas',433,55);
INSERT INTO "django_geo_db_city" VALUES(100,'San Juan','San Juan, Puero Rico',435,47);
INSERT INTO "django_geo_db_city" VALUES(101,'Fort Buchanan','Fort Buchanan, Puero Rico',453,47);
INSERT INTO "django_geo_db_city" VALUES(102,'Toa Baja','Toa Baja, Puero Rico',454,47);
INSERT INTO "django_geo_db_city" VALUES(103,'Sabana Seca','Sabana Seca, Puero Rico',456,47);
INSERT INTO "django_geo_db_city" VALUES(104,'Toa Alta','Toa Alta, Puero Rico',457,47);
INSERT INTO "django_geo_db_city" VALUES(105,'Bayamon','Bayamon, Puero Rico',459,47);
INSERT INTO "django_geo_db_city" VALUES(106,'Catano','Catano, Puero Rico',464,47);
INSERT INTO "django_geo_db_city" VALUES(107,'Guaynabo','Guaynabo, Puero Rico',466,47);
INSERT INTO "django_geo_db_city" VALUES(108,'Trujillo Alto','Trujillo Alto, Puero Rico',472,47);
INSERT INTO "django_geo_db_city" VALUES(109,'St Just','St Just, Puero Rico',473,47);
INSERT INTO "django_geo_db_city" VALUES(110,'Carolina','Carolina, Puero Rico',474,47);
INSERT INTO "django_geo_db_city" VALUES(111,'Agawam','Agawam, Massachusetts',480,39);
INSERT INTO "django_geo_db_city" VALUES(112,'Amherst','Amherst, Massachusetts',481,39);
INSERT INTO "django_geo_db_city" VALUES(113,'Barre','Barre, Massachusetts',484,39);
INSERT INTO "django_geo_db_city" VALUES(114,'Belchertown','Belchertown, Massachusetts',485,39);
INSERT INTO "django_geo_db_city" VALUES(115,'Blandford','Blandford, Massachusetts',486,39);
INSERT INTO "django_geo_db_city" VALUES(116,'Bondsville','Bondsville, Massachusetts',487,39);
INSERT INTO "django_geo_db_city" VALUES(117,'Brimfield','Brimfield, Massachusetts',488,39);
INSERT INTO "django_geo_db_city" VALUES(118,'Chester','Chester, Massachusetts',489,39);
INSERT INTO "django_geo_db_city" VALUES(119,'Chesterfield','Chesterfield, Massachusetts',490,39);
INSERT INTO "django_geo_db_city" VALUES(120,'Chicopee','Chicopee, Massachusetts',491,39);
INSERT INTO "django_geo_db_city" VALUES(121,'Cummington','Cummington, Massachusetts',495,39);
INSERT INTO "django_geo_db_city" VALUES(122,'Easthampton','Easthampton, Massachusetts',496,39);
INSERT INTO "django_geo_db_city" VALUES(123,'East Longmeadow','East Longmeadow, Massachusetts',497,39);
INSERT INTO "django_geo_db_city" VALUES(124,'East Otis','East Otis, Massachusetts',498,39);
INSERT INTO "django_geo_db_city" VALUES(125,'Feeding Hills','Feeding Hills, Massachusetts',499,39);
INSERT INTO "django_geo_db_city" VALUES(126,'Gilbertville','Gilbertville, Massachusetts',500,39);
INSERT INTO "django_geo_db_city" VALUES(127,'Goshen','Goshen, Massachusetts',501,39);
INSERT INTO "django_geo_db_city" VALUES(128,'Granby','Granby, Massachusetts',502,39);
INSERT INTO "django_geo_db_city" VALUES(129,'Granville','Granville, Massachusetts',503,39);
INSERT INTO "django_geo_db_city" VALUES(130,'Hadley','Hadley, Massachusetts',504,39);
INSERT INTO "django_geo_db_city" VALUES(131,'Hampden','Hampden, Massachusetts',505,39);
INSERT INTO "django_geo_db_city" VALUES(132,'Hardwick','Hardwick, Massachusetts',506,39);
INSERT INTO "django_geo_db_city" VALUES(133,'Hatfield','Hatfield, Massachusetts',507,39);
INSERT INTO "django_geo_db_city" VALUES(134,'Haydenville','Haydenville, Massachusetts',508,39);
INSERT INTO "django_geo_db_city" VALUES(135,'Holyoke','Holyoke, Massachusetts',509,39);
INSERT INTO "django_geo_db_city" VALUES(136,'Huntington','Huntington, Massachusetts',510,39);
INSERT INTO "django_geo_db_city" VALUES(137,'Leeds','Leeds, Massachusetts',511,39);
INSERT INTO "django_geo_db_city" VALUES(138,'Leverett','Leverett, Massachusetts',512,39);
INSERT INTO "django_geo_db_city" VALUES(139,'Ludlow','Ludlow, Massachusetts',513,39);
INSERT INTO "django_geo_db_city" VALUES(140,'Monson','Monson, Massachusetts',514,39);
INSERT INTO "django_geo_db_city" VALUES(141,'North Amherst','North Amherst, Massachusetts',482,39);
INSERT INTO "django_geo_db_city" VALUES(142,'Northampton','Northampton, Massachusetts',515,39);
INSERT INTO "django_geo_db_city" VALUES(143,'Florence','Florence, Massachusetts',516,39);
INSERT INTO "django_geo_db_city" VALUES(144,'North Hatfield','North Hatfield, Massachusetts',518,39);
INSERT INTO "django_geo_db_city" VALUES(145,'Oakham','Oakham, Massachusetts',519,39);
INSERT INTO "django_geo_db_city" VALUES(146,'Palmer','Palmer, Massachusetts',520,39);
INSERT INTO "django_geo_db_city" VALUES(147,'Plainfield','Plainfield, Massachusetts',521,39);
INSERT INTO "django_geo_db_city" VALUES(148,'Russell','Russell, Massachusetts',522,39);
INSERT INTO "django_geo_db_city" VALUES(149,'Shutesbury','Shutesbury, Massachusetts',523,39);
INSERT INTO "django_geo_db_city" VALUES(150,'Southampton','Southampton, Massachusetts',524,39);
INSERT INTO "django_geo_db_city" VALUES(151,'South Barre','South Barre, Massachusetts',525,39);
INSERT INTO "django_geo_db_city" VALUES(152,'South Hadley','South Hadley, Massachusetts',526,39);
INSERT INTO "django_geo_db_city" VALUES(153,'Southwick','Southwick, Massachusetts',527,39);
INSERT INTO "django_geo_db_city" VALUES(154,'Thorndike','Thorndike, Massachusetts',528,39);
INSERT INTO "django_geo_db_city" VALUES(155,'Three Rivers','Three Rivers, Massachusetts',529,39);
INSERT INTO "django_geo_db_city" VALUES(156,'Wales','Wales, Massachusetts',530,39);
INSERT INTO "django_geo_db_city" VALUES(157,'Ware','Ware, Massachusetts',531,39);
INSERT INTO "django_geo_db_city" VALUES(158,'Warren','Warren, Massachusetts',532,39);
INSERT INTO "django_geo_db_city" VALUES(159,'West Chesterfield','West Chesterfield, Massachusetts',533,39);
INSERT INTO "django_geo_db_city" VALUES(160,'Westfield','Westfield, Massachusetts',534,39);
INSERT INTO "django_geo_db_city" VALUES(161,'West Hatfield','West Hatfield, Massachusetts',536,39);
INSERT INTO "django_geo_db_city" VALUES(162,'West Springfield','West Springfield, Massachusetts',537,39);
INSERT INTO "django_geo_db_city" VALUES(163,'West Warren','West Warren, Massachusetts',538,39);
INSERT INTO "django_geo_db_city" VALUES(164,'Whately','Whately, Massachusetts',539,39);
INSERT INTO "django_geo_db_city" VALUES(165,'Wheelwright','Wheelwright, Massachusetts',540,39);
INSERT INTO "django_geo_db_city" VALUES(166,'Wilbraham','Wilbraham, Massachusetts',541,39);
INSERT INTO "django_geo_db_city" VALUES(167,'Williamsburg','Williamsburg, Massachusetts',542,39);
INSERT INTO "django_geo_db_city" VALUES(168,'Woronoco','Woronoco, Massachusetts',543,39);
INSERT INTO "django_geo_db_city" VALUES(169,'Worthington','Worthington, Massachusetts',544,39);
INSERT INTO "django_geo_db_city" VALUES(170,'Springfield','Springfield, Massachusetts',492,39);
INSERT INTO "django_geo_db_city" VALUES(171,'Longmeadow','Longmeadow, Massachusetts',548,39);
INSERT INTO "django_geo_db_city" VALUES(172,'Indian Orchard','Indian Orchard, Massachusetts',558,39);
INSERT INTO "django_geo_db_city" VALUES(173,'Pittsfield','Pittsfield, Massachusetts',560,39);
INSERT INTO "django_geo_db_city" VALUES(174,'Adams','Adams, Massachusetts',562,39);
INSERT INTO "django_geo_db_city" VALUES(175,'Ashley Falls','Ashley Falls, Massachusetts',563,39);
INSERT INTO "django_geo_db_city" VALUES(176,'Becket','Becket, Massachusetts',564,39);
INSERT INTO "django_geo_db_city" VALUES(177,'Berkshire','Berkshire, Massachusetts',561,39);
INSERT INTO "django_geo_db_city" VALUES(178,'Cheshire','Cheshire, Massachusetts',565,39);
INSERT INTO "django_geo_db_city" VALUES(179,'Dalton','Dalton, Massachusetts',566,39);
INSERT INTO "django_geo_db_city" VALUES(180,'Glendale','Glendale, Massachusetts',568,39);
INSERT INTO "django_geo_db_city" VALUES(181,'Great Barrington','Great Barrington, Massachusetts',569,39);
INSERT INTO "django_geo_db_city" VALUES(182,'Sheffield','Sheffield, Massachusetts',570,39);
INSERT INTO "django_geo_db_city" VALUES(183,'Hinsdale','Hinsdale, Massachusetts',571,39);
INSERT INTO "django_geo_db_city" VALUES(184,'Housatonic','Housatonic, Massachusetts',572,39);
INSERT INTO "django_geo_db_city" VALUES(185,'Lanesboro','Lanesboro, Massachusetts',573,39);
INSERT INTO "django_geo_db_city" VALUES(186,'Lee','Lee, Massachusetts',574,39);
INSERT INTO "django_geo_db_city" VALUES(187,'Lenox','Lenox, Massachusetts',575,39);
INSERT INTO "django_geo_db_city" VALUES(188,'Lenox Dale','Lenox Dale, Massachusetts',576,39);
INSERT INTO "django_geo_db_city" VALUES(189,'Middlefield','Middlefield, Massachusetts',577,39);
INSERT INTO "django_geo_db_city" VALUES(190,'Mill River','Mill River, Massachusetts',578,39);
INSERT INTO "django_geo_db_city" VALUES(191,'Monterey','Monterey, Massachusetts',579,39);
INSERT INTO "django_geo_db_city" VALUES(192,'North Adams','North Adams, Massachusetts',580,39);
INSERT INTO "django_geo_db_city" VALUES(193,'North Egremont','North Egremont, Massachusetts',581,39);
INSERT INTO "django_geo_db_city" VALUES(194,'Otis','Otis, Massachusetts',582,39);
INSERT INTO "django_geo_db_city" VALUES(195,'Richmond','Richmond, Massachusetts',583,39);
INSERT INTO "django_geo_db_city" VALUES(196,'Sandisfield','Sandisfield, Massachusetts',584,39);
INSERT INTO "django_geo_db_city" VALUES(197,'Savoy','Savoy, Massachusetts',585,39);
INSERT INTO "django_geo_db_city" VALUES(198,'South Egremont','South Egremont, Massachusetts',587,39);
INSERT INTO "django_geo_db_city" VALUES(199,'Southfield','Southfield, Massachusetts',588,39);
INSERT INTO "django_geo_db_city" VALUES(200,'South Lee','South Lee, Massachusetts',589,39);
INSERT INTO "django_geo_db_city" VALUES(201,'Stockbridge','Stockbridge, Massachusetts',590,39);
INSERT INTO "django_geo_db_city" VALUES(202,'Tyringham','Tyringham, Massachusetts',591,39);
INSERT INTO "django_geo_db_city" VALUES(203,'West Stockbridge','West Stockbridge, Massachusetts',592,39);
INSERT INTO "django_geo_db_city" VALUES(204,'Williamstown','Williamstown, Massachusetts',593,39);
INSERT INTO "django_geo_db_city" VALUES(205,'Windsor','Windsor, Massachusetts',594,39);
INSERT INTO "django_geo_db_city" VALUES(206,'Greenfield','Greenfield, Massachusetts',595,39);
INSERT INTO "django_geo_db_city" VALUES(207,'Ashfield','Ashfield, Massachusetts',597,39);
INSERT INTO "django_geo_db_city" VALUES(208,'Athol','Athol, Massachusetts',598,39);
INSERT INTO "django_geo_db_city" VALUES(209,'Bernardston','Bernardston, Massachusetts',599,39);
INSERT INTO "django_geo_db_city" VALUES(210,'Buckland','Buckland, Massachusetts',600,39);
INSERT INTO "django_geo_db_city" VALUES(211,'Charlemont','Charlemont, Massachusetts',601,39);
INSERT INTO "django_geo_db_city" VALUES(212,'Colrain','Colrain, Massachusetts',602,39);
INSERT INTO "django_geo_db_city" VALUES(213,'Conway','Conway, Massachusetts',603,39);
INSERT INTO "django_geo_db_city" VALUES(214,'Deerfield','Deerfield, Massachusetts',604,39);
INSERT INTO "django_geo_db_city" VALUES(215,'Drury','Drury, Massachusetts',605,39);
INSERT INTO "django_geo_db_city" VALUES(216,'Erving','Erving, Massachusetts',606,39);
INSERT INTO "django_geo_db_city" VALUES(217,'Heath','Heath, Massachusetts',607,39);
INSERT INTO "django_geo_db_city" VALUES(218,'Lake Pleasant','Lake Pleasant, Massachusetts',608,39);
INSERT INTO "django_geo_db_city" VALUES(219,'Turners Falls','Turners Falls, Massachusetts',609,39);
INSERT INTO "django_geo_db_city" VALUES(220,'Monroe Bridge','Monroe Bridge, Massachusetts',610,39);
INSERT INTO "django_geo_db_city" VALUES(221,'Montague','Montague, Massachusetts',611,39);
INSERT INTO "django_geo_db_city" VALUES(222,'Northfield','Northfield, Massachusetts',596,39);
INSERT INTO "django_geo_db_city" VALUES(223,'New Salem','New Salem, Massachusetts',612,39);
INSERT INTO "django_geo_db_city" VALUES(224,'Orange','Orange, Massachusetts',614,39);
INSERT INTO "django_geo_db_city" VALUES(225,'Petersham','Petersham, Massachusetts',615,39);
INSERT INTO "django_geo_db_city" VALUES(226,'Rowe','Rowe, Massachusetts',616,39);
INSERT INTO "django_geo_db_city" VALUES(227,'Royalston','Royalston, Massachusetts',617,39);
INSERT INTO "django_geo_db_city" VALUES(228,'Shattuckville','Shattuckville, Massachusetts',596,39);
INSERT INTO "django_geo_db_city" VALUES(229,'Shelburne Falls','Shelburne Falls, Massachusetts',618,39);
INSERT INTO "django_geo_db_city" VALUES(230,'South Deerfield','South Deerfield, Massachusetts',619,39);
INSERT INTO "django_geo_db_city" VALUES(231,'Sunderland','Sunderland, Massachusetts',621,39);
INSERT INTO "django_geo_db_city" VALUES(232,'Warwick','Warwick, Massachusetts',623,39);
INSERT INTO "django_geo_db_city" VALUES(233,'Wendell','Wendell, Massachusetts',624,39);
INSERT INTO "django_geo_db_city" VALUES(234,'Wendell Depot','Wendell Depot, Massachusetts',625,39);
INSERT INTO "django_geo_db_city" VALUES(235,'Fitchburg','Fitchburg, Massachusetts',627,39);
INSERT INTO "django_geo_db_city" VALUES(236,'Westborough','Westborough, Massachusetts',628,39);
INSERT INTO "django_geo_db_city" VALUES(237,'Ashburnham','Ashburnham, Massachusetts',629,39);
INSERT INTO "django_geo_db_city" VALUES(238,'Ashby','Ashby, Massachusetts',630,39);
INSERT INTO "django_geo_db_city" VALUES(239,'Ayer','Ayer, Massachusetts',631,39);
INSERT INTO "django_geo_db_city" VALUES(240,'Baldwinville','Baldwinville, Massachusetts',632,39);
INSERT INTO "django_geo_db_city" VALUES(241,'East Templeton','East Templeton, Massachusetts',633,39);
INSERT INTO "django_geo_db_city" VALUES(242,'Gardner','Gardner, Massachusetts',634,39);
INSERT INTO "django_geo_db_city" VALUES(243,'Groton','Groton, Massachusetts',636,39);
INSERT INTO "django_geo_db_city" VALUES(244,'Harvard','Harvard, Massachusetts',637,39);
INSERT INTO "django_geo_db_city" VALUES(245,'Hubbardston','Hubbardston, Massachusetts',638,39);
INSERT INTO "django_geo_db_city" VALUES(246,'Leominster','Leominster, Massachusetts',639,39);
INSERT INTO "django_geo_db_city" VALUES(247,'Littleton','Littleton, Massachusetts',640,39);
INSERT INTO "django_geo_db_city" VALUES(248,'Lunenburg','Lunenburg, Massachusetts',641,39);
INSERT INTO "django_geo_db_city" VALUES(249,'Pepperell','Pepperell, Massachusetts',642,39);
INSERT INTO "django_geo_db_city" VALUES(250,'Shirley','Shirley, Massachusetts',643,39);
INSERT INTO "django_geo_db_city" VALUES(251,'Still River','Still River, Massachusetts',644,39);
INSERT INTO "django_geo_db_city" VALUES(252,'Templeton','Templeton, Massachusetts',645,39);
INSERT INTO "django_geo_db_city" VALUES(253,'Townsend','Townsend, Massachusetts',646,39);
INSERT INTO "django_geo_db_city" VALUES(254,'West Groton','West Groton, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(255,'Westminster','Westminster, Massachusetts',648,39);
INSERT INTO "django_geo_db_city" VALUES(256,'West Townsend','West Townsend, Massachusetts',649,39);
INSERT INTO "django_geo_db_city" VALUES(257,'Winchendon','Winchendon, Massachusetts',650,39);
INSERT INTO "django_geo_db_city" VALUES(258,'Winchendon Springs','Winchendon Springs, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(259,'Auburn','Auburn, Massachusetts',651,39);
INSERT INTO "django_geo_db_city" VALUES(260,'Berlin','Berlin, Massachusetts',652,39);
INSERT INTO "django_geo_db_city" VALUES(261,'Blackstone','Blackstone, Massachusetts',653,39);
INSERT INTO "django_geo_db_city" VALUES(262,'Boylston','Boylston, Massachusetts',654,39);
INSERT INTO "django_geo_db_city" VALUES(263,'Brookfield','Brookfield, Massachusetts',655,39);
INSERT INTO "django_geo_db_city" VALUES(264,'Charlton','Charlton, Massachusetts',656,39);
INSERT INTO "django_geo_db_city" VALUES(265,'Charlton City','Charlton City, Massachusetts',657,39);
INSERT INTO "django_geo_db_city" VALUES(266,'Charlton Depot','Charlton Depot, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(267,'Clinton','Clinton, Massachusetts',658,39);
INSERT INTO "django_geo_db_city" VALUES(268,'East Brookfield','East Brookfield, Massachusetts',659,39);
INSERT INTO "django_geo_db_city" VALUES(269,'Douglas','Douglas, Massachusetts',660,39);
INSERT INTO "django_geo_db_city" VALUES(270,'East Princeton','East Princeton, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(271,'Fiskdale','Fiskdale, Massachusetts',661,39);
INSERT INTO "django_geo_db_city" VALUES(272,'Grafton','Grafton, Massachusetts',662,39);
INSERT INTO "django_geo_db_city" VALUES(273,'Holden','Holden, Massachusetts',663,39);
INSERT INTO "django_geo_db_city" VALUES(274,'Holland','Holland, Massachusetts',664,39);
INSERT INTO "django_geo_db_city" VALUES(275,'Jefferson','Jefferson, Massachusetts',665,39);
INSERT INTO "django_geo_db_city" VALUES(276,'Lancaster','Lancaster, Massachusetts',666,39);
INSERT INTO "django_geo_db_city" VALUES(277,'Leicester','Leicester, Massachusetts',667,39);
INSERT INTO "django_geo_db_city" VALUES(278,'Linwood','Linwood, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(279,'Manchaug','Manchaug, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(280,'Millbury','Millbury, Massachusetts',668,39);
INSERT INTO "django_geo_db_city" VALUES(281,'Millville','Millville, Massachusetts',669,39);
INSERT INTO "django_geo_db_city" VALUES(282,'New Braintree','New Braintree, Massachusetts',670,39);
INSERT INTO "django_geo_db_city" VALUES(283,'Northborough','Northborough, Massachusetts',671,39);
INSERT INTO "django_geo_db_city" VALUES(284,'Northbridge','Northbridge, Massachusetts',672,39);
INSERT INTO "django_geo_db_city" VALUES(285,'North Brookfield','North Brookfield, Massachusetts',673,39);
INSERT INTO "django_geo_db_city" VALUES(286,'North Grafton','North Grafton, Massachusetts',674,39);
INSERT INTO "django_geo_db_city" VALUES(287,'North Oxford','North Oxford, Massachusetts',675,39);
INSERT INTO "django_geo_db_city" VALUES(288,'North Uxbridge','North Uxbridge, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(289,'Oxford','Oxford, Massachusetts',676,39);
INSERT INTO "django_geo_db_city" VALUES(290,'Princeton','Princeton, Massachusetts',677,39);
INSERT INTO "django_geo_db_city" VALUES(291,'Rochdale','Rochdale, Massachusetts',678,39);
INSERT INTO "django_geo_db_city" VALUES(292,'Rutland','Rutland, Massachusetts',679,39);
INSERT INTO "django_geo_db_city" VALUES(293,'Shrewsbury','Shrewsbury, Massachusetts',680,39);
INSERT INTO "django_geo_db_city" VALUES(294,'Southbridge','Southbridge, Massachusetts',681,39);
INSERT INTO "django_geo_db_city" VALUES(295,'South Grafton','South Grafton, Massachusetts',682,39);
INSERT INTO "django_geo_db_city" VALUES(296,'South Lancaster','South Lancaster, Massachusetts',683,39);
INSERT INTO "django_geo_db_city" VALUES(297,'Spencer','Spencer, Massachusetts',684,39);
INSERT INTO "django_geo_db_city" VALUES(298,'Sterling','Sterling, Massachusetts',685,39);
INSERT INTO "django_geo_db_city" VALUES(299,'Sturbridge','Sturbridge, Massachusetts',686,39);
INSERT INTO "django_geo_db_city" VALUES(300,'Upton','Upton, Massachusetts',687,39);
INSERT INTO "django_geo_db_city" VALUES(301,'Uxbridge','Uxbridge, Massachusetts',688,39);
INSERT INTO "django_geo_db_city" VALUES(302,'Webster','Webster, Massachusetts',689,39);
INSERT INTO "django_geo_db_city" VALUES(303,'Dudley','Dudley, Massachusetts',690,39);
INSERT INTO "django_geo_db_city" VALUES(304,'West Boylston','West Boylston, Massachusetts',692,39);
INSERT INTO "django_geo_db_city" VALUES(305,'West Brookfield','West Brookfield, Massachusetts',693,39);
INSERT INTO "django_geo_db_city" VALUES(306,'West Millbury','West Millbury, Massachusetts',635,39);
INSERT INTO "django_geo_db_city" VALUES(307,'Whitinsville','Whitinsville, Massachusetts',694,39);
INSERT INTO "django_geo_db_city" VALUES(308,'Sutton','Sutton, Massachusetts',695,39);
INSERT INTO "django_geo_db_city" VALUES(309,'Worcester','Worcester, Massachusetts',696,39);
INSERT INTO "django_geo_db_city" VALUES(310,'Cherry Valley','Cherry Valley, Massachusetts',706,39);
INSERT INTO "django_geo_db_city" VALUES(311,'Paxton','Paxton, Massachusetts',707,39);
INSERT INTO "django_geo_db_city" VALUES(312,'Tolland','Tolland, Massachusetts',709,39);
INSERT INTO "django_geo_db_city" VALUES(313,'Framingham','Framingham, Massachusetts',710,39);
INSERT INTO "django_geo_db_city" VALUES(314,'Village Of Nagog Woods','Village Of Nagog Woods, Massachusetts',712,39);
INSERT INTO "django_geo_db_city" VALUES(315,'Boxborough','Boxborough, Massachusetts',713,39);
INSERT INTO "django_geo_db_city" VALUES(316,'Acton','Acton, Massachusetts',714,39);
INSERT INTO "django_geo_db_city" VALUES(317,'Ashland','Ashland, Massachusetts',715,39);
INSERT INTO "django_geo_db_city" VALUES(318,'Bedford','Bedford, Massachusetts',716,39);
INSERT INTO "django_geo_db_city" VALUES(319,'Hanscom AFB','Hanscom AFB, Massachusetts',717,39);
INSERT INTO "django_geo_db_city" VALUES(320,'Bolton','Bolton, Massachusetts',718,39);
INSERT INTO "django_geo_db_city" VALUES(321,'Carlisle','Carlisle, Massachusetts',719,39);
INSERT INTO "django_geo_db_city" VALUES(322,'Concord','Concord, Massachusetts',720,39);
INSERT INTO "django_geo_db_city" VALUES(323,'Fayville','Fayville, Massachusetts',721,39);
INSERT INTO "django_geo_db_city" VALUES(324,'Holliston','Holliston, Massachusetts',722,39);
INSERT INTO "django_geo_db_city" VALUES(325,'Hopedale','Hopedale, Massachusetts',723,39);
INSERT INTO "django_geo_db_city" VALUES(326,'Hopkinton','Hopkinton, Massachusetts',724,39);
INSERT INTO "django_geo_db_city" VALUES(327,'Hudson','Hudson, Massachusetts',725,39);
INSERT INTO "django_geo_db_city" VALUES(328,'Natick','Natick, Massachusetts',726,39);
INSERT INTO "django_geo_db_city" VALUES(329,'Marlborough','Marlborough, Massachusetts',727,39);
INSERT INTO "django_geo_db_city" VALUES(330,'Maynard','Maynard, Massachusetts',728,39);
INSERT INTO "django_geo_db_city" VALUES(331,'Mendon','Mendon, Massachusetts',729,39);
INSERT INTO "django_geo_db_city" VALUES(332,'Milford','Milford, Massachusetts',730,39);
INSERT INTO "django_geo_db_city" VALUES(333,'Sherborn','Sherborn, Massachusetts',732,39);
INSERT INTO "django_geo_db_city" VALUES(334,'Southborough','Southborough, Massachusetts',733,39);
INSERT INTO "django_geo_db_city" VALUES(335,'Lincoln','Lincoln, Massachusetts',734,39);
INSERT INTO "django_geo_db_city" VALUES(336,'Stow','Stow, Massachusetts',735,39);
INSERT INTO "django_geo_db_city" VALUES(337,'Sudbury','Sudbury, Massachusetts',736,39);
INSERT INTO "django_geo_db_city" VALUES(338,'Wayland','Wayland, Massachusetts',737,39);
INSERT INTO "django_geo_db_city" VALUES(339,'Woodville','Woodville, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(340,'Woburn','Woburn, Massachusetts',738,39);
INSERT INTO "django_geo_db_city" VALUES(341,'Burlington','Burlington, Massachusetts',739,39);
INSERT INTO "django_geo_db_city" VALUES(342,'Andover','Andover, Massachusetts',740,39);
INSERT INTO "django_geo_db_city" VALUES(343,'Pinehurst','Pinehurst, Massachusetts',742,39);
INSERT INTO "django_geo_db_city" VALUES(344,'Billerica','Billerica, Massachusetts',743,39);
INSERT INTO "django_geo_db_city" VALUES(345,'Haverhill','Haverhill, Massachusetts',744,39);
INSERT INTO "django_geo_db_city" VALUES(346,'Chelmsford','Chelmsford, Massachusetts',745,39);
INSERT INTO "django_geo_db_city" VALUES(347,'Dracut','Dracut, Massachusetts',746,39);
INSERT INTO "django_geo_db_city" VALUES(348,'Dunstable','Dunstable, Massachusetts',747,39);
INSERT INTO "django_geo_db_city" VALUES(349,'Georgetown','Georgetown, Massachusetts',751,39);
INSERT INTO "django_geo_db_city" VALUES(350,'Groveland','Groveland, Massachusetts',752,39);
INSERT INTO "django_geo_db_city" VALUES(351,'Lawrence','Lawrence, Massachusetts',754,39);
INSERT INTO "django_geo_db_city" VALUES(352,'Methuen','Methuen, Massachusetts',758,39);
INSERT INTO "django_geo_db_city" VALUES(353,'North Andover','North Andover, Massachusetts',759,39);
INSERT INTO "django_geo_db_city" VALUES(354,'Lowell','Lowell, Massachusetts',760,39);
INSERT INTO "django_geo_db_city" VALUES(355,'Merrimac','Merrimac, Massachusetts',765,39);
INSERT INTO "django_geo_db_city" VALUES(356,'North Billerica','North Billerica, Massachusetts',766,39);
INSERT INTO "django_geo_db_city" VALUES(357,'North Chelmsford','North Chelmsford, Massachusetts',767,39);
INSERT INTO "django_geo_db_city" VALUES(358,'North Reading','North Reading, Massachusetts',768,39);
INSERT INTO "django_geo_db_city" VALUES(359,'Nutting Lake','Nutting Lake, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(360,'Reading','Reading, Massachusetts',769,39);
INSERT INTO "django_geo_db_city" VALUES(361,'Tewksbury','Tewksbury, Massachusetts',770,39);
INSERT INTO "django_geo_db_city" VALUES(362,'Tyngsboro','Tyngsboro, Massachusetts',771,39);
INSERT INTO "django_geo_db_city" VALUES(363,'Wakefield','Wakefield, Massachusetts',772,39);
INSERT INTO "django_geo_db_city" VALUES(364,'West Boxford','West Boxford, Massachusetts',756,39);
INSERT INTO "django_geo_db_city" VALUES(365,'Westford','Westford, Massachusetts',773,39);
INSERT INTO "django_geo_db_city" VALUES(366,'Wilmington','Wilmington, Massachusetts',774,39);
INSERT INTO "django_geo_db_city" VALUES(367,'Winchester','Winchester, Massachusetts',776,39);
INSERT INTO "django_geo_db_city" VALUES(368,'Lynn','Lynn, Massachusetts',777,39);
INSERT INTO "django_geo_db_city" VALUES(369,'Saugus','Saugus, Massachusetts',781,39);
INSERT INTO "django_geo_db_city" VALUES(370,'Swampscott','Swampscott, Massachusetts',782,39);
INSERT INTO "django_geo_db_city" VALUES(371,'Nahant','Nahant, Massachusetts',783,39);
INSERT INTO "django_geo_db_city" VALUES(372,'Amesbury','Amesbury, Massachusetts',785,39);
INSERT INTO "django_geo_db_city" VALUES(373,'Beverly','Beverly, Massachusetts',786,39);
INSERT INTO "django_geo_db_city" VALUES(374,'Boxford','Boxford, Massachusetts',787,39);
INSERT INTO "django_geo_db_city" VALUES(375,'Byfield','Byfield, Massachusetts',788,39);
INSERT INTO "django_geo_db_city" VALUES(376,'Danvers','Danvers, Massachusetts',789,39);
INSERT INTO "django_geo_db_city" VALUES(377,'Essex','Essex, Massachusetts',790,39);
INSERT INTO "django_geo_db_city" VALUES(378,'Gloucester','Gloucester, Massachusetts',791,39);
INSERT INTO "django_geo_db_city" VALUES(379,'Hamilton','Hamilton, Massachusetts',756,39);
INSERT INTO "django_geo_db_city" VALUES(380,'Hathorne','Hathorne, Massachusetts',756,39);
INSERT INTO "django_geo_db_city" VALUES(381,'Ipswich','Ipswich, Massachusetts',792,39);
INSERT INTO "django_geo_db_city" VALUES(382,'Lynnfield','Lynnfield, Massachusetts',793,39);
INSERT INTO "django_geo_db_city" VALUES(383,'Manchester','Manchester, Massachusetts',794,39);
INSERT INTO "django_geo_db_city" VALUES(384,'Marblehead','Marblehead, Massachusetts',795,39);
INSERT INTO "django_geo_db_city" VALUES(385,'Salem','Salem, Massachusetts',796,39);
INSERT INTO "django_geo_db_city" VALUES(386,'Middleton','Middleton, Massachusetts',797,39);
INSERT INTO "django_geo_db_city" VALUES(387,'Newburyport','Newburyport, Massachusetts',798,39);
INSERT INTO "django_geo_db_city" VALUES(388,'Newbury','Newbury, Massachusetts',799,39);
INSERT INTO "django_geo_db_city" VALUES(389,'Salisbury','Salisbury, Massachusetts',800,39);
INSERT INTO "django_geo_db_city" VALUES(390,'Peabody','Peabody, Massachusetts',801,39);
INSERT INTO "django_geo_db_city" VALUES(391,'Prides Crossing','Prides Crossing, Massachusetts',802,39);
INSERT INTO "django_geo_db_city" VALUES(392,'Rockport','Rockport, Massachusetts',803,39);
INSERT INTO "django_geo_db_city" VALUES(393,'Rowley','Rowley, Massachusetts',804,39);
INSERT INTO "django_geo_db_city" VALUES(394,'South Hamilton','South Hamilton, Massachusetts',806,39);
INSERT INTO "django_geo_db_city" VALUES(395,'Topsfield','Topsfield, Massachusetts',807,39);
INSERT INTO "django_geo_db_city" VALUES(396,'Wenham','Wenham, Massachusetts',808,39);
INSERT INTO "django_geo_db_city" VALUES(397,'West Newbury','West Newbury, Massachusetts',809,39);
INSERT INTO "django_geo_db_city" VALUES(398,'Accord','Accord, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(399,'Bellingham','Bellingham, Massachusetts',811,39);
INSERT INTO "django_geo_db_city" VALUES(400,'Brant Rock','Brant Rock, Massachusetts',812,39);
INSERT INTO "django_geo_db_city" VALUES(401,'Canton','Canton, Massachusetts',813,39);
INSERT INTO "django_geo_db_city" VALUES(402,'Cohasset','Cohasset, Massachusetts',814,39);
INSERT INTO "django_geo_db_city" VALUES(403,'Dedham','Dedham, Massachusetts',815,39);
INSERT INTO "django_geo_db_city" VALUES(404,'Providence','Providence, Rhode Island',817,46);
INSERT INTO "django_geo_db_city" VALUES(405,'Dover','Dover, Massachusetts',818,39);
INSERT INTO "django_geo_db_city" VALUES(406,'East Mansfield','East Mansfield, Massachusetts',819,39);
INSERT INTO "django_geo_db_city" VALUES(407,'East Walpole','East Walpole, Massachusetts',820,39);
INSERT INTO "django_geo_db_city" VALUES(408,'Foxboro','Foxboro, Massachusetts',821,39);
INSERT INTO "django_geo_db_city" VALUES(409,'Franklin','Franklin, Massachusetts',822,39);
INSERT INTO "django_geo_db_city" VALUES(410,'Greenbush','Greenbush, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(411,'Green Harbor','Green Harbor, Massachusetts',823,39);
INSERT INTO "django_geo_db_city" VALUES(412,'Hingham','Hingham, Massachusetts',824,39);
INSERT INTO "django_geo_db_city" VALUES(413,'Hull','Hull, Massachusetts',825,39);
INSERT INTO "django_geo_db_city" VALUES(414,'Humarock','Humarock, Massachusetts',826,39);
INSERT INTO "django_geo_db_city" VALUES(415,'Mansfield','Mansfield, Massachusetts',827,39);
INSERT INTO "django_geo_db_city" VALUES(416,'Marshfield','Marshfield, Massachusetts',828,39);
INSERT INTO "django_geo_db_city" VALUES(417,'Marshfield Hills','Marshfield Hills, Massachusetts',829,39);
INSERT INTO "django_geo_db_city" VALUES(418,'Medfield','Medfield, Massachusetts',830,39);
INSERT INTO "django_geo_db_city" VALUES(419,'Medway','Medway, Massachusetts',831,39);
INSERT INTO "django_geo_db_city" VALUES(420,'Millis','Millis, Massachusetts',832,39);
INSERT INTO "django_geo_db_city" VALUES(421,'Minot','Minot, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(422,'Norfolk','Norfolk, Massachusetts',833,39);
INSERT INTO "django_geo_db_city" VALUES(423,'North Marshfield','North Marshfield, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(424,'North Scituate','North Scituate, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(425,'Norwell','Norwell, Massachusetts',834,39);
INSERT INTO "django_geo_db_city" VALUES(426,'Norwood','Norwood, Massachusetts',835,39);
INSERT INTO "django_geo_db_city" VALUES(427,'Ocean Bluff','Ocean Bluff, Massachusetts',836,39);
INSERT INTO "django_geo_db_city" VALUES(428,'Scituate','Scituate, Massachusetts',837,39);
INSERT INTO "django_geo_db_city" VALUES(429,'Sharon','Sharon, Massachusetts',838,39);
INSERT INTO "django_geo_db_city" VALUES(430,'Sheldonville','Sheldonville, Massachusetts',816,39);
INSERT INTO "django_geo_db_city" VALUES(431,'South Walpole','South Walpole, Massachusetts',839,39);
INSERT INTO "django_geo_db_city" VALUES(432,'Stoughton','Stoughton, Massachusetts',840,39);
INSERT INTO "django_geo_db_city" VALUES(433,'Walpole','Walpole, Massachusetts',841,39);
INSERT INTO "django_geo_db_city" VALUES(434,'Foxborough','Foxborough, Massachusetts',842,39);
INSERT INTO "django_geo_db_city" VALUES(435,'Westwood','Westwood, Massachusetts',843,39);
INSERT INTO "django_geo_db_city" VALUES(436,'Wrentham','Wrentham, Massachusetts',844,39);
INSERT INTO "django_geo_db_city" VALUES(437,'Boston','Boston, Massachusetts',845,39);
INSERT INTO "django_geo_db_city" VALUES(438,'Mattapan','Mattapan, Massachusetts',863,39);
INSERT INTO "django_geo_db_city" VALUES(439,'Charlestown','Charlestown, Massachusetts',866,39);
INSERT INTO "django_geo_db_city" VALUES(440,'Jamaica Plain','Jamaica Plain, Massachusetts',867,39);
INSERT INTO "django_geo_db_city" VALUES(441,'Roslindale','Roslindale, Massachusetts',868,39);
INSERT INTO "django_geo_db_city" VALUES(442,'West Roxbury','West Roxbury, Massachusetts',869,39);
INSERT INTO "django_geo_db_city" VALUES(443,'Allston','Allston, Massachusetts',870,39);
INSERT INTO "django_geo_db_city" VALUES(444,'Brighton','Brighton, Massachusetts',871,39);
INSERT INTO "django_geo_db_city" VALUES(445,'Hyde Park','Hyde Park, Massachusetts',872,39);
INSERT INTO "django_geo_db_city" VALUES(446,'Readville','Readville, Massachusetts',846,39);
INSERT INTO "django_geo_db_city" VALUES(447,'Cambridge','Cambridge, Massachusetts',873,39);
INSERT INTO "django_geo_db_city" VALUES(448,'Somerville','Somerville, Massachusetts',878,39);
INSERT INTO "django_geo_db_city" VALUES(449,'Brookline','Brookline, Massachusetts',881,39);
INSERT INTO "django_geo_db_city" VALUES(450,'Brookline Village','Brookline Village, Massachusetts',816,39);
INSERT INTO "django_geo_db_city" VALUES(451,'Malden','Malden, Massachusetts',882,39);
INSERT INTO "django_geo_db_city" VALUES(452,'Everett','Everett, Massachusetts',883,39);
INSERT INTO "django_geo_db_city" VALUES(453,'Chelsea','Chelsea, Massachusetts',884,39);
INSERT INTO "django_geo_db_city" VALUES(454,'Revere','Revere, Massachusetts',885,39);
INSERT INTO "django_geo_db_city" VALUES(455,'Winthrop','Winthrop, Massachusetts',886,39);
INSERT INTO "django_geo_db_city" VALUES(456,'Medford','Medford, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(457,'Waltham','Waltham, Massachusetts',887,39);
INSERT INTO "django_geo_db_city" VALUES(458,'West Medford','West Medford, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(459,'Babson Park','Babson Park, Massachusetts',889,39);
INSERT INTO "django_geo_db_city" VALUES(460,'Newton','Newton, Massachusetts',890,39);
INSERT INTO "django_geo_db_city" VALUES(461,'Auburndale','Auburndale, Massachusetts',894,39);
INSERT INTO "django_geo_db_city" VALUES(462,'Chestnut Hill','Chestnut Hill, Massachusetts',895,39);
INSERT INTO "django_geo_db_city" VALUES(463,'Waban','Waban, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(464,'Quincy','Quincy, Massachusetts',896,39);
INSERT INTO "django_geo_db_city" VALUES(465,'Watertown','Watertown, Massachusetts',899,39);
INSERT INTO "django_geo_db_city" VALUES(466,'Lexington','Lexington, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(467,'Arlington','Arlington, Massachusetts',900,39);
INSERT INTO "django_geo_db_city" VALUES(468,'Arlington Heights','Arlington Heights, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(469,'Melrose','Melrose, Massachusetts',901,39);
INSERT INTO "django_geo_db_city" VALUES(470,'Belmont','Belmont, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(471,'Waverley','Waverley, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(472,'Stoneham','Stoneham, Massachusetts',902,39);
INSERT INTO "django_geo_db_city" VALUES(473,'Wellesley','Wellesley, Massachusetts',903,39);
INSERT INTO "django_geo_db_city" VALUES(474,'Braintree','Braintree, Massachusetts',904,39);
INSERT INTO "django_geo_db_city" VALUES(475,'Milton','Milton, Massachusetts',905,39);
INSERT INTO "django_geo_db_city" VALUES(476,'Milton Village','Milton Village, Massachusetts',816,39);
INSERT INTO "django_geo_db_city" VALUES(477,'Weymouth','Weymouth, Massachusetts',906,39);
INSERT INTO "django_geo_db_city" VALUES(478,'Needham','Needham, Massachusetts',816,39);
INSERT INTO "django_geo_db_city" VALUES(479,'Weston','Weston, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(480,'Brockton','Brockton, Massachusetts',918,39);
INSERT INTO "django_geo_db_city" VALUES(481,'Avon','Avon, Massachusetts',920,39);
INSERT INTO "django_geo_db_city" VALUES(482,'Bridgewater','Bridgewater, Massachusetts',921,39);
INSERT INTO "django_geo_db_city" VALUES(483,'Bryantville','Bryantville, Massachusetts',923,39);
INSERT INTO "django_geo_db_city" VALUES(484,'Carver','Carver, Massachusetts',924,39);
INSERT INTO "django_geo_db_city" VALUES(485,'Duxbury','Duxbury, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(486,'East Bridgewater','East Bridgewater, Massachusetts',926,39);
INSERT INTO "django_geo_db_city" VALUES(487,'Easton','Easton, Massachusetts',927,39);
INSERT INTO "django_geo_db_city" VALUES(488,'Elmwood','Elmwood, Massachusetts',928,39);
INSERT INTO "django_geo_db_city" VALUES(489,'Halifax','Halifax, Massachusetts',929,39);
INSERT INTO "django_geo_db_city" VALUES(490,'Hanover','Hanover, Massachusetts',930,39);
INSERT INTO "django_geo_db_city" VALUES(491,'Hanson','Hanson, Massachusetts',931,39);
INSERT INTO "django_geo_db_city" VALUES(492,'Holbrook','Holbrook, Massachusetts',932,39);
INSERT INTO "django_geo_db_city" VALUES(493,'Middleboro','Middleboro, Massachusetts',810,39);
INSERT INTO "django_geo_db_city" VALUES(494,'Manomet','Manomet, Massachusetts',933,39);
INSERT INTO "django_geo_db_city" VALUES(495,'Lakeville','Lakeville, Massachusetts',935,39);
INSERT INTO "django_geo_db_city" VALUES(496,'Monponsett','Monponsett, Massachusetts',936,39);
INSERT INTO "django_geo_db_city" VALUES(497,'Abington','Abington, Massachusetts',937,39);
INSERT INTO "django_geo_db_city" VALUES(498,'North Carver','North Carver, Massachusetts',938,39);
INSERT INTO "django_geo_db_city" VALUES(499,'North Easton','North Easton, Massachusetts',939,39);
INSERT INTO "django_geo_db_city" VALUES(500,'North Pembroke','North Pembroke, Massachusetts',941,39);
INSERT INTO "django_geo_db_city" VALUES(501,'Pembroke','Pembroke, Massachusetts',942,39);
INSERT INTO "django_geo_db_city" VALUES(502,'Plymouth','Plymouth, Massachusetts',943,39);
INSERT INTO "django_geo_db_city" VALUES(503,'Kingston','Kingston, Massachusetts',945,39);
INSERT INTO "django_geo_db_city" VALUES(504,'South Carver','South Carver, Massachusetts',946,39);
INSERT INTO "django_geo_db_city" VALUES(505,'Plympton','Plympton, Massachusetts',947,39);
INSERT INTO "django_geo_db_city" VALUES(506,'Randolph','Randolph, Massachusetts',948,39);
INSERT INTO "django_geo_db_city" VALUES(507,'Dennis Port','Dennis Port, Massachusetts',949,39);
INSERT INTO "django_geo_db_city" VALUES(508,'Rockland','Rockland, Massachusetts',950,39);
INSERT INTO "django_geo_db_city" VALUES(509,'South Easton','South Easton, Massachusetts',951,39);
INSERT INTO "django_geo_db_city" VALUES(510,'West Bridgewater','West Bridgewater, Massachusetts',952,39);
INSERT INTO "django_geo_db_city" VALUES(511,'White Horse Beach','White Horse Beach, Massachusetts',953,39);
INSERT INTO "django_geo_db_city" VALUES(512,'Whitman','Whitman, Massachusetts',954,39);
INSERT INTO "django_geo_db_city" VALUES(513,'New Town','New Town, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(514,'Newton Center','Newton Center, Massachusetts',967,39);
INSERT INTO "django_geo_db_city" VALUES(515,'Newtonville','Newtonville, Massachusetts',968,39);
INSERT INTO "django_geo_db_city" VALUES(516,'Newton Highlands','Newton Highlands, Massachusetts',969,39);
INSERT INTO "django_geo_db_city" VALUES(517,'Newton Lower Falls','Newton Lower Falls, Massachusetts',970,39);
INSERT INTO "django_geo_db_city" VALUES(518,'Newton Upper Falls','Newton Upper Falls, Massachusetts',971,39);
INSERT INTO "django_geo_db_city" VALUES(519,'West Newton','West Newton, Massachusetts',972,39);
INSERT INTO "django_geo_db_city" VALUES(520,'Wellesley Hills','Wellesley Hills, Massachusetts',980,39);
INSERT INTO "django_geo_db_city" VALUES(521,'Nonantum','Nonantum, Massachusetts',647,39);
INSERT INTO "django_geo_db_city" VALUES(522,'Buzzards Bay','Buzzards Bay, Massachusetts',985,39);
INSERT INTO "django_geo_db_city" VALUES(523,'Cataumet','Cataumet, Massachusetts',986,39);
INSERT INTO "django_geo_db_city" VALUES(524,'Chilmark','Chilmark, Massachusetts',987,39);
INSERT INTO "django_geo_db_city" VALUES(525,'East Falmouth','East Falmouth, Massachusetts',988,39);
INSERT INTO "django_geo_db_city" VALUES(526,'East Sandwich','East Sandwich, Massachusetts',989,39);
INSERT INTO "django_geo_db_city" VALUES(527,'East Wareham','East Wareham, Massachusetts',990,39);
INSERT INTO "django_geo_db_city" VALUES(528,'Edgartown','Edgartown, Massachusetts',991,39);
INSERT INTO "django_geo_db_city" VALUES(529,'Falmouth','Falmouth, Massachusetts',992,39);
INSERT INTO "django_geo_db_city" VALUES(530,'Woods Hole','Woods Hole, Massachusetts',995,39);
INSERT INTO "django_geo_db_city" VALUES(531,'Mashpee','Mashpee, Massachusetts',996,39);
INSERT INTO "django_geo_db_city" VALUES(532,'Oak Bluffs','Oak Bluffs, Massachusetts',997,39);
INSERT INTO "django_geo_db_city" VALUES(533,'Menemsha','Menemsha, Massachusetts',998,39);
INSERT INTO "django_geo_db_city" VALUES(534,'Monument Beach','Monument Beach, Massachusetts',999,39);
INSERT INTO "django_geo_db_city" VALUES(535,'Nantucket','Nantucket, Massachusetts',1000,39);
INSERT INTO "django_geo_db_city" VALUES(536,'North Falmouth','North Falmouth, Massachusetts',1001,39);
INSERT INTO "django_geo_db_city" VALUES(537,'Onset','Onset, Massachusetts',1003,39);
INSERT INTO "django_geo_db_city" VALUES(538,'Pocasset','Pocasset, Massachusetts',1004,39);
INSERT INTO "django_geo_db_city" VALUES(539,'Sagamore','Sagamore, Massachusetts',1005,39);
INSERT INTO "django_geo_db_city" VALUES(540,'Sagamore Beach','Sagamore Beach, Massachusetts',1006,39);
INSERT INTO "django_geo_db_city" VALUES(541,'Sandwich','Sandwich, Massachusetts',1007,39);
INSERT INTO "django_geo_db_city" VALUES(542,'Siasconset','Siasconset, Massachusetts',1008,39);
INSERT INTO "django_geo_db_city" VALUES(543,'Silver Beach','Silver Beach, Massachusetts',993,39);
INSERT INTO "django_geo_db_city" VALUES(544,'Vineyard Haven','Vineyard Haven, Massachusetts',1010,39);
INSERT INTO "django_geo_db_city" VALUES(545,'Wareham','Wareham, Massachusetts',1011,39);
INSERT INTO "django_geo_db_city" VALUES(546,'West Falmouth','West Falmouth, Massachusetts',1012,39);
INSERT INTO "django_geo_db_city" VALUES(547,'West Tisbury','West Tisbury, Massachusetts',1013,39);
INSERT INTO "django_geo_db_city" VALUES(548,'West Wareham','West Wareham, Massachusetts',1014,39);
INSERT INTO "django_geo_db_city" VALUES(549,'Hyannis','Hyannis, Massachusetts',1017,39);
INSERT INTO "django_geo_db_city" VALUES(550,'Barnstable Town','Barnstable Town, Massachusetts',1018,39);
INSERT INTO "django_geo_db_city" VALUES(551,'Barnstable','Barnstable, Massachusetts',1019,39);
INSERT INTO "django_geo_db_city" VALUES(552,'Brewster','Brewster, Massachusetts',1020,39);
INSERT INTO "django_geo_db_city" VALUES(553,'Centerville','Centerville, Massachusetts',1021,39);
INSERT INTO "django_geo_db_city" VALUES(554,'Chatham','Chatham, Massachusetts',1022,39);
INSERT INTO "django_geo_db_city" VALUES(555,'Cotuit','Cotuit, Massachusetts',1023,39);
INSERT INTO "django_geo_db_city" VALUES(556,'Cummaquid','Cummaquid, Massachusetts',1024,39);
INSERT INTO "django_geo_db_city" VALUES(557,'Dennis','Dennis, Massachusetts',1025,39);
INSERT INTO "django_geo_db_city" VALUES(558,'East Dennis','East Dennis, Massachusetts',1027,39);
INSERT INTO "django_geo_db_city" VALUES(559,'Eastham','Eastham, Massachusetts',1028,39);
INSERT INTO "django_geo_db_city" VALUES(560,'East Orleans','East Orleans, Massachusetts',1029,39);
INSERT INTO "django_geo_db_city" VALUES(561,'Forestdale','Forestdale, Massachusetts',1030,39);
INSERT INTO "django_geo_db_city" VALUES(562,'Harwich','Harwich, Massachusetts',1031,39);
INSERT INTO "django_geo_db_city" VALUES(563,'Harwich Port','Harwich Port, Massachusetts',1032,39);
INSERT INTO "django_geo_db_city" VALUES(564,'Hyannis Port','Hyannis Port, Massachusetts',1033,39);
INSERT INTO "django_geo_db_city" VALUES(565,'Marstons Mills','Marstons Mills, Massachusetts',1034,39);
INSERT INTO "django_geo_db_city" VALUES(566,'North Chatham','North Chatham, Massachusetts',1036,39);
INSERT INTO "django_geo_db_city" VALUES(567,'North Eastham','North Eastham, Massachusetts',1037,39);
INSERT INTO "django_geo_db_city" VALUES(568,'North Truro','North Truro, Massachusetts',1038,39);
INSERT INTO "django_geo_db_city" VALUES(569,'Orleans','Orleans, Massachusetts',1039,39);
INSERT INTO "django_geo_db_city" VALUES(570,'Osterville','Osterville, Massachusetts',1041,39);
INSERT INTO "django_geo_db_city" VALUES(571,'Provincetown','Provincetown, Massachusetts',1042,39);
INSERT INTO "django_geo_db_city" VALUES(572,'South Chatham','South Chatham, Massachusetts',1043,39);
INSERT INTO "django_geo_db_city" VALUES(573,'South Dennis','South Dennis, Massachusetts',1044,39);
INSERT INTO "django_geo_db_city" VALUES(574,'South Harwich','South Harwich, Massachusetts',1045,39);
INSERT INTO "django_geo_db_city" VALUES(575,'South Orleans','South Orleans, Massachusetts',1046,39);
INSERT INTO "django_geo_db_city" VALUES(576,'South Wellfleet','South Wellfleet, Massachusetts',1047,39);
INSERT INTO "django_geo_db_city" VALUES(577,'South Yarmouth','South Yarmouth, Massachusetts',1048,39);
INSERT INTO "django_geo_db_city" VALUES(578,'Truro','Truro, Massachusetts',1049,39);
INSERT INTO "django_geo_db_city" VALUES(579,'Wellfleet','Wellfleet, Massachusetts',1050,39);
INSERT INTO "django_geo_db_city" VALUES(580,'West Barnstable','West Barnstable, Massachusetts',1051,39);
INSERT INTO "django_geo_db_city" VALUES(581,'West Chatham','West Chatham, Massachusetts',1052,39);
INSERT INTO "django_geo_db_city" VALUES(582,'West Dennis','West Dennis, Massachusetts',1053,39);
INSERT INTO "django_geo_db_city" VALUES(583,'West Harwich','West Harwich, Massachusetts',1054,39);
INSERT INTO "django_geo_db_city" VALUES(584,'West Hyannisport','West Hyannisport, Massachusetts',1055,39);
INSERT INTO "django_geo_db_city" VALUES(585,'West Yarmouth','West Yarmouth, Massachusetts',1056,39);
INSERT INTO "django_geo_db_city" VALUES(586,'Yarmouth Port','Yarmouth Port, Massachusetts',1057,39);
INSERT INTO "django_geo_db_city" VALUES(587,'Assonet','Assonet, Massachusetts',1058,39);
INSERT INTO "django_geo_db_city" VALUES(588,'Attleboro','Attleboro, Massachusetts',1059,39);
INSERT INTO "django_geo_db_city" VALUES(589,'Chartley','Chartley, Massachusetts',1060,39);
INSERT INTO "django_geo_db_city" VALUES(590,'Cuttyhunk','Cuttyhunk, Massachusetts',1061,39);
INSERT INTO "django_geo_db_city" VALUES(591,'Dartmouth','Dartmouth, Massachusetts',1060,39);
INSERT INTO "django_geo_db_city" VALUES(592,'Dighton','Dighton, Massachusetts',1062,39);
INSERT INTO "django_geo_db_city" VALUES(593,'East Freetown','East Freetown, Massachusetts',1063,39);
INSERT INTO "django_geo_db_city" VALUES(594,'East Taunton','East Taunton, Massachusetts',1064,39);
INSERT INTO "django_geo_db_city" VALUES(595,'Fairhaven','Fairhaven, Massachusetts',1065,39);
INSERT INTO "django_geo_db_city" VALUES(596,'Fall River','Fall River, Massachusetts',1066,39);
INSERT INTO "django_geo_db_city" VALUES(597,'Somerset','Somerset, Massachusetts',1070,39);
INSERT INTO "django_geo_db_city" VALUES(598,'Marion','Marion, Massachusetts',1073,39);
INSERT INTO "django_geo_db_city" VALUES(599,'Mattapoisett','Mattapoisett, Massachusetts',1074,39);
INSERT INTO "django_geo_db_city" VALUES(600,'New Bedford','New Bedford, Massachusetts',1075,39);
INSERT INTO "django_geo_db_city" VALUES(601,'Acushnet','Acushnet, Massachusetts',1077,39);
INSERT INTO "django_geo_db_city" VALUES(602,'North Dartmouth','North Dartmouth, Massachusetts',1081,39);
INSERT INTO "django_geo_db_city" VALUES(603,'South Dartmouth','South Dartmouth, Massachusetts',1082,39);
INSERT INTO "django_geo_db_city" VALUES(604,'North Attleboro','North Attleboro, Massachusetts',1083,39);
INSERT INTO "django_geo_db_city" VALUES(605,'Plainville','Plainville, Massachusetts',1084,39);
INSERT INTO "django_geo_db_city" VALUES(606,'Attleboro Falls','Attleboro Falls, Massachusetts',1085,39);
INSERT INTO "django_geo_db_city" VALUES(607,'North Dighton','North Dighton, Massachusetts',1086,39);
INSERT INTO "django_geo_db_city" VALUES(608,'Norton','Norton, Massachusetts',1087,39);
INSERT INTO "django_geo_db_city" VALUES(609,'Raynham','Raynham, Massachusetts',1088,39);
INSERT INTO "django_geo_db_city" VALUES(610,'Raynham Center','Raynham Center, Massachusetts',1060,39);
INSERT INTO "django_geo_db_city" VALUES(611,'Rehoboth','Rehoboth, Massachusetts',1089,39);
INSERT INTO "django_geo_db_city" VALUES(612,'Rochester','Rochester, Massachusetts',1090,39);
INSERT INTO "django_geo_db_city" VALUES(613,'Seekonk','Seekonk, Massachusetts',1091,39);
INSERT INTO "django_geo_db_city" VALUES(614,'Swansea','Swansea, Massachusetts',1092,39);
INSERT INTO "django_geo_db_city" VALUES(615,'Berkley','Berkley, Massachusetts',1093,39);
INSERT INTO "django_geo_db_city" VALUES(616,'Taunton','Taunton, Massachusetts',1094,39);
INSERT INTO "django_geo_db_city" VALUES(617,'Westport','Westport, Massachusetts',1095,39);
INSERT INTO "django_geo_db_city" VALUES(618,'South Kingstown','South Kingstown, Rhode Island',1096,46);
INSERT INTO "django_geo_db_city" VALUES(619,'Westport Point','Westport Point, Massachusetts',1098,39);
INSERT INTO "django_geo_db_city" VALUES(620,'Adamsville','Adamsville, Rhode Island',1099,46);
INSERT INTO "django_geo_db_city" VALUES(621,'Albion','Albion, Rhode Island',1100,46);
INSERT INTO "django_geo_db_city" VALUES(622,'Ashaway','Ashaway, Rhode Island',1101,46);
INSERT INTO "django_geo_db_city" VALUES(623,'Foster','Foster, Rhode Island',1102,46);
INSERT INTO "django_geo_db_city" VALUES(624,'Barrington','Barrington, Rhode Island',1103,46);
INSERT INTO "django_geo_db_city" VALUES(625,'Block Island','Block Island, Rhode Island',1104,46);
INSERT INTO "django_geo_db_city" VALUES(626,'Bradford','Bradford, Rhode Island',1105,46);
INSERT INTO "django_geo_db_city" VALUES(627,'Bristol','Bristol, Rhode Island',1106,46);
INSERT INTO "django_geo_db_city" VALUES(628,'Carolina','Carolina, Rhode Island',1107,46);
INSERT INTO "django_geo_db_city" VALUES(629,'Charlestown','Charlestown, Rhode Island',1108,46);
INSERT INTO "django_geo_db_city" VALUES(630,'Chepachet','Chepachet, Rhode Island',1109,46);
INSERT INTO "django_geo_db_city" VALUES(631,'Clayville','Clayville, Rhode Island',1110,46);
INSERT INTO "django_geo_db_city" VALUES(632,'Coventry','Coventry, Rhode Island',1111,46);
INSERT INTO "django_geo_db_city" VALUES(633,'West Greenwich','West Greenwich, Rhode Island',1112,46);
INSERT INTO "django_geo_db_city" VALUES(634,'East Greenwich','East Greenwich, Rhode Island',1113,46);
INSERT INTO "django_geo_db_city" VALUES(635,'Exeter','Exeter, Rhode Island',1114,46);
INSERT INTO "django_geo_db_city" VALUES(636,'Fiskeville','Fiskeville, Rhode Island',1115,46);
INSERT INTO "django_geo_db_city" VALUES(637,'Forestdale','Forestdale, Rhode Island',1116,46);
INSERT INTO "django_geo_db_city" VALUES(638,'Glendale','Glendale, Rhode Island',1118,46);
INSERT INTO "django_geo_db_city" VALUES(639,'Greene','Greene, Rhode Island',1119,46);
INSERT INTO "django_geo_db_city" VALUES(640,'Greenville','Greenville, Rhode Island',1120,46);
INSERT INTO "django_geo_db_city" VALUES(641,'Harmony','Harmony, Rhode Island',1121,46);
INSERT INTO "django_geo_db_city" VALUES(642,'Harrisville','Harrisville, Rhode Island',1122,46);
INSERT INTO "django_geo_db_city" VALUES(643,'Hope','Hope, Rhode Island',1123,46);
INSERT INTO "django_geo_db_city" VALUES(644,'Hope Valley','Hope Valley, Rhode Island',1124,46);
INSERT INTO "django_geo_db_city" VALUES(645,'Hopkinton','Hopkinton, Rhode Island',1125,46);
INSERT INTO "django_geo_db_city" VALUES(646,'Jamestown','Jamestown, Rhode Island',1126,46);
INSERT INTO "django_geo_db_city" VALUES(647,'Kenyon','Kenyon, Rhode Island',1127,46);
INSERT INTO "django_geo_db_city" VALUES(648,'Little Compton','Little Compton, Rhode Island',1128,46);
INSERT INTO "django_geo_db_city" VALUES(649,'Manville','Manville, Rhode Island',1129,46);
INSERT INTO "django_geo_db_city" VALUES(650,'Mapleville','Mapleville, Rhode Island',1130,46);
INSERT INTO "django_geo_db_city" VALUES(651,'Newport','Newport, Rhode Island',1131,46);
INSERT INTO "django_geo_db_city" VALUES(652,'Middletown','Middletown, Rhode Island',1133,46);
INSERT INTO "django_geo_db_city" VALUES(653,'North Kingstown','North Kingstown, Rhode Island',1134,46);
INSERT INTO "django_geo_db_city" VALUES(654,'North Scituate','North Scituate, Rhode Island',1136,46);
INSERT INTO "django_geo_db_city" VALUES(655,'Oakland','Oakland, Rhode Island',1137,46);
INSERT INTO "django_geo_db_city" VALUES(656,'Pascoag','Pascoag, Rhode Island',1138,46);
INSERT INTO "django_geo_db_city" VALUES(657,'Pawtucket','Pawtucket, Rhode Island',1139,46);
INSERT INTO "django_geo_db_city" VALUES(658,'Central Falls','Central Falls, Rhode Island',1142,46);
INSERT INTO "django_geo_db_city" VALUES(659,'Cumberland','Cumberland, Rhode Island',1143,46);
INSERT INTO "django_geo_db_city" VALUES(660,'Lincoln','Lincoln, Rhode Island',1144,46);
INSERT INTO "django_geo_db_city" VALUES(661,'Portsmouth','Portsmouth, Rhode Island',1145,46);
INSERT INTO "django_geo_db_city" VALUES(662,'Prudence Island','Prudence Island, Rhode Island',1146,46);
INSERT INTO "django_geo_db_city" VALUES(663,'Rockville','Rockville, Rhode Island',1147,46);
INSERT INTO "django_geo_db_city" VALUES(664,'Saunderstown','Saunderstown, Rhode Island',1148,46);
INSERT INTO "django_geo_db_city" VALUES(665,'Shannock','Shannock, Rhode Island',1149,46);
INSERT INTO "django_geo_db_city" VALUES(666,'Slatersville','Slatersville, Rhode Island',1150,46);
INSERT INTO "django_geo_db_city" VALUES(667,'Slocum','Slocum, Rhode Island',1151,46);
INSERT INTO "django_geo_db_city" VALUES(668,'Tiverton','Tiverton, Rhode Island',1152,46);
INSERT INTO "django_geo_db_city" VALUES(669,'Wakefield','Wakefield, Rhode Island',1153,46);
INSERT INTO "django_geo_db_city" VALUES(670,'Kingston','Kingston, Rhode Island',1154,46);
INSERT INTO "django_geo_db_city" VALUES(671,'Narragansett','Narragansett, Rhode Island',1155,46);
INSERT INTO "django_geo_db_city" VALUES(672,'Peace Dale','Peace Dale, Rhode Island',1135,46);
INSERT INTO "django_geo_db_city" VALUES(673,'Warren','Warren, Rhode Island',1156,46);
INSERT INTO "django_geo_db_city" VALUES(674,'Warwick','Warwick, Rhode Island',1157,46);
INSERT INTO "django_geo_db_city" VALUES(675,'Westerly','Westerly, Rhode Island',1161,46);
INSERT INTO "django_geo_db_city" VALUES(676,'West Kingston','West Kingston, Rhode Island',1162,46);
INSERT INTO "django_geo_db_city" VALUES(677,'West Warwick','West Warwick, Rhode Island',1163,46);
INSERT INTO "django_geo_db_city" VALUES(678,'Wood River Junction','Wood River Junction, Rhode Island',1164,46);
INSERT INTO "django_geo_db_city" VALUES(679,'Woonsocket','Woonsocket, Rhode Island',1165,46);
INSERT INTO "django_geo_db_city" VALUES(680,'North Smithfield','North Smithfield, Rhode Island',1166,46);
INSERT INTO "django_geo_db_city" VALUES(681,'Wyoming','Wyoming, Rhode Island',1167,46);
INSERT INTO "django_geo_db_city" VALUES(682,'Cranston','Cranston, Rhode Island',1177,46);
INSERT INTO "django_geo_db_city" VALUES(683,'North Providence','North Providence, Rhode Island',1178,46);
INSERT INTO "django_geo_db_city" VALUES(684,'East Providence','East Providence, Rhode Island',1180,46);
INSERT INTO "django_geo_db_city" VALUES(685,'Riverside','Riverside, Rhode Island',1181,46);
INSERT INTO "django_geo_db_city" VALUES(686,'Rumford','Rumford, Rhode Island',1182,46);
INSERT INTO "django_geo_db_city" VALUES(687,'Smithfield','Smithfield, Rhode Island',1183,46);
INSERT INTO "django_geo_db_city" VALUES(688,'Johnston','Johnston, Rhode Island',1185,46);
INSERT INTO "django_geo_db_city" VALUES(689,'Fremont','Fremont, New Hampshire',1189,29);
INSERT INTO "django_geo_db_city" VALUES(690,'Nashua','Nashua, New Hampshire',1190,29);
INSERT INTO "django_geo_db_city" VALUES(691,'Amherst','Amherst, New Hampshire',1191,29);
INSERT INTO "django_geo_db_city" VALUES(692,'Auburn','Auburn, New Hampshire',1192,29);
INSERT INTO "django_geo_db_city" VALUES(693,'Brookline','Brookline, New Hampshire',1193,29);
INSERT INTO "django_geo_db_city" VALUES(694,'Candia','Candia, New Hampshire',1194,29);
INSERT INTO "django_geo_db_city" VALUES(695,'Chester','Chester, New Hampshire',1195,29);
INSERT INTO "django_geo_db_city" VALUES(696,'Deerfield','Deerfield, New Hampshire',1196,29);
INSERT INTO "django_geo_db_city" VALUES(697,'Derry','Derry, New Hampshire',1197,29);
INSERT INTO "django_geo_db_city" VALUES(698,'East Candia','East Candia, New Hampshire',294,29);
INSERT INTO "django_geo_db_city" VALUES(699,'East Derry','East Derry, New Hampshire',294,29);
INSERT INTO "django_geo_db_city" VALUES(700,'Epping','Epping, New Hampshire',1198,29);
INSERT INTO "django_geo_db_city" VALUES(701,'Francestown','Francestown, New Hampshire',1199,29);
INSERT INTO "django_geo_db_city" VALUES(702,'Goffstown','Goffstown, New Hampshire',1201,29);
INSERT INTO "django_geo_db_city" VALUES(703,'Dunbarton','Dunbarton, New Hampshire',1202,29);
INSERT INTO "django_geo_db_city" VALUES(704,'Greenfield','Greenfield, New Hampshire',1203,29);
INSERT INTO "django_geo_db_city" VALUES(705,'Greenville','Greenville, New Hampshire',1204,29);
INSERT INTO "django_geo_db_city" VALUES(706,'Hollis','Hollis, New Hampshire',1205,29);
INSERT INTO "django_geo_db_city" VALUES(707,'Hudson','Hudson, New Hampshire',1206,29);
INSERT INTO "django_geo_db_city" VALUES(708,'Litchfield','Litchfield, New Hampshire',1207,29);
INSERT INTO "django_geo_db_city" VALUES(709,'Londonderry','Londonderry, New Hampshire',1208,29);
INSERT INTO "django_geo_db_city" VALUES(710,'Merrimack','Merrimack, New Hampshire',1209,29);
INSERT INTO "django_geo_db_city" VALUES(711,'Milford','Milford, New Hampshire',1210,29);
INSERT INTO "django_geo_db_city" VALUES(712,'Mont Vernon','Mont Vernon, New Hampshire',1211,29);
INSERT INTO "django_geo_db_city" VALUES(713,'Sharon','Sharon, New Hampshire',1212,29);
INSERT INTO "django_geo_db_city" VALUES(714,'New Boston','New Boston, New Hampshire',1218,29);
INSERT INTO "django_geo_db_city" VALUES(715,'New Ipswich','New Ipswich, New Hampshire',1219,29);
INSERT INTO "django_geo_db_city" VALUES(716,'North Salem','North Salem, New Hampshire',294,29);
INSERT INTO "django_geo_db_city" VALUES(717,'Pelham','Pelham, New Hampshire',1220,29);
INSERT INTO "django_geo_db_city" VALUES(718,'Raymond','Raymond, New Hampshire',1221,29);
INSERT INTO "django_geo_db_city" VALUES(719,'Salem','Salem, New Hampshire',1222,29);
INSERT INTO "django_geo_db_city" VALUES(720,'Lyndeborough','Lyndeborough, New Hampshire',1223,29);
INSERT INTO "django_geo_db_city" VALUES(721,'Temple','Temple, New Hampshire',1224,29);
INSERT INTO "django_geo_db_city" VALUES(722,'Wilton','Wilton, New Hampshire',1225,29);
INSERT INTO "django_geo_db_city" VALUES(723,'Windham','Windham, New Hampshire',1226,29);
INSERT INTO "django_geo_db_city" VALUES(724,'Berwick','Berwick, Maine',1227,23);
INSERT INTO "django_geo_db_city" VALUES(725,'Ogunquit','Ogunquit, Maine',1228,23);
INSERT INTO "django_geo_db_city" VALUES(726,'Manchester','Manchester, New Hampshire',1229,29);
INSERT INTO "django_geo_db_city" VALUES(727,'Hooksett','Hooksett, New Hampshire',1233,29);
INSERT INTO "django_geo_db_city" VALUES(728,'Bedford','Bedford, New Hampshire',1235,29);
INSERT INTO "django_geo_db_city" VALUES(729,'Waterville Valley','Waterville Valley, New Hampshire',1236,29);
INSERT INTO "django_geo_db_city" VALUES(730,'Andover','Andover, New Hampshire',1237,29);
INSERT INTO "django_geo_db_city" VALUES(731,'Ashland','Ashland, New Hampshire',1238,29);
INSERT INTO "django_geo_db_city" VALUES(732,'Barnstead','Barnstead, New Hampshire',1239,29);
INSERT INTO "django_geo_db_city" VALUES(733,'Belmont','Belmont, New Hampshire',1240,29);
INSERT INTO "django_geo_db_city" VALUES(734,'Bradford','Bradford, New Hampshire',1241,29);
INSERT INTO "django_geo_db_city" VALUES(735,'Bristol','Bristol, New Hampshire',1242,29);
INSERT INTO "django_geo_db_city" VALUES(736,'Campton','Campton, New Hampshire',1243,29);
INSERT INTO "django_geo_db_city" VALUES(737,'Canterbury','Canterbury, New Hampshire',1244,29);
INSERT INTO "django_geo_db_city" VALUES(738,'Center Barnstead','Center Barnstead, New Hampshire',1245,29);
INSERT INTO "django_geo_db_city" VALUES(739,'Center Harbor','Center Harbor, New Hampshire',1246,29);
INSERT INTO "django_geo_db_city" VALUES(740,'Center Sandwich','Center Sandwich, New Hampshire',1247,29);
INSERT INTO "django_geo_db_city" VALUES(741,'Contoocook','Contoocook, New Hampshire',1248,29);
INSERT INTO "django_geo_db_city" VALUES(742,'Danbury','Danbury, New Hampshire',1249,29);
INSERT INTO "django_geo_db_city" VALUES(743,'East Andover','East Andover, New Hampshire',1250,29);
INSERT INTO "django_geo_db_city" VALUES(744,'East Hebron','East Hebron, New Hampshire',1251,29);
INSERT INTO "django_geo_db_city" VALUES(745,'Elkins','Elkins, New Hampshire',1252,29);
INSERT INTO "django_geo_db_city" VALUES(746,'Epsom','Epsom, New Hampshire',1253,29);
INSERT INTO "django_geo_db_city" VALUES(747,'Franklin','Franklin, New Hampshire',1254,29);
INSERT INTO "django_geo_db_city" VALUES(748,'Gilmanton','Gilmanton, New Hampshire',1255,29);
INSERT INTO "django_geo_db_city" VALUES(749,'Glencliff','Glencliff, New Hampshire',1251,29);
INSERT INTO "django_geo_db_city" VALUES(750,'Grafton','Grafton, New Hampshire',1256,29);
INSERT INTO "django_geo_db_city" VALUES(751,'Hebron','Hebron, New Hampshire',1257,29);
INSERT INTO "django_geo_db_city" VALUES(752,'Henniker','Henniker, New Hampshire',1258,29);
INSERT INTO "django_geo_db_city" VALUES(753,'Hill','Hill, New Hampshire',1259,29);
INSERT INTO "django_geo_db_city" VALUES(754,'Hillsboro','Hillsboro, New Hampshire',1260,29);
INSERT INTO "django_geo_db_city" VALUES(755,'Holderness','Holderness, New Hampshire',1261,29);
INSERT INTO "django_geo_db_city" VALUES(756,'Laconia','Laconia, New Hampshire',1262,29);
INSERT INTO "django_geo_db_city" VALUES(757,'Lincoln','Lincoln, New Hampshire',1265,29);
INSERT INTO "django_geo_db_city" VALUES(758,'Lochmere','Lochmere, New Hampshire',1266,29);
INSERT INTO "django_geo_db_city" VALUES(759,'Meredith','Meredith, New Hampshire',1267,29);
INSERT INTO "django_geo_db_city" VALUES(760,'Moultonborough','Moultonborough, New Hampshire',1268,29);
INSERT INTO "django_geo_db_city" VALUES(761,'Newbury','Newbury, New Hampshire',1269,29);
INSERT INTO "django_geo_db_city" VALUES(762,'New Hampton','New Hampton, New Hampshire',1270,29);
INSERT INTO "django_geo_db_city" VALUES(763,'New London','New London, New Hampshire',1271,29);
INSERT INTO "django_geo_db_city" VALUES(764,'Chichester','Chichester, New Hampshire',1272,29);
INSERT INTO "django_geo_db_city" VALUES(765,'North Sandwich','North Sandwich, New Hampshire',1273,29);
INSERT INTO "django_geo_db_city" VALUES(766,'North Sutton','North Sutton, New Hampshire',1274,29);
INSERT INTO "django_geo_db_city" VALUES(767,'Northwood','Northwood, New Hampshire',1275,29);
INSERT INTO "django_geo_db_city" VALUES(768,'North Woodstock','North Woodstock, New Hampshire',1276,29);
INSERT INTO "django_geo_db_city" VALUES(769,'Pittsfield','Pittsfield, New Hampshire',1277,29);
INSERT INTO "django_geo_db_city" VALUES(770,'Plymouth','Plymouth, New Hampshire',1278,29);
INSERT INTO "django_geo_db_city" VALUES(771,'Rumney','Rumney, New Hampshire',1279,29);
INSERT INTO "django_geo_db_city" VALUES(772,'Salisbury','Salisbury, New Hampshire',1280,29);
INSERT INTO "django_geo_db_city" VALUES(773,'Sanbornton','Sanbornton, New Hampshire',1281,29);
INSERT INTO "django_geo_db_city" VALUES(774,'South Newbury','South Newbury, New Hampshire',1283,29);
INSERT INTO "django_geo_db_city" VALUES(775,'South Sutton','South Sutton, New Hampshire',1284,29);
INSERT INTO "django_geo_db_city" VALUES(776,'Stinson Lake','Stinson Lake, New Hampshire',1251,29);
INSERT INTO "django_geo_db_city" VALUES(777,'Suncook','Suncook, New Hampshire',1285,29);
INSERT INTO "django_geo_db_city" VALUES(778,'Tilton','Tilton, New Hampshire',1286,29);
INSERT INTO "django_geo_db_city" VALUES(779,'Warner','Warner, New Hampshire',1287,29);
INSERT INTO "django_geo_db_city" VALUES(780,'Warren','Warren, New Hampshire',1288,29);
INSERT INTO "django_geo_db_city" VALUES(781,'Washington','Washington, New Hampshire',1289,29);
INSERT INTO "django_geo_db_city" VALUES(782,'Weare','Weare, New Hampshire',1290,29);
INSERT INTO "django_geo_db_city" VALUES(783,'Wentworth','Wentworth, New Hampshire',1291,29);
INSERT INTO "django_geo_db_city" VALUES(784,'Springfield','Springfield, New Hampshire',1292,29);
INSERT INTO "django_geo_db_city" VALUES(785,'Wilmot','Wilmot, New Hampshire',1293,29);
INSERT INTO "django_geo_db_city" VALUES(786,'Winnisquam','Winnisquam, New Hampshire',1294,29);
INSERT INTO "django_geo_db_city" VALUES(787,'Nottingham','Nottingham, New Hampshire',1295,29);
INSERT INTO "django_geo_db_city" VALUES(788,'West Nottingham','West Nottingham, New Hampshire',1296,29);
INSERT INTO "django_geo_db_city" VALUES(789,'Woodstock','Woodstock, New Hampshire',1251,29);
INSERT INTO "django_geo_db_city" VALUES(790,'Concord','Concord, New Hampshire',1298,29);
INSERT INTO "django_geo_db_city" VALUES(791,'Bow','Bow, New Hampshire',1300,29);
INSERT INTO "django_geo_db_city" VALUES(792,'Loudon','Loudon, New Hampshire',1302,29);
INSERT INTO "django_geo_db_city" VALUES(793,'Bennington','Bennington, New Hampshire',1303,29);
INSERT INTO "django_geo_db_city" VALUES(794,'Tamworth','Tamworth, New Hampshire',1304,29);
INSERT INTO "django_geo_db_city" VALUES(795,'Keene','Keene, New Hampshire',1305,29);
INSERT INTO "django_geo_db_city" VALUES(796,'Harrisville','Harrisville, New Hampshire',1307,29);
INSERT INTO "django_geo_db_city" VALUES(797,'Antrim','Antrim, New Hampshire',1308,29);
INSERT INTO "django_geo_db_city" VALUES(798,'Ashuelot','Ashuelot, New Hampshire',1309,29);
INSERT INTO "django_geo_db_city" VALUES(799,'Chesterfield','Chesterfield, New Hampshire',1311,29);
INSERT INTO "django_geo_db_city" VALUES(800,'Dublin','Dublin, New Hampshire',1312,29);
INSERT INTO "django_geo_db_city" VALUES(801,'Sullivan','Sullivan, New Hampshire',1313,29);
INSERT INTO "django_geo_db_city" VALUES(802,'Swanzey','Swanzey, New Hampshire',1314,29);
INSERT INTO "django_geo_db_city" VALUES(803,'Fitzwilliam','Fitzwilliam, New Hampshire',1315,29);
INSERT INTO "django_geo_db_city" VALUES(804,'Gilsum','Gilsum, New Hampshire',1316,29);
INSERT INTO "django_geo_db_city" VALUES(805,'Hancock','Hancock, New Hampshire',1317,29);
INSERT INTO "django_geo_db_city" VALUES(806,'Hinsdale','Hinsdale, New Hampshire',1319,29);
INSERT INTO "django_geo_db_city" VALUES(807,'Jaffrey','Jaffrey, New Hampshire',1320,29);
INSERT INTO "django_geo_db_city" VALUES(808,'Marlborough','Marlborough, New Hampshire',1321,29);
INSERT INTO "django_geo_db_city" VALUES(809,'Marlow','Marlow, New Hampshire',1322,29);
INSERT INTO "django_geo_db_city" VALUES(810,'Munsonville','Munsonville, New Hampshire',1323,29);
INSERT INTO "django_geo_db_city" VALUES(811,'Peterborough','Peterborough, New Hampshire',1324,29);
INSERT INTO "django_geo_db_city" VALUES(812,'Rindge','Rindge, New Hampshire',1325,29);
INSERT INTO "django_geo_db_city" VALUES(813,'Spofford','Spofford, New Hampshire',1326,29);
INSERT INTO "django_geo_db_city" VALUES(814,'Stoddard','Stoddard, New Hampshire',1327,29);
INSERT INTO "django_geo_db_city" VALUES(815,'Troy','Troy, New Hampshire',1328,29);
INSERT INTO "django_geo_db_city" VALUES(816,'West Chesterfield','West Chesterfield, New Hampshire',1329,29);
INSERT INTO "django_geo_db_city" VALUES(817,'Westmoreland','Westmoreland, New Hampshire',1330,29);
INSERT INTO "django_geo_db_city" VALUES(818,'West Peterborough','West Peterborough, New Hampshire',1331,29);
INSERT INTO "django_geo_db_city" VALUES(819,'West Swanzey','West Swanzey, New Hampshire',1332,29);
INSERT INTO "django_geo_db_city" VALUES(820,'Winchester','Winchester, New Hampshire',1333,29);
INSERT INTO "django_geo_db_city" VALUES(821,'Pittsburg','Pittsburg, New Hampshire',1335,29);
INSERT INTO "django_geo_db_city" VALUES(822,'Littleton','Littleton, New Hampshire',1336,29);
INSERT INTO "django_geo_db_city" VALUES(823,'Berlin','Berlin, New Hampshire',1337,29);
INSERT INTO "django_geo_db_city" VALUES(824,'Goshen','Goshen, New Hampshire',1338,29);
INSERT INTO "django_geo_db_city" VALUES(825,'Bethlehem','Bethlehem, New Hampshire',1339,29);
INSERT INTO "django_geo_db_city" VALUES(826,'Bretton Woods','Bretton Woods, New Hampshire',1340,29);
INSERT INTO "django_geo_db_city" VALUES(827,'Colebrook','Colebrook, New Hampshire',1341,29);
INSERT INTO "django_geo_db_city" VALUES(828,'Landaff','Landaff, New Hampshire',1342,29);
INSERT INTO "django_geo_db_city" VALUES(829,'Errol','Errol, New Hampshire',1343,29);
INSERT INTO "django_geo_db_city" VALUES(830,'Franconia','Franconia, New Hampshire',1344,29);
INSERT INTO "django_geo_db_city" VALUES(831,'Gorham','Gorham, New Hampshire',1345,29);
INSERT INTO "django_geo_db_city" VALUES(832,'Groveton','Groveton, New Hampshire',1346,29);
INSERT INTO "django_geo_db_city" VALUES(833,'Jefferson','Jefferson, New Hampshire',1347,29);
INSERT INTO "django_geo_db_city" VALUES(834,'Lancaster','Lancaster, New Hampshire',1348,29);
INSERT INTO "django_geo_db_city" VALUES(835,'Lisbon','Lisbon, New Hampshire',1349,29);
INSERT INTO "django_geo_db_city" VALUES(836,'Meadows','Meadows, New Hampshire',1340,29);
INSERT INTO "django_geo_db_city" VALUES(837,'Milan','Milan, New Hampshire',1350,29);
INSERT INTO "django_geo_db_city" VALUES(838,'Mount Washington','Mount Washington, New Hampshire',1340,29);
INSERT INTO "django_geo_db_city" VALUES(839,'North Stratford','North Stratford, New Hampshire',1351,29);
INSERT INTO "django_geo_db_city" VALUES(840,'Twin Mountain','Twin Mountain, New Hampshire',1353,29);
INSERT INTO "django_geo_db_city" VALUES(841,'West Stewartstown','West Stewartstown, New Hampshire',1340,29);
INSERT INTO "django_geo_db_city" VALUES(842,'Whitefield','Whitefield, New Hampshire',1354,29);
INSERT INTO "django_geo_db_city" VALUES(843,'Acworth','Acworth, New Hampshire',1355,29);
INSERT INTO "django_geo_db_city" VALUES(844,'Alstead','Alstead, New Hampshire',1356,29);
INSERT INTO "django_geo_db_city" VALUES(845,'Charlestown','Charlestown, New Hampshire',1357,29);
INSERT INTO "django_geo_db_city" VALUES(846,'Drewsville','Drewsville, New Hampshire',1306,29);
INSERT INTO "django_geo_db_city" VALUES(847,'Lempster','Lempster, New Hampshire',1358,29);
INSERT INTO "django_geo_db_city" VALUES(848,'South Acworth','South Acworth, New Hampshire',1359,29);
INSERT INTO "django_geo_db_city" VALUES(849,'Walpole','Walpole, New Hampshire',1360,29);
INSERT INTO "django_geo_db_city" VALUES(850,'North Walpole','North Walpole, New Hampshire',1361,29);
INSERT INTO "django_geo_db_city" VALUES(851,'Freedom','Freedom, New Hampshire',1362,29);
INSERT INTO "django_geo_db_city" VALUES(852,'Enfield','Enfield, New Hampshire',1363,29);
INSERT INTO "django_geo_db_city" VALUES(853,'Lyme','Lyme, New Hampshire',1364,29);
INSERT INTO "django_geo_db_city" VALUES(854,'Lebanon','Lebanon, Maine',1365,23);
INSERT INTO "django_geo_db_city" VALUES(855,'Newport','Newport, New Hampshire',1366,29);
INSERT INTO "django_geo_db_city" VALUES(856,'Bath','Bath, New Hampshire',1367,29);
INSERT INTO "django_geo_db_city" VALUES(857,'Canaan','Canaan, New Hampshire',1368,29);
INSERT INTO "django_geo_db_city" VALUES(858,'Claremont','Claremont, New Hampshire',1369,29);
INSERT INTO "django_geo_db_city" VALUES(859,'Cornish','Cornish, New Hampshire',1370,29);
INSERT INTO "django_geo_db_city" VALUES(860,'Cornish Flat','Cornish Flat, New Hampshire',1371,29);
INSERT INTO "django_geo_db_city" VALUES(861,'Enfield Center','Enfield Center, New Hampshire',1374,29);
INSERT INTO "django_geo_db_city" VALUES(862,'Etna','Etna, New Hampshire',1375,29);
INSERT INTO "django_geo_db_city" VALUES(863,'Georges Mills','Georges Mills, New Hampshire',1376,29);
INSERT INTO "django_geo_db_city" VALUES(864,'Grantham','Grantham, New Hampshire',1378,29);
INSERT INTO "django_geo_db_city" VALUES(865,'Guild','Guild, New Hampshire',1379,29);
INSERT INTO "django_geo_db_city" VALUES(866,'Hanover','Hanover, New Hampshire',1380,29);
INSERT INTO "django_geo_db_city" VALUES(867,'Lebanon','Lebanon, New Hampshire',1251,29);
INSERT INTO "django_geo_db_city" VALUES(868,'Sunapee','Sunapee, New Hampshire',1381,29);
INSERT INTO "django_geo_db_city" VALUES(869,'Haverhill','Haverhill, New Hampshire',1382,29);
INSERT INTO "django_geo_db_city" VALUES(870,'Lyme Center','Lyme Center, New Hampshire',1385,29);
INSERT INTO "django_geo_db_city" VALUES(871,'Meriden','Meriden, New Hampshire',1386,29);
INSERT INTO "django_geo_db_city" VALUES(872,'Monroe','Monroe, New Hampshire',1387,29);
INSERT INTO "django_geo_db_city" VALUES(873,'North Haverhill','North Haverhill, New Hampshire',1389,29);
INSERT INTO "django_geo_db_city" VALUES(874,'Orford','Orford, New Hampshire',1390,29);
INSERT INTO "django_geo_db_city" VALUES(875,'Piermont','Piermont, New Hampshire',1391,29);
INSERT INTO "django_geo_db_city" VALUES(876,'Pike','Pike, New Hampshire',1392,29);
INSERT INTO "django_geo_db_city" VALUES(877,'Plainfield','Plainfield, New Hampshire',1393,29);
INSERT INTO "django_geo_db_city" VALUES(878,'West Lebanon','West Lebanon, New Hampshire',1395,29);
INSERT INTO "django_geo_db_city" VALUES(879,'Woodsville','Woodsville, New Hampshire',1396,29);
INSERT INTO "django_geo_db_city" VALUES(880,'Rollinsford','Rollinsford, New Hampshire',1399,29);
INSERT INTO "django_geo_db_city" VALUES(881,'Alton','Alton, New Hampshire',1400,29);
INSERT INTO "django_geo_db_city" VALUES(882,'Alton Bay','Alton Bay, New Hampshire',1401,29);
INSERT INTO "django_geo_db_city" VALUES(883,'Atkinson','Atkinson, New Hampshire',1402,29);
INSERT INTO "django_geo_db_city" VALUES(884,'Bartlett','Bartlett, New Hampshire',1403,29);
INSERT INTO "django_geo_db_city" VALUES(885,'Center Conway','Center Conway, New Hampshire',1404,29);
INSERT INTO "django_geo_db_city" VALUES(886,'Center Ossipee','Center Ossipee, New Hampshire',1405,29);
INSERT INTO "django_geo_db_city" VALUES(887,'Center Strafford','Center Strafford, New Hampshire',1406,29);
INSERT INTO "django_geo_db_city" VALUES(888,'Center Tuftonboro','Center Tuftonboro, New Hampshire',1407,29);
INSERT INTO "django_geo_db_city" VALUES(889,'Chocorua','Chocorua, New Hampshire',1408,29);
INSERT INTO "django_geo_db_city" VALUES(890,'Conway','Conway, New Hampshire',1409,29);
INSERT INTO "django_geo_db_city" VALUES(891,'Danville','Danville, New Hampshire',1410,29);
INSERT INTO "django_geo_db_city" VALUES(892,'Dover','Dover, New Hampshire',1411,29);
INSERT INTO "django_geo_db_city" VALUES(893,'Durham','Durham, New Hampshire',1413,29);
INSERT INTO "django_geo_db_city" VALUES(894,'Barrington','Barrington, New Hampshire',1414,29);
INSERT INTO "django_geo_db_city" VALUES(895,'East Hampstead','East Hampstead, New Hampshire',1415,29);
INSERT INTO "django_geo_db_city" VALUES(896,'East Kingston','East Kingston, New Hampshire',1416,29);
INSERT INTO "django_geo_db_city" VALUES(897,'East Wakefield','East Wakefield, New Hampshire',1417,29);
INSERT INTO "django_geo_db_city" VALUES(898,'Eaton Center','Eaton Center, New Hampshire',1418,29);
INSERT INTO "django_geo_db_city" VALUES(899,'Exeter','Exeter, New Hampshire',1419,29);
INSERT INTO "django_geo_db_city" VALUES(900,'Farmington','Farmington, New Hampshire',1420,29);
INSERT INTO "django_geo_db_city" VALUES(901,'Gilmanton Iron Works','Gilmanton Iron Works, New Hampshire',1422,29);
INSERT INTO "django_geo_db_city" VALUES(902,'Glen','Glen, New Hampshire',1423,29);
INSERT INTO "django_geo_db_city" VALUES(903,'Rochester','Rochester, New Hampshire',1424,29);
INSERT INTO "django_geo_db_city" VALUES(904,'Greenland','Greenland, New Hampshire',1425,29);
INSERT INTO "django_geo_db_city" VALUES(905,'Hampstead','Hampstead, New Hampshire',1426,29);
INSERT INTO "django_geo_db_city" VALUES(906,'Hampton','Hampton, New Hampshire',1427,29);
INSERT INTO "django_geo_db_city" VALUES(907,'Hampton Falls','Hampton Falls, New Hampshire',1428,29);
INSERT INTO "django_geo_db_city" VALUES(908,'Intervale','Intervale, New Hampshire',1429,29);
INSERT INTO "django_geo_db_city" VALUES(909,'Jackson','Jackson, New Hampshire',1430,29);
INSERT INTO "django_geo_db_city" VALUES(910,'Kearsarge','Kearsarge, New Hampshire',1431,29);
INSERT INTO "django_geo_db_city" VALUES(911,'Kingston','Kingston, New Hampshire',1432,29);
INSERT INTO "django_geo_db_city" VALUES(912,'Madison','Madison, New Hampshire',1433,29);
INSERT INTO "django_geo_db_city" VALUES(913,'Melvin Village','Melvin Village, New Hampshire',1434,29);
INSERT INTO "django_geo_db_city" VALUES(914,'Milton','Milton, New Hampshire',1435,29);
INSERT INTO "django_geo_db_city" VALUES(915,'Milton Mills','Milton Mills, New Hampshire',1436,29);
INSERT INTO "django_geo_db_city" VALUES(916,'Mirror Lake','Mirror Lake, New Hampshire',1437,29);
INSERT INTO "django_geo_db_city" VALUES(917,'New Castle','New Castle, New Hampshire',1438,29);
INSERT INTO "django_geo_db_city" VALUES(918,'New Durham','New Durham, New Hampshire',1439,29);
INSERT INTO "django_geo_db_city" VALUES(919,'Newfields','Newfields, New Hampshire',1440,29);
INSERT INTO "django_geo_db_city" VALUES(920,'Newmarket','Newmarket, New Hampshire',1441,29);
INSERT INTO "django_geo_db_city" VALUES(921,'Newton','Newton, New Hampshire',1442,29);
INSERT INTO "django_geo_db_city" VALUES(922,'Newton Junction','Newton Junction, New Hampshire',1443,29);
INSERT INTO "django_geo_db_city" VALUES(923,'North Conway','North Conway, New Hampshire',1444,29);
INSERT INTO "django_geo_db_city" VALUES(924,'North Hampton','North Hampton, New Hampshire',1445,29);
INSERT INTO "django_geo_db_city" VALUES(925,'Ossipee','Ossipee, New Hampshire',1446,29);
INSERT INTO "django_geo_db_city" VALUES(926,'Plaistow','Plaistow, New Hampshire',1447,29);
INSERT INTO "django_geo_db_city" VALUES(927,'Rye','Rye, New Hampshire',1452,29);
INSERT INTO "django_geo_db_city" VALUES(928,'Rye Beach','Rye Beach, New Hampshire',1453,29);
INSERT INTO "django_geo_db_city" VALUES(929,'Sanbornville','Sanbornville, New Hampshire',1454,29);
INSERT INTO "django_geo_db_city" VALUES(930,'Sandown','Sandown, New Hampshire',1455,29);
INSERT INTO "django_geo_db_city" VALUES(931,'Seabrook','Seabrook, New Hampshire',1456,29);
INSERT INTO "django_geo_db_city" VALUES(932,'Silver Lake','Silver Lake, New Hampshire',1457,29);
INSERT INTO "django_geo_db_city" VALUES(933,'Somersworth','Somersworth, New Hampshire',1458,29);
INSERT INTO "django_geo_db_city" VALUES(934,'South Effingham','South Effingham, New Hampshire',1459,29);
INSERT INTO "django_geo_db_city" VALUES(935,'South Tamworth','South Tamworth, New Hampshire',1460,29);
INSERT INTO "django_geo_db_city" VALUES(936,'Strafford','Strafford, New Hampshire',1461,29);
INSERT INTO "django_geo_db_city" VALUES(937,'Stratham','Stratham, New Hampshire',1462,29);
INSERT INTO "django_geo_db_city" VALUES(938,'Union','Union, New Hampshire',1464,29);
INSERT INTO "django_geo_db_city" VALUES(939,'West Ossipee','West Ossipee, New Hampshire',1465,29);
INSERT INTO "django_geo_db_city" VALUES(940,'Wolfeboro','Wolfeboro, New Hampshire',1467,29);
INSERT INTO "django_geo_db_city" VALUES(941,'Wolfeboro Falls','Wolfeboro Falls, New Hampshire',1468,29);
INSERT INTO "django_geo_db_city" VALUES(942,'Wonalancet','Wonalancet, New Hampshire',1469,29);
INSERT INTO "django_geo_db_city" VALUES(943,'Cape Neddick','Cape Neddick, Maine',1471,23);
INSERT INTO "django_geo_db_city" VALUES(944,'Eliot','Eliot, Maine',1472,23);
INSERT INTO "django_geo_db_city" VALUES(945,'Kittery','Kittery, Maine',1473,23);
INSERT INTO "django_geo_db_city" VALUES(946,'Kittery Point','Kittery Point, Maine',1474,23);
INSERT INTO "django_geo_db_city" VALUES(947,'North Berwick','North Berwick, Maine',1475,23);
INSERT INTO "django_geo_db_city" VALUES(948,'South Berwick','South Berwick, Maine',1477,23);
INSERT INTO "django_geo_db_city" VALUES(949,'York','York, Maine',1478,23);
INSERT INTO "django_geo_db_city" VALUES(950,'York Beach','York Beach, Maine',1479,23);
INSERT INTO "django_geo_db_city" VALUES(951,'York Harbor','York Harbor, Maine',1480,23);
INSERT INTO "django_geo_db_city" VALUES(952,'Acton','Acton, Maine',1481,23);
INSERT INTO "django_geo_db_city" VALUES(953,'Alfred','Alfred, Maine',1482,23);
INSERT INTO "django_geo_db_city" VALUES(954,'Bailey Island','Bailey Island, Maine',1483,23);
INSERT INTO "django_geo_db_city" VALUES(955,'Bar Mills','Bar Mills, Maine',1484,23);
INSERT INTO "django_geo_db_city" VALUES(956,'Biddeford','Biddeford, Maine',1485,23);
INSERT INTO "django_geo_db_city" VALUES(957,'Biddeford Pool','Biddeford Pool, Maine',1486,23);
INSERT INTO "django_geo_db_city" VALUES(958,'Bowdoinham','Bowdoinham, Maine',1488,23);
INSERT INTO "django_geo_db_city" VALUES(959,'Bridgton','Bridgton, Maine',1489,23);
INSERT INTO "django_geo_db_city" VALUES(960,'Brownfield','Brownfield, Maine',1490,23);
INSERT INTO "django_geo_db_city" VALUES(961,'Brunswick','Brunswick, Maine',1491,23);
INSERT INTO "django_geo_db_city" VALUES(962,'Bustins Island','Bustins Island, Maine',1492,23);
INSERT INTO "django_geo_db_city" VALUES(963,'Cape Porpoise','Cape Porpoise, Maine',1484,23);
INSERT INTO "django_geo_db_city" VALUES(964,'Casco','Casco, Maine',1493,23);
INSERT INTO "django_geo_db_city" VALUES(965,'Center Lovell','Center Lovell, Maine',1494,23);
INSERT INTO "django_geo_db_city" VALUES(966,'Chebeague Island','Chebeague Island, Maine',1495,23);
INSERT INTO "django_geo_db_city" VALUES(967,'Cliff Island','Cliff Island, Maine',1496,23);
INSERT INTO "django_geo_db_city" VALUES(968,'Cornish','Cornish, Maine',1497,23);
INSERT INTO "django_geo_db_city" VALUES(969,'Cumberland Center','Cumberland Center, Maine',1498,23);
INSERT INTO "django_geo_db_city" VALUES(970,'Denmark','Denmark, Maine',1499,23);
INSERT INTO "django_geo_db_city" VALUES(971,'East Baldwin','East Baldwin, Maine',1500,23);
INSERT INTO "django_geo_db_city" VALUES(972,'East Parsonfield','East Parsonfield, Maine',1502,23);
INSERT INTO "django_geo_db_city" VALUES(973,'Sebago','Sebago, Maine',1503,23);
INSERT INTO "django_geo_db_city" VALUES(974,'East Waterboro','East Waterboro, Maine',1504,23);
INSERT INTO "django_geo_db_city" VALUES(975,'Raymond','Raymond, Maine',1505,23);
INSERT INTO "django_geo_db_city" VALUES(976,'Freeport','Freeport, Maine',1506,23);
INSERT INTO "django_geo_db_city" VALUES(977,'Fryeburg','Fryeburg, Maine',1507,23);
INSERT INTO "django_geo_db_city" VALUES(978,'Gorham','Gorham, Maine',1508,23);
INSERT INTO "django_geo_db_city" VALUES(979,'Gray','Gray, Maine',1509,23);
INSERT INTO "django_geo_db_city" VALUES(980,'Harrison','Harrison, Maine',1510,23);
INSERT INTO "django_geo_db_city" VALUES(981,'Hiram','Hiram, Maine',1511,23);
INSERT INTO "django_geo_db_city" VALUES(982,'Hollis Center','Hollis Center, Maine',1512,23);
INSERT INTO "django_geo_db_city" VALUES(983,'Kennebunk','Kennebunk, Maine',1513,23);
INSERT INTO "django_geo_db_city" VALUES(984,'Kennebunkport','Kennebunkport, Maine',1514,23);
INSERT INTO "django_geo_db_city" VALUES(985,'Parsonsfield','Parsonsfield, Maine',1515,23);
INSERT INTO "django_geo_db_city" VALUES(986,'Limerick','Limerick, Maine',1516,23);
INSERT INTO "django_geo_db_city" VALUES(987,'Limington','Limington, Maine',1517,23);
INSERT INTO "django_geo_db_city" VALUES(988,'Long Island','Long Island, Maine',1518,23);
INSERT INTO "django_geo_db_city" VALUES(989,'Lovell','Lovell, Maine',1519,23);
INSERT INTO "django_geo_db_city" VALUES(990,'Merepoint','Merepoint, Maine',1492,23);
INSERT INTO "django_geo_db_city" VALUES(991,'Moody','Moody, Maine',1520,23);
INSERT INTO "django_geo_db_city" VALUES(992,'Naples','Naples, Maine',1521,23);
INSERT INTO "django_geo_db_city" VALUES(993,'Newfield','Newfield, Maine',1522,23);
INSERT INTO "django_geo_db_city" VALUES(994,'North Bridgton','North Bridgton, Maine',1492,23);
INSERT INTO "django_geo_db_city" VALUES(995,'North Waterboro','North Waterboro, Maine',1523,23);
INSERT INTO "django_geo_db_city" VALUES(996,'Windham','Windham, Maine',1524,23);
INSERT INTO "django_geo_db_city" VALUES(997,'Ocean Park','Ocean Park, Maine',1525,23);
INSERT INTO "django_geo_db_city" VALUES(998,'Old Orchard Beach','Old Orchard Beach, Maine',1526,23);
INSERT INTO "django_geo_db_city" VALUES(999,'Ellsworth','Ellsworth, Maine',1527,23);
INSERT INTO "django_geo_db_city" VALUES(1000,'Orrs Island','Orrs Island, Maine',1528,23);
INSERT INTO "django_geo_db_city" VALUES(1001,'Porter','Porter, Maine',1529,23);
INSERT INTO "django_geo_db_city" VALUES(1002,'Pownal','Pownal, Maine',1530,23);
INSERT INTO "django_geo_db_city" VALUES(1003,'Scarborough','Scarborough, Maine',1531,23);
INSERT INTO "django_geo_db_city" VALUES(1004,'Saco','Saco, Maine',1533,23);
INSERT INTO "django_geo_db_city" VALUES(1005,'Sanford','Sanford, Maine',1534,23);
INSERT INTO "django_geo_db_city" VALUES(1006,'Sebago Lake','Sebago Lake, Maine',1536,23);
INSERT INTO "django_geo_db_city" VALUES(1007,'Shapleigh','Shapleigh, Maine',1537,23);
INSERT INTO "django_geo_db_city" VALUES(1008,'South Casco','South Casco, Maine',1538,23);
INSERT INTO "django_geo_db_city" VALUES(1009,'South Freeport','South Freeport, Maine',1539,23);
INSERT INTO "django_geo_db_city" VALUES(1010,'Harpswell','Harpswell, Maine',1540,23);
INSERT INTO "django_geo_db_city" VALUES(1011,'South Waterford','South Waterford, Maine',1541,23);
INSERT INTO "django_geo_db_city" VALUES(1012,'South Windham','South Windham, Maine',1492,23);
INSERT INTO "django_geo_db_city" VALUES(1013,'Springvale','Springvale, Maine',1542,23);
INSERT INTO "django_geo_db_city" VALUES(1014,'Standish','Standish, Maine',1543,23);
INSERT INTO "django_geo_db_city" VALUES(1015,'Steep Falls','Steep Falls, Maine',1544,23);
INSERT INTO "django_geo_db_city" VALUES(1016,'Topsham','Topsham, Maine',1545,23);
INSERT INTO "django_geo_db_city" VALUES(1017,'Waterboro','Waterboro, Maine',1546,23);
INSERT INTO "django_geo_db_city" VALUES(1018,'Waterford','Waterford, Maine',1547,23);
INSERT INTO "django_geo_db_city" VALUES(1019,'Wells','Wells, Maine',1548,23);
INSERT INTO "django_geo_db_city" VALUES(1020,'West Baldwin','West Baldwin, Maine',1549,23);
INSERT INTO "django_geo_db_city" VALUES(1021,'Westbrook','Westbrook, Maine',1550,23);
INSERT INTO "django_geo_db_city" VALUES(1022,'West Buxton','West Buxton, Maine',1551,23);
INSERT INTO "django_geo_db_city" VALUES(1023,'West Kennebunk','West Kennebunk, Maine',1552,23);
INSERT INTO "django_geo_db_city" VALUES(1024,'West Newfield','West Newfield, Maine',1553,23);
INSERT INTO "django_geo_db_city" VALUES(1025,'Yarmouth','Yarmouth, Maine',1554,23);
INSERT INTO "django_geo_db_city" VALUES(1026,'North Yarmouth','North Yarmouth, Maine',1555,23);
INSERT INTO "django_geo_db_city" VALUES(1027,'Portland','Portland, Maine',1556,23);
INSERT INTO "django_geo_db_city" VALUES(1028,'Falmouth','Falmouth, Maine',1560,23);
INSERT INTO "django_geo_db_city" VALUES(1029,'South Portland','South Portland, Maine',1561,23);
INSERT INTO "django_geo_db_city" VALUES(1030,'Cape Elizabeth','Cape Elizabeth, Maine',1562,23);
INSERT INTO "django_geo_db_city" VALUES(1031,'Peaks Island','Peaks Island, Maine',1563,23);
INSERT INTO "django_geo_db_city" VALUES(1032,'Cumberland Foreside','Cumberland Foreside, Maine',1565,23);
INSERT INTO "django_geo_db_city" VALUES(1033,'Auburn','Auburn, Maine',1566,23);
INSERT INTO "django_geo_db_city" VALUES(1034,'Andover','Andover, Maine',1568,23);
INSERT INTO "django_geo_db_city" VALUES(1035,'Bethel','Bethel, Maine',1569,23);
INSERT INTO "django_geo_db_city" VALUES(1036,'Bryant Pond','Bryant Pond, Maine',1570,23);
INSERT INTO "django_geo_db_city" VALUES(1037,'Buckfield','Buckfield, Maine',1571,23);
INSERT INTO "django_geo_db_city" VALUES(1038,'Canton','Canton, Maine',1572,23);
INSERT INTO "django_geo_db_city" VALUES(1039,'Durham','Durham, Maine',1573,23);
INSERT INTO "django_geo_db_city" VALUES(1040,'Danville','Danville, Maine',1574,23);
INSERT INTO "django_geo_db_city" VALUES(1041,'Dixfield','Dixfield, Maine',1575,23);
INSERT INTO "django_geo_db_city" VALUES(1042,'Dryden','Dryden, Maine',1576,23);
INSERT INTO "django_geo_db_city" VALUES(1043,'East Andover','East Andover, Maine',1577,23);
INSERT INTO "django_geo_db_city" VALUES(1044,'East Dixfield','East Dixfield, Maine',1578,23);
INSERT INTO "django_geo_db_city" VALUES(1045,'East Livermore','East Livermore, Maine',1579,23);
INSERT INTO "django_geo_db_city" VALUES(1046,'East Poland','East Poland, Maine',1580,23);
INSERT INTO "django_geo_db_city" VALUES(1047,'Stoneham','Stoneham, Maine',1581,23);
INSERT INTO "django_geo_db_city" VALUES(1048,'East Wilton','East Wilton, Maine',1582,23);
INSERT INTO "django_geo_db_city" VALUES(1049,'Greene','Greene, Maine',1583,23);
INSERT INTO "django_geo_db_city" VALUES(1050,'Hanover','Hanover, Maine',1584,23);
INSERT INTO "django_geo_db_city" VALUES(1051,'Hebron','Hebron, Maine',1585,23);
INSERT INTO "django_geo_db_city" VALUES(1052,'Jay','Jay, Maine',1586,23);
INSERT INTO "django_geo_db_city" VALUES(1053,'Lewiston','Lewiston, Maine',1587,23);
INSERT INTO "django_geo_db_city" VALUES(1054,'Lisbon','Lisbon, Maine',1588,23);
INSERT INTO "django_geo_db_city" VALUES(1055,'Lisbon Falls','Lisbon Falls, Maine',1589,23);
INSERT INTO "django_geo_db_city" VALUES(1056,'Livermore','Livermore, Maine',1590,23);
INSERT INTO "django_geo_db_city" VALUES(1057,'Livermore Falls','Livermore Falls, Maine',1591,23);
INSERT INTO "django_geo_db_city" VALUES(1058,'Locke Mills','Locke Mills, Maine',1592,23);
INSERT INTO "django_geo_db_city" VALUES(1059,'Mechanic Falls','Mechanic Falls, Maine',1593,23);
INSERT INTO "django_geo_db_city" VALUES(1060,'Mexico','Mexico, Maine',1594,23);
INSERT INTO "django_geo_db_city" VALUES(1061,'Minot','Minot, Maine',1595,23);
INSERT INTO "django_geo_db_city" VALUES(1062,'Monmouth','Monmouth, Maine',1596,23);
INSERT INTO "django_geo_db_city" VALUES(1063,'New Gloucester','New Gloucester, Maine',1597,23);
INSERT INTO "django_geo_db_city" VALUES(1064,'Newry','Newry, Maine',1598,23);
INSERT INTO "django_geo_db_city" VALUES(1065,'North Jay','North Jay, Maine',1599,23);
INSERT INTO "django_geo_db_city" VALUES(1066,'Leeds','Leeds, Maine',1600,23);
INSERT INTO "django_geo_db_city" VALUES(1067,'North Monmouth','North Monmouth, Maine',1601,23);
INSERT INTO "django_geo_db_city" VALUES(1068,'North Turner','North Turner, Maine',1602,23);
INSERT INTO "django_geo_db_city" VALUES(1069,'North Waterford','North Waterford, Maine',1541,23);
INSERT INTO "django_geo_db_city" VALUES(1070,'Norway','Norway, Maine',1603,23);
INSERT INTO "django_geo_db_city" VALUES(1071,'Oxford','Oxford, Maine',1604,23);
INSERT INTO "django_geo_db_city" VALUES(1072,'Paris','Paris, Maine',1605,23);
INSERT INTO "django_geo_db_city" VALUES(1073,'Poland','Poland, Maine',1607,23);
INSERT INTO "django_geo_db_city" VALUES(1074,'Roxbury','Roxbury, Maine',1608,23);
INSERT INTO "django_geo_db_city" VALUES(1075,'Rumford','Rumford, Maine',1609,23);
INSERT INTO "django_geo_db_city" VALUES(1076,'Rumford Center','Rumford Center, Maine',1610,23);
INSERT INTO "django_geo_db_city" VALUES(1077,'Sabattus','Sabattus, Maine',1612,23);
INSERT INTO "django_geo_db_city" VALUES(1078,'South Paris','South Paris, Maine',1613,23);
INSERT INTO "django_geo_db_city" VALUES(1079,'Turner','Turner, Maine',1614,23);
INSERT INTO "django_geo_db_city" VALUES(1080,'Turner Center','Turner Center, Maine',1567,23);
INSERT INTO "django_geo_db_city" VALUES(1081,'Wayne','Wayne, Maine',1615,23);
INSERT INTO "django_geo_db_city" VALUES(1082,'Weld','Weld, Maine',1616,23);
INSERT INTO "django_geo_db_city" VALUES(1083,'West Bethel','West Bethel, Maine',1617,23);
INSERT INTO "django_geo_db_city" VALUES(1084,'Bowdoin','Bowdoin, Maine',1618,23);
INSERT INTO "django_geo_db_city" VALUES(1085,'West Minot','West Minot, Maine',1567,23);
INSERT INTO "django_geo_db_city" VALUES(1086,'West Paris','West Paris, Maine',1619,23);
INSERT INTO "django_geo_db_city" VALUES(1087,'Peru','Peru, Maine',1620,23);
INSERT INTO "django_geo_db_city" VALUES(1088,'West Poland','West Poland, Maine',1621,23);
INSERT INTO "django_geo_db_city" VALUES(1089,'Sumner','Sumner, Maine',1622,23);
INSERT INTO "django_geo_db_city" VALUES(1090,'Wilton','Wilton, Maine',1623,23);
INSERT INTO "django_geo_db_city" VALUES(1091,'Richmond','Richmond, Maine',1625,23);
INSERT INTO "django_geo_db_city" VALUES(1092,'Augusta','Augusta, Maine',1626,23);
INSERT INTO "django_geo_db_city" VALUES(1093,'Coopers Mills','Coopers Mills, Maine',1629,23);
INSERT INTO "django_geo_db_city" VALUES(1094,'Dresden','Dresden, Maine',1630,23);
INSERT INTO "django_geo_db_city" VALUES(1095,'East Winthrop','East Winthrop, Maine',1627,23);
INSERT INTO "django_geo_db_city" VALUES(1096,'Farmingdale','Farmingdale, Maine',1631,23);
INSERT INTO "django_geo_db_city" VALUES(1097,'Gardiner','Gardiner, Maine',1632,23);
INSERT INTO "django_geo_db_city" VALUES(1098,'Randolph','Randolph, Maine',1633,23);
INSERT INTO "django_geo_db_city" VALUES(1099,'Hallowell','Hallowell, Maine',1634,23);
INSERT INTO "django_geo_db_city" VALUES(1100,'Jefferson','Jefferson, Maine',1635,23);
INSERT INTO "django_geo_db_city" VALUES(1101,'Kents Hill','Kents Hill, Maine',1636,23);
INSERT INTO "django_geo_db_city" VALUES(1102,'Litchfield','Litchfield, Maine',1637,23);
INSERT INTO "django_geo_db_city" VALUES(1103,'Manchester','Manchester, Maine',1638,23);
INSERT INTO "django_geo_db_city" VALUES(1104,'Mount Vernon','Mount Vernon, Maine',1639,23);
INSERT INTO "django_geo_db_city" VALUES(1105,'Whitefield','Whitefield, Maine',1640,23);
INSERT INTO "django_geo_db_city" VALUES(1106,'Palermo','Palermo, Maine',1641,23);
INSERT INTO "django_geo_db_city" VALUES(1107,'Readfield','Readfield, Maine',1642,23);
INSERT INTO "django_geo_db_city" VALUES(1108,'South China','South China, Maine',1644,23);
INSERT INTO "django_geo_db_city" VALUES(1109,'South Gardiner','South Gardiner, Maine',1645,23);
INSERT INTO "django_geo_db_city" VALUES(1110,'Vienna','Vienna, Maine',1646,23);
INSERT INTO "django_geo_db_city" VALUES(1111,'Windsor','Windsor, Maine',1647,23);
INSERT INTO "django_geo_db_city" VALUES(1112,'Winthrop','Winthrop, Maine',1648,23);
INSERT INTO "django_geo_db_city" VALUES(1113,'Bangor','Bangor, Maine',1649,23);
INSERT INTO "django_geo_db_city" VALUES(1114,'Abbot','Abbot, Maine',1651,23);
INSERT INTO "django_geo_db_city" VALUES(1115,'Aurora','Aurora, Maine',1652,23);
INSERT INTO "django_geo_db_city" VALUES(1116,'Bradford','Bradford, Maine',1653,23);
INSERT INTO "django_geo_db_city" VALUES(1117,'Bradley','Bradley, Maine',1654,23);
INSERT INTO "django_geo_db_city" VALUES(1118,'Brewer','Brewer, Maine',1655,23);
INSERT INTO "django_geo_db_city" VALUES(1119,'Brookton','Brookton, Maine',1656,23);
INSERT INTO "django_geo_db_city" VALUES(1120,'Brownville','Brownville, Maine',1657,23);
INSERT INTO "django_geo_db_city" VALUES(1121,'Brownville Junction','Brownville Junction, Maine',1658,23);
INSERT INTO "django_geo_db_city" VALUES(1122,'Bucksport','Bucksport, Maine',1659,23);
INSERT INTO "django_geo_db_city" VALUES(1123,'Burlington','Burlington, Maine',1660,23);
INSERT INTO "django_geo_db_city" VALUES(1124,'Cardville','Cardville, Maine',1661,23);
INSERT INTO "django_geo_db_city" VALUES(1125,'Carmel','Carmel, Maine',1662,23);
INSERT INTO "django_geo_db_city" VALUES(1126,'Castine','Castine, Maine',1663,23);
INSERT INTO "django_geo_db_city" VALUES(1127,'Charleston','Charleston, Maine',1665,23);
INSERT INTO "django_geo_db_city" VALUES(1128,'Costigan','Costigan, Maine',1666,23);
INSERT INTO "django_geo_db_city" VALUES(1129,'Danforth','Danforth, Maine',1667,23);
INSERT INTO "django_geo_db_city" VALUES(1130,'Dover Foxcroft','Dover Foxcroft, Maine',1668,23);
INSERT INTO "django_geo_db_city" VALUES(1131,'Corinth','Corinth, Maine',1669,23);
INSERT INTO "django_geo_db_city" VALUES(1132,'Eddington','Eddington, Maine',1670,23);
INSERT INTO "django_geo_db_city" VALUES(1133,'Holden','Holden, Maine',1671,23);
INSERT INTO "django_geo_db_city" VALUES(1134,'East Millinocket','East Millinocket, Maine',1672,23);
INSERT INTO "django_geo_db_city" VALUES(1135,'East Orland','East Orland, Maine',1673,23);
INSERT INTO "django_geo_db_city" VALUES(1136,'Etna','Etna, Maine',1674,23);
INSERT INTO "django_geo_db_city" VALUES(1137,'Exeter','Exeter, Maine',1675,23);
INSERT INTO "django_geo_db_city" VALUES(1138,'Frankfort','Frankfort, Maine',1676,23);
INSERT INTO "django_geo_db_city" VALUES(1139,'Greenville','Greenville, Maine',1677,23);
INSERT INTO "django_geo_db_city" VALUES(1140,'Greenville Junction','Greenville Junction, Maine',1678,23);
INSERT INTO "django_geo_db_city" VALUES(1141,'Guilford','Guilford, Maine',1679,23);
INSERT INTO "django_geo_db_city" VALUES(1142,'Hampden','Hampden, Maine',1680,23);
INSERT INTO "django_geo_db_city" VALUES(1143,'Howland','Howland, Maine',1681,23);
INSERT INTO "django_geo_db_city" VALUES(1144,'Hudson','Hudson, Maine',1682,23);
INSERT INTO "django_geo_db_city" VALUES(1145,'Kenduskeag','Kenduskeag, Maine',1683,23);
INSERT INTO "django_geo_db_city" VALUES(1146,'Kingman','Kingman, Maine',1684,23);
INSERT INTO "django_geo_db_city" VALUES(1147,'Lagrange','Lagrange, Maine',1685,23);
INSERT INTO "django_geo_db_city" VALUES(1148,'Lambert Lake','Lambert Lake, Maine',1686,23);
INSERT INTO "django_geo_db_city" VALUES(1149,'Lee','Lee, Maine',1687,23);
INSERT INTO "django_geo_db_city" VALUES(1150,'Levant','Levant, Maine',1688,23);
INSERT INTO "django_geo_db_city" VALUES(1151,'Lincoln','Lincoln, Maine',1689,23);
INSERT INTO "django_geo_db_city" VALUES(1152,'Mattawamkeag','Mattawamkeag, Maine',1690,23);
INSERT INTO "django_geo_db_city" VALUES(1153,'Medway','Medway, Maine',1691,23);
INSERT INTO "django_geo_db_city" VALUES(1154,'Milford','Milford, Maine',1692,23);
INSERT INTO "django_geo_db_city" VALUES(1155,'Millinocket','Millinocket, Maine',1693,23);
INSERT INTO "django_geo_db_city" VALUES(1156,'Milo','Milo, Maine',1694,23);
INSERT INTO "django_geo_db_city" VALUES(1157,'Monson','Monson, Maine',1695,23);
INSERT INTO "django_geo_db_city" VALUES(1158,'Cary','Cary, Maine',1696,23);
INSERT INTO "django_geo_db_city" VALUES(1159,'Olamon','Olamon, Maine',1650,23);
INSERT INTO "django_geo_db_city" VALUES(1160,'Old Town','Old Town, Maine',1697,23);
INSERT INTO "django_geo_db_city" VALUES(1161,'Orono','Orono, Maine',1698,23);
INSERT INTO "django_geo_db_city" VALUES(1162,'Orient','Orient, Maine',1699,23);
INSERT INTO "django_geo_db_city" VALUES(1163,'Orland','Orland, Maine',1700,23);
INSERT INTO "django_geo_db_city" VALUES(1164,'Orrington','Orrington, Maine',1702,23);
INSERT INTO "django_geo_db_city" VALUES(1165,'Passadumkeag','Passadumkeag, Maine',1703,23);
INSERT INTO "django_geo_db_city" VALUES(1166,'Penobscot','Penobscot, Maine',1704,23);
INSERT INTO "django_geo_db_city" VALUES(1167,'Rockwood','Rockwood, Maine',1705,23);
INSERT INTO "django_geo_db_city" VALUES(1168,'Sangerville','Sangerville, Maine',1706,23);
INSERT INTO "django_geo_db_city" VALUES(1169,'Sebec','Sebec, Maine',1707,23);
INSERT INTO "django_geo_db_city" VALUES(1170,'Shirley Mills','Shirley Mills, Maine',1707,23);
INSERT INTO "django_geo_db_city" VALUES(1171,'Springfield','Springfield, Maine',1708,23);
INSERT INTO "django_geo_db_city" VALUES(1172,'Stetson','Stetson, Maine',1709,23);
INSERT INTO "django_geo_db_city" VALUES(1173,'Stillwater','Stillwater, Maine',1710,23);
INSERT INTO "django_geo_db_city" VALUES(1174,'Topsfield','Topsfield, Maine',1711,23);
INSERT INTO "django_geo_db_city" VALUES(1175,'Vanceboro','Vanceboro, Maine',1686,23);
INSERT INTO "django_geo_db_city" VALUES(1176,'Waite','Waite, Maine',1686,23);
INSERT INTO "django_geo_db_city" VALUES(1177,'West Enfield','West Enfield, Maine',1712,23);
INSERT INTO "django_geo_db_city" VALUES(1178,'Winn','Winn, Maine',1713,23);
INSERT INTO "django_geo_db_city" VALUES(1179,'Winterport','Winterport, Maine',1714,23);
INSERT INTO "django_geo_db_city" VALUES(1180,'Wytopitlock','Wytopitlock, Maine',1715,23);
INSERT INTO "django_geo_db_city" VALUES(1181,'Bath','Bath, Maine',1716,23);
INSERT INTO "django_geo_db_city" VALUES(1182,'Alna','Alna, Maine',1717,23);
INSERT INTO "django_geo_db_city" VALUES(1183,'Bayville','Bayville, Maine',1718,23);
INSERT INTO "django_geo_db_city" VALUES(1184,'Boothbay','Boothbay, Maine',1719,23);
INSERT INTO "django_geo_db_city" VALUES(1185,'Boothbay Harbor','Boothbay Harbor, Maine',1720,23);
INSERT INTO "django_geo_db_city" VALUES(1186,'Bristol','Bristol, Maine',1721,23);
INSERT INTO "django_geo_db_city" VALUES(1187,'Chamberlain','Chamberlain, Maine',1722,23);
INSERT INTO "django_geo_db_city" VALUES(1188,'Damariscotta','Damariscotta, Maine',1723,23);
INSERT INTO "django_geo_db_city" VALUES(1189,'East Boothbay','East Boothbay, Maine',1724,23);
INSERT INTO "django_geo_db_city" VALUES(1190,'Georgetown','Georgetown, Maine',1725,23);
INSERT INTO "django_geo_db_city" VALUES(1191,'Friendship','Friendship, Maine',1726,23);
INSERT INTO "django_geo_db_city" VALUES(1192,'Isle Of Springs','Isle Of Springs, Maine',1718,23);
INSERT INTO "django_geo_db_city" VALUES(1193,'Bremen','Bremen, Maine',1728,23);
INSERT INTO "django_geo_db_city" VALUES(1194,'Newagen','Newagen, Maine',1718,23);
INSERT INTO "django_geo_db_city" VALUES(1195,'Newcastle','Newcastle, Maine',1729,23);
INSERT INTO "django_geo_db_city" VALUES(1196,'New Harbor','New Harbor, Maine',1730,23);
INSERT INTO "django_geo_db_city" VALUES(1197,'Nobleboro','Nobleboro, Maine',1731,23);
INSERT INTO "django_geo_db_city" VALUES(1198,'Edgecomb','Edgecomb, Maine',1732,23);
INSERT INTO "django_geo_db_city" VALUES(1199,'Pemaquid','Pemaquid, Maine',1734,23);
INSERT INTO "django_geo_db_city" VALUES(1200,'Phippsburg','Phippsburg, Maine',1735,23);
INSERT INTO "django_geo_db_city" VALUES(1201,'Cushing','Cushing, Maine',1736,23);
INSERT INTO "django_geo_db_city" VALUES(1202,'Round Pond','Round Pond, Maine',1737,23);
INSERT INTO "django_geo_db_city" VALUES(1203,'Sebasco Estates','Sebasco Estates, Maine',1738,23);
INSERT INTO "django_geo_db_city" VALUES(1204,'Small Point','Small Point, Maine',1739,23);
INSERT INTO "django_geo_db_city" VALUES(1205,'South Bristol','South Bristol, Maine',1740,23);
INSERT INTO "django_geo_db_city" VALUES(1206,'Squirrel Island','Squirrel Island, Maine',1718,23);
INSERT INTO "django_geo_db_city" VALUES(1207,'Trevett','Trevett, Maine',1741,23);
INSERT INTO "django_geo_db_city" VALUES(1208,'Waldoboro','Waldoboro, Maine',1742,23);
INSERT INTO "django_geo_db_city" VALUES(1209,'Walpole','Walpole, Maine',1743,23);
INSERT INTO "django_geo_db_city" VALUES(1210,'Washington','Washington, Maine',1744,23);
INSERT INTO "django_geo_db_city" VALUES(1211,'West Boothbay Harbor','West Boothbay Harbor, Maine',1745,23);
INSERT INTO "django_geo_db_city" VALUES(1212,'Southport','Southport, Maine',1746,23);
INSERT INTO "django_geo_db_city" VALUES(1213,'Wiscasset','Wiscasset, Maine',1747,23);
INSERT INTO "django_geo_db_city" VALUES(1214,'Woolwich','Woolwich, Maine',1748,23);
INSERT INTO "django_geo_db_city" VALUES(1215,'Winter Harbor','Winter Harbor, Maine',1749,23);
INSERT INTO "django_geo_db_city" VALUES(1216,'Addison','Addison, Maine',1751,23);
INSERT INTO "django_geo_db_city" VALUES(1217,'Gouldsboro','Gouldsboro, Maine',1752,23);
INSERT INTO "django_geo_db_city" VALUES(1218,'Bar Harbor','Bar Harbor, Maine',1753,23);
INSERT INTO "django_geo_db_city" VALUES(1219,'Beals','Beals, Maine',1754,23);
INSERT INTO "django_geo_db_city" VALUES(1220,'Bernard','Bernard, Maine',1755,23);
INSERT INTO "django_geo_db_city" VALUES(1221,'Birch Harbor','Birch Harbor, Maine',1756,23);
INSERT INTO "django_geo_db_city" VALUES(1222,'Blue Hill','Blue Hill, Maine',1757,23);
INSERT INTO "django_geo_db_city" VALUES(1223,'Blue Hill Falls','Blue Hill Falls, Maine',1758,23);
INSERT INTO "django_geo_db_city" VALUES(1224,'Brooklin','Brooklin, Maine',1759,23);
INSERT INTO "django_geo_db_city" VALUES(1225,'Brooksville','Brooksville, Maine',1760,23);
INSERT INTO "django_geo_db_city" VALUES(1226,'Calais','Calais, Maine',1761,23);
INSERT INTO "django_geo_db_city" VALUES(1227,'Eastport','Eastport, Maine',1762,23);
INSERT INTO "django_geo_db_city" VALUES(1228,'Cherryfield','Cherryfield, Maine',1763,23);
INSERT INTO "django_geo_db_city" VALUES(1229,'Columbia Falls','Columbia Falls, Maine',1764,23);
INSERT INTO "django_geo_db_city" VALUES(1230,'Corea','Corea, Maine',1765,23);
INSERT INTO "django_geo_db_city" VALUES(1231,'Cranberry Isles','Cranberry Isles, Maine',1766,23);
INSERT INTO "django_geo_db_city" VALUES(1232,'Cutler','Cutler, Maine',1767,23);
INSERT INTO "django_geo_db_city" VALUES(1233,'Deer Isle','Deer Isle, Maine',1768,23);
INSERT INTO "django_geo_db_city" VALUES(1234,'Dennysville','Dennysville, Maine',1769,23);
INSERT INTO "django_geo_db_city" VALUES(1235,'East Blue Hill','East Blue Hill, Maine',1770,23);
INSERT INTO "django_geo_db_city" VALUES(1236,'East Machias','East Machias, Maine',1771,23);
INSERT INTO "django_geo_db_city" VALUES(1237,'Franklin','Franklin, Maine',1773,23);
INSERT INTO "django_geo_db_city" VALUES(1238,'Frenchboro','Frenchboro, Maine',1774,23);
INSERT INTO "django_geo_db_city" VALUES(1239,'Grand Lake Stream','Grand Lake Stream, Maine',1775,23);
INSERT INTO "django_geo_db_city" VALUES(1240,'Hancock','Hancock, Maine',1776,23);
INSERT INTO "django_geo_db_city" VALUES(1241,'Harborside','Harborside, Maine',1777,23);
INSERT INTO "django_geo_db_city" VALUES(1242,'Harrington','Harrington, Maine',1778,23);
INSERT INTO "django_geo_db_city" VALUES(1243,'Hulls Cove','Hulls Cove, Maine',1779,23);
INSERT INTO "django_geo_db_city" VALUES(1244,'Isle Au Haut','Isle Au Haut, Maine',1780,23);
INSERT INTO "django_geo_db_city" VALUES(1245,'Islesford','Islesford, Maine',1781,23);
INSERT INTO "django_geo_db_city" VALUES(1246,'Jonesboro','Jonesboro, Maine',1782,23);
INSERT INTO "django_geo_db_city" VALUES(1247,'Jonesport','Jonesport, Maine',1783,23);
INSERT INTO "django_geo_db_city" VALUES(1248,'Little Deer Isle','Little Deer Isle, Maine',1784,23);
INSERT INTO "django_geo_db_city" VALUES(1249,'Lubec','Lubec, Maine',1785,23);
INSERT INTO "django_geo_db_city" VALUES(1250,'Bass Harbor','Bass Harbor, Maine',1786,23);
INSERT INTO "django_geo_db_city" VALUES(1251,'Machias','Machias, Maine',1787,23);
INSERT INTO "django_geo_db_city" VALUES(1252,'Machiasport','Machiasport, Maine',1788,23);
INSERT INTO "django_geo_db_city" VALUES(1253,'Manset','Manset, Maine',1779,23);
INSERT INTO "django_geo_db_city" VALUES(1254,'Meddybemps','Meddybemps, Maine',1789,23);
INSERT INTO "django_geo_db_city" VALUES(1255,'Milbridge','Milbridge, Maine',1790,23);
INSERT INTO "django_geo_db_city" VALUES(1256,'Mount Desert','Mount Desert, Maine',1791,23);
INSERT INTO "django_geo_db_city" VALUES(1257,'Northeast Harbor','Northeast Harbor, Maine',1792,23);
INSERT INTO "django_geo_db_city" VALUES(1258,'Sullivan','Sullivan, Maine',1793,23);
INSERT INTO "django_geo_db_city" VALUES(1259,'Otter Creek','Otter Creek, Maine',1779,23);
INSERT INTO "django_geo_db_city" VALUES(1260,'Pembroke','Pembroke, Maine',1794,23);
INSERT INTO "django_geo_db_city" VALUES(1261,'Perry','Perry, Maine',1795,23);
INSERT INTO "django_geo_db_city" VALUES(1262,'Princeton','Princeton, Maine',1796,23);
INSERT INTO "django_geo_db_city" VALUES(1263,'Prospect Harbor','Prospect Harbor, Maine',1797,23);
INSERT INTO "django_geo_db_city" VALUES(1264,'Robbinston','Robbinston, Maine',1798,23);
INSERT INTO "django_geo_db_city" VALUES(1265,'Salsbury Cove','Salsbury Cove, Maine',1799,23);
INSERT INTO "django_geo_db_city" VALUES(1266,'Sargentville','Sargentville, Maine',1800,23);
INSERT INTO "django_geo_db_city" VALUES(1267,'Seal Cove','Seal Cove, Maine',1801,23);
INSERT INTO "django_geo_db_city" VALUES(1268,'Seal Harbor','Seal Harbor, Maine',1802,23);
INSERT INTO "django_geo_db_city" VALUES(1269,'Sedgwick','Sedgwick, Maine',1803,23);
INSERT INTO "django_geo_db_city" VALUES(1270,'Sorrento','Sorrento, Maine',1804,23);
INSERT INTO "django_geo_db_city" VALUES(1271,'Southwest Harbor','Southwest Harbor, Maine',1805,23);
INSERT INTO "django_geo_db_city" VALUES(1272,'Steuben','Steuben, Maine',1806,23);
INSERT INTO "django_geo_db_city" VALUES(1273,'Stonington','Stonington, Maine',1807,23);
INSERT INTO "django_geo_db_city" VALUES(1274,'Sunset','Sunset, Maine',1808,23);
INSERT INTO "django_geo_db_city" VALUES(1275,'Surry','Surry, Maine',1809,23);
INSERT INTO "django_geo_db_city" VALUES(1276,'Swans Island','Swans Island, Maine',1810,23);
INSERT INTO "django_geo_db_city" VALUES(1277,'Wesley','Wesley, Maine',1686,23);
INSERT INTO "django_geo_db_city" VALUES(1278,'West Tremont','West Tremont, Maine',1779,23);
INSERT INTO "django_geo_db_city" VALUES(1279,'Whiting','Whiting, Maine',1811,23);
INSERT INTO "django_geo_db_city" VALUES(1280,'Baileyville','Baileyville, Maine',1813,23);
INSERT INTO "django_geo_db_city" VALUES(1281,'Houlton','Houlton, Maine',1815,23);
INSERT INTO "django_geo_db_city" VALUES(1282,'Ashland','Ashland, Maine',1816,23);
INSERT INTO "django_geo_db_city" VALUES(1283,'Benedicta','Benedicta, Maine',1817,23);
INSERT INTO "django_geo_db_city" VALUES(1284,'Blaine','Blaine, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1285,'Bridgewater','Bridgewater, Maine',1819,23);
INSERT INTO "django_geo_db_city" VALUES(1286,'Caribou','Caribou, Maine',1820,23);
INSERT INTO "django_geo_db_city" VALUES(1287,'Clayton Lake','Clayton Lake, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1288,'Crouseville','Crouseville, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1289,'Eagle Lake','Eagle Lake, Maine',1821,23);
INSERT INTO "django_geo_db_city" VALUES(1290,'Easton','Easton, Maine',1822,23);
INSERT INTO "django_geo_db_city" VALUES(1291,'Estcourt Station','Estcourt Station, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1292,'Fort Fairfield','Fort Fairfield, Maine',1823,23);
INSERT INTO "django_geo_db_city" VALUES(1293,'Fort Kent','Fort Kent, Maine',1824,23);
INSERT INTO "django_geo_db_city" VALUES(1294,'Fort Kent Mills','Fort Kent Mills, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1295,'Frenchville','Frenchville, Maine',1825,23);
INSERT INTO "django_geo_db_city" VALUES(1296,'Grand Isle','Grand Isle, Maine',1826,23);
INSERT INTO "django_geo_db_city" VALUES(1297,'Island Falls','Island Falls, Maine',1827,23);
INSERT INTO "django_geo_db_city" VALUES(1298,'Limestone','Limestone, Maine',1828,23);
INSERT INTO "django_geo_db_city" VALUES(1299,'Madawaska','Madawaska, Maine',1831,23);
INSERT INTO "django_geo_db_city" VALUES(1300,'Mapleton','Mapleton, Maine',1832,23);
INSERT INTO "django_geo_db_city" VALUES(1301,'Mars Hill','Mars Hill, Maine',1833,23);
INSERT INTO "django_geo_db_city" VALUES(1302,'Masardis','Masardis, Maine',1834,23);
INSERT INTO "django_geo_db_city" VALUES(1303,'Monticello','Monticello, Maine',1835,23);
INSERT INTO "django_geo_db_city" VALUES(1304,'New Limerick','New Limerick, Maine',1836,23);
INSERT INTO "django_geo_db_city" VALUES(1305,'New Sweden','New Sweden, Maine',1837,23);
INSERT INTO "django_geo_db_city" VALUES(1306,'Oakfield','Oakfield, Maine',1838,23);
INSERT INTO "django_geo_db_city" VALUES(1307,'Oxbow','Oxbow, Maine',1839,23);
INSERT INTO "django_geo_db_city" VALUES(1308,'Patten','Patten, Maine',1840,23);
INSERT INTO "django_geo_db_city" VALUES(1309,'Perham','Perham, Maine',1841,23);
INSERT INTO "django_geo_db_city" VALUES(1310,'Portage','Portage, Maine',1842,23);
INSERT INTO "django_geo_db_city" VALUES(1311,'Presque Isle','Presque Isle, Maine',1843,23);
INSERT INTO "django_geo_db_city" VALUES(1312,'Quimby','Quimby, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1313,'Saint Agatha','Saint Agatha, Maine',1844,23);
INSERT INTO "django_geo_db_city" VALUES(1314,'Saint David','Saint David, Maine',1845,23);
INSERT INTO "django_geo_db_city" VALUES(1315,'Saint Francis','Saint Francis, Maine',1846,23);
INSERT INTO "django_geo_db_city" VALUES(1316,'Sheridan','Sheridan, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1317,'Sherman Mills','Sherman Mills, Maine',1847,23);
INSERT INTO "django_geo_db_city" VALUES(1318,'Sherman Station','Sherman Station, Maine',1848,23);
INSERT INTO "django_geo_db_city" VALUES(1319,'Sinclair','Sinclair, Maine',1849,23);
INSERT INTO "django_geo_db_city" VALUES(1320,'Smyrna Mills','Smyrna Mills, Maine',1850,23);
INSERT INTO "django_geo_db_city" VALUES(1321,'Soldier Pond','Soldier Pond, Maine',1851,23);
INSERT INTO "django_geo_db_city" VALUES(1322,'Stacyville','Stacyville, Maine',1650,23);
INSERT INTO "django_geo_db_city" VALUES(1323,'Stockholm','Stockholm, Maine',1852,23);
INSERT INTO "django_geo_db_city" VALUES(1324,'Van Buren','Van Buren, Maine',1853,23);
INSERT INTO "django_geo_db_city" VALUES(1325,'Washburn','Washburn, Maine',1854,23);
INSERT INTO "django_geo_db_city" VALUES(1326,'Westfield','Westfield, Maine',1855,23);
INSERT INTO "django_geo_db_city" VALUES(1327,'Winterville','Winterville, Maine',1818,23);
INSERT INTO "django_geo_db_city" VALUES(1328,'Camden','Camden, Maine',1856,23);
INSERT INTO "django_geo_db_city" VALUES(1329,'Rockland','Rockland, Maine',1857,23);
INSERT INTO "django_geo_db_city" VALUES(1330,'Owls Head','Owls Head, Maine',1858,23);
INSERT INTO "django_geo_db_city" VALUES(1331,'Glen Cove','Glen Cove, Maine',1860,23);
INSERT INTO "django_geo_db_city" VALUES(1332,'Hope','Hope, Maine',1861,23);
INSERT INTO "django_geo_db_city" VALUES(1333,'Islesboro','Islesboro, Maine',1862,23);
INSERT INTO "django_geo_db_city" VALUES(1334,'Lincolnville','Lincolnville, Maine',1863,23);
INSERT INTO "django_geo_db_city" VALUES(1335,'Lincolnville Center','Lincolnville Center, Maine',1864,23);
INSERT INTO "django_geo_db_city" VALUES(1336,'Matinicus','Matinicus, Maine',1865,23);
INSERT INTO "django_geo_db_city" VALUES(1337,'Monhegan','Monhegan, Maine',1866,23);
INSERT INTO "django_geo_db_city" VALUES(1338,'North Haven','North Haven, Maine',1867,23);
INSERT INTO "django_geo_db_city" VALUES(1339,'Port Clyde','Port Clyde, Maine',1869,23);
INSERT INTO "django_geo_db_city" VALUES(1340,'Rockport','Rockport, Maine',1870,23);
INSERT INTO "django_geo_db_city" VALUES(1341,'Saint George','Saint George, Maine',1871,23);
INSERT INTO "django_geo_db_city" VALUES(1342,'South Thomaston','South Thomaston, Maine',1872,23);
INSERT INTO "django_geo_db_city" VALUES(1343,'Spruce Head','Spruce Head, Maine',1873,23);
INSERT INTO "django_geo_db_city" VALUES(1344,'Tenants Harbor','Tenants Harbor, Maine',1874,23);
INSERT INTO "django_geo_db_city" VALUES(1345,'Thomaston','Thomaston, Maine',1875,23);
INSERT INTO "django_geo_db_city" VALUES(1346,'Union','Union, Maine',1876,23);
INSERT INTO "django_geo_db_city" VALUES(1347,'Vinalhaven','Vinalhaven, Maine',1877,23);
INSERT INTO "django_geo_db_city" VALUES(1348,'Warren','Warren, Maine',1878,23);
INSERT INTO "django_geo_db_city" VALUES(1349,'West Rockport','West Rockport, Maine',1879,23);
INSERT INTO "django_geo_db_city" VALUES(1350,'Waterville','Waterville, Maine',1880,23);
INSERT INTO "django_geo_db_city" VALUES(1351,'Albion','Albion, Maine',1882,23);
INSERT INTO "django_geo_db_city" VALUES(1352,'Anson','Anson, Maine',1883,23);
INSERT INTO "django_geo_db_city" VALUES(1353,'Athens','Athens, Maine',1884,23);
INSERT INTO "django_geo_db_city" VALUES(1354,'Belfast','Belfast, Maine',1885,23);
INSERT INTO "django_geo_db_city" VALUES(1355,'Belgrade','Belgrade, Maine',1886,23);
INSERT INTO "django_geo_db_city" VALUES(1356,'Belgrade Lakes','Belgrade Lakes, Maine',1627,23);
INSERT INTO "django_geo_db_city" VALUES(1357,'Bingham','Bingham, Maine',1887,23);
INSERT INTO "django_geo_db_city" VALUES(1358,'Brooks','Brooks, Maine',1888,23);
INSERT INTO "django_geo_db_city" VALUES(1359,'Burnham','Burnham, Maine',1889,23);
INSERT INTO "django_geo_db_city" VALUES(1360,'Cambridge','Cambridge, Maine',1890,23);
INSERT INTO "django_geo_db_city" VALUES(1361,'Canaan','Canaan, Maine',1891,23);
INSERT INTO "django_geo_db_city" VALUES(1362,'Caratunk','Caratunk, Maine',1892,23);
INSERT INTO "django_geo_db_city" VALUES(1363,'China','China, Maine',1893,23);
INSERT INTO "django_geo_db_city" VALUES(1364,'Clinton','Clinton, Maine',1894,23);
INSERT INTO "django_geo_db_city" VALUES(1365,'Corinna','Corinna, Maine',1895,23);
INSERT INTO "django_geo_db_city" VALUES(1366,'Detroit','Detroit, Maine',1896,23);
INSERT INTO "django_geo_db_city" VALUES(1367,'Dexter','Dexter, Maine',1897,23);
INSERT INTO "django_geo_db_city" VALUES(1368,'Dixmont','Dixmont, Maine',1898,23);
INSERT INTO "django_geo_db_city" VALUES(1369,'East Newport','East Newport, Maine',1650,23);
INSERT INTO "django_geo_db_city" VALUES(1370,'East Vassalboro','East Vassalboro, Maine',1627,23);
INSERT INTO "django_geo_db_city" VALUES(1371,'Eustis','Eustis, Maine',1899,23);
INSERT INTO "django_geo_db_city" VALUES(1372,'Fairfield','Fairfield, Maine',1900,23);
INSERT INTO "django_geo_db_city" VALUES(1373,'Farmington','Farmington, Maine',1901,23);
INSERT INTO "django_geo_db_city" VALUES(1374,'Garland','Garland, Maine',1902,23);
INSERT INTO "django_geo_db_city" VALUES(1375,'Farmington Falls','Farmington Falls, Maine',1903,23);
INSERT INTO "django_geo_db_city" VALUES(1376,'Freedom','Freedom, Maine',1904,23);
INSERT INTO "django_geo_db_city" VALUES(1377,'Harmony','Harmony, Maine',1905,23);
INSERT INTO "django_geo_db_city" VALUES(1378,'Hartland','Hartland, Maine',1906,23);
INSERT INTO "django_geo_db_city" VALUES(1379,'Hinckley','Hinckley, Maine',1907,23);
INSERT INTO "django_geo_db_city" VALUES(1380,'Jackman','Jackman, Maine',1908,23);
INSERT INTO "django_geo_db_city" VALUES(1381,'Kingfield','Kingfield, Maine',1909,23);
INSERT INTO "django_geo_db_city" VALUES(1382,'Liberty','Liberty, Maine',1910,23);
INSERT INTO "django_geo_db_city" VALUES(1383,'Madison','Madison, Maine',1911,23);
INSERT INTO "django_geo_db_city" VALUES(1384,'Monroe','Monroe, Maine',1912,23);
INSERT INTO "django_geo_db_city" VALUES(1385,'Morrill','Morrill, Maine',1913,23);
INSERT INTO "django_geo_db_city" VALUES(1386,'Newport','Newport, Maine',1914,23);
INSERT INTO "django_geo_db_city" VALUES(1387,'New Portland','New Portland, Maine',1915,23);
INSERT INTO "django_geo_db_city" VALUES(1388,'New Sharon','New Sharon, Maine',1916,23);
INSERT INTO "django_geo_db_city" VALUES(1389,'New Vineyard','New Vineyard, Maine',1917,23);
INSERT INTO "django_geo_db_city" VALUES(1390,'Norridgewock','Norridgewock, Maine',1918,23);
INSERT INTO "django_geo_db_city" VALUES(1391,'North Anson','North Anson, Maine',1919,23);
INSERT INTO "django_geo_db_city" VALUES(1392,'North New Portland','North New Portland, Maine',1920,23);
INSERT INTO "django_geo_db_city" VALUES(1393,'North Vassalboro','North Vassalboro, Maine',1921,23);
INSERT INTO "django_geo_db_city" VALUES(1394,'Oakland','Oakland, Maine',1922,23);
INSERT INTO "django_geo_db_city" VALUES(1395,'Oquossoc','Oquossoc, Maine',1923,23);
INSERT INTO "django_geo_db_city" VALUES(1396,'Palmyra','Palmyra, Maine',1924,23);
INSERT INTO "django_geo_db_city" VALUES(1397,'Phillips','Phillips, Maine',1925,23);
INSERT INTO "django_geo_db_city" VALUES(1398,'Pittsfield','Pittsfield, Maine',1926,23);
INSERT INTO "django_geo_db_city" VALUES(1399,'Plymouth','Plymouth, Maine',1927,23);
INSERT INTO "django_geo_db_city" VALUES(1400,'Rangeley','Rangeley, Maine',1928,23);
INSERT INTO "django_geo_db_city" VALUES(1401,'Saint Albans','Saint Albans, Maine',1929,23);
INSERT INTO "django_geo_db_city" VALUES(1402,'Sandy Point','Sandy Point, Maine',1864,23);
INSERT INTO "django_geo_db_city" VALUES(1403,'Searsmont','Searsmont, Maine',1930,23);
INSERT INTO "django_geo_db_city" VALUES(1404,'Searsport','Searsport, Maine',1931,23);
INSERT INTO "django_geo_db_city" VALUES(1405,'Shawmut','Shawmut, Maine',1932,23);
INSERT INTO "django_geo_db_city" VALUES(1406,'Skowhegan','Skowhegan, Maine',1933,23);
INSERT INTO "django_geo_db_city" VALUES(1407,'Smithfield','Smithfield, Maine',1934,23);
INSERT INTO "django_geo_db_city" VALUES(1408,'Solon','Solon, Maine',1935,23);
INSERT INTO "django_geo_db_city" VALUES(1409,'Stockton Springs','Stockton Springs, Maine',1936,23);
INSERT INTO "django_geo_db_city" VALUES(1410,'Stratton','Stratton, Maine',1937,23);
INSERT INTO "django_geo_db_city" VALUES(1411,'Strong','Strong, Maine',1938,23);
INSERT INTO "django_geo_db_city" VALUES(1412,'Temple','Temple, Maine',1939,23);
INSERT INTO "django_geo_db_city" VALUES(1413,'West Forks','West Forks, Maine',1940,23);
INSERT INTO "django_geo_db_city" VALUES(1414,'Thorndike','Thorndike, Maine',1941,23);
INSERT INTO "django_geo_db_city" VALUES(1415,'Troy','Troy, Maine',1942,23);
INSERT INTO "django_geo_db_city" VALUES(1416,'Unity','Unity, Maine',1943,23);
INSERT INTO "django_geo_db_city" VALUES(1417,'Vassalboro','Vassalboro, Maine',1944,23);
INSERT INTO "django_geo_db_city" VALUES(1418,'West Farmington','West Farmington, Maine',1945,23);
INSERT INTO "django_geo_db_city" VALUES(1419,'White River Junction','White River Junction, Vermont',1946,53);
INSERT INTO "django_geo_db_city" VALUES(1420,'Ascutney','Ascutney, Vermont',1948,53);
INSERT INTO "django_geo_db_city" VALUES(1421,'Barnard','Barnard, Vermont',1949,53);
INSERT INTO "django_geo_db_city" VALUES(1422,'Bethel','Bethel, Vermont',1950,53);
INSERT INTO "django_geo_db_city" VALUES(1423,'Bradford','Bradford, Vermont',1951,53);
INSERT INTO "django_geo_db_city" VALUES(1424,'Bridgewater','Bridgewater, Vermont',1952,53);
INSERT INTO "django_geo_db_city" VALUES(1425,'Bridgewater Corners','Bridgewater Corners, Vermont',1953,53);
INSERT INTO "django_geo_db_city" VALUES(1426,'Brookfield','Brookfield, Vermont',1954,53);
INSERT INTO "django_geo_db_city" VALUES(1427,'Brownsville','Brownsville, Vermont',1955,53);
INSERT INTO "django_geo_db_city" VALUES(1428,'Chelsea','Chelsea, Vermont',1956,53);
INSERT INTO "django_geo_db_city" VALUES(1429,'Corinth','Corinth, Vermont',1957,53);
INSERT INTO "django_geo_db_city" VALUES(1430,'East Corinth','East Corinth, Vermont',1958,53);
INSERT INTO "django_geo_db_city" VALUES(1431,'East Randolph','East Randolph, Vermont',1959,53);
INSERT INTO "django_geo_db_city" VALUES(1432,'East Ryegate','East Ryegate, Vermont',1960,53);
INSERT INTO "django_geo_db_city" VALUES(1433,'East Thetford','East Thetford, Vermont',1961,53);
INSERT INTO "django_geo_db_city" VALUES(1434,'Fairlee','Fairlee, Vermont',1962,53);
INSERT INTO "django_geo_db_city" VALUES(1435,'Groton','Groton, Vermont',1963,53);
INSERT INTO "django_geo_db_city" VALUES(1436,'Hartford','Hartford, Vermont',1964,53);
INSERT INTO "django_geo_db_city" VALUES(1437,'Hartland','Hartland, Vermont',1965,53);
INSERT INTO "django_geo_db_city" VALUES(1438,'Hartland Four Corners','Hartland Four Corners, Vermont',1947,53);
INSERT INTO "django_geo_db_city" VALUES(1439,'McIndoe Falls','McIndoe Falls, Vermont',1966,53);
INSERT INTO "django_geo_db_city" VALUES(1440,'Newbury','Newbury, Vermont',1967,53);
INSERT INTO "django_geo_db_city" VALUES(1441,'North Hartland','North Hartland, Vermont',1968,53);
INSERT INTO "django_geo_db_city" VALUES(1442,'North Pomfret','North Pomfret, Vermont',1969,53);
INSERT INTO "django_geo_db_city" VALUES(1443,'North Thetford','North Thetford, Vermont',1970,53);
INSERT INTO "django_geo_db_city" VALUES(1444,'Norwich','Norwich, Vermont',1971,53);
INSERT INTO "django_geo_db_city" VALUES(1445,'Plymouth','Plymouth, Vermont',1972,53);
INSERT INTO "django_geo_db_city" VALUES(1446,'Post Mills','Post Mills, Vermont',1973,53);
INSERT INTO "django_geo_db_city" VALUES(1447,'Quechee','Quechee, Vermont',1974,53);
INSERT INTO "django_geo_db_city" VALUES(1448,'Randolph','Randolph, Vermont',1975,53);
INSERT INTO "django_geo_db_city" VALUES(1449,'Randolph Center','Randolph Center, Vermont',1976,53);
INSERT INTO "django_geo_db_city" VALUES(1450,'Reading','Reading, Vermont',1977,53);
INSERT INTO "django_geo_db_city" VALUES(1451,'Sharon','Sharon, Vermont',1978,53);
INSERT INTO "django_geo_db_city" VALUES(1452,'South Pomfret','South Pomfret, Vermont',1979,53);
INSERT INTO "django_geo_db_city" VALUES(1453,'South Royalton','South Royalton, Vermont',1980,53);
INSERT INTO "django_geo_db_city" VALUES(1454,'South Ryegate','South Ryegate, Vermont',1981,53);
INSERT INTO "django_geo_db_city" VALUES(1455,'South Strafford','South Strafford, Vermont',1982,53);
INSERT INTO "django_geo_db_city" VALUES(1456,'South Woodstock','South Woodstock, Vermont',1983,53);
INSERT INTO "django_geo_db_city" VALUES(1457,'Strafford','Strafford, Vermont',1984,53);
INSERT INTO "django_geo_db_city" VALUES(1458,'Taftsville','Taftsville, Vermont',1985,53);
INSERT INTO "django_geo_db_city" VALUES(1459,'Thetford','Thetford, Vermont',1986,53);
INSERT INTO "django_geo_db_city" VALUES(1460,'Thetford Center','Thetford Center, Vermont',1987,53);
INSERT INTO "django_geo_db_city" VALUES(1461,'Tunbridge','Tunbridge, Vermont',1989,53);
INSERT INTO "django_geo_db_city" VALUES(1462,'Vershire','Vershire, Vermont',1990,53);
INSERT INTO "django_geo_db_city" VALUES(1463,'Wells River','Wells River, Vermont',1992,53);
INSERT INTO "django_geo_db_city" VALUES(1464,'West Fairlee','West Fairlee, Vermont',1993,53);
INSERT INTO "django_geo_db_city" VALUES(1465,'West Hartford','West Hartford, Vermont',1994,53);
INSERT INTO "django_geo_db_city" VALUES(1466,'West Newbury','West Newbury, Vermont',1995,53);
INSERT INTO "django_geo_db_city" VALUES(1467,'West Topsham','West Topsham, Vermont',1996,53);
INSERT INTO "django_geo_db_city" VALUES(1468,'Wilder','Wilder, Vermont',1997,53);
INSERT INTO "django_geo_db_city" VALUES(1469,'Windsor','Windsor, Vermont',1998,53);
INSERT INTO "django_geo_db_city" VALUES(1470,'Woodstock','Woodstock, Vermont',1999,53);
INSERT INTO "django_geo_db_city" VALUES(1471,'Bellows Falls','Bellows Falls, Vermont',2000,53);
INSERT INTO "django_geo_db_city" VALUES(1472,'Cavendish','Cavendish, Vermont',2001,53);
INSERT INTO "django_geo_db_city" VALUES(1473,'Cambridgeport','Cambridgeport, Vermont',2002,53);
INSERT INTO "django_geo_db_city" VALUES(1474,'Chester','Chester, Vermont',2004,53);
INSERT INTO "django_geo_db_city" VALUES(1475,'Chester Depot','Chester Depot, Vermont',1947,53);
INSERT INTO "django_geo_db_city" VALUES(1476,'Grafton','Grafton, Vermont',2005,53);
INSERT INTO "django_geo_db_city" VALUES(1477,'Londonderry','Londonderry, Vermont',2006,53);
INSERT INTO "django_geo_db_city" VALUES(1478,'Ludlow','Ludlow, Vermont',2007,53);
INSERT INTO "django_geo_db_city" VALUES(1479,'North Springfield','North Springfield, Vermont',2008,53);
INSERT INTO "django_geo_db_city" VALUES(1480,'Perkinsville','Perkinsville, Vermont',2009,53);
INSERT INTO "django_geo_db_city" VALUES(1481,'Peru','Peru, Vermont',2010,53);
INSERT INTO "django_geo_db_city" VALUES(1482,'Proctorsville','Proctorsville, Vermont',2011,53);
INSERT INTO "django_geo_db_city" VALUES(1483,'Saxtons River','Saxtons River, Vermont',2012,53);
INSERT INTO "django_geo_db_city" VALUES(1484,'South Londonderry','South Londonderry, Vermont',2013,53);
INSERT INTO "django_geo_db_city" VALUES(1485,'Springfield','Springfield, Vermont',2014,53);
INSERT INTO "django_geo_db_city" VALUES(1486,'Westminster','Westminster, Vermont',2015,53);
INSERT INTO "django_geo_db_city" VALUES(1487,'Westminster Station','Westminster Station, Vermont',2016,53);
INSERT INTO "django_geo_db_city" VALUES(1488,'Weston','Weston, Vermont',2017,53);
INSERT INTO "django_geo_db_city" VALUES(1489,'Bennington','Bennington, Vermont',2018,53);
INSERT INTO "django_geo_db_city" VALUES(1490,'Woodford','Woodford, Vermont',2019,53);
INSERT INTO "django_geo_db_city" VALUES(1491,'Barnet','Barnet, Vermont',2020,53);
INSERT INTO "django_geo_db_city" VALUES(1492,'Sudbury','Sudbury, Vermont',2021,53);
INSERT INTO "django_geo_db_city" VALUES(1493,'Arlington','Arlington, Vermont',2022,53);
INSERT INTO "django_geo_db_city" VALUES(1494,'Dorset','Dorset, Vermont',2023,53);
INSERT INTO "django_geo_db_city" VALUES(1495,'East Arlington','East Arlington, Vermont',2024,53);
INSERT INTO "django_geo_db_city" VALUES(1496,'East Dorset','East Dorset, Vermont',2025,53);
INSERT INTO "django_geo_db_city" VALUES(1497,'Manchester','Manchester, Vermont',2026,53);
INSERT INTO "django_geo_db_city" VALUES(1498,'Manchester Center','Manchester Center, Vermont',2027,53);
INSERT INTO "django_geo_db_city" VALUES(1499,'North Bennington','North Bennington, Vermont',2028,53);
INSERT INTO "django_geo_db_city" VALUES(1500,'North Pownal','North Pownal, Vermont',2029,53);
INSERT INTO "django_geo_db_city" VALUES(1501,'Pownal','Pownal, Vermont',2030,53);
INSERT INTO "django_geo_db_city" VALUES(1502,'Shaftsbury','Shaftsbury, Vermont',2031,53);
INSERT INTO "django_geo_db_city" VALUES(1503,'Sutton','Sutton, Vermont',2032,53);
INSERT INTO "django_geo_db_city" VALUES(1504,'Craftsbury','Craftsbury, Vermont',2033,53);
INSERT INTO "django_geo_db_city" VALUES(1505,'Brattleboro','Brattleboro, Vermont',2034,53);
INSERT INTO "django_geo_db_city" VALUES(1506,'Bondville','Bondville, Vermont',2035,53);
INSERT INTO "django_geo_db_city" VALUES(1507,'East Dover','East Dover, Vermont',2036,53);
INSERT INTO "django_geo_db_city" VALUES(1508,'Jacksonville','Jacksonville, Vermont',2037,53);
INSERT INTO "django_geo_db_city" VALUES(1509,'Jamaica','Jamaica, Vermont',2038,53);
INSERT INTO "django_geo_db_city" VALUES(1510,'Marlboro','Marlboro, Vermont',2039,53);
INSERT INTO "django_geo_db_city" VALUES(1511,'Newfane','Newfane, Vermont',2040,53);
INSERT INTO "django_geo_db_city" VALUES(1512,'Putney','Putney, Vermont',2041,53);
INSERT INTO "django_geo_db_city" VALUES(1513,'Readsboro','Readsboro, Vermont',2042,53);
INSERT INTO "django_geo_db_city" VALUES(1514,'South Newfane','South Newfane, Vermont',2043,53);
INSERT INTO "django_geo_db_city" VALUES(1515,'Townshend','Townshend, Vermont',2045,53);
INSERT INTO "django_geo_db_city" VALUES(1516,'Vernon','Vernon, Vermont',2046,53);
INSERT INTO "django_geo_db_city" VALUES(1517,'Wardsboro','Wardsboro, Vermont',2047,53);
INSERT INTO "django_geo_db_city" VALUES(1518,'West Dover','West Dover, Vermont',2048,53);
INSERT INTO "django_geo_db_city" VALUES(1519,'West Dummerston','West Dummerston, Vermont',2049,53);
INSERT INTO "django_geo_db_city" VALUES(1520,'West Halifax','West Halifax, Vermont',2050,53);
INSERT INTO "django_geo_db_city" VALUES(1521,'West Townshend','West Townshend, Vermont',2051,53);
INSERT INTO "django_geo_db_city" VALUES(1522,'West Wardsboro','West Wardsboro, Vermont',2052,53);
INSERT INTO "django_geo_db_city" VALUES(1523,'Whitingham','Whitingham, Vermont',2053,53);
INSERT INTO "django_geo_db_city" VALUES(1524,'Williamsville','Williamsville, Vermont',2054,53);
INSERT INTO "django_geo_db_city" VALUES(1525,'Wilmington','Wilmington, Vermont',2055,53);
INSERT INTO "django_geo_db_city" VALUES(1526,'Burlington','Burlington, Vermont',2057,53);
INSERT INTO "django_geo_db_city" VALUES(1527,'South Burlington','South Burlington, Vermont',2059,53);
INSERT INTO "django_geo_db_city" VALUES(1528,'Winooski','Winooski, Vermont',2060,53);
INSERT INTO "django_geo_db_city" VALUES(1529,'Fletcher','Fletcher, Vermont',2061,53);
INSERT INTO "django_geo_db_city" VALUES(1530,'Lincoln','Lincoln, Vermont',2062,53);
INSERT INTO "django_geo_db_city" VALUES(1531,'Colchester','Colchester, Vermont',2063,53);
INSERT INTO "django_geo_db_city" VALUES(1532,'Alburg','Alburg, Vermont',2064,53);
INSERT INTO "django_geo_db_city" VALUES(1533,'Bakersfield','Bakersfield, Vermont',2065,53);
INSERT INTO "django_geo_db_city" VALUES(1534,'Belvidere Center','Belvidere Center, Vermont',2066,53);
INSERT INTO "django_geo_db_city" VALUES(1535,'Bristol','Bristol, Vermont',2067,53);
INSERT INTO "django_geo_db_city" VALUES(1536,'Cambridge','Cambridge, Vermont',2068,53);
INSERT INTO "django_geo_db_city" VALUES(1537,'Charlotte','Charlotte, Vermont',2069,53);
INSERT INTO "django_geo_db_city" VALUES(1538,'East Berkshire','East Berkshire, Vermont',2071,53);
INSERT INTO "django_geo_db_city" VALUES(1539,'East Fairfield','East Fairfield, Vermont',2072,53);
INSERT INTO "django_geo_db_city" VALUES(1540,'Enosburg Falls','Enosburg Falls, Vermont',2073,53);
INSERT INTO "django_geo_db_city" VALUES(1541,'Essex','Essex, Vermont',2074,53);
INSERT INTO "django_geo_db_city" VALUES(1542,'Essex Junction','Essex Junction, Vermont',2075,53);
INSERT INTO "django_geo_db_city" VALUES(1543,'Fairfax','Fairfax, Vermont',2076,53);
INSERT INTO "django_geo_db_city" VALUES(1544,'Fairfield','Fairfield, Vermont',2077,53);
INSERT INTO "django_geo_db_city" VALUES(1545,'Ferrisburg','Ferrisburg, Vermont',2078,53);
INSERT INTO "django_geo_db_city" VALUES(1546,'Franklin','Franklin, Vermont',2079,53);
INSERT INTO "django_geo_db_city" VALUES(1547,'Grand Isle','Grand Isle, Vermont',2080,53);
INSERT INTO "django_geo_db_city" VALUES(1548,'Highgate Center','Highgate Center, Vermont',2081,53);
INSERT INTO "django_geo_db_city" VALUES(1549,'Highgate Springs','Highgate Springs, Vermont',2082,53);
INSERT INTO "django_geo_db_city" VALUES(1550,'Hinesburg','Hinesburg, Vermont',2083,53);
INSERT INTO "django_geo_db_city" VALUES(1551,'Huntington','Huntington, Vermont',2084,53);
INSERT INTO "django_geo_db_city" VALUES(1552,'Isle La Motte','Isle La Motte, Vermont',2085,53);
INSERT INTO "django_geo_db_city" VALUES(1553,'Jeffersonville','Jeffersonville, Vermont',2086,53);
INSERT INTO "django_geo_db_city" VALUES(1554,'Jericho','Jericho, Vermont',2087,53);
INSERT INTO "django_geo_db_city" VALUES(1555,'Jonesville','Jonesville, Vermont',2088,53);
INSERT INTO "django_geo_db_city" VALUES(1556,'Milton','Milton, Vermont',2089,53);
INSERT INTO "django_geo_db_city" VALUES(1557,'Monkton','Monkton, Vermont',2090,53);
INSERT INTO "django_geo_db_city" VALUES(1558,'Montgomery','Montgomery, Vermont',2071,53);
INSERT INTO "django_geo_db_city" VALUES(1559,'Montgomery Center','Montgomery Center, Vermont',2091,53);
INSERT INTO "django_geo_db_city" VALUES(1560,'New Haven','New Haven, Vermont',2092,53);
INSERT INTO "django_geo_db_city" VALUES(1561,'North Ferrisburg','North Ferrisburg, Vermont',2093,53);
INSERT INTO "django_geo_db_city" VALUES(1562,'North Hero','North Hero, Vermont',2094,53);
INSERT INTO "django_geo_db_city" VALUES(1563,'Richford','Richford, Vermont',2095,53);
INSERT INTO "django_geo_db_city" VALUES(1564,'Richmond','Richmond, Vermont',2096,53);
INSERT INTO "django_geo_db_city" VALUES(1565,'Saint Albans','Saint Albans, Vermont',2097,53);
INSERT INTO "django_geo_db_city" VALUES(1566,'Saint Albans Bay','Saint Albans Bay, Vermont',2071,53);
INSERT INTO "django_geo_db_city" VALUES(1567,'Shelburne','Shelburne, Vermont',2098,53);
INSERT INTO "django_geo_db_city" VALUES(1568,'Sheldon','Sheldon, Vermont',2099,53);
INSERT INTO "django_geo_db_city" VALUES(1569,'Sheldon Springs','Sheldon Springs, Vermont',2100,53);
INSERT INTO "django_geo_db_city" VALUES(1570,'South Hero','South Hero, Vermont',2101,53);
INSERT INTO "django_geo_db_city" VALUES(1571,'Starksboro','Starksboro, Vermont',2102,53);
INSERT INTO "django_geo_db_city" VALUES(1572,'Swanton','Swanton, Vermont',2103,53);
INSERT INTO "django_geo_db_city" VALUES(1573,'Underhill','Underhill, Vermont',2104,53);
INSERT INTO "django_geo_db_city" VALUES(1574,'Underhill Center','Underhill Center, Vermont',2105,53);
INSERT INTO "django_geo_db_city" VALUES(1575,'Vergennes','Vergennes, Vermont',2106,53);
INSERT INTO "django_geo_db_city" VALUES(1576,'Waterville','Waterville, Vermont',2107,53);
INSERT INTO "django_geo_db_city" VALUES(1577,'Westford','Westford, Vermont',2108,53);
INSERT INTO "django_geo_db_city" VALUES(1578,'Williston','Williston, Vermont',2109,53);
INSERT INTO "django_geo_db_city" VALUES(1579,'Montpelier','Montpelier, Vermont',2110,53);
INSERT INTO "django_geo_db_city" VALUES(1580,'Waterbury','Waterbury, Vermont',2114,53);
INSERT INTO "django_geo_db_city" VALUES(1581,'Adamant','Adamant, Vermont',2115,53);
INSERT INTO "django_geo_db_city" VALUES(1582,'Barre','Barre, Vermont',2116,53);
INSERT INTO "django_geo_db_city" VALUES(1583,'Cabot','Cabot, Vermont',2117,53);
INSERT INTO "django_geo_db_city" VALUES(1584,'Calais','Calais, Vermont',2118,53);
INSERT INTO "django_geo_db_city" VALUES(1585,'East Barre','East Barre, Vermont',2119,53);
INSERT INTO "django_geo_db_city" VALUES(1586,'East Calais','East Calais, Vermont',2120,53);
INSERT INTO "django_geo_db_city" VALUES(1587,'East Montpelier','East Montpelier, Vermont',2121,53);
INSERT INTO "django_geo_db_city" VALUES(1588,'Eden','Eden, Vermont',2122,53);
INSERT INTO "django_geo_db_city" VALUES(1589,'Eden Mills','Eden Mills, Vermont',2123,53);
INSERT INTO "django_geo_db_city" VALUES(1590,'Graniteville','Graniteville, Vermont',2124,53);
INSERT INTO "django_geo_db_city" VALUES(1591,'Hyde Park','Hyde Park, Vermont',2125,53);
INSERT INTO "django_geo_db_city" VALUES(1592,'Johnson','Johnson, Vermont',2126,53);
INSERT INTO "django_geo_db_city" VALUES(1593,'Lake Elmore','Lake Elmore, Vermont',2127,53);
INSERT INTO "django_geo_db_city" VALUES(1594,'Marshfield','Marshfield, Vermont',2128,53);
INSERT INTO "django_geo_db_city" VALUES(1595,'Moretown','Moretown, Vermont',2129,53);
INSERT INTO "django_geo_db_city" VALUES(1596,'Morrisville','Morrisville, Vermont',2130,53);
INSERT INTO "django_geo_db_city" VALUES(1597,'Moscow','Moscow, Vermont',2131,53);
INSERT INTO "django_geo_db_city" VALUES(1598,'Northfield','Northfield, Vermont',2132,53);
INSERT INTO "django_geo_db_city" VALUES(1599,'Northfield Falls','Northfield Falls, Vermont',2133,53);
INSERT INTO "django_geo_db_city" VALUES(1600,'North Hyde Park','North Hyde Park, Vermont',2134,53);
INSERT INTO "django_geo_db_city" VALUES(1601,'North Montpelier','North Montpelier, Vermont',2135,53);
INSERT INTO "django_geo_db_city" VALUES(1602,'Plainfield','Plainfield, Vermont',2136,53);
INSERT INTO "django_geo_db_city" VALUES(1603,'Roxbury','Roxbury, Vermont',2137,53);
INSERT INTO "django_geo_db_city" VALUES(1604,'South Barre','South Barre, Vermont',2138,53);
INSERT INTO "django_geo_db_city" VALUES(1605,'Stowe','Stowe, Vermont',2139,53);
INSERT INTO "django_geo_db_city" VALUES(1606,'Waitsfield','Waitsfield, Vermont',2140,53);
INSERT INTO "django_geo_db_city" VALUES(1607,'Warren','Warren, Vermont',2141,53);
INSERT INTO "django_geo_db_city" VALUES(1608,'Washington','Washington, Vermont',2142,53);
INSERT INTO "django_geo_db_city" VALUES(1609,'Waterbury Center','Waterbury Center, Vermont',2144,53);
INSERT INTO "django_geo_db_city" VALUES(1610,'Websterville','Websterville, Vermont',2145,53);
INSERT INTO "django_geo_db_city" VALUES(1611,'Williamstown','Williamstown, Vermont',2146,53);
INSERT INTO "django_geo_db_city" VALUES(1612,'Wolcott','Wolcott, Vermont',2147,53);
INSERT INTO "django_geo_db_city" VALUES(1613,'Woodbury','Woodbury, Vermont',2148,53);
INSERT INTO "django_geo_db_city" VALUES(1614,'Worcester','Worcester, Vermont',2149,53);
INSERT INTO "django_geo_db_city" VALUES(1615,'Rutland','Rutland, Vermont',2150,53);
INSERT INTO "django_geo_db_city" VALUES(1616,'Belmont','Belmont, Vermont',2152,53);
INSERT INTO "django_geo_db_city" VALUES(1617,'Benson','Benson, Vermont',2153,53);
INSERT INTO "django_geo_db_city" VALUES(1618,'Bomoseen','Bomoseen, Vermont',2154,53);
INSERT INTO "django_geo_db_city" VALUES(1619,'Brandon','Brandon, Vermont',2155,53);
INSERT INTO "django_geo_db_city" VALUES(1620,'Bridport','Bridport, Vermont',2156,53);
INSERT INTO "django_geo_db_city" VALUES(1621,'Castleton','Castleton, Vermont',2157,53);
INSERT INTO "django_geo_db_city" VALUES(1622,'Center Rutland','Center Rutland, Vermont',2158,53);
INSERT INTO "django_geo_db_city" VALUES(1623,'Chittenden','Chittenden, Vermont',2159,53);
INSERT INTO "django_geo_db_city" VALUES(1624,'Cuttingsville','Cuttingsville, Vermont',2160,53);
INSERT INTO "django_geo_db_city" VALUES(1625,'Danby','Danby, Vermont',2161,53);
INSERT INTO "django_geo_db_city" VALUES(1626,'East Middlebury','East Middlebury, Vermont',2162,53);
INSERT INTO "django_geo_db_city" VALUES(1627,'East Poultney','East Poultney, Vermont',2163,53);
INSERT INTO "django_geo_db_city" VALUES(1628,'East Wallingford','East Wallingford, Vermont',2164,53);
INSERT INTO "django_geo_db_city" VALUES(1629,'Fair Haven','Fair Haven, Vermont',2165,53);
INSERT INTO "django_geo_db_city" VALUES(1630,'Florence','Florence, Vermont',2166,53);
INSERT INTO "django_geo_db_city" VALUES(1631,'Forest Dale','Forest Dale, Vermont',2163,53);
INSERT INTO "django_geo_db_city" VALUES(1632,'Gaysville','Gaysville, Vermont',2167,53);
INSERT INTO "django_geo_db_city" VALUES(1633,'Granville','Granville, Vermont',2168,53);
INSERT INTO "django_geo_db_city" VALUES(1634,'Hancock','Hancock, Vermont',2169,53);
INSERT INTO "django_geo_db_city" VALUES(1635,'Hydeville','Hydeville, Vermont',2170,53);
INSERT INTO "django_geo_db_city" VALUES(1636,'Killington','Killington, Vermont',2171,53);
INSERT INTO "django_geo_db_city" VALUES(1637,'Poultney','Poultney, Vermont',2172,53);
INSERT INTO "django_geo_db_city" VALUES(1638,'Middlebury','Middlebury, Vermont',2173,53);
INSERT INTO "django_geo_db_city" VALUES(1639,'Middletown Springs','Middletown Springs, Vermont',2174,53);
INSERT INTO "django_geo_db_city" VALUES(1640,'Mount Holly','Mount Holly, Vermont',2175,53);
INSERT INTO "django_geo_db_city" VALUES(1641,'North Clarendon','North Clarendon, Vermont',2176,53);
INSERT INTO "django_geo_db_city" VALUES(1642,'Orwell','Orwell, Vermont',2177,53);
INSERT INTO "django_geo_db_city" VALUES(1643,'Pawlet','Pawlet, Vermont',2178,53);
INSERT INTO "django_geo_db_city" VALUES(1644,'Pittsfield','Pittsfield, Vermont',2179,53);
INSERT INTO "django_geo_db_city" VALUES(1645,'Pittsford','Pittsford, Vermont',2180,53);
INSERT INTO "django_geo_db_city" VALUES(1646,'Proctor','Proctor, Vermont',2182,53);
INSERT INTO "django_geo_db_city" VALUES(1647,'Ripton','Ripton, Vermont',2183,53);
INSERT INTO "django_geo_db_city" VALUES(1648,'Rochester','Rochester, Vermont',2184,53);
INSERT INTO "django_geo_db_city" VALUES(1649,'Rupert','Rupert, Vermont',2185,53);
INSERT INTO "django_geo_db_city" VALUES(1650,'Salisbury','Salisbury, Vermont',2186,53);
INSERT INTO "django_geo_db_city" VALUES(1651,'Shoreham','Shoreham, Vermont',2187,53);
INSERT INTO "django_geo_db_city" VALUES(1652,'Stockbridge','Stockbridge, Vermont',2188,53);
INSERT INTO "django_geo_db_city" VALUES(1653,'Wallingford','Wallingford, Vermont',2189,53);
INSERT INTO "django_geo_db_city" VALUES(1654,'Wells','Wells, Vermont',2190,53);
INSERT INTO "django_geo_db_city" VALUES(1655,'West Pawlet','West Pawlet, Vermont',2191,53);
INSERT INTO "django_geo_db_city" VALUES(1656,'West Rupert','West Rupert, Vermont',2192,53);
INSERT INTO "django_geo_db_city" VALUES(1657,'West Rutland','West Rutland, Vermont',2193,53);
INSERT INTO "django_geo_db_city" VALUES(1658,'Whiting','Whiting, Vermont',2194,53);
INSERT INTO "django_geo_db_city" VALUES(1659,'Saint Johnsbury','Saint Johnsbury, Vermont',2196,53);
INSERT INTO "django_geo_db_city" VALUES(1660,'Albany','Albany, Vermont',2197,53);
INSERT INTO "django_geo_db_city" VALUES(1661,'Barton','Barton, Vermont',2199,53);
INSERT INTO "django_geo_db_city" VALUES(1662,'Beebe Plain','Beebe Plain, Vermont',2200,53);
INSERT INTO "django_geo_db_city" VALUES(1663,'Concord','Concord, Vermont',2201,53);
INSERT INTO "django_geo_db_city" VALUES(1664,'Coventry','Coventry, Vermont',2202,53);
INSERT INTO "django_geo_db_city" VALUES(1665,'Craftsbury Common','Craftsbury Common, Vermont',2204,53);
INSERT INTO "django_geo_db_city" VALUES(1666,'Danville','Danville, Vermont',2205,53);
INSERT INTO "django_geo_db_city" VALUES(1667,'Derby','Derby, Vermont',2206,53);
INSERT INTO "django_geo_db_city" VALUES(1668,'Derby Line','Derby Line, Vermont',2207,53);
INSERT INTO "django_geo_db_city" VALUES(1669,'East Burke','East Burke, Vermont',2208,53);
INSERT INTO "django_geo_db_city" VALUES(1670,'East Charleston','East Charleston, Vermont',2209,53);
INSERT INTO "django_geo_db_city" VALUES(1671,'East Hardwick','East Hardwick, Vermont',2210,53);
INSERT INTO "django_geo_db_city" VALUES(1672,'East Haven','East Haven, Vermont',2211,53);
INSERT INTO "django_geo_db_city" VALUES(1673,'East Saint Johnsbury','East Saint Johnsbury, Vermont',2212,53);
INSERT INTO "django_geo_db_city" VALUES(1674,'Glover','Glover, Vermont',2213,53);
INSERT INTO "django_geo_db_city" VALUES(1675,'Granby','Granby, Vermont',2214,53);
INSERT INTO "django_geo_db_city" VALUES(1676,'Greensboro','Greensboro, Vermont',2215,53);
INSERT INTO "django_geo_db_city" VALUES(1677,'Greensboro Bend','Greensboro Bend, Vermont',2216,53);
INSERT INTO "django_geo_db_city" VALUES(1678,'Hardwick','Hardwick, Vermont',2217,53);
INSERT INTO "django_geo_db_city" VALUES(1679,'Irasburg','Irasburg, Vermont',2218,53);
INSERT INTO "django_geo_db_city" VALUES(1680,'Island Pond','Island Pond, Vermont',2219,53);
INSERT INTO "django_geo_db_city" VALUES(1681,'Lowell','Lowell, Vermont',2220,53);
INSERT INTO "django_geo_db_city" VALUES(1682,'Lower Waterford','Lower Waterford, Vermont',2221,53);
INSERT INTO "django_geo_db_city" VALUES(1683,'Lyndon','Lyndon, Vermont',2222,53);
INSERT INTO "django_geo_db_city" VALUES(1684,'Lyndon Center','Lyndon Center, Vermont',2223,53);
INSERT INTO "django_geo_db_city" VALUES(1685,'Lyndonville','Lyndonville, Vermont',2224,53);
INSERT INTO "django_geo_db_city" VALUES(1686,'Newport','Newport, Vermont',2225,53);
INSERT INTO "django_geo_db_city" VALUES(1687,'Morgan','Morgan, Vermont',2226,53);
INSERT INTO "django_geo_db_city" VALUES(1688,'Newport Center','Newport Center, Vermont',2228,53);
INSERT INTO "django_geo_db_city" VALUES(1689,'North Concord','North Concord, Vermont',2229,53);
INSERT INTO "django_geo_db_city" VALUES(1690,'North Troy','North Troy, Vermont',2230,53);
INSERT INTO "django_geo_db_city" VALUES(1691,'Orleans','Orleans, Vermont',2231,53);
INSERT INTO "django_geo_db_city" VALUES(1692,'Passumpsic','Passumpsic, Vermont',1966,53);
INSERT INTO "django_geo_db_city" VALUES(1693,'Peacham','Peacham, Vermont',1966,53);
INSERT INTO "django_geo_db_city" VALUES(1694,'Saint Johnsbury Center','Saint Johnsbury Center, Vermont',2232,53);
INSERT INTO "django_geo_db_city" VALUES(1695,'Stannard','Stannard, Vermont',2233,53);
INSERT INTO "django_geo_db_city" VALUES(1696,'Sheffield','Sheffield, Vermont',2234,53);
INSERT INTO "django_geo_db_city" VALUES(1697,'Troy','Troy, Vermont',2236,53);
INSERT INTO "django_geo_db_city" VALUES(1698,'West Burke','West Burke, Vermont',2237,53);
INSERT INTO "django_geo_db_city" VALUES(1699,'West Charleston','West Charleston, Vermont',2238,53);
INSERT INTO "django_geo_db_city" VALUES(1700,'West Danville','West Danville, Vermont',2239,53);
INSERT INTO "django_geo_db_city" VALUES(1701,'Westfield','Westfield, Vermont',2240,53);
INSERT INTO "django_geo_db_city" VALUES(1702,'West Glover','West Glover, Vermont',2241,53);
INSERT INTO "django_geo_db_city" VALUES(1703,'Averill','Averill, Vermont',2243,53);
INSERT INTO "django_geo_db_city" VALUES(1704,'Beecher Falls','Beecher Falls, Vermont',2244,53);
INSERT INTO "django_geo_db_city" VALUES(1705,'Canaan','Canaan, Vermont',2245,53);
INSERT INTO "django_geo_db_city" VALUES(1706,'Gilman','Gilman, Vermont',2246,53);
INSERT INTO "django_geo_db_city" VALUES(1707,'Guildhall','Guildhall, Vermont',2247,53);
INSERT INTO "django_geo_db_city" VALUES(1708,'Lunenburg','Lunenburg, Vermont',2248,53);
INSERT INTO "django_geo_db_city" VALUES(1709,'Norton','Norton, Vermont',2249,53);
INSERT INTO "django_geo_db_city" VALUES(1710,'Derby Center','Derby Center, Vermont',2250,53);
INSERT INTO "django_geo_db_city" VALUES(1711,'Avon','Avon, Connecticut',2252,8);
INSERT INTO "django_geo_db_city" VALUES(1712,'Bloomfield','Bloomfield, Connecticut',2253,8);
INSERT INTO "django_geo_db_city" VALUES(1713,'Windsor','Windsor, Connecticut',2254,8);
INSERT INTO "django_geo_db_city" VALUES(1714,'Bristol','Bristol, Connecticut',2255,8);
INSERT INTO "django_geo_db_city" VALUES(1715,'Burlington','Burlington, Connecticut',2257,8);
INSERT INTO "django_geo_db_city" VALUES(1716,'Broad Brook','Broad Brook, Connecticut',2258,8);
INSERT INTO "django_geo_db_city" VALUES(1717,'Canaan','Canaan, Connecticut',2259,8);
INSERT INTO "django_geo_db_city" VALUES(1718,'Canton','Canton, Connecticut',2260,8);
INSERT INTO "django_geo_db_city" VALUES(1719,'Canton Center','Canton Center, Connecticut',2261,8);
INSERT INTO "django_geo_db_city" VALUES(1720,'Colebrook','Colebrook, Connecticut',2262,8);
INSERT INTO "django_geo_db_city" VALUES(1721,'Collinsville','Collinsville, Connecticut',2263,8);
INSERT INTO "django_geo_db_city" VALUES(1722,'East Berlin','East Berlin, Connecticut',2264,8);
INSERT INTO "django_geo_db_city" VALUES(1723,'East Canaan','East Canaan, Connecticut',2265,8);
INSERT INTO "django_geo_db_city" VALUES(1724,'East Glastonbury','East Glastonbury, Connecticut',2266,8);
INSERT INTO "django_geo_db_city" VALUES(1725,'East Granby','East Granby, Connecticut',2267,8);
INSERT INTO "django_geo_db_city" VALUES(1726,'East Hartland','East Hartland, Connecticut',2268,8);
INSERT INTO "django_geo_db_city" VALUES(1727,'East Windsor Hill','East Windsor Hill, Connecticut',2269,8);
INSERT INTO "django_geo_db_city" VALUES(1728,'Ellington','Ellington, Connecticut',2270,8);
INSERT INTO "django_geo_db_city" VALUES(1729,'Farmington','Farmington, Connecticut',2256,8);
INSERT INTO "django_geo_db_city" VALUES(1730,'Falls Village','Falls Village, Connecticut',2271,8);
INSERT INTO "django_geo_db_city" VALUES(1731,'Glastonbury','Glastonbury, Connecticut',2273,8);
INSERT INTO "django_geo_db_city" VALUES(1732,'Granby','Granby, Connecticut',2274,8);
INSERT INTO "django_geo_db_city" VALUES(1733,'Kensington','Kensington, Connecticut',2275,8);
INSERT INTO "django_geo_db_city" VALUES(1734,'Lakeville','Lakeville, Connecticut',2276,8);
INSERT INTO "django_geo_db_city" VALUES(1735,'Manchester','Manchester, Connecticut',2277,8);
INSERT INTO "django_geo_db_city" VALUES(1736,'Bolton','Bolton, Connecticut',2279,8);
INSERT INTO "django_geo_db_city" VALUES(1737,'Melrose','Melrose, Connecticut',2256,8);
INSERT INTO "django_geo_db_city" VALUES(1738,'New Britain','New Britain, Connecticut',2280,8);
INSERT INTO "django_geo_db_city" VALUES(1739,'New Hartford','New Hartford, Connecticut',2284,8);
INSERT INTO "django_geo_db_city" VALUES(1740,'Norfolk','Norfolk, Connecticut',2285,8);
INSERT INTO "django_geo_db_city" VALUES(1741,'North Canton','North Canton, Connecticut',2286,8);
INSERT INTO "django_geo_db_city" VALUES(1742,'North Granby','North Granby, Connecticut',2287,8);
INSERT INTO "django_geo_db_city" VALUES(1743,'Pine Meadow','Pine Meadow, Connecticut',2288,8);
INSERT INTO "django_geo_db_city" VALUES(1744,'Plainville','Plainville, Connecticut',2289,8);
INSERT INTO "django_geo_db_city" VALUES(1745,'Pleasant Valley','Pleasant Valley, Connecticut',2290,8);
INSERT INTO "django_geo_db_city" VALUES(1746,'Poquonock','Poquonock, Connecticut',2256,8);
INSERT INTO "django_geo_db_city" VALUES(1747,'Riverton','Riverton, Connecticut',2291,8);
INSERT INTO "django_geo_db_city" VALUES(1748,'Vernon Rockville','Vernon Rockville, Connecticut',2292,8);
INSERT INTO "django_geo_db_city" VALUES(1749,'Rocky Hill','Rocky Hill, Connecticut',2293,8);
INSERT INTO "django_geo_db_city" VALUES(1750,'Salisbury','Salisbury, Connecticut',2294,8);
INSERT INTO "django_geo_db_city" VALUES(1751,'Sharon','Sharon, Connecticut',2295,8);
INSERT INTO "django_geo_db_city" VALUES(1752,'Simsbury','Simsbury, Connecticut',2296,8);
INSERT INTO "django_geo_db_city" VALUES(1753,'Somers','Somers, Connecticut',2297,8);
INSERT INTO "django_geo_db_city" VALUES(1754,'Somersville','Somersville, Connecticut',2298,8);
INSERT INTO "django_geo_db_city" VALUES(1755,'South Glastonbury','South Glastonbury, Connecticut',2299,8);
INSERT INTO "django_geo_db_city" VALUES(1756,'South Windsor','South Windsor, Connecticut',2300,8);
INSERT INTO "django_geo_db_city" VALUES(1757,'Stafford','Stafford, Connecticut',2301,8);
INSERT INTO "django_geo_db_city" VALUES(1758,'Stafford Springs','Stafford Springs, Connecticut',2302,8);
INSERT INTO "django_geo_db_city" VALUES(1759,'Staffordville','Staffordville, Connecticut',2303,8);
INSERT INTO "django_geo_db_city" VALUES(1760,'Suffield','Suffield, Connecticut',2304,8);
INSERT INTO "django_geo_db_city" VALUES(1761,'Taconic','Taconic, Connecticut',2305,8);
INSERT INTO "django_geo_db_city" VALUES(1762,'Tariffville','Tariffville, Connecticut',2307,8);
INSERT INTO "django_geo_db_city" VALUES(1763,'Enfield','Enfield, Connecticut',2308,8);
INSERT INTO "django_geo_db_city" VALUES(1764,'Tolland','Tolland, Connecticut',2309,8);
INSERT INTO "django_geo_db_city" VALUES(1765,'Unionville','Unionville, Connecticut',2310,8);
INSERT INTO "django_geo_db_city" VALUES(1766,'East Windsor','East Windsor, Connecticut',2312,8);
INSERT INTO "django_geo_db_city" VALUES(1767,'Weatogue','Weatogue, Connecticut',2313,8);
INSERT INTO "django_geo_db_city" VALUES(1768,'West Granby','West Granby, Connecticut',2314,8);
INSERT INTO "django_geo_db_city" VALUES(1769,'West Hartland','West Hartland, Connecticut',2315,8);
INSERT INTO "django_geo_db_city" VALUES(1770,'West Simsbury','West Simsbury, Connecticut',2316,8);
INSERT INTO "django_geo_db_city" VALUES(1771,'West Suffield','West Suffield, Connecticut',2317,8);
INSERT INTO "django_geo_db_city" VALUES(1772,'Winchester Center','Winchester Center, Connecticut',2318,8);
INSERT INTO "django_geo_db_city" VALUES(1773,'Windsor Locks','Windsor Locks, Connecticut',2320,8);
INSERT INTO "django_geo_db_city" VALUES(1774,'Winsted','Winsted, Connecticut',2321,8);
INSERT INTO "django_geo_db_city" VALUES(1775,'Hartford','Hartford, Connecticut',2322,8);
INSERT INTO "django_geo_db_city" VALUES(1776,'W Hartford','W Hartford, Connecticut',2326,8);
INSERT INTO "django_geo_db_city" VALUES(1777,'East Hartford','East Hartford, Connecticut',2327,8);
INSERT INTO "django_geo_db_city" VALUES(1778,'Wethersfield','Wethersfield, Connecticut',2328,8);
INSERT INTO "django_geo_db_city" VALUES(1779,'Newington','Newington, Connecticut',2330,8);
INSERT INTO "django_geo_db_city" VALUES(1780,'Willimantic','Willimantic, Connecticut',2345,8);
INSERT INTO "django_geo_db_city" VALUES(1781,'Abington','Abington, Connecticut',2346,8);
INSERT INTO "django_geo_db_city" VALUES(1782,'Amston','Amston, Connecticut',2347,8);
INSERT INTO "django_geo_db_city" VALUES(1783,'Andover','Andover, Connecticut',2348,8);
INSERT INTO "django_geo_db_city" VALUES(1784,'Ballouville','Ballouville, Connecticut',2349,8);
INSERT INTO "django_geo_db_city" VALUES(1785,'Brooklyn','Brooklyn, Connecticut',2350,8);
INSERT INTO "django_geo_db_city" VALUES(1786,'Chaplin','Chaplin, Connecticut',2351,8);
INSERT INTO "django_geo_db_city" VALUES(1787,'Columbia','Columbia, Connecticut',2352,8);
INSERT INTO "django_geo_db_city" VALUES(1788,'Coventry','Coventry, Connecticut',2353,8);
INSERT INTO "django_geo_db_city" VALUES(1789,'Danielson','Danielson, Connecticut',2354,8);
INSERT INTO "django_geo_db_city" VALUES(1790,'Dayville','Dayville, Connecticut',2355,8);
INSERT INTO "django_geo_db_city" VALUES(1791,'Eastford','Eastford, Connecticut',2356,8);
INSERT INTO "django_geo_db_city" VALUES(1792,'East Killingly','East Killingly, Connecticut',2357,8);
INSERT INTO "django_geo_db_city" VALUES(1793,'East Woodstock','East Woodstock, Connecticut',2358,8);
INSERT INTO "django_geo_db_city" VALUES(1794,'Fabyan','Fabyan, Connecticut',2359,8);
INSERT INTO "django_geo_db_city" VALUES(1795,'Grosvenor Dale','Grosvenor Dale, Connecticut',2360,8);
INSERT INTO "django_geo_db_city" VALUES(1796,'Hampton','Hampton, Connecticut',2361,8);
INSERT INTO "django_geo_db_city" VALUES(1797,'Hebron','Hebron, Connecticut',2362,8);
INSERT INTO "django_geo_db_city" VALUES(1798,'Lebanon','Lebanon, Connecticut',2363,8);
INSERT INTO "django_geo_db_city" VALUES(1799,'Mansfield Center','Mansfield Center, Connecticut',2364,8);
INSERT INTO "django_geo_db_city" VALUES(1800,'Mansfield Depot','Mansfield Depot, Connecticut',2365,8);
INSERT INTO "django_geo_db_city" VALUES(1801,'North Franklin','North Franklin, Connecticut',2366,8);
INSERT INTO "django_geo_db_city" VALUES(1802,'North Grosvenordale','North Grosvenordale, Connecticut',2367,8);
INSERT INTO "django_geo_db_city" VALUES(1803,'North Windham','North Windham, Connecticut',2368,8);
INSERT INTO "django_geo_db_city" VALUES(1804,'Pomfret','Pomfret, Connecticut',2369,8);
INSERT INTO "django_geo_db_city" VALUES(1805,'Pomfret Center','Pomfret Center, Connecticut',2370,8);
INSERT INTO "django_geo_db_city" VALUES(1806,'Putnam','Putnam, Connecticut',2371,8);
INSERT INTO "django_geo_db_city" VALUES(1807,'Quinebaug','Quinebaug, Connecticut',2372,8);
INSERT INTO "django_geo_db_city" VALUES(1808,'Rogers','Rogers, Connecticut',2373,8);
INSERT INTO "django_geo_db_city" VALUES(1809,'Scotland','Scotland, Connecticut',2374,8);
INSERT INTO "django_geo_db_city" VALUES(1810,'South Willington','South Willington, Connecticut',2301,8);
INSERT INTO "django_geo_db_city" VALUES(1811,'South Windham','South Windham, Connecticut',2375,8);
INSERT INTO "django_geo_db_city" VALUES(1812,'South Woodstock','South Woodstock, Connecticut',2376,8);
INSERT INTO "django_geo_db_city" VALUES(1813,'Storrs Mansfield','Storrs Mansfield, Connecticut',2377,8);
INSERT INTO "django_geo_db_city" VALUES(1814,'Thompson','Thompson, Connecticut',2379,8);
INSERT INTO "django_geo_db_city" VALUES(1815,'Ashford','Ashford, Connecticut',2380,8);
INSERT INTO "django_geo_db_city" VALUES(1816,'Willington','Willington, Connecticut',2381,8);
INSERT INTO "django_geo_db_city" VALUES(1817,'Windham','Windham, Connecticut',2382,8);
INSERT INTO "django_geo_db_city" VALUES(1818,'Woodstock','Woodstock, Connecticut',2383,8);
INSERT INTO "django_geo_db_city" VALUES(1819,'Woodstock Valley','Woodstock Valley, Connecticut',2384,8);
INSERT INTO "django_geo_db_city" VALUES(1820,'New London','New London, Connecticut',2385,8);
INSERT INTO "django_geo_db_city" VALUES(1821,'Baltic','Baltic, Connecticut',2386,8);
INSERT INTO "django_geo_db_city" VALUES(1822,'Canterbury','Canterbury, Connecticut',2387,8);
INSERT INTO "django_geo_db_city" VALUES(1823,'Central Village','Central Village, Connecticut',2388,8);
INSERT INTO "django_geo_db_city" VALUES(1824,'East Lyme','East Lyme, Connecticut',2389,8);
INSERT INTO "django_geo_db_city" VALUES(1825,'Bozrah','Bozrah, Connecticut',2390,8);
INSERT INTO "django_geo_db_city" VALUES(1826,'Gales Ferry','Gales Ferry, Connecticut',2391,8);
INSERT INTO "django_geo_db_city" VALUES(1827,'Gilman','Gilman, Connecticut',2392,8);
INSERT INTO "django_geo_db_city" VALUES(1828,'Glasgo','Glasgo, Connecticut',2393,8);
INSERT INTO "django_geo_db_city" VALUES(1829,'Ledyard','Ledyard, Connecticut',2394,8);
INSERT INTO "django_geo_db_city" VALUES(1830,'Groton','Groton, Connecticut',2395,8);
INSERT INTO "django_geo_db_city" VALUES(1831,'Hanover','Hanover, Connecticut',2397,8);
INSERT INTO "django_geo_db_city" VALUES(1832,'Jewett City','Jewett City, Connecticut',2398,8);
INSERT INTO "django_geo_db_city" VALUES(1833,'Montville','Montville, Connecticut',2399,8);
INSERT INTO "django_geo_db_city" VALUES(1834,'Moosup','Moosup, Connecticut',2400,8);
INSERT INTO "django_geo_db_city" VALUES(1835,'Mystic','Mystic, Connecticut',2401,8);
INSERT INTO "django_geo_db_city" VALUES(1836,'Niantic','Niantic, Connecticut',2402,8);
INSERT INTO "django_geo_db_city" VALUES(1837,'North Stonington','North Stonington, Connecticut',2403,8);
INSERT INTO "django_geo_db_city" VALUES(1838,'Norwich','Norwich, Connecticut',2404,8);
INSERT INTO "django_geo_db_city" VALUES(1839,'Preston','Preston, Connecticut',2405,8);
INSERT INTO "django_geo_db_city" VALUES(1840,'Oakdale','Oakdale, Connecticut',2406,8);
INSERT INTO "django_geo_db_city" VALUES(1841,'Old Lyme','Old Lyme, Connecticut',2407,8);
INSERT INTO "django_geo_db_city" VALUES(1842,'Old Mystic','Old Mystic, Connecticut',2408,8);
INSERT INTO "django_geo_db_city" VALUES(1843,'Oneco','Oneco, Connecticut',2409,8);
INSERT INTO "django_geo_db_city" VALUES(1844,'Plainfield','Plainfield, Connecticut',2410,8);
INSERT INTO "django_geo_db_city" VALUES(1845,'Quaker Hill','Quaker Hill, Connecticut',2411,8);
INSERT INTO "django_geo_db_city" VALUES(1846,'South Lyme','South Lyme, Connecticut',2412,8);
INSERT INTO "django_geo_db_city" VALUES(1847,'Sterling','Sterling, Connecticut',2413,8);
INSERT INTO "django_geo_db_city" VALUES(1848,'Stonington','Stonington, Connecticut',2414,8);
INSERT INTO "django_geo_db_city" VALUES(1849,'Pawcatuck','Pawcatuck, Connecticut',2415,8);
INSERT INTO "django_geo_db_city" VALUES(1850,'Taftville','Taftville, Connecticut',2416,8);
INSERT INTO "django_geo_db_city" VALUES(1851,'Uncasville','Uncasville, Connecticut',2417,8);
INSERT INTO "django_geo_db_city" VALUES(1852,'Versailles','Versailles, Connecticut',2418,8);
INSERT INTO "django_geo_db_city" VALUES(1853,'Voluntown','Voluntown, Connecticut',2419,8);
INSERT INTO "django_geo_db_city" VALUES(1854,'Waterford','Waterford, Connecticut',2420,8);
INSERT INTO "django_geo_db_city" VALUES(1855,'Wauregan','Wauregan, Connecticut',2422,8);
INSERT INTO "django_geo_db_city" VALUES(1856,'West Mystic','West Mystic, Connecticut',2423,8);
INSERT INTO "django_geo_db_city" VALUES(1857,'Yantic','Yantic, Connecticut',2424,8);
INSERT INTO "django_geo_db_city" VALUES(1858,'Fishers Island','Fishers Island, New York',2425,32);
INSERT INTO "django_geo_db_city" VALUES(1859,'Ansonia','Ansonia, Connecticut',2426,8);
INSERT INTO "django_geo_db_city" VALUES(1860,'Beacon Falls','Beacon Falls, Connecticut',2427,8);
INSERT INTO "django_geo_db_city" VALUES(1861,'Botsford','Botsford, Connecticut',2428,8);
INSERT INTO "django_geo_db_city" VALUES(1862,'Branford','Branford, Connecticut',2429,8);
INSERT INTO "django_geo_db_city" VALUES(1863,'Cheshire','Cheshire, Connecticut',2430,8);
INSERT INTO "django_geo_db_city" VALUES(1864,'Centerbrook','Centerbrook, Connecticut',2431,8);
INSERT INTO "django_geo_db_city" VALUES(1865,'Chester','Chester, Connecticut',2434,8);
INSERT INTO "django_geo_db_city" VALUES(1866,'Clinton','Clinton, Connecticut',2435,8);
INSERT INTO "django_geo_db_city" VALUES(1867,'Cobalt','Cobalt, Connecticut',2436,8);
INSERT INTO "django_geo_db_city" VALUES(1868,'Colchester','Colchester, Connecticut',2437,8);
INSERT INTO "django_geo_db_city" VALUES(1869,'Cromwell','Cromwell, Connecticut',2438,8);
INSERT INTO "django_geo_db_city" VALUES(1870,'Deep River','Deep River, Connecticut',2439,8);
INSERT INTO "django_geo_db_city" VALUES(1871,'Derby','Derby, Connecticut',2440,8);
INSERT INTO "django_geo_db_city" VALUES(1872,'Killingworth','Killingworth, Connecticut',2441,8);
INSERT INTO "django_geo_db_city" VALUES(1873,'Salem','Salem, Connecticut',2442,8);
INSERT INTO "django_geo_db_city" VALUES(1874,'Durham','Durham, Connecticut',2443,8);
INSERT INTO "django_geo_db_city" VALUES(1875,'East Haddam','East Haddam, Connecticut',2444,8);
INSERT INTO "django_geo_db_city" VALUES(1876,'East Hampton','East Hampton, Connecticut',2445,8);
INSERT INTO "django_geo_db_city" VALUES(1877,'Essex','Essex, Connecticut',2446,8);
INSERT INTO "django_geo_db_city" VALUES(1878,'Fairfield','Fairfield, Connecticut',2447,8);
INSERT INTO "django_geo_db_city" VALUES(1879,'Greens Farms','Greens Farms, Connecticut',2450,8);
INSERT INTO "django_geo_db_city" VALUES(1880,'Guilford','Guilford, Connecticut',2451,8);
INSERT INTO "django_geo_db_city" VALUES(1881,'Haddam','Haddam, Connecticut',2452,8);
INSERT INTO "django_geo_db_city" VALUES(1882,'Hadlyme','Hadlyme, Connecticut',2453,8);
INSERT INTO "django_geo_db_city" VALUES(1883,'Hawleyville','Hawleyville, Connecticut',2450,8);
INSERT INTO "django_geo_db_city" VALUES(1884,'Higganum','Higganum, Connecticut',2454,8);
INSERT INTO "django_geo_db_city" VALUES(1885,'Ivoryton','Ivoryton, Connecticut',2455,8);
INSERT INTO "django_geo_db_city" VALUES(1886,'Madison','Madison, Connecticut',2456,8);
INSERT INTO "django_geo_db_city" VALUES(1887,'Marion','Marion, Connecticut',2256,8);
INSERT INTO "django_geo_db_city" VALUES(1888,'Marlborough','Marlborough, Connecticut',2457,8);
INSERT INTO "django_geo_db_city" VALUES(1889,'Meriden','Meriden, Connecticut',2458,8);
INSERT INTO "django_geo_db_city" VALUES(1890,'Middlefield','Middlefield, Connecticut',2460,8);
INSERT INTO "django_geo_db_city" VALUES(1891,'Middle Haddam','Middle Haddam, Connecticut',2461,8);
INSERT INTO "django_geo_db_city" VALUES(1892,'Middletown','Middletown, Connecticut',2462,8);
INSERT INTO "django_geo_db_city" VALUES(1893,'Milford','Milford, Connecticut',2464,8);
INSERT INTO "django_geo_db_city" VALUES(1894,'Milldale','Milldale, Connecticut',2465,8);
INSERT INTO "django_geo_db_city" VALUES(1895,'Monroe','Monroe, Connecticut',2466,8);
INSERT INTO "django_geo_db_city" VALUES(1896,'Moodus','Moodus, Connecticut',2467,8);
INSERT INTO "django_geo_db_city" VALUES(1897,'Newtown','Newtown, Connecticut',2468,8);
INSERT INTO "django_geo_db_city" VALUES(1898,'North Branford','North Branford, Connecticut',2469,8);
INSERT INTO "django_geo_db_city" VALUES(1899,'Northford','Northford, Connecticut',2470,8);
INSERT INTO "django_geo_db_city" VALUES(1900,'North Haven','North Haven, Connecticut',2471,8);
INSERT INTO "django_geo_db_city" VALUES(1901,'North Westchester','North Westchester, Connecticut',2421,8);
INSERT INTO "django_geo_db_city" VALUES(1902,'Old Saybrook','Old Saybrook, Connecticut',2472,8);
INSERT INTO "django_geo_db_city" VALUES(1903,'Orange','Orange, Connecticut',2473,8);
INSERT INTO "django_geo_db_city" VALUES(1904,'Oxford','Oxford, Connecticut',2474,8);
INSERT INTO "django_geo_db_city" VALUES(1905,'Plantsville','Plantsville, Connecticut',2475,8);
INSERT INTO "django_geo_db_city" VALUES(1906,'Portland','Portland, Connecticut',2476,8);
INSERT INTO "django_geo_db_city" VALUES(1907,'Rockfall','Rockfall, Connecticut',2477,8);
INSERT INTO "django_geo_db_city" VALUES(1908,'Sandy Hook','Sandy Hook, Connecticut',2478,8);
INSERT INTO "django_geo_db_city" VALUES(1909,'Seymour','Seymour, Connecticut',2479,8);
INSERT INTO "django_geo_db_city" VALUES(1910,'Shelton','Shelton, Connecticut',2480,8);
INSERT INTO "django_geo_db_city" VALUES(1911,'South Britain','South Britain, Connecticut',2430,8);
INSERT INTO "django_geo_db_city" VALUES(1912,'Southbury','Southbury, Connecticut',2481,8);
INSERT INTO "django_geo_db_city" VALUES(1913,'Southington','Southington, Connecticut',2482,8);
INSERT INTO "django_geo_db_city" VALUES(1914,'Southport','Southport, Connecticut',2483,8);
INSERT INTO "django_geo_db_city" VALUES(1915,'Stevenson','Stevenson, Connecticut',2484,8);
INSERT INTO "django_geo_db_city" VALUES(1916,'Wallingford','Wallingford, Connecticut',2485,8);
INSERT INTO "django_geo_db_city" VALUES(1917,'Stratford','Stratford, Connecticut',2486,8);
INSERT INTO "django_geo_db_city" VALUES(1918,'Westbrook','Westbrook, Connecticut',2487,8);
INSERT INTO "django_geo_db_city" VALUES(1919,'New Haven','New Haven, Connecticut',2430,8);
INSERT INTO "django_geo_db_city" VALUES(1920,'East Haven','East Haven, Connecticut',2492,8);
INSERT INTO "django_geo_db_city" VALUES(1921,'Hamden','Hamden, Connecticut',2494,8);
INSERT INTO "django_geo_db_city" VALUES(1922,'West Haven','West Haven, Connecticut',2496,8);
INSERT INTO "django_geo_db_city" VALUES(1923,'Bethany','Bethany, Connecticut',2500,8);
INSERT INTO "django_geo_db_city" VALUES(1924,'Woodbridge','Woodbridge, Connecticut',2501,8);
INSERT INTO "django_geo_db_city" VALUES(1925,'Bridgeport','Bridgeport, Connecticut',2450,8);
INSERT INTO "django_geo_db_city" VALUES(1926,'Trumbull','Trumbull, Connecticut',2510,8);
INSERT INTO "django_geo_db_city" VALUES(1927,'Easton','Easton, Connecticut',2511,8);
INSERT INTO "django_geo_db_city" VALUES(1928,'Waterbury','Waterbury, Connecticut',2430,8);
INSERT INTO "django_geo_db_city" VALUES(1929,'Prospect','Prospect, Connecticut',2520,8);
INSERT INTO "django_geo_db_city" VALUES(1930,'Wolcott','Wolcott, Connecticut',2521,8);
INSERT INTO "django_geo_db_city" VALUES(1931,'Bantam','Bantam, Connecticut',2524,8);
INSERT INTO "django_geo_db_city" VALUES(1932,'Bethlehem','Bethlehem, Connecticut',2525,8);
INSERT INTO "django_geo_db_city" VALUES(1933,'Bridgewater','Bridgewater, Connecticut',2526,8);
INSERT INTO "django_geo_db_city" VALUES(1934,'Cornwall','Cornwall, Connecticut',2527,8);
INSERT INTO "django_geo_db_city" VALUES(1935,'Cornwall Bridge','Cornwall Bridge, Connecticut',2528,8);
INSERT INTO "django_geo_db_city" VALUES(1936,'Gaylordsville','Gaylordsville, Connecticut',2529,8);
INSERT INTO "django_geo_db_city" VALUES(1937,'Goshen','Goshen, Connecticut',2530,8);
INSERT INTO "django_geo_db_city" VALUES(1938,'Kent','Kent, Connecticut',2531,8);
INSERT INTO "django_geo_db_city" VALUES(1939,'Lakeside','Lakeside, Connecticut',2532,8);
INSERT INTO "django_geo_db_city" VALUES(1940,'Litchfield','Litchfield, Connecticut',2533,8);
INSERT INTO "django_geo_db_city" VALUES(1941,'Middlebury','Middlebury, Connecticut',2534,8);
INSERT INTO "django_geo_db_city" VALUES(1942,'Morris','Morris, Connecticut',2535,8);
INSERT INTO "django_geo_db_city" VALUES(1943,'Naugatuck','Naugatuck, Connecticut',2536,8);
INSERT INTO "django_geo_db_city" VALUES(1944,'New Milford','New Milford, Connecticut',2537,8);
INSERT INTO "django_geo_db_city" VALUES(1945,'New Preston Marble Dale','New Preston Marble Dale, Connecticut',2538,8);
INSERT INTO "django_geo_db_city" VALUES(1946,'Northfield','Northfield, Connecticut',2539,8);
INSERT INTO "django_geo_db_city" VALUES(1947,'Oakville','Oakville, Connecticut',2540,8);
INSERT INTO "django_geo_db_city" VALUES(1948,'Pequabuck','Pequabuck, Connecticut',2541,8);
INSERT INTO "django_geo_db_city" VALUES(1949,'Plymouth','Plymouth, Connecticut',2542,8);
INSERT INTO "django_geo_db_city" VALUES(1950,'Roxbury','Roxbury, Connecticut',2543,8);
INSERT INTO "django_geo_db_city" VALUES(1951,'Sherman','Sherman, Connecticut',2544,8);
INSERT INTO "django_geo_db_city" VALUES(1952,'South Kent','South Kent, Connecticut',2545,8);
INSERT INTO "django_geo_db_city" VALUES(1953,'Terryville','Terryville, Connecticut',2546,8);
INSERT INTO "django_geo_db_city" VALUES(1954,'Thomaston','Thomaston, Connecticut',2547,8);
INSERT INTO "django_geo_db_city" VALUES(1955,'Torrington','Torrington, Connecticut',2548,8);
INSERT INTO "django_geo_db_city" VALUES(1956,'Harwinton','Harwinton, Connecticut',2549,8);
INSERT INTO "django_geo_db_city" VALUES(1957,'Washington','Washington, Connecticut',2550,8);
INSERT INTO "django_geo_db_city" VALUES(1958,'Washington Depot','Washington Depot, Connecticut',2551,8);
INSERT INTO "django_geo_db_city" VALUES(1959,'Watertown','Watertown, Connecticut',2552,8);
INSERT INTO "django_geo_db_city" VALUES(1960,'West Cornwall','West Cornwall, Connecticut',2553,8);
INSERT INTO "django_geo_db_city" VALUES(1961,'Woodbury','Woodbury, Connecticut',2554,8);
INSERT INTO "django_geo_db_city" VALUES(1962,'Bethel','Bethel, Connecticut',2555,8);
INSERT INTO "django_geo_db_city" VALUES(1963,'Brookfield','Brookfield, Connecticut',2556,8);
INSERT INTO "django_geo_db_city" VALUES(1964,'Cos Cob','Cos Cob, Connecticut',2557,8);
INSERT INTO "django_geo_db_city" VALUES(1965,'Danbury','Danbury, Connecticut',2558,8);
INSERT INTO "django_geo_db_city" VALUES(1966,'New Fairfield','New Fairfield, Connecticut',2560,8);
INSERT INTO "django_geo_db_city" VALUES(1967,'Darien','Darien, Connecticut',2563,8);
INSERT INTO "django_geo_db_city" VALUES(1968,'Georgetown','Georgetown, Connecticut',2566,8);
INSERT INTO "django_geo_db_city" VALUES(1969,'Greenwich','Greenwich, Connecticut',2567,8);
INSERT INTO "django_geo_db_city" VALUES(1970,'New Canaan','New Canaan, Connecticut',2569,8);
INSERT INTO "django_geo_db_city" VALUES(1971,'Norwalk','Norwalk, Connecticut',2571,8);
INSERT INTO "django_geo_db_city" VALUES(1972,'Old Greenwich','Old Greenwich, Connecticut',2578,8);
INSERT INTO "django_geo_db_city" VALUES(1973,'Redding Center','Redding Center, Connecticut',2450,8);
INSERT INTO "django_geo_db_city" VALUES(1974,'Redding Ridge','Redding Ridge, Connecticut',2579,8);
INSERT INTO "django_geo_db_city" VALUES(1975,'Ridgefield','Ridgefield, Connecticut',2580,8);
INSERT INTO "django_geo_db_city" VALUES(1976,'Riverside','Riverside, Connecticut',2581,8);
INSERT INTO "django_geo_db_city" VALUES(1977,'Westport','Westport, Connecticut',2582,8);
INSERT INTO "django_geo_db_city" VALUES(1978,'Weston','Weston, Connecticut',2583,8);
INSERT INTO "django_geo_db_city" VALUES(1979,'Redding','Redding, Connecticut',2586,8);
INSERT INTO "django_geo_db_city" VALUES(1980,'Wilton','Wilton, Connecticut',2587,8);
INSERT INTO "django_geo_db_city" VALUES(1981,'Stamford','Stamford, Connecticut',2588,8);
INSERT INTO "django_geo_db_city" VALUES(1982,'Avenel','Avenel, New Jersey',2599,30);
INSERT INTO "django_geo_db_city" VALUES(1983,'Bayonne','Bayonne, New Jersey',2600,30);
INSERT INTO "django_geo_db_city" VALUES(1984,'Bloomfield','Bloomfield, New Jersey',2601,30);
INSERT INTO "django_geo_db_city" VALUES(1985,'Fairfield','Fairfield, New Jersey',2602,30);
INSERT INTO "django_geo_db_city" VALUES(1986,'Boonton','Boonton, New Jersey',2603,30);
INSERT INTO "django_geo_db_city" VALUES(1987,'Caldwell','Caldwell, New Jersey',2604,30);
INSERT INTO "django_geo_db_city" VALUES(1988,'Carteret','Carteret, New Jersey',2606,30);
INSERT INTO "django_geo_db_city" VALUES(1989,'Cedar Grove','Cedar Grove, New Jersey',2607,30);
INSERT INTO "django_geo_db_city" VALUES(1990,'Cliffside Park','Cliffside Park, New Jersey',2608,30);
INSERT INTO "django_geo_db_city" VALUES(1991,'Clifton','Clifton, New Jersey',2609,30);
INSERT INTO "django_geo_db_city" VALUES(1992,'Cranford','Cranford, New Jersey',2614,30);
INSERT INTO "django_geo_db_city" VALUES(1993,'East Orange','East Orange, New Jersey',2615,30);
INSERT INTO "django_geo_db_city" VALUES(1994,'Edgewater','Edgewater, New Jersey',2617,30);
INSERT INTO "django_geo_db_city" VALUES(1995,'Essex Fells','Essex Fells, New Jersey',2618,30);
INSERT INTO "django_geo_db_city" VALUES(1996,'Fairview','Fairview, New Jersey',2619,30);
INSERT INTO "django_geo_db_city" VALUES(1997,'Fanwood','Fanwood, New Jersey',2620,30);
INSERT INTO "django_geo_db_city" VALUES(1998,'Fort Lee','Fort Lee, New Jersey',2621,30);
INSERT INTO "django_geo_db_city" VALUES(1999,'Garfield','Garfield, New Jersey',2622,30);
INSERT INTO "django_geo_db_city" VALUES(2000,'Garwood','Garwood, New Jersey',2623,30);
INSERT INTO "django_geo_db_city" VALUES(2001,'Glen Ridge','Glen Ridge, New Jersey',2624,30);
INSERT INTO "django_geo_db_city" VALUES(2002,'Harrison','Harrison, New Jersey',2625,30);
INSERT INTO "django_geo_db_city" VALUES(2003,'Hoboken','Hoboken, New Jersey',2626,30);
INSERT INTO "django_geo_db_city" VALUES(2004,'North Arlington','North Arlington, New Jersey',2627,30);
INSERT INTO "django_geo_db_city" VALUES(2005,'Kearny','Kearny, New Jersey',2628,30);
INSERT INTO "django_geo_db_city" VALUES(2006,'Kenilworth','Kenilworth, New Jersey',2629,30);
INSERT INTO "django_geo_db_city" VALUES(2007,'Lake Hiawatha','Lake Hiawatha, New Jersey',2630,30);
INSERT INTO "django_geo_db_city" VALUES(2008,'Lincoln Park','Lincoln Park, New Jersey',2631,30);
INSERT INTO "django_geo_db_city" VALUES(2009,'Linden','Linden, New Jersey',2632,30);
INSERT INTO "django_geo_db_city" VALUES(2010,'Livingston','Livingston, New Jersey',2633,30);
INSERT INTO "django_geo_db_city" VALUES(2011,'Maplewood','Maplewood, New Jersey',2634,30);
INSERT INTO "django_geo_db_city" VALUES(2012,'Millburn','Millburn, New Jersey',2635,30);
INSERT INTO "django_geo_db_city" VALUES(2013,'Montclair','Montclair, New Jersey',2636,30);
INSERT INTO "django_geo_db_city" VALUES(2014,'Verona','Verona, New Jersey',2638,30);
INSERT INTO "django_geo_db_city" VALUES(2015,'Montville','Montville, New Jersey',2639,30);
INSERT INTO "django_geo_db_city" VALUES(2016,'Mountain Lakes','Mountain Lakes, New Jersey',2640,30);
INSERT INTO "django_geo_db_city" VALUES(2017,'North Bergen','North Bergen, New Jersey',2641,30);
INSERT INTO "django_geo_db_city" VALUES(2018,'Orange','Orange, New Jersey',2642,30);
INSERT INTO "django_geo_db_city" VALUES(2019,'West Orange','West Orange, New Jersey',2643,30);
INSERT INTO "django_geo_db_city" VALUES(2020,'Parsippany','Parsippany, New Jersey',2644,30);
INSERT INTO "django_geo_db_city" VALUES(2021,'Passaic','Passaic, New Jersey',2645,30);
INSERT INTO "django_geo_db_city" VALUES(2022,'Wallington','Wallington, New Jersey',2646,30);
INSERT INTO "django_geo_db_city" VALUES(2023,'Pine Brook','Pine Brook, New Jersey',2647,30);
INSERT INTO "django_geo_db_city" VALUES(2024,'Warren','Warren, New Jersey',2648,30);
INSERT INTO "django_geo_db_city" VALUES(2025,'Plainfield','Plainfield, New Jersey',2649,30);
INSERT INTO "django_geo_db_city" VALUES(2026,'Port Reading','Port Reading, New Jersey',2653,30);
INSERT INTO "django_geo_db_city" VALUES(2027,'Rahway','Rahway, New Jersey',2654,30);
INSERT INTO "django_geo_db_city" VALUES(2028,'Clark','Clark, New Jersey',2655,30);
INSERT INTO "django_geo_db_city" VALUES(2029,'Colonia','Colonia, New Jersey',2656,30);
INSERT INTO "django_geo_db_city" VALUES(2030,'Roseland','Roseland, New Jersey',2657,30);
INSERT INTO "django_geo_db_city" VALUES(2031,'Watchung','Watchung, New Jersey',2658,30);
INSERT INTO "django_geo_db_city" VALUES(2032,'Rutherford','Rutherford, New Jersey',2659,30);
INSERT INTO "django_geo_db_city" VALUES(2033,'Lyndhurst','Lyndhurst, New Jersey',2660,30);
INSERT INTO "django_geo_db_city" VALUES(2034,'Carlstadt','Carlstadt, New Jersey',2661,30);
INSERT INTO "django_geo_db_city" VALUES(2035,'East Rutherford','East Rutherford, New Jersey',2662,30);
INSERT INTO "django_geo_db_city" VALUES(2036,'Moonachie','Moonachie, New Jersey',2663,30);
INSERT INTO "django_geo_db_city" VALUES(2037,'Wood Ridge','Wood Ridge, New Jersey',2664,30);
INSERT INTO "django_geo_db_city" VALUES(2038,'Scotch Plains','Scotch Plains, New Jersey',2665,30);
INSERT INTO "django_geo_db_city" VALUES(2039,'Sewaren','Sewaren, New Jersey',2666,30);
INSERT INTO "django_geo_db_city" VALUES(2040,'Short Hills','Short Hills, New Jersey',2667,30);
INSERT INTO "django_geo_db_city" VALUES(2041,'South Orange','South Orange, New Jersey',2668,30);
INSERT INTO "django_geo_db_city" VALUES(2042,'South Plainfield','South Plainfield, New Jersey',2669,30);
INSERT INTO "django_geo_db_city" VALUES(2043,'Springfield','Springfield, New Jersey',2670,30);
INSERT INTO "django_geo_db_city" VALUES(2044,'Towaco','Towaco, New Jersey',2671,30);
INSERT INTO "django_geo_db_city" VALUES(2045,'Union','Union, New Jersey',2672,30);
INSERT INTO "django_geo_db_city" VALUES(2046,'Union City','Union City, New Jersey',2673,30);
INSERT INTO "django_geo_db_city" VALUES(2047,'Vauxhall','Vauxhall, New Jersey',2675,30);
INSERT INTO "django_geo_db_city" VALUES(2048,'Westfield','Westfield, New Jersey',2676,30);
INSERT INTO "django_geo_db_city" VALUES(2049,'Mountainside','Mountainside, New Jersey',2677,30);
INSERT INTO "django_geo_db_city" VALUES(2050,'West New York','West New York, New Jersey',2678,30);
INSERT INTO "django_geo_db_city" VALUES(2051,'Secaucus','Secaucus, New Jersey',2679,30);
INSERT INTO "django_geo_db_city" VALUES(2052,'Woodbridge','Woodbridge, New Jersey',2680,30);
INSERT INTO "django_geo_db_city" VALUES(2053,'Jersey City','Jersey City, New Jersey',2681,30);
INSERT INTO "django_geo_db_city" VALUES(2054,'Newark','Newark, New Jersey',2682,30);
INSERT INTO "django_geo_db_city" VALUES(2055,'Belleville','Belleville, New Jersey',2690,30);
INSERT INTO "django_geo_db_city" VALUES(2056,'Nutley','Nutley, New Jersey',2691,30);
INSERT INTO "django_geo_db_city" VALUES(2057,'Irvington','Irvington, New Jersey',2692,30);
INSERT INTO "django_geo_db_city" VALUES(2058,'Elizabeth','Elizabeth, New Jersey',2696,30);
INSERT INTO "django_geo_db_city" VALUES(2059,'Roselle','Roselle, New Jersey',2698,30);
INSERT INTO "django_geo_db_city" VALUES(2060,'Roselle Park','Roselle Park, New Jersey',2699,30);
INSERT INTO "django_geo_db_city" VALUES(2061,'Hillside','Hillside, New Jersey',2700,30);
INSERT INTO "django_geo_db_city" VALUES(2062,'Bernards','Bernards, New Jersey',2703,30);
INSERT INTO "django_geo_db_city" VALUES(2063,'Allendale','Allendale, New Jersey',2712,30);
INSERT INTO "django_geo_db_city" VALUES(2064,'Bloomingdale','Bloomingdale, New Jersey',2713,30);
INSERT INTO "django_geo_db_city" VALUES(2065,'Butler','Butler, New Jersey',2714,30);
INSERT INTO "django_geo_db_city" VALUES(2066,'Elmwood Park','Elmwood Park, New Jersey',2715,30);
INSERT INTO "django_geo_db_city" VALUES(2067,'Fair Lawn','Fair Lawn, New Jersey',2716,30);
INSERT INTO "django_geo_db_city" VALUES(2068,'Franklin','Franklin, New Jersey',2717,30);
INSERT INTO "django_geo_db_city" VALUES(2069,'Franklin Lakes','Franklin Lakes, New Jersey',2718,30);
INSERT INTO "django_geo_db_city" VALUES(2070,'Glenwood','Glenwood, New Jersey',2719,30);
INSERT INTO "django_geo_db_city" VALUES(2071,'Hamburg','Hamburg, New Jersey',2720,30);
INSERT INTO "django_geo_db_city" VALUES(2072,'Haskell','Haskell, New Jersey',2721,30);
INSERT INTO "django_geo_db_city" VALUES(2073,'Hewitt','Hewitt, New Jersey',2722,30);
INSERT INTO "django_geo_db_city" VALUES(2074,'Highland Lakes','Highland Lakes, New Jersey',2723,30);
INSERT INTO "django_geo_db_city" VALUES(2075,'Ho Ho Kus','Ho Ho Kus, New Jersey',2724,30);
INSERT INTO "django_geo_db_city" VALUES(2076,'Little Falls','Little Falls, New Jersey',2725,30);
INSERT INTO "django_geo_db_city" VALUES(2077,'West Paterson','West Paterson, New Jersey',2726,30);
INSERT INTO "django_geo_db_city" VALUES(2078,'McAfee','McAfee, New Jersey',2727,30);
INSERT INTO "django_geo_db_city" VALUES(2079,'Mahwah','Mahwah, New Jersey',2728,30);
INSERT INTO "django_geo_db_city" VALUES(2080,'Midland Park','Midland Park, New Jersey',2729,30);
INSERT INTO "django_geo_db_city" VALUES(2081,'Newfoundland','Newfoundland, New Jersey',2730,30);
INSERT INTO "django_geo_db_city" VALUES(2082,'Oakland','Oakland, New Jersey',2731,30);
INSERT INTO "django_geo_db_city" VALUES(2083,'Oak Ridge','Oak Ridge, New Jersey',2732,30);
INSERT INTO "django_geo_db_city" VALUES(2084,'Ogdensburg','Ogdensburg, New Jersey',2733,30);
INSERT INTO "django_geo_db_city" VALUES(2085,'Pequannock','Pequannock, New Jersey',2734,30);
INSERT INTO "django_geo_db_city" VALUES(2086,'Pompton Lakes','Pompton Lakes, New Jersey',2735,30);
INSERT INTO "django_geo_db_city" VALUES(2087,'Pompton Plains','Pompton Plains, New Jersey',2736,30);
INSERT INTO "django_geo_db_city" VALUES(2088,'Ramsey','Ramsey, New Jersey',2737,30);
INSERT INTO "django_geo_db_city" VALUES(2089,'Ridgewood','Ridgewood, New Jersey',2738,30);
INSERT INTO "django_geo_db_city" VALUES(2090,'Glen Rock','Glen Rock, New Jersey',2740,30);
INSERT INTO "django_geo_db_city" VALUES(2091,'Ringwood','Ringwood, New Jersey',2741,30);
INSERT INTO "django_geo_db_city" VALUES(2092,'Riverdale','Riverdale, New Jersey',2742,30);
INSERT INTO "django_geo_db_city" VALUES(2093,'Saddle River','Saddle River, New Jersey',2743,30);
INSERT INTO "django_geo_db_city" VALUES(2094,'Stockholm','Stockholm, New Jersey',2744,30);
INSERT INTO "django_geo_db_city" VALUES(2095,'Sussex','Sussex, New Jersey',2745,30);
INSERT INTO "django_geo_db_city" VALUES(2096,'Vernon','Vernon, New Jersey',2746,30);
INSERT INTO "django_geo_db_city" VALUES(2097,'Waldwick','Waldwick, New Jersey',2747,30);
INSERT INTO "django_geo_db_city" VALUES(2098,'Wanaque','Wanaque, New Jersey',2748,30);
INSERT INTO "django_geo_db_city" VALUES(2099,'Wayne','Wayne, New Jersey',2749,30);
INSERT INTO "django_geo_db_city" VALUES(2100,'West Milford','West Milford, New Jersey',2750,30);
INSERT INTO "django_geo_db_city" VALUES(2101,'Wyckoff','Wyckoff, New Jersey',2751,30);
INSERT INTO "django_geo_db_city" VALUES(2102,'Paterson','Paterson, New Jersey',2752,30);
INSERT INTO "django_geo_db_city" VALUES(2103,'Hawthorne','Hawthorne, New Jersey',2757,30);
INSERT INTO "django_geo_db_city" VALUES(2104,'Haledon','Haledon, New Jersey',2758,30);
INSERT INTO "django_geo_db_city" VALUES(2105,'Totowa','Totowa, New Jersey',2613,30);
INSERT INTO "django_geo_db_city" VALUES(2106,'Hackensack','Hackensack, New Jersey',2765,30);
INSERT INTO "django_geo_db_city" VALUES(2107,'Bogota','Bogota, New Jersey',2766,30);
INSERT INTO "django_geo_db_city" VALUES(2108,'Hasbrouck Heights','Hasbrouck Heights, New Jersey',2767,30);
INSERT INTO "django_geo_db_city" VALUES(2109,'Leonia','Leonia, New Jersey',2768,30);
INSERT INTO "django_geo_db_city" VALUES(2110,'South Hackensack','South Hackensack, New Jersey',2769,30);
INSERT INTO "django_geo_db_city" VALUES(2111,'Maywood','Maywood, New Jersey',2770,30);
INSERT INTO "django_geo_db_city" VALUES(2112,'Teterboro','Teterboro, New Jersey',2771,30);
INSERT INTO "django_geo_db_city" VALUES(2113,'Oradell','Oradell, New Jersey',2772,30);
INSERT INTO "django_geo_db_city" VALUES(2114,'Alpine','Alpine, New Jersey',2773,30);
INSERT INTO "django_geo_db_city" VALUES(2115,'Bergenfield','Bergenfield, New Jersey',2774,30);
INSERT INTO "django_geo_db_city" VALUES(2116,'Closter','Closter, New Jersey',2775,30);
INSERT INTO "django_geo_db_city" VALUES(2117,'Cresskill','Cresskill, New Jersey',2776,30);
INSERT INTO "django_geo_db_city" VALUES(2118,'Demarest','Demarest, New Jersey',2777,30);
INSERT INTO "django_geo_db_city" VALUES(2119,'Dumont','Dumont, New Jersey',2778,30);
INSERT INTO "django_geo_db_city" VALUES(2120,'Emerson','Emerson, New Jersey',2779,30);
INSERT INTO "django_geo_db_city" VALUES(2121,'Englewood','Englewood, New Jersey',2780,30);
INSERT INTO "django_geo_db_city" VALUES(2122,'Englewood Cliffs','Englewood Cliffs, New Jersey',2781,30);
INSERT INTO "django_geo_db_city" VALUES(2123,'Harrington Park','Harrington Park, New Jersey',2782,30);
INSERT INTO "django_geo_db_city" VALUES(2124,'Haworth','Haworth, New Jersey',2783,30);
INSERT INTO "django_geo_db_city" VALUES(2125,'Hillsdale','Hillsdale, New Jersey',2784,30);
INSERT INTO "django_geo_db_city" VALUES(2126,'Little Ferry','Little Ferry, New Jersey',2785,30);
INSERT INTO "django_geo_db_city" VALUES(2127,'Lodi','Lodi, New Jersey',2786,30);
INSERT INTO "django_geo_db_city" VALUES(2128,'Montvale','Montvale, New Jersey',2787,30);
INSERT INTO "django_geo_db_city" VALUES(2129,'New Milford','New Milford, New Jersey',2788,30);
INSERT INTO "django_geo_db_city" VALUES(2130,'Northvale','Northvale, New Jersey',2789,30);
INSERT INTO "django_geo_db_city" VALUES(2131,'Norwood','Norwood, New Jersey',2790,30);
INSERT INTO "django_geo_db_city" VALUES(2132,'Palisades Park','Palisades Park, New Jersey',2792,30);
INSERT INTO "django_geo_db_city" VALUES(2133,'Paramus','Paramus, New Jersey',2793,30);
INSERT INTO "django_geo_db_city" VALUES(2134,'Park Ridge','Park Ridge, New Jersey',2794,30);
INSERT INTO "django_geo_db_city" VALUES(2135,'Ridgefield','Ridgefield, New Jersey',2795,30);
INSERT INTO "django_geo_db_city" VALUES(2136,'Ridgefield Park','Ridgefield Park, New Jersey',2796,30);
INSERT INTO "django_geo_db_city" VALUES(2137,'River Edge','River Edge, New Jersey',2797,30);
INSERT INTO "django_geo_db_city" VALUES(2138,'Rochelle Park','Rochelle Park, New Jersey',2798,30);
INSERT INTO "django_geo_db_city" VALUES(2139,'Saddle Brook','Saddle Brook, New Jersey',2799,30);
INSERT INTO "django_geo_db_city" VALUES(2140,'Teaneck','Teaneck, New Jersey',2800,30);
INSERT INTO "django_geo_db_city" VALUES(2141,'Tenafly','Tenafly, New Jersey',2801,30);
INSERT INTO "django_geo_db_city" VALUES(2142,'Westwood','Westwood, New Jersey',2802,30);
INSERT INTO "django_geo_db_city" VALUES(2143,'Ho-Ho-Kus','Ho-Ho-Kus, New Jersey',2803,30);
INSERT INTO "django_geo_db_city" VALUES(2144,'Woodcliff Lake','Woodcliff Lake, New Jersey',2804,30);
INSERT INTO "django_geo_db_city" VALUES(2145,'Red Bank','Red Bank, New Jersey',2805,30);
INSERT INTO "django_geo_db_city" VALUES(2146,'Shrewsbury','Shrewsbury, New Jersey',2806,30);
INSERT INTO "django_geo_db_city" VALUES(2147,'Fort Monmouth','Fort Monmouth, New Jersey',2807,30);
INSERT INTO "django_geo_db_city" VALUES(2148,'Fair Haven','Fair Haven, New Jersey',2808,30);
INSERT INTO "django_geo_db_city" VALUES(2149,'Allenhurst','Allenhurst, New Jersey',2809,30);
INSERT INTO "django_geo_db_city" VALUES(2150,'Adelphia','Adelphia, New Jersey',2809,30);
INSERT INTO "django_geo_db_city" VALUES(2151,'Asbury Park','Asbury Park, New Jersey',2811,30);
INSERT INTO "django_geo_db_city" VALUES(2152,'Belmar','Belmar, New Jersey',2809,30);
INSERT INTO "django_geo_db_city" VALUES(2153,'Atlantic Highlands','Atlantic Highlands, New Jersey',2812,30);
INSERT INTO "django_geo_db_city" VALUES(2154,'Avon By The Sea','Avon By The Sea, New Jersey',2813,30);
INSERT INTO "django_geo_db_city" VALUES(2155,'Belford','Belford, New Jersey',2814,30);
INSERT INTO "django_geo_db_city" VALUES(2156,'Bradley Beach','Bradley Beach, New Jersey',2816,30);
INSERT INTO "django_geo_db_city" VALUES(2157,'Cliffwood','Cliffwood, New Jersey',2817,30);
INSERT INTO "django_geo_db_city" VALUES(2158,'Colts Neck','Colts Neck, New Jersey',2818,30);
INSERT INTO "django_geo_db_city" VALUES(2159,'Deal','Deal, New Jersey',2819,30);
INSERT INTO "django_geo_db_city" VALUES(2160,'Eatontown','Eatontown, New Jersey',2820,30);
INSERT INTO "django_geo_db_city" VALUES(2161,'Englishtown','Englishtown, New Jersey',2821,30);
INSERT INTO "django_geo_db_city" VALUES(2162,'Farmingdale','Farmingdale, New Jersey',2822,30);
INSERT INTO "django_geo_db_city" VALUES(2163,'Freehold','Freehold, New Jersey',2823,30);
INSERT INTO "django_geo_db_city" VALUES(2164,'Hazlet','Hazlet, New Jersey',2824,30);
INSERT INTO "django_geo_db_city" VALUES(2165,'Howell','Howell, New Jersey',2825,30);
INSERT INTO "django_geo_db_city" VALUES(2166,'Highlands','Highlands, New Jersey',2826,30);
INSERT INTO "django_geo_db_city" VALUES(2167,'Holmdel','Holmdel, New Jersey',2827,30);
INSERT INTO "django_geo_db_city" VALUES(2168,'Keansburg','Keansburg, New Jersey',2828,30);
INSERT INTO "django_geo_db_city" VALUES(2169,'Keyport','Keyport, New Jersey',2829,30);
INSERT INTO "django_geo_db_city" VALUES(2170,'Leonardo','Leonardo, New Jersey',2830,30);
INSERT INTO "django_geo_db_city" VALUES(2171,'Lincroft','Lincroft, New Jersey',2831,30);
INSERT INTO "django_geo_db_city" VALUES(2172,'Little Silver','Little Silver, New Jersey',2832,30);
INSERT INTO "django_geo_db_city" VALUES(2173,'Long Branch','Long Branch, New Jersey',2833,30);
INSERT INTO "django_geo_db_city" VALUES(2174,'Marlboro','Marlboro, New Jersey',2834,30);
INSERT INTO "django_geo_db_city" VALUES(2175,'Matawan','Matawan, New Jersey',2835,30);
INSERT INTO "django_geo_db_city" VALUES(2176,'Middletown','Middletown, New Jersey',2836,30);
INSERT INTO "django_geo_db_city" VALUES(2177,'Monmouth Beach','Monmouth Beach, New Jersey',2837,30);
INSERT INTO "django_geo_db_city" VALUES(2178,'Morganville','Morganville, New Jersey',2838,30);
INSERT INTO "django_geo_db_city" VALUES(2179,'Navesink','Navesink, New Jersey',2839,30);
INSERT INTO "django_geo_db_city" VALUES(2180,'Neptune','Neptune, New Jersey',2840,30);
INSERT INTO "django_geo_db_city" VALUES(2181,'Oakhurst','Oakhurst, New Jersey',2841,30);
INSERT INTO "django_geo_db_city" VALUES(2182,'Ocean Grove','Ocean Grove, New Jersey',2842,30);
INSERT INTO "django_geo_db_city" VALUES(2183,'Oceanport','Oceanport, New Jersey',2843,30);
INSERT INTO "django_geo_db_city" VALUES(2184,'Port Monmouth','Port Monmouth, New Jersey',2844,30);
INSERT INTO "django_geo_db_city" VALUES(2185,'Rumson','Rumson, New Jersey',2845,30);
INSERT INTO "django_geo_db_city" VALUES(2186,'Spring Lake','Spring Lake, New Jersey',2846,30);
INSERT INTO "django_geo_db_city" VALUES(2187,'Tennent','Tennent, New Jersey',2809,30);
INSERT INTO "django_geo_db_city" VALUES(2188,'West Long Branch','West Long Branch, New Jersey',2847,30);
INSERT INTO "django_geo_db_city" VALUES(2189,'Wickatunk','Wickatunk, New Jersey',2809,30);
INSERT INTO "django_geo_db_city" VALUES(2190,'Dover','Dover, New Jersey',2848,30);
INSERT INTO "django_geo_db_city" VALUES(2191,'Mine Hill','Mine Hill, New Jersey',2850,30);
INSERT INTO "django_geo_db_city" VALUES(2192,'Picatinny Arsenal','Picatinny Arsenal, New Jersey',2849,30);
INSERT INTO "django_geo_db_city" VALUES(2193,'Hardyston','Hardyston, New Jersey',2851,30);
INSERT INTO "django_geo_db_city" VALUES(2194,'Allamuchy','Allamuchy, New Jersey',2852,30);
INSERT INTO "django_geo_db_city" VALUES(2195,'Andover','Andover, New Jersey',2853,30);
INSERT INTO "django_geo_db_city" VALUES(2196,'Augusta','Augusta, New Jersey',2854,30);
INSERT INTO "django_geo_db_city" VALUES(2197,'Belvidere','Belvidere, New Jersey',2855,30);
INSERT INTO "django_geo_db_city" VALUES(2198,'Blairstown','Blairstown, New Jersey',2856,30);
INSERT INTO "django_geo_db_city" VALUES(2199,'Branchville','Branchville, New Jersey',2857,30);
INSERT INTO "django_geo_db_city" VALUES(2200,'Montague','Montague, New Jersey',2858,30);
INSERT INTO "django_geo_db_city" VALUES(2201,'Budd Lake','Budd Lake, New Jersey',2859,30);
INSERT INTO "django_geo_db_city" VALUES(2202,'Buttzville','Buttzville, New Jersey',2860,30);
INSERT INTO "django_geo_db_city" VALUES(2203,'Califon','Califon, New Jersey',2861,30);
INSERT INTO "django_geo_db_city" VALUES(2204,'Changewater','Changewater, New Jersey',2862,30);
INSERT INTO "django_geo_db_city" VALUES(2205,'Columbia','Columbia, New Jersey',2863,30);
INSERT INTO "django_geo_db_city" VALUES(2206,'Delaware','Delaware, New Jersey',2864,30);
INSERT INTO "django_geo_db_city" VALUES(2207,'Denville','Denville, New Jersey',2865,30);
INSERT INTO "django_geo_db_city" VALUES(2208,'Flanders','Flanders, New Jersey',2866,30);
INSERT INTO "django_geo_db_city" VALUES(2209,'Glasser','Glasser, New Jersey',2867,30);
INSERT INTO "django_geo_db_city" VALUES(2210,'Great Meadows','Great Meadows, New Jersey',2868,30);
INSERT INTO "django_geo_db_city" VALUES(2211,'Greendell','Greendell, New Jersey',2867,30);
INSERT INTO "django_geo_db_city" VALUES(2212,'Hackettstown','Hackettstown, New Jersey',2869,30);
INSERT INTO "django_geo_db_city" VALUES(2213,'Great Meadows-Vienna','Great Meadows-Vienna, New Jersey',2870,30);
INSERT INTO "django_geo_db_city" VALUES(2214,'Hibernia','Hibernia, New Jersey',2871,30);
INSERT INTO "django_geo_db_city" VALUES(2215,'Hopatcong','Hopatcong, New Jersey',2872,30);
INSERT INTO "django_geo_db_city" VALUES(2216,'Hope','Hope, New Jersey',2873,30);
INSERT INTO "django_geo_db_city" VALUES(2217,'Ironia','Ironia, New Jersey',2849,30);
INSERT INTO "django_geo_db_city" VALUES(2218,'Johnsonburg','Johnsonburg, New Jersey',2874,30);
INSERT INTO "django_geo_db_city" VALUES(2219,'Kenvil','Kenvil, New Jersey',2875,30);
INSERT INTO "django_geo_db_city" VALUES(2220,'Lafayette','Lafayette, New Jersey',2876,30);
INSERT INTO "django_geo_db_city" VALUES(2221,'Lake Hopatcong','Lake Hopatcong, New Jersey',2877,30);
INSERT INTO "django_geo_db_city" VALUES(2222,'Landing','Landing, New Jersey',2878,30);
INSERT INTO "django_geo_db_city" VALUES(2223,'Layton','Layton, New Jersey',2879,30);
INSERT INTO "django_geo_db_city" VALUES(2224,'Ledgewood','Ledgewood, New Jersey',2880,30);
INSERT INTO "django_geo_db_city" VALUES(2225,'Long Valley','Long Valley, New Jersey',2881,30);
INSERT INTO "django_geo_db_city" VALUES(2226,'Middleville','Middleville, New Jersey',2867,30);
INSERT INTO "django_geo_db_city" VALUES(2227,'Mount Arlington','Mount Arlington, New Jersey',2882,30);
INSERT INTO "django_geo_db_city" VALUES(2228,'Netcong','Netcong, New Jersey',2883,30);
INSERT INTO "django_geo_db_city" VALUES(2229,'Newton','Newton, New Jersey',2884,30);
INSERT INTO "django_geo_db_city" VALUES(2230,'Oxford','Oxford, New Jersey',2885,30);
INSERT INTO "django_geo_db_city" VALUES(2231,'Port Murray','Port Murray, New Jersey',2886,30);
INSERT INTO "django_geo_db_city" VALUES(2232,'Rockaway','Rockaway, New Jersey',2887,30);
INSERT INTO "django_geo_db_city" VALUES(2233,'Randolph','Randolph, New Jersey',2888,30);
INSERT INTO "django_geo_db_city" VALUES(2234,'Schooleys Mountain','Schooleys Mountain, New Jersey',2889,30);
INSERT INTO "django_geo_db_city" VALUES(2235,'Sparta','Sparta, New Jersey',2890,30);
INSERT INTO "django_geo_db_city" VALUES(2236,'Stanhope','Stanhope, New Jersey',2891,30);
INSERT INTO "django_geo_db_city" VALUES(2237,'Stillwater','Stillwater, New Jersey',2892,30);
INSERT INTO "django_geo_db_city" VALUES(2238,'Succasunna','Succasunna, New Jersey',2893,30);
INSERT INTO "django_geo_db_city" VALUES(2239,'Swartswood','Swartswood, New Jersey',2894,30);
INSERT INTO "django_geo_db_city" VALUES(2240,'Mount Tabor','Mount Tabor, New Jersey',2895,30);
INSERT INTO "django_geo_db_city" VALUES(2241,'Tranquility','Tranquility, New Jersey',2896,30);
INSERT INTO "django_geo_db_city" VALUES(2242,'Vienna','Vienna, New Jersey',2897,30);
INSERT INTO "django_geo_db_city" VALUES(2243,'Wallpack Center','Wallpack Center, New Jersey',2898,30);
INSERT INTO "django_geo_db_city" VALUES(2244,'Washington','Washington, New Jersey',2899,30);
INSERT INTO "django_geo_db_city" VALUES(2245,'Wharton','Wharton, New Jersey',2900,30);
INSERT INTO "django_geo_db_city" VALUES(2246,'Summit','Summit, New Jersey',2901,30);
INSERT INTO "django_geo_db_city" VALUES(2247,'Basking Ridge','Basking Ridge, New Jersey',2903,30);
INSERT INTO "django_geo_db_city" VALUES(2248,'Bedminster','Bedminster, New Jersey',2904,30);
INSERT INTO "django_geo_db_city" VALUES(2249,'Berkeley Heights','Berkeley Heights, New Jersey',2905,30);
INSERT INTO "django_geo_db_city" VALUES(2250,'Bernardsville','Bernardsville, New Jersey',2906,30);
INSERT INTO "django_geo_db_city" VALUES(2251,'Brookside','Brookside, New Jersey',2907,30);
INSERT INTO "django_geo_db_city" VALUES(2252,'Cedar Knolls','Cedar Knolls, New Jersey',2908,30);
INSERT INTO "django_geo_db_city" VALUES(2253,'Chatham','Chatham, New Jersey',2909,30);
INSERT INTO "django_geo_db_city" VALUES(2254,'Chester','Chester, New Jersey',2910,30);
INSERT INTO "django_geo_db_city" VALUES(2255,'Far Hills','Far Hills, New Jersey',2911,30);
INSERT INTO "django_geo_db_city" VALUES(2256,'Florham Park','Florham Park, New Jersey',2912,30);
INSERT INTO "django_geo_db_city" VALUES(2257,'Gillette','Gillette, New Jersey',2913,30);
INSERT INTO "django_geo_db_city" VALUES(2258,'Gladstone','Gladstone, New Jersey',2914,30);
INSERT INTO "django_geo_db_city" VALUES(2259,'Green Village','Green Village, New Jersey',2915,30);
INSERT INTO "django_geo_db_city" VALUES(2260,'East Hanover','East Hanover, New Jersey',2916,30);
INSERT INTO "django_geo_db_city" VALUES(2261,'Liberty Corner','Liberty Corner, New Jersey',2917,30);
INSERT INTO "django_geo_db_city" VALUES(2262,'Lyons','Lyons, New Jersey',2918,30);
INSERT INTO "django_geo_db_city" VALUES(2263,'Madison','Madison, New Jersey',2919,30);
INSERT INTO "django_geo_db_city" VALUES(2264,'Mendham','Mendham, New Jersey',2920,30);
INSERT INTO "django_geo_db_city" VALUES(2265,'Millington','Millington, New Jersey',2921,30);
INSERT INTO "django_geo_db_city" VALUES(2266,'Morris Plains','Morris Plains, New Jersey',2922,30);
INSERT INTO "django_geo_db_city" VALUES(2267,'Morristown','Morristown, New Jersey',2924,30);
INSERT INTO "django_geo_db_city" VALUES(2268,'Mount Freedom','Mount Freedom, New Jersey',2927,30);
INSERT INTO "django_geo_db_city" VALUES(2269,'New Providence','New Providence, New Jersey',2928,30);
INSERT INTO "django_geo_db_city" VALUES(2270,'New Vernon','New Vernon, New Jersey',2929,30);
INSERT INTO "django_geo_db_city" VALUES(2271,'Peapack','Peapack, New Jersey',2930,30);
INSERT INTO "django_geo_db_city" VALUES(2272,'Pluckemin','Pluckemin, New Jersey',2931,30);
INSERT INTO "django_geo_db_city" VALUES(2273,'Pottersville','Pottersville, New Jersey',2932,30);
INSERT INTO "django_geo_db_city" VALUES(2274,'Stirling','Stirling, New Jersey',2933,30);
INSERT INTO "django_geo_db_city" VALUES(2275,'Whippany','Whippany, New Jersey',2934,30);
INSERT INTO "django_geo_db_city" VALUES(2276,'Peapack and Gladstone','Peapack and Gladstone, New Jersey',2935,30);
INSERT INTO "django_geo_db_city" VALUES(2277,'Alloway','Alloway, New Jersey',2936,30);
INSERT INTO "django_geo_db_city" VALUES(2278,'Cherry Hill','Cherry Hill, New Jersey',2937,30);
INSERT INTO "django_geo_db_city" VALUES(2279,'Atco','Atco, New Jersey',2939,30);
INSERT INTO "django_geo_db_city" VALUES(2280,'Barnegat','Barnegat, New Jersey',2940,30);
INSERT INTO "django_geo_db_city" VALUES(2281,'Barnegat Light','Barnegat Light, New Jersey',2941,30);
INSERT INTO "django_geo_db_city" VALUES(2282,'Barrington','Barrington, New Jersey',2942,30);
INSERT INTO "django_geo_db_city" VALUES(2283,'Beach Haven','Beach Haven, New Jersey',2943,30);
INSERT INTO "django_geo_db_city" VALUES(2284,'Berlin','Berlin, New Jersey',2944,30);
INSERT INTO "django_geo_db_city" VALUES(2285,'Beverly','Beverly, New Jersey',2945,30);
INSERT INTO "django_geo_db_city" VALUES(2286,'Birmingham','Birmingham, New Jersey',2946,30);
INSERT INTO "django_geo_db_city" VALUES(2287,'Blackwood','Blackwood, New Jersey',2947,30);
INSERT INTO "django_geo_db_city" VALUES(2288,'Bridgeport','Bridgeport, New Jersey',2948,30);
INSERT INTO "django_geo_db_city" VALUES(2289,'Browns Mills','Browns Mills, New Jersey',2949,30);
INSERT INTO "django_geo_db_city" VALUES(2290,'Burlington','Burlington, New Jersey',2950,30);
INSERT INTO "django_geo_db_city" VALUES(2291,'Elwood-Magnolia','Elwood-Magnolia, New Jersey',2951,30);
INSERT INTO "django_geo_db_city" VALUES(2292,'Cedar Brook','Cedar Brook, New Jersey',2952,30);
INSERT INTO "django_geo_db_city" VALUES(2293,'Chatsworth','Chatsworth, New Jersey',2953,30);
INSERT INTO "django_geo_db_city" VALUES(2294,'Clarksboro','Clarksboro, New Jersey',2954,30);
INSERT INTO "django_geo_db_city" VALUES(2295,'Clementon','Clementon, New Jersey',2955,30);
INSERT INTO "django_geo_db_city" VALUES(2296,'Columbus','Columbus, New Jersey',2956,30);
INSERT INTO "django_geo_db_city" VALUES(2297,'Deepwater','Deepwater, New Jersey',2957,30);
INSERT INTO "django_geo_db_city" VALUES(2298,'Ewan','Ewan, New Jersey',2958,30);
INSERT INTO "django_geo_db_city" VALUES(2299,'Gibbsboro','Gibbsboro, New Jersey',2959,30);
INSERT INTO "django_geo_db_city" VALUES(2300,'Gibbstown','Gibbstown, New Jersey',2960,30);
INSERT INTO "django_geo_db_city" VALUES(2301,'Glassboro','Glassboro, New Jersey',2961,30);
INSERT INTO "django_geo_db_city" VALUES(2302,'Glendora','Glendora, New Jersey',2962,30);
INSERT INTO "django_geo_db_city" VALUES(2303,'Gloucester City','Gloucester City, New Jersey',2963,30);
INSERT INTO "django_geo_db_city" VALUES(2304,'Bellmawr','Bellmawr, New Jersey',2964,30);
INSERT INTO "django_geo_db_city" VALUES(2305,'Grenloch','Grenloch, New Jersey',2965,30);
INSERT INTO "django_geo_db_city" VALUES(2306,'Haddonfield','Haddonfield, New Jersey',2966,30);
INSERT INTO "django_geo_db_city" VALUES(2307,'Haddon Heights','Haddon Heights, New Jersey',2968,30);
INSERT INTO "django_geo_db_city" VALUES(2308,'Hainesport','Hainesport, New Jersey',2969,30);
INSERT INTO "django_geo_db_city" VALUES(2309,'Hammonton','Hammonton, New Jersey',2970,30);
INSERT INTO "django_geo_db_city" VALUES(2310,'Hancocks Bridge','Hancocks Bridge, New Jersey',2971,30);
INSERT INTO "django_geo_db_city" VALUES(2311,'Harrisonville','Harrisonville, New Jersey',2972,30);
INSERT INTO "django_geo_db_city" VALUES(2312,'Jobstown','Jobstown, New Jersey',2973,30);
INSERT INTO "django_geo_db_city" VALUES(2313,'Juliustown','Juliustown, New Jersey',2974,30);
INSERT INTO "django_geo_db_city" VALUES(2314,'Voorhees','Voorhees, New Jersey',2975,30);
INSERT INTO "django_geo_db_city" VALUES(2315,'Lawnside','Lawnside, New Jersey',2976,30);
INSERT INTO "django_geo_db_city" VALUES(2316,'Willingboro','Willingboro, New Jersey',2977,30);
INSERT INTO "django_geo_db_city" VALUES(2317,'Lumberton','Lumberton, New Jersey',2978,30);
INSERT INTO "django_geo_db_city" VALUES(2318,'Magnolia','Magnolia, New Jersey',2979,30);
INSERT INTO "django_geo_db_city" VALUES(2319,'Manahawkin','Manahawkin, New Jersey',2980,30);
INSERT INTO "django_geo_db_city" VALUES(2320,'Mantua','Mantua, New Jersey',2981,30);
INSERT INTO "django_geo_db_city" VALUES(2321,'Maple Shade','Maple Shade, New Jersey',2982,30);
INSERT INTO "django_geo_db_city" VALUES(2322,'Marlton','Marlton, New Jersey',2983,30);
INSERT INTO "django_geo_db_city" VALUES(2323,'Mount Laurel','Mount Laurel, New Jersey',2984,30);
INSERT INTO "django_geo_db_city" VALUES(2324,'Medford','Medford, New Jersey',2985,30);
INSERT INTO "django_geo_db_city" VALUES(2325,'Mickleton','Mickleton, New Jersey',2986,30);
INSERT INTO "django_geo_db_city" VALUES(2326,'Moorestown','Moorestown, New Jersey',2987,30);
INSERT INTO "django_geo_db_city" VALUES(2327,'Mount Ephraim','Mount Ephraim, New Jersey',2988,30);
INSERT INTO "django_geo_db_city" VALUES(2328,'Mount Holly','Mount Holly, New Jersey',2989,30);
INSERT INTO "django_geo_db_city" VALUES(2329,'Mount Royal','Mount Royal, New Jersey',2990,30);
INSERT INTO "django_geo_db_city" VALUES(2330,'Mullica Hill','Mullica Hill, New Jersey',2991,30);
INSERT INTO "django_geo_db_city" VALUES(2331,'National Park','National Park, New Jersey',2992,30);
INSERT INTO "django_geo_db_city" VALUES(2332,'New Lisbon','New Lisbon, New Jersey',2993,30);
INSERT INTO "django_geo_db_city" VALUES(2333,'Palmyra','Palmyra, New Jersey',2994,30);
INSERT INTO "django_geo_db_city" VALUES(2334,'Paulsboro','Paulsboro, New Jersey',2995,30);
INSERT INTO "django_geo_db_city" VALUES(2335,'Pedricktown','Pedricktown, New Jersey',2996,30);
INSERT INTO "django_geo_db_city" VALUES(2336,'Pemberton','Pemberton, New Jersey',2997,30);
INSERT INTO "django_geo_db_city" VALUES(2337,'Penns Grove','Penns Grove, New Jersey',2998,30);
INSERT INTO "django_geo_db_city" VALUES(2338,'Pennsville','Pennsville, New Jersey',2999,30);
INSERT INTO "django_geo_db_city" VALUES(2339,'Pitman','Pitman, New Jersey',3000,30);
INSERT INTO "django_geo_db_city" VALUES(2340,'Quinton','Quinton, New Jersey',3001,30);
INSERT INTO "django_geo_db_city" VALUES(2341,'Rancocas','Rancocas, New Jersey',3002,30);
INSERT INTO "django_geo_db_city" VALUES(2342,'Richwood','Richwood, New Jersey',3003,30);
INSERT INTO "django_geo_db_city" VALUES(2343,'Riverside','Riverside, New Jersey',3004,30);
INSERT INTO "django_geo_db_city" VALUES(2344,'Riverton','Riverton, New Jersey',3005,30);
INSERT INTO "django_geo_db_city" VALUES(2345,'Runnemede','Runnemede, New Jersey',3007,30);
INSERT INTO "django_geo_db_city" VALUES(2346,'Salem','Salem, New Jersey',3008,30);
INSERT INTO "django_geo_db_city" VALUES(2347,'Sewell','Sewell, New Jersey',3009,30);
INSERT INTO "django_geo_db_city" VALUES(2348,'Sicklerville','Sicklerville, New Jersey',3010,30);
INSERT INTO "django_geo_db_city" VALUES(2349,'Somerdale','Somerdale, New Jersey',3011,30);
INSERT INTO "django_geo_db_city" VALUES(2350,'Stratford','Stratford, New Jersey',3012,30);
INSERT INTO "django_geo_db_city" VALUES(2351,'Swedesboro','Swedesboro, New Jersey',3013,30);
INSERT INTO "django_geo_db_city" VALUES(2352,'Thorofare','Thorofare, New Jersey',3014,30);
INSERT INTO "django_geo_db_city" VALUES(2353,'Tuckerton','Tuckerton, New Jersey',3015,30);
INSERT INTO "django_geo_db_city" VALUES(2354,'Vincentown','Vincentown, New Jersey',3016,30);
INSERT INTO "django_geo_db_city" VALUES(2355,'Waterford Works','Waterford Works, New Jersey',3017,30);
INSERT INTO "django_geo_db_city" VALUES(2356,'Wenonah','Wenonah, New Jersey',3018,30);
INSERT INTO "django_geo_db_city" VALUES(2357,'West Berlin','West Berlin, New Jersey',3019,30);
INSERT INTO "django_geo_db_city" VALUES(2358,'West Creek','West Creek, New Jersey',3020,30);
INSERT INTO "django_geo_db_city" VALUES(2359,'Westville','Westville, New Jersey',3021,30);
INSERT INTO "django_geo_db_city" VALUES(2360,'Williamstown','Williamstown, New Jersey',3022,30);
INSERT INTO "django_geo_db_city" VALUES(2361,'Winslow','Winslow, New Jersey',3023,30);
INSERT INTO "django_geo_db_city" VALUES(2362,'Woodbury','Woodbury, New Jersey',3024,30);
INSERT INTO "django_geo_db_city" VALUES(2363,'Woodbury Heights','Woodbury Heights, New Jersey',3025,30);
INSERT INTO "django_geo_db_city" VALUES(2364,'Woodstown','Woodstown, New Jersey',3026,30);
INSERT INTO "django_geo_db_city" VALUES(2365,'Camden','Camden, New Jersey',2952,30);
INSERT INTO "django_geo_db_city" VALUES(2366,'Audubon','Audubon, New Jersey',3032,30);
INSERT INTO "django_geo_db_city" VALUES(2367,'Oaklyn','Oaklyn, New Jersey',3033,30);
INSERT INTO "django_geo_db_city" VALUES(2368,'Collingswood','Collingswood, New Jersey',3034,30);
INSERT INTO "django_geo_db_city" VALUES(2369,'Merchantville','Merchantville, New Jersey',3035,30);
INSERT INTO "django_geo_db_city" VALUES(2370,'Pennsauken','Pennsauken, New Jersey',3036,30);
INSERT INTO "django_geo_db_city" VALUES(2371,'Absecon','Absecon, New Jersey',3037,30);
INSERT INTO "django_geo_db_city" VALUES(2372,'Avalon','Avalon, New Jersey',3038,30);
INSERT INTO "django_geo_db_city" VALUES(2373,'Brigantine','Brigantine, New Jersey',3039,30);
INSERT INTO "django_geo_db_city" VALUES(2374,'Cape May','Cape May, New Jersey',3040,30);
INSERT INTO "django_geo_db_city" VALUES(2375,'Cape May Court House','Cape May Court House, New Jersey',3042,30);
INSERT INTO "django_geo_db_city" VALUES(2376,'Cape May Point','Cape May Point, New Jersey',3043,30);
INSERT INTO "django_geo_db_city" VALUES(2377,'Cologne','Cologne, New Jersey',3044,30);
INSERT INTO "django_geo_db_city" VALUES(2378,'Dennisville','Dennisville, New Jersey',3045,30);
INSERT INTO "django_geo_db_city" VALUES(2379,'Egg Harbor City','Egg Harbor City, New Jersey',3046,30);
INSERT INTO "django_geo_db_city" VALUES(2380,'Elwood','Elwood, New Jersey',3047,30);
INSERT INTO "django_geo_db_city" VALUES(2381,'Goshen','Goshen, New Jersey',3045,30);
INSERT INTO "django_geo_db_city" VALUES(2382,'Green Creek','Green Creek, New Jersey',3045,30);
INSERT INTO "django_geo_db_city" VALUES(2383,'Leeds Point','Leeds Point, New Jersey',3044,30);
INSERT INTO "django_geo_db_city" VALUES(2384,'Linwood','Linwood, New Jersey',3048,30);
INSERT INTO "django_geo_db_city" VALUES(2385,'Marmora','Marmora, New Jersey',3049,30);
INSERT INTO "django_geo_db_city" VALUES(2386,'New Gretna','New Gretna, New Jersey',3050,30);
INSERT INTO "django_geo_db_city" VALUES(2387,'Northfield','Northfield, New Jersey',3051,30);
INSERT INTO "django_geo_db_city" VALUES(2388,'Ocean City','Ocean City, New Jersey',3052,30);
INSERT INTO "django_geo_db_city" VALUES(2389,'Bass River','Bass River, New Jersey',3053,30);
INSERT INTO "django_geo_db_city" VALUES(2390,'Ocean View','Ocean View, New Jersey',3054,30);
INSERT INTO "django_geo_db_city" VALUES(2391,'Oceanville','Oceanville, New Jersey',3044,30);
INSERT INTO "django_geo_db_city" VALUES(2392,'Pleasantville','Pleasantville, New Jersey',3055,30);
INSERT INTO "django_geo_db_city" VALUES(2393,'Egg Harbor Township','Egg Harbor Township, New Jersey',3056,30);
INSERT INTO "django_geo_db_city" VALUES(2394,'Maurice River','Maurice River, New Jersey',3057,30);
INSERT INTO "django_geo_db_city" VALUES(2395,'Pomona','Pomona, New Jersey',3058,30);
INSERT INTO "django_geo_db_city" VALUES(2396,'Port Republic','Port Republic, New Jersey',3059,30);
INSERT INTO "django_geo_db_city" VALUES(2397,'Rio Grande','Rio Grande, New Jersey',3060,30);
INSERT INTO "django_geo_db_city" VALUES(2398,'Sea Isle City','Sea Isle City, New Jersey',3061,30);
INSERT INTO "django_geo_db_city" VALUES(2399,'Somers Point','Somers Point, New Jersey',3062,30);
INSERT INTO "django_geo_db_city" VALUES(2400,'South Dennis','South Dennis, New Jersey',3063,30);
INSERT INTO "django_geo_db_city" VALUES(2401,'South Seaville','South Seaville, New Jersey',3045,30);
INSERT INTO "django_geo_db_city" VALUES(2402,'Stone Harbor','Stone Harbor, New Jersey',3064,30);
INSERT INTO "django_geo_db_city" VALUES(2403,'Strathmere','Strathmere, New Jersey',3065,30);
INSERT INTO "django_geo_db_city" VALUES(2404,'Tuckahoe','Tuckahoe, New Jersey',3045,30);
INSERT INTO "django_geo_db_city" VALUES(2405,'Villas','Villas, New Jersey',3066,30);
INSERT INTO "django_geo_db_city" VALUES(2406,'Whitesboro','Whitesboro, New Jersey',3067,30);
INSERT INTO "django_geo_db_city" VALUES(2407,'Shiloh','Shiloh, New Jersey',3068,30);
INSERT INTO "django_geo_db_city" VALUES(2408,'Wildwood','Wildwood, New Jersey',3069,30);
INSERT INTO "django_geo_db_city" VALUES(2409,'Woodbine','Woodbine, New Jersey',3070,30);
INSERT INTO "django_geo_db_city" VALUES(2410,'Bridgeton','Bridgeton, New Jersey',3072,30);
INSERT INTO "django_geo_db_city" VALUES(2411,'Buena','Buena, New Jersey',3073,30);
INSERT INTO "django_geo_db_city" VALUES(2412,'Cedarville','Cedarville, New Jersey',3074,30);
INSERT INTO "django_geo_db_city" VALUES(2413,'Clayton','Clayton, New Jersey',3075,30);
INSERT INTO "django_geo_db_city" VALUES(2414,'Deerfield Street','Deerfield Street, New Jersey',3076,30);
INSERT INTO "django_geo_db_city" VALUES(2415,'Delmont','Delmont, New Jersey',3077,30);
INSERT INTO "django_geo_db_city" VALUES(2416,'Dividing Creek','Dividing Creek, New Jersey',3078,30);
INSERT INTO "django_geo_db_city" VALUES(2417,'Dorchester','Dorchester, New Jersey',3079,30);
INSERT INTO "django_geo_db_city" VALUES(2418,'Dorothy','Dorothy, New Jersey',3080,30);
INSERT INTO "django_geo_db_city" VALUES(2419,'Elmer','Elmer, New Jersey',3081,30);
INSERT INTO "django_geo_db_city" VALUES(2420,'Estell Manor','Estell Manor, New Jersey',3082,30);
INSERT INTO "django_geo_db_city" VALUES(2421,'Fairton','Fairton, New Jersey',3083,30);
INSERT INTO "django_geo_db_city" VALUES(2422,'Fortescue','Fortescue, New Jersey',3084,30);
INSERT INTO "django_geo_db_city" VALUES(2423,'Franklinville','Franklinville, New Jersey',3085,30);
INSERT INTO "django_geo_db_city" VALUES(2424,'Greenwich','Greenwich, New Jersey',3086,30);
INSERT INTO "django_geo_db_city" VALUES(2425,'Heislerville','Heislerville, New Jersey',3087,30);
INSERT INTO "django_geo_db_city" VALUES(2426,'Landisville','Landisville, New Jersey',3088,30);
INSERT INTO "django_geo_db_city" VALUES(2427,'Leesburg','Leesburg, New Jersey',3089,30);
INSERT INTO "django_geo_db_city" VALUES(2428,'Malaga','Malaga, New Jersey',3090,30);
INSERT INTO "django_geo_db_city" VALUES(2429,'Mauricetown','Mauricetown, New Jersey',3091,30);
INSERT INTO "django_geo_db_city" VALUES(2430,'Mays Landing','Mays Landing, New Jersey',3092,30);
INSERT INTO "django_geo_db_city" VALUES(2431,'Millville','Millville, New Jersey',3093,30);
INSERT INTO "django_geo_db_city" VALUES(2432,'Downe','Downe, New Jersey',3094,30);
INSERT INTO "django_geo_db_city" VALUES(2433,'Milmay','Milmay, New Jersey',3095,30);
INSERT INTO "django_geo_db_city" VALUES(2434,'Minotola','Minotola, New Jersey',3096,30);
INSERT INTO "django_geo_db_city" VALUES(2435,'Mizpah','Mizpah, New Jersey',3097,30);
INSERT INTO "django_geo_db_city" VALUES(2436,'Monroeville','Monroeville, New Jersey',3098,30);
INSERT INTO "django_geo_db_city" VALUES(2437,'Newfield','Newfield, New Jersey',3099,30);
INSERT INTO "django_geo_db_city" VALUES(2438,'Newport','Newport, New Jersey',3100,30);
INSERT INTO "django_geo_db_city" VALUES(2439,'Newtonville','Newtonville, New Jersey',3101,30);
INSERT INTO "django_geo_db_city" VALUES(2440,'Norma','Norma, New Jersey',3102,30);
INSERT INTO "django_geo_db_city" VALUES(2441,'Port Elizabeth','Port Elizabeth, New Jersey',3103,30);
INSERT INTO "django_geo_db_city" VALUES(2442,'Port Norris','Port Norris, New Jersey',3104,30);
INSERT INTO "django_geo_db_city" VALUES(2443,'Richland','Richland, New Jersey',3105,30);
INSERT INTO "django_geo_db_city" VALUES(2444,'Rosenhayn','Rosenhayn, New Jersey',3106,30);
INSERT INTO "django_geo_db_city" VALUES(2445,'Vineland','Vineland, New Jersey',3108,30);
INSERT INTO "django_geo_db_city" VALUES(2446,'Atlantic City','Atlantic City, New Jersey',3111,30);
INSERT INTO "django_geo_db_city" VALUES(2447,'Margate City','Margate City, New Jersey',3112,30);
INSERT INTO "django_geo_db_city" VALUES(2448,'Longport','Longport, New Jersey',3113,30);
INSERT INTO "django_geo_db_city" VALUES(2449,'Ventnor City','Ventnor City, New Jersey',3114,30);
INSERT INTO "django_geo_db_city" VALUES(2450,'Allentown','Allentown, New Jersey',3115,30);
INSERT INTO "django_geo_db_city" VALUES(2451,'Belle Mead','Belle Mead, New Jersey',3116,30);
INSERT INTO "django_geo_db_city" VALUES(2452,'Blawenburg','Blawenburg, New Jersey',3117,30);
INSERT INTO "django_geo_db_city" VALUES(2453,'Bordentown','Bordentown, New Jersey',3118,30);
INSERT INTO "django_geo_db_city" VALUES(2454,'Clarksburg','Clarksburg, New Jersey',3119,30);
INSERT INTO "django_geo_db_city" VALUES(2455,'Cookstown','Cookstown, New Jersey',3120,30);
INSERT INTO "django_geo_db_city" VALUES(2456,'Cranbury','Cranbury, New Jersey',3121,30);
INSERT INTO "django_geo_db_city" VALUES(2457,'Cream Ridge','Cream Ridge, New Jersey',3122,30);
INSERT INTO "django_geo_db_city" VALUES(2458,'Crosswicks','Crosswicks, New Jersey',3123,30);
INSERT INTO "django_geo_db_city" VALUES(2459,'Florence','Florence, New Jersey',3124,30);
INSERT INTO "django_geo_db_city" VALUES(2460,'Hightstown','Hightstown, New Jersey',3125,30);
INSERT INTO "django_geo_db_city" VALUES(2461,'Hopewell','Hopewell, New Jersey',3126,30);
INSERT INTO "django_geo_db_city" VALUES(2462,'Imlaystown','Imlaystown, New Jersey',3127,30);
INSERT INTO "django_geo_db_city" VALUES(2463,'Jackson','Jackson, New Jersey',3128,30);
INSERT INTO "django_geo_db_city" VALUES(2464,'Kingston','Kingston, New Jersey',3129,30);
INSERT INTO "django_geo_db_city" VALUES(2465,'Lambertville','Lambertville, New Jersey',3130,30);
INSERT INTO "django_geo_db_city" VALUES(2466,'New Egypt','New Egypt, New Jersey',3131,30);
INSERT INTO "django_geo_db_city" VALUES(2467,'Pennington','Pennington, New Jersey',3132,30);
INSERT INTO "django_geo_db_city" VALUES(2468,'Perrineville','Perrineville, New Jersey',3133,30);
INSERT INTO "django_geo_db_city" VALUES(2469,'Plainsboro','Plainsboro, New Jersey',3134,30);
INSERT INTO "django_geo_db_city" VALUES(2470,'Princeton','Princeton, New Jersey',3135,30);
INSERT INTO "django_geo_db_city" VALUES(2471,'Princeton Junction','Princeton Junction, New Jersey',3139,30);
INSERT INTO "django_geo_db_city" VALUES(2472,'Ringoes','Ringoes, New Jersey',3140,30);
INSERT INTO "django_geo_db_city" VALUES(2473,'Rocky Hill','Rocky Hill, New Jersey',3141,30);
INSERT INTO "django_geo_db_city" VALUES(2474,'Roebling','Roebling, New Jersey',3142,30);
INSERT INTO "django_geo_db_city" VALUES(2475,'Roosevelt','Roosevelt, New Jersey',3143,30);
INSERT INTO "django_geo_db_city" VALUES(2476,'Rosemont','Rosemont, New Jersey',3144,30);
INSERT INTO "django_geo_db_city" VALUES(2477,'Sergeantsville','Sergeantsville, New Jersey',3145,30);
INSERT INTO "django_geo_db_city" VALUES(2478,'Skillman','Skillman, New Jersey',3146,30);
INSERT INTO "django_geo_db_city" VALUES(2479,'Stockton','Stockton, New Jersey',3147,30);
INSERT INTO "django_geo_db_city" VALUES(2480,'Titusville','Titusville, New Jersey',3148,30);
INSERT INTO "django_geo_db_city" VALUES(2481,'Windsor','Windsor, New Jersey',3149,30);
INSERT INTO "django_geo_db_city" VALUES(2482,'Wrightstown','Wrightstown, New Jersey',3150,30);
INSERT INTO "django_geo_db_city" VALUES(2483,'Trenton','Trenton, New Jersey',3136,30);
INSERT INTO "django_geo_db_city" VALUES(2484,'Lakewood','Lakewood, New Jersey',3168,30);
INSERT INTO "django_geo_db_city" VALUES(2485,'Allenwood','Allenwood, New Jersey',3169,30);
INSERT INTO "django_geo_db_city" VALUES(2486,'Bayville','Bayville, New Jersey',3170,30);
INSERT INTO "django_geo_db_city" VALUES(2487,'Beachwood','Beachwood, New Jersey',3171,30);
INSERT INTO "django_geo_db_city" VALUES(2488,'Brick','Brick, New Jersey',3172,30);
INSERT INTO "django_geo_db_city" VALUES(2489,'Brielle','Brielle, New Jersey',3174,30);
INSERT INTO "django_geo_db_city" VALUES(2490,'Forked River','Forked River, New Jersey',3175,30);
INSERT INTO "django_geo_db_city" VALUES(2491,'Island Heights','Island Heights, New Jersey',3176,30);
INSERT INTO "django_geo_db_city" VALUES(2492,'Lakehurst','Lakehurst, New Jersey',3177,30);
INSERT INTO "django_geo_db_city" VALUES(2493,'Lanoka Harbor','Lanoka Harbor, New Jersey',3178,30);
INSERT INTO "django_geo_db_city" VALUES(2494,'Lavallette','Lavallette, New Jersey',3179,30);
INSERT INTO "django_geo_db_city" VALUES(2495,'Manasquan','Manasquan, New Jersey',3180,30);
INSERT INTO "django_geo_db_city" VALUES(2496,'Mantoloking','Mantoloking, New Jersey',3181,30);
INSERT INTO "django_geo_db_city" VALUES(2497,'Normandy Beach','Normandy Beach, New Jersey',3182,30);
INSERT INTO "django_geo_db_city" VALUES(2498,'Ocean Gate','Ocean Gate, New Jersey',3183,30);
INSERT INTO "django_geo_db_city" VALUES(2499,'Pine Beach','Pine Beach, New Jersey',3184,30);
INSERT INTO "django_geo_db_city" VALUES(2500,'Point Pleasant Beach','Point Pleasant Beach, New Jersey',3185,30);
INSERT INTO "django_geo_db_city" VALUES(2501,'Sea Girt','Sea Girt, New Jersey',3186,30);
INSERT INTO "django_geo_db_city" VALUES(2502,'Seaside Heights','Seaside Heights, New Jersey',3187,30);
INSERT INTO "django_geo_db_city" VALUES(2503,'Seaside Park','Seaside Park, New Jersey',3188,30);
INSERT INTO "django_geo_db_city" VALUES(2504,'Toms River','Toms River, New Jersey',3189,30);
INSERT INTO "django_geo_db_city" VALUES(2505,'Waretown','Waretown, New Jersey',3193,30);
INSERT INTO "django_geo_db_city" VALUES(2506,'Whiting','Whiting, New Jersey',3194,30);
INSERT INTO "django_geo_db_city" VALUES(2507,'Berkeley','Berkeley, New Jersey',3195,30);
INSERT INTO "django_geo_db_city" VALUES(2508,'Annandale','Annandale, New Jersey',3196,30);
INSERT INTO "django_geo_db_city" VALUES(2509,'Asbury','Asbury, New Jersey',3197,30);
INSERT INTO "django_geo_db_city" VALUES(2510,'Baptistown','Baptistown, New Jersey',3145,30);
INSERT INTO "django_geo_db_city" VALUES(2511,'Bloomsbury','Bloomsbury, New Jersey',3198,30);
INSERT INTO "django_geo_db_city" VALUES(2512,'Bound Brook','Bound Brook, New Jersey',3199,30);
INSERT INTO "django_geo_db_city" VALUES(2513,'Bridgewater','Bridgewater, New Jersey',3200,30);
INSERT INTO "django_geo_db_city" VALUES(2514,'Broadway','Broadway, New Jersey',3201,30);
INSERT INTO "django_geo_db_city" VALUES(2515,'Clinton','Clinton, New Jersey',3202,30);
INSERT INTO "django_geo_db_city" VALUES(2516,'Dayton','Dayton, New Jersey',3203,30);
INSERT INTO "django_geo_db_city" VALUES(2517,'Dunellen','Dunellen, New Jersey',3204,30);
INSERT INTO "django_geo_db_city" VALUES(2518,'East Brunswick','East Brunswick, New Jersey',3205,30);
INSERT INTO "django_geo_db_city" VALUES(2519,'Edison','Edison, New Jersey',3206,30);
INSERT INTO "django_geo_db_city" VALUES(2520,'Flagtown','Flagtown, New Jersey',3208,30);
INSERT INTO "django_geo_db_city" VALUES(2521,'Flemington','Flemington, New Jersey',3209,30);
INSERT INTO "django_geo_db_city" VALUES(2522,'Franklin Park','Franklin Park, New Jersey',3210,30);
INSERT INTO "django_geo_db_city" VALUES(2523,'Kendall Park','Kendall Park, New Jersey',3211,30);
INSERT INTO "django_geo_db_city" VALUES(2524,'Frenchtown','Frenchtown, New Jersey',3212,30);
INSERT INTO "django_geo_db_city" VALUES(2525,'Glen Gardner','Glen Gardner, New Jersey',3213,30);
INSERT INTO "django_geo_db_city" VALUES(2526,'Hampton','Hampton, New Jersey',3214,30);
INSERT INTO "django_geo_db_city" VALUES(2527,'Helmetta','Helmetta, New Jersey',3215,30);
INSERT INTO "django_geo_db_city" VALUES(2528,'High Bridge','High Bridge, New Jersey',3216,30);
INSERT INTO "django_geo_db_city" VALUES(2529,'Iselin','Iselin, New Jersey',3217,30);
INSERT INTO "django_geo_db_city" VALUES(2530,'Jamesburg','Jamesburg, New Jersey',3218,30);
INSERT INTO "django_geo_db_city" VALUES(2531,'Keasbey','Keasbey, New Jersey',3219,30);
INSERT INTO "django_geo_db_city" VALUES(2532,'Lebanon','Lebanon, New Jersey',3220,30);
INSERT INTO "django_geo_db_city" VALUES(2533,'Little York','Little York, New Jersey',3145,30);
INSERT INTO "django_geo_db_city" VALUES(2534,'Manville','Manville, New Jersey',3221,30);
INSERT INTO "django_geo_db_city" VALUES(2535,'Martinsville','Martinsville, New Jersey',3222,30);
INSERT INTO "django_geo_db_city" VALUES(2536,'Metuchen','Metuchen, New Jersey',3224,30);
INSERT INTO "django_geo_db_city" VALUES(2537,'Millstone','Millstone, New Jersey',3225,30);
INSERT INTO "django_geo_db_city" VALUES(2538,'Middlesex','Middlesex, New Jersey',3226,30);
INSERT INTO "django_geo_db_city" VALUES(2539,'Milford','Milford, New Jersey',3227,30);
INSERT INTO "django_geo_db_city" VALUES(2540,'Milltown','Milltown, New Jersey',3228,30);
INSERT INTO "django_geo_db_city" VALUES(2541,'East Amwell','East Amwell, New Jersey',3229,30);
INSERT INTO "django_geo_db_city" VALUES(2542,'Monmouth Junction','Monmouth Junction, New Jersey',3230,30);
INSERT INTO "django_geo_db_city" VALUES(2543,'Neshanic Station','Neshanic Station, New Jersey',3231,30);
INSERT INTO "django_geo_db_city" VALUES(2544,'Piscataway','Piscataway, New Jersey',3232,30);
INSERT INTO "django_geo_db_city" VALUES(2545,'Old Bridge','Old Bridge, New Jersey',3233,30);
INSERT INTO "django_geo_db_city" VALUES(2546,'Oldwick','Oldwick, New Jersey',3234,30);
INSERT INTO "django_geo_db_city" VALUES(2547,'Parlin','Parlin, New Jersey',3235,30);
INSERT INTO "django_geo_db_city" VALUES(2548,'Perth Amboy','Perth Amboy, New Jersey',3236,30);
INSERT INTO "django_geo_db_city" VALUES(2549,'Fords','Fords, New Jersey',3237,30);
INSERT INTO "django_geo_db_city" VALUES(2550,'Phillipsburg','Phillipsburg, New Jersey',3238,30);
INSERT INTO "django_geo_db_city" VALUES(2551,'Pittstown','Pittstown, New Jersey',3239,30);
INSERT INTO "django_geo_db_city" VALUES(2552,'Quakertown','Quakertown, New Jersey',3240,30);
INSERT INTO "django_geo_db_city" VALUES(2553,'Raritan','Raritan, New Jersey',3241,30);
INSERT INTO "django_geo_db_city" VALUES(2554,'Readington','Readington, New Jersey',3145,30);
INSERT INTO "django_geo_db_city" VALUES(2555,'Sayreville','Sayreville, New Jersey',3151,30);
INSERT INTO "django_geo_db_city" VALUES(2556,'Somerset','Somerset, New Jersey',3243,30);
INSERT INTO "django_geo_db_city" VALUES(2557,'Somerville','Somerville, New Jersey',3245,30);
INSERT INTO "django_geo_db_city" VALUES(2558,'South River','South River, New Jersey',3151,30);
INSERT INTO "django_geo_db_city" VALUES(2559,'South Amboy','South Amboy, New Jersey',3246,30);
INSERT INTO "django_geo_db_city" VALUES(2560,'South Bound Brook','South Bound Brook, New Jersey',3248,30);
INSERT INTO "django_geo_db_city" VALUES(2561,'Spotswood','Spotswood, New Jersey',3250,30);
INSERT INTO "django_geo_db_city" VALUES(2562,'Stanton','Stanton, New Jersey',3251,30);
INSERT INTO "django_geo_db_city" VALUES(2563,'Stewartsville','Stewartsville, New Jersey',3252,30);
INSERT INTO "django_geo_db_city" VALUES(2564,'Three Bridges','Three Bridges, New Jersey',3253,30);
INSERT INTO "django_geo_db_city" VALUES(2565,'Whitehouse','Whitehouse, New Jersey',3254,30);
INSERT INTO "django_geo_db_city" VALUES(2566,'Whitehouse Station','Whitehouse Station, New Jersey',3255,30);
INSERT INTO "django_geo_db_city" VALUES(2567,'Zarephath','Zarephath, New Jersey',3256,30);
INSERT INTO "django_geo_db_city" VALUES(2568,'New Brunswick','New Brunswick, New Jersey',3258,30);
INSERT INTO "django_geo_db_city" VALUES(2569,'North Brunswick','North Brunswick, New Jersey',3259,30);
INSERT INTO "django_geo_db_city" VALUES(2570,'Highland Park','Highland Park, New Jersey',3261,30);
INSERT INTO "django_geo_db_city" VALUES(2571,'New York','New York, New York',3263,32);
INSERT INTO "django_geo_db_city" VALUES(2572,'New York','New York, New Jersey',3266,30);
INSERT INTO "django_geo_db_city" VALUES(2573,'Staten Island','Staten Island, New York',3356,32);
INSERT INTO "django_geo_db_city" VALUES(2574,'Bronx','Bronx, New York',3371,32);
INSERT INTO "django_geo_db_city" VALUES(2575,'Amawalk','Amawalk, New York',3397,32);
INSERT INTO "django_geo_db_city" VALUES(2576,'Ardsley','Ardsley, New York',3398,32);
INSERT INTO "django_geo_db_city" VALUES(2577,'Ardsley On Hudson','Ardsley On Hudson, New York',3399,32);
INSERT INTO "django_geo_db_city" VALUES(2578,'Armonk','Armonk, New York',3400,32);
INSERT INTO "django_geo_db_city" VALUES(2579,'Baldwin Place','Baldwin Place, New York',3401,32);
INSERT INTO "django_geo_db_city" VALUES(2580,'Bedford','Bedford, New York',3402,32);
INSERT INTO "django_geo_db_city" VALUES(2581,'Bedford Hills','Bedford Hills, New York',3403,32);
INSERT INTO "django_geo_db_city" VALUES(2582,'Brewster','Brewster, New York',3404,32);
INSERT INTO "django_geo_db_city" VALUES(2583,'Briarcliff Manor','Briarcliff Manor, New York',3405,32);
INSERT INTO "django_geo_db_city" VALUES(2584,'Buchanan','Buchanan, New York',3406,32);
INSERT INTO "django_geo_db_city" VALUES(2585,'Carmel','Carmel, New York',3407,32);
INSERT INTO "django_geo_db_city" VALUES(2586,'Chappaqua','Chappaqua, New York',3408,32);
INSERT INTO "django_geo_db_city" VALUES(2587,'Cold Spring','Cold Spring, New York',3409,32);
INSERT INTO "django_geo_db_city" VALUES(2588,'Crompond','Crompond, New York',3410,32);
INSERT INTO "django_geo_db_city" VALUES(2589,'Cross River','Cross River, New York',3411,32);
INSERT INTO "django_geo_db_city" VALUES(2590,'Croton Falls','Croton Falls, New York',3412,32);
INSERT INTO "django_geo_db_city" VALUES(2591,'Croton On Hudson','Croton On Hudson, New York',3413,32);
INSERT INTO "django_geo_db_city" VALUES(2592,'Dobbs Ferry','Dobbs Ferry, New York',3415,32);
INSERT INTO "django_geo_db_city" VALUES(2593,'Elmsford','Elmsford, New York',3416,32);
INSERT INTO "django_geo_db_city" VALUES(2594,'Garrison','Garrison, New York',3417,32);
INSERT INTO "django_geo_db_city" VALUES(2595,'Goldens Bridge','Goldens Bridge, New York',3418,32);
INSERT INTO "django_geo_db_city" VALUES(2596,'Granite Springs','Granite Springs, New York',3419,32);
INSERT INTO "django_geo_db_city" VALUES(2597,'Harrison','Harrison, New York',3420,32);
INSERT INTO "django_geo_db_city" VALUES(2598,'Hartsdale','Hartsdale, New York',3421,32);
INSERT INTO "django_geo_db_city" VALUES(2599,'Hawthorne','Hawthorne, New York',3422,32);
INSERT INTO "django_geo_db_city" VALUES(2600,'Irvington','Irvington, New York',3423,32);
INSERT INTO "django_geo_db_city" VALUES(2601,'Jefferson Valley','Jefferson Valley, New York',3424,32);
INSERT INTO "django_geo_db_city" VALUES(2602,'Katonah','Katonah, New York',3425,32);
INSERT INTO "django_geo_db_city" VALUES(2603,'Lake Peekskill','Lake Peekskill, New York',3426,32);
INSERT INTO "django_geo_db_city" VALUES(2604,'Larchmont','Larchmont, New York',3427,32);
INSERT INTO "django_geo_db_city" VALUES(2605,'Lincolndale','Lincolndale, New York',3428,32);
INSERT INTO "django_geo_db_city" VALUES(2606,'Mahopac','Mahopac, New York',3429,32);
INSERT INTO "django_geo_db_city" VALUES(2607,'Mahopac Falls','Mahopac Falls, New York',3430,32);
INSERT INTO "django_geo_db_city" VALUES(2608,'Mamaroneck','Mamaroneck, New York',3431,32);
INSERT INTO "django_geo_db_city" VALUES(2609,'Maryknoll','Maryknoll, New York',3432,32);
INSERT INTO "django_geo_db_city" VALUES(2610,'Millwood','Millwood, New York',3433,32);
INSERT INTO "django_geo_db_city" VALUES(2611,'Mohegan Lake','Mohegan Lake, New York',3434,32);
INSERT INTO "django_geo_db_city" VALUES(2612,'Montrose','Montrose, New York',3435,32);
INSERT INTO "django_geo_db_city" VALUES(2613,'Mount Kisco','Mount Kisco, New York',3436,32);
INSERT INTO "django_geo_db_city" VALUES(2614,'Mount Vernon','Mount Vernon, New York',3437,32);
INSERT INTO "django_geo_db_city" VALUES(2615,'North Salem','North Salem, New York',3440,32);
INSERT INTO "django_geo_db_city" VALUES(2616,'Ossining','Ossining, New York',3441,32);
INSERT INTO "django_geo_db_city" VALUES(2617,'Peekskill','Peekskill, New York',3442,32);
INSERT INTO "django_geo_db_city" VALUES(2618,'Cortlandt Manor','Cortlandt Manor, New York',3443,32);
INSERT INTO "django_geo_db_city" VALUES(2619,'Pleasantville','Pleasantville, New York',3444,32);
INSERT INTO "django_geo_db_city" VALUES(2620,'Port Chester','Port Chester, New York',3445,32);
INSERT INTO "django_geo_db_city" VALUES(2621,'Pound Ridge','Pound Ridge, New York',3446,32);
INSERT INTO "django_geo_db_city" VALUES(2622,'Purchase','Purchase, New York',3447,32);
INSERT INTO "django_geo_db_city" VALUES(2623,'Purdys','Purdys, New York',3448,32);
INSERT INTO "django_geo_db_city" VALUES(2624,'Putnam Valley','Putnam Valley, New York',3449,32);
INSERT INTO "django_geo_db_city" VALUES(2625,'Rye','Rye, New York',3450,32);
INSERT INTO "django_geo_db_city" VALUES(2626,'Scarsdale','Scarsdale, New York',3451,32);
INSERT INTO "django_geo_db_city" VALUES(2627,'Greenville','Greenville, New York',3452,32);
INSERT INTO "django_geo_db_city" VALUES(2628,'Shenorock','Shenorock, New York',3453,32);
INSERT INTO "django_geo_db_city" VALUES(2629,'Shrub Oak','Shrub Oak, New York',3454,32);
INSERT INTO "django_geo_db_city" VALUES(2630,'Somers','Somers, New York',3455,32);
INSERT INTO "django_geo_db_city" VALUES(2631,'South Salem','South Salem, New York',3456,32);
INSERT INTO "django_geo_db_city" VALUES(2632,'Tarrytown','Tarrytown, New York',3457,32);
INSERT INTO "django_geo_db_city" VALUES(2633,'Thornwood','Thornwood, New York',3458,32);
INSERT INTO "django_geo_db_city" VALUES(2634,'Valhalla','Valhalla, New York',3459,32);
INSERT INTO "django_geo_db_city" VALUES(2635,'Verplanck','Verplanck, New York',3460,32);
INSERT INTO "django_geo_db_city" VALUES(2636,'Waccabuc','Waccabuc, New York',3461,32);
INSERT INTO "django_geo_db_city" VALUES(2637,'Yorktown Heights','Yorktown Heights, New York',3462,32);
INSERT INTO "django_geo_db_city" VALUES(2638,'White Plains','White Plains, New York',3463,32);
INSERT INTO "django_geo_db_city" VALUES(2639,'West Harrison','West Harrison, New York',3465,32);
INSERT INTO "django_geo_db_city" VALUES(2640,'Yonkers','Yonkers, New York',3470,32);
INSERT INTO "django_geo_db_city" VALUES(2641,'Hastings On Hudson','Hastings On Hudson, New York',3474,32);
INSERT INTO "django_geo_db_city" VALUES(2642,'Tuckahoe','Tuckahoe, New York',3475,32);
INSERT INTO "django_geo_db_city" VALUES(2643,'Bronxville','Bronxville, New York',3476,32);
INSERT INTO "django_geo_db_city" VALUES(2644,'Eastchester','Eastchester, New York',3477,32);
INSERT INTO "django_geo_db_city" VALUES(2645,'Woodbury','Woodbury, New York',3479,32);
INSERT INTO "django_geo_db_city" VALUES(2646,'New Rochelle','New Rochelle, New York',3480,32);
INSERT INTO "django_geo_db_city" VALUES(2647,'Pelham','Pelham, New York',3482,32);
INSERT INTO "django_geo_db_city" VALUES(2648,'Wykagyl','Wykagyl, New York',3483,32);
INSERT INTO "django_geo_db_city" VALUES(2649,'Suffern','Suffern, New York',3485,32);
INSERT INTO "django_geo_db_city" VALUES(2650,'Arden','Arden, New York',3486,32);
INSERT INTO "django_geo_db_city" VALUES(2651,'Bear Mountain','Bear Mountain, New York',3487,32);
INSERT INTO "django_geo_db_city" VALUES(2652,'Bellvale','Bellvale, New York',3488,32);
INSERT INTO "django_geo_db_city" VALUES(2653,'Blauvelt','Blauvelt, New York',3489,32);
INSERT INTO "django_geo_db_city" VALUES(2654,'Blooming Grove','Blooming Grove, New York',3490,32);
INSERT INTO "django_geo_db_city" VALUES(2655,'Bullville','Bullville, New York',3491,32);
INSERT INTO "django_geo_db_city" VALUES(2656,'Campbell Hall','Campbell Hall, New York',3492,32);
INSERT INTO "django_geo_db_city" VALUES(2657,'Central Valley','Central Valley, New York',3493,32);
INSERT INTO "django_geo_db_city" VALUES(2658,'Chester','Chester, New York',3494,32);
INSERT INTO "django_geo_db_city" VALUES(2659,'Circleville','Circleville, New York',3495,32);
INSERT INTO "django_geo_db_city" VALUES(2660,'Congers','Congers, New York',3496,32);
INSERT INTO "django_geo_db_city" VALUES(2661,'Florida','Florida, New York',3497,32);
INSERT INTO "django_geo_db_city" VALUES(2662,'Fort Montgomery','Fort Montgomery, New York',3498,32);
INSERT INTO "django_geo_db_city" VALUES(2663,'Garnerville','Garnerville, New York',3499,32);
INSERT INTO "django_geo_db_city" VALUES(2664,'Goshen','Goshen, New York',3500,32);
INSERT INTO "django_geo_db_city" VALUES(2665,'Greenwood Lake','Greenwood Lake, New York',3501,32);
INSERT INTO "django_geo_db_city" VALUES(2666,'Harriman','Harriman, New York',3502,32);
INSERT INTO "django_geo_db_city" VALUES(2667,'Haverstraw','Haverstraw, New York',3503,32);
INSERT INTO "django_geo_db_city" VALUES(2668,'Highland Falls','Highland Falls, New York',3504,32);
INSERT INTO "django_geo_db_city" VALUES(2669,'Highland Mills','Highland Mills, New York',3505,32);
INSERT INTO "django_geo_db_city" VALUES(2670,'Hillburn','Hillburn, New York',3506,32);
INSERT INTO "django_geo_db_city" VALUES(2671,'Howells','Howells, New York',3507,32);
INSERT INTO "django_geo_db_city" VALUES(2672,'Johnson','Johnson, New York',3508,32);
INSERT INTO "django_geo_db_city" VALUES(2673,'Middletown','Middletown, New York',3509,32);
INSERT INTO "django_geo_db_city" VALUES(2674,'Wallkill','Wallkill, New York',3511,32);
INSERT INTO "django_geo_db_city" VALUES(2675,'Monroe','Monroe, New York',3512,32);
INSERT INTO "django_geo_db_city" VALUES(2676,'Monsey','Monsey, New York',3513,32);
INSERT INTO "django_geo_db_city" VALUES(2677,'Mountainville','Mountainville, New York',3514,32);
INSERT INTO "django_geo_db_city" VALUES(2678,'Nanuet','Nanuet, New York',3515,32);
INSERT INTO "django_geo_db_city" VALUES(2679,'New City','New City, New York',3516,32);
INSERT INTO "django_geo_db_city" VALUES(2680,'Lewisboro','Lewisboro, New York',3517,32);
INSERT INTO "django_geo_db_city" VALUES(2681,'New Hampton','New Hampton, New York',3518,32);
INSERT INTO "django_geo_db_city" VALUES(2682,'New Milford','New Milford, New York',3488,32);
INSERT INTO "django_geo_db_city" VALUES(2683,'Nyack','Nyack, New York',3519,32);
INSERT INTO "django_geo_db_city" VALUES(2684,'Orangeburg','Orangeburg, New York',3520,32);
INSERT INTO "django_geo_db_city" VALUES(2685,'Otisville','Otisville, New York',3521,32);
INSERT INTO "django_geo_db_city" VALUES(2686,'Palisades','Palisades, New York',3522,32);
INSERT INTO "django_geo_db_city" VALUES(2687,'Pearl River','Pearl River, New York',3523,32);
INSERT INTO "django_geo_db_city" VALUES(2688,'Piermont','Piermont, New York',3524,32);
INSERT INTO "django_geo_db_city" VALUES(2689,'Pine Island','Pine Island, New York',3525,32);
INSERT INTO "django_geo_db_city" VALUES(2690,'Pomona','Pomona, New York',3526,32);
INSERT INTO "django_geo_db_city" VALUES(2691,'Slate Hill','Slate Hill, New York',3527,32);
INSERT INTO "django_geo_db_city" VALUES(2692,'Sloatsburg','Sloatsburg, New York',3528,32);
INSERT INTO "django_geo_db_city" VALUES(2693,'Southfields','Southfields, New York',3529,32);
INSERT INTO "django_geo_db_city" VALUES(2694,'Sparkill','Sparkill, New York',3530,32);
INSERT INTO "django_geo_db_city" VALUES(2695,'Spring Valley','Spring Valley, New York',3531,32);
INSERT INTO "django_geo_db_city" VALUES(2696,'Sterling Forest','Sterling Forest, New York',3532,32);
INSERT INTO "django_geo_db_city" VALUES(2697,'Stony Point','Stony Point, New York',3533,32);
INSERT INTO "django_geo_db_city" VALUES(2698,'Sugar Loaf','Sugar Loaf, New York',3534,32);
INSERT INTO "django_geo_db_city" VALUES(2699,'Tallman','Tallman, New York',3487,32);
INSERT INTO "django_geo_db_city" VALUES(2700,'Tappan','Tappan, New York',3535,32);
INSERT INTO "django_geo_db_city" VALUES(2701,'Thiells','Thiells, New York',3536,32);
INSERT INTO "django_geo_db_city" VALUES(2702,'Thompson Ridge','Thompson Ridge, New York',3537,32);
INSERT INTO "django_geo_db_city" VALUES(2703,'Tomkins Cove','Tomkins Cove, New York',3538,32);
INSERT INTO "django_geo_db_city" VALUES(2704,'Tuxedo Park','Tuxedo Park, New York',3539,32);
INSERT INTO "django_geo_db_city" VALUES(2705,'Unionville','Unionville, New York',3540,32);
INSERT INTO "django_geo_db_city" VALUES(2706,'Valley Cottage','Valley Cottage, New York',3541,32);
INSERT INTO "django_geo_db_city" VALUES(2707,'Warwick','Warwick, New York',3542,32);
INSERT INTO "django_geo_db_city" VALUES(2708,'Washingtonville','Washingtonville, New York',3543,32);
INSERT INTO "django_geo_db_city" VALUES(2709,'West Haverstraw','West Haverstraw, New York',3544,32);
INSERT INTO "django_geo_db_city" VALUES(2710,'West Nyack','West Nyack, New York',3545,32);
INSERT INTO "django_geo_db_city" VALUES(2711,'West Point','West Point, New York',3546,32);
INSERT INTO "django_geo_db_city" VALUES(2712,'Westtown','Westtown, New York',3547,32);
INSERT INTO "django_geo_db_city" VALUES(2713,'Floral Park','Floral Park, New York',3548,32);
INSERT INTO "django_geo_db_city" VALUES(2714,'Elmont','Elmont, New York',3550,32);
INSERT INTO "django_geo_db_city" VALUES(2715,'Glen Oaks','Glen Oaks, New York',3551,32);
INSERT INTO "django_geo_db_city" VALUES(2716,'Franklin Square','Franklin Square, New York',3553,32);
INSERT INTO "django_geo_db_city" VALUES(2717,'Great Neck','Great Neck, New York',3554,32);
INSERT INTO "django_geo_db_city" VALUES(2718,'Manhasset','Manhasset, New York',3558,32);
INSERT INTO "django_geo_db_city" VALUES(2719,'New Hyde Park','New Hyde Park, New York',3559,32);
INSERT INTO "django_geo_db_city" VALUES(2720,'Port Washington','Port Washington, New York',3561,32);
INSERT INTO "django_geo_db_city" VALUES(2721,'Inwood','Inwood, New York',3562,32);
INSERT INTO "django_geo_db_city" VALUES(2722,'Long Island City','Long Island City, New York',3563,32);
INSERT INTO "django_geo_db_city" VALUES(2723,'Astoria','Astoria, New York',3564,32);
INSERT INTO "django_geo_db_city" VALUES(2724,'Sunnyside','Sunnyside, New York',3566,32);
INSERT INTO "django_geo_db_city" VALUES(2725,'Brooklyn','Brooklyn, New York',3570,32);
INSERT INTO "django_geo_db_city" VALUES(2726,'Flushing','Flushing, New York',3610,32);
INSERT INTO "django_geo_db_city" VALUES(2727,'College Point','College Point, New York',3613,32);
INSERT INTO "django_geo_db_city" VALUES(2728,'Whitestone','Whitestone, New York',3614,32);
INSERT INTO "django_geo_db_city" VALUES(2729,'Bayside','Bayside, New York',3616,32);
INSERT INTO "django_geo_db_city" VALUES(2730,'Little Neck','Little Neck, New York',3619,32);
INSERT INTO "django_geo_db_city" VALUES(2731,'Oakland Gardens','Oakland Gardens, New York',3621,32);
INSERT INTO "django_geo_db_city" VALUES(2732,'Fresh Meadows','Fresh Meadows, New York',3622,32);
INSERT INTO "django_geo_db_city" VALUES(2733,'Corona','Corona, New York',3625,32);
INSERT INTO "django_geo_db_city" VALUES(2734,'East Elmhurst','East Elmhurst, New York',3626,32);
INSERT INTO "django_geo_db_city" VALUES(2735,'Jackson Heights','Jackson Heights, New York',3629,32);
INSERT INTO "django_geo_db_city" VALUES(2736,'Elmhurst','Elmhurst, New York',3630,32);
INSERT INTO "django_geo_db_city" VALUES(2737,'Rego Park','Rego Park, New York',3631,32);
INSERT INTO "django_geo_db_city" VALUES(2738,'Forest Hills','Forest Hills, New York',3632,32);
INSERT INTO "django_geo_db_city" VALUES(2739,'Woodside','Woodside, New York',3633,32);
INSERT INTO "django_geo_db_city" VALUES(2740,'Maspeth','Maspeth, New York',3634,32);
INSERT INTO "django_geo_db_city" VALUES(2741,'Middle Village','Middle Village, New York',3635,32);
INSERT INTO "django_geo_db_city" VALUES(2742,'Ridgewood','Ridgewood, New York',3636,32);
INSERT INTO "django_geo_db_city" VALUES(2743,'Jamaica','Jamaica, New York',3569,32);
INSERT INTO "django_geo_db_city" VALUES(2744,'Cambria Heights','Cambria Heights, New York',3637,32);
INSERT INTO "django_geo_db_city" VALUES(2745,'Saint Albans','Saint Albans, New York',3638,32);
INSERT INTO "django_geo_db_city" VALUES(2746,'Springfield Gardens','Springfield Gardens, New York',3639,32);
INSERT INTO "django_geo_db_city" VALUES(2747,'Howard Beach','Howard Beach, New York',3640,32);
INSERT INTO "django_geo_db_city" VALUES(2748,'Kew Gardens','Kew Gardens, New York',3641,32);
INSERT INTO "django_geo_db_city" VALUES(2749,'Ozone Park','Ozone Park, New York',3642,32);
INSERT INTO "django_geo_db_city" VALUES(2750,'Richmond Hill','Richmond Hill, New York',3644,32);
INSERT INTO "django_geo_db_city" VALUES(2751,'South Richmond Hill','South Richmond Hill, New York',3645,32);
INSERT INTO "django_geo_db_city" VALUES(2752,'South Ozone Park','South Ozone Park, New York',3646,32);
INSERT INTO "django_geo_db_city" VALUES(2753,'Woodhaven','Woodhaven, New York',3647,32);
INSERT INTO "django_geo_db_city" VALUES(2754,'Rosedale','Rosedale, New York',3648,32);
INSERT INTO "django_geo_db_city" VALUES(2755,'Hollis','Hollis, New York',3649,32);
INSERT INTO "django_geo_db_city" VALUES(2756,'Bellerose','Bellerose, New York',3650,32);
INSERT INTO "django_geo_db_city" VALUES(2757,'Queens Village','Queens Village, New York',3651,32);
INSERT INTO "django_geo_db_city" VALUES(2758,'Mineola','Mineola, New York',3662,32);
INSERT INTO "django_geo_db_city" VALUES(2759,'Albertson','Albertson, New York',3663,32);
INSERT INTO "django_geo_db_city" VALUES(2760,'Atlantic Beach','Atlantic Beach, New York',3664,32);
INSERT INTO "django_geo_db_city" VALUES(2761,'Baldwin','Baldwin, New York',3665,32);
INSERT INTO "django_geo_db_city" VALUES(2762,'Carle Place','Carle Place, New York',3666,32);
INSERT INTO "django_geo_db_city" VALUES(2763,'Cedarhurst','Cedarhurst, New York',3667,32);
INSERT INTO "django_geo_db_city" VALUES(2764,'East Rockaway','East Rockaway, New York',3669,32);
INSERT INTO "django_geo_db_city" VALUES(2765,'Freeport','Freeport, New York',3670,32);
INSERT INTO "django_geo_db_city" VALUES(2766,'Garden City','Garden City, New York',3671,32);
INSERT INTO "django_geo_db_city" VALUES(2767,'Glen Cove','Glen Cove, New York',3672,32);
INSERT INTO "django_geo_db_city" VALUES(2768,'Glen Head','Glen Head, New York',3673,32);
INSERT INTO "django_geo_db_city" VALUES(2769,'Glenwood Landing','Glenwood Landing, New York',3674,32);
INSERT INTO "django_geo_db_city" VALUES(2770,'Greenvale','Greenvale, New York',3675,32);
INSERT INTO "django_geo_db_city" VALUES(2771,'Hempstead','Hempstead, New York',3549,32);
INSERT INTO "django_geo_db_city" VALUES(2772,'West Hempstead','West Hempstead, New York',3677,32);
INSERT INTO "django_geo_db_city" VALUES(2773,'Uniondale','Uniondale, New York',3678,32);
INSERT INTO "django_geo_db_city" VALUES(2774,'East Meadow','East Meadow, New York',3679,32);
INSERT INTO "django_geo_db_city" VALUES(2775,'Hewlett','Hewlett, New York',3680,32);
INSERT INTO "django_geo_db_city" VALUES(2776,'Island Park','Island Park, New York',3681,32);
INSERT INTO "django_geo_db_city" VALUES(2777,'Lawrence','Lawrence, New York',3682,32);
INSERT INTO "django_geo_db_city" VALUES(2778,'Locust Valley','Locust Valley, New York',3683,32);
INSERT INTO "django_geo_db_city" VALUES(2779,'Long Beach','Long Beach, New York',3684,32);
INSERT INTO "django_geo_db_city" VALUES(2780,'Lynbrook','Lynbrook, New York',3685,32);
INSERT INTO "django_geo_db_city" VALUES(2781,'Malverne','Malverne, New York',3687,32);
INSERT INTO "django_geo_db_city" VALUES(2782,'Merrick','Merrick, New York',3688,32);
INSERT INTO "django_geo_db_city" VALUES(2783,'Old Westbury','Old Westbury, New York',3689,32);
INSERT INTO "django_geo_db_city" VALUES(2784,'Point Lookout','Point Lookout, New York',3690,32);
INSERT INTO "django_geo_db_city" VALUES(2785,'Rockville Centre','Rockville Centre, New York',3691,32);
INSERT INTO "django_geo_db_city" VALUES(2786,'Oceanside','Oceanside, New York',3692,32);
INSERT INTO "django_geo_db_city" VALUES(2787,'Roosevelt','Roosevelt, New York',3693,32);
INSERT INTO "django_geo_db_city" VALUES(2788,'Roslyn','Roslyn, New York',3694,32);
INSERT INTO "django_geo_db_city" VALUES(2789,'Roslyn Heights','Roslyn Heights, New York',3695,32);
INSERT INTO "django_geo_db_city" VALUES(2790,'Sea Cliff','Sea Cliff, New York',3696,32);
INSERT INTO "django_geo_db_city" VALUES(2791,'Valley Stream','Valley Stream, New York',3697,32);
INSERT INTO "django_geo_db_city" VALUES(2792,'Westbury','Westbury, New York',3699,32);
INSERT INTO "django_geo_db_city" VALUES(2793,'Williston Park','Williston Park, New York',3701,32);
INSERT INTO "django_geo_db_city" VALUES(2794,'Woodmere','Woodmere, New York',3702,32);
INSERT INTO "django_geo_db_city" VALUES(2795,'Far Rockaway','Far Rockaway, New York',3569,32);
INSERT INTO "django_geo_db_city" VALUES(2796,'Arverne','Arverne, New York',3705,32);
INSERT INTO "django_geo_db_city" VALUES(2797,'Rockaway Park','Rockaway Park, New York',3707,32);
INSERT INTO "django_geo_db_city" VALUES(2798,'Breezy Point','Breezy Point, New York',3708,32);
INSERT INTO "django_geo_db_city" VALUES(2799,'Amityville','Amityville, New York',3709,32);
INSERT INTO "django_geo_db_city" VALUES(2800,'Babylon','Babylon, New York',3710,32);
INSERT INTO "django_geo_db_city" VALUES(2801,'North Babylon','North Babylon, New York',3711,32);
INSERT INTO "django_geo_db_city" VALUES(2802,'West Babylon','West Babylon, New York',3712,32);
INSERT INTO "django_geo_db_city" VALUES(2803,'Bayport','Bayport, New York',3713,32);
INSERT INTO "django_geo_db_city" VALUES(2804,'Bay Shore','Bay Shore, New York',3714,32);
INSERT INTO "django_geo_db_city" VALUES(2805,'Bayville','Bayville, New York',3715,32);
INSERT INTO "django_geo_db_city" VALUES(2806,'Bellmore','Bellmore, New York',3716,32);
INSERT INTO "django_geo_db_city" VALUES(2807,'Bellport','Bellport, New York',3717,32);
INSERT INTO "django_geo_db_city" VALUES(2808,'Bethpage','Bethpage, New York',3718,32);
INSERT INTO "django_geo_db_city" VALUES(2809,'Blue Point','Blue Point, New York',3719,32);
INSERT INTO "django_geo_db_city" VALUES(2810,'Bohemia','Bohemia, New York',3720,32);
INSERT INTO "django_geo_db_city" VALUES(2811,'Brentwood','Brentwood, New York',3721,32);
INSERT INTO "django_geo_db_city" VALUES(2812,'Brightwaters','Brightwaters, New York',3722,32);
INSERT INTO "django_geo_db_city" VALUES(2813,'Brookhaven','Brookhaven, New York',3723,32);
INSERT INTO "django_geo_db_city" VALUES(2814,'Centereach','Centereach, New York',3724,32);
INSERT INTO "django_geo_db_city" VALUES(2815,'Centerport','Centerport, New York',3725,32);
INSERT INTO "django_geo_db_city" VALUES(2816,'Central Islip','Central Islip, New York',3726,32);
INSERT INTO "django_geo_db_city" VALUES(2817,'Cold Spring Harbor','Cold Spring Harbor, New York',3727,32);
INSERT INTO "django_geo_db_city" VALUES(2818,'Commack','Commack, New York',3728,32);
INSERT INTO "django_geo_db_city" VALUES(2819,'Copiague','Copiague, New York',3729,32);
INSERT INTO "django_geo_db_city" VALUES(2820,'Coram','Coram, New York',3730,32);
INSERT INTO "django_geo_db_city" VALUES(2821,'Deer Park','Deer Park, New York',3731,32);
INSERT INTO "django_geo_db_city" VALUES(2822,'East Islip','East Islip, New York',3732,32);
INSERT INTO "django_geo_db_city" VALUES(2823,'East Northport','East Northport, New York',3733,32);
INSERT INTO "django_geo_db_city" VALUES(2824,'East Norwich','East Norwich, New York',3734,32);
INSERT INTO "django_geo_db_city" VALUES(2825,'East Setauket','East Setauket, New York',3735,32);
INSERT INTO "django_geo_db_city" VALUES(2826,'Farmingdale','Farmingdale, New York',3736,32);
INSERT INTO "django_geo_db_city" VALUES(2827,'Farmingville','Farmingville, New York',3737,32);
INSERT INTO "django_geo_db_city" VALUES(2828,'Great River','Great River, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2829,'Greenlawn','Greenlawn, New York',3738,32);
INSERT INTO "django_geo_db_city" VALUES(2830,'Holbrook','Holbrook, New York',3739,32);
INSERT INTO "django_geo_db_city" VALUES(2831,'Huntington','Huntington, New York',3741,32);
INSERT INTO "django_geo_db_city" VALUES(2832,'Smithtown','Smithtown, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2833,'Huntington Station','Huntington Station, New York',3742,32);
INSERT INTO "django_geo_db_city" VALUES(2834,'Melville','Melville, New York',3743,32);
INSERT INTO "django_geo_db_city" VALUES(2835,'Islandia','Islandia, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2836,'Islip','Islip, New York',3744,32);
INSERT INTO "django_geo_db_city" VALUES(2837,'Islip Terrace','Islip Terrace, New York',3745,32);
INSERT INTO "django_geo_db_city" VALUES(2838,'Jericho','Jericho, New York',3746,32);
INSERT INTO "django_geo_db_city" VALUES(2839,'Kings Park','Kings Park, New York',3747,32);
INSERT INTO "django_geo_db_city" VALUES(2840,'Lake Grove','Lake Grove, New York',3748,32);
INSERT INTO "django_geo_db_city" VALUES(2841,'Levittown','Levittown, New York',3749,32);
INSERT INTO "django_geo_db_city" VALUES(2842,'Lindenhurst','Lindenhurst, New York',3750,32);
INSERT INTO "django_geo_db_city" VALUES(2843,'Massapequa','Massapequa, New York',3751,32);
INSERT INTO "django_geo_db_city" VALUES(2844,'Hauppauge','Hauppauge, New York',3752,32);
INSERT INTO "django_geo_db_city" VALUES(2845,'Massapequa Park','Massapequa Park, New York',3753,32);
INSERT INTO "django_geo_db_city" VALUES(2846,'Medford','Medford, New York',3754,32);
INSERT INTO "django_geo_db_city" VALUES(2847,'Miller Place','Miller Place, New York',3755,32);
INSERT INTO "django_geo_db_city" VALUES(2848,'Mill Neck','Mill Neck, New York',3756,32);
INSERT INTO "django_geo_db_city" VALUES(2849,'Mount Sinai','Mount Sinai, New York',3757,32);
INSERT INTO "django_geo_db_city" VALUES(2850,'Nesconset','Nesconset, New York',3758,32);
INSERT INTO "django_geo_db_city" VALUES(2851,'Northport','Northport, New York',3759,32);
INSERT INTO "django_geo_db_city" VALUES(2852,'Oakdale','Oakdale, New York',3760,32);
INSERT INTO "django_geo_db_city" VALUES(2853,'Ocean Beach','Ocean Beach, New York',3761,32);
INSERT INTO "django_geo_db_city" VALUES(2854,'Oyster Bay','Oyster Bay, New York',3762,32);
INSERT INTO "django_geo_db_city" VALUES(2855,'Patchogue','Patchogue, New York',3763,32);
INSERT INTO "django_geo_db_city" VALUES(2856,'Syosset','Syosset, New York',3549,32);
INSERT INTO "django_geo_db_city" VALUES(2857,'Port Jefferson Station','Port Jefferson Station, New York',3764,32);
INSERT INTO "django_geo_db_city" VALUES(2858,'Port Jefferson','Port Jefferson, New York',3765,32);
INSERT INTO "django_geo_db_city" VALUES(2859,'Rocky Point','Rocky Point, New York',3766,32);
INSERT INTO "django_geo_db_city" VALUES(2860,'Ronkonkoma','Ronkonkoma, New York',3767,32);
INSERT INTO "django_geo_db_city" VALUES(2861,'Saint James','Saint James, New York',3768,32);
INSERT INTO "django_geo_db_city" VALUES(2862,'Sayville','Sayville, New York',3769,32);
INSERT INTO "django_geo_db_city" VALUES(2863,'Seaford','Seaford, New York',3770,32);
INSERT INTO "django_geo_db_city" VALUES(2864,'Selden','Selden, New York',3771,32);
INSERT INTO "django_geo_db_city" VALUES(2865,'Shoreham','Shoreham, New York',3772,32);
INSERT INTO "django_geo_db_city" VALUES(2866,'Sound Beach','Sound Beach, New York',3775,32);
INSERT INTO "django_geo_db_city" VALUES(2867,'Stony Brook','Stony Brook, New York',3776,32);
INSERT INTO "django_geo_db_city" VALUES(2868,'Wading River','Wading River, New York',3778,32);
INSERT INTO "django_geo_db_city" VALUES(2869,'Wantagh','Wantagh, New York',3779,32);
INSERT INTO "django_geo_db_city" VALUES(2870,'West Islip','West Islip, New York',3780,32);
INSERT INTO "django_geo_db_city" VALUES(2871,'West Sayville','West Sayville, New York',3781,32);
INSERT INTO "django_geo_db_city" VALUES(2872,'Wyandanch','Wyandanch, New York',3783,32);
INSERT INTO "django_geo_db_city" VALUES(2873,'Hicksville','Hicksville, New York',3784,32);
INSERT INTO "django_geo_db_city" VALUES(2874,'Plainview','Plainview, New York',3785,32);
INSERT INTO "django_geo_db_city" VALUES(2875,'Old Bethpage','Old Bethpage, New York',3786,32);
INSERT INTO "django_geo_db_city" VALUES(2876,'Mid Island','Mid Island, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2877,'Riverhead','Riverhead, New York',3787,32);
INSERT INTO "django_geo_db_city" VALUES(2878,'Amagansett','Amagansett, New York',3788,32);
INSERT INTO "django_geo_db_city" VALUES(2879,'Aquebogue','Aquebogue, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2880,'Bridgehampton','Bridgehampton, New York',3789,32);
INSERT INTO "django_geo_db_city" VALUES(2881,'Calverton','Calverton, New York',3790,32);
INSERT INTO "django_geo_db_city" VALUES(2882,'Center Moriches','Center Moriches, New York',3791,32);
INSERT INTO "django_geo_db_city" VALUES(2883,'Cutchogue','Cutchogue, New York',3792,32);
INSERT INTO "django_geo_db_city" VALUES(2884,'East Hampton','East Hampton, New York',3793,32);
INSERT INTO "django_geo_db_city" VALUES(2885,'East Marion','East Marion, New York',3794,32);
INSERT INTO "django_geo_db_city" VALUES(2886,'East Moriches','East Moriches, New York',3795,32);
INSERT INTO "django_geo_db_city" VALUES(2887,'Eastport','Eastport, New York',3796,32);
INSERT INTO "django_geo_db_city" VALUES(2888,'East Quogue','East Quogue, New York',3797,32);
INSERT INTO "django_geo_db_city" VALUES(2889,'Greenport','Greenport, New York',3798,32);
INSERT INTO "django_geo_db_city" VALUES(2890,'Hampton Bays','Hampton Bays, New York',3799,32);
INSERT INTO "django_geo_db_city" VALUES(2891,'Jamesport','Jamesport, New York',3800,32);
INSERT INTO "django_geo_db_city" VALUES(2892,'Laurel','Laurel, New York',3801,32);
INSERT INTO "django_geo_db_city" VALUES(2893,'Manorville','Manorville, New York',3802,32);
INSERT INTO "django_geo_db_city" VALUES(2894,'Mastic','Mastic, New York',3803,32);
INSERT INTO "django_geo_db_city" VALUES(2895,'Mastic Beach','Mastic Beach, New York',3804,32);
INSERT INTO "django_geo_db_city" VALUES(2896,'Mattituck','Mattituck, New York',3805,32);
INSERT INTO "django_geo_db_city" VALUES(2897,'Middle Island','Middle Island, New York',3806,32);
INSERT INTO "django_geo_db_city" VALUES(2898,'Montauk','Montauk, New York',3807,32);
INSERT INTO "django_geo_db_city" VALUES(2899,'Moriches','Moriches, New York',3808,32);
INSERT INTO "django_geo_db_city" VALUES(2900,'New Suffolk','New Suffolk, New York',3809,32);
INSERT INTO "django_geo_db_city" VALUES(2901,'Orient','Orient, New York',3810,32);
INSERT INTO "django_geo_db_city" VALUES(2902,'Peconic','Peconic, New York',3811,32);
INSERT INTO "django_geo_db_city" VALUES(2903,'Quogue','Quogue, New York',3812,32);
INSERT INTO "django_geo_db_city" VALUES(2904,'Remsenburg','Remsenburg, New York',3813,32);
INSERT INTO "django_geo_db_city" VALUES(2905,'Ridge','Ridge, New York',3814,32);
INSERT INTO "django_geo_db_city" VALUES(2906,'Sagaponack','Sagaponack, New York',3815,32);
INSERT INTO "django_geo_db_city" VALUES(2907,'Sag Harbor','Sag Harbor, New York',3816,32);
INSERT INTO "django_geo_db_city" VALUES(2908,'Shelter Island','Shelter Island, New York',3817,32);
INSERT INTO "django_geo_db_city" VALUES(2909,'Shelter Island Heights','Shelter Island Heights, New York',3818,32);
INSERT INTO "django_geo_db_city" VALUES(2910,'Shirley','Shirley, New York',3819,32);
INSERT INTO "django_geo_db_city" VALUES(2911,'Southampton','Southampton, New York',3820,32);
INSERT INTO "django_geo_db_city" VALUES(2912,'South Jamesport','South Jamesport, New York',3821,32);
INSERT INTO "django_geo_db_city" VALUES(2913,'Southold','Southold, New York',3822,32);
INSERT INTO "django_geo_db_city" VALUES(2914,'Speonk','Speonk, New York',3823,32);
INSERT INTO "django_geo_db_city" VALUES(2915,'Upton','Upton, New York',295,32);
INSERT INTO "django_geo_db_city" VALUES(2916,'Wainscott','Wainscott, New York',3824,32);
INSERT INTO "django_geo_db_city" VALUES(2917,'Water Mill','Water Mill, New York',3825,32);
INSERT INTO "django_geo_db_city" VALUES(2918,'Westhampton','Westhampton, New York',3826,32);
INSERT INTO "django_geo_db_city" VALUES(2919,'Westhampton Beach','Westhampton Beach, New York',3827,32);
INSERT INTO "django_geo_db_city" VALUES(2920,'Yaphank','Yaphank, New York',3828,32);
INSERT INTO "django_geo_db_city" VALUES(2921,'Alcove','Alcove, New York',3829,32);
INSERT INTO "django_geo_db_city" VALUES(2922,'Alplaus','Alplaus, New York',3830,32);
INSERT INTO "django_geo_db_city" VALUES(2923,'Altamont','Altamont, New York',3831,32);
INSERT INTO "django_geo_db_city" VALUES(2924,'Amsterdam','Amsterdam, New York',3832,32);
INSERT INTO "django_geo_db_city" VALUES(2925,'Athens','Athens, New York',3833,32);
INSERT INTO "django_geo_db_city" VALUES(2926,'Auriesville','Auriesville, New York',3834,32);
INSERT INTO "django_geo_db_city" VALUES(2927,'Austerlitz','Austerlitz, New York',3835,32);
INSERT INTO "django_geo_db_city" VALUES(2928,'Averill Park','Averill Park, New York',3836,32);
INSERT INTO "django_geo_db_city" VALUES(2929,'Ballston Lake','Ballston Lake, New York',3837,32);
INSERT INTO "django_geo_db_city" VALUES(2930,'Ballston Spa','Ballston Spa, New York',3838,32);
INSERT INTO "django_geo_db_city" VALUES(2931,'Berlin','Berlin, New York',3839,32);
INSERT INTO "django_geo_db_city" VALUES(2932,'Berne','Berne, New York',3840,32);
INSERT INTO "django_geo_db_city" VALUES(2933,'Brainard','Brainard, New York',3841,32);
INSERT INTO "django_geo_db_city" VALUES(2934,'Broadalbin','Broadalbin, New York',3842,32);
INSERT INTO "django_geo_db_city" VALUES(2935,'Burnt Hills','Burnt Hills, New York',3843,32);
INSERT INTO "django_geo_db_city" VALUES(2936,'Buskirk','Buskirk, New York',3844,32);
INSERT INTO "django_geo_db_city" VALUES(2937,'Canaan','Canaan, New York',3845,32);
INSERT INTO "django_geo_db_city" VALUES(2938,'Carlisle','Carlisle, New York',3846,32);
INSERT INTO "django_geo_db_city" VALUES(2939,'Caroga Lake','Caroga Lake, New York',3847,32);
INSERT INTO "django_geo_db_city" VALUES(2940,'Castleton On Hudson','Castleton On Hudson, New York',3848,32);
INSERT INTO "django_geo_db_city" VALUES(2941,'Central Bridge','Central Bridge, New York',3849,32);
INSERT INTO "django_geo_db_city" VALUES(2942,'Charlotteville','Charlotteville, New York',3850,32);
INSERT INTO "django_geo_db_city" VALUES(2943,'Chatham','Chatham, New York',3851,32);
INSERT INTO "django_geo_db_city" VALUES(2944,'Cherry Plain','Cherry Plain, New York',3852,32);
INSERT INTO "django_geo_db_city" VALUES(2945,'Clarksville','Clarksville, New York',3853,32);
INSERT INTO "django_geo_db_city" VALUES(2946,'Climax','Climax, New York',3854,32);
INSERT INTO "django_geo_db_city" VALUES(2947,'Cobleskill','Cobleskill, New York',3855,32);
INSERT INTO "django_geo_db_city" VALUES(2948,'Coeymans','Coeymans, New York',3856,32);
INSERT INTO "django_geo_db_city" VALUES(2949,'Coeymans Hollow','Coeymans Hollow, New York',3857,32);
INSERT INTO "django_geo_db_city" VALUES(2950,'Cohoes','Cohoes, New York',3858,32);
INSERT INTO "django_geo_db_city" VALUES(2951,'Columbiaville','Columbiaville, New York',3859,32);
INSERT INTO "django_geo_db_city" VALUES(2952,'Coxsackie','Coxsackie, New York',3860,32);
INSERT INTO "django_geo_db_city" VALUES(2953,'Cropseyville','Cropseyville, New York',3861,32);
INSERT INTO "django_geo_db_city" VALUES(2954,'Delanson','Delanson, New York',3862,32);
INSERT INTO "django_geo_db_city" VALUES(2955,'Delmar','Delmar, New York',3863,32);
INSERT INTO "django_geo_db_city" VALUES(2956,'Dormansville','Dormansville, New York',3864,32);
INSERT INTO "django_geo_db_city" VALUES(2957,'Duanesburg','Duanesburg, New York',3865,32);
INSERT INTO "django_geo_db_city" VALUES(2958,'Eagle Bridge','Eagle Bridge, New York',3866,32);
INSERT INTO "django_geo_db_city" VALUES(2959,'Earlton','Earlton, New York',3867,32);
INSERT INTO "django_geo_db_city" VALUES(2960,'East Berne','East Berne, New York',3868,32);
INSERT INTO "django_geo_db_city" VALUES(2961,'East Chatham','East Chatham, New York',3869,32);
INSERT INTO "django_geo_db_city" VALUES(2962,'East Greenbush','East Greenbush, New York',3870,32);
INSERT INTO "django_geo_db_city" VALUES(2963,'East Nassau','East Nassau, New York',3871,32);
INSERT INTO "django_geo_db_city" VALUES(2964,'East Schodack','East Schodack, New York',3872,32);
INSERT INTO "django_geo_db_city" VALUES(2965,'East Worcester','East Worcester, New York',3873,32);
INSERT INTO "django_geo_db_city" VALUES(2966,'Clifton Park','Clifton Park, New York',3874,32);
INSERT INTO "django_geo_db_city" VALUES(2967,'Esperance','Esperance, New York',3875,32);
INSERT INTO "django_geo_db_city" VALUES(2968,'Feura Bush','Feura Bush, New York',3876,32);
INSERT INTO "django_geo_db_city" VALUES(2969,'Fonda','Fonda, New York',3877,32);
INSERT INTO "django_geo_db_city" VALUES(2970,'Fort Hunter','Fort Hunter, New York',3878,32);
INSERT INTO "django_geo_db_city" VALUES(2971,'Fort Johnson','Fort Johnson, New York',3879,32);
INSERT INTO "django_geo_db_city" VALUES(2972,'Fultonham','Fultonham, New York',3880,32);
INSERT INTO "django_geo_db_city" VALUES(2973,'Fultonville','Fultonville, New York',3881,32);
INSERT INTO "django_geo_db_city" VALUES(2974,'Gallupville','Gallupville, New York',3882,32);
INSERT INTO "django_geo_db_city" VALUES(2975,'Galway','Galway, New York',3883,32);
INSERT INTO "django_geo_db_city" VALUES(2976,'Ghent','Ghent, New York',3884,32);
INSERT INTO "django_geo_db_city" VALUES(2977,'Gilboa','Gilboa, New York',3885,32);
INSERT INTO "django_geo_db_city" VALUES(2978,'Glenmont','Glenmont, New York',3886,32);
INSERT INTO "django_geo_db_city" VALUES(2979,'Gloversville','Gloversville, New York',3887,32);
INSERT INTO "django_geo_db_city" VALUES(2980,'Nassau','Nassau, New York',3888,32);
INSERT INTO "django_geo_db_city" VALUES(2981,'Grafton','Grafton, New York',3889,32);
INSERT INTO "django_geo_db_city" VALUES(2982,'Guilderland','Guilderland, New York',3891,32);
INSERT INTO "django_geo_db_city" VALUES(2983,'Guilderland Center','Guilderland Center, New York',3892,32);
INSERT INTO "django_geo_db_city" VALUES(2984,'Hagaman','Hagaman, New York',3893,32);
INSERT INTO "django_geo_db_city" VALUES(2985,'Hannacroix','Hannacroix, New York',3894,32);
INSERT INTO "django_geo_db_city" VALUES(2986,'Hoosick','Hoosick, New York',3895,32);
INSERT INTO "django_geo_db_city" VALUES(2987,'Hoosick Falls','Hoosick Falls, New York',3896,32);
INSERT INTO "django_geo_db_city" VALUES(2988,'Howes Cave','Howes Cave, New York',3897,32);
INSERT INTO "django_geo_db_city" VALUES(2989,'Jefferson','Jefferson, New York',3898,32);
INSERT INTO "django_geo_db_city" VALUES(2990,'Johnsonville','Johnsonville, New York',3899,32);
INSERT INTO "django_geo_db_city" VALUES(2991,'Johnstown','Johnstown, New York',3900,32);
INSERT INTO "django_geo_db_city" VALUES(2992,'Knox','Knox, New York',3901,32);
INSERT INTO "django_geo_db_city" VALUES(2993,'Kinderhook','Kinderhook, New York',3902,32);
INSERT INTO "django_geo_db_city" VALUES(2994,'Lake Pleasant','Lake Pleasant, New York',3904,32);
INSERT INTO "django_geo_db_city" VALUES(2995,'Latham','Latham, New York',3905,32);
INSERT INTO "django_geo_db_city" VALUES(2996,'Malden Bridge','Malden Bridge, New York',3906,32);
INSERT INTO "django_geo_db_city" VALUES(2997,'Maryland','Maryland, New York',3907,32);
INSERT INTO "django_geo_db_city" VALUES(2998,'Mayfield','Mayfield, New York',3908,32);
INSERT INTO "django_geo_db_city" VALUES(2999,'Mechanicville','Mechanicville, New York',3909,32);
INSERT INTO "django_geo_db_city" VALUES(3000,'Medusa','Medusa, New York',3910,32);
INSERT INTO "django_geo_db_city" VALUES(3001,'Melrose','Melrose, New York',3911,32);
INSERT INTO "django_geo_db_city" VALUES(3002,'Middleburgh','Middleburgh, New York',3912,32);
INSERT INTO "django_geo_db_city" VALUES(3003,'New Baltimore','New Baltimore, New York',3914,32);
INSERT INTO "django_geo_db_city" VALUES(3004,'New Lebanon','New Lebanon, New York',3915,32);
INSERT INTO "django_geo_db_city" VALUES(3005,'Newtonville','Newtonville, New York',3916,32);
INSERT INTO "django_geo_db_city" VALUES(3006,'Niverville','Niverville, New York',3917,32);
INSERT INTO "django_geo_db_city" VALUES(3007,'North Blenheim','North Blenheim, New York',3918,32);
INSERT INTO "django_geo_db_city" VALUES(3008,'North Chatham','North Chatham, New York',3919,32);
INSERT INTO "django_geo_db_city" VALUES(3009,'North Hoosick','North Hoosick, New York',3920,32);
INSERT INTO "django_geo_db_city" VALUES(3010,'Northville','Northville, New York',3921,32);
INSERT INTO "django_geo_db_city" VALUES(3011,'Old Chatham','Old Chatham, New York',3922,32);
INSERT INTO "django_geo_db_city" VALUES(3012,'Pattersonville','Pattersonville, New York',3923,32);
INSERT INTO "django_geo_db_city" VALUES(3013,'Petersburg','Petersburg, New York',3924,32);
INSERT INTO "django_geo_db_city" VALUES(3014,'Piseco','Piseco, New York',3925,32);
INSERT INTO "django_geo_db_city" VALUES(3015,'Poestenkill','Poestenkill, New York',3926,32);
INSERT INTO "django_geo_db_city" VALUES(3016,'Quaker Street','Quaker Street, New York',3927,32);
INSERT INTO "django_geo_db_city" VALUES(3017,'Ravena','Ravena, New York',3928,32);
INSERT INTO "django_geo_db_city" VALUES(3018,'Rensselaer','Rensselaer, New York',3929,32);
INSERT INTO "django_geo_db_city" VALUES(3019,'Rensselaerville','Rensselaerville, New York',3930,32);
INSERT INTO "django_geo_db_city" VALUES(3020,'Rexford','Rexford, New York',3931,32);
INSERT INTO "django_geo_db_city" VALUES(3021,'Richmondville','Richmondville, New York',3932,32);
INSERT INTO "django_geo_db_city" VALUES(3022,'Rotterdam Junction','Rotterdam Junction, New York',3933,32);
INSERT INTO "django_geo_db_city" VALUES(3023,'Round Lake','Round Lake, New York',3934,32);
INSERT INTO "django_geo_db_city" VALUES(3024,'Sand Lake','Sand Lake, New York',3935,32);
INSERT INTO "django_geo_db_city" VALUES(3025,'Schaghticoke','Schaghticoke, New York',3936,32);
INSERT INTO "django_geo_db_city" VALUES(3026,'Schenevus','Schenevus, New York',3937,32);
INSERT INTO "django_geo_db_city" VALUES(3027,'Schodack Landing','Schodack Landing, New York',3938,32);
INSERT INTO "django_geo_db_city" VALUES(3028,'Schoharie','Schoharie, New York',3939,32);
INSERT INTO "django_geo_db_city" VALUES(3029,'Selkirk','Selkirk, New York',3940,32);
INSERT INTO "django_geo_db_city" VALUES(3030,'Slingerlands','Slingerlands, New York',3941,32);
INSERT INTO "django_geo_db_city" VALUES(3031,'Sloansville','Sloansville, New York',3942,32);
INSERT INTO "django_geo_db_city" VALUES(3032,'South Bethlehem','South Bethlehem, New York',3943,32);
INSERT INTO "django_geo_db_city" VALUES(3033,'South Schodack','South Schodack, New York',3944,32);
INSERT INTO "django_geo_db_city" VALUES(3034,'Speculator','Speculator, New York',3945,32);
INSERT INTO "django_geo_db_city" VALUES(3035,'Spencertown','Spencertown, New York',3946,32);
INSERT INTO "django_geo_db_city" VALUES(3036,'Sprakers','Sprakers, New York',3947,32);
INSERT INTO "django_geo_db_city" VALUES(3037,'Stamford','Stamford, New York',3948,32);
INSERT INTO "django_geo_db_city" VALUES(3038,'Stephentown','Stephentown, New York',3949,32);
INSERT INTO "django_geo_db_city" VALUES(3039,'Stillwater','Stillwater, New York',3951,32);
INSERT INTO "django_geo_db_city" VALUES(3040,'Stottville','Stottville, New York',3952,32);
INSERT INTO "django_geo_db_city" VALUES(3041,'Stuyvesant','Stuyvesant, New York',3953,32);
INSERT INTO "django_geo_db_city" VALUES(3042,'Stuyvesant Falls','Stuyvesant Falls, New York',3954,32);
INSERT INTO "django_geo_db_city" VALUES(3043,'Summit','Summit, New York',3955,32);
INSERT INTO "django_geo_db_city" VALUES(3044,'Surprise','Surprise, New York',3956,32);
INSERT INTO "django_geo_db_city" VALUES(3045,'Tribes Hill','Tribes Hill, New York',3957,32);
INSERT INTO "django_geo_db_city" VALUES(3046,'Troy','Troy, New York',3958,32);
INSERT INTO "django_geo_db_city" VALUES(3047,'Valatie','Valatie, New York',3963,32);
INSERT INTO "django_geo_db_city" VALUES(3048,'Valley Falls','Valley Falls, New York',3964,32);
INSERT INTO "django_geo_db_city" VALUES(3049,'Voorheesville','Voorheesville, New York',3965,32);
INSERT INTO "django_geo_db_city" VALUES(3050,'Warnerville','Warnerville, New York',3966,32);
INSERT INTO "django_geo_db_city" VALUES(3051,'Waterford','Waterford, New York',3967,32);
INSERT INTO "django_geo_db_city" VALUES(3052,'Watervliet','Watervliet, New York',3968,32);
INSERT INTO "django_geo_db_city" VALUES(3053,'Wells','Wells, New York',3969,32);
INSERT INTO "django_geo_db_city" VALUES(3054,'West Coxsackie','West Coxsackie, New York',3970,32);
INSERT INTO "django_geo_db_city" VALUES(3055,'Westerlo','Westerlo, New York',3971,32);
INSERT INTO "django_geo_db_city" VALUES(3056,'West Fulton','West Fulton, New York',3972,32);
INSERT INTO "django_geo_db_city" VALUES(3057,'West Lebanon','West Lebanon, New York',3973,32);
INSERT INTO "django_geo_db_city" VALUES(3058,'West Sand Lake','West Sand Lake, New York',3974,32);
INSERT INTO "django_geo_db_city" VALUES(3059,'Worcester','Worcester, New York',3975,32);
INSERT INTO "django_geo_db_city" VALUES(3060,'Wynantskill','Wynantskill, New York',3976,32);
INSERT INTO "django_geo_db_city" VALUES(3061,'Albany','Albany, New York',3864,32);
INSERT INTO "django_geo_db_city" VALUES(3062,'Schenectady','Schenectady, New York',3990,32);
INSERT INTO "django_geo_db_city" VALUES(3063,'Kingston','Kingston, New York',3999,32);
INSERT INTO "django_geo_db_city" VALUES(3064,'Accord','Accord, New York',4001,32);
INSERT INTO "django_geo_db_city" VALUES(3065,'Acra','Acra, New York',4002,32);
INSERT INTO "django_geo_db_city" VALUES(3066,'Arkville','Arkville, New York',4003,32);
INSERT INTO "django_geo_db_city" VALUES(3067,'Ashland','Ashland, New York',4004,32);
INSERT INTO "django_geo_db_city" VALUES(3068,'Bearsville','Bearsville, New York',4005,32);
INSERT INTO "django_geo_db_city" VALUES(3069,'Big Indian','Big Indian, New York',4006,32);
INSERT INTO "django_geo_db_city" VALUES(3070,'Bloomington','Bloomington, New York',4007,32);
INSERT INTO "django_geo_db_city" VALUES(3071,'Boiceville','Boiceville, New York',4008,32);
INSERT INTO "django_geo_db_city" VALUES(3072,'Cairo','Cairo, New York',4009,32);
INSERT INTO "django_geo_db_city" VALUES(3073,'Catskill','Catskill, New York',4010,32);
INSERT INTO "django_geo_db_city" VALUES(3074,'Chichester','Chichester, New York',4011,32);
INSERT INTO "django_geo_db_city" VALUES(3075,'Connelly','Connelly, New York',4012,32);
INSERT INTO "django_geo_db_city" VALUES(3076,'Cornwallville','Cornwallville, New York',4013,32);
INSERT INTO "django_geo_db_city" VALUES(3077,'Cottekill','Cottekill, New York',4014,32);
INSERT INTO "django_geo_db_city" VALUES(3078,'Cragsmoor','Cragsmoor, New York',4015,32);
INSERT INTO "django_geo_db_city" VALUES(3079,'Denver','Denver, New York',4016,32);
INSERT INTO "django_geo_db_city" VALUES(3080,'Durham','Durham, New York',4017,32);
INSERT INTO "django_geo_db_city" VALUES(3081,'East Durham','East Durham, New York',4018,32);
INSERT INTO "django_geo_db_city" VALUES(3082,'East Jewett','East Jewett, New York',4019,32);
INSERT INTO "django_geo_db_city" VALUES(3083,'Elka Park','Elka Park, New York',4020,32);
INSERT INTO "django_geo_db_city" VALUES(3084,'Ellenville','Ellenville, New York',4021,32);
INSERT INTO "django_geo_db_city" VALUES(3085,'Esopus','Esopus, New York',4022,32);
INSERT INTO "django_geo_db_city" VALUES(3086,'Fleischmanns','Fleischmanns, New York',4023,32);
INSERT INTO "django_geo_db_city" VALUES(3087,'Freehold','Freehold, New York',4024,32);
INSERT INTO "django_geo_db_city" VALUES(3088,'Glasco','Glasco, New York',4025,32);
INSERT INTO "django_geo_db_city" VALUES(3089,'Glenford','Glenford, New York',4026,32);
INSERT INTO "django_geo_db_city" VALUES(3090,'Grand Gorge','Grand Gorge, New York',4027,32);
INSERT INTO "django_geo_db_city" VALUES(3091,'Greenfield Park','Greenfield Park, New York',4028,32);
INSERT INTO "django_geo_db_city" VALUES(3092,'Haines Falls','Haines Falls, New York',4029,32);
INSERT INTO "django_geo_db_city" VALUES(3093,'Halcottsville','Halcottsville, New York',4030,32);
INSERT INTO "django_geo_db_city" VALUES(3094,'Hensonville','Hensonville, New York',4031,32);
INSERT INTO "django_geo_db_city" VALUES(3095,'High Falls','High Falls, New York',4032,32);
INSERT INTO "django_geo_db_city" VALUES(3096,'Highmount','Highmount, New York',4000,32);
INSERT INTO "django_geo_db_city" VALUES(3097,'Hunter','Hunter, New York',4033,32);
INSERT INTO "django_geo_db_city" VALUES(3098,'Hurley','Hurley, New York',4034,32);
INSERT INTO "django_geo_db_city" VALUES(3099,'Jewett','Jewett, New York',4035,32);
INSERT INTO "django_geo_db_city" VALUES(3100,'Kerhonkson','Kerhonkson, New York',4036,32);
INSERT INTO "django_geo_db_city" VALUES(3101,'Saugerties','Saugerties, New York',4037,32);
INSERT INTO "django_geo_db_city" VALUES(3102,'Lake Hill','Lake Hill, New York',4038,32);
INSERT INTO "django_geo_db_city" VALUES(3103,'Lake Katrine','Lake Katrine, New York',4039,32);
INSERT INTO "django_geo_db_city" VALUES(3104,'Lanesville','Lanesville, New York',4040,32);
INSERT INTO "django_geo_db_city" VALUES(3105,'Leeds','Leeds, New York',4041,32);
INSERT INTO "django_geo_db_city" VALUES(3106,'Lexington','Lexington, New York',4042,32);
INSERT INTO "django_geo_db_city" VALUES(3107,'Malden On Hudson','Malden On Hudson, New York',4043,32);
INSERT INTO "django_geo_db_city" VALUES(3108,'Maplecrest','Maplecrest, New York',4044,32);
INSERT INTO "django_geo_db_city" VALUES(3109,'Margaretville','Margaretville, New York',4045,32);
INSERT INTO "django_geo_db_city" VALUES(3110,'Mount Marion','Mount Marion, New York',4046,32);
INSERT INTO "django_geo_db_city" VALUES(3111,'Mount Tremper','Mount Tremper, New York',4047,32);
INSERT INTO "django_geo_db_city" VALUES(3112,'Napanoch','Napanoch, New York',4048,32);
INSERT INTO "django_geo_db_city" VALUES(3113,'New Kingston','New Kingston, New York',4049,32);
INSERT INTO "django_geo_db_city" VALUES(3114,'Oak Hill','Oak Hill, New York',4050,32);
INSERT INTO "django_geo_db_city" VALUES(3115,'Olivebridge','Olivebridge, New York',4051,32);
INSERT INTO "django_geo_db_city" VALUES(3116,'Palenville','Palenville, New York',4052,32);
INSERT INTO "django_geo_db_city" VALUES(3117,'Phoenicia','Phoenicia, New York',4053,32);
INSERT INTO "django_geo_db_city" VALUES(3118,'Pine Hill','Pine Hill, New York',4054,32);
INSERT INTO "django_geo_db_city" VALUES(3119,'Port Ewen','Port Ewen, New York',4055,32);
INSERT INTO "django_geo_db_city" VALUES(3120,'Prattsville','Prattsville, New York',4056,32);
INSERT INTO "django_geo_db_city" VALUES(3121,'Preston Hollow','Preston Hollow, New York',4057,32);
INSERT INTO "django_geo_db_city" VALUES(3122,'Purling','Purling, New York',4058,32);
INSERT INTO "django_geo_db_city" VALUES(3123,'Rifton','Rifton, New York',4059,32);
INSERT INTO "django_geo_db_city" VALUES(3124,'Rosendale','Rosendale, New York',4060,32);
INSERT INTO "django_geo_db_city" VALUES(3125,'Round Top','Round Top, New York',4061,32);
INSERT INTO "django_geo_db_city" VALUES(3126,'Roxbury','Roxbury, New York',4062,32);
INSERT INTO "django_geo_db_city" VALUES(3127,'Ruby','Ruby, New York',4063,32);
INSERT INTO "django_geo_db_city" VALUES(3128,'Shandaken','Shandaken, New York',4065,32);
INSERT INTO "django_geo_db_city" VALUES(3129,'Shokan','Shokan, New York',4066,32);
INSERT INTO "django_geo_db_city" VALUES(3130,'South Cairo','South Cairo, New York',4067,32);
INSERT INTO "django_geo_db_city" VALUES(3131,'Spring Glen','Spring Glen, New York',4068,32);
INSERT INTO "django_geo_db_city" VALUES(3132,'Stone Ridge','Stone Ridge, New York',4069,32);
INSERT INTO "django_geo_db_city" VALUES(3133,'Tannersville','Tannersville, New York',4070,32);
INSERT INTO "django_geo_db_city" VALUES(3134,'Tillson','Tillson, New York',4071,32);
INSERT INTO "django_geo_db_city" VALUES(3135,'Ulster Park','Ulster Park, New York',4072,32);
INSERT INTO "django_geo_db_city" VALUES(3136,'Wawarsing','Wawarsing, New York',4073,32);
INSERT INTO "django_geo_db_city" VALUES(3137,'West Camp','West Camp, New York',4074,32);
INSERT INTO "django_geo_db_city" VALUES(3138,'West Hurley','West Hurley, New York',4075,32);
INSERT INTO "django_geo_db_city" VALUES(3139,'West Kill','West Kill, New York',4076,32);
INSERT INTO "django_geo_db_city" VALUES(3140,'West Park','West Park, New York',4077,32);
INSERT INTO "django_geo_db_city" VALUES(3141,'West Shokan','West Shokan, New York',4078,32);
INSERT INTO "django_geo_db_city" VALUES(3142,'Willow','Willow, New York',4079,32);
INSERT INTO "django_geo_db_city" VALUES(3143,'Windham','Windham, New York',4080,32);
INSERT INTO "django_geo_db_city" VALUES(3144,'Woodstock','Woodstock, New York',4081,32);
INSERT INTO "django_geo_db_city" VALUES(3145,'Amenia','Amenia, New York',4082,32);
INSERT INTO "django_geo_db_city" VALUES(3146,'Ancram','Ancram, New York',4083,32);
INSERT INTO "django_geo_db_city" VALUES(3147,'Ancramdale','Ancramdale, New York',4084,32);
INSERT INTO "django_geo_db_city" VALUES(3148,'Annandale On Hudson','Annandale On Hudson, New York',4085,32);
INSERT INTO "django_geo_db_city" VALUES(3149,'Bangall','Bangall, New York',4086,32);
INSERT INTO "django_geo_db_city" VALUES(3150,'Barrytown','Barrytown, New York',4087,32);
INSERT INTO "django_geo_db_city" VALUES(3151,'Beacon','Beacon, New York',4088,32);
INSERT INTO "django_geo_db_city" VALUES(3152,'La Grange','La Grange, New York',4089,32);
INSERT INTO "django_geo_db_city" VALUES(3153,'Billings','Billings, New York',4086,32);
INSERT INTO "django_geo_db_city" VALUES(3154,'Castle Point','Castle Point, New York',4086,32);
INSERT INTO "django_geo_db_city" VALUES(3155,'Chelsea','Chelsea, New York',4090,32);
INSERT INTO "django_geo_db_city" VALUES(3156,'Claverack','Claverack, New York',4091,32);
INSERT INTO "django_geo_db_city" VALUES(3157,'Clinton Corners','Clinton Corners, New York',4092,32);
INSERT INTO "django_geo_db_city" VALUES(3158,'Clintondale','Clintondale, New York',4093,32);
INSERT INTO "django_geo_db_city" VALUES(3159,'Copake','Copake, New York',4094,32);
INSERT INTO "django_geo_db_city" VALUES(3160,'Copake Falls','Copake Falls, New York',4095,32);
INSERT INTO "django_geo_db_city" VALUES(3161,'Cornwall','Cornwall, New York',4096,32);
INSERT INTO "django_geo_db_city" VALUES(3162,'Cornwall On Hudson','Cornwall On Hudson, New York',4097,32);
INSERT INTO "django_geo_db_city" VALUES(3163,'Craryville','Craryville, New York',4098,32);
INSERT INTO "django_geo_db_city" VALUES(3164,'Dover Plains','Dover Plains, New York',4099,32);
INSERT INTO "django_geo_db_city" VALUES(3165,'Elizaville','Elizaville, New York',4100,32);
INSERT INTO "django_geo_db_city" VALUES(3166,'Fishkill','Fishkill, New York',4101,32);
INSERT INTO "django_geo_db_city" VALUES(3167,'Gardiner','Gardiner, New York',4102,32);
INSERT INTO "django_geo_db_city" VALUES(3168,'Germantown','Germantown, New York',4103,32);
INSERT INTO "django_geo_db_city" VALUES(3169,'Glenham','Glenham, New York',4104,32);
INSERT INTO "django_geo_db_city" VALUES(3170,'Highland','Highland, New York',4105,32);
INSERT INTO "django_geo_db_city" VALUES(3171,'Hillsdale','Hillsdale, New York',4106,32);
INSERT INTO "django_geo_db_city" VALUES(3172,'Hollowville','Hollowville, New York',4107,32);
INSERT INTO "django_geo_db_city" VALUES(3173,'Holmes','Holmes, New York',4108,32);
INSERT INTO "django_geo_db_city" VALUES(3174,'Hopewell Junction','Hopewell Junction, New York',4109,32);
INSERT INTO "django_geo_db_city" VALUES(3175,'Hudson','Hudson, New York',4110,32);
INSERT INTO "django_geo_db_city" VALUES(3176,'Hughsonville','Hughsonville, New York',4111,32);
INSERT INTO "django_geo_db_city" VALUES(3177,'Hyde Park','Hyde Park, New York',4112,32);
INSERT INTO "django_geo_db_city" VALUES(3178,'Lagrangeville','Lagrangeville, New York',4113,32);
INSERT INTO "django_geo_db_city" VALUES(3179,'Livingston','Livingston, New York',4114,32);
INSERT INTO "django_geo_db_city" VALUES(3180,'Marlboro','Marlboro, New York',4115,32);
INSERT INTO "django_geo_db_city" VALUES(3181,'Maybrook','Maybrook, New York',4116,32);
INSERT INTO "django_geo_db_city" VALUES(3182,'Mellenville','Mellenville, New York',4117,32);
INSERT INTO "django_geo_db_city" VALUES(3183,'Millbrook','Millbrook, New York',4118,32);
INSERT INTO "django_geo_db_city" VALUES(3184,'Millerton','Millerton, New York',4119,32);
INSERT INTO "django_geo_db_city" VALUES(3185,'Milton','Milton, New York',4120,32);
INSERT INTO "django_geo_db_city" VALUES(3186,'Modena','Modena, New York',4121,32);
INSERT INTO "django_geo_db_city" VALUES(3187,'Montgomery','Montgomery, New York',4122,32);
INSERT INTO "django_geo_db_city" VALUES(3188,'Newburgh','Newburgh, New York',4123,32);
INSERT INTO "django_geo_db_city" VALUES(3189,'New Windsor','New Windsor, New York',4124,32);
INSERT INTO "django_geo_db_city" VALUES(3190,'Mid Hudson','Mid Hudson, New York',3488,32);
INSERT INTO "django_geo_db_city" VALUES(3191,'New Paltz','New Paltz, New York',4126,32);
INSERT INTO "django_geo_db_city" VALUES(3192,'Patterson','Patterson, New York',4127,32);
INSERT INTO "django_geo_db_city" VALUES(3193,'Pawling','Pawling, New York',4128,32);
INSERT INTO "django_geo_db_city" VALUES(3194,'Philmont','Philmont, New York',4129,32);
INSERT INTO "django_geo_db_city" VALUES(3195,'Pine Bush','Pine Bush, New York',4130,32);
INSERT INTO "django_geo_db_city" VALUES(3196,'Pine Plains','Pine Plains, New York',4131,32);
INSERT INTO "django_geo_db_city" VALUES(3197,'Plattekill','Plattekill, New York',4132,32);
INSERT INTO "django_geo_db_city" VALUES(3198,'Pleasant Valley','Pleasant Valley, New York',4133,32);
INSERT INTO "django_geo_db_city" VALUES(3199,'Poughquag','Poughquag, New York',4134,32);
INSERT INTO "django_geo_db_city" VALUES(3200,'Red Hook','Red Hook, New York',4135,32);
INSERT INTO "django_geo_db_city" VALUES(3201,'Rhinebeck','Rhinebeck, New York',4136,32);
INSERT INTO "django_geo_db_city" VALUES(3202,'Rhinecliff','Rhinecliff, New York',4137,32);
INSERT INTO "django_geo_db_city" VALUES(3203,'Rock Tavern','Rock Tavern, New York',4138,32);
INSERT INTO "django_geo_db_city" VALUES(3204,'Salisbury Mills','Salisbury Mills, New York',4139,32);
INSERT INTO "django_geo_db_city" VALUES(3205,'Salt Point','Salt Point, New York',4140,32);
INSERT INTO "django_geo_db_city" VALUES(3206,'Staatsburg','Staatsburg, New York',4141,32);
INSERT INTO "django_geo_db_city" VALUES(3207,'Stanfordville','Stanfordville, New York',4142,32);
INSERT INTO "django_geo_db_city" VALUES(3208,'Stormville','Stormville, New York',4143,32);
INSERT INTO "django_geo_db_city" VALUES(3209,'Tivoli','Tivoli, New York',4144,32);
INSERT INTO "django_geo_db_city" VALUES(3210,'Vails Gate','Vails Gate, New York',4145,32);
INSERT INTO "django_geo_db_city" VALUES(3211,'Verbank','Verbank, New York',4146,32);
INSERT INTO "django_geo_db_city" VALUES(3212,'Walden','Walden, New York',4147,32);
INSERT INTO "django_geo_db_city" VALUES(3213,'Walker Valley','Walker Valley, New York',4000,32);
INSERT INTO "django_geo_db_city" VALUES(3214,'Wappingers Falls','Wappingers Falls, New York',4149,32);
INSERT INTO "django_geo_db_city" VALUES(3215,'Wassaic','Wassaic, New York',4150,32);
INSERT INTO "django_geo_db_city" VALUES(3216,'West Copake','West Copake, New York',4151,32);
INSERT INTO "django_geo_db_city" VALUES(3217,'Wingdale','Wingdale, New York',4152,32);
INSERT INTO "django_geo_db_city" VALUES(3218,'Poughkeepsie','Poughkeepsie, New York',4153,32);
INSERT INTO "django_geo_db_city" VALUES(3219,'Moira','Moira, New York',4155,32);
INSERT INTO "django_geo_db_city" VALUES(3220,'Monticello','Monticello, New York',4156,32);
INSERT INTO "django_geo_db_city" VALUES(3221,'Neversink','Neversink, New York',4157,32);
INSERT INTO "django_geo_db_city" VALUES(3222,'Barryville','Barryville, New York',4158,32);
INSERT INTO "django_geo_db_city" VALUES(3223,'Bethel','Bethel, New York',4159,32);
INSERT INTO "django_geo_db_city" VALUES(3224,'Bloomingburg','Bloomingburg, New York',4160,32);
INSERT INTO "django_geo_db_city" VALUES(3225,'Burlingham','Burlingham, New York',4161,32);
INSERT INTO "django_geo_db_city" VALUES(3226,'Callicoon','Callicoon, New York',4162,32);
INSERT INTO "django_geo_db_city" VALUES(3227,'Callicoon Center','Callicoon Center, New York',4163,32);
INSERT INTO "django_geo_db_city" VALUES(3228,'Claryville','Claryville, New York',4164,32);
INSERT INTO "django_geo_db_city" VALUES(3229,'Cochecton','Cochecton, New York',4165,32);
INSERT INTO "django_geo_db_city" VALUES(3230,'Cochecton Center','Cochecton Center, New York',4166,32);
INSERT INTO "django_geo_db_city" VALUES(3231,'Cuddebackville','Cuddebackville, New York',4167,32);
INSERT INTO "django_geo_db_city" VALUES(3232,'Eldred','Eldred, New York',4168,32);
INSERT INTO "django_geo_db_city" VALUES(3233,'Fallsburg','Fallsburg, New York',4169,32);
INSERT INTO "django_geo_db_city" VALUES(3234,'Ferndale','Ferndale, New York',4170,32);
INSERT INTO "django_geo_db_city" VALUES(3235,'Fremont Center','Fremont Center, New York',4171,32);
INSERT INTO "django_geo_db_city" VALUES(3236,'Glen Spey','Glen Spey, New York',4172,32);
INSERT INTO "django_geo_db_city" VALUES(3237,'Glen Wild','Glen Wild, New York',4173,32);
INSERT INTO "django_geo_db_city" VALUES(3238,'Godeffroy','Godeffroy, New York',4174,32);
INSERT INTO "django_geo_db_city" VALUES(3239,'Grahamsville','Grahamsville, New York',4175,32);
INSERT INTO "django_geo_db_city" VALUES(3240,'Hankins','Hankins, New York',4176,32);
INSERT INTO "django_geo_db_city" VALUES(3241,'Harris','Harris, New York',4177,32);
INSERT INTO "django_geo_db_city" VALUES(3242,'Highland Lake','Highland Lake, New York',4178,32);
INSERT INTO "django_geo_db_city" VALUES(3243,'Hortonville','Hortonville, New York',4179,32);
INSERT INTO "django_geo_db_city" VALUES(3244,'Huguenot','Huguenot, New York',4180,32);
INSERT INTO "django_geo_db_city" VALUES(3245,'Hurleyville','Hurleyville, New York',4181,32);
INSERT INTO "django_geo_db_city" VALUES(3246,'Jeffersonville','Jeffersonville, New York',4182,32);
INSERT INTO "django_geo_db_city" VALUES(3247,'Kauneonga Lake','Kauneonga Lake, New York',4183,32);
INSERT INTO "django_geo_db_city" VALUES(3248,'Kenoza Lake','Kenoza Lake, New York',4184,32);
INSERT INTO "django_geo_db_city" VALUES(3249,'Kiamesha Lake','Kiamesha Lake, New York',4185,32);
INSERT INTO "django_geo_db_city" VALUES(3250,'Lake Huntington','Lake Huntington, New York',4186,32);
INSERT INTO "django_geo_db_city" VALUES(3251,'Liberty','Liberty, New York',4187,32);
INSERT INTO "django_geo_db_city" VALUES(3252,'Ellenburg','Ellenburg, New York',4188,32);
INSERT INTO "django_geo_db_city" VALUES(3253,'Livingston Manor','Livingston Manor, New York',4189,32);
INSERT INTO "django_geo_db_city" VALUES(3254,'Loch Sheldrake','Loch Sheldrake, New York',4191,32);
INSERT INTO "django_geo_db_city" VALUES(3255,'Long Eddy','Long Eddy, New York',4192,32);
INSERT INTO "django_geo_db_city" VALUES(3256,'Mongaup Valley','Mongaup Valley, New York',4193,32);
INSERT INTO "django_geo_db_city" VALUES(3257,'Mountain Dale','Mountain Dale, New York',4194,32);
INSERT INTO "django_geo_db_city" VALUES(3258,'Narrowsburg','Narrowsburg, New York',4195,32);
INSERT INTO "django_geo_db_city" VALUES(3259,'North Branch','North Branch, New York',4197,32);
INSERT INTO "django_geo_db_city" VALUES(3260,'Obernburg','Obernburg, New York',4161,32);
INSERT INTO "django_geo_db_city" VALUES(3261,'Parksville','Parksville, New York',4198,32);
INSERT INTO "django_geo_db_city" VALUES(3262,'Phillipsport','Phillipsport, New York',4199,32);
INSERT INTO "django_geo_db_city" VALUES(3263,'Pond Eddy','Pond Eddy, New York',4200,32);
INSERT INTO "django_geo_db_city" VALUES(3264,'Port Jervis','Port Jervis, New York',4201,32);
INSERT INTO "django_geo_db_city" VALUES(3265,'Rock Hill','Rock Hill, New York',4202,32);
INSERT INTO "django_geo_db_city" VALUES(3266,'Roscoe','Roscoe, New York',4203,32);
INSERT INTO "django_geo_db_city" VALUES(3267,'Forestburgh','Forestburgh, New York',4204,32);
INSERT INTO "django_geo_db_city" VALUES(3268,'Smallwood','Smallwood, New York',4205,32);
INSERT INTO "django_geo_db_city" VALUES(3269,'South Fallsburg','South Fallsburg, New York',4206,32);
INSERT INTO "django_geo_db_city" VALUES(3270,'Sparrow Bush','Sparrow Bush, New York',4207,32);
INSERT INTO "django_geo_db_city" VALUES(3271,'Summitville','Summitville, New York',4161,32);
INSERT INTO "django_geo_db_city" VALUES(3272,'Sundown','Sundown, New York',4208,32);
INSERT INTO "django_geo_db_city" VALUES(3273,'Swan Lake','Swan Lake, New York',4209,32);
INSERT INTO "django_geo_db_city" VALUES(3274,'Thompsonville','Thompsonville, New York',4210,32);
INSERT INTO "django_geo_db_city" VALUES(3275,'Westbrookville','Westbrookville, New York',4211,32);
INSERT INTO "django_geo_db_city" VALUES(3276,'White Lake','White Lake, New York',4212,32);
INSERT INTO "django_geo_db_city" VALUES(3277,'White Sulphur Springs','White Sulphur Springs, New York',4213,32);
INSERT INTO "django_geo_db_city" VALUES(3278,'Woodbourne','Woodbourne, New York',4214,32);
INSERT INTO "django_geo_db_city" VALUES(3279,'Woodridge','Woodridge, New York',4215,32);
INSERT INTO "django_geo_db_city" VALUES(3280,'Wurtsboro','Wurtsboro, New York',4216,32);
INSERT INTO "django_geo_db_city" VALUES(3281,'Youngsville','Youngsville, New York',4217,32);
INSERT INTO "django_geo_db_city" VALUES(3282,'Yulan','Yulan, New York',4218,32);
INSERT INTO "django_geo_db_city" VALUES(3283,'Glens Falls','Glens Falls, New York',4220,32);
INSERT INTO "django_geo_db_city" VALUES(3284,'South Glens Falls','South Glens Falls, New York',4221,32);
INSERT INTO "django_geo_db_city" VALUES(3285,'Queensbury','Queensbury, New York',4222,32);
INSERT INTO "django_geo_db_city" VALUES(3286,'Argyle','Argyle, New York',4223,32);
INSERT INTO "django_geo_db_city" VALUES(3287,'Adirondack','Adirondack, New York',4225,32);
INSERT INTO "django_geo_db_city" VALUES(3288,'Athol','Athol, New York',4227,32);
INSERT INTO "django_geo_db_city" VALUES(3289,'Bakers Mills','Bakers Mills, New York',4228,32);
INSERT INTO "django_geo_db_city" VALUES(3290,'Blue Mountain Lake','Blue Mountain Lake, New York',4229,32);
INSERT INTO "django_geo_db_city" VALUES(3291,'Bolton Landing','Bolton Landing, New York',4230,32);
INSERT INTO "django_geo_db_city" VALUES(3292,'Brant Lake','Brant Lake, New York',4231,32);
INSERT INTO "django_geo_db_city" VALUES(3293,'Cambridge','Cambridge, New York',4232,32);
INSERT INTO "django_geo_db_city" VALUES(3294,'Chestertown','Chestertown, New York',4233,32);
INSERT INTO "django_geo_db_city" VALUES(3295,'Clemons','Clemons, New York',4234,32);
INSERT INTO "django_geo_db_city" VALUES(3296,'Cleverdale','Cleverdale, New York',4235,32);
INSERT INTO "django_geo_db_city" VALUES(3297,'Comstock','Comstock, New York',4236,32);
INSERT INTO "django_geo_db_city" VALUES(3298,'Corinth','Corinth, New York',4237,32);
INSERT INTO "django_geo_db_city" VALUES(3299,'Cossayuna','Cossayuna, New York',4238,32);
INSERT INTO "django_geo_db_city" VALUES(3300,'Diamond Point','Diamond Point, New York',4239,32);
INSERT INTO "django_geo_db_city" VALUES(3301,'Fort Ann','Fort Ann, New York',4241,32);
INSERT INTO "django_geo_db_city" VALUES(3302,'Fort Edward','Fort Edward, New York',4242,32);
INSERT INTO "django_geo_db_city" VALUES(3303,'Wilton','Wilton, New York',4243,32);
INSERT INTO "django_geo_db_city" VALUES(3304,'Gansevoort','Gansevoort, New York',4244,32);
INSERT INTO "django_geo_db_city" VALUES(3305,'Granville','Granville, New York',4245,32);
INSERT INTO "django_geo_db_city" VALUES(3306,'Greenfield Center','Greenfield Center, New York',4246,32);
INSERT INTO "django_geo_db_city" VALUES(3307,'Greenwich','Greenwich, New York',4247,32);
INSERT INTO "django_geo_db_city" VALUES(3308,'Hadley','Hadley, New York',4248,32);
INSERT INTO "django_geo_db_city" VALUES(3309,'Hague','Hague, New York',4249,32);
INSERT INTO "django_geo_db_city" VALUES(3310,'Hampton','Hampton, New York',4250,32);
INSERT INTO "django_geo_db_city" VALUES(3311,'Hartford','Hartford, New York',4251,32);
INSERT INTO "django_geo_db_city" VALUES(3312,'Hudson Falls','Hudson Falls, New York',4252,32);
INSERT INTO "django_geo_db_city" VALUES(3313,'Huletts Landing','Huletts Landing, New York',4253,32);
INSERT INTO "django_geo_db_city" VALUES(3314,'Indian Lake','Indian Lake, New York',4254,32);
INSERT INTO "django_geo_db_city" VALUES(3315,'Johnsburg','Johnsburg, New York',4255,32);
INSERT INTO "django_geo_db_city" VALUES(3316,'Kattskill Bay','Kattskill Bay, New York',4256,32);
INSERT INTO "django_geo_db_city" VALUES(3317,'Lake George','Lake George, New York',4257,32);
INSERT INTO "django_geo_db_city" VALUES(3318,'Lake Luzerne','Lake Luzerne, New York',4258,32);
INSERT INTO "django_geo_db_city" VALUES(3319,'Long Lake','Long Lake, New York',4259,32);
INSERT INTO "django_geo_db_city" VALUES(3320,'Middle Falls','Middle Falls, New York',4260,32);
INSERT INTO "django_geo_db_city" VALUES(3321,'Middle Granville','Middle Granville, New York',4261,32);
INSERT INTO "django_geo_db_city" VALUES(3322,'Middle Grove','Middle Grove, New York',4262,32);
INSERT INTO "django_geo_db_city" VALUES(3323,'Minerva','Minerva, New York',4263,32);
INSERT INTO "django_geo_db_city" VALUES(3324,'Newcomb','Newcomb, New York',4264,32);
INSERT INTO "django_geo_db_city" VALUES(3325,'North Creek','North Creek, New York',4265,32);
INSERT INTO "django_geo_db_city" VALUES(3326,'North Granville','North Granville, New York',4266,32);
INSERT INTO "django_geo_db_city" VALUES(3327,'North Hudson','North Hudson, New York',4267,32);
INSERT INTO "django_geo_db_city" VALUES(3328,'North River','North River, New York',4268,32);
INSERT INTO "django_geo_db_city" VALUES(3329,'Olmstedville','Olmstedville, New York',4269,32);
INSERT INTO "django_geo_db_city" VALUES(3330,'Paradox','Paradox, New York',4270,32);
INSERT INTO "django_geo_db_city" VALUES(3331,'Porter Corners','Porter Corners, New York',4271,32);
INSERT INTO "django_geo_db_city" VALUES(3332,'Pottersville','Pottersville, New York',4272,32);
INSERT INTO "django_geo_db_city" VALUES(3333,'Putnam Station','Putnam Station, New York',4273,32);
INSERT INTO "django_geo_db_city" VALUES(3334,'Riparius','Riparius, New York',4274,32);
INSERT INTO "django_geo_db_city" VALUES(3335,'Rock City Falls','Rock City Falls, New York',4275,32);
INSERT INTO "django_geo_db_city" VALUES(3336,'Sabael','Sabael, New York',4276,32);
INSERT INTO "django_geo_db_city" VALUES(3337,'Salem','Salem, New York',4277,32);
INSERT INTO "django_geo_db_city" VALUES(3338,'Saratoga Springs','Saratoga Springs, New York',4278,32);
INSERT INTO "django_geo_db_city" VALUES(3339,'Schroon Lake','Schroon Lake, New York',4279,32);
INSERT INTO "django_geo_db_city" VALUES(3340,'Schuylerville','Schuylerville, New York',4280,32);
INSERT INTO "django_geo_db_city" VALUES(3341,'Severance','Severance, New York',4281,32);
INSERT INTO "django_geo_db_city" VALUES(3342,'Shushan','Shushan, New York',4282,32);
INSERT INTO "django_geo_db_city" VALUES(3343,'Silver Bay','Silver Bay, New York',4283,32);
INSERT INTO "django_geo_db_city" VALUES(3344,'Whitehall','Whitehall, New York',4284,32);
INSERT INTO "django_geo_db_city" VALUES(3345,'Stony Creek','Stony Creek, New York',4285,32);
INSERT INTO "django_geo_db_city" VALUES(3346,'Ticonderoga','Ticonderoga, New York',4286,32);
INSERT INTO "django_geo_db_city" VALUES(3347,'Victory Mills','Victory Mills, New York',4287,32);
INSERT INTO "django_geo_db_city" VALUES(3348,'Warrensburg','Warrensburg, New York',4288,32);
INSERT INTO "django_geo_db_city" VALUES(3349,'Wevertown','Wevertown, New York',4289,32);
INSERT INTO "django_geo_db_city" VALUES(3350,'Plattsburgh','Plattsburgh, New York',4291,32);
INSERT INTO "django_geo_db_city" VALUES(3351,'Altona','Altona, New York',4293,32);
INSERT INTO "django_geo_db_city" VALUES(3352,'Keeseville','Keeseville, New York',4294,32);
INSERT INTO "django_geo_db_city" VALUES(3353,'Au Sable Forks','Au Sable Forks, New York',4295,32);
INSERT INTO "django_geo_db_city" VALUES(3354,'Bloomingdale','Bloomingdale, New York',4296,32);
INSERT INTO "django_geo_db_city" VALUES(3355,'Bombay','Bombay, New York',4297,32);
INSERT INTO "django_geo_db_city" VALUES(3356,'Brainardsville','Brainardsville, New York',4298,32);
INSERT INTO "django_geo_db_city" VALUES(3357,'Brushton','Brushton, New York',4299,32);
INSERT INTO "django_geo_db_city" VALUES(3358,'Burke','Burke, New York',4300,32);
INSERT INTO "django_geo_db_city" VALUES(3359,'Cadyville','Cadyville, New York',4301,32);
INSERT INTO "django_geo_db_city" VALUES(3360,'Champlain','Champlain, New York',4302,32);
INSERT INTO "django_geo_db_city" VALUES(3361,'Chateaugay','Chateaugay, New York',4303,32);
INSERT INTO "django_geo_db_city" VALUES(3362,'Chazy','Chazy, New York',4304,32);
INSERT INTO "django_geo_db_city" VALUES(3363,'Childwold','Childwold, New York',4305,32);
INSERT INTO "django_geo_db_city" VALUES(3364,'Churubusco','Churubusco, New York',4306,32);
INSERT INTO "django_geo_db_city" VALUES(3365,'Constable','Constable, New York',4308,32);
INSERT INTO "django_geo_db_city" VALUES(3366,'Cranberry Lake','Cranberry Lake, New York',4309,32);
INSERT INTO "django_geo_db_city" VALUES(3367,'Crown Point','Crown Point, New York',4310,32);
INSERT INTO "django_geo_db_city" VALUES(3368,'Dannemora','Dannemora, New York',4311,32);
INSERT INTO "django_geo_db_city" VALUES(3369,'Dickinson Center','Dickinson Center, New York',4312,32);
INSERT INTO "django_geo_db_city" VALUES(3370,'Elizabethtown','Elizabethtown, New York',4313,32);
INSERT INTO "django_geo_db_city" VALUES(3371,'Ellenburg Center','Ellenburg Center, New York',4315,32);
INSERT INTO "django_geo_db_city" VALUES(3372,'Ellenburg Depot','Ellenburg Depot, New York',4316,32);
INSERT INTO "django_geo_db_city" VALUES(3373,'Essex','Essex, New York',4317,32);
INSERT INTO "django_geo_db_city" VALUES(3374,'Fort Covington','Fort Covington, New York',4318,32);
INSERT INTO "django_geo_db_city" VALUES(3375,'Gabriels','Gabriels, New York',4298,32);
INSERT INTO "django_geo_db_city" VALUES(3376,'Jay','Jay, New York',4320,32);
INSERT INTO "django_geo_db_city" VALUES(3377,'Keene','Keene, New York',4321,32);
INSERT INTO "django_geo_db_city" VALUES(3378,'Keene Valley','Keene Valley, New York',4322,32);
INSERT INTO "django_geo_db_city" VALUES(3379,'Lake Clear','Lake Clear, New York',4324,32);
INSERT INTO "django_geo_db_city" VALUES(3380,'Lake Placid','Lake Placid, New York',4325,32);
INSERT INTO "django_geo_db_city" VALUES(3381,'Lawrenceville','Lawrenceville, New York',4326,32);
INSERT INTO "django_geo_db_city" VALUES(3382,'Lewis','Lewis, New York',4327,32);
INSERT INTO "django_geo_db_city" VALUES(3383,'Lyon Mountain','Lyon Mountain, New York',4328,32);
INSERT INTO "django_geo_db_city" VALUES(3384,'Malone','Malone, New York',4329,32);
INSERT INTO "django_geo_db_city" VALUES(3385,'Mineville','Mineville, New York',4331,32);
INSERT INTO "django_geo_db_city" VALUES(3386,'Mooers','Mooers, New York',4333,32);
INSERT INTO "django_geo_db_city" VALUES(3387,'Mooers Forks','Mooers Forks, New York',4334,32);
INSERT INTO "django_geo_db_city" VALUES(3388,'Moriah','Moriah, New York',4335,32);
INSERT INTO "django_geo_db_city" VALUES(3389,'Moriah Center','Moriah Center, New York',4336,32);
INSERT INTO "django_geo_db_city" VALUES(3390,'Morrisonville','Morrisonville, New York',4337,32);
INSERT INTO "django_geo_db_city" VALUES(3391,'New Russia','New Russia, New York',4338,32);
INSERT INTO "django_geo_db_city" VALUES(3392,'Nicholville','Nicholville, New York',4339,32);
INSERT INTO "django_geo_db_city" VALUES(3393,'North Bangor','North Bangor, New York',4340,32);
INSERT INTO "django_geo_db_city" VALUES(3394,'North Lawrence','North Lawrence, New York',4341,32);
INSERT INTO "django_geo_db_city" VALUES(3395,'Owls Head','Owls Head, New York',4342,32);
INSERT INTO "django_geo_db_city" VALUES(3396,'Paul Smiths','Paul Smiths, New York',4343,32);
INSERT INTO "django_geo_db_city" VALUES(3397,'Peru','Peru, New York',4344,32);
INSERT INTO "django_geo_db_city" VALUES(3398,'Piercefield','Piercefield, New York',4345,32);
INSERT INTO "django_geo_db_city" VALUES(3399,'Port Henry','Port Henry, New York',4346,32);
INSERT INTO "django_geo_db_city" VALUES(3400,'Port Kent','Port Kent, New York',4347,32);
INSERT INTO "django_geo_db_city" VALUES(3401,'Rainbow Lake','Rainbow Lake, New York',4298,32);
INSERT INTO "django_geo_db_city" VALUES(3402,'Ray Brook','Ray Brook, New York',4281,32);
INSERT INTO "django_geo_db_city" VALUES(3403,'Redford','Redford, New York',4348,32);
INSERT INTO "django_geo_db_city" VALUES(3404,'Rouses Point','Rouses Point, New York',4349,32);
INSERT INTO "django_geo_db_city" VALUES(3405,'Saint Regis Falls','Saint Regis Falls, New York',4350,32);
INSERT INTO "django_geo_db_city" VALUES(3406,'Saranac','Saranac, New York',4351,32);
INSERT INTO "django_geo_db_city" VALUES(3407,'Saranac Lake','Saranac Lake, New York',4352,32);
INSERT INTO "django_geo_db_city" VALUES(3408,'Schuyler Falls','Schuyler Falls, New York',4353,32);
INSERT INTO "django_geo_db_city" VALUES(3409,'Tupper Lake','Tupper Lake, New York',4354,32);
INSERT INTO "django_geo_db_city" VALUES(3410,'Upper Jay','Upper Jay, New York',4355,32);
INSERT INTO "django_geo_db_city" VALUES(3411,'Vermontville','Vermontville, New York',4356,32);
INSERT INTO "django_geo_db_city" VALUES(3412,'West Chazy','West Chazy, New York',4357,32);
INSERT INTO "django_geo_db_city" VALUES(3413,'Westport','Westport, New York',4358,32);
INSERT INTO "django_geo_db_city" VALUES(3414,'Whippleville','Whippleville, New York',4359,32);
INSERT INTO "django_geo_db_city" VALUES(3415,'Willsboro','Willsboro, New York',4360,32);
INSERT INTO "django_geo_db_city" VALUES(3416,'Wilmington','Wilmington, New York',4281,32);
INSERT INTO "django_geo_db_city" VALUES(3417,'Witherbee','Witherbee, New York',4361,32);
INSERT INTO "django_geo_db_city" VALUES(3418,'Apulia Station','Apulia Station, New York',4362,32);
INSERT INTO "django_geo_db_city" VALUES(3419,'Auburn','Auburn, New York',4363,32);
INSERT INTO "django_geo_db_city" VALUES(3420,'Aurora','Aurora, New York',4365,32);
INSERT INTO "django_geo_db_city" VALUES(3421,'Baldwinsville','Baldwinsville, New York',4366,32);
INSERT INTO "django_geo_db_city" VALUES(3422,'Bernhards Bay','Bernhards Bay, New York',4367,32);
INSERT INTO "django_geo_db_city" VALUES(3423,'Brewerton','Brewerton, New York',4368,32);
INSERT INTO "django_geo_db_city" VALUES(3424,'Bridgeport','Bridgeport, New York',4369,32);
INSERT INTO "django_geo_db_city" VALUES(3425,'Camillus','Camillus, New York',4370,32);
INSERT INTO "django_geo_db_city" VALUES(3426,'Canastota','Canastota, New York',4371,32);
INSERT INTO "django_geo_db_city" VALUES(3427,'Cato','Cato, New York',4372,32);
INSERT INTO "django_geo_db_city" VALUES(3428,'Cayuga','Cayuga, New York',4373,32);
INSERT INTO "django_geo_db_city" VALUES(3429,'Cazenovia','Cazenovia, New York',4374,32);
INSERT INTO "django_geo_db_city" VALUES(3430,'Central Square','Central Square, New York',4375,32);
INSERT INTO "django_geo_db_city" VALUES(3431,'Chittenango','Chittenango, New York',4376,32);
INSERT INTO "django_geo_db_city" VALUES(3432,'Cicero','Cicero, New York',4377,32);
INSERT INTO "django_geo_db_city" VALUES(3433,'Cincinnatus','Cincinnatus, New York',4378,32);
INSERT INTO "django_geo_db_city" VALUES(3434,'Clay','Clay, New York',4379,32);
INSERT INTO "django_geo_db_city" VALUES(3435,'Cleveland','Cleveland, New York',4380,32);
INSERT INTO "django_geo_db_city" VALUES(3436,'Clockville','Clockville, New York',4381,32);
INSERT INTO "django_geo_db_city" VALUES(3437,'Constantia','Constantia, New York',4382,32);
INSERT INTO "django_geo_db_city" VALUES(3438,'Cortland','Cortland, New York',4383,32);
INSERT INTO "django_geo_db_city" VALUES(3439,'Delphi Falls','Delphi Falls, New York',4384,32);
INSERT INTO "django_geo_db_city" VALUES(3440,'De Ruyter','De Ruyter, New York',4385,32);
INSERT INTO "django_geo_db_city" VALUES(3441,'Dryden','Dryden, New York',4386,32);
INSERT INTO "django_geo_db_city" VALUES(3442,'Durhamville','Durhamville, New York',4387,32);
INSERT INTO "django_geo_db_city" VALUES(3443,'East Homer','East Homer, New York',4388,32);
INSERT INTO "django_geo_db_city" VALUES(3444,'East Syracuse','East Syracuse, New York',4389,32);
INSERT INTO "django_geo_db_city" VALUES(3445,'Elbridge','Elbridge, New York',4390,32);
INSERT INTO "django_geo_db_city" VALUES(3446,'Erieville','Erieville, New York',4391,32);
INSERT INTO "django_geo_db_city" VALUES(3447,'Etna','Etna, New York',4392,32);
INSERT INTO "django_geo_db_city" VALUES(3448,'Fabius','Fabius, New York',4393,32);
INSERT INTO "django_geo_db_city" VALUES(3449,'Fair Haven','Fair Haven, New York',4394,32);
INSERT INTO "django_geo_db_city" VALUES(3450,'Fayette','Fayette, New York',4395,32);
INSERT INTO "django_geo_db_city" VALUES(3451,'Fayetteville','Fayetteville, New York',4396,32);
INSERT INTO "django_geo_db_city" VALUES(3452,'Freeville','Freeville, New York',4397,32);
INSERT INTO "django_geo_db_city" VALUES(3453,'Fulton','Fulton, New York',4398,32);
INSERT INTO "django_geo_db_city" VALUES(3454,'Genoa','Genoa, New York',4399,32);
INSERT INTO "django_geo_db_city" VALUES(3455,'Georgetown','Georgetown, New York',4400,32);
INSERT INTO "django_geo_db_city" VALUES(3456,'Groton','Groton, New York',4401,32);
INSERT INTO "django_geo_db_city" VALUES(3457,'Hannibal','Hannibal, New York',4402,32);
INSERT INTO "django_geo_db_city" VALUES(3458,'Hastings','Hastings, New York',4403,32);
INSERT INTO "django_geo_db_city" VALUES(3459,'Homer','Homer, New York',4404,32);
INSERT INTO "django_geo_db_city" VALUES(3460,'Jamesville','Jamesville, New York',4405,32);
INSERT INTO "django_geo_db_city" VALUES(3461,'Jordan','Jordan, New York',4406,32);
INSERT INTO "django_geo_db_city" VALUES(3462,'King Ferry','King Ferry, New York',4407,32);
INSERT INTO "django_geo_db_city" VALUES(3463,'Kirkville','Kirkville, New York',4408,32);
INSERT INTO "django_geo_db_city" VALUES(3464,'Lacona','Lacona, New York',4409,32);
INSERT INTO "django_geo_db_city" VALUES(3465,'La Fayette','La Fayette, New York',4410,32);
INSERT INTO "django_geo_db_city" VALUES(3466,'Little York','Little York, New York',4411,32);
INSERT INTO "django_geo_db_city" VALUES(3467,'Liverpool','Liverpool, New York',4412,32);
INSERT INTO "django_geo_db_city" VALUES(3468,'Locke','Locke, New York',4415,32);
INSERT INTO "django_geo_db_city" VALUES(3469,'Lycoming','Lycoming, New York',4394,32);
INSERT INTO "django_geo_db_city" VALUES(3470,'McGraw','McGraw, New York',4416,32);
INSERT INTO "django_geo_db_city" VALUES(3471,'McLean','McLean, New York',4417,32);
INSERT INTO "django_geo_db_city" VALUES(3472,'Mallory','Mallory, New York',4418,32);
INSERT INTO "django_geo_db_city" VALUES(3473,'Manlius','Manlius, New York',4419,32);
INSERT INTO "django_geo_db_city" VALUES(3474,'Maple View','Maple View, New York',4420,32);
INSERT INTO "django_geo_db_city" VALUES(3475,'Marcellus','Marcellus, New York',4421,32);
INSERT INTO "django_geo_db_city" VALUES(3476,'Marietta','Marietta, New York',4422,32);
INSERT INTO "django_geo_db_city" VALUES(3477,'Martville','Martville, New York',4423,32);
INSERT INTO "django_geo_db_city" VALUES(3478,'Memphis','Memphis, New York',4424,32);
INSERT INTO "django_geo_db_city" VALUES(3479,'Meridian','Meridian, New York',4425,32);
INSERT INTO "django_geo_db_city" VALUES(3480,'Mexico','Mexico, New York',4426,32);
INSERT INTO "django_geo_db_city" VALUES(3481,'Minetto','Minetto, New York',4427,32);
INSERT INTO "django_geo_db_city" VALUES(3482,'Minoa','Minoa, New York',4428,32);
INSERT INTO "django_geo_db_city" VALUES(3483,'Montezuma','Montezuma, New York',4429,32);
INSERT INTO "django_geo_db_city" VALUES(3484,'Moravia','Moravia, New York',4430,32);
INSERT INTO "django_geo_db_city" VALUES(3485,'Mottville','Mottville, New York',4431,32);
INSERT INTO "django_geo_db_city" VALUES(3486,'Nedrow','Nedrow, New York',4432,32);
INSERT INTO "django_geo_db_city" VALUES(3487,'New Haven','New Haven, New York',4433,32);
INSERT INTO "django_geo_db_city" VALUES(3488,'New Woodstock','New Woodstock, New York',4434,32);
INSERT INTO "django_geo_db_city" VALUES(3489,'North Bay','North Bay, New York',4435,32);
INSERT INTO "django_geo_db_city" VALUES(3490,'North Pitcher','North Pitcher, New York',4436,32);
INSERT INTO "django_geo_db_city" VALUES(3491,'Oswego','Oswego, New York',4437,32);
INSERT INTO "django_geo_db_city" VALUES(3492,'Parish','Parish, New York',4439,32);
INSERT INTO "django_geo_db_city" VALUES(3493,'Pennellville','Pennellville, New York',4440,32);
INSERT INTO "django_geo_db_city" VALUES(3494,'Colesville','Colesville, New York',4441,32);
INSERT INTO "django_geo_db_city" VALUES(3495,'Peterboro','Peterboro, New York',4442,32);
INSERT INTO "django_geo_db_city" VALUES(3496,'Phoenix','Phoenix, New York',4443,32);
INSERT INTO "django_geo_db_city" VALUES(3497,'Pitcher','Pitcher, New York',4444,32);
INSERT INTO "django_geo_db_city" VALUES(3498,'Plainville','Plainville, New York',4445,32);
INSERT INTO "django_geo_db_city" VALUES(3499,'Pompey','Pompey, New York',4446,32);
INSERT INTO "django_geo_db_city" VALUES(3500,'Poplar Ridge','Poplar Ridge, New York',4447,32);
INSERT INTO "django_geo_db_city" VALUES(3501,'Port Byron','Port Byron, New York',4448,32);
INSERT INTO "django_geo_db_city" VALUES(3502,'Preble','Preble, New York',4449,32);
INSERT INTO "django_geo_db_city" VALUES(3503,'Pulaski','Pulaski, New York',4450,32);
INSERT INTO "django_geo_db_city" VALUES(3504,'Red Creek','Red Creek, New York',4451,32);
INSERT INTO "django_geo_db_city" VALUES(3505,'Richland','Richland, New York',4452,32);
INSERT INTO "django_geo_db_city" VALUES(3506,'Sandy Creek','Sandy Creek, New York',4453,32);
INSERT INTO "django_geo_db_city" VALUES(3507,'Savannah','Savannah, New York',4454,32);
INSERT INTO "django_geo_db_city" VALUES(3508,'Scipio Center','Scipio Center, New York',4455,32);
INSERT INTO "django_geo_db_city" VALUES(3509,'Seneca Falls','Seneca Falls, New York',4456,32);
INSERT INTO "django_geo_db_city" VALUES(3510,'Skaneateles','Skaneateles, New York',4458,32);
INSERT INTO "django_geo_db_city" VALUES(3511,'Skaneateles Falls','Skaneateles Falls, New York',4459,32);
INSERT INTO "django_geo_db_city" VALUES(3512,'South Butler','South Butler, New York',4460,32);
INSERT INTO "django_geo_db_city" VALUES(3513,'South Otselic','South Otselic, New York',4461,32);
INSERT INTO "django_geo_db_city" VALUES(3514,'Sterling','Sterling, New York',4462,32);
INSERT INTO "django_geo_db_city" VALUES(3515,'Sylvan Beach','Sylvan Beach, New York',4463,32);
INSERT INTO "django_geo_db_city" VALUES(3516,'Truxton','Truxton, New York',4464,32);
INSERT INTO "django_geo_db_city" VALUES(3517,'Tully','Tully, New York',4465,32);
INSERT INTO "django_geo_db_city" VALUES(3518,'Union Springs','Union Springs, New York',4466,32);
INSERT INTO "django_geo_db_city" VALUES(3519,'Verona Beach','Verona Beach, New York',4467,32);
INSERT INTO "django_geo_db_city" VALUES(3520,'Wampsville','Wampsville, New York',4468,32);
INSERT INTO "django_geo_db_city" VALUES(3521,'Warners','Warners, New York',4469,32);
INSERT INTO "django_geo_db_city" VALUES(3522,'Waterloo','Waterloo, New York',4470,32);
INSERT INTO "django_geo_db_city" VALUES(3523,'Weedsport','Weedsport, New York',4471,32);
INSERT INTO "django_geo_db_city" VALUES(3524,'West Monroe','West Monroe, New York',4472,32);
INSERT INTO "django_geo_db_city" VALUES(3525,'Syracuse','Syracuse, New York',4413,32);
INSERT INTO "django_geo_db_city" VALUES(3526,'Alder Creek','Alder Creek, New York',4492,32);
INSERT INTO "django_geo_db_city" VALUES(3527,'Altmar','Altmar, New York',4493,32);
INSERT INTO "django_geo_db_city" VALUES(3528,'Ava','Ava, New York',4494,32);
INSERT INTO "django_geo_db_city" VALUES(3529,'Barneveld','Barneveld, New York',4495,32);
INSERT INTO "django_geo_db_city" VALUES(3530,'Beaver Falls','Beaver Falls, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3531,'Blossvale','Blossvale, New York',4497,32);
INSERT INTO "django_geo_db_city" VALUES(3532,'Boonville','Boonville, New York',4498,32);
INSERT INTO "django_geo_db_city" VALUES(3533,'Bouckville','Bouckville, New York',4499,32);
INSERT INTO "django_geo_db_city" VALUES(3534,'Brantingham','Brantingham, New York',4500,32);
INSERT INTO "django_geo_db_city" VALUES(3535,'Bridgewater','Bridgewater, New York',4501,32);
INSERT INTO "django_geo_db_city" VALUES(3536,'Brookfield','Brookfield, New York',4502,32);
INSERT INTO "django_geo_db_city" VALUES(3537,'Burlington Flats','Burlington Flats, New York',4503,32);
INSERT INTO "django_geo_db_city" VALUES(3538,'Camden','Camden, New York',4504,32);
INSERT INTO "django_geo_db_city" VALUES(3539,'Canajoharie','Canajoharie, New York',4505,32);
INSERT INTO "django_geo_db_city" VALUES(3540,'Cassville','Cassville, New York',4506,32);
INSERT INTO "django_geo_db_city" VALUES(3541,'Chadwicks','Chadwicks, New York',4507,32);
INSERT INTO "django_geo_db_city" VALUES(3542,'Cherry Valley','Cherry Valley, New York',4508,32);
INSERT INTO "django_geo_db_city" VALUES(3543,'Clark Mills','Clark Mills, New York',4509,32);
INSERT INTO "django_geo_db_city" VALUES(3544,'Clayville','Clayville, New York',4510,32);
INSERT INTO "django_geo_db_city" VALUES(3545,'Clinton','Clinton, New York',4511,32);
INSERT INTO "django_geo_db_city" VALUES(3546,'Cold Brook','Cold Brook, New York',4512,32);
INSERT INTO "django_geo_db_city" VALUES(3547,'Constableville','Constableville, New York',4513,32);
INSERT INTO "django_geo_db_city" VALUES(3548,'Cooperstown','Cooperstown, New York',4514,32);
INSERT INTO "django_geo_db_city" VALUES(3549,'Croghan','Croghan, New York',4515,32);
INSERT INTO "django_geo_db_city" VALUES(3550,'Deansboro','Deansboro, New York',4516,32);
INSERT INTO "django_geo_db_city" VALUES(3551,'Dolgeville','Dolgeville, New York',4517,32);
INSERT INTO "django_geo_db_city" VALUES(3552,'Eagle Bay','Eagle Bay, New York',4518,32);
INSERT INTO "django_geo_db_city" VALUES(3553,'Earlville','Earlville, New York',4519,32);
INSERT INTO "django_geo_db_city" VALUES(3554,'East Springfield','East Springfield, New York',4520,32);
INSERT INTO "django_geo_db_city" VALUES(3555,'Eaton','Eaton, New York',4521,32);
INSERT INTO "django_geo_db_city" VALUES(3556,'Edmeston','Edmeston, New York',4522,32);
INSERT INTO "django_geo_db_city" VALUES(3557,'Fly Creek','Fly Creek, New York',4523,32);
INSERT INTO "django_geo_db_city" VALUES(3558,'Forestport','Forestport, New York',4524,32);
INSERT INTO "django_geo_db_city" VALUES(3559,'Fort Plain','Fort Plain, New York',4525,32);
INSERT INTO "django_geo_db_city" VALUES(3560,'Frankfort','Frankfort, New York',4526,32);
INSERT INTO "django_geo_db_city" VALUES(3561,'Franklin Springs','Franklin Springs, New York',4527,32);
INSERT INTO "django_geo_db_city" VALUES(3562,'Garrattsville','Garrattsville, New York',4528,32);
INSERT INTO "django_geo_db_city" VALUES(3563,'Glenfield','Glenfield, New York',4529,32);
INSERT INTO "django_geo_db_city" VALUES(3564,'Greig','Greig, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3565,'Hamilton','Hamilton, New York',4530,32);
INSERT INTO "django_geo_db_city" VALUES(3566,'Hartwick','Hartwick, New York',4531,32);
INSERT INTO "django_geo_db_city" VALUES(3567,'Herkimer','Herkimer, New York',4532,32);
INSERT INTO "django_geo_db_city" VALUES(3568,'Hinckley','Hinckley, New York',4533,32);
INSERT INTO "django_geo_db_city" VALUES(3569,'Hoffmeister','Hoffmeister, New York',4534,32);
INSERT INTO "django_geo_db_city" VALUES(3570,'Holland Patent','Holland Patent, New York',4535,32);
INSERT INTO "django_geo_db_city" VALUES(3571,'Hubbardsville','Hubbardsville, New York',4536,32);
INSERT INTO "django_geo_db_city" VALUES(3572,'Ilion','Ilion, New York',4537,32);
INSERT INTO "django_geo_db_city" VALUES(3573,'Inlet','Inlet, New York',4538,32);
INSERT INTO "django_geo_db_city" VALUES(3574,'Jordanville','Jordanville, New York',4539,32);
INSERT INTO "django_geo_db_city" VALUES(3575,'Knoxboro','Knoxboro, New York',4540,32);
INSERT INTO "django_geo_db_city" VALUES(3576,'Lee Center','Lee Center, New York',4541,32);
INSERT INTO "django_geo_db_city" VALUES(3577,'Leonardsville','Leonardsville, New York',4542,32);
INSERT INTO "django_geo_db_city" VALUES(3578,'Little Falls','Little Falls, New York',4543,32);
INSERT INTO "django_geo_db_city" VALUES(3579,'Lowville','Lowville, New York',4544,32);
INSERT INTO "django_geo_db_city" VALUES(3580,'Lyons Falls','Lyons Falls, New York',4545,32);
INSERT INTO "django_geo_db_city" VALUES(3581,'Webb','Webb, New York',4546,32);
INSERT INTO "django_geo_db_city" VALUES(3582,'Madison','Madison, New York',4547,32);
INSERT INTO "django_geo_db_city" VALUES(3583,'McConnellsville','McConnellsville, New York',4548,32);
INSERT INTO "django_geo_db_city" VALUES(3584,'Marcy','Marcy, New York',4550,32);
INSERT INTO "django_geo_db_city" VALUES(3585,'Martinsburg','Martinsburg, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3586,'Middleville','Middleville, New York',4551,32);
INSERT INTO "django_geo_db_city" VALUES(3587,'Mohawk','Mohawk, New York',4552,32);
INSERT INTO "django_geo_db_city" VALUES(3588,'Morrisville','Morrisville, New York',4553,32);
INSERT INTO "django_geo_db_city" VALUES(3589,'Munnsville','Munnsville, New York',4554,32);
INSERT INTO "django_geo_db_city" VALUES(3590,'Nelliston','Nelliston, New York',4555,32);
INSERT INTO "django_geo_db_city" VALUES(3591,'New Berlin','New Berlin, New York',4556,32);
INSERT INTO "django_geo_db_city" VALUES(3592,'New Hartford','New Hartford, New York',4557,32);
INSERT INTO "django_geo_db_city" VALUES(3593,'New Lisbon','New Lisbon, New York',4558,32);
INSERT INTO "django_geo_db_city" VALUES(3594,'Newport','Newport, New York',4559,32);
INSERT INTO "django_geo_db_city" VALUES(3595,'New York Mills','New York Mills, New York',4560,32);
INSERT INTO "django_geo_db_city" VALUES(3596,'North Brookfield','North Brookfield, New York',4561,32);
INSERT INTO "django_geo_db_city" VALUES(3597,'Old Forge','Old Forge, New York',4562,32);
INSERT INTO "django_geo_db_city" VALUES(3598,'Oneida','Oneida, New York',4563,32);
INSERT INTO "django_geo_db_city" VALUES(3599,'Oriskany','Oriskany, New York',4564,32);
INSERT INTO "django_geo_db_city" VALUES(3600,'Oriskany Falls','Oriskany Falls, New York',4565,32);
INSERT INTO "django_geo_db_city" VALUES(3601,'Orwell','Orwell, New York',4566,32);
INSERT INTO "django_geo_db_city" VALUES(3602,'Palatine Bridge','Palatine Bridge, New York',4567,32);
INSERT INTO "django_geo_db_city" VALUES(3603,'Poland','Poland, New York',4568,32);
INSERT INTO "django_geo_db_city" VALUES(3604,'Port Leyden','Port Leyden, New York',4569,32);
INSERT INTO "django_geo_db_city" VALUES(3605,'Prospect','Prospect, New York',4570,32);
INSERT INTO "django_geo_db_city" VALUES(3606,'Raquette Lake','Raquette Lake, New York',4571,32);
INSERT INTO "django_geo_db_city" VALUES(3607,'Redfield','Redfield, New York',4572,32);
INSERT INTO "django_geo_db_city" VALUES(3608,'Remsen','Remsen, New York',4573,32);
INSERT INTO "django_geo_db_city" VALUES(3609,'Richfield Springs','Richfield Springs, New York',4574,32);
INSERT INTO "django_geo_db_city" VALUES(3610,'Rome','Rome, New York',4575,32);
INSERT INTO "django_geo_db_city" VALUES(3611,'Plymouth','Plymouth, New York',4578,32);
INSERT INTO "django_geo_db_city" VALUES(3612,'Roseboom','Roseboom, New York',4579,32);
INSERT INTO "django_geo_db_city" VALUES(3613,'Saint Johnsville','Saint Johnsville, New York',4580,32);
INSERT INTO "django_geo_db_city" VALUES(3614,'Williamstown','Williamstown, New York',4581,32);
INSERT INTO "django_geo_db_city" VALUES(3615,'Salisbury Center','Salisbury Center, New York',4582,32);
INSERT INTO "django_geo_db_city" VALUES(3616,'Sangerfield','Sangerfield, New York',4583,32);
INSERT INTO "django_geo_db_city" VALUES(3617,'Sauquoit','Sauquoit, New York',4584,32);
INSERT INTO "django_geo_db_city" VALUES(3618,'Schuyler Lake','Schuyler Lake, New York',4585,32);
INSERT INTO "django_geo_db_city" VALUES(3619,'Sharon Springs','Sharon Springs, New York',4586,32);
INSERT INTO "django_geo_db_city" VALUES(3620,'Sherburne','Sherburne, New York',4587,32);
INSERT INTO "django_geo_db_city" VALUES(3621,'Sherrill','Sherrill, New York',4588,32);
INSERT INTO "django_geo_db_city" VALUES(3622,'Smyrna','Smyrna, New York',4589,32);
INSERT INTO "django_geo_db_city" VALUES(3623,'Solsville','Solsville, New York',4542,32);
INSERT INTO "django_geo_db_city" VALUES(3624,'Springfield Center','Springfield Center, New York',4590,32);
INSERT INTO "django_geo_db_city" VALUES(3625,'Stittville','Stittville, New York',4591,32);
INSERT INTO "django_geo_db_city" VALUES(3626,'Stratford','Stratford, New York',4592,32);
INSERT INTO "django_geo_db_city" VALUES(3627,'Taberg','Taberg, New York',4593,32);
INSERT INTO "django_geo_db_city" VALUES(3628,'Thendara','Thendara, New York',4594,32);
INSERT INTO "django_geo_db_city" VALUES(3629,'Turin','Turin, New York',4595,32);
INSERT INTO "django_geo_db_city" VALUES(3630,'Van Hornesville','Van Hornesville, New York',4596,32);
INSERT INTO "django_geo_db_city" VALUES(3631,'Vernon','Vernon, New York',4597,32);
INSERT INTO "django_geo_db_city" VALUES(3632,'Vernon Center','Vernon Center, New York',4598,32);
INSERT INTO "django_geo_db_city" VALUES(3633,'Verona','Verona, New York',4599,32);
INSERT INTO "django_geo_db_city" VALUES(3634,'Washington Mills','Washington Mills, New York',4600,32);
INSERT INTO "django_geo_db_city" VALUES(3635,'Waterville','Waterville, New York',4601,32);
INSERT INTO "django_geo_db_city" VALUES(3636,'West Burlington','West Burlington, New York',4602,32);
INSERT INTO "django_geo_db_city" VALUES(3637,'Westdale','Westdale, New York',4603,32);
INSERT INTO "django_geo_db_city" VALUES(3638,'West Eaton','West Eaton, New York',4604,32);
INSERT INTO "django_geo_db_city" VALUES(3639,'West Edmeston','West Edmeston, New York',4605,32);
INSERT INTO "django_geo_db_city" VALUES(3640,'Westernville','Westernville, New York',4606,32);
INSERT INTO "django_geo_db_city" VALUES(3641,'Westford','Westford, New York',4607,32);
INSERT INTO "django_geo_db_city" VALUES(3642,'West Leyden','West Leyden, New York',4608,32);
INSERT INTO "django_geo_db_city" VALUES(3643,'Westmoreland','Westmoreland, New York',4609,32);
INSERT INTO "django_geo_db_city" VALUES(3644,'West Winfield','West Winfield, New York',4610,32);
INSERT INTO "django_geo_db_city" VALUES(3645,'Whitesboro','Whitesboro, New York',4611,32);
INSERT INTO "django_geo_db_city" VALUES(3646,'Woodgate','Woodgate, New York',4613,32);
INSERT INTO "django_geo_db_city" VALUES(3647,'Yorkville','Yorkville, New York',4614,32);
INSERT INTO "django_geo_db_city" VALUES(3648,'Utica','Utica, New York',4615,32);
INSERT INTO "django_geo_db_city" VALUES(3649,'Hermon','Hermon, New York',4621,32);
INSERT INTO "django_geo_db_city" VALUES(3650,'Pharsalia','Pharsalia, New York',4622,32);
INSERT INTO "django_geo_db_city" VALUES(3651,'Watertown','Watertown, New York',4623,32);
INSERT INTO "django_geo_db_city" VALUES(3652,'Fort Drum','Fort Drum, New York',4624,32);
INSERT INTO "django_geo_db_city" VALUES(3653,'Adams','Adams, New York',4626,32);
INSERT INTO "django_geo_db_city" VALUES(3654,'Adams Center','Adams Center, New York',4627,32);
INSERT INTO "django_geo_db_city" VALUES(3655,'Alexandria Bay','Alexandria Bay, New York',4628,32);
INSERT INTO "django_geo_db_city" VALUES(3656,'Antwerp','Antwerp, New York',4629,32);
INSERT INTO "django_geo_db_city" VALUES(3657,'Rodman','Rodman, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3658,'Belleville','Belleville, New York',4630,32);
INSERT INTO "django_geo_db_city" VALUES(3659,'Black River','Black River, New York',4631,32);
INSERT INTO "django_geo_db_city" VALUES(3660,'Brasher Falls','Brasher Falls, New York',4632,32);
INSERT INTO "django_geo_db_city" VALUES(3661,'Brier Hill','Brier Hill, New York',4633,32);
INSERT INTO "django_geo_db_city" VALUES(3662,'Brownville','Brownville, New York',4634,32);
INSERT INTO "django_geo_db_city" VALUES(3663,'Calcium','Calcium, New York',4635,32);
INSERT INTO "django_geo_db_city" VALUES(3664,'Canton','Canton, New York',4636,32);
INSERT INTO "django_geo_db_city" VALUES(3665,'Cape Vincent','Cape Vincent, New York',4637,32);
INSERT INTO "django_geo_db_city" VALUES(3666,'Carthage','Carthage, New York',4638,32);
INSERT INTO "django_geo_db_city" VALUES(3667,'Castorland','Castorland, New York',4639,32);
INSERT INTO "django_geo_db_city" VALUES(3668,'Chase Mills','Chase Mills, New York',4640,32);
INSERT INTO "django_geo_db_city" VALUES(3669,'Chaumont','Chaumont, New York',4641,32);
INSERT INTO "django_geo_db_city" VALUES(3670,'Chippewa Bay','Chippewa Bay, New York',4642,32);
INSERT INTO "django_geo_db_city" VALUES(3671,'Clayton','Clayton, New York',4643,32);
INSERT INTO "django_geo_db_city" VALUES(3672,'Colton','Colton, New York',4644,32);
INSERT INTO "django_geo_db_city" VALUES(3673,'Copenhagen','Copenhagen, New York',4645,32);
INSERT INTO "django_geo_db_city" VALUES(3674,'Deer River','Deer River, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3675,'Deferiet','Deferiet, New York',4646,32);
INSERT INTO "django_geo_db_city" VALUES(3676,'De Kalb Junction','De Kalb Junction, New York',4647,32);
INSERT INTO "django_geo_db_city" VALUES(3677,'Denmark','Denmark, New York',4496,32);
INSERT INTO "django_geo_db_city" VALUES(3678,'Depauville','Depauville, New York',4648,32);
INSERT INTO "django_geo_db_city" VALUES(3679,'De Peyster','De Peyster, New York',4649,32);
INSERT INTO "django_geo_db_city" VALUES(3680,'Dexter','Dexter, New York',4650,32);
INSERT INTO "django_geo_db_city" VALUES(3681,'Edwards','Edwards, New York',4651,32);
INSERT INTO "django_geo_db_city" VALUES(3682,'Ellisburg','Ellisburg, New York',4652,32);
INSERT INTO "django_geo_db_city" VALUES(3683,'Evans Mills','Evans Mills, New York',4653,32);
INSERT INTO "django_geo_db_city" VALUES(3684,'Felts Mills','Felts Mills, New York',4654,32);
INSERT INTO "django_geo_db_city" VALUES(3685,'Fine','Fine, New York',4655,32);
INSERT INTO "django_geo_db_city" VALUES(3686,'Wellesley Island','Wellesley Island, New York',4656,32);
INSERT INTO "django_geo_db_city" VALUES(3687,'Fishers Landing','Fishers Landing, New York',4657,32);
INSERT INTO "django_geo_db_city" VALUES(3688,'Gouverneur','Gouverneur, New York',4658,32);
INSERT INTO "django_geo_db_city" VALUES(3689,'Great Bend','Great Bend, New York',4659,32);
INSERT INTO "django_geo_db_city" VALUES(3690,'Hailesboro','Hailesboro, New York',4660,32);
INSERT INTO "django_geo_db_city" VALUES(3691,'Hammond','Hammond, New York',4661,32);
INSERT INTO "django_geo_db_city" VALUES(3692,'Hannawa Falls','Hannawa Falls, New York',4662,32);
INSERT INTO "django_geo_db_city" VALUES(3693,'Harrisville','Harrisville, New York',4663,32);
INSERT INTO "django_geo_db_city" VALUES(3694,'Helena','Helena, New York',4664,32);
INSERT INTO "django_geo_db_city" VALUES(3695,'Henderson','Henderson, New York',4665,32);
INSERT INTO "django_geo_db_city" VALUES(3696,'Henderson Harbor','Henderson Harbor, New York',4666,32);
INSERT INTO "django_geo_db_city" VALUES(3697,'Heuvelton','Heuvelton, New York',4668,32);
INSERT INTO "django_geo_db_city" VALUES(3698,'Hogansburg','Hogansburg, New York',4669,32);
INSERT INTO "django_geo_db_city" VALUES(3699,'La Fargeville','La Fargeville, New York',4670,32);
INSERT INTO "django_geo_db_city" VALUES(3700,'Limerick','Limerick, New York',4671,32);
INSERT INTO "django_geo_db_city" VALUES(3701,'Lisbon','Lisbon, New York',4672,32);
INSERT INTO "django_geo_db_city" VALUES(3702,'Lorraine','Lorraine, New York',4673,32);
INSERT INTO "django_geo_db_city" VALUES(3703,'Madrid','Madrid, New York',4674,32);
INSERT INTO "django_geo_db_city" VALUES(3704,'Mannsville','Mannsville, New York',4675,32);
INSERT INTO "django_geo_db_city" VALUES(3705,'Massena','Massena, New York',4676,32);
INSERT INTO "django_geo_db_city" VALUES(3706,'Morristown','Morristown, New York',4677,32);
INSERT INTO "django_geo_db_city" VALUES(3707,'Natural Bridge','Natural Bridge, New York',4678,32);
INSERT INTO "django_geo_db_city" VALUES(3708,'Newton Falls','Newton Falls, New York',4660,32);
INSERT INTO "django_geo_db_city" VALUES(3709,'Norfolk','Norfolk, New York',4679,32);
INSERT INTO "django_geo_db_city" VALUES(3710,'Norwood','Norwood, New York',4680,32);
INSERT INTO "django_geo_db_city" VALUES(3711,'Ogdensburg','Ogdensburg, New York',4681,32);
INSERT INTO "django_geo_db_city" VALUES(3712,'Oswegatchie','Oswegatchie, New York',4682,32);
INSERT INTO "django_geo_db_city" VALUES(3713,'Oxbow','Oxbow, New York',4683,32);
INSERT INTO "django_geo_db_city" VALUES(3714,'Parishville','Parishville, New York',4684,32);
INSERT INTO "django_geo_db_city" VALUES(3715,'Philadelphia','Philadelphia, New York',4685,32);
INSERT INTO "django_geo_db_city" VALUES(3716,'Pierrepont Manor','Pierrepont Manor, New York',4686,32);
INSERT INTO "django_geo_db_city" VALUES(3717,'Plessis','Plessis, New York',4687,32);
INSERT INTO "django_geo_db_city" VALUES(3718,'Potsdam','Potsdam, New York',4688,32);
INSERT INTO "django_geo_db_city" VALUES(3719,'Pyrites','Pyrites, New York',4689,32);
INSERT INTO "django_geo_db_city" VALUES(3720,'Raymondville','Raymondville, New York',4690,32);
INSERT INTO "django_geo_db_city" VALUES(3721,'Redwood','Redwood, New York',4691,32);
INSERT INTO "django_geo_db_city" VALUES(3722,'Rensselaer Falls','Rensselaer Falls, New York',4692,32);
INSERT INTO "django_geo_db_city" VALUES(3723,'Richville','Richville, New York',4693,32);
INSERT INTO "django_geo_db_city" VALUES(3724,'Rooseveltown','Rooseveltown, New York',4660,32);
INSERT INTO "django_geo_db_city" VALUES(3725,'Russell','Russell, New York',4695,32);
INSERT INTO "django_geo_db_city" VALUES(3726,'Sackets Harbor','Sackets Harbor, New York',4696,32);
INSERT INTO "django_geo_db_city" VALUES(3727,'South Colton','South Colton, New York',4697,32);
INSERT INTO "django_geo_db_city" VALUES(3728,'South Rutland','South Rutland, New York',4698,32);
INSERT INTO "django_geo_db_city" VALUES(3729,'Star Lake','Star Lake, New York',4699,32);
INSERT INTO "django_geo_db_city" VALUES(3730,'Theresa','Theresa, New York',4700,32);
INSERT INTO "django_geo_db_city" VALUES(3731,'Thousand Island Park','Thousand Island Park, New York',4701,32);
INSERT INTO "django_geo_db_city" VALUES(3732,'Three Mile Bay','Three Mile Bay, New York',4702,32);
INSERT INTO "django_geo_db_city" VALUES(3733,'Waddington','Waddington, New York',4703,32);
INSERT INTO "django_geo_db_city" VALUES(3734,'Wanakena','Wanakena, New York',4704,32);
INSERT INTO "django_geo_db_city" VALUES(3735,'West Stockholm','West Stockholm, New York',4705,32);
INSERT INTO "django_geo_db_city" VALUES(3736,'Winthrop','Winthrop, New York',4706,32);
INSERT INTO "django_geo_db_city" VALUES(3737,'Afton','Afton, New York',4709,32);
INSERT INTO "django_geo_db_city" VALUES(3738,'Andes','Andes, New York',4710,32);
INSERT INTO "django_geo_db_city" VALUES(3739,'Apalachin','Apalachin, New York',4711,32);
INSERT INTO "django_geo_db_city" VALUES(3740,'Bainbridge','Bainbridge, New York',4712,32);
INSERT INTO "django_geo_db_city" VALUES(3741,'Barton','Barton, New York',4713,32);
INSERT INTO "django_geo_db_city" VALUES(3742,'Berkshire','Berkshire, New York',4714,32);
INSERT INTO "django_geo_db_city" VALUES(3743,'Bible School Park','Bible School Park, New York',4715,32);
INSERT INTO "django_geo_db_city" VALUES(3744,'Blodgett Mills','Blodgett Mills, New York',4716,32);
INSERT INTO "django_geo_db_city" VALUES(3745,'Bloomville','Bloomville, New York',4717,32);
INSERT INTO "django_geo_db_city" VALUES(3746,'Bovina Center','Bovina Center, New York',4718,32);
INSERT INTO "django_geo_db_city" VALUES(3747,'Candor','Candor, New York',4719,32);
INSERT INTO "django_geo_db_city" VALUES(3748,'Castle Creek','Castle Creek, New York',4720,32);
INSERT INTO "django_geo_db_city" VALUES(3749,'Chenango Bridge','Chenango Bridge, New York',4721,32);
INSERT INTO "django_geo_db_city" VALUES(3750,'Chenango Forks','Chenango Forks, New York',4722,32);
INSERT INTO "django_geo_db_city" VALUES(3751,'Colliersville','Colliersville, New York',4723,32);
INSERT INTO "django_geo_db_city" VALUES(3752,'Conklin','Conklin, New York',4724,32);
INSERT INTO "django_geo_db_city" VALUES(3753,'Corbettsville','Corbettsville, New York',4725,32);
INSERT INTO "django_geo_db_city" VALUES(3754,'Davenport','Davenport, New York',4726,32);
INSERT INTO "django_geo_db_city" VALUES(3755,'Davenport Center','Davenport Center, New York',4727,32);
INSERT INTO "django_geo_db_city" VALUES(3756,'De Lancey','De Lancey, New York',4728,32);
INSERT INTO "django_geo_db_city" VALUES(3757,'Delhi','Delhi, New York',4729,32);
INSERT INTO "django_geo_db_city" VALUES(3758,'Deposit','Deposit, New York',4730,32);
INSERT INTO "django_geo_db_city" VALUES(3759,'Downsville','Downsville, New York',4731,32);
INSERT INTO "django_geo_db_city" VALUES(3760,'East Branch','East Branch, New York',4732,32);
INSERT INTO "django_geo_db_city" VALUES(3761,'East Meredith','East Meredith, New York',4733,32);
INSERT INTO "django_geo_db_city" VALUES(3762,'East Pharsalia','East Pharsalia, New York',4734,32);
INSERT INTO "django_geo_db_city" VALUES(3763,'Endicott','Endicott, New York',4735,32);
INSERT INTO "django_geo_db_city" VALUES(3764,'Endwell','Endwell, New York',4725,32);
INSERT INTO "django_geo_db_city" VALUES(3765,'Maine','Maine, New York',4736,32);
INSERT INTO "django_geo_db_city" VALUES(3766,'Fishs Eddy','Fishs Eddy, New York',4737,32);
INSERT INTO "django_geo_db_city" VALUES(3767,'Franklin','Franklin, New York',4738,32);
INSERT INTO "django_geo_db_city" VALUES(3768,'Gilbertsville','Gilbertsville, New York',4739,32);
INSERT INTO "django_geo_db_city" VALUES(3769,'Glen Aubrey','Glen Aubrey, New York',4740,32);
INSERT INTO "django_geo_db_city" VALUES(3770,'Greene','Greene, New York',4741,32);
INSERT INTO "django_geo_db_city" VALUES(3771,'Guilford','Guilford, New York',4742,32);
INSERT INTO "django_geo_db_city" VALUES(3772,'Hamden','Hamden, New York',4743,32);
INSERT INTO "django_geo_db_city" VALUES(3773,'Hancock','Hancock, New York',4744,32);
INSERT INTO "django_geo_db_city" VALUES(3774,'Harford','Harford, New York',4745,32);
INSERT INTO "django_geo_db_city" VALUES(3775,'Harpersfield','Harpersfield, New York',4746,32);
INSERT INTO "django_geo_db_city" VALUES(3776,'Harpursville','Harpursville, New York',4747,32);
INSERT INTO "django_geo_db_city" VALUES(3777,'Hobart','Hobart, New York',4748,32);
INSERT INTO "django_geo_db_city" VALUES(3778,'Johnson City','Johnson City, New York',4749,32);
INSERT INTO "django_geo_db_city" VALUES(3779,'Morris','Morris, New York',4750,32);
INSERT INTO "django_geo_db_city" VALUES(3780,'Killawog','Killawog, New York',4751,32);
INSERT INTO "django_geo_db_city" VALUES(3781,'Kirkwood','Kirkwood, New York',4752,32);
INSERT INTO "django_geo_db_city" VALUES(3782,'Laurens','Laurens, New York',4753,32);
INSERT INTO "django_geo_db_city" VALUES(3783,'Lisle','Lisle, New York',4754,32);
INSERT INTO "django_geo_db_city" VALUES(3784,'McDonough','McDonough, New York',4755,32);
INSERT INTO "django_geo_db_city" VALUES(3785,'Marathon','Marathon, New York',4757,32);
INSERT INTO "django_geo_db_city" VALUES(3786,'Masonville','Masonville, New York',4758,32);
INSERT INTO "django_geo_db_city" VALUES(3787,'Meridale','Meridale, New York',4030,32);
INSERT INTO "django_geo_db_city" VALUES(3788,'Milford','Milford, New York',4759,32);
INSERT INTO "django_geo_db_city" VALUES(3789,'Mount Upton','Mount Upton, New York',4761,32);
INSERT INTO "django_geo_db_city" VALUES(3790,'Mount Vision','Mount Vision, New York',4762,32);
INSERT INTO "django_geo_db_city" VALUES(3791,'Newark Valley','Newark Valley, New York',4763,32);
INSERT INTO "django_geo_db_city" VALUES(3792,'Nichols','Nichols, New York',4764,32);
INSERT INTO "django_geo_db_city" VALUES(3793,'Nineveh','Nineveh, New York',4765,32);
INSERT INTO "django_geo_db_city" VALUES(3794,'North Norwich','North Norwich, New York',4766,32);
INSERT INTO "django_geo_db_city" VALUES(3795,'Norwich','Norwich, New York',4767,32);
INSERT INTO "django_geo_db_city" VALUES(3796,'Oneonta','Oneonta, New York',4768,32);
INSERT INTO "django_geo_db_city" VALUES(3797,'Otego','Otego, New York',4769,32);
INSERT INTO "django_geo_db_city" VALUES(3798,'Ouaquaga','Ouaquaga, New York',4770,32);
INSERT INTO "django_geo_db_city" VALUES(3799,'Owego','Owego, New York',4771,32);
INSERT INTO "django_geo_db_city" VALUES(3800,'Oxford','Oxford, New York',4772,32);
INSERT INTO "django_geo_db_city" VALUES(3801,'Port Crane','Port Crane, New York',4774,32);
INSERT INTO "django_geo_db_city" VALUES(3802,'Portlandville','Portlandville, New York',4775,32);
INSERT INTO "django_geo_db_city" VALUES(3803,'Richford','Richford, New York',4776,32);
INSERT INTO "django_geo_db_city" VALUES(3804,'Shinhopple','Shinhopple, New York',4030,32);
INSERT INTO "django_geo_db_city" VALUES(3805,'Sidney','Sidney, New York',4777,32);
INSERT INTO "django_geo_db_city" VALUES(3806,'Sidney Center','Sidney Center, New York',4778,32);
INSERT INTO "django_geo_db_city" VALUES(3807,'Smithboro','Smithboro, New York',4779,32);
INSERT INTO "django_geo_db_city" VALUES(3808,'Smithville Flats','Smithville Flats, New York',4780,32);
INSERT INTO "django_geo_db_city" VALUES(3809,'South Kortright','South Kortright, New York',4781,32);
INSERT INTO "django_geo_db_city" VALUES(3810,'South New Berlin','South New Berlin, New York',4782,32);
INSERT INTO "django_geo_db_city" VALUES(3811,'South Plymouth','South Plymouth, New York',4783,32);
INSERT INTO "django_geo_db_city" VALUES(3812,'Tioga Center','Tioga Center, New York',4784,32);
INSERT INTO "django_geo_db_city" VALUES(3813,'Treadwell','Treadwell, New York',4785,32);
INSERT INTO "django_geo_db_city" VALUES(3814,'Trout Creek','Trout Creek, New York',4030,32);
INSERT INTO "django_geo_db_city" VALUES(3815,'Tunnel','Tunnel, New York',4786,32);
INSERT INTO "django_geo_db_city" VALUES(3816,'Unadilla','Unadilla, New York',4787,32);
INSERT INTO "django_geo_db_city" VALUES(3817,'Vestal','Vestal, New York',4788,32);
INSERT INTO "django_geo_db_city" VALUES(3818,'Walton','Walton, New York',4789,32);
INSERT INTO "django_geo_db_city" VALUES(3819,'Wells Bridge','Wells Bridge, New York',4790,32);
INSERT INTO "django_geo_db_city" VALUES(3820,'West Davenport','West Davenport, New York',4030,32);
INSERT INTO "django_geo_db_city" VALUES(3821,'West Oneonta','West Oneonta, New York',4791,32);
INSERT INTO "django_geo_db_city" VALUES(3822,'Whitney Point','Whitney Point, New York',4792,32);
INSERT INTO "django_geo_db_city" VALUES(3823,'Willet','Willet, New York',4793,32);
INSERT INTO "django_geo_db_city" VALUES(3824,'Willseyville','Willseyville, New York',4794,32);
INSERT INTO "django_geo_db_city" VALUES(3825,'Windsor','Windsor, New York',4795,32);
INSERT INTO "django_geo_db_city" VALUES(3826,'Binghamton','Binghamton, New York',4796,32);
INSERT INTO "django_geo_db_city" VALUES(3827,'Whitestown','Whitestown, New York',4801,32);
INSERT INTO "django_geo_db_city" VALUES(3828,'Akron','Akron, New York',4802,32);
INSERT INTO "django_geo_db_city" VALUES(3829,'Alabama','Alabama, New York',4803,32);
INSERT INTO "django_geo_db_city" VALUES(3830,'Alden','Alden, New York',4804,32);
INSERT INTO "django_geo_db_city" VALUES(3831,'Alexander','Alexander, New York',4805,32);
INSERT INTO "django_geo_db_city" VALUES(3832,'Angola','Angola, New York',4806,32);
INSERT INTO "django_geo_db_city" VALUES(3833,'Appleton','Appleton, New York',4807,32);
INSERT INTO "django_geo_db_city" VALUES(3834,'Arcade','Arcade, New York',4808,32);
INSERT INTO "django_geo_db_city" VALUES(3835,'Athol Springs','Athol Springs, New York',4809,32);
INSERT INTO "django_geo_db_city" VALUES(3836,'Attica','Attica, New York',4810,32);
INSERT INTO "django_geo_db_city" VALUES(3837,'Barker','Barker, New York',4811,32);
INSERT INTO "django_geo_db_city" VALUES(3838,'Basom','Basom, New York',4812,32);
INSERT INTO "django_geo_db_city" VALUES(3839,'Batavia','Batavia, New York',4813,32);
INSERT INTO "django_geo_db_city" VALUES(3840,'Bliss','Bliss, New York',4814,32);
INSERT INTO "django_geo_db_city" VALUES(3841,'Boston','Boston, New York',4815,32);
INSERT INTO "django_geo_db_city" VALUES(3842,'Bowmansville','Bowmansville, New York',4816,32);
INSERT INTO "django_geo_db_city" VALUES(3843,'Brant','Brant, New York',4817,32);
INSERT INTO "django_geo_db_city" VALUES(3844,'Burt','Burt, New York',4818,32);
INSERT INTO "django_geo_db_city" VALUES(3845,'Centerville','Centerville, New York',4819,32);
INSERT INTO "django_geo_db_city" VALUES(3846,'Chaffee','Chaffee, New York',4820,32);
INSERT INTO "django_geo_db_city" VALUES(3847,'Clarence','Clarence, New York',4821,32);
INSERT INTO "django_geo_db_city" VALUES(3848,'Clarence Center','Clarence Center, New York',4822,32);
INSERT INTO "django_geo_db_city" VALUES(3849,'Colden','Colden, New York',4823,32);
INSERT INTO "django_geo_db_city" VALUES(3850,'Collins','Collins, New York',4824,32);
INSERT INTO "django_geo_db_city" VALUES(3851,'Collins Center','Collins Center, New York',4825,32);
INSERT INTO "django_geo_db_city" VALUES(3852,'Corfu','Corfu, New York',4826,32);
INSERT INTO "django_geo_db_city" VALUES(3853,'Cowlesville','Cowlesville, New York',4827,32);
INSERT INTO "django_geo_db_city" VALUES(3854,'Crittenden','Crittenden, New York',4828,32);
INSERT INTO "django_geo_db_city" VALUES(3855,'Dale','Dale, New York',4829,32);
INSERT INTO "django_geo_db_city" VALUES(3856,'Darien Center','Darien Center, New York',4830,32);
INSERT INTO "django_geo_db_city" VALUES(3857,'Dayton','Dayton, New York',4831,32);
INSERT INTO "django_geo_db_city" VALUES(3858,'Delevan','Delevan, New York',4832,32);
INSERT INTO "django_geo_db_city" VALUES(3859,'Depew','Depew, New York',4833,32);
INSERT INTO "django_geo_db_city" VALUES(3860,'Derby','Derby, New York',4834,32);
INSERT INTO "django_geo_db_city" VALUES(3861,'Dunkirk','Dunkirk, New York',4835,32);
INSERT INTO "django_geo_db_city" VALUES(3862,'East Amherst','East Amherst, New York',4836,32);
INSERT INTO "django_geo_db_city" VALUES(3863,'East Aurora','East Aurora, New York',4837,32);
INSERT INTO "django_geo_db_city" VALUES(3864,'East Bethany','East Bethany, New York',4838,32);
INSERT INTO "django_geo_db_city" VALUES(3865,'East Concord','East Concord, New York',4839,32);
INSERT INTO "django_geo_db_city" VALUES(3866,'East Pembroke','East Pembroke, New York',4840,32);
INSERT INTO "django_geo_db_city" VALUES(3867,'Eden','Eden, New York',4841,32);
INSERT INTO "django_geo_db_city" VALUES(3868,'Elba','Elba, New York',4842,32);
INSERT INTO "django_geo_db_city" VALUES(3869,'Elma','Elma, New York',4843,32);
INSERT INTO "django_geo_db_city" VALUES(3870,'Farmersville Station','Farmersville Station, New York',4844,32);
INSERT INTO "django_geo_db_city" VALUES(3871,'Farnham','Farnham, New York',4845,32);
INSERT INTO "django_geo_db_city" VALUES(3872,'Forestville','Forestville, New York',4846,32);
INSERT INTO "django_geo_db_city" VALUES(3873,'Fredonia','Fredonia, New York',4847,32);
INSERT INTO "django_geo_db_city" VALUES(3874,'Rochester','Rochester, New York',4848,32);
INSERT INTO "django_geo_db_city" VALUES(3875,'Freedom','Freedom, New York',4849,32);
INSERT INTO "django_geo_db_city" VALUES(3876,'Gainesville','Gainesville, New York',4850,32);
INSERT INTO "django_geo_db_city" VALUES(3877,'Gasport','Gasport, New York',4851,32);
INSERT INTO "django_geo_db_city" VALUES(3878,'Getzville','Getzville, New York',4852,32);
INSERT INTO "django_geo_db_city" VALUES(3879,'Glenwood','Glenwood, New York',4853,32);
INSERT INTO "django_geo_db_city" VALUES(3880,'Gowanda','Gowanda, New York',4854,32);
INSERT INTO "django_geo_db_city" VALUES(3881,'Grand Island','Grand Island, New York',4855,32);
INSERT INTO "django_geo_db_city" VALUES(3882,'Hamburg','Hamburg, New York',4856,32);
INSERT INTO "django_geo_db_city" VALUES(3883,'Holland','Holland, New York',4857,32);
INSERT INTO "django_geo_db_city" VALUES(3884,'Irving','Irving, New York',4858,32);
INSERT INTO "django_geo_db_city" VALUES(3885,'Java Center','Java Center, New York',4859,32);
INSERT INTO "django_geo_db_city" VALUES(3886,'Java Village','Java Village, New York',4860,32);
INSERT INTO "django_geo_db_city" VALUES(3887,'Lake View','Lake View, New York',4861,32);
INSERT INTO "django_geo_db_city" VALUES(3888,'Lancaster','Lancaster, New York',4862,32);
INSERT INTO "django_geo_db_city" VALUES(3889,'Lawtons','Lawtons, New York',4863,32);
INSERT INTO "django_geo_db_city" VALUES(3890,'Lewiston','Lewiston, New York',4864,32);
INSERT INTO "django_geo_db_city" VALUES(3891,'Lockport','Lockport, New York',4865,32);
INSERT INTO "django_geo_db_city" VALUES(3892,'Lyndonville','Lyndonville, New York',4867,32);
INSERT INTO "django_geo_db_city" VALUES(3893,'Machias','Machias, New York',4868,32);
INSERT INTO "django_geo_db_city" VALUES(3894,'Marilla','Marilla, New York',4869,32);
INSERT INTO "django_geo_db_city" VALUES(3895,'Medina','Medina, New York',4870,32);
INSERT INTO "django_geo_db_city" VALUES(3896,'Middleport','Middleport, New York',4871,32);
INSERT INTO "django_geo_db_city" VALUES(3897,'Model City','Model City, New York',4866,32);
INSERT INTO "django_geo_db_city" VALUES(3898,'Newfane','Newfane, New York',4872,32);
INSERT INTO "django_geo_db_city" VALUES(3899,'Niagara University','Niagara University, New York',4866,32);
INSERT INTO "django_geo_db_city" VALUES(3900,'North Boston','North Boston, New York',4809,32);
INSERT INTO "django_geo_db_city" VALUES(3901,'North Collins','North Collins, New York',4873,32);
INSERT INTO "django_geo_db_city" VALUES(3902,'North Evans','North Evans, New York',4874,32);
INSERT INTO "django_geo_db_city" VALUES(3903,'North Java','North Java, New York',4875,32);
INSERT INTO "django_geo_db_city" VALUES(3904,'North Tonawanda','North Tonawanda, New York',4876,32);
INSERT INTO "django_geo_db_city" VALUES(3905,'Oakfield','Oakfield, New York',4877,32);
INSERT INTO "django_geo_db_city" VALUES(3906,'Olcott','Olcott, New York',4878,32);
INSERT INTO "django_geo_db_city" VALUES(3907,'Orchard Park','Orchard Park, New York',4879,32);
INSERT INTO "django_geo_db_city" VALUES(3908,'Perrysburg','Perrysburg, New York',4880,32);
INSERT INTO "django_geo_db_city" VALUES(3909,'Pike','Pike, New York',4881,32);
INSERT INTO "django_geo_db_city" VALUES(3910,'Ransomville','Ransomville, New York',4882,32);
INSERT INTO "django_geo_db_city" VALUES(3911,'Sanborn','Sanborn, New York',4883,32);
INSERT INTO "django_geo_db_city" VALUES(3912,'Sandusky','Sandusky, New York',4884,32);
INSERT INTO "django_geo_db_city" VALUES(3913,'Sardinia','Sardinia, New York',4885,32);
INSERT INTO "django_geo_db_city" VALUES(3914,'Sheridan','Sheridan, New York',4886,32);
INSERT INTO "django_geo_db_city" VALUES(3915,'Silver Creek','Silver Creek, New York',4887,32);
INSERT INTO "django_geo_db_city" VALUES(3916,'South Dayton','South Dayton, New York',4888,32);
INSERT INTO "django_geo_db_city" VALUES(3917,'South Wales','South Wales, New York',4889,32);
INSERT INTO "django_geo_db_city" VALUES(3918,'Spring Brook','Spring Brook, New York',4890,32);
INSERT INTO "django_geo_db_city" VALUES(3919,'Springville','Springville, New York',4891,32);
INSERT INTO "django_geo_db_city" VALUES(3920,'Stafford','Stafford, New York',4892,32);
INSERT INTO "django_geo_db_city" VALUES(3921,'Stella Niagara','Stella Niagara, New York',4893,32);
INSERT INTO "django_geo_db_city" VALUES(3922,'Strykersville','Strykersville, New York',4894,32);
INSERT INTO "django_geo_db_city" VALUES(3923,'Tonawanda','Tonawanda, New York',4895,32);
INSERT INTO "django_geo_db_city" VALUES(3924,'Van Buren Point','Van Buren Point, New York',4896,32);
INSERT INTO "django_geo_db_city" VALUES(3925,'Varysburg','Varysburg, New York',4897,32);
INSERT INTO "django_geo_db_city" VALUES(3926,'Versailles','Versailles, New York',4898,32);
INSERT INTO "django_geo_db_city" VALUES(3927,'Wales Center','Wales Center, New York',4899,32);
INSERT INTO "django_geo_db_city" VALUES(3928,'West Falls','West Falls, New York',4900,32);
INSERT INTO "django_geo_db_city" VALUES(3929,'West Valley','West Valley, New York',4901,32);
INSERT INTO "django_geo_db_city" VALUES(3930,'Wilson','Wilson, New York',4902,32);
INSERT INTO "django_geo_db_city" VALUES(3931,'Yorkshire','Yorkshire, New York',4903,32);
INSERT INTO "django_geo_db_city" VALUES(3932,'Youngstown','Youngstown, New York',4904,32);
INSERT INTO "django_geo_db_city" VALUES(3933,'Buffalo','Buffalo, New York',4905,32);
INSERT INTO "django_geo_db_city" VALUES(3934,'Niagara Falls','Niagara Falls, New York',4935,32);
INSERT INTO "django_geo_db_city" VALUES(3935,'Adams Basin','Adams Basin, New York',4939,32);
INSERT INTO "django_geo_db_city" VALUES(3936,'Albion','Albion, New York',4940,32);
INSERT INTO "django_geo_db_city" VALUES(3937,'Alton','Alton, New York',4941,32);
INSERT INTO "django_geo_db_city" VALUES(3938,'Avon','Avon, New York',4942,32);
INSERT INTO "django_geo_db_city" VALUES(3939,'Bellona','Bellona, New York',4943,32);
INSERT INTO "django_geo_db_city" VALUES(3940,'Bergen','Bergen, New York',4944,32);
INSERT INTO "django_geo_db_city" VALUES(3941,'Geneseo','Geneseo, New York',4945,32);
INSERT INTO "django_geo_db_city" VALUES(3942,'Branchport','Branchport, New York',4946,32);
INSERT INTO "django_geo_db_city" VALUES(3943,'Brockport','Brockport, New York',4947,32);
INSERT INTO "django_geo_db_city" VALUES(3944,'Byron','Byron, New York',4948,32);
INSERT INTO "django_geo_db_city" VALUES(3945,'Caledonia','Caledonia, New York',4949,32);
INSERT INTO "django_geo_db_city" VALUES(3946,'Canandaigua','Canandaigua, New York',4950,32);
INSERT INTO "django_geo_db_city" VALUES(3947,'Farmington','Farmington, New York',4951,32);
INSERT INTO "django_geo_db_city" VALUES(3948,'Castile','Castile, New York',4952,32);
INSERT INTO "django_geo_db_city" VALUES(3949,'Churchville','Churchville, New York',4953,32);
INSERT INTO "django_geo_db_city" VALUES(3950,'Clarendon','Clarendon, New York',4954,32);
INSERT INTO "django_geo_db_city" VALUES(3951,'Clarkson','Clarkson, New York',4955,32);
INSERT INTO "django_geo_db_city" VALUES(3952,'Clifton Springs','Clifton Springs, New York',4956,32);
INSERT INTO "django_geo_db_city" VALUES(3953,'Clyde','Clyde, New York',4957,32);
INSERT INTO "django_geo_db_city" VALUES(3954,'Conesus','Conesus, New York',4958,32);
INSERT INTO "django_geo_db_city" VALUES(3955,'Dansville','Dansville, New York',4959,32);
INSERT INTO "django_geo_db_city" VALUES(3956,'Dresden','Dresden, New York',4960,32);
INSERT INTO "django_geo_db_city" VALUES(3957,'East Bloomfield','East Bloomfield, New York',4961,32);
INSERT INTO "django_geo_db_city" VALUES(3958,'East Rochester','East Rochester, New York',4962,32);
INSERT INTO "django_geo_db_city" VALUES(3959,'East Williamson','East Williamson, New York',4963,32);
INSERT INTO "django_geo_db_city" VALUES(3960,'Fairport','Fairport, New York',4964,32);
INSERT INTO "django_geo_db_city" VALUES(3961,'Fancher','Fancher, New York',4954,32);
INSERT INTO "django_geo_db_city" VALUES(3962,'Fishers','Fishers, New York',4965,32);
INSERT INTO "django_geo_db_city" VALUES(3963,'Geneva','Geneva, New York',4967,32);
INSERT INTO "django_geo_db_city" VALUES(3964,'Lima','Lima, New York',4968,32);
INSERT INTO "django_geo_db_city" VALUES(3965,'Gorham','Gorham, New York',4969,32);
INSERT INTO "django_geo_db_city" VALUES(3966,'Groveland','Groveland, New York',4970,32);
INSERT INTO "django_geo_db_city" VALUES(3967,'Hall','Hall, New York',4971,32);
INSERT INTO "django_geo_db_city" VALUES(3968,'Hamlin','Hamlin, New York',4972,32);
INSERT INTO "django_geo_db_city" VALUES(3969,'Hemlock','Hemlock, New York',4973,32);
INSERT INTO "django_geo_db_city" VALUES(3970,'Henrietta','Henrietta, New York',4974,32);
INSERT INTO "django_geo_db_city" VALUES(3971,'Hilton','Hilton, New York',4975,32);
INSERT INTO "django_geo_db_city" VALUES(3972,'Bloomfield','Bloomfield, New York',4976,32);
INSERT INTO "django_geo_db_city" VALUES(3973,'Holley','Holley, New York',4977,32);
INSERT INTO "django_geo_db_city" VALUES(3974,'Honeoye','Honeoye, New York',4978,32);
INSERT INTO "django_geo_db_city" VALUES(3975,'Honeoye Falls','Honeoye Falls, New York',4979,32);
INSERT INTO "django_geo_db_city" VALUES(3976,'Ionia','Ionia, New York',4980,32);
INSERT INTO "django_geo_db_city" VALUES(3977,'Kendall','Kendall, New York',4981,32);
INSERT INTO "django_geo_db_city" VALUES(3978,'Kent','Kent, New York',4982,32);
INSERT INTO "django_geo_db_city" VALUES(3979,'Keuka Park','Keuka Park, New York',4983,32);
INSERT INTO "django_geo_db_city" VALUES(3980,'Knowlesville','Knowlesville, New York',4984,32);
INSERT INTO "django_geo_db_city" VALUES(3981,'Lakeville','Lakeville, New York',4985,32);
INSERT INTO "django_geo_db_city" VALUES(3982,'Leicester','Leicester, New York',4986,32);
INSERT INTO "django_geo_db_city" VALUES(3983,'Le Roy','Le Roy, New York',4987,32);
INSERT INTO "django_geo_db_city" VALUES(3984,'Portage','Portage, New York',4988,32);
INSERT INTO "django_geo_db_city" VALUES(3985,'Linwood','Linwood, New York',4990,32);
INSERT INTO "django_geo_db_city" VALUES(3986,'Livonia','Livonia, New York',4991,32);
INSERT INTO "django_geo_db_city" VALUES(3987,'Livonia Center','Livonia Center, New York',4992,32);
INSERT INTO "django_geo_db_city" VALUES(3988,'Lyons','Lyons, New York',4993,32);
INSERT INTO "django_geo_db_city" VALUES(3989,'Macedon','Macedon, New York',4994,32);
INSERT INTO "django_geo_db_city" VALUES(3990,'Manchester','Manchester, New York',4995,32);
INSERT INTO "django_geo_db_city" VALUES(3991,'Marion','Marion, New York',4996,32);
INSERT INTO "django_geo_db_city" VALUES(3992,'Mendon','Mendon, New York',4997,32);
INSERT INTO "django_geo_db_city" VALUES(3993,'Middlesex','Middlesex, New York',4998,32);
INSERT INTO "django_geo_db_city" VALUES(3994,'Morton','Morton, New York',4954,32);
INSERT INTO "django_geo_db_city" VALUES(3995,'Mount Morris','Mount Morris, New York',4999,32);
INSERT INTO "django_geo_db_city" VALUES(3996,'Mumford','Mumford, New York',5000,32);
INSERT INTO "django_geo_db_city" VALUES(3997,'Naples','Naples, New York',5001,32);
INSERT INTO "django_geo_db_city" VALUES(3998,'Newark','Newark, New York',5002,32);
INSERT INTO "django_geo_db_city" VALUES(3999,'North Chili','North Chili, New York',5003,32);
INSERT INTO "django_geo_db_city" VALUES(4000,'North Greece','North Greece, New York',5004,32);
INSERT INTO "django_geo_db_city" VALUES(4001,'North Rose','North Rose, New York',5005,32);
INSERT INTO "django_geo_db_city" VALUES(4002,'Nunda','Nunda, New York',5006,32);
INSERT INTO "django_geo_db_city" VALUES(4003,'Oaks Corners','Oaks Corners, New York',5007,32);
INSERT INTO "django_geo_db_city" VALUES(4004,'Ontario','Ontario, New York',5008,32);
INSERT INTO "django_geo_db_city" VALUES(4005,'Ontario Center','Ontario Center, New York',5009,32);
INSERT INTO "django_geo_db_city" VALUES(4006,'Ovid','Ovid, New York',5010,32);
INSERT INTO "django_geo_db_city" VALUES(4007,'Palmyra','Palmyra, New York',5011,32);
INSERT INTO "django_geo_db_city" VALUES(4008,'Pavilion','Pavilion, New York',5012,32);
INSERT INTO "django_geo_db_city" VALUES(4009,'Penfield','Penfield, New York',5013,32);
INSERT INTO "django_geo_db_city" VALUES(4010,'Penn Yan','Penn Yan, New York',5014,32);
INSERT INTO "django_geo_db_city" VALUES(4011,'Perkinsville','Perkinsville, New York',5015,32);
INSERT INTO "django_geo_db_city" VALUES(4012,'Perry','Perry, New York',5016,32);
INSERT INTO "django_geo_db_city" VALUES(4013,'Phelps','Phelps, New York',5017,32);
INSERT INTO "django_geo_db_city" VALUES(4014,'Piffard','Piffard, New York',5018,32);
INSERT INTO "django_geo_db_city" VALUES(4015,'Pittsford','Pittsford, New York',5019,32);
INSERT INTO "django_geo_db_city" VALUES(4016,'Portageville','Portageville, New York',5020,32);
INSERT INTO "django_geo_db_city" VALUES(4017,'Port Gibson','Port Gibson, New York',5021,32);
INSERT INTO "django_geo_db_city" VALUES(4018,'Pultneyville','Pultneyville, New York',5022,32);
INSERT INTO "django_geo_db_city" VALUES(4019,'Retsof','Retsof, New York',5023,32);
INSERT INTO "django_geo_db_city" VALUES(4020,'Romulus','Romulus, New York',5024,32);
INSERT INTO "django_geo_db_city" VALUES(4021,'Rose','Rose, New York',5025,32);
INSERT INTO "django_geo_db_city" VALUES(4022,'Rush','Rush, New York',5026,32);
INSERT INTO "django_geo_db_city" VALUES(4023,'Rushville','Rushville, New York',5027,32);
INSERT INTO "django_geo_db_city" VALUES(4024,'Scottsburg','Scottsburg, New York',5028,32);
INSERT INTO "django_geo_db_city" VALUES(4025,'Scottsville','Scottsville, New York',5029,32);
INSERT INTO "django_geo_db_city" VALUES(4026,'Seneca Castle','Seneca Castle, New York',4969,32);
INSERT INTO "django_geo_db_city" VALUES(4027,'Shortsville','Shortsville, New York',5030,32);
INSERT INTO "django_geo_db_city" VALUES(4028,'Silver Lake','Silver Lake, New York',5031,32);
INSERT INTO "django_geo_db_city" VALUES(4029,'Silver Springs','Silver Springs, New York',5032,32);
INSERT INTO "django_geo_db_city" VALUES(4030,'Sodus','Sodus, New York',5033,32);
INSERT INTO "django_geo_db_city" VALUES(4031,'Sodus Point','Sodus Point, New York',5034,32);
INSERT INTO "django_geo_db_city" VALUES(4032,'Sonyea','Sonyea, New York',4992,32);
INSERT INTO "django_geo_db_city" VALUES(4033,'South Byron','South Byron, New York',5035,32);
INSERT INTO "django_geo_db_city" VALUES(4034,'South Lima','South Lima, New York',5036,32);
INSERT INTO "django_geo_db_city" VALUES(4035,'Spencerport','Spencerport, New York',5037,32);
INSERT INTO "django_geo_db_city" VALUES(4036,'Springwater','Springwater, New York',5038,32);
INSERT INTO "django_geo_db_city" VALUES(4037,'Stanley','Stanley, New York',5039,32);
INSERT INTO "django_geo_db_city" VALUES(4038,'Union Hill','Union Hill, New York',5009,32);
INSERT INTO "django_geo_db_city" VALUES(4039,'Victor','Victor, New York',5040,32);
INSERT INTO "django_geo_db_city" VALUES(4040,'Walworth','Walworth, New York',5041,32);
INSERT INTO "django_geo_db_city" VALUES(4041,'Warsaw','Warsaw, New York',5042,32);
INSERT INTO "django_geo_db_city" VALUES(4042,'Waterport','Waterport, New York',5043,32);
INSERT INTO "django_geo_db_city" VALUES(4043,'Wayland','Wayland, New York',5044,32);
INSERT INTO "django_geo_db_city" VALUES(4044,'Webster','Webster, New York',5045,32);
INSERT INTO "django_geo_db_city" VALUES(4045,'West Bloomfield','West Bloomfield, New York',5046,32);
INSERT INTO "django_geo_db_city" VALUES(4046,'West Henrietta','West Henrietta, New York',5047,32);
INSERT INTO "django_geo_db_city" VALUES(4047,'Willard','Willard, New York',5048,32);
INSERT INTO "django_geo_db_city" VALUES(4048,'Williamson','Williamson, New York',5049,32);
INSERT INTO "django_geo_db_city" VALUES(4049,'Wolcott','Wolcott, New York',5050,32);
INSERT INTO "django_geo_db_city" VALUES(4050,'Wyoming','Wyoming, New York',5051,32);
INSERT INTO "django_geo_db_city" VALUES(4051,'York','York, New York',5052,32);
INSERT INTO "django_geo_db_city" VALUES(4052,'Jamestown','Jamestown, New York',5078,32);
INSERT INTO "django_geo_db_city" VALUES(4053,'Allegany','Allegany, New York',5081,32);
INSERT INTO "django_geo_db_city" VALUES(4054,'Allentown','Allentown, New York',5082,32);
INSERT INTO "django_geo_db_city" VALUES(4055,'Alma','Alma, New York',5083,32);
INSERT INTO "django_geo_db_city" VALUES(4056,'Angelica','Angelica, New York',5084,32);
INSERT INTO "django_geo_db_city" VALUES(4057,'Ashville','Ashville, New York',5085,32);
INSERT INTO "django_geo_db_city" VALUES(4058,'Belfast','Belfast, New York',5086,32);
INSERT INTO "django_geo_db_city" VALUES(4059,'Bemus Point','Bemus Point, New York',5087,32);
INSERT INTO "django_geo_db_city" VALUES(4060,'Black Creek','Black Creek, New York',5088,32);
INSERT INTO "django_geo_db_city" VALUES(4061,'Bolivar','Bolivar, New York',5089,32);
INSERT INTO "django_geo_db_city" VALUES(4062,'Brocton','Brocton, New York',5090,32);
INSERT INTO "django_geo_db_city" VALUES(4063,'Caneadea','Caneadea, New York',5091,32);
INSERT INTO "django_geo_db_city" VALUES(4064,'Cassadaga','Cassadaga, New York',5092,32);
INSERT INTO "django_geo_db_city" VALUES(4065,'Cattaraugus','Cattaraugus, New York',5093,32);
INSERT INTO "django_geo_db_city" VALUES(4066,'Celoron','Celoron, New York',5094,32);
INSERT INTO "django_geo_db_city" VALUES(4067,'Ceres','Ceres, New York',5095,32);
INSERT INTO "django_geo_db_city" VALUES(4068,'Chautauqua','Chautauqua, New York',5096,32);
INSERT INTO "django_geo_db_city" VALUES(4069,'Cherry Creek','Cherry Creek, New York',5097,32);
INSERT INTO "django_geo_db_city" VALUES(4070,'Clymer','Clymer, New York',5098,32);
INSERT INTO "django_geo_db_city" VALUES(4071,'Conewango Valley','Conewango Valley, New York',5099,32);
INSERT INTO "django_geo_db_city" VALUES(4072,'Cuba','Cuba, New York',5100,32);
INSERT INTO "django_geo_db_city" VALUES(4073,'Dewittville','Dewittville, New York',5101,32);
INSERT INTO "django_geo_db_city" VALUES(4074,'East Otto','East Otto, New York',5102,32);
INSERT INTO "django_geo_db_city" VALUES(4075,'East Randolph','East Randolph, New York',5103,32);
INSERT INTO "django_geo_db_city" VALUES(4076,'Ellicottville','Ellicottville, New York',5104,32);
INSERT INTO "django_geo_db_city" VALUES(4077,'Ellington','Ellington, New York',5105,32);
INSERT INTO "django_geo_db_city" VALUES(4078,'Falconer','Falconer, New York',5106,32);
INSERT INTO "django_geo_db_city" VALUES(4079,'Fillmore','Fillmore, New York',5107,32);
INSERT INTO "django_geo_db_city" VALUES(4080,'Findley Lake','Findley Lake, New York',5108,32);
INSERT INTO "django_geo_db_city" VALUES(4081,'Franklinville','Franklinville, New York',5109,32);
INSERT INTO "django_geo_db_city" VALUES(4082,'Frewsburg','Frewsburg, New York',5110,32);
INSERT INTO "django_geo_db_city" VALUES(4083,'Friendship','Friendship, New York',5111,32);
INSERT INTO "django_geo_db_city" VALUES(4084,'Gerry','Gerry, New York',5112,32);
INSERT INTO "django_geo_db_city" VALUES(4085,'Great Valley','Great Valley, New York',5113,32);
INSERT INTO "django_geo_db_city" VALUES(4086,'Greenhurst','Greenhurst, New York',5114,32);
INSERT INTO "django_geo_db_city" VALUES(4087,'Hinsdale','Hinsdale, New York',5115,32);
INSERT INTO "django_geo_db_city" VALUES(4088,'Houghton','Houghton, New York',5116,32);
INSERT INTO "django_geo_db_city" VALUES(4089,'Hume','Hume, New York',5117,32);
INSERT INTO "django_geo_db_city" VALUES(4090,'Kennedy','Kennedy, New York',5118,32);
INSERT INTO "django_geo_db_city" VALUES(4091,'Kill Buck','Kill Buck, New York',5119,32);
INSERT INTO "django_geo_db_city" VALUES(4092,'Lakewood','Lakewood, New York',5120,32);
INSERT INTO "django_geo_db_city" VALUES(4093,'Leon','Leon, New York',5121,32);
INSERT INTO "django_geo_db_city" VALUES(4094,'Lily Dale','Lily Dale, New York',5122,32);
INSERT INTO "django_geo_db_city" VALUES(4095,'Limestone','Limestone, New York',5123,32);
INSERT INTO "django_geo_db_city" VALUES(4096,'Little Genesee','Little Genesee, New York',5124,32);
INSERT INTO "django_geo_db_city" VALUES(4097,'Little Valley','Little Valley, New York',5125,32);
INSERT INTO "django_geo_db_city" VALUES(4098,'Maple Springs','Maple Springs, New York',5126,32);
INSERT INTO "django_geo_db_city" VALUES(4099,'Mayville','Mayville, New York',5127,32);
INSERT INTO "django_geo_db_city" VALUES(4100,'Niobe','Niobe, New York',5080,32);
INSERT INTO "django_geo_db_city" VALUES(4101,'Olean','Olean, New York',5128,32);
INSERT INTO "django_geo_db_city" VALUES(4102,'Otto','Otto, New York',5129,32);
INSERT INTO "django_geo_db_city" VALUES(4103,'Panama','Panama, New York',5130,32);
INSERT INTO "django_geo_db_city" VALUES(4104,'Portland','Portland, New York',5131,32);
INSERT INTO "django_geo_db_city" VALUES(4105,'Portville','Portville, New York',5132,32);
INSERT INTO "django_geo_db_city" VALUES(4106,'Canadice','Canadice, New York',5133,32);
INSERT INTO "django_geo_db_city" VALUES(4107,'Randolph','Randolph, New York',5134,32);
INSERT INTO "django_geo_db_city" VALUES(4108,'Richburg','Richburg, New York',5135,32);
INSERT INTO "django_geo_db_city" VALUES(4109,'Ripley','Ripley, New York',5136,32);
INSERT INTO "django_geo_db_city" VALUES(4110,'Rossburg','Rossburg, New York',5137,32);
INSERT INTO "django_geo_db_city" VALUES(4111,'Rushford','Rushford, New York',5138,32);
INSERT INTO "django_geo_db_city" VALUES(4112,'Saint Bonaventure','Saint Bonaventure, New York',5139,32);
INSERT INTO "django_geo_db_city" VALUES(4113,'Salamanca','Salamanca, New York',5140,32);
INSERT INTO "django_geo_db_city" VALUES(4114,'Sherman','Sherman, New York',5141,32);
INSERT INTO "django_geo_db_city" VALUES(4115,'Sinclairville','Sinclairville, New York',5142,32);
INSERT INTO "django_geo_db_city" VALUES(4116,'Steamburg','Steamburg, New York',5143,32);
INSERT INTO "django_geo_db_city" VALUES(4117,'Stockton','Stockton, New York',5144,32);
INSERT INTO "django_geo_db_city" VALUES(4118,'Stow','Stow, New York',5145,32);
INSERT INTO "django_geo_db_city" VALUES(4119,'West Clarksville','West Clarksville, New York',5146,32);
INSERT INTO "django_geo_db_city" VALUES(4120,'Westfield','Westfield, New York',5147,32);
INSERT INTO "django_geo_db_city" VALUES(4121,'Westons Mills','Westons Mills, New York',5148,32);
INSERT INTO "django_geo_db_city" VALUES(4122,'Addison','Addison, New York',5149,32);
INSERT INTO "django_geo_db_city" VALUES(4123,'Alfred','Alfred, New York',5150,32);
INSERT INTO "django_geo_db_city" VALUES(4124,'Alfred Station','Alfred Station, New York',5151,32);
INSERT INTO "django_geo_db_city" VALUES(4125,'Almond','Almond, New York',5152,32);
INSERT INTO "django_geo_db_city" VALUES(4126,'Alpine','Alpine, New York',5153,32);
INSERT INTO "django_geo_db_city" VALUES(4127,'Andover','Andover, New York',5154,32);
INSERT INTO "django_geo_db_city" VALUES(4128,'Arkport','Arkport, New York',5155,32);
INSERT INTO "django_geo_db_city" VALUES(4129,'Atlanta','Atlanta, New York',5156,32);
INSERT INTO "django_geo_db_city" VALUES(4130,'Avoca','Avoca, New York',5157,32);
INSERT INTO "django_geo_db_city" VALUES(4131,'Bath','Bath, New York',5158,32);
INSERT INTO "django_geo_db_city" VALUES(4132,'Beaver Dams','Beaver Dams, New York',5159,32);
INSERT INTO "django_geo_db_city" VALUES(4133,'Belmont','Belmont, New York',5160,32);
INSERT INTO "django_geo_db_city" VALUES(4134,'Big Flats','Big Flats, New York',5161,32);
INSERT INTO "django_geo_db_city" VALUES(4135,'Bradford','Bradford, New York',5162,32);
INSERT INTO "django_geo_db_city" VALUES(4136,'Breesport','Breesport, New York',5163,32);
INSERT INTO "django_geo_db_city" VALUES(4137,'Brooktondale','Brooktondale, New York',5164,32);
INSERT INTO "django_geo_db_city" VALUES(4138,'Burdett','Burdett, New York',5165,32);
INSERT INTO "django_geo_db_city" VALUES(4139,'Cameron','Cameron, New York',5166,32);
INSERT INTO "django_geo_db_city" VALUES(4140,'Cameron Mills','Cameron Mills, New York',5167,32);
INSERT INTO "django_geo_db_city" VALUES(4141,'Campbell','Campbell, New York',5168,32);
INSERT INTO "django_geo_db_city" VALUES(4142,'Canaseraga','Canaseraga, New York',5169,32);
INSERT INTO "django_geo_db_city" VALUES(4143,'Canisteo','Canisteo, New York',5170,32);
INSERT INTO "django_geo_db_city" VALUES(4144,'Cayuta','Cayuta, New York',5171,32);
INSERT INTO "django_geo_db_city" VALUES(4145,'Chemung','Chemung, New York',5172,32);
INSERT INTO "django_geo_db_city" VALUES(4146,'Cohocton','Cohocton, New York',5173,32);
INSERT INTO "django_geo_db_city" VALUES(4147,'Coopers Plains','Coopers Plains, New York',5174,32);
INSERT INTO "django_geo_db_city" VALUES(4148,'Corning','Corning, New York',5175,32);
INSERT INTO "django_geo_db_city" VALUES(4149,'Dalton','Dalton, New York',5177,32);
INSERT INTO "django_geo_db_city" VALUES(4150,'Dundee','Dundee, New York',5178,32);
INSERT INTO "django_geo_db_city" VALUES(4151,'Erin','Erin, New York',5179,32);
INSERT INTO "django_geo_db_city" VALUES(4152,'Greenwood','Greenwood, New York',5180,32);
INSERT INTO "django_geo_db_city" VALUES(4153,'Hammondsport','Hammondsport, New York',5181,32);
INSERT INTO "django_geo_db_city" VALUES(4154,'Hector','Hector, New York',5182,32);
INSERT INTO "django_geo_db_city" VALUES(4155,'Himrod','Himrod, New York',5183,32);
INSERT INTO "django_geo_db_city" VALUES(4156,'Hornell','Hornell, New York',5184,32);
INSERT INTO "django_geo_db_city" VALUES(4157,'Horseheads','Horseheads, New York',5185,32);
INSERT INTO "django_geo_db_city" VALUES(4158,'Hunt','Hunt, New York',5187,32);
INSERT INTO "django_geo_db_city" VALUES(4159,'Interlaken','Interlaken, New York',5188,32);
INSERT INTO "django_geo_db_city" VALUES(4160,'Ithaca','Ithaca, New York',5189,32);
INSERT INTO "django_geo_db_city" VALUES(4161,'Jacksonville','Jacksonville, New York',5193,32);
INSERT INTO "django_geo_db_city" VALUES(4162,'Jasper','Jasper, New York',5194,32);
INSERT INTO "django_geo_db_city" VALUES(4163,'Kanona','Kanona, New York',5195,32);
INSERT INTO "django_geo_db_city" VALUES(4164,'Lakemont','Lakemont, New York',5196,32);
INSERT INTO "django_geo_db_city" VALUES(4165,'Lindley','Lindley, New York',5197,32);
INSERT INTO "django_geo_db_city" VALUES(4166,'Lockwood','Lockwood, New York',5198,32);
INSERT INTO "django_geo_db_city" VALUES(4167,'Lodi','Lodi, New York',5199,32);
INSERT INTO "django_geo_db_city" VALUES(4168,'Lowman','Lowman, New York',5200,32);
INSERT INTO "django_geo_db_city" VALUES(4169,'Mecklenburg','Mecklenburg, New York',5201,32);
INSERT INTO "django_geo_db_city" VALUES(4170,'Millport','Millport, New York',5202,32);
INSERT INTO "django_geo_db_city" VALUES(4171,'Montour Falls','Montour Falls, New York',5203,32);
INSERT INTO "django_geo_db_city" VALUES(4172,'Newfield','Newfield, New York',5204,32);
INSERT INTO "django_geo_db_city" VALUES(4173,'Odessa','Odessa, New York',5205,32);
INSERT INTO "django_geo_db_city" VALUES(4174,'Painted Post','Painted Post, New York',5206,32);
INSERT INTO "django_geo_db_city" VALUES(4175,'Pine City','Pine City, New York',5207,32);
INSERT INTO "django_geo_db_city" VALUES(4176,'Pine Valley','Pine Valley, New York',5208,32);
INSERT INTO "django_geo_db_city" VALUES(4177,'Prattsburgh','Prattsburgh, New York',5209,32);
INSERT INTO "django_geo_db_city" VALUES(4178,'Pulteney','Pulteney, New York',5210,32);
INSERT INTO "django_geo_db_city" VALUES(4179,'Reading Center','Reading Center, New York',5211,32);
INSERT INTO "django_geo_db_city" VALUES(4180,'Rexville','Rexville, New York',5212,32);
INSERT INTO "django_geo_db_city" VALUES(4181,'Rock Stream','Rock Stream, New York',5213,32);
INSERT INTO "django_geo_db_city" VALUES(4182,'Savona','Savona, New York',5214,32);
INSERT INTO "django_geo_db_city" VALUES(4183,'Scio','Scio, New York',5215,32);
INSERT INTO "django_geo_db_city" VALUES(4184,'Slaterville Springs','Slaterville Springs, New York',5216,32);
INSERT INTO "django_geo_db_city" VALUES(4185,'Lansing','Lansing, New York',5217,32);
INSERT INTO "django_geo_db_city" VALUES(4186,'Spencer','Spencer, New York',5218,32);
INSERT INTO "django_geo_db_city" VALUES(4187,'Swain','Swain, New York',5219,32);
INSERT INTO "django_geo_db_city" VALUES(4188,'Troupsburg','Troupsburg, New York',5220,32);
INSERT INTO "django_geo_db_city" VALUES(4189,'Trumansburg','Trumansburg, New York',5221,32);
INSERT INTO "django_geo_db_city" VALUES(4190,'Tyrone','Tyrone, New York',5222,32);
INSERT INTO "django_geo_db_city" VALUES(4191,'Van Etten','Van Etten, New York',5223,32);
INSERT INTO "django_geo_db_city" VALUES(4192,'Watkins Glen','Watkins Glen, New York',5224,32);
INSERT INTO "django_geo_db_city" VALUES(4193,'Waverly','Waverly, New York',5225,32);
INSERT INTO "django_geo_db_city" VALUES(4194,'Wayne','Wayne, New York',5226,32);
INSERT INTO "django_geo_db_city" VALUES(4195,'Wellsburg','Wellsburg, New York',5227,32);
INSERT INTO "django_geo_db_city" VALUES(4196,'Wellsville','Wellsville, New York',5228,32);
INSERT INTO "django_geo_db_city" VALUES(4197,'Whitesville','Whitesville, New York',5229,32);
INSERT INTO "django_geo_db_city" VALUES(4198,'Woodhull','Woodhull, New York',5230,32);
INSERT INTO "django_geo_db_city" VALUES(4199,'Elmira','Elmira, New York',5231,32);
INSERT INTO "django_geo_db_city" VALUES(4200,'Aliquippa','Aliquippa, Pennsylvania',5236,44);
INSERT INTO "django_geo_db_city" VALUES(4201,'Ambridge','Ambridge, Pennsylvania',5237,44);
INSERT INTO "django_geo_db_city" VALUES(4202,'Atlasburg','Atlasburg, Pennsylvania',5238,44);
INSERT INTO "django_geo_db_city" VALUES(4203,'Baden','Baden, Pennsylvania',5239,44);
INSERT INTO "django_geo_db_city" VALUES(4204,'Bairdford','Bairdford, Pennsylvania',5240,44);
INSERT INTO "django_geo_db_city" VALUES(4205,'Bakerstown','Bakerstown, Pennsylvania',5241,44);
INSERT INTO "django_geo_db_city" VALUES(4206,'Beaver','Beaver, Pennsylvania',5242,44);
INSERT INTO "django_geo_db_city" VALUES(4207,'Beaver Falls','Beaver Falls, Pennsylvania',5243,44);
INSERT INTO "django_geo_db_city" VALUES(4208,'Belle Vernon','Belle Vernon, Pennsylvania',5244,44);
INSERT INTO "django_geo_db_city" VALUES(4209,'Brackenridge','Brackenridge, Pennsylvania',5245,44);
INSERT INTO "django_geo_db_city" VALUES(4210,'Bradfordwoods','Bradfordwoods, Pennsylvania',5246,44);
INSERT INTO "django_geo_db_city" VALUES(4211,'Bridgeville','Bridgeville, Pennsylvania',5247,44);
INSERT INTO "django_geo_db_city" VALUES(4212,'Buena Vista','Buena Vista, Pennsylvania',5248,44);
INSERT INTO "django_geo_db_city" VALUES(4213,'Bulger','Bulger, Pennsylvania',5249,44);
INSERT INTO "django_geo_db_city" VALUES(4214,'Bunola','Bunola, Pennsylvania',5250,44);
INSERT INTO "django_geo_db_city" VALUES(4215,'Burgettstown','Burgettstown, Pennsylvania',5251,44);
INSERT INTO "django_geo_db_city" VALUES(4216,'Charleroi','Charleroi, Pennsylvania',5252,44);
INSERT INTO "django_geo_db_city" VALUES(4217,'Cheswick','Cheswick, Pennsylvania',5253,44);
INSERT INTO "django_geo_db_city" VALUES(4218,'Clairton','Clairton, Pennsylvania',5254,44);
INSERT INTO "django_geo_db_city" VALUES(4219,'Clinton','Clinton, Pennsylvania',5255,44);
INSERT INTO "django_geo_db_city" VALUES(4220,'Conway','Conway, Pennsylvania',5256,44);
INSERT INTO "django_geo_db_city" VALUES(4221,'Coulters','Coulters, Pennsylvania',5257,44);
INSERT INTO "django_geo_db_city" VALUES(4222,'Creighton','Creighton, Pennsylvania',5258,44);
INSERT INTO "django_geo_db_city" VALUES(4223,'Cuddy','Cuddy, Pennsylvania',5259,44);
INSERT INTO "django_geo_db_city" VALUES(4224,'Curtisville','Curtisville, Pennsylvania',5260,44);
INSERT INTO "django_geo_db_city" VALUES(4225,'Donora','Donora, Pennsylvania',5261,44);
INSERT INTO "django_geo_db_city" VALUES(4226,'Dravosburg','Dravosburg, Pennsylvania',5262,44);
INSERT INTO "django_geo_db_city" VALUES(4227,'East McKeesport','East McKeesport, Pennsylvania',5263,44);
INSERT INTO "django_geo_db_city" VALUES(4228,'Eldersville','Eldersville, Pennsylvania',5264,44);
INSERT INTO "django_geo_db_city" VALUES(4229,'Elizabeth','Elizabeth, Pennsylvania',5265,44);
INSERT INTO "django_geo_db_city" VALUES(4230,'Elrama','Elrama, Pennsylvania',5266,44);
INSERT INTO "django_geo_db_city" VALUES(4231,'Freedom','Freedom, Pennsylvania',5267,44);
INSERT INTO "django_geo_db_city" VALUES(4232,'Georgetown','Georgetown, Pennsylvania',5268,44);
INSERT INTO "django_geo_db_city" VALUES(4233,'Gibsonia','Gibsonia, Pennsylvania',5269,44);
INSERT INTO "django_geo_db_city" VALUES(4234,'Glassport','Glassport, Pennsylvania',5270,44);
INSERT INTO "django_geo_db_city" VALUES(4235,'Crescent','Crescent, Pennsylvania',5271,44);
INSERT INTO "django_geo_db_city" VALUES(4236,'Greenock','Greenock, Pennsylvania',5260,44);
INSERT INTO "django_geo_db_city" VALUES(4237,'Harwick','Harwick, Pennsylvania',5272,44);
INSERT INTO "django_geo_db_city" VALUES(4238,'Hookstown','Hookstown, Pennsylvania',5273,44);
INSERT INTO "django_geo_db_city" VALUES(4239,'Indianola','Indianola, Pennsylvania',5274,44);
INSERT INTO "django_geo_db_city" VALUES(4240,'Industry','Industry, Pennsylvania',5275,44);
INSERT INTO "django_geo_db_city" VALUES(4241,'Joffre','Joffre, Pennsylvania',5276,44);
INSERT INTO "django_geo_db_city" VALUES(4242,'Langeloth','Langeloth, Pennsylvania',5277,44);
INSERT INTO "django_geo_db_city" VALUES(4243,'Lawrence','Lawrence, Pennsylvania',5278,44);
INSERT INTO "django_geo_db_city" VALUES(4244,'Leetsdale','Leetsdale, Pennsylvania',5279,44);
INSERT INTO "django_geo_db_city" VALUES(4245,'McDonald','McDonald, Pennsylvania',5280,44);
INSERT INTO "django_geo_db_city" VALUES(4246,'Midland','Midland, Pennsylvania',5281,44);
INSERT INTO "django_geo_db_city" VALUES(4247,'Midway','Midway, Pennsylvania',5282,44);
INSERT INTO "django_geo_db_city" VALUES(4248,'Monaca','Monaca, Pennsylvania',5283,44);
INSERT INTO "django_geo_db_city" VALUES(4249,'Monessen','Monessen, Pennsylvania',5284,44);
INSERT INTO "django_geo_db_city" VALUES(4250,'Monongahela','Monongahela, Pennsylvania',5285,44);
INSERT INTO "django_geo_db_city" VALUES(4251,'Morgan','Morgan, Pennsylvania',5286,44);
INSERT INTO "django_geo_db_city" VALUES(4252,'Natrona Heights','Natrona Heights, Pennsylvania',5287,44);
INSERT INTO "django_geo_db_city" VALUES(4253,'New Brighton','New Brighton, Pennsylvania',5288,44);
INSERT INTO "django_geo_db_city" VALUES(4254,'New Eagle','New Eagle, Pennsylvania',5289,44);
INSERT INTO "django_geo_db_city" VALUES(4255,'New Kensington','New Kensington, Pennsylvania',5290,44);
INSERT INTO "django_geo_db_city" VALUES(4256,'Oakdale','Oakdale, Pennsylvania',5292,44);
INSERT INTO "django_geo_db_city" VALUES(4257,'Pricedale','Pricedale, Pennsylvania',5293,44);
INSERT INTO "django_geo_db_city" VALUES(4258,'Rochester','Rochester, Pennsylvania',5294,44);
INSERT INTO "django_geo_db_city" VALUES(4259,'Rural Ridge','Rural Ridge, Pennsylvania',5295,44);
INSERT INTO "django_geo_db_city" VALUES(4260,'Russellton','Russellton, Pennsylvania',5296,44);
INSERT INTO "django_geo_db_city" VALUES(4261,'Shippingport','Shippingport, Pennsylvania',5297,44);
INSERT INTO "django_geo_db_city" VALUES(4262,'Slovan','Slovan, Pennsylvania',5298,44);
INSERT INTO "django_geo_db_city" VALUES(4263,'South Heights','South Heights, Pennsylvania',5299,44);
INSERT INTO "django_geo_db_city" VALUES(4264,'Sturgeon','Sturgeon, Pennsylvania',5300,44);
INSERT INTO "django_geo_db_city" VALUES(4265,'Sutersville','Sutersville, Pennsylvania',5301,44);
INSERT INTO "django_geo_db_city" VALUES(4266,'Tarentum','Tarentum, Pennsylvania',5302,44);
INSERT INTO "django_geo_db_city" VALUES(4267,'Trafford','Trafford, Pennsylvania',5303,44);
INSERT INTO "django_geo_db_city" VALUES(4268,'Warrendale','Warrendale, Pennsylvania',5304,44);
INSERT INTO "django_geo_db_city" VALUES(4269,'Webster','Webster, Pennsylvania',5305,44);
INSERT INTO "django_geo_db_city" VALUES(4270,'West Elizabeth','West Elizabeth, Pennsylvania',5306,44);
INSERT INTO "django_geo_db_city" VALUES(4271,'West Newton','West Newton, Pennsylvania',5307,44);
INSERT INTO "django_geo_db_city" VALUES(4272,'Wexford','Wexford, Pennsylvania',5308,44);
INSERT INTO "django_geo_db_city" VALUES(4273,'Wildwood','Wildwood, Pennsylvania',5260,44);
INSERT INTO "django_geo_db_city" VALUES(4274,'Allison Park','Allison Park, Pennsylvania',5309,44);
INSERT INTO "django_geo_db_city" VALUES(4275,'Bethel Park','Bethel Park, Pennsylvania',5310,44);
INSERT INTO "django_geo_db_city" VALUES(4276,'Braddock','Braddock, Pennsylvania',5311,44);
INSERT INTO "django_geo_db_city" VALUES(4277,'Carnegie','Carnegie, Pennsylvania',5312,44);
INSERT INTO "django_geo_db_city" VALUES(4278,'Coraopolis','Coraopolis, Pennsylvania',5313,44);
INSERT INTO "django_geo_db_city" VALUES(4279,'Duquesne','Duquesne, Pennsylvania',5314,44);
INSERT INTO "django_geo_db_city" VALUES(4280,'East Pittsburgh','East Pittsburgh, Pennsylvania',5315,44);
INSERT INTO "django_geo_db_city" VALUES(4281,'Glenshaw','Glenshaw, Pennsylvania',5316,44);
INSERT INTO "django_geo_db_city" VALUES(4282,'Homestead','Homestead, Pennsylvania',5317,44);
INSERT INTO "django_geo_db_city" VALUES(4283,'West Mifflin','West Mifflin, Pennsylvania',5318,44);
INSERT INTO "django_geo_db_city" VALUES(4284,'Imperial','Imperial, Pennsylvania',5319,44);
INSERT INTO "django_geo_db_city" VALUES(4285,'Ingomar','Ingomar, Pennsylvania',5260,44);
INSERT INTO "django_geo_db_city" VALUES(4286,'Library','Library, Pennsylvania',5320,44);
INSERT INTO "django_geo_db_city" VALUES(4287,'McKeesport','McKeesport, Pennsylvania',5260,44);
INSERT INTO "django_geo_db_city" VALUES(4288,'McKees Rocks','McKees Rocks, Pennsylvania',5325,44);
INSERT INTO "django_geo_db_city" VALUES(4289,'North Versailles','North Versailles, Pennsylvania',5326,44);
INSERT INTO "django_geo_db_city" VALUES(4290,'Oakmont','Oakmont, Pennsylvania',5327,44);
INSERT INTO "django_geo_db_city" VALUES(4291,'Pitcairn','Pitcairn, Pennsylvania',5328,44);
INSERT INTO "django_geo_db_city" VALUES(4292,'Presto','Presto, Pennsylvania',5329,44);
INSERT INTO "django_geo_db_city" VALUES(4293,'Sewickley','Sewickley, Pennsylvania',5330,44);
INSERT INTO "django_geo_db_city" VALUES(4294,'Springdale','Springdale, Pennsylvania',5331,44);
INSERT INTO "django_geo_db_city" VALUES(4295,'Turtle Creek','Turtle Creek, Pennsylvania',5332,44);
INSERT INTO "django_geo_db_city" VALUES(4296,'Monroeville','Monroeville, Pennsylvania',5333,44);
INSERT INTO "django_geo_db_city" VALUES(4297,'Verona','Verona, Pennsylvania',5334,44);
INSERT INTO "django_geo_db_city" VALUES(4298,'Wilmerding','Wilmerding, Pennsylvania',5335,44);
INSERT INTO "django_geo_db_city" VALUES(4299,'North Apollo','North Apollo, Pennsylvania',5336,44);
INSERT INTO "django_geo_db_city" VALUES(4300,'Pittsburgh','Pittsburgh, Pennsylvania',5337,44);
INSERT INTO "django_geo_db_city" VALUES(4301,'Washington','Washington, Pennsylvania',5379,44);
INSERT INTO "django_geo_db_city" VALUES(4302,'Aleppo','Aleppo, Pennsylvania',5380,44);
INSERT INTO "django_geo_db_city" VALUES(4303,'Amity','Amity, Pennsylvania',5381,44);
INSERT INTO "django_geo_db_city" VALUES(4304,'Avella','Avella, Pennsylvania',5382,44);
INSERT INTO "django_geo_db_city" VALUES(4305,'Beallsville','Beallsville, Pennsylvania',5383,44);
INSERT INTO "django_geo_db_city" VALUES(4306,'Bentleyville','Bentleyville, Pennsylvania',5384,44);
INSERT INTO "django_geo_db_city" VALUES(4307,'Bobtown','Bobtown, Pennsylvania',5385,44);
INSERT INTO "django_geo_db_city" VALUES(4308,'Brave','Brave, Pennsylvania',5386,44);
INSERT INTO "django_geo_db_city" VALUES(4309,'Canonsburg','Canonsburg, Pennsylvania',5387,44);
INSERT INTO "django_geo_db_city" VALUES(4310,'Carmichaels','Carmichaels, Pennsylvania',5388,44);
INSERT INTO "django_geo_db_city" VALUES(4311,'Cecil','Cecil, Pennsylvania',5389,44);
INSERT INTO "django_geo_db_city" VALUES(4312,'Clarksville','Clarksville, Pennsylvania',5390,44);
INSERT INTO "django_geo_db_city" VALUES(4313,'Claysville','Claysville, Pennsylvania',5391,44);
INSERT INTO "django_geo_db_city" VALUES(4314,'Cokeburg','Cokeburg, Pennsylvania',5392,44);
INSERT INTO "django_geo_db_city" VALUES(4315,'Crucible','Crucible, Pennsylvania',5393,44);
INSERT INTO "django_geo_db_city" VALUES(4316,'Dilliner','Dilliner, Pennsylvania',5394,44);
INSERT INTO "django_geo_db_city" VALUES(4317,'Prosperity','Prosperity, Pennsylvania',5395,44);
INSERT INTO "django_geo_db_city" VALUES(4318,'Eighty Four','Eighty Four, Pennsylvania',5396,44);
INSERT INTO "django_geo_db_city" VALUES(4319,'Ellsworth','Ellsworth, Pennsylvania',5397,44);
INSERT INTO "django_geo_db_city" VALUES(4320,'Finleyville','Finleyville, Pennsylvania',5398,44);
INSERT INTO "django_geo_db_city" VALUES(4321,'Fredericktown','Fredericktown, Pennsylvania',5399,44);
INSERT INTO "django_geo_db_city" VALUES(4322,'Garards Fort','Garards Fort, Pennsylvania',5400,44);
INSERT INTO "django_geo_db_city" VALUES(4323,'Gastonville','Gastonville, Pennsylvania',5401,44);
INSERT INTO "django_geo_db_city" VALUES(4324,'Graysville','Graysville, Pennsylvania',5402,44);
INSERT INTO "django_geo_db_city" VALUES(4325,'Greensboro','Greensboro, Pennsylvania',5403,44);
INSERT INTO "django_geo_db_city" VALUES(4326,'Hendersonville','Hendersonville, Pennsylvania',5404,44);
INSERT INTO "django_geo_db_city" VALUES(4327,'Hickory','Hickory, Pennsylvania',5405,44);
INSERT INTO "django_geo_db_city" VALUES(4328,'Holbrook','Holbrook, Pennsylvania',5406,44);
INSERT INTO "django_geo_db_city" VALUES(4329,'Houston','Houston, Pennsylvania',5407,44);
INSERT INTO "django_geo_db_city" VALUES(4330,'Jefferson','Jefferson, Pennsylvania',5408,44);
INSERT INTO "django_geo_db_city" VALUES(4331,'Marianna','Marianna, Pennsylvania',5409,44);
INSERT INTO "django_geo_db_city" VALUES(4332,'Mather','Mather, Pennsylvania',5410,44);
INSERT INTO "django_geo_db_city" VALUES(4333,'Meadow Lands','Meadow Lands, Pennsylvania',5411,44);
INSERT INTO "django_geo_db_city" VALUES(4334,'Millsboro','Millsboro, Pennsylvania',5412,44);
INSERT INTO "django_geo_db_city" VALUES(4335,'Mount Morris','Mount Morris, Pennsylvania',5413,44);
INSERT INTO "django_geo_db_city" VALUES(4336,'Muse','Muse, Pennsylvania',5414,44);
INSERT INTO "django_geo_db_city" VALUES(4337,'Nemacolin','Nemacolin, Pennsylvania',5415,44);
INSERT INTO "django_geo_db_city" VALUES(4338,'New Freeport','New Freeport, Pennsylvania',5416,44);
INSERT INTO "django_geo_db_city" VALUES(4339,'Nineveh','Nineveh, Pennsylvania',5417,44);
INSERT INTO "django_geo_db_city" VALUES(4340,'Pine Bank','Pine Bank, Pennsylvania',5418,44);
INSERT INTO "django_geo_db_city" VALUES(4341,'Centerville','Centerville, Pennsylvania',5419,44);
INSERT INTO "django_geo_db_city" VALUES(4342,'Rices Landing','Rices Landing, Pennsylvania',5420,44);
INSERT INTO "django_geo_db_city" VALUES(4343,'Richeyville','Richeyville, Pennsylvania',5421,44);
INSERT INTO "django_geo_db_city" VALUES(4344,'Rogersville','Rogersville, Pennsylvania',5422,44);
INSERT INTO "django_geo_db_city" VALUES(4345,'Scenery Hill','Scenery Hill, Pennsylvania',5423,44);
INSERT INTO "django_geo_db_city" VALUES(4346,'Southview','Southview, Pennsylvania',5424,44);
INSERT INTO "django_geo_db_city" VALUES(4347,'Spraggs','Spraggs, Pennsylvania',5425,44);
INSERT INTO "django_geo_db_city" VALUES(4348,'Strabane','Strabane, Pennsylvania',5426,44);
INSERT INTO "django_geo_db_city" VALUES(4349,'Sycamore','Sycamore, Pennsylvania',5427,44);
INSERT INTO "django_geo_db_city" VALUES(4350,'Taylorstown','Taylorstown, Pennsylvania',5428,44);
INSERT INTO "django_geo_db_city" VALUES(4351,'Van Voorhis','Van Voorhis, Pennsylvania',5429,44);
INSERT INTO "django_geo_db_city" VALUES(4352,'Venetia','Venetia, Pennsylvania',5430,44);
INSERT INTO "django_geo_db_city" VALUES(4353,'Vestaburg','Vestaburg, Pennsylvania',5431,44);
INSERT INTO "django_geo_db_city" VALUES(4354,'Waynesburg','Waynesburg, Pennsylvania',5432,44);
INSERT INTO "django_geo_db_city" VALUES(4355,'West Alexander','West Alexander, Pennsylvania',5433,44);
INSERT INTO "django_geo_db_city" VALUES(4356,'West Finley','West Finley, Pennsylvania',5434,44);
INSERT INTO "django_geo_db_city" VALUES(4357,'Westland','Westland, Pennsylvania',5435,44);
INSERT INTO "django_geo_db_city" VALUES(4358,'West Middletown','West Middletown, Pennsylvania',5436,44);
INSERT INTO "django_geo_db_city" VALUES(4359,'Wind Ridge','Wind Ridge, Pennsylvania',5437,44);
INSERT INTO "django_geo_db_city" VALUES(4360,'Uniontown','Uniontown, Pennsylvania',5438,44);
INSERT INTO "django_geo_db_city" VALUES(4361,'Adah','Adah, Pennsylvania',5439,44);
INSERT INTO "django_geo_db_city" VALUES(4362,'Addison','Addison, Pennsylvania',5440,44);
INSERT INTO "django_geo_db_city" VALUES(4363,'Allenport','Allenport, Pennsylvania',5441,44);
INSERT INTO "django_geo_db_city" VALUES(4364,'Allison','Allison, Pennsylvania',5442,44);
INSERT INTO "django_geo_db_city" VALUES(4365,'Brier Hill','Brier Hill, Pennsylvania',5443,44);
INSERT INTO "django_geo_db_city" VALUES(4366,'Brownfield','Brownfield, Pennsylvania',5444,44);
INSERT INTO "django_geo_db_city" VALUES(4367,'Brownsville','Brownsville, Pennsylvania',5445,44);
INSERT INTO "django_geo_db_city" VALUES(4368,'California','California, Pennsylvania',5446,44);
INSERT INTO "django_geo_db_city" VALUES(4369,'Cardale','Cardale, Pennsylvania',5447,44);
INSERT INTO "django_geo_db_city" VALUES(4370,'Chalk Hill','Chalk Hill, Pennsylvania',5448,44);
INSERT INTO "django_geo_db_city" VALUES(4371,'Chestnut Ridge','Chestnut Ridge, Pennsylvania',5449,44);
INSERT INTO "django_geo_db_city" VALUES(4372,'Coal Center','Coal Center, Pennsylvania',5450,44);
INSERT INTO "django_geo_db_city" VALUES(4373,'Confluence','Confluence, Pennsylvania',5451,44);
INSERT INTO "django_geo_db_city" VALUES(4374,'Connellsville','Connellsville, Pennsylvania',5452,44);
INSERT INTO "django_geo_db_city" VALUES(4375,'Daisytown','Daisytown, Pennsylvania',5453,44);
INSERT INTO "django_geo_db_city" VALUES(4376,'Dawson','Dawson, Pennsylvania',5454,44);
INSERT INTO "django_geo_db_city" VALUES(4377,'Denbo','Denbo, Pennsylvania',5455,44);
INSERT INTO "django_geo_db_city" VALUES(4378,'Dickerson Run','Dickerson Run, Pennsylvania',5456,44);
INSERT INTO "django_geo_db_city" VALUES(4379,'Dunbar','Dunbar, Pennsylvania',5457,44);
INSERT INTO "django_geo_db_city" VALUES(4380,'Dunlevy','Dunlevy, Pennsylvania',5458,44);
INSERT INTO "django_geo_db_city" VALUES(4381,'East Millsboro','East Millsboro, Pennsylvania',5459,44);
INSERT INTO "django_geo_db_city" VALUES(4382,'Elco','Elco, Pennsylvania',5460,44);
INSERT INTO "django_geo_db_city" VALUES(4383,'Fairbank','Fairbank, Pennsylvania',5461,44);
INSERT INTO "django_geo_db_city" VALUES(4384,'Fairchance','Fairchance, Pennsylvania',5462,44);
INSERT INTO "django_geo_db_city" VALUES(4385,'Farmington','Farmington, Pennsylvania',5463,44);
INSERT INTO "django_geo_db_city" VALUES(4386,'Fayette City','Fayette City, Pennsylvania',5464,44);
INSERT INTO "django_geo_db_city" VALUES(4387,'Gans','Gans, Pennsylvania',5465,44);
INSERT INTO "django_geo_db_city" VALUES(4388,'Gibbon Glade','Gibbon Glade, Pennsylvania',5466,44);
INSERT INTO "django_geo_db_city" VALUES(4389,'Grindstone','Grindstone, Pennsylvania',5467,44);
INSERT INTO "django_geo_db_city" VALUES(4390,'Hibbs','Hibbs, Pennsylvania',5468,44);
INSERT INTO "django_geo_db_city" VALUES(4391,'Hiller','Hiller, Pennsylvania',5469,44);
INSERT INTO "django_geo_db_city" VALUES(4392,'Hopwood','Hopwood, Pennsylvania',5470,44);
INSERT INTO "django_geo_db_city" VALUES(4393,'Indian Head','Indian Head, Pennsylvania',5471,44);
INSERT INTO "django_geo_db_city" VALUES(4394,'Isabella','Isabella, Pennsylvania',5472,44);
INSERT INTO "django_geo_db_city" VALUES(4395,'Jacobs Creek','Jacobs Creek, Pennsylvania',5473,44);
INSERT INTO "django_geo_db_city" VALUES(4396,'Keisterville','Keisterville, Pennsylvania',5474,44);
INSERT INTO "django_geo_db_city" VALUES(4397,'La Belle','La Belle, Pennsylvania',5475,44);
INSERT INTO "django_geo_db_city" VALUES(4398,'Lake Lynn','Lake Lynn, Pennsylvania',5476,44);
INSERT INTO "django_geo_db_city" VALUES(4399,'Leckrone','Leckrone, Pennsylvania',5477,44);
INSERT INTO "django_geo_db_city" VALUES(4400,'Leisenring','Leisenring, Pennsylvania',5478,44);
INSERT INTO "django_geo_db_city" VALUES(4401,'Lemont Furnace','Lemont Furnace, Pennsylvania',5479,44);
INSERT INTO "django_geo_db_city" VALUES(4402,'McClellandtown','McClellandtown, Pennsylvania',5480,44);
INSERT INTO "django_geo_db_city" VALUES(4403,'Markleysburg','Markleysburg, Pennsylvania',5481,44);
INSERT INTO "django_geo_db_city" VALUES(4404,'Martin','Martin, Pennsylvania',5482,44);
INSERT INTO "django_geo_db_city" VALUES(4405,'Masontown','Masontown, Pennsylvania',5483,44);
INSERT INTO "django_geo_db_city" VALUES(4406,'Melcroft','Melcroft, Pennsylvania',5484,44);
INSERT INTO "django_geo_db_city" VALUES(4407,'Merrittstown','Merrittstown, Pennsylvania',5485,44);
INSERT INTO "django_geo_db_city" VALUES(4408,'Mill Run','Mill Run, Pennsylvania',5486,44);
INSERT INTO "django_geo_db_city" VALUES(4409,'Mount Braddock','Mount Braddock, Pennsylvania',5444,44);
INSERT INTO "django_geo_db_city" VALUES(4410,'Newell','Newell, Pennsylvania',5487,44);
INSERT INTO "django_geo_db_city" VALUES(4411,'New Geneva','New Geneva, Pennsylvania',5444,44);
INSERT INTO "django_geo_db_city" VALUES(4412,'New Salem','New Salem, Pennsylvania',5488,44);
INSERT INTO "django_geo_db_city" VALUES(4413,'Normalville','Normalville, Pennsylvania',5489,44);
INSERT INTO "django_geo_db_city" VALUES(4414,'Ohiopyle','Ohiopyle, Pennsylvania',5490,44);
INSERT INTO "django_geo_db_city" VALUES(4415,'German','German, Pennsylvania',5491,44);
INSERT INTO "django_geo_db_city" VALUES(4416,'Oliver','Oliver, Pennsylvania',5492,44);
INSERT INTO "django_geo_db_city" VALUES(4417,'Perryopolis','Perryopolis, Pennsylvania',5493,44);
INSERT INTO "django_geo_db_city" VALUES(4418,'Point Marion','Point Marion, Pennsylvania',5494,44);
INSERT INTO "django_geo_db_city" VALUES(4419,'Republic','Republic, Pennsylvania',5495,44);
INSERT INTO "django_geo_db_city" VALUES(4420,'Ronco','Ronco, Pennsylvania',5496,44);
INSERT INTO "django_geo_db_city" VALUES(4421,'Roscoe','Roscoe, Pennsylvania',5497,44);
INSERT INTO "django_geo_db_city" VALUES(4422,'Smithfield','Smithfield, Pennsylvania',5498,44);
INSERT INTO "django_geo_db_city" VALUES(4423,'Smithton','Smithton, Pennsylvania',5499,44);
INSERT INTO "django_geo_db_city" VALUES(4424,'Smock','Smock, Pennsylvania',5500,44);
INSERT INTO "django_geo_db_city" VALUES(4425,'Star Junction','Star Junction, Pennsylvania',5501,44);
INSERT INTO "django_geo_db_city" VALUES(4426,'Stockdale','Stockdale, Pennsylvania',5502,44);
INSERT INTO "django_geo_db_city" VALUES(4427,'Uledi','Uledi, Pennsylvania',5503,44);
INSERT INTO "django_geo_db_city" VALUES(4428,'Ursina','Ursina, Pennsylvania',5504,44);
INSERT INTO "django_geo_db_city" VALUES(4429,'Vanderbilt','Vanderbilt, Pennsylvania',5505,44);
INSERT INTO "django_geo_db_city" VALUES(4430,'Waltersburg','Waltersburg, Pennsylvania',5506,44);
INSERT INTO "django_geo_db_city" VALUES(4431,'West Leisenring','West Leisenring, Pennsylvania',5507,44);
INSERT INTO "django_geo_db_city" VALUES(4432,'White','White, Pennsylvania',5508,44);
INSERT INTO "django_geo_db_city" VALUES(4433,'Wickhaven','Wickhaven, Pennsylvania',5509,44);
INSERT INTO "django_geo_db_city" VALUES(4434,'Perry','Perry, Pennsylvania',5510,44);
INSERT INTO "django_geo_db_city" VALUES(4435,'Somerset','Somerset, Pennsylvania',5511,44);
INSERT INTO "django_geo_db_city" VALUES(4436,'Hidden Valley','Hidden Valley, Pennsylvania',5512,44);
INSERT INTO "django_geo_db_city" VALUES(4437,'Acosta','Acosta, Pennsylvania',5514,44);
INSERT INTO "django_geo_db_city" VALUES(4438,'Alum Bank','Alum Bank, Pennsylvania',5515,44);
INSERT INTO "django_geo_db_city" VALUES(4439,'Bedford','Bedford, Pennsylvania',5516,44);
INSERT INTO "django_geo_db_city" VALUES(4440,'Berlin','Berlin, Pennsylvania',5517,44);
INSERT INTO "django_geo_db_city" VALUES(4441,'Boswell','Boswell, Pennsylvania',5518,44);
INSERT INTO "django_geo_db_city" VALUES(4442,'Boynton','Boynton, Pennsylvania',5519,44);
INSERT INTO "django_geo_db_city" VALUES(4443,'Breezewood','Breezewood, Pennsylvania',5520,44);
INSERT INTO "django_geo_db_city" VALUES(4444,'Buffalo Mills','Buffalo Mills, Pennsylvania',5521,44);
INSERT INTO "django_geo_db_city" VALUES(4445,'Clearville','Clearville, Pennsylvania',5522,44);
INSERT INTO "django_geo_db_city" VALUES(4446,'Crystal Spring','Crystal Spring, Pennsylvania',5523,44);
INSERT INTO "django_geo_db_city" VALUES(4447,'Everett','Everett, Pennsylvania',5524,44);
INSERT INTO "django_geo_db_city" VALUES(4448,'Fairhope','Fairhope, Pennsylvania',5525,44);
INSERT INTO "django_geo_db_city" VALUES(4449,'Fishertown','Fishertown, Pennsylvania',5526,44);
INSERT INTO "django_geo_db_city" VALUES(4450,'Fort Hill','Fort Hill, Pennsylvania',5527,44);
INSERT INTO "django_geo_db_city" VALUES(4451,'Friedens','Friedens, Pennsylvania',5528,44);
INSERT INTO "django_geo_db_city" VALUES(4452,'Garrett','Garrett, Pennsylvania',5529,44);
INSERT INTO "django_geo_db_city" VALUES(4453,'Gray','Gray, Pennsylvania',5530,44);
INSERT INTO "django_geo_db_city" VALUES(4454,'Hyndman','Hyndman, Pennsylvania',5531,44);
INSERT INTO "django_geo_db_city" VALUES(4455,'Jenners','Jenners, Pennsylvania',5532,44);
INSERT INTO "django_geo_db_city" VALUES(4456,'Jennerstown','Jennerstown, Pennsylvania',5533,44);
INSERT INTO "django_geo_db_city" VALUES(4457,'Kantner','Kantner, Pennsylvania',5534,44);
INSERT INTO "django_geo_db_city" VALUES(4458,'Listie','Listie, Pennsylvania',5535,44);
INSERT INTO "django_geo_db_city" VALUES(4459,'Manns Choice','Manns Choice, Pennsylvania',5536,44);
INSERT INTO "django_geo_db_city" VALUES(4460,'Markleton','Markleton, Pennsylvania',5537,44);
INSERT INTO "django_geo_db_city" VALUES(4461,'Meyersdale','Meyersdale, Pennsylvania',5538,44);
INSERT INTO "django_geo_db_city" VALUES(4462,'New Baltimore','New Baltimore, Pennsylvania',5539,44);
INSERT INTO "django_geo_db_city" VALUES(4463,'New Paris','New Paris, Pennsylvania',5540,44);
INSERT INTO "django_geo_db_city" VALUES(4464,'Quecreek','Quecreek, Pennsylvania',5541,44);
INSERT INTO "django_geo_db_city" VALUES(4465,'Rockwood','Rockwood, Pennsylvania',5542,44);
INSERT INTO "django_geo_db_city" VALUES(4466,'Salisbury','Salisbury, Pennsylvania',5543,44);
INSERT INTO "django_geo_db_city" VALUES(4467,'Schellsburg','Schellsburg, Pennsylvania',5544,44);
INSERT INTO "django_geo_db_city" VALUES(4468,'Shanksville','Shanksville, Pennsylvania',5545,44);
INSERT INTO "django_geo_db_city" VALUES(4469,'Sipesville','Sipesville, Pennsylvania',5546,44);
INSERT INTO "django_geo_db_city" VALUES(4470,'Springs','Springs, Pennsylvania',5547,44);
INSERT INTO "django_geo_db_city" VALUES(4471,'Stoystown','Stoystown, Pennsylvania',5548,44);
INSERT INTO "django_geo_db_city" VALUES(4472,'Wellersburg','Wellersburg, Pennsylvania',5549,44);
INSERT INTO "django_geo_db_city" VALUES(4473,'West Salisbury','West Salisbury, Pennsylvania',5550,44);
INSERT INTO "django_geo_db_city" VALUES(4474,'Greensburg','Greensburg, Pennsylvania',5551,44);
INSERT INTO "django_geo_db_city" VALUES(4475,'Acme','Acme, Pennsylvania',5552,44);
INSERT INTO "django_geo_db_city" VALUES(4476,'Adamsburg','Adamsburg, Pennsylvania',5553,44);
INSERT INTO "django_geo_db_city" VALUES(4477,'Alverton','Alverton, Pennsylvania',5554,44);
INSERT INTO "django_geo_db_city" VALUES(4478,'Apollo','Apollo, Pennsylvania',5555,44);
INSERT INTO "django_geo_db_city" VALUES(4479,'Ardara','Ardara, Pennsylvania',5556,44);
INSERT INTO "django_geo_db_city" VALUES(4480,'Armbrust','Armbrust, Pennsylvania',5291,44);
INSERT INTO "django_geo_db_city" VALUES(4481,'Arona','Arona, Pennsylvania',5557,44);
INSERT INTO "django_geo_db_city" VALUES(4482,'Avonmore','Avonmore, Pennsylvania',5558,44);
INSERT INTO "django_geo_db_city" VALUES(4483,'Bovard','Bovard, Pennsylvania',5291,44);
INSERT INTO "django_geo_db_city" VALUES(4484,'Bradenville','Bradenville, Pennsylvania',5559,44);
INSERT INTO "django_geo_db_city" VALUES(4485,'Calumet','Calumet, Pennsylvania',5291,44);
INSERT INTO "django_geo_db_city" VALUES(4486,'Champion','Champion, Pennsylvania',5560,44);
INSERT INTO "django_geo_db_city" VALUES(4487,'Claridge','Claridge, Pennsylvania',5561,44);
INSERT INTO "django_geo_db_city" VALUES(4488,'Crabtree','Crabtree, Pennsylvania',5562,44);
INSERT INTO "django_geo_db_city" VALUES(4489,'Darragh','Darragh, Pennsylvania',5563,44);
INSERT INTO "django_geo_db_city" VALUES(4490,'Delmont','Delmont, Pennsylvania',5564,44);
INSERT INTO "django_geo_db_city" VALUES(4491,'Derry','Derry, Pennsylvania',5565,44);
INSERT INTO "django_geo_db_city" VALUES(4492,'Donegal','Donegal, Pennsylvania',5566,44);
INSERT INTO "django_geo_db_city" VALUES(4493,'East Vandergrift','East Vandergrift, Pennsylvania',5567,44);
INSERT INTO "django_geo_db_city" VALUES(4494,'Edmon','Edmon, Pennsylvania',5568,44);
INSERT INTO "django_geo_db_city" VALUES(4495,'Everson','Everson, Pennsylvania',5569,44);
INSERT INTO "django_geo_db_city" VALUES(4496,'Export','Export, Pennsylvania',5570,44);
INSERT INTO "django_geo_db_city" VALUES(4497,'Forbes Road','Forbes Road, Pennsylvania',5571,44);
INSERT INTO "django_geo_db_city" VALUES(4498,'Grapeville','Grapeville, Pennsylvania',5572,44);
INSERT INTO "django_geo_db_city" VALUES(4499,'Hannastown','Hannastown, Pennsylvania',5573,44);
INSERT INTO "django_geo_db_city" VALUES(4500,'Harrison City','Harrison City, Pennsylvania',5574,44);
INSERT INTO "django_geo_db_city" VALUES(4501,'Herminie','Herminie, Pennsylvania',5575,44);
INSERT INTO "django_geo_db_city" VALUES(4502,'Hostetter','Hostetter, Pennsylvania',5576,44);
INSERT INTO "django_geo_db_city" VALUES(4503,'Hunker','Hunker, Pennsylvania',5577,44);
INSERT INTO "django_geo_db_city" VALUES(4504,'Hutchinson','Hutchinson, Pennsylvania',5578,44);
INSERT INTO "django_geo_db_city" VALUES(4505,'Hyde Park','Hyde Park, Pennsylvania',5579,44);
INSERT INTO "django_geo_db_city" VALUES(4506,'Irwin','Irwin, Pennsylvania',5580,44);
INSERT INTO "django_geo_db_city" VALUES(4507,'Hempfield','Hempfield, Pennsylvania',5581,44);
INSERT INTO "django_geo_db_city" VALUES(4508,'Jeannette','Jeannette, Pennsylvania',5582,44);
INSERT INTO "django_geo_db_city" VALUES(4509,'Jones Mills','Jones Mills, Pennsylvania',5583,44);
INSERT INTO "django_geo_db_city" VALUES(4510,'Larimer','Larimer, Pennsylvania',5584,44);
INSERT INTO "django_geo_db_city" VALUES(4511,'Latrobe','Latrobe, Pennsylvania',5585,44);
INSERT INTO "django_geo_db_city" VALUES(4512,'Laughlintown','Laughlintown, Pennsylvania',5586,44);
INSERT INTO "django_geo_db_city" VALUES(4513,'Leechburg','Leechburg, Pennsylvania',5587,44);
INSERT INTO "django_geo_db_city" VALUES(4514,'Ligonier','Ligonier, Pennsylvania',5588,44);
INSERT INTO "django_geo_db_city" VALUES(4515,'Lowber','Lowber, Pennsylvania',5589,44);
INSERT INTO "django_geo_db_city" VALUES(4516,'Loyalhanna','Loyalhanna, Pennsylvania',5590,44);
INSERT INTO "django_geo_db_city" VALUES(4517,'Luxor','Luxor, Pennsylvania',5591,44);
INSERT INTO "django_geo_db_city" VALUES(4518,'Madison','Madison, Pennsylvania',5592,44);
INSERT INTO "django_geo_db_city" VALUES(4519,'Mammoth','Mammoth, Pennsylvania',5593,44);
INSERT INTO "django_geo_db_city" VALUES(4520,'Manor','Manor, Pennsylvania',5594,44);
INSERT INTO "django_geo_db_city" VALUES(4521,'Mount Pleasant','Mount Pleasant, Pennsylvania',5595,44);
INSERT INTO "django_geo_db_city" VALUES(4522,'Murrysville','Murrysville, Pennsylvania',5596,44);
INSERT INTO "django_geo_db_city" VALUES(4523,'New Alexandria','New Alexandria, Pennsylvania',5597,44);
INSERT INTO "django_geo_db_city" VALUES(4524,'New Derry','New Derry, Pennsylvania',5598,44);
INSERT INTO "django_geo_db_city" VALUES(4525,'New Stanton','New Stanton, Pennsylvania',5599,44);
INSERT INTO "django_geo_db_city" VALUES(4526,'Norvelt','Norvelt, Pennsylvania',5601,44);
INSERT INTO "django_geo_db_city" VALUES(4527,'Penn','Penn, Pennsylvania',5602,44);
INSERT INTO "django_geo_db_city" VALUES(4528,'Pleasant Unity','Pleasant Unity, Pennsylvania',5603,44);
INSERT INTO "django_geo_db_city" VALUES(4529,'Rector','Rector, Pennsylvania',5604,44);
INSERT INTO "django_geo_db_city" VALUES(4530,'Rillton','Rillton, Pennsylvania',5605,44);
INSERT INTO "django_geo_db_city" VALUES(4531,'Ruffs Dale','Ruffs Dale, Pennsylvania',5606,44);
INSERT INTO "django_geo_db_city" VALUES(4532,'Salina','Salina, Pennsylvania',5607,44);
INSERT INTO "django_geo_db_city" VALUES(4533,'Saltsburg','Saltsburg, Pennsylvania',5608,44);
INSERT INTO "django_geo_db_city" VALUES(4534,'Schenley','Schenley, Pennsylvania',5568,44);
INSERT INTO "django_geo_db_city" VALUES(4535,'Scottdale','Scottdale, Pennsylvania',5609,44);
INSERT INTO "django_geo_db_city" VALUES(4536,'Slickville','Slickville, Pennsylvania',5610,44);
INSERT INTO "django_geo_db_city" VALUES(4537,'Southwest','Southwest, Pennsylvania',5611,44);
INSERT INTO "django_geo_db_city" VALUES(4538,'Spring Church','Spring Church, Pennsylvania',5612,44);
INSERT INTO "django_geo_db_city" VALUES(4539,'Stahlstown','Stahlstown, Pennsylvania',5613,44);
INSERT INTO "django_geo_db_city" VALUES(4540,'Tarrs','Tarrs, Pennsylvania',5614,44);
INSERT INTO "django_geo_db_city" VALUES(4541,'United','United, Pennsylvania',5615,44);
INSERT INTO "django_geo_db_city" VALUES(4542,'Vandergrift','Vandergrift, Pennsylvania',5616,44);
INSERT INTO "django_geo_db_city" VALUES(4543,'Wendel','Wendel, Pennsylvania',5617,44);
INSERT INTO "django_geo_db_city" VALUES(4544,'Westmoreland City','Westmoreland City, Pennsylvania',5618,44);
INSERT INTO "django_geo_db_city" VALUES(4545,'Whitney','Whitney, Pennsylvania',5619,44);
INSERT INTO "django_geo_db_city" VALUES(4546,'Wyano','Wyano, Pennsylvania',5620,44);
INSERT INTO "django_geo_db_city" VALUES(4547,'Youngstown','Youngstown, Pennsylvania',5621,44);
INSERT INTO "django_geo_db_city" VALUES(4548,'Youngwood','Youngwood, Pennsylvania',5622,44);
INSERT INTO "django_geo_db_city" VALUES(4549,'Yukon','Yukon, Pennsylvania',5623,44);
INSERT INTO "django_geo_db_city" VALUES(4550,'Indiana','Indiana, Pennsylvania',5624,44);
INSERT INTO "django_geo_db_city" VALUES(4551,'Alverda','Alverda, Pennsylvania',5626,44);
INSERT INTO "django_geo_db_city" VALUES(4552,'Anita','Anita, Pennsylvania',5627,44);
INSERT INTO "django_geo_db_city" VALUES(4553,'Arcadia','Arcadia, Pennsylvania',5628,44);
INSERT INTO "django_geo_db_city" VALUES(4554,'Aultman','Aultman, Pennsylvania',5629,44);
INSERT INTO "django_geo_db_city" VALUES(4555,'Barnesboro','Barnesboro, Pennsylvania',5630,44);
INSERT INTO "django_geo_db_city" VALUES(4556,'Big Run','Big Run, Pennsylvania',5631,44);
INSERT INTO "django_geo_db_city" VALUES(4557,'Black Lick','Black Lick, Pennsylvania',5632,44);
INSERT INTO "django_geo_db_city" VALUES(4558,'Blairsville','Blairsville, Pennsylvania',5633,44);
INSERT INTO "django_geo_db_city" VALUES(4559,'Brush Valley','Brush Valley, Pennsylvania',5634,44);
INSERT INTO "django_geo_db_city" VALUES(4560,'Burnside','Burnside, Pennsylvania',5635,44);
INSERT INTO "django_geo_db_city" VALUES(4561,'Carrolltown','Carrolltown, Pennsylvania',5636,44);
INSERT INTO "django_geo_db_city" VALUES(4562,'Chambersville','Chambersville, Pennsylvania',5637,44);
INSERT INTO "django_geo_db_city" VALUES(4563,'Cherry Tree','Cherry Tree, Pennsylvania',5638,44);
INSERT INTO "django_geo_db_city" VALUES(4564,'Clarksburg','Clarksburg, Pennsylvania',5639,44);
INSERT INTO "django_geo_db_city" VALUES(4565,'Clune','Clune, Pennsylvania',5640,44);
INSERT INTO "django_geo_db_city" VALUES(4566,'Clymer','Clymer, Pennsylvania',5641,44);
INSERT INTO "django_geo_db_city" VALUES(4567,'Commodore','Commodore, Pennsylvania',5642,44);
INSERT INTO "django_geo_db_city" VALUES(4568,'Coolspring','Coolspring, Pennsylvania',5643,44);
INSERT INTO "django_geo_db_city" VALUES(4569,'Coral','Coral, Pennsylvania',5644,44);
INSERT INTO "django_geo_db_city" VALUES(4570,'Creekside','Creekside, Pennsylvania',5645,44);
INSERT INTO "django_geo_db_city" VALUES(4571,'De Lancey','De Lancey, Pennsylvania',5646,44);
INSERT INTO "django_geo_db_city" VALUES(4572,'Dixonville','Dixonville, Pennsylvania',5647,44);
INSERT INTO "django_geo_db_city" VALUES(4573,'Elderton','Elderton, Pennsylvania',5648,44);
INSERT INTO "django_geo_db_city" VALUES(4574,'Elmora','Elmora, Pennsylvania',5649,44);
INSERT INTO "django_geo_db_city" VALUES(4575,'Emeigh','Emeigh, Pennsylvania',5650,44);
INSERT INTO "django_geo_db_city" VALUES(4576,'Ernest','Ernest, Pennsylvania',5651,44);
INSERT INTO "django_geo_db_city" VALUES(4577,'Frostburg','Frostburg, Pennsylvania',5652,44);
INSERT INTO "django_geo_db_city" VALUES(4578,'Gipsy','Gipsy, Pennsylvania',5653,44);
INSERT INTO "django_geo_db_city" VALUES(4579,'Glen Campbell','Glen Campbell, Pennsylvania',5654,44);
INSERT INTO "django_geo_db_city" VALUES(4580,'Hamilton','Hamilton, Pennsylvania',5655,44);
INSERT INTO "django_geo_db_city" VALUES(4581,'Heilwood','Heilwood, Pennsylvania',5656,44);
INSERT INTO "django_geo_db_city" VALUES(4582,'Hillsdale','Hillsdale, Pennsylvania',5657,44);
INSERT INTO "django_geo_db_city" VALUES(4583,'Home','Home, Pennsylvania',5658,44);
INSERT INTO "django_geo_db_city" VALUES(4584,'Homer City','Homer City, Pennsylvania',5659,44);
INSERT INTO "django_geo_db_city" VALUES(4585,'Josephine','Josephine, Pennsylvania',5660,44);
INSERT INTO "django_geo_db_city" VALUES(4586,'Juneau','Juneau, Pennsylvania',5625,44);
INSERT INTO "django_geo_db_city" VALUES(4587,'Kent','Kent, Pennsylvania',5661,44);
INSERT INTO "django_geo_db_city" VALUES(4588,'La Jose','La Jose, Pennsylvania',5662,44);
INSERT INTO "django_geo_db_city" VALUES(4589,'Lucernemines','Lucernemines, Pennsylvania',5663,44);
INSERT INTO "django_geo_db_city" VALUES(4590,'McIntyre','McIntyre, Pennsylvania',5664,44);
INSERT INTO "django_geo_db_city" VALUES(4591,'Mahaffey','Mahaffey, Pennsylvania',5665,44);
INSERT INTO "django_geo_db_city" VALUES(4592,'Marchand','Marchand, Pennsylvania',5625,44);
INSERT INTO "django_geo_db_city" VALUES(4593,'Marion Center','Marion Center, Pennsylvania',5666,44);
INSERT INTO "django_geo_db_city" VALUES(4594,'Marsteller','Marsteller, Pennsylvania',5667,44);
INSERT INTO "django_geo_db_city" VALUES(4595,'Mentcle','Mentcle, Pennsylvania',5668,44);
INSERT INTO "django_geo_db_city" VALUES(4596,'Nicktown','Nicktown, Pennsylvania',5669,44);
INSERT INTO "django_geo_db_city" VALUES(4597,'Northpoint','Northpoint, Pennsylvania',5670,44);
INSERT INTO "django_geo_db_city" VALUES(4598,'Oliveburg','Oliveburg, Pennsylvania',5671,44);
INSERT INTO "django_geo_db_city" VALUES(4599,'Penn Run','Penn Run, Pennsylvania',5672,44);
INSERT INTO "django_geo_db_city" VALUES(4600,'Punxsutawney','Punxsutawney, Pennsylvania',5673,44);
INSERT INTO "django_geo_db_city" VALUES(4601,'Ringgold','Ringgold, Pennsylvania',5674,44);
INSERT INTO "django_geo_db_city" VALUES(4602,'Rochester Mills','Rochester Mills, Pennsylvania',5675,44);
INSERT INTO "django_geo_db_city" VALUES(4603,'Rossiter','Rossiter, Pennsylvania',5676,44);
INSERT INTO "django_geo_db_city" VALUES(4604,'Saint Benedict','Saint Benedict, Pennsylvania',5677,44);
INSERT INTO "django_geo_db_city" VALUES(4605,'Shelocta','Shelocta, Pennsylvania',5678,44);
INSERT INTO "django_geo_db_city" VALUES(4606,'Spangler','Spangler, Pennsylvania',5679,44);
INSERT INTO "django_geo_db_city" VALUES(4607,'Sprankle Mills','Sprankle Mills, Pennsylvania',5680,44);
INSERT INTO "django_geo_db_city" VALUES(4608,'Starford','Starford, Pennsylvania',5681,44);
INSERT INTO "django_geo_db_city" VALUES(4609,'Timblin','Timblin, Pennsylvania',5682,44);
INSERT INTO "django_geo_db_city" VALUES(4610,'Torrance','Torrance, Pennsylvania',5683,44);
INSERT INTO "django_geo_db_city" VALUES(4611,'Valier','Valier, Pennsylvania',5684,44);
INSERT INTO "django_geo_db_city" VALUES(4612,'Walston','Walston, Pennsylvania',5685,44);
INSERT INTO "django_geo_db_city" VALUES(4613,'West Lebanon','West Lebanon, Pennsylvania',5686,44);
INSERT INTO "django_geo_db_city" VALUES(4614,'Worthville','Worthville, Pennsylvania',5687,44);
INSERT INTO "django_geo_db_city" VALUES(4615,'Du Bois','Du Bois, Pennsylvania',5688,44);
INSERT INTO "django_geo_db_city" VALUES(4616,'South Fayette','South Fayette, Pennsylvania',5689,44);
INSERT INTO "django_geo_db_city" VALUES(4617,'Benezett','Benezett, Pennsylvania',5690,44);
INSERT INTO "django_geo_db_city" VALUES(4618,'Brandy Camp','Brandy Camp, Pennsylvania',5691,44);
INSERT INTO "django_geo_db_city" VALUES(4619,'Brockport','Brockport, Pennsylvania',5692,44);
INSERT INTO "django_geo_db_city" VALUES(4620,'Brockway','Brockway, Pennsylvania',5693,44);
INSERT INTO "django_geo_db_city" VALUES(4621,'Brookville','Brookville, Pennsylvania',5694,44);
INSERT INTO "django_geo_db_city" VALUES(4622,'Byrnedale','Byrnedale, Pennsylvania',5695,44);
INSERT INTO "django_geo_db_city" VALUES(4623,'Clarington','Clarington, Pennsylvania',5696,44);
INSERT INTO "django_geo_db_city" VALUES(4624,'Corsica','Corsica, Pennsylvania',5697,44);
INSERT INTO "django_geo_db_city" VALUES(4625,'Dagus Mines','Dagus Mines, Pennsylvania',5698,44);
INSERT INTO "django_geo_db_city" VALUES(4626,'Driftwood','Driftwood, Pennsylvania',5699,44);
INSERT INTO "django_geo_db_city" VALUES(4627,'Emporium','Emporium, Pennsylvania',5700,44);
INSERT INTO "django_geo_db_city" VALUES(4628,'Falls Creek','Falls Creek, Pennsylvania',5701,44);
INSERT INTO "django_geo_db_city" VALUES(4629,'Force','Force, Pennsylvania',5702,44);
INSERT INTO "django_geo_db_city" VALUES(4630,'Johnsonburg','Johnsonburg, Pennsylvania',5703,44);
INSERT INTO "django_geo_db_city" VALUES(4631,'Kersey','Kersey, Pennsylvania',5704,44);
INSERT INTO "django_geo_db_city" VALUES(4632,'Knox Dale','Knox Dale, Pennsylvania',5705,44);
INSERT INTO "django_geo_db_city" VALUES(4633,'Luthersburg','Luthersburg, Pennsylvania',5706,44);
INSERT INTO "django_geo_db_city" VALUES(4634,'Penfield','Penfield, Pennsylvania',5707,44);
INSERT INTO "django_geo_db_city" VALUES(4635,'Reynoldsville','Reynoldsville, Pennsylvania',5708,44);
INSERT INTO "django_geo_db_city" VALUES(4636,'Ridgway','Ridgway, Pennsylvania',5709,44);
INSERT INTO "django_geo_db_city" VALUES(4637,'Rockton','Rockton, Pennsylvania',5710,44);
INSERT INTO "django_geo_db_city" VALUES(4638,'Saint Marys','Saint Marys, Pennsylvania',5711,44);
INSERT INTO "django_geo_db_city" VALUES(4639,'Sigel','Sigel, Pennsylvania',5712,44);
INSERT INTO "django_geo_db_city" VALUES(4640,'Sinnamahoning','Sinnamahoning, Pennsylvania',5713,44);
INSERT INTO "django_geo_db_city" VALUES(4641,'Stump Creek','Stump Creek, Pennsylvania',5714,44);
INSERT INTO "django_geo_db_city" VALUES(4642,'Summerville','Summerville, Pennsylvania',5715,44);
INSERT INTO "django_geo_db_city" VALUES(4643,'Sykesville','Sykesville, Pennsylvania',5716,44);
INSERT INTO "django_geo_db_city" VALUES(4644,'Troutville','Troutville, Pennsylvania',5717,44);
INSERT INTO "django_geo_db_city" VALUES(4645,'Weedville','Weedville, Pennsylvania',5718,44);
INSERT INTO "django_geo_db_city" VALUES(4646,'Wilcox','Wilcox, Pennsylvania',5719,44);
INSERT INTO "django_geo_db_city" VALUES(4647,'Johnstown','Johnstown, Pennsylvania',5721,44);
INSERT INTO "django_geo_db_city" VALUES(4648,'Armagh','Armagh, Pennsylvania',5729,44);
INSERT INTO "django_geo_db_city" VALUES(4649,'Beaverdale','Beaverdale, Pennsylvania',5730,44);
INSERT INTO "django_geo_db_city" VALUES(4650,'Belsano','Belsano, Pennsylvania',5728,44);
INSERT INTO "django_geo_db_city" VALUES(4651,'Bolivar','Bolivar, Pennsylvania',5731,44);
INSERT INTO "django_geo_db_city" VALUES(4652,'Cairnbrook','Cairnbrook, Pennsylvania',5732,44);
INSERT INTO "django_geo_db_city" VALUES(4653,'Cassandra','Cassandra, Pennsylvania',5733,44);
INSERT INTO "django_geo_db_city" VALUES(4654,'Central City','Central City, Pennsylvania',5734,44);
INSERT INTO "django_geo_db_city" VALUES(4655,'Colver','Colver, Pennsylvania',5735,44);
INSERT INTO "django_geo_db_city" VALUES(4656,'Davidsville','Davidsville, Pennsylvania',5736,44);
INSERT INTO "django_geo_db_city" VALUES(4657,'Dilltown','Dilltown, Pennsylvania',5737,44);
INSERT INTO "django_geo_db_city" VALUES(4658,'Dunlo','Dunlo, Pennsylvania',5738,44);
INSERT INTO "django_geo_db_city" VALUES(4659,'Ebensburg','Ebensburg, Pennsylvania',5739,44);
INSERT INTO "django_geo_db_city" VALUES(4660,'Elton','Elton, Pennsylvania',5740,44);
INSERT INTO "django_geo_db_city" VALUES(4661,'Hollsopple','Hollsopple, Pennsylvania',5741,44);
INSERT INTO "django_geo_db_city" VALUES(4662,'Hooversville','Hooversville, Pennsylvania',5742,44);
INSERT INTO "django_geo_db_city" VALUES(4663,'Jerome','Jerome, Pennsylvania',5743,44);
INSERT INTO "django_geo_db_city" VALUES(4664,'Lilly','Lilly, Pennsylvania',5744,44);
INSERT INTO "django_geo_db_city" VALUES(4665,'Loretto','Loretto, Pennsylvania',5745,44);
INSERT INTO "django_geo_db_city" VALUES(4666,'Mineral Point','Mineral Point, Pennsylvania',5746,44);
INSERT INTO "django_geo_db_city" VALUES(4667,'Nanty Glo','Nanty Glo, Pennsylvania',5747,44);
INSERT INTO "django_geo_db_city" VALUES(4668,'New Florence','New Florence, Pennsylvania',5748,44);
INSERT INTO "django_geo_db_city" VALUES(4669,'Parkhill','Parkhill, Pennsylvania',5749,44);
INSERT INTO "django_geo_db_city" VALUES(4670,'Portage','Portage, Pennsylvania',5750,44);
INSERT INTO "django_geo_db_city" VALUES(4671,'Revloc','Revloc, Pennsylvania',5751,44);
INSERT INTO "django_geo_db_city" VALUES(4672,'Robinson','Robinson, Pennsylvania',5752,44);
INSERT INTO "django_geo_db_city" VALUES(4673,'Saint Michael','Saint Michael, Pennsylvania',5753,44);
INSERT INTO "django_geo_db_city" VALUES(4674,'Salix','Salix, Pennsylvania',5754,44);
INSERT INTO "django_geo_db_city" VALUES(4675,'Seanor','Seanor, Pennsylvania',5755,44);
INSERT INTO "django_geo_db_city" VALUES(4676,'Seward','Seward, Pennsylvania',5756,44);
INSERT INTO "django_geo_db_city" VALUES(4677,'Sidman','Sidman, Pennsylvania',5757,44);
INSERT INTO "django_geo_db_city" VALUES(4678,'South Fork','South Fork, Pennsylvania',5758,44);
INSERT INTO "django_geo_db_city" VALUES(4679,'Strongstown','Strongstown, Pennsylvania',5759,44);
INSERT INTO "django_geo_db_city" VALUES(4680,'Summerhill','Summerhill, Pennsylvania',5760,44);
INSERT INTO "django_geo_db_city" VALUES(4681,'Tire Hill','Tire Hill, Pennsylvania',5761,44);
INSERT INTO "django_geo_db_city" VALUES(4682,'Twin Rocks','Twin Rocks, Pennsylvania',5762,44);
INSERT INTO "django_geo_db_city" VALUES(4683,'Vintondale','Vintondale, Pennsylvania',5763,44);
INSERT INTO "django_geo_db_city" VALUES(4684,'Wilmore','Wilmore, Pennsylvania',5764,44);
INSERT INTO "django_geo_db_city" VALUES(4685,'Windber','Windber, Pennsylvania',5765,44);
INSERT INTO "django_geo_db_city" VALUES(4686,'Butler','Butler, Pennsylvania',5768,44);
INSERT INTO "django_geo_db_city" VALUES(4687,'Cranberry','Cranberry, Pennsylvania',5771,44);
INSERT INTO "django_geo_db_city" VALUES(4688,'Boyers','Boyers, Pennsylvania',5770,44);
INSERT INTO "django_geo_db_city" VALUES(4689,'Branchton','Branchton, Pennsylvania',5770,44);
INSERT INTO "django_geo_db_city" VALUES(4690,'Bruin','Bruin, Pennsylvania',5773,44);
INSERT INTO "django_geo_db_city" VALUES(4691,'Cabot','Cabot, Pennsylvania',5774,44);
INSERT INTO "django_geo_db_city" VALUES(4692,'Callery','Callery, Pennsylvania',5775,44);
INSERT INTO "django_geo_db_city" VALUES(4693,'Chicora','Chicora, Pennsylvania',5776,44);
INSERT INTO "django_geo_db_city" VALUES(4694,'Connoquenessing','Connoquenessing, Pennsylvania',5777,44);
INSERT INTO "django_geo_db_city" VALUES(4695,'East Brady','East Brady, Pennsylvania',5778,44);
INSERT INTO "django_geo_db_city" VALUES(4696,'East Butler','East Butler, Pennsylvania',5779,44);
INSERT INTO "django_geo_db_city" VALUES(4697,'Eau Claire','Eau Claire, Pennsylvania',5780,44);
INSERT INTO "django_geo_db_city" VALUES(4698,'Evans City','Evans City, Pennsylvania',5781,44);
INSERT INTO "django_geo_db_city" VALUES(4699,'Fenelton','Fenelton, Pennsylvania',5782,44);
INSERT INTO "django_geo_db_city" VALUES(4700,'Forestville','Forestville, Pennsylvania',5783,44);
INSERT INTO "django_geo_db_city" VALUES(4701,'Foxburg','Foxburg, Pennsylvania',5784,44);
INSERT INTO "django_geo_db_city" VALUES(4702,'Harmony','Harmony, Pennsylvania',5785,44);
INSERT INTO "django_geo_db_city" VALUES(4703,'Harrisville','Harrisville, Pennsylvania',5786,44);
INSERT INTO "django_geo_db_city" VALUES(4704,'Herman','Herman, Pennsylvania',5770,44);
INSERT INTO "django_geo_db_city" VALUES(4705,'Hilliards','Hilliards, Pennsylvania',5787,44);
INSERT INTO "django_geo_db_city" VALUES(4706,'Karns City','Karns City, Pennsylvania',5788,44);
INSERT INTO "django_geo_db_city" VALUES(4707,'Lyndora','Lyndora, Pennsylvania',5789,44);
INSERT INTO "django_geo_db_city" VALUES(4708,'Mars','Mars, Pennsylvania',5790,44);
INSERT INTO "django_geo_db_city" VALUES(4709,'North Washington','North Washington, Pennsylvania',5791,44);
INSERT INTO "django_geo_db_city" VALUES(4710,'Parker','Parker, Pennsylvania',5792,44);
INSERT INTO "django_geo_db_city" VALUES(4711,'Petrolia','Petrolia, Pennsylvania',5793,44);
INSERT INTO "django_geo_db_city" VALUES(4712,'Portersville','Portersville, Pennsylvania',5794,44);
INSERT INTO "django_geo_db_city" VALUES(4713,'Prospect','Prospect, Pennsylvania',5795,44);
INSERT INTO "django_geo_db_city" VALUES(4714,'Renfrew','Renfrew, Pennsylvania',5796,44);
INSERT INTO "django_geo_db_city" VALUES(4715,'Saint Petersburg','Saint Petersburg, Pennsylvania',5797,44);
INSERT INTO "django_geo_db_city" VALUES(4716,'Sarver','Sarver, Pennsylvania',5798,44);
INSERT INTO "django_geo_db_city" VALUES(4717,'Saxonburg','Saxonburg, Pennsylvania',5799,44);
INSERT INTO "django_geo_db_city" VALUES(4718,'Slippery Rock','Slippery Rock, Pennsylvania',5800,44);
INSERT INTO "django_geo_db_city" VALUES(4719,'Turkey City','Turkey City, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4720,'Valencia','Valencia, Pennsylvania',5802,44);
INSERT INTO "django_geo_db_city" VALUES(4721,'West Sunbury','West Sunbury, Pennsylvania',5803,44);
INSERT INTO "django_geo_db_city" VALUES(4722,'Zelienople','Zelienople, Pennsylvania',5804,44);
INSERT INTO "django_geo_db_city" VALUES(4723,'Cranberry Twp','Cranberry Twp, Pennsylvania',5805,44);
INSERT INTO "django_geo_db_city" VALUES(4724,'New Castle','New Castle, Pennsylvania',5806,44);
INSERT INTO "django_geo_db_city" VALUES(4725,'Adamsville','Adamsville, Pennsylvania',5810,44);
INSERT INTO "django_geo_db_city" VALUES(4726,'Atlantic','Atlantic, Pennsylvania',5811,44);
INSERT INTO "django_geo_db_city" VALUES(4727,'Bessemer','Bessemer, Pennsylvania',5812,44);
INSERT INTO "django_geo_db_city" VALUES(4728,'Clark','Clark, Pennsylvania',5813,44);
INSERT INTO "django_geo_db_city" VALUES(4729,'Clarks Mills','Clarks Mills, Pennsylvania',5814,44);
INSERT INTO "django_geo_db_city" VALUES(4730,'Darlington','Darlington, Pennsylvania',5815,44);
INSERT INTO "django_geo_db_city" VALUES(4731,'Edinburg','Edinburg, Pennsylvania',5816,44);
INSERT INTO "django_geo_db_city" VALUES(4732,'Ellwood City','Ellwood City, Pennsylvania',5817,44);
INSERT INTO "django_geo_db_city" VALUES(4733,'Enon Valley','Enon Valley, Pennsylvania',5818,44);
INSERT INTO "django_geo_db_city" VALUES(4734,'Farrell','Farrell, Pennsylvania',5819,44);
INSERT INTO "django_geo_db_city" VALUES(4735,'Fombell','Fombell, Pennsylvania',5820,44);
INSERT INTO "django_geo_db_city" VALUES(4736,'Fredonia','Fredonia, Pennsylvania',5821,44);
INSERT INTO "django_geo_db_city" VALUES(4737,'Greenville','Greenville, Pennsylvania',5822,44);
INSERT INTO "django_geo_db_city" VALUES(4738,'Grove City','Grove City, Pennsylvania',5823,44);
INSERT INTO "django_geo_db_city" VALUES(4739,'Hadley','Hadley, Pennsylvania',5824,44);
INSERT INTO "django_geo_db_city" VALUES(4740,'Hartstown','Hartstown, Pennsylvania',5825,44);
INSERT INTO "django_geo_db_city" VALUES(4741,'Hillsville','Hillsville, Pennsylvania',5826,44);
INSERT INTO "django_geo_db_city" VALUES(4742,'Jackson Center','Jackson Center, Pennsylvania',5827,44);
INSERT INTO "django_geo_db_city" VALUES(4743,'Jamestown','Jamestown, Pennsylvania',5828,44);
INSERT INTO "django_geo_db_city" VALUES(4744,'Koppel','Koppel, Pennsylvania',5829,44);
INSERT INTO "django_geo_db_city" VALUES(4745,'Mercer','Mercer, Pennsylvania',5830,44);
INSERT INTO "django_geo_db_city" VALUES(4746,'New Bedford','New Bedford, Pennsylvania',5831,44);
INSERT INTO "django_geo_db_city" VALUES(4747,'New Galilee','New Galilee, Pennsylvania',5832,44);
INSERT INTO "django_geo_db_city" VALUES(4748,'New Wilmington','New Wilmington, Pennsylvania',5833,44);
INSERT INTO "django_geo_db_city" VALUES(4749,'Pulaski','Pulaski, Pennsylvania',5834,44);
INSERT INTO "django_geo_db_city" VALUES(4750,'Sandy Lake','Sandy Lake, Pennsylvania',5835,44);
INSERT INTO "django_geo_db_city" VALUES(4751,'Sharon','Sharon, Pennsylvania',5836,44);
INSERT INTO "django_geo_db_city" VALUES(4752,'Hermitage','Hermitage, Pennsylvania',5837,44);
INSERT INTO "django_geo_db_city" VALUES(4753,'Sharpsville','Sharpsville, Pennsylvania',5838,44);
INSERT INTO "django_geo_db_city" VALUES(4754,'Sheakleyville','Sheakleyville, Pennsylvania',5839,44);
INSERT INTO "django_geo_db_city" VALUES(4755,'Stoneboro','Stoneboro, Pennsylvania',5840,44);
INSERT INTO "django_geo_db_city" VALUES(4756,'Transfer','Transfer, Pennsylvania',5841,44);
INSERT INTO "django_geo_db_city" VALUES(4757,'Villa Maria','Villa Maria, Pennsylvania',5842,44);
INSERT INTO "django_geo_db_city" VALUES(4758,'Volant','Volant, Pennsylvania',5843,44);
INSERT INTO "django_geo_db_city" VALUES(4759,'Wampum','Wampum, Pennsylvania',5844,44);
INSERT INTO "django_geo_db_city" VALUES(4760,'West Middlesex','West Middlesex, Pennsylvania',5845,44);
INSERT INTO "django_geo_db_city" VALUES(4761,'West Pittsburg','West Pittsburg, Pennsylvania',5846,44);
INSERT INTO "django_geo_db_city" VALUES(4762,'Wheatland','Wheatland, Pennsylvania',5847,44);
INSERT INTO "django_geo_db_city" VALUES(4763,'Kittanning','Kittanning, Pennsylvania',5849,44);
INSERT INTO "django_geo_db_city" VALUES(4764,'Adrian','Adrian, Pennsylvania',5850,44);
INSERT INTO "django_geo_db_city" VALUES(4765,'Beyer','Beyer, Pennsylvania',5625,44);
INSERT INTO "django_geo_db_city" VALUES(4766,'Cadogan','Cadogan, Pennsylvania',5851,44);
INSERT INTO "django_geo_db_city" VALUES(4767,'Callensburg','Callensburg, Pennsylvania',5852,44);
INSERT INTO "django_geo_db_city" VALUES(4768,'Clarion','Clarion, Pennsylvania',5853,44);
INSERT INTO "django_geo_db_city" VALUES(4769,'Climax','Climax, Pennsylvania',5568,44);
INSERT INTO "django_geo_db_city" VALUES(4770,'Cooksburg','Cooksburg, Pennsylvania',5854,44);
INSERT INTO "django_geo_db_city" VALUES(4771,'Cowansville','Cowansville, Pennsylvania',5855,44);
INSERT INTO "django_geo_db_city" VALUES(4772,'Crown','Crown, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4773,'Curllsville','Curllsville, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4774,'Dayton','Dayton, Pennsylvania',5856,44);
INSERT INTO "django_geo_db_city" VALUES(4775,'Distant','Distant, Pennsylvania',5857,44);
INSERT INTO "django_geo_db_city" VALUES(4776,'Fairmount City','Fairmount City, Pennsylvania',5858,44);
INSERT INTO "django_geo_db_city" VALUES(4777,'Fisher','Fisher, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4778,'Ford City','Ford City, Pennsylvania',5859,44);
INSERT INTO "django_geo_db_city" VALUES(4779,'Ford Cliff','Ford Cliff, Pennsylvania',5860,44);
INSERT INTO "django_geo_db_city" VALUES(4780,'Freeport','Freeport, Pennsylvania',5861,44);
INSERT INTO "django_geo_db_city" VALUES(4781,'Hawthorn','Hawthorn, Pennsylvania',5862,44);
INSERT INTO "django_geo_db_city" VALUES(4782,'Knox','Knox, Pennsylvania',5863,44);
INSERT INTO "django_geo_db_city" VALUES(4783,'Leeper','Leeper, Pennsylvania',5864,44);
INSERT INTO "django_geo_db_city" VALUES(4784,'Limestone','Limestone, Pennsylvania',5865,44);
INSERT INTO "django_geo_db_city" VALUES(4785,'Lucinda','Lucinda, Pennsylvania',5866,44);
INSERT INTO "django_geo_db_city" VALUES(4786,'McGrann','McGrann, Pennsylvania',5867,44);
INSERT INTO "django_geo_db_city" VALUES(4787,'Manorville','Manorville, Pennsylvania',5868,44);
INSERT INTO "django_geo_db_city" VALUES(4788,'Marienville','Marienville, Pennsylvania',5869,44);
INSERT INTO "django_geo_db_city" VALUES(4789,'Mayport','Mayport, Pennsylvania',5870,44);
INSERT INTO "django_geo_db_city" VALUES(4790,'New Bethlehem','New Bethlehem, Pennsylvania',5871,44);
INSERT INTO "django_geo_db_city" VALUES(4791,'Nu Mine','Nu Mine, Pennsylvania',5872,44);
INSERT INTO "django_geo_db_city" VALUES(4792,'Oak Ridge','Oak Ridge, Pennsylvania',5873,44);
INSERT INTO "django_geo_db_city" VALUES(4793,'Plumville','Plumville, Pennsylvania',5874,44);
INSERT INTO "django_geo_db_city" VALUES(4794,'Rimersburg','Rimersburg, Pennsylvania',5875,44);
INSERT INTO "django_geo_db_city" VALUES(4795,'Rural Valley','Rural Valley, Pennsylvania',5876,44);
INSERT INTO "django_geo_db_city" VALUES(4796,'Sagamore','Sagamore, Pennsylvania',5877,44);
INSERT INTO "django_geo_db_city" VALUES(4797,'Seminole','Seminole, Pennsylvania',5878,44);
INSERT INTO "django_geo_db_city" VALUES(4798,'Shippenville','Shippenville, Pennsylvania',5879,44);
INSERT INTO "django_geo_db_city" VALUES(4799,'Sligo','Sligo, Pennsylvania',5880,44);
INSERT INTO "django_geo_db_city" VALUES(4800,'Smicksburg','Smicksburg, Pennsylvania',5881,44);
INSERT INTO "django_geo_db_city" VALUES(4801,'Snydersburg','Snydersburg, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4802,'Strattanville','Strattanville, Pennsylvania',5882,44);
INSERT INTO "django_geo_db_city" VALUES(4803,'Templeton','Templeton, Pennsylvania',5883,44);
INSERT INTO "django_geo_db_city" VALUES(4804,'Vowinckel','Vowinckel, Pennsylvania',5884,44);
INSERT INTO "django_geo_db_city" VALUES(4805,'Widnoon','Widnoon, Pennsylvania',5568,44);
INSERT INTO "django_geo_db_city" VALUES(4806,'Worthington','Worthington, Pennsylvania',5885,44);
INSERT INTO "django_geo_db_city" VALUES(4807,'Yatesboro','Yatesboro, Pennsylvania',5886,44);
INSERT INTO "django_geo_db_city" VALUES(4808,'South Buffalo','South Buffalo, Pennsylvania',5887,44);
INSERT INTO "django_geo_db_city" VALUES(4809,'Oil City','Oil City, Pennsylvania',5888,44);
INSERT INTO "django_geo_db_city" VALUES(4810,'Carlton','Carlton, Pennsylvania',5890,44);
INSERT INTO "django_geo_db_city" VALUES(4811,'Chandlers Valley','Chandlers Valley, Pennsylvania',5891,44);
INSERT INTO "django_geo_db_city" VALUES(4812,'Clarendon','Clarendon, Pennsylvania',5892,44);
INSERT INTO "django_geo_db_city" VALUES(4813,'Cochranton','Cochranton, Pennsylvania',5893,44);
INSERT INTO "django_geo_db_city" VALUES(4814,'Conneaut Lake','Conneaut Lake, Pennsylvania',5894,44);
INSERT INTO "django_geo_db_city" VALUES(4815,'Cooperstown','Cooperstown, Pennsylvania',5895,44);
INSERT INTO "django_geo_db_city" VALUES(4816,'East Hickory','East Hickory, Pennsylvania',5897,44);
INSERT INTO "django_geo_db_city" VALUES(4817,'Endeavor','Endeavor, Pennsylvania',5898,44);
INSERT INTO "django_geo_db_city" VALUES(4818,'Franklin','Franklin, Pennsylvania',5899,44);
INSERT INTO "django_geo_db_city" VALUES(4819,'Fryburg','Fryburg, Pennsylvania',5900,44);
INSERT INTO "django_geo_db_city" VALUES(4820,'Guys Mills','Guys Mills, Pennsylvania',5901,44);
INSERT INTO "django_geo_db_city" VALUES(4821,'Hydetown','Hydetown, Pennsylvania',5902,44);
INSERT INTO "django_geo_db_city" VALUES(4822,'Irvine','Irvine, Pennsylvania',5903,44);
INSERT INTO "django_geo_db_city" VALUES(4823,'Kossuth','Kossuth, Pennsylvania',5904,44);
INSERT INTO "django_geo_db_city" VALUES(4824,'Lickingville','Lickingville, Pennsylvania',5905,44);
INSERT INTO "django_geo_db_city" VALUES(4825,'Ludlow','Ludlow, Pennsylvania',5906,44);
INSERT INTO "django_geo_db_city" VALUES(4826,'Marble','Marble, Pennsylvania',5907,44);
INSERT INTO "django_geo_db_city" VALUES(4827,'Meadville','Meadville, Pennsylvania',5908,44);
INSERT INTO "django_geo_db_city" VALUES(4828,'Pittsfield','Pittsfield, Pennsylvania',5909,44);
INSERT INTO "django_geo_db_city" VALUES(4829,'Pleasantville','Pleasantville, Pennsylvania',5910,44);
INSERT INTO "django_geo_db_city" VALUES(4830,'Polk','Polk, Pennsylvania',5911,44);
INSERT INTO "django_geo_db_city" VALUES(4831,'Reno','Reno, Pennsylvania',5912,44);
INSERT INTO "django_geo_db_city" VALUES(4832,'Rouseville','Rouseville, Pennsylvania',5913,44);
INSERT INTO "django_geo_db_city" VALUES(4833,'Russell','Russell, Pennsylvania',5914,44);
INSERT INTO "django_geo_db_city" VALUES(4834,'Seneca','Seneca, Pennsylvania',5915,44);
INSERT INTO "django_geo_db_city" VALUES(4835,'Sheffield','Sheffield, Pennsylvania',5916,44);
INSERT INTO "django_geo_db_city" VALUES(4836,'Sugar Grove','Sugar Grove, Pennsylvania',5917,44);
INSERT INTO "django_geo_db_city" VALUES(4837,'Tidioute','Tidioute, Pennsylvania',5918,44);
INSERT INTO "django_geo_db_city" VALUES(4838,'Tiona','Tiona, Pennsylvania',5919,44);
INSERT INTO "django_geo_db_city" VALUES(4839,'Tionesta','Tionesta, Pennsylvania',5920,44);
INSERT INTO "django_geo_db_city" VALUES(4840,'Titusville','Titusville, Pennsylvania',5921,44);
INSERT INTO "django_geo_db_city" VALUES(4841,'East Fairfield','East Fairfield, Pennsylvania',5922,44);
INSERT INTO "django_geo_db_city" VALUES(4842,'Townville','Townville, Pennsylvania',5923,44);
INSERT INTO "django_geo_db_city" VALUES(4843,'Tylersburg','Tylersburg, Pennsylvania',5924,44);
INSERT INTO "django_geo_db_city" VALUES(4844,'Utica','Utica, Pennsylvania',5925,44);
INSERT INTO "django_geo_db_city" VALUES(4845,'Venus','Venus, Pennsylvania',5926,44);
INSERT INTO "django_geo_db_city" VALUES(4846,'Warren','Warren, Pennsylvania',5927,44);
INSERT INTO "django_geo_db_city" VALUES(4847,'West Hickory','West Hickory, Pennsylvania',5929,44);
INSERT INTO "django_geo_db_city" VALUES(4848,'Youngsville','Youngsville, Pennsylvania',5930,44);
INSERT INTO "django_geo_db_city" VALUES(4849,'Clintonville','Clintonville, Pennsylvania',5931,44);
INSERT INTO "django_geo_db_city" VALUES(4850,'Emlenton','Emlenton, Pennsylvania',5932,44);
INSERT INTO "django_geo_db_city" VALUES(4851,'Kennerdell','Kennerdell, Pennsylvania',5933,44);
INSERT INTO "django_geo_db_city" VALUES(4852,'Lamartine','Lamartine, Pennsylvania',5801,44);
INSERT INTO "django_geo_db_city" VALUES(4853,'Albion','Albion, Pennsylvania',5935,44);
INSERT INTO "django_geo_db_city" VALUES(4854,'Bear Lake','Bear Lake, Pennsylvania',5936,44);
INSERT INTO "django_geo_db_city" VALUES(4855,'Cambridge Springs','Cambridge Springs, Pennsylvania',5937,44);
INSERT INTO "django_geo_db_city" VALUES(4856,'Columbus','Columbus, Pennsylvania',5939,44);
INSERT INTO "django_geo_db_city" VALUES(4857,'Conneautville','Conneautville, Pennsylvania',5940,44);
INSERT INTO "django_geo_db_city" VALUES(4858,'Corry','Corry, Pennsylvania',5941,44);
INSERT INTO "django_geo_db_city" VALUES(4859,'Cranesville','Cranesville, Pennsylvania',5942,44);
INSERT INTO "django_geo_db_city" VALUES(4860,'East Springfield','East Springfield, Pennsylvania',5943,44);
INSERT INTO "django_geo_db_city" VALUES(4861,'Edinboro','Edinboro, Pennsylvania',5944,44);
INSERT INTO "django_geo_db_city" VALUES(4862,'Elgin','Elgin, Pennsylvania',5945,44);
INSERT INTO "django_geo_db_city" VALUES(4863,'Bloomfield','Bloomfield, Pennsylvania',5946,44);
INSERT INTO "django_geo_db_city" VALUES(4864,'Fairview','Fairview, Pennsylvania',5947,44);
INSERT INTO "django_geo_db_city" VALUES(4865,'Garland','Garland, Pennsylvania',5948,44);
INSERT INTO "django_geo_db_city" VALUES(4866,'Girard','Girard, Pennsylvania',5949,44);
INSERT INTO "django_geo_db_city" VALUES(4867,'Grand Valley','Grand Valley, Pennsylvania',5950,44);
INSERT INTO "django_geo_db_city" VALUES(4868,'Harborcreek','Harborcreek, Pennsylvania',5951,44);
INSERT INTO "django_geo_db_city" VALUES(4869,'Harmonsburg','Harmonsburg, Pennsylvania',5952,44);
INSERT INTO "django_geo_db_city" VALUES(4870,'Lake City','Lake City, Pennsylvania',5953,44);
INSERT INTO "django_geo_db_city" VALUES(4871,'Linesville','Linesville, Pennsylvania',5954,44);
INSERT INTO "django_geo_db_city" VALUES(4872,'McKean','McKean, Pennsylvania',5955,44);
INSERT INTO "django_geo_db_city" VALUES(4873,'Mill Village','Mill Village, Pennsylvania',5956,44);
INSERT INTO "django_geo_db_city" VALUES(4874,'North East','North East, Pennsylvania',5957,44);
INSERT INTO "django_geo_db_city" VALUES(4875,'North Springfield','North Springfield, Pennsylvania',5958,44);
INSERT INTO "django_geo_db_city" VALUES(4876,'Riceville','Riceville, Pennsylvania',5902,44);
INSERT INTO "django_geo_db_city" VALUES(4877,'Saegertown','Saegertown, Pennsylvania',5959,44);
INSERT INTO "django_geo_db_city" VALUES(4878,'Spartansburg','Spartansburg, Pennsylvania',5960,44);
INSERT INTO "django_geo_db_city" VALUES(4879,'Springboro','Springboro, Pennsylvania',5961,44);
INSERT INTO "django_geo_db_city" VALUES(4880,'Spring Creek','Spring Creek, Pennsylvania',5962,44);
INSERT INTO "django_geo_db_city" VALUES(4881,'Union City','Union City, Pennsylvania',5963,44);
INSERT INTO "django_geo_db_city" VALUES(4882,'Venango','Venango, Pennsylvania',5964,44);
INSERT INTO "django_geo_db_city" VALUES(4883,'Waterford','Waterford, Pennsylvania',5965,44);
INSERT INTO "django_geo_db_city" VALUES(4884,'Wattsburg','Wattsburg, Pennsylvania',5966,44);
INSERT INTO "django_geo_db_city" VALUES(4885,'West Springfield','West Springfield, Pennsylvania',5967,44);
INSERT INTO "django_geo_db_city" VALUES(4886,'Erie','Erie, Pennsylvania',5968,44);
INSERT INTO "django_geo_db_city" VALUES(4887,'Altoona','Altoona, Pennsylvania',5980,44);
INSERT INTO "django_geo_db_city" VALUES(4888,'Alexandria','Alexandria, Pennsylvania',5983,44);
INSERT INTO "django_geo_db_city" VALUES(4889,'Ashville','Ashville, Pennsylvania',5984,44);
INSERT INTO "django_geo_db_city" VALUES(4890,'Bakers Summit','Bakers Summit, Pennsylvania',5985,44);
INSERT INTO "django_geo_db_city" VALUES(4891,'Beccaria','Beccaria, Pennsylvania',5986,44);
INSERT INTO "django_geo_db_city" VALUES(4892,'Bellwood','Bellwood, Pennsylvania',5987,44);
INSERT INTO "django_geo_db_city" VALUES(4893,'Blandburg','Blandburg, Pennsylvania',5988,44);
INSERT INTO "django_geo_db_city" VALUES(4894,'Brisbin','Brisbin, Pennsylvania',5989,44);
INSERT INTO "django_geo_db_city" VALUES(4895,'Broad Top','Broad Top, Pennsylvania',5990,44);
INSERT INTO "django_geo_db_city" VALUES(4896,'Calvin','Calvin, Pennsylvania',5991,44);
INSERT INTO "django_geo_db_city" VALUES(4897,'Cassville','Cassville, Pennsylvania',5992,44);
INSERT INTO "django_geo_db_city" VALUES(4898,'Chest Springs','Chest Springs, Pennsylvania',5993,44);
INSERT INTO "django_geo_db_city" VALUES(4899,'Claysburg','Claysburg, Pennsylvania',5994,44);
INSERT INTO "django_geo_db_city" VALUES(4900,'Coalport','Coalport, Pennsylvania',5995,44);
INSERT INTO "django_geo_db_city" VALUES(4901,'Coupon','Coupon, Pennsylvania',5996,44);
INSERT INTO "django_geo_db_city" VALUES(4902,'Cresson','Cresson, Pennsylvania',5997,44);
INSERT INTO "django_geo_db_city" VALUES(4903,'Curryville','Curryville, Pennsylvania',5998,44);
INSERT INTO "django_geo_db_city" VALUES(4904,'Defiance','Defiance, Pennsylvania',5999,44);
INSERT INTO "django_geo_db_city" VALUES(4905,'Dudley','Dudley, Pennsylvania',6000,44);
INSERT INTO "django_geo_db_city" VALUES(4906,'Duncansville','Duncansville, Pennsylvania',6001,44);
INSERT INTO "django_geo_db_city" VALUES(4907,'Dysart','Dysart, Pennsylvania',6002,44);
INSERT INTO "django_geo_db_city" VALUES(4908,'East Freedom','East Freedom, Pennsylvania',6003,44);
INSERT INTO "django_geo_db_city" VALUES(4909,'Entriken','Entriken, Pennsylvania',6004,44);
INSERT INTO "django_geo_db_city" VALUES(4910,'Fallentimber','Fallentimber, Pennsylvania',6005,44);
INSERT INTO "django_geo_db_city" VALUES(4911,'Flinton','Flinton, Pennsylvania',6006,44);
INSERT INTO "django_geo_db_city" VALUES(4912,'Gallitzin','Gallitzin, Pennsylvania',6007,44);
INSERT INTO "django_geo_db_city" VALUES(4913,'Glasgow','Glasgow, Pennsylvania',6008,44);
INSERT INTO "django_geo_db_city" VALUES(4914,'Glen Hope','Glen Hope, Pennsylvania',6009,44);
INSERT INTO "django_geo_db_city" VALUES(4915,'Hastings','Hastings, Pennsylvania',6010,44);
INSERT INTO "django_geo_db_city" VALUES(4916,'Hesston','Hesston, Pennsylvania',6011,44);
INSERT INTO "django_geo_db_city" VALUES(4917,'Hollidaysburg','Hollidaysburg, Pennsylvania',6012,44);
INSERT INTO "django_geo_db_city" VALUES(4918,'Hopewell','Hopewell, Pennsylvania',6013,44);
INSERT INTO "django_geo_db_city" VALUES(4919,'Houtzdale','Houtzdale, Pennsylvania',6014,44);
INSERT INTO "django_geo_db_city" VALUES(4920,'Huntingdon','Huntingdon, Pennsylvania',6015,44);
INSERT INTO "django_geo_db_city" VALUES(4921,'Imler','Imler, Pennsylvania',6017,44);
INSERT INTO "django_geo_db_city" VALUES(4922,'Irvona','Irvona, Pennsylvania',6018,44);
INSERT INTO "django_geo_db_city" VALUES(4923,'James Creek','James Creek, Pennsylvania',6019,44);
INSERT INTO "django_geo_db_city" VALUES(4924,'Loysburg','Loysburg, Pennsylvania',6020,44);
INSERT INTO "django_geo_db_city" VALUES(4925,'McConnellstown','McConnellstown, Pennsylvania',6016,44);
INSERT INTO "django_geo_db_city" VALUES(4926,'Madera','Madera, Pennsylvania',6021,44);
INSERT INTO "django_geo_db_city" VALUES(4927,'Martinsburg','Martinsburg, Pennsylvania',6022,44);
INSERT INTO "django_geo_db_city" VALUES(4928,'Morann','Morann, Pennsylvania',6023,44);
INSERT INTO "django_geo_db_city" VALUES(4929,'New Enterprise','New Enterprise, Pennsylvania',6024,44);
INSERT INTO "django_geo_db_city" VALUES(4930,'Newry','Newry, Pennsylvania',6025,44);
INSERT INTO "django_geo_db_city" VALUES(4931,'Osceola Mills','Osceola Mills, Pennsylvania',6026,44);
INSERT INTO "django_geo_db_city" VALUES(4932,'Osterburg','Osterburg, Pennsylvania',6027,44);
INSERT INTO "django_geo_db_city" VALUES(4933,'Patton','Patton, Pennsylvania',6028,44);
INSERT INTO "django_geo_db_city" VALUES(4934,'Petersburg','Petersburg, Pennsylvania',6029,44);
INSERT INTO "django_geo_db_city" VALUES(4935,'Queen','Queen, Pennsylvania',6030,44);
INSERT INTO "django_geo_db_city" VALUES(4936,'Ramey','Ramey, Pennsylvania',6031,44);
INSERT INTO "django_geo_db_city" VALUES(4937,'Riddlesburg','Riddlesburg, Pennsylvania',6032,44);
INSERT INTO "django_geo_db_city" VALUES(4938,'Roaring Spring','Roaring Spring, Pennsylvania',6033,44);
INSERT INTO "django_geo_db_city" VALUES(4939,'Robertsdale','Robertsdale, Pennsylvania',6034,44);
INSERT INTO "django_geo_db_city" VALUES(4940,'Saint Boniface','Saint Boniface, Pennsylvania',6035,44);
INSERT INTO "django_geo_db_city" VALUES(4941,'Sandy Ridge','Sandy Ridge, Pennsylvania',6036,44);
INSERT INTO "django_geo_db_city" VALUES(4942,'Saxton','Saxton, Pennsylvania',6037,44);
INSERT INTO "django_geo_db_city" VALUES(4943,'Six Mile Run','Six Mile Run, Pennsylvania',6038,44);
INSERT INTO "django_geo_db_city" VALUES(4944,'Smithmill','Smithmill, Pennsylvania',6039,44);
INSERT INTO "django_geo_db_city" VALUES(4945,'Smokerun','Smokerun, Pennsylvania',6040,44);
INSERT INTO "django_geo_db_city" VALUES(4946,'Sproul','Sproul, Pennsylvania',6041,44);
INSERT INTO "django_geo_db_city" VALUES(4947,'Spruce Creek','Spruce Creek, Pennsylvania',6042,44);
INSERT INTO "django_geo_db_city" VALUES(4948,'Tipton','Tipton, Pennsylvania',6043,44);
INSERT INTO "django_geo_db_city" VALUES(4949,'Todd','Todd, Pennsylvania',6044,44);
INSERT INTO "django_geo_db_city" VALUES(4950,'Tyrone','Tyrone, Pennsylvania',6045,44);
INSERT INTO "django_geo_db_city" VALUES(4951,'Waterfall','Waterfall, Pennsylvania',6046,44);
INSERT INTO "django_geo_db_city" VALUES(4952,'Wells Tannery','Wells Tannery, Pennsylvania',6047,44);
INSERT INTO "django_geo_db_city" VALUES(4953,'Westover','Westover, Pennsylvania',6048,44);
INSERT INTO "django_geo_db_city" VALUES(4954,'Williamsburg','Williamsburg, Pennsylvania',6049,44);
INSERT INTO "django_geo_db_city" VALUES(4955,'Wood','Wood, Pennsylvania',6050,44);
INSERT INTO "django_geo_db_city" VALUES(4956,'Woodbury','Woodbury, Pennsylvania',6051,44);
INSERT INTO "django_geo_db_city" VALUES(4957,'Bradford','Bradford, Pennsylvania',6053,44);
INSERT INTO "django_geo_db_city" VALUES(4958,'Austin','Austin, Pennsylvania',6054,44);
INSERT INTO "django_geo_db_city" VALUES(4959,'Crosby','Crosby, Pennsylvania',6055,44);
INSERT INTO "django_geo_db_city" VALUES(4960,'Custer City','Custer City, Pennsylvania',6056,44);
INSERT INTO "django_geo_db_city" VALUES(4961,'Cyclone','Cyclone, Pennsylvania',6057,44);
INSERT INTO "django_geo_db_city" VALUES(4962,'Derrick City','Derrick City, Pennsylvania',6058,44);
INSERT INTO "django_geo_db_city" VALUES(4963,'De Young','De Young, Pennsylvania',5691,44);
INSERT INTO "django_geo_db_city" VALUES(4964,'Duke Center','Duke Center, Pennsylvania',6059,44);
INSERT INTO "django_geo_db_city" VALUES(4965,'East Smethport','East Smethport, Pennsylvania',6060,44);
INSERT INTO "django_geo_db_city" VALUES(4966,'Eldred','Eldred, Pennsylvania',6061,44);
INSERT INTO "django_geo_db_city" VALUES(4967,'Gifford','Gifford, Pennsylvania',6062,44);
INSERT INTO "django_geo_db_city" VALUES(4968,'Hazel Hurst','Hazel Hurst, Pennsylvania',6063,44);
INSERT INTO "django_geo_db_city" VALUES(4969,'James City','James City, Pennsylvania',6064,44);
INSERT INTO "django_geo_db_city" VALUES(4970,'Kane','Kane, Pennsylvania',6065,44);
INSERT INTO "django_geo_db_city" VALUES(4971,'Lewis Run','Lewis Run, Pennsylvania',6066,44);
INSERT INTO "django_geo_db_city" VALUES(4972,'Mount Jewett','Mount Jewett, Pennsylvania',6067,44);
INSERT INTO "django_geo_db_city" VALUES(4973,'Port Allegany','Port Allegany, Pennsylvania',6068,44);
INSERT INTO "django_geo_db_city" VALUES(4974,'Rew','Rew, Pennsylvania',6069,44);
INSERT INTO "django_geo_db_city" VALUES(4975,'Rixford','Rixford, Pennsylvania',6070,44);
INSERT INTO "django_geo_db_city" VALUES(4976,'Roulette','Roulette, Pennsylvania',6071,44);
INSERT INTO "django_geo_db_city" VALUES(4977,'Shinglehouse','Shinglehouse, Pennsylvania',6072,44);
INSERT INTO "django_geo_db_city" VALUES(4978,'Smethport','Smethport, Pennsylvania',6073,44);
INSERT INTO "django_geo_db_city" VALUES(4979,'Turtlepoint','Turtlepoint, Pennsylvania',6074,44);
INSERT INTO "django_geo_db_city" VALUES(4980,'Westline','Westline, Pennsylvania',6075,44);
INSERT INTO "django_geo_db_city" VALUES(4981,'State College','State College, Pennsylvania',6076,44);
INSERT INTO "django_geo_db_city" VALUES(4982,'University Park','University Park, Pennsylvania',6077,44);
INSERT INTO "django_geo_db_city" VALUES(4983,'Potter','Potter, Pennsylvania',6080,44);
INSERT INTO "django_geo_db_city" VALUES(4984,'Aaronsburg','Aaronsburg, Pennsylvania',6081,44);
INSERT INTO "django_geo_db_city" VALUES(4985,'Allport','Allport, Pennsylvania',6052,44);
INSERT INTO "django_geo_db_city" VALUES(4986,'Beech Creek','Beech Creek, Pennsylvania',6082,44);
INSERT INTO "django_geo_db_city" VALUES(4987,'Bellefonte','Bellefonte, Pennsylvania',6083,44);
INSERT INTO "django_geo_db_city" VALUES(4988,'Bigler','Bigler, Pennsylvania',6084,44);
INSERT INTO "django_geo_db_city" VALUES(4989,'Blanchard','Blanchard, Pennsylvania',6085,44);
INSERT INTO "django_geo_db_city" VALUES(4990,'Boalsburg','Boalsburg, Pennsylvania',6086,44);
INSERT INTO "django_geo_db_city" VALUES(4991,'Centre Hall','Centre Hall, Pennsylvania',6087,44);
INSERT INTO "django_geo_db_city" VALUES(4992,'Clarence','Clarence, Pennsylvania',6088,44);
INSERT INTO "django_geo_db_city" VALUES(4993,'Clearfield','Clearfield, Pennsylvania',6089,44);
INSERT INTO "django_geo_db_city" VALUES(4994,'Coburn','Coburn, Pennsylvania',6090,44);
INSERT INTO "django_geo_db_city" VALUES(4995,'Curwensville','Curwensville, Pennsylvania',6091,44);
INSERT INTO "django_geo_db_city" VALUES(4996,'Drifting','Drifting, Pennsylvania',6092,44);
INSERT INTO "django_geo_db_city" VALUES(4997,'Fleming','Fleming, Pennsylvania',6093,44);
INSERT INTO "django_geo_db_city" VALUES(4998,'Frenchville','Frenchville, Pennsylvania',6094,44);
INSERT INTO "django_geo_db_city" VALUES(4999,'Glen Richey','Glen Richey, Pennsylvania',6095,44);
INSERT INTO "django_geo_db_city" VALUES(5000,'Grampian','Grampian, Pennsylvania',6096,44);
INSERT INTO "django_geo_db_city" VALUES(5001,'Grassflat','Grassflat, Pennsylvania',6097,44);
INSERT INTO "django_geo_db_city" VALUES(5002,'Hawk Run','Hawk Run, Pennsylvania',6098,44);
INSERT INTO "django_geo_db_city" VALUES(5003,'Howard','Howard, Pennsylvania',6099,44);
INSERT INTO "django_geo_db_city" VALUES(5004,'Hyde','Hyde, Pennsylvania',6100,44);
INSERT INTO "django_geo_db_city" VALUES(5005,'Julian','Julian, Pennsylvania',6101,44);
INSERT INTO "django_geo_db_city" VALUES(5006,'Karthaus','Karthaus, Pennsylvania',6102,44);
INSERT INTO "django_geo_db_city" VALUES(5007,'Kylertown','Kylertown, Pennsylvania',6103,44);
INSERT INTO "django_geo_db_city" VALUES(5008,'Lamar','Lamar, Pennsylvania',6104,44);
INSERT INTO "django_geo_db_city" VALUES(5009,'Lanse','Lanse, Pennsylvania',6105,44);
INSERT INTO "django_geo_db_city" VALUES(5010,'Lecontes Mills','Lecontes Mills, Pennsylvania',6052,44);
INSERT INTO "django_geo_db_city" VALUES(5011,'Lemont','Lemont, Pennsylvania',6106,44);
INSERT INTO "django_geo_db_city" VALUES(5012,'Madisonburg','Madisonburg, Pennsylvania',6107,44);
INSERT INTO "django_geo_db_city" VALUES(5013,'Milesburg','Milesburg, Pennsylvania',6108,44);
INSERT INTO "django_geo_db_city" VALUES(5014,'Millheim','Millheim, Pennsylvania',6109,44);
INSERT INTO "django_geo_db_city" VALUES(5015,'Mineral Springs','Mineral Springs, Pennsylvania',6110,44);
INSERT INTO "django_geo_db_city" VALUES(5016,'Mingoville','Mingoville, Pennsylvania',6111,44);
INSERT INTO "django_geo_db_city" VALUES(5017,'Morrisdale','Morrisdale, Pennsylvania',6112,44);
INSERT INTO "django_geo_db_city" VALUES(5018,'Moshannon','Moshannon, Pennsylvania',6113,44);
INSERT INTO "django_geo_db_city" VALUES(5019,'Munson','Munson, Pennsylvania',6114,44);
INSERT INTO "django_geo_db_city" VALUES(5020,'New Millport','New Millport, Pennsylvania',6115,44);
INSERT INTO "django_geo_db_city" VALUES(5021,'Olanta','Olanta, Pennsylvania',6116,44);
INSERT INTO "django_geo_db_city" VALUES(5022,'Orviston','Orviston, Pennsylvania',6117,44);
INSERT INTO "django_geo_db_city" VALUES(5023,'Pennsylvania Furnace','Pennsylvania Furnace, Pennsylvania',6118,44);
INSERT INTO "django_geo_db_city" VALUES(5024,'Philipsburg','Philipsburg, Pennsylvania',6119,44);
INSERT INTO "django_geo_db_city" VALUES(5025,'Pine Grove Mills','Pine Grove Mills, Pennsylvania',6120,44);
INSERT INTO "django_geo_db_city" VALUES(5026,'Port Matilda','Port Matilda, Pennsylvania',6121,44);
INSERT INTO "django_geo_db_city" VALUES(5027,'Pottersdale','Pottersdale, Pennsylvania',6122,44);
INSERT INTO "django_geo_db_city" VALUES(5028,'Rebersburg','Rebersburg, Pennsylvania',6123,44);
INSERT INTO "django_geo_db_city" VALUES(5029,'Shawville','Shawville, Pennsylvania',6052,44);
INSERT INTO "django_geo_db_city" VALUES(5030,'Snow Shoe','Snow Shoe, Pennsylvania',6124,44);
INSERT INTO "django_geo_db_city" VALUES(5031,'Spring Mills','Spring Mills, Pennsylvania',6125,44);
INSERT INTO "django_geo_db_city" VALUES(5032,'Wallaceton','Wallaceton, Pennsylvania',6126,44);
INSERT INTO "django_geo_db_city" VALUES(5033,'Warriors Mark','Warriors Mark, Pennsylvania',6127,44);
INSERT INTO "django_geo_db_city" VALUES(5034,'West Decatur','West Decatur, Pennsylvania',6128,44);
INSERT INTO "django_geo_db_city" VALUES(5035,'Winburne','Winburne, Pennsylvania',6129,44);
INSERT INTO "django_geo_db_city" VALUES(5036,'Woodland','Woodland, Pennsylvania',6130,44);
INSERT INTO "django_geo_db_city" VALUES(5037,'Woodward','Woodward, Pennsylvania',6131,44);
INSERT INTO "django_geo_db_city" VALUES(5038,'Wellsboro','Wellsboro, Pennsylvania',6132,44);
INSERT INTO "django_geo_db_city" VALUES(5039,'Alba','Alba, Pennsylvania',6133,44);
INSERT INTO "django_geo_db_city" VALUES(5040,'Arnot','Arnot, Pennsylvania',6134,44);
INSERT INTO "django_geo_db_city" VALUES(5041,'Blossburg','Blossburg, Pennsylvania',6135,44);
INSERT INTO "django_geo_db_city" VALUES(5042,'Columbia Cross Roads','Columbia Cross Roads, Pennsylvania',6136,44);
INSERT INTO "django_geo_db_city" VALUES(5043,'Coudersport','Coudersport, Pennsylvania',6137,44);
INSERT INTO "django_geo_db_city" VALUES(5044,'Covington','Covington, Pennsylvania',6138,44);
INSERT INTO "django_geo_db_city" VALUES(5045,'Cowanesque','Cowanesque, Pennsylvania',6139,44);
INSERT INTO "django_geo_db_city" VALUES(5046,'Elkland','Elkland, Pennsylvania',6140,44);
INSERT INTO "django_geo_db_city" VALUES(5047,'Gaines','Gaines, Pennsylvania',6141,44);
INSERT INTO "django_geo_db_city" VALUES(5048,'Galeton','Galeton, Pennsylvania',6142,44);
INSERT INTO "django_geo_db_city" VALUES(5049,'Genesee','Genesee, Pennsylvania',6143,44);
INSERT INTO "django_geo_db_city" VALUES(5050,'Gillett','Gillett, Pennsylvania',6144,44);
INSERT INTO "django_geo_db_city" VALUES(5051,'Granville Summit','Granville Summit, Pennsylvania',6145,44);
INSERT INTO "django_geo_db_city" VALUES(5052,'Harrison Valley','Harrison Valley, Pennsylvania',6146,44);
INSERT INTO "django_geo_db_city" VALUES(5053,'Knoxville','Knoxville, Pennsylvania',6147,44);
INSERT INTO "django_geo_db_city" VALUES(5054,'Lawrenceville','Lawrenceville, Pennsylvania',6148,44);
INSERT INTO "django_geo_db_city" VALUES(5055,'Liberty','Liberty, Pennsylvania',6149,44);
INSERT INTO "django_geo_db_city" VALUES(5056,'Mainesburg','Mainesburg, Pennsylvania',6150,44);
INSERT INTO "django_geo_db_city" VALUES(5057,'Mansfield','Mansfield, Pennsylvania',6151,44);
INSERT INTO "django_geo_db_city" VALUES(5058,'Middlebury Center','Middlebury Center, Pennsylvania',6152,44);
INSERT INTO "django_geo_db_city" VALUES(5059,'Millerton','Millerton, Pennsylvania',6153,44);
INSERT INTO "django_geo_db_city" VALUES(5060,'Mills','Mills, Pennsylvania',6154,44);
INSERT INTO "django_geo_db_city" VALUES(5061,'Morris','Morris, Pennsylvania',6155,44);
INSERT INTO "django_geo_db_city" VALUES(5062,'Morris Run','Morris Run, Pennsylvania',6156,44);
INSERT INTO "django_geo_db_city" VALUES(5063,'Nelson','Nelson, Pennsylvania',6157,44);
INSERT INTO "django_geo_db_city" VALUES(5064,'Osceola','Osceola, Pennsylvania',6159,44);
INSERT INTO "django_geo_db_city" VALUES(5065,'Sabinsville','Sabinsville, Pennsylvania',6160,44);
INSERT INTO "django_geo_db_city" VALUES(5066,'Sylvania','Sylvania, Pennsylvania',6133,44);
INSERT INTO "django_geo_db_city" VALUES(5067,'Tioga','Tioga, Pennsylvania',6161,44);
INSERT INTO "django_geo_db_city" VALUES(5068,'Troy','Troy, Pennsylvania',6162,44);
INSERT INTO "django_geo_db_city" VALUES(5069,'Ulysses','Ulysses, Pennsylvania',6163,44);
INSERT INTO "django_geo_db_city" VALUES(5070,'Westfield','Westfield, Pennsylvania',6164,44);
INSERT INTO "django_geo_db_city" VALUES(5071,'Camp Hill','Camp Hill, Pennsylvania',6165,44);
INSERT INTO "django_geo_db_city" VALUES(5072,'Allensville','Allensville, Pennsylvania',6166,44);
INSERT INTO "django_geo_db_city" VALUES(5073,'Annville','Annville, Pennsylvania',6167,44);
INSERT INTO "django_geo_db_city" VALUES(5074,'Belleville','Belleville, Pennsylvania',6168,44);
INSERT INTO "django_geo_db_city" VALUES(5075,'Berrysburg','Berrysburg, Pennsylvania',6169,44);
INSERT INTO "django_geo_db_city" VALUES(5076,'Blain','Blain, Pennsylvania',6170,44);
INSERT INTO "django_geo_db_city" VALUES(5077,'Boiling Springs','Boiling Springs, Pennsylvania',6171,44);
INSERT INTO "django_geo_db_city" VALUES(5078,'Bowmansdale','Bowmansdale, Pennsylvania',6172,44);
INSERT INTO "django_geo_db_city" VALUES(5079,'Burnham','Burnham, Pennsylvania',6173,44);
INSERT INTO "django_geo_db_city" VALUES(5080,'Campbelltown','Campbelltown, Pennsylvania',6174,44);
INSERT INTO "django_geo_db_city" VALUES(5081,'Carlisle','Carlisle, Pennsylvania',6177,44);
INSERT INTO "django_geo_db_city" VALUES(5082,'Cocolamus','Cocolamus, Pennsylvania',6178,44);
INSERT INTO "django_geo_db_city" VALUES(5083,'South Londonderry','South Londonderry, Pennsylvania',6179,44);
INSERT INTO "django_geo_db_city" VALUES(5084,'Cornwall','Cornwall, Pennsylvania',6180,44);
INSERT INTO "django_geo_db_city" VALUES(5085,'Dalmatia','Dalmatia, Pennsylvania',6181,44);
INSERT INTO "django_geo_db_city" VALUES(5086,'Dauphin','Dauphin, Pennsylvania',6182,44);
INSERT INTO "django_geo_db_city" VALUES(5087,'Dillsburg','Dillsburg, Pennsylvania',6183,44);
INSERT INTO "django_geo_db_city" VALUES(5088,'Duncannon','Duncannon, Pennsylvania',6184,44);
INSERT INTO "django_geo_db_city" VALUES(5089,'East Waterford','East Waterford, Pennsylvania',6185,44);
INSERT INTO "django_geo_db_city" VALUES(5090,'Elizabethtown','Elizabethtown, Pennsylvania',6186,44);
INSERT INTO "django_geo_db_city" VALUES(5091,'Elizabethville','Elizabethville, Pennsylvania',6187,44);
INSERT INTO "django_geo_db_city" VALUES(5092,'Elliottsburg','Elliottsburg, Pennsylvania',6188,44);
INSERT INTO "django_geo_db_city" VALUES(5093,'Enola','Enola, Pennsylvania',6189,44);
INSERT INTO "django_geo_db_city" VALUES(5094,'Fredericksburg','Fredericksburg, Pennsylvania',6190,44);
INSERT INTO "django_geo_db_city" VALUES(5095,'Grantham','Grantham, Pennsylvania',6191,44);
INSERT INTO "django_geo_db_city" VALUES(5096,'Grantville','Grantville, Pennsylvania',6192,44);
INSERT INTO "django_geo_db_city" VALUES(5097,'Granville','Granville, Pennsylvania',6193,44);
INSERT INTO "django_geo_db_city" VALUES(5098,'Gratz','Gratz, Pennsylvania',6194,44);
INSERT INTO "django_geo_db_city" VALUES(5099,'Green Park','Green Park, Pennsylvania',6195,44);
INSERT INTO "django_geo_db_city" VALUES(5100,'Halifax','Halifax, Pennsylvania',6196,44);
INSERT INTO "django_geo_db_city" VALUES(5101,'Hershey','Hershey, Pennsylvania',6197,44);
INSERT INTO "django_geo_db_city" VALUES(5102,'Highspire','Highspire, Pennsylvania',6198,44);
INSERT INTO "django_geo_db_city" VALUES(5103,'Honey Grove','Honey Grove, Pennsylvania',6199,44);
INSERT INTO "django_geo_db_city" VALUES(5104,'Hummelstown','Hummelstown, Pennsylvania',6200,44);
INSERT INTO "django_geo_db_city" VALUES(5105,'Ickesburg','Ickesburg, Pennsylvania',6201,44);
INSERT INTO "django_geo_db_city" VALUES(5106,'Jonestown','Jonestown, Pennsylvania',6202,44);
INSERT INTO "django_geo_db_city" VALUES(5107,'Kleinfeltersville','Kleinfeltersville, Pennsylvania',6203,44);
INSERT INTO "django_geo_db_city" VALUES(5108,'Landisburg','Landisburg, Pennsylvania',6204,44);
INSERT INTO "django_geo_db_city" VALUES(5109,'Lawn','Lawn, Pennsylvania',6205,44);
INSERT INTO "django_geo_db_city" VALUES(5110,'Lebanon','Lebanon, Pennsylvania',6206,44);
INSERT INTO "django_geo_db_city" VALUES(5111,'Lemoyne','Lemoyne, Pennsylvania',6207,44);
INSERT INTO "django_geo_db_city" VALUES(5112,'Lewistown','Lewistown, Pennsylvania',6208,44);
INSERT INTO "django_geo_db_city" VALUES(5113,'Liverpool','Liverpool, Pennsylvania',6209,44);
INSERT INTO "django_geo_db_city" VALUES(5114,'Loysville','Loysville, Pennsylvania',6211,44);
INSERT INTO "django_geo_db_city" VALUES(5115,'Lykens','Lykens, Pennsylvania',6212,44);
INSERT INTO "django_geo_db_city" VALUES(5116,'McAlisterville','McAlisterville, Pennsylvania',6213,44);
INSERT INTO "django_geo_db_city" VALUES(5117,'Mechanicsburg','Mechanicsburg, Pennsylvania',6214,44);
INSERT INTO "django_geo_db_city" VALUES(5118,'McVeytown','McVeytown, Pennsylvania',6215,44);
INSERT INTO "django_geo_db_city" VALUES(5119,'Mapleton Depot','Mapleton Depot, Pennsylvania',6216,44);
INSERT INTO "django_geo_db_city" VALUES(5120,'Marysville','Marysville, Pennsylvania',6217,44);
INSERT INTO "django_geo_db_city" VALUES(5121,'Mattawana','Mattawana, Pennsylvania',6218,44);
INSERT INTO "django_geo_db_city" VALUES(5122,'Mexico','Mexico, Pennsylvania',6178,44);
INSERT INTO "django_geo_db_city" VALUES(5123,'Middletown','Middletown, Pennsylvania',6220,44);
INSERT INTO "django_geo_db_city" VALUES(5124,'Mifflin','Mifflin, Pennsylvania',6221,44);
INSERT INTO "django_geo_db_city" VALUES(5125,'Mifflintown','Mifflintown, Pennsylvania',6222,44);
INSERT INTO "django_geo_db_city" VALUES(5126,'Mill Creek','Mill Creek, Pennsylvania',6223,44);
INSERT INTO "django_geo_db_city" VALUES(5127,'Millersburg','Millersburg, Pennsylvania',6224,44);
INSERT INTO "django_geo_db_city" VALUES(5128,'Millerstown','Millerstown, Pennsylvania',6225,44);
INSERT INTO "django_geo_db_city" VALUES(5129,'Milroy','Milroy, Pennsylvania',6226,44);
INSERT INTO "django_geo_db_city" VALUES(5130,'Mount Gretna','Mount Gretna, Pennsylvania',6227,44);
INSERT INTO "django_geo_db_city" VALUES(5131,'Mount Holly Springs','Mount Holly Springs, Pennsylvania',6228,44);
INSERT INTO "django_geo_db_city" VALUES(5132,'Mount Union','Mount Union, Pennsylvania',6229,44);
INSERT INTO "django_geo_db_city" VALUES(5133,'Myerstown','Myerstown, Pennsylvania',6230,44);
INSERT INTO "django_geo_db_city" VALUES(5134,'New Bloomfield','New Bloomfield, Pennsylvania',6231,44);
INSERT INTO "django_geo_db_city" VALUES(5135,'New Buffalo','New Buffalo, Pennsylvania',6232,44);
INSERT INTO "django_geo_db_city" VALUES(5136,'New Cumberland','New Cumberland, Pennsylvania',6233,44);
INSERT INTO "django_geo_db_city" VALUES(5137,'New Germantown','New Germantown, Pennsylvania',6195,44);
INSERT INTO "django_geo_db_city" VALUES(5138,'New Kingstown','New Kingstown, Pennsylvania',6234,44);
INSERT INTO "django_geo_db_city" VALUES(5139,'Newmanstown','Newmanstown, Pennsylvania',6235,44);
INSERT INTO "django_geo_db_city" VALUES(5140,'Newport','Newport, Pennsylvania',6236,44);
INSERT INTO "django_geo_db_city" VALUES(5141,'Newton Hamilton','Newton Hamilton, Pennsylvania',6237,44);
INSERT INTO "django_geo_db_city" VALUES(5142,'Oakland Mills','Oakland Mills, Pennsylvania',6238,44);
INSERT INTO "django_geo_db_city" VALUES(5143,'Ono','Ono, Pennsylvania',6239,44);
INSERT INTO "django_geo_db_city" VALUES(5144,'Palmyra','Palmyra, Pennsylvania',6240,44);
INSERT INTO "django_geo_db_city" VALUES(5145,'Pillow','Pillow, Pennsylvania',6241,44);
INSERT INTO "django_geo_db_city" VALUES(5146,'Plainfield','Plainfield, Pennsylvania',6242,44);
INSERT INTO "django_geo_db_city" VALUES(5147,'Port Royal','Port Royal, Pennsylvania',6243,44);
INSERT INTO "django_geo_db_city" VALUES(5148,'Quentin','Quentin, Pennsylvania',6244,44);
INSERT INTO "django_geo_db_city" VALUES(5149,'Reedsville','Reedsville, Pennsylvania',6245,44);
INSERT INTO "django_geo_db_city" VALUES(5150,'Rexmont','Rexmont, Pennsylvania',6246,44);
INSERT INTO "django_geo_db_city" VALUES(5151,'Richfield','Richfield, Pennsylvania',6247,44);
INSERT INTO "django_geo_db_city" VALUES(5152,'Richland','Richland, Pennsylvania',6248,44);
INSERT INTO "django_geo_db_city" VALUES(5153,'Schaefferstown','Schaefferstown, Pennsylvania',6249,44);
INSERT INTO "django_geo_db_city" VALUES(5154,'Shermans Dale','Shermans Dale, Pennsylvania',6251,44);
INSERT INTO "django_geo_db_city" VALUES(5155,'Summerdale','Summerdale, Pennsylvania',6252,44);
INSERT INTO "django_geo_db_city" VALUES(5156,'Thompsontown','Thompsontown, Pennsylvania',6253,44);
INSERT INTO "django_geo_db_city" VALUES(5157,'Wiconisco','Wiconisco, Pennsylvania',6254,44);
INSERT INTO "django_geo_db_city" VALUES(5158,'Williamstown','Williamstown, Pennsylvania',6255,44);
INSERT INTO "django_geo_db_city" VALUES(5159,'Yeagertown','Yeagertown, Pennsylvania',6256,44);
INSERT INTO "django_geo_db_city" VALUES(5160,'Harrisburg','Harrisburg, Pennsylvania',6257,44);
INSERT INTO "django_geo_db_city" VALUES(5161,'Chambersburg','Chambersburg, Pennsylvania',6282,44);
INSERT INTO "django_geo_db_city" VALUES(5162,'Amberson','Amberson, Pennsylvania',6283,44);
INSERT INTO "django_geo_db_city" VALUES(5163,'Artemas','Artemas, Pennsylvania',6284,44);
INSERT INTO "django_geo_db_city" VALUES(5164,'Big Cove Tannery','Big Cove Tannery, Pennsylvania',6285,44);
INSERT INTO "django_geo_db_city" VALUES(5165,'Blairs Mills','Blairs Mills, Pennsylvania',6286,44);
INSERT INTO "django_geo_db_city" VALUES(5166,'Blue Ridge Summit','Blue Ridge Summit, Pennsylvania',6287,44);
INSERT INTO "django_geo_db_city" VALUES(5167,'Burnt Cabins','Burnt Cabins, Pennsylvania',6288,44);
INSERT INTO "django_geo_db_city" VALUES(5168,'Concord','Concord, Pennsylvania',6289,44);
INSERT INTO "django_geo_db_city" VALUES(5169,'Doylesburg','Doylesburg, Pennsylvania',6290,44);
INSERT INTO "django_geo_db_city" VALUES(5170,'Dry Run','Dry Run, Pennsylvania',6291,44);
INSERT INTO "django_geo_db_city" VALUES(5171,'Fannettsburg','Fannettsburg, Pennsylvania',6292,44);
INSERT INTO "django_geo_db_city" VALUES(5172,'Fayetteville','Fayetteville, Pennsylvania',6293,44);
INSERT INTO "django_geo_db_city" VALUES(5173,'Fort Littleton','Fort Littleton, Pennsylvania',6294,44);
INSERT INTO "django_geo_db_city" VALUES(5174,'Fort Loudon','Fort Loudon, Pennsylvania',6295,44);
INSERT INTO "django_geo_db_city" VALUES(5175,'Greencastle','Greencastle, Pennsylvania',6296,44);
INSERT INTO "django_geo_db_city" VALUES(5176,'Harrisonville','Harrisonville, Pennsylvania',6297,44);
INSERT INTO "django_geo_db_city" VALUES(5177,'Hustontown','Hustontown, Pennsylvania',6298,44);
INSERT INTO "django_geo_db_city" VALUES(5178,'Lemasters','Lemasters, Pennsylvania',6299,44);
INSERT INTO "django_geo_db_city" VALUES(5179,'Lurgan','Lurgan, Pennsylvania',6300,44);
INSERT INTO "django_geo_db_city" VALUES(5180,'McConnellsburg','McConnellsburg, Pennsylvania',6301,44);
INSERT INTO "django_geo_db_city" VALUES(5181,'Marion','Marion, Pennsylvania',6302,44);
INSERT INTO "django_geo_db_city" VALUES(5182,'Mercersburg','Mercersburg, Pennsylvania',6303,44);
INSERT INTO "django_geo_db_city" VALUES(5183,'Mont Alto','Mont Alto, Pennsylvania',6304,44);
INSERT INTO "django_geo_db_city" VALUES(5184,'Needmore','Needmore, Pennsylvania',6305,44);
INSERT INTO "django_geo_db_city" VALUES(5185,'Neelyton','Neelyton, Pennsylvania',6306,44);
INSERT INTO "django_geo_db_city" VALUES(5186,'Newburg','Newburg, Pennsylvania',6307,44);
INSERT INTO "django_geo_db_city" VALUES(5187,'Newville','Newville, Pennsylvania',6308,44);
INSERT INTO "django_geo_db_city" VALUES(5188,'Orbisonia','Orbisonia, Pennsylvania',6309,44);
INSERT INTO "django_geo_db_city" VALUES(5189,'Orrstown','Orrstown, Pennsylvania',6310,44);
INSERT INTO "django_geo_db_city" VALUES(5190,'Pleasant Hall','Pleasant Hall, Pennsylvania',6311,44);
INSERT INTO "django_geo_db_city" VALUES(5191,'Quincy','Quincy, Pennsylvania',6312,44);
INSERT INTO "django_geo_db_city" VALUES(5192,'Rockhill Furnace','Rockhill Furnace, Pennsylvania',6313,44);
INSERT INTO "django_geo_db_city" VALUES(5193,'Rouzerville','Rouzerville, Pennsylvania',6314,44);
INSERT INTO "django_geo_db_city" VALUES(5194,'Roxbury','Roxbury, Pennsylvania',6315,44);
INSERT INTO "django_geo_db_city" VALUES(5195,'Saint Thomas','Saint Thomas, Pennsylvania',6316,44);
INSERT INTO "django_geo_db_city" VALUES(5196,'Saltillo','Saltillo, Pennsylvania',6317,44);
INSERT INTO "django_geo_db_city" VALUES(5197,'Scotland','Scotland, Pennsylvania',6318,44);
INSERT INTO "django_geo_db_city" VALUES(5198,'Shade Gap','Shade Gap, Pennsylvania',6319,44);
INSERT INTO "django_geo_db_city" VALUES(5199,'Shady Grove','Shady Grove, Pennsylvania',6320,44);
INSERT INTO "django_geo_db_city" VALUES(5200,'Shippensburg','Shippensburg, Pennsylvania',6321,44);
INSERT INTO "django_geo_db_city" VALUES(5201,'Shirleysburg','Shirleysburg, Pennsylvania',6322,44);
INSERT INTO "django_geo_db_city" VALUES(5202,'South Mountain','South Mountain, Pennsylvania',6323,44);
INSERT INTO "django_geo_db_city" VALUES(5203,'Spring Run','Spring Run, Pennsylvania',6324,44);
INSERT INTO "django_geo_db_city" VALUES(5204,'State Line','State Line, Pennsylvania',6325,44);
INSERT INTO "django_geo_db_city" VALUES(5205,'Three Springs','Three Springs, Pennsylvania',6326,44);
INSERT INTO "django_geo_db_city" VALUES(5206,'Upperstrasburg','Upperstrasburg, Pennsylvania',6327,44);
INSERT INTO "django_geo_db_city" VALUES(5207,'Walnut Bottom','Walnut Bottom, Pennsylvania',6328,44);
INSERT INTO "django_geo_db_city" VALUES(5208,'Warfordsburg','Warfordsburg, Pennsylvania',6329,44);
INSERT INTO "django_geo_db_city" VALUES(5209,'Waynesboro','Waynesboro, Pennsylvania',6330,44);
INSERT INTO "django_geo_db_city" VALUES(5210,'Brush Creek','Brush Creek, Pennsylvania',6331,44);
INSERT INTO "django_geo_db_city" VALUES(5211,'Williamson','Williamson, Pennsylvania',6332,44);
INSERT INTO "django_geo_db_city" VALUES(5212,'Willow Hill','Willow Hill, Pennsylvania',6333,44);
INSERT INTO "django_geo_db_city" VALUES(5213,'Zullinger','Zullinger, Pennsylvania',6334,44);
INSERT INTO "django_geo_db_city" VALUES(5214,'Southampton','Southampton, Pennsylvania',6335,44);
INSERT INTO "django_geo_db_city" VALUES(5215,'Abbottstown','Abbottstown, Pennsylvania',6337,44);
INSERT INTO "django_geo_db_city" VALUES(5216,'Airville','Airville, Pennsylvania',6338,44);
INSERT INTO "django_geo_db_city" VALUES(5217,'Arendtsville','Arendtsville, Pennsylvania',6339,44);
INSERT INTO "django_geo_db_city" VALUES(5218,'Aspers','Aspers, Pennsylvania',6340,44);
INSERT INTO "django_geo_db_city" VALUES(5219,'Bendersville','Bendersville, Pennsylvania',6341,44);
INSERT INTO "django_geo_db_city" VALUES(5220,'Biglerville','Biglerville, Pennsylvania',6342,44);
INSERT INTO "django_geo_db_city" VALUES(5221,'Brogue','Brogue, Pennsylvania',6343,44);
INSERT INTO "django_geo_db_city" VALUES(5222,'Cashtown','Cashtown, Pennsylvania',6344,44);
INSERT INTO "django_geo_db_city" VALUES(5223,'Codorus','Codorus, Pennsylvania',6345,44);
INSERT INTO "django_geo_db_city" VALUES(5224,'Craley','Craley, Pennsylvania',6346,44);
INSERT INTO "django_geo_db_city" VALUES(5225,'Dallastown','Dallastown, Pennsylvania',6347,44);
INSERT INTO "django_geo_db_city" VALUES(5226,'Delta','Delta, Pennsylvania',6348,44);
INSERT INTO "django_geo_db_city" VALUES(5227,'Dover','Dover, Pennsylvania',6349,44);
INSERT INTO "django_geo_db_city" VALUES(5228,'East Berlin','East Berlin, Pennsylvania',6350,44);
INSERT INTO "django_geo_db_city" VALUES(5229,'East Prospect','East Prospect, Pennsylvania',6351,44);
INSERT INTO "django_geo_db_city" VALUES(5230,'Emigsville','Emigsville, Pennsylvania',6352,44);
INSERT INTO "django_geo_db_city" VALUES(5231,'Etters','Etters, Pennsylvania',6353,44);
INSERT INTO "django_geo_db_city" VALUES(5232,'Fairfield','Fairfield, Pennsylvania',6354,44);
INSERT INTO "django_geo_db_city" VALUES(5233,'Fawn Grove','Fawn Grove, Pennsylvania',6355,44);
INSERT INTO "django_geo_db_city" VALUES(5234,'Felton','Felton, Pennsylvania',6356,44);
INSERT INTO "django_geo_db_city" VALUES(5235,'Franklintown','Franklintown, Pennsylvania',6357,44);
INSERT INTO "django_geo_db_city" VALUES(5236,'Gardners','Gardners, Pennsylvania',6358,44);
INSERT INTO "django_geo_db_city" VALUES(5237,'Gettysburg','Gettysburg, Pennsylvania',6359,44);
INSERT INTO "django_geo_db_city" VALUES(5238,'Glen Rock','Glen Rock, Pennsylvania',6361,44);
INSERT INTO "django_geo_db_city" VALUES(5239,'Glenville','Glenville, Pennsylvania',6362,44);
INSERT INTO "django_geo_db_city" VALUES(5240,'Hanover','Hanover, Pennsylvania',6363,44);
INSERT INTO "django_geo_db_city" VALUES(5241,'Idaville','Idaville, Pennsylvania',6366,44);
INSERT INTO "django_geo_db_city" VALUES(5242,'Lewisberry','Lewisberry, Pennsylvania',6367,44);
INSERT INTO "django_geo_db_city" VALUES(5243,'Littlestown','Littlestown, Pennsylvania',6368,44);
INSERT INTO "django_geo_db_city" VALUES(5244,'Loganville','Loganville, Pennsylvania',6369,44);
INSERT INTO "django_geo_db_city" VALUES(5245,'McKnightstown','McKnightstown, Pennsylvania',6370,44);
INSERT INTO "django_geo_db_city" VALUES(5246,'McSherrystown','McSherrystown, Pennsylvania',6371,44);
INSERT INTO "django_geo_db_city" VALUES(5247,'Manchester','Manchester, Pennsylvania',6372,44);
INSERT INTO "django_geo_db_city" VALUES(5248,'Menges Mills','Menges Mills, Pennsylvania',6373,44);
INSERT INTO "django_geo_db_city" VALUES(5249,'Mount Wolf','Mount Wolf, Pennsylvania',6374,44);
INSERT INTO "django_geo_db_city" VALUES(5250,'New Freedom','New Freedom, Pennsylvania',6375,44);
INSERT INTO "django_geo_db_city" VALUES(5251,'New Oxford','New Oxford, Pennsylvania',6376,44);
INSERT INTO "django_geo_db_city" VALUES(5252,'New Park','New Park, Pennsylvania',6377,44);
INSERT INTO "django_geo_db_city" VALUES(5253,'Orrtanna','Orrtanna, Pennsylvania',6378,44);
INSERT INTO "django_geo_db_city" VALUES(5254,'Porters Sideling','Porters Sideling, Pennsylvania',6379,44);
INSERT INTO "django_geo_db_city" VALUES(5255,'Railroad','Railroad, Pennsylvania',6380,44);
INSERT INTO "django_geo_db_city" VALUES(5256,'Red Lion','Red Lion, Pennsylvania',6381,44);
INSERT INTO "django_geo_db_city" VALUES(5257,'Rossville','Rossville, Pennsylvania',6365,44);
INSERT INTO "django_geo_db_city" VALUES(5258,'Seven Valleys','Seven Valleys, Pennsylvania',6382,44);
INSERT INTO "django_geo_db_city" VALUES(5259,'Shrewsbury','Shrewsbury, Pennsylvania',6383,44);
INSERT INTO "django_geo_db_city" VALUES(5260,'Spring Grove','Spring Grove, Pennsylvania',6384,44);
INSERT INTO "django_geo_db_city" VALUES(5261,'Stewartstown','Stewartstown, Pennsylvania',6385,44);
INSERT INTO "django_geo_db_city" VALUES(5262,'Thomasville','Thomasville, Pennsylvania',6386,44);
INSERT INTO "django_geo_db_city" VALUES(5263,'Wellsville','Wellsville, Pennsylvania',6387,44);
INSERT INTO "django_geo_db_city" VALUES(5264,'Windsor','Windsor, Pennsylvania',6388,44);
INSERT INTO "django_geo_db_city" VALUES(5265,'Wrightsville','Wrightsville, Pennsylvania',6389,44);
INSERT INTO "django_geo_db_city" VALUES(5266,'York Haven','York Haven, Pennsylvania',6390,44);
INSERT INTO "django_geo_db_city" VALUES(5267,'York New Salem','York New Salem, Pennsylvania',6391,44);
INSERT INTO "django_geo_db_city" VALUES(5268,'York Springs','York Springs, Pennsylvania',6392,44);
INSERT INTO "django_geo_db_city" VALUES(5269,'Peach Glen','Peach Glen, Pennsylvania',6360,44);
INSERT INTO "django_geo_db_city" VALUES(5270,'York','York, Pennsylvania',6393,44);
INSERT INTO "django_geo_db_city" VALUES(5271,'Akron','Akron, Pennsylvania',6400,44);
INSERT INTO "django_geo_db_city" VALUES(5272,'Bainbridge','Bainbridge, Pennsylvania',6401,44);
INSERT INTO "django_geo_db_city" VALUES(5273,'Bart','Bart, Pennsylvania',6402,44);
INSERT INTO "django_geo_db_city" VALUES(5274,'Bausman','Bausman, Pennsylvania',6403,44);
INSERT INTO "django_geo_db_city" VALUES(5275,'Bird In Hand','Bird In Hand, Pennsylvania',6404,44);
INSERT INTO "django_geo_db_city" VALUES(5276,'Blue Ball','Blue Ball, Pennsylvania',6405,44);
INSERT INTO "django_geo_db_city" VALUES(5277,'Bowmansville','Bowmansville, Pennsylvania',6406,44);
INSERT INTO "django_geo_db_city" VALUES(5278,'Brownstown','Brownstown, Pennsylvania',6407,44);
INSERT INTO "django_geo_db_city" VALUES(5279,'Christiana','Christiana, Pennsylvania',6408,44);
INSERT INTO "django_geo_db_city" VALUES(5280,'Columbia','Columbia, Pennsylvania',6409,44);
INSERT INTO "django_geo_db_city" VALUES(5281,'Conestoga','Conestoga, Pennsylvania',6411,44);
INSERT INTO "django_geo_db_city" VALUES(5282,'Denver','Denver, Pennsylvania',6412,44);
INSERT INTO "django_geo_db_city" VALUES(5283,'Drumore','Drumore, Pennsylvania',6413,44);
INSERT INTO "django_geo_db_city" VALUES(5284,'East Earl','East Earl, Pennsylvania',6414,44);
INSERT INTO "django_geo_db_city" VALUES(5285,'East Petersburg','East Petersburg, Pennsylvania',6415,44);
INSERT INTO "django_geo_db_city" VALUES(5286,'Elm','Elm, Pennsylvania',6416,44);
INSERT INTO "django_geo_db_city" VALUES(5287,'Ephrata','Ephrata, Pennsylvania',6417,44);
INSERT INTO "django_geo_db_city" VALUES(5288,'Gap','Gap, Pennsylvania',6418,44);
INSERT INTO "django_geo_db_city" VALUES(5289,'Goodville','Goodville, Pennsylvania',6419,44);
INSERT INTO "django_geo_db_city" VALUES(5290,'Gordonville','Gordonville, Pennsylvania',6420,44);
INSERT INTO "django_geo_db_city" VALUES(5291,'Holtwood','Holtwood, Pennsylvania',6421,44);
INSERT INTO "django_geo_db_city" VALUES(5292,'Hopeland','Hopeland, Pennsylvania',6422,44);
INSERT INTO "django_geo_db_city" VALUES(5293,'Intercourse','Intercourse, Pennsylvania',6423,44);
INSERT INTO "django_geo_db_city" VALUES(5294,'Kinzers','Kinzers, Pennsylvania',6424,44);
INSERT INTO "django_geo_db_city" VALUES(5295,'Kirkwood','Kirkwood, Pennsylvania',6425,44);
INSERT INTO "django_geo_db_city" VALUES(5296,'Lampeter','Lampeter, Pennsylvania',6426,44);
INSERT INTO "django_geo_db_city" VALUES(5297,'Landisville','Landisville, Pennsylvania',6427,44);
INSERT INTO "django_geo_db_city" VALUES(5298,'Leola','Leola, Pennsylvania',6428,44);
INSERT INTO "django_geo_db_city" VALUES(5299,'Lititz','Lititz, Pennsylvania',6429,44);
INSERT INTO "django_geo_db_city" VALUES(5300,'Manheim','Manheim, Pennsylvania',6430,44);
INSERT INTO "django_geo_db_city" VALUES(5301,'Marietta','Marietta, Pennsylvania',6431,44);
INSERT INTO "django_geo_db_city" VALUES(5302,'Martindale','Martindale, Pennsylvania',6432,44);
INSERT INTO "django_geo_db_city" VALUES(5303,'Maytown','Maytown, Pennsylvania',6433,44);
INSERT INTO "django_geo_db_city" VALUES(5304,'Millersville','Millersville, Pennsylvania',6434,44);
INSERT INTO "django_geo_db_city" VALUES(5305,'Mount Joy','Mount Joy, Pennsylvania',6435,44);
INSERT INTO "django_geo_db_city" VALUES(5306,'Mountville','Mountville, Pennsylvania',6436,44);
INSERT INTO "django_geo_db_city" VALUES(5307,'Narvon','Narvon, Pennsylvania',6437,44);
INSERT INTO "django_geo_db_city" VALUES(5308,'New Holland','New Holland, Pennsylvania',6438,44);
INSERT INTO "django_geo_db_city" VALUES(5309,'New Providence','New Providence, Pennsylvania',6439,44);
INSERT INTO "django_geo_db_city" VALUES(5310,'Paradise','Paradise, Pennsylvania',6440,44);
INSERT INTO "django_geo_db_city" VALUES(5311,'Peach Bottom','Peach Bottom, Pennsylvania',6441,44);
INSERT INTO "django_geo_db_city" VALUES(5312,'Penryn','Penryn, Pennsylvania',6402,44);
INSERT INTO "django_geo_db_city" VALUES(5313,'Pequea','Pequea, Pennsylvania',6442,44);
INSERT INTO "django_geo_db_city" VALUES(5314,'Quarryville','Quarryville, Pennsylvania',6443,44);
INSERT INTO "django_geo_db_city" VALUES(5315,'Reamstown','Reamstown, Pennsylvania',6444,44);
INSERT INTO "django_geo_db_city" VALUES(5316,'Refton','Refton, Pennsylvania',6445,44);
INSERT INTO "django_geo_db_city" VALUES(5317,'Reinholds','Reinholds, Pennsylvania',6446,44);
INSERT INTO "django_geo_db_city" VALUES(5318,'Rheems','Rheems, Pennsylvania',6447,44);
INSERT INTO "django_geo_db_city" VALUES(5319,'Ronks','Ronks, Pennsylvania',6448,44);
INSERT INTO "django_geo_db_city" VALUES(5320,'Silver Spring','Silver Spring, Pennsylvania',6449,44);
INSERT INTO "django_geo_db_city" VALUES(5321,'Smoketown','Smoketown, Pennsylvania',6450,44);
INSERT INTO "django_geo_db_city" VALUES(5322,'Soudersburg','Soudersburg, Pennsylvania',6402,44);
INSERT INTO "django_geo_db_city" VALUES(5323,'Stevens','Stevens, Pennsylvania',6451,44);
INSERT INTO "django_geo_db_city" VALUES(5324,'Strasburg','Strasburg, Pennsylvania',6452,44);
INSERT INTO "django_geo_db_city" VALUES(5325,'Talmage','Talmage, Pennsylvania',6453,44);
INSERT INTO "django_geo_db_city" VALUES(5326,'Terre Hill','Terre Hill, Pennsylvania',6454,44);
INSERT INTO "django_geo_db_city" VALUES(5327,'Washington Boro','Washington Boro, Pennsylvania',6455,44);
INSERT INTO "django_geo_db_city" VALUES(5328,'West Willow','West Willow, Pennsylvania',6456,44);
INSERT INTO "django_geo_db_city" VALUES(5329,'Willow Street','Willow Street, Pennsylvania',6457,44);
INSERT INTO "django_geo_db_city" VALUES(5330,'Witmer','Witmer, Pennsylvania',6458,44);
INSERT INTO "django_geo_db_city" VALUES(5331,'Lancaster','Lancaster, Pennsylvania',6459,44);
INSERT INTO "django_geo_db_city" VALUES(5332,'Williamsport','Williamsport, Pennsylvania',6464,44);
INSERT INTO "django_geo_db_city" VALUES(5333,'Antes Fort','Antes Fort, Pennsylvania',6467,44);
INSERT INTO "django_geo_db_city" VALUES(5334,'Avis','Avis, Pennsylvania',6468,44);
INSERT INTO "django_geo_db_city" VALUES(5335,'Bodines','Bodines, Pennsylvania',6466,44);
INSERT INTO "django_geo_db_city" VALUES(5336,'Jersey Shore','Jersey Shore, Pennsylvania',6466,44);
INSERT INTO "django_geo_db_city" VALUES(5337,'Canton','Canton, Pennsylvania',6469,44);
INSERT INTO "django_geo_db_city" VALUES(5338,'Castanea','Castanea, Pennsylvania',6470,44);
INSERT INTO "django_geo_db_city" VALUES(5339,'Cedar Run','Cedar Run, Pennsylvania',6466,44);
INSERT INTO "django_geo_db_city" VALUES(5340,'Cogan Station','Cogan Station, Pennsylvania',6471,44);
INSERT INTO "django_geo_db_city" VALUES(5341,'Cross Fork','Cross Fork, Pennsylvania',6472,44);
INSERT INTO "django_geo_db_city" VALUES(5342,'Dewart','Dewart, Pennsylvania',6473,44);
INSERT INTO "django_geo_db_city" VALUES(5343,'Eagles Mere','Eagles Mere, Pennsylvania',6474,44);
INSERT INTO "django_geo_db_city" VALUES(5344,'Grover','Grover, Pennsylvania',6133,44);
INSERT INTO "django_geo_db_city" VALUES(5345,'Hughesville','Hughesville, Pennsylvania',6475,44);
INSERT INTO "django_geo_db_city" VALUES(5346,'Hyner','Hyner, Pennsylvania',6476,44);
INSERT INTO "django_geo_db_city" VALUES(5347,'Jersey Mills','Jersey Mills, Pennsylvania',6477,44);
INSERT INTO "django_geo_db_city" VALUES(5348,'Watson','Watson, Pennsylvania',6479,44);
INSERT INTO "django_geo_db_city" VALUES(5349,'Lairdsville','Lairdsville, Pennsylvania',6480,44);
INSERT INTO "django_geo_db_city" VALUES(5350,'Leroy','Leroy, Pennsylvania',6133,44);
INSERT INTO "django_geo_db_city" VALUES(5351,'Linden','Linden, Pennsylvania',6481,44);
INSERT INTO "django_geo_db_city" VALUES(5352,'Lock Haven','Lock Haven, Pennsylvania',6482,44);
INSERT INTO "django_geo_db_city" VALUES(5353,'Loganton','Loganton, Pennsylvania',6483,44);
INSERT INTO "django_geo_db_city" VALUES(5354,'McElhattan','McElhattan, Pennsylvania',6484,44);
INSERT INTO "django_geo_db_city" VALUES(5355,'McEwensville','McEwensville, Pennsylvania',6485,44);
INSERT INTO "django_geo_db_city" VALUES(5356,'Mackeyville','Mackeyville, Pennsylvania',6486,44);
INSERT INTO "django_geo_db_city" VALUES(5357,'Mill Hall','Mill Hall, Pennsylvania',6487,44);
INSERT INTO "django_geo_db_city" VALUES(5358,'Montgomery','Montgomery, Pennsylvania',6488,44);
INSERT INTO "django_geo_db_city" VALUES(5359,'Montoursville','Montoursville, Pennsylvania',6489,44);
INSERT INTO "django_geo_db_city" VALUES(5360,'Muncy','Muncy, Pennsylvania',6490,44);
INSERT INTO "django_geo_db_city" VALUES(5361,'Wolf','Wolf, Pennsylvania',6491,44);
INSERT INTO "django_geo_db_city" VALUES(5362,'Muncy Valley','Muncy Valley, Pennsylvania',6492,44);
INSERT INTO "django_geo_db_city" VALUES(5363,'Nisbet','Nisbet, Pennsylvania',6493,44);
INSERT INTO "django_geo_db_city" VALUES(5364,'North Bend','North Bend, Pennsylvania',6494,44);
INSERT INTO "django_geo_db_city" VALUES(5365,'Picture Rocks','Picture Rocks, Pennsylvania',6495,44);
INSERT INTO "django_geo_db_city" VALUES(5366,'Ralston','Ralston, Pennsylvania',6496,44);
INSERT INTO "django_geo_db_city" VALUES(5367,'Renovo','Renovo, Pennsylvania',6497,44);
INSERT INTO "django_geo_db_city" VALUES(5368,'Roaring Branch','Roaring Branch, Pennsylvania',6498,44);
INSERT INTO "django_geo_db_city" VALUES(5369,'Salona','Salona, Pennsylvania',6499,44);
INSERT INTO "django_geo_db_city" VALUES(5370,'Shunk','Shunk, Pennsylvania',6500,44);
INSERT INTO "django_geo_db_city" VALUES(5371,'Slate Run','Slate Run, Pennsylvania',6466,44);
INSERT INTO "django_geo_db_city" VALUES(5372,'Trout Run','Trout Run, Pennsylvania',6501,44);
INSERT INTO "django_geo_db_city" VALUES(5373,'Turbotville','Turbotville, Pennsylvania',6502,44);
INSERT INTO "django_geo_db_city" VALUES(5374,'Tylersville','Tylersville, Pennsylvania',6503,44);
INSERT INTO "django_geo_db_city" VALUES(5375,'Unityville','Unityville, Pennsylvania',6504,44);
INSERT INTO "django_geo_db_city" VALUES(5376,'Waterville','Waterville, Pennsylvania',6505,44);
INSERT INTO "django_geo_db_city" VALUES(5377,'Watsontown','Watsontown, Pennsylvania',6506,44);
INSERT INTO "django_geo_db_city" VALUES(5378,'Westport','Westport, Pennsylvania',6507,44);
INSERT INTO "django_geo_db_city" VALUES(5379,'Woolrich','Woolrich, Pennsylvania',6508,44);
INSERT INTO "django_geo_db_city" VALUES(5380,'Sunbury','Sunbury, Pennsylvania',6510,44);
INSERT INTO "django_geo_db_city" VALUES(5381,'Allenwood','Allenwood, Pennsylvania',6511,44);
INSERT INTO "django_geo_db_city" VALUES(5382,'Beaver Springs','Beaver Springs, Pennsylvania',6512,44);
INSERT INTO "django_geo_db_city" VALUES(5383,'Beavertown','Beavertown, Pennsylvania',6513,44);
INSERT INTO "django_geo_db_city" VALUES(5384,'Benton','Benton, Pennsylvania',6514,44);
INSERT INTO "django_geo_db_city" VALUES(5385,'Bloomsburg','Bloomsburg, Pennsylvania',6515,44);
INSERT INTO "django_geo_db_city" VALUES(5386,'Catawissa','Catawissa, Pennsylvania',6516,44);
INSERT INTO "django_geo_db_city" VALUES(5387,'Danville','Danville, Pennsylvania',6517,44);
INSERT INTO "django_geo_db_city" VALUES(5388,'Dornsife','Dornsife, Pennsylvania',6519,44);
INSERT INTO "django_geo_db_city" VALUES(5389,'Elysburg','Elysburg, Pennsylvania',6520,44);
INSERT INTO "django_geo_db_city" VALUES(5390,'Excelsior','Excelsior, Pennsylvania',6521,44);
INSERT INTO "django_geo_db_city" VALUES(5391,'Freeburg','Freeburg, Pennsylvania',6522,44);
INSERT INTO "django_geo_db_city" VALUES(5392,'Gowen City','Gowen City, Pennsylvania',6523,44);
INSERT INTO "django_geo_db_city" VALUES(5393,'Hartleton','Hartleton, Pennsylvania',6524,44);
INSERT INTO "django_geo_db_city" VALUES(5394,'Herndon','Herndon, Pennsylvania',6525,44);
INSERT INTO "django_geo_db_city" VALUES(5395,'Hummels Wharf','Hummels Wharf, Pennsylvania',6526,44);
INSERT INTO "django_geo_db_city" VALUES(5396,'Marion Heights','Marion Heights, Pennsylvania',6527,44);
INSERT INTO "django_geo_db_city" VALUES(5397,'Kreamer','Kreamer, Pennsylvania',6528,44);
INSERT INTO "django_geo_db_city" VALUES(5398,'Kulpmont','Kulpmont, Pennsylvania',6529,44);
INSERT INTO "django_geo_db_city" VALUES(5399,'Laurelton','Laurelton, Pennsylvania',6530,44);
INSERT INTO "django_geo_db_city" VALUES(5400,'Leck Kill','Leck Kill, Pennsylvania',6531,44);
INSERT INTO "django_geo_db_city" VALUES(5401,'Lewisburg','Lewisburg, Pennsylvania',6532,44);
INSERT INTO "django_geo_db_city" VALUES(5402,'Light Street','Light Street, Pennsylvania',6533,44);
INSERT INTO "django_geo_db_city" VALUES(5403,'Locust Gap','Locust Gap, Pennsylvania',6534,44);
INSERT INTO "django_geo_db_city" VALUES(5404,'McClure','McClure, Pennsylvania',6535,44);
INSERT INTO "django_geo_db_city" VALUES(5405,'Middleburg','Middleburg, Pennsylvania',6536,44);
INSERT INTO "django_geo_db_city" VALUES(5406,'Mifflinburg','Mifflinburg, Pennsylvania',6538,44);
INSERT INTO "django_geo_db_city" VALUES(5407,'Millmont','Millmont, Pennsylvania',6539,44);
INSERT INTO "django_geo_db_city" VALUES(5408,'Millville','Millville, Pennsylvania',6540,44);
INSERT INTO "django_geo_db_city" VALUES(5409,'Milton','Milton, Pennsylvania',6541,44);
INSERT INTO "django_geo_db_city" VALUES(5410,'Montandon','Montandon, Pennsylvania',6542,44);
INSERT INTO "django_geo_db_city" VALUES(5411,'Mount Carmel','Mount Carmel, Pennsylvania',6543,44);
INSERT INTO "django_geo_db_city" VALUES(5412,'Mount Pleasant Mills','Mount Pleasant Mills, Pennsylvania',6544,44);
INSERT INTO "django_geo_db_city" VALUES(5413,'New Berlin','New Berlin, Pennsylvania',6545,44);
INSERT INTO "django_geo_db_city" VALUES(5414,'New Columbia','New Columbia, Pennsylvania',6546,44);
INSERT INTO "django_geo_db_city" VALUES(5415,'Northumberland','Northumberland, Pennsylvania',6547,44);
INSERT INTO "django_geo_db_city" VALUES(5416,'Numidia','Numidia, Pennsylvania',6548,44);
INSERT INTO "django_geo_db_city" VALUES(5417,'Orangeville','Orangeville, Pennsylvania',6549,44);
INSERT INTO "django_geo_db_city" VALUES(5418,'Paxinos','Paxinos, Pennsylvania',6550,44);
INSERT INTO "django_geo_db_city" VALUES(5419,'Paxtonville','Paxtonville, Pennsylvania',6551,44);
INSERT INTO "django_geo_db_city" VALUES(5420,'Penns Creek','Penns Creek, Pennsylvania',6552,44);
INSERT INTO "django_geo_db_city" VALUES(5421,'Port Trevorton','Port Trevorton, Pennsylvania',6553,44);
INSERT INTO "django_geo_db_city" VALUES(5422,'Potts Grove','Potts Grove, Pennsylvania',6554,44);
INSERT INTO "django_geo_db_city" VALUES(5423,'Coal Township','Coal Township, Pennsylvania',6555,44);
INSERT INTO "django_geo_db_city" VALUES(5424,'Rebuck','Rebuck, Pennsylvania',6556,44);
INSERT INTO "django_geo_db_city" VALUES(5425,'Riverside','Riverside, Pennsylvania',6557,44);
INSERT INTO "django_geo_db_city" VALUES(5426,'Selinsgrove','Selinsgrove, Pennsylvania',6558,44);
INSERT INTO "django_geo_db_city" VALUES(5427,'Shamokin','Shamokin, Pennsylvania',6559,44);
INSERT INTO "django_geo_db_city" VALUES(5428,'Shamokin Dam','Shamokin Dam, Pennsylvania',6560,44);
INSERT INTO "django_geo_db_city" VALUES(5429,'Snydertown','Snydertown, Pennsylvania',6561,44);
INSERT INTO "django_geo_db_city" VALUES(5430,'Stillwater','Stillwater, Pennsylvania',6562,44);
INSERT INTO "django_geo_db_city" VALUES(5431,'Swengel','Swengel, Pennsylvania',6563,44);
INSERT INTO "django_geo_db_city" VALUES(5432,'Trevorton','Trevorton, Pennsylvania',6564,44);
INSERT INTO "django_geo_db_city" VALUES(5433,'Troxelville','Troxelville, Pennsylvania',6565,44);
INSERT INTO "django_geo_db_city" VALUES(5434,'Vicksburg','Vicksburg, Pennsylvania',6563,44);
INSERT INTO "django_geo_db_city" VALUES(5435,'Washingtonville','Washingtonville, Pennsylvania',6566,44);
INSERT INTO "django_geo_db_city" VALUES(5436,'Weikert','Weikert, Pennsylvania',6567,44);
INSERT INTO "django_geo_db_city" VALUES(5437,'West Milton','West Milton, Pennsylvania',6568,44);
INSERT INTO "django_geo_db_city" VALUES(5438,'White Deer','White Deer, Pennsylvania',6569,44);
INSERT INTO "django_geo_db_city" VALUES(5439,'Wilburton','Wilburton, Pennsylvania',6570,44);
INSERT INTO "django_geo_db_city" VALUES(5440,'Winfield','Winfield, Pennsylvania',6571,44);
INSERT INTO "django_geo_db_city" VALUES(5441,'Pottsville','Pottsville, Pennsylvania',6572,44);
INSERT INTO "django_geo_db_city" VALUES(5442,'Aristes','Aristes, Pennsylvania',6573,44);
INSERT INTO "django_geo_db_city" VALUES(5443,'Ashland','Ashland, Pennsylvania',6574,44);
INSERT INTO "django_geo_db_city" VALUES(5444,'Auburn','Auburn, Pennsylvania',6575,44);
INSERT INTO "django_geo_db_city" VALUES(5445,'Branchdale','Branchdale, Pennsylvania',6576,44);
INSERT INTO "django_geo_db_city" VALUES(5446,'Brockton','Brockton, Pennsylvania',6577,44);
INSERT INTO "django_geo_db_city" VALUES(5447,'Centralia','Centralia, Pennsylvania',6578,44);
INSERT INTO "django_geo_db_city" VALUES(5448,'Cressona','Cressona, Pennsylvania',6579,44);
INSERT INTO "django_geo_db_city" VALUES(5449,'Cumbola','Cumbola, Pennsylvania',6580,44);
INSERT INTO "django_geo_db_city" VALUES(5450,'Frackville','Frackville, Pennsylvania',6581,44);
INSERT INTO "django_geo_db_city" VALUES(5451,'Friedensburg','Friedensburg, Pennsylvania',6583,44);
INSERT INTO "django_geo_db_city" VALUES(5452,'Gilberton','Gilberton, Pennsylvania',6584,44);
INSERT INTO "django_geo_db_city" VALUES(5453,'Girardville','Girardville, Pennsylvania',6585,44);
INSERT INTO "django_geo_db_city" VALUES(5454,'Gordon','Gordon, Pennsylvania',6586,44);
INSERT INTO "django_geo_db_city" VALUES(5455,'Hegins','Hegins, Pennsylvania',6587,44);
INSERT INTO "django_geo_db_city" VALUES(5456,'Klingerstown','Klingerstown, Pennsylvania',6588,44);
INSERT INTO "django_geo_db_city" VALUES(5457,'Landingville','Landingville, Pennsylvania',6589,44);
INSERT INTO "django_geo_db_city" VALUES(5458,'Lavelle','Lavelle, Pennsylvania',6590,44);
INSERT INTO "django_geo_db_city" VALUES(5459,'Llewellyn','Llewellyn, Pennsylvania',6591,44);
INSERT INTO "django_geo_db_city" VALUES(5460,'Locustdale','Locustdale, Pennsylvania',6592,44);
INSERT INTO "django_geo_db_city" VALUES(5461,'Lost Creek','Lost Creek, Pennsylvania',6593,44);
INSERT INTO "django_geo_db_city" VALUES(5462,'Mahanoy City','Mahanoy City, Pennsylvania',6594,44);
INSERT INTO "django_geo_db_city" VALUES(5463,'Mahanoy Plane','Mahanoy Plane, Pennsylvania',6595,44);
INSERT INTO "django_geo_db_city" VALUES(5464,'Mar Lin','Mar Lin, Pennsylvania',6596,44);
INSERT INTO "django_geo_db_city" VALUES(5465,'Mary D','Mary D, Pennsylvania',6597,44);
INSERT INTO "django_geo_db_city" VALUES(5466,'Middleport','Middleport, Pennsylvania',6598,44);
INSERT INTO "django_geo_db_city" VALUES(5467,'Minersville','Minersville, Pennsylvania',6599,44);
INSERT INTO "django_geo_db_city" VALUES(5468,'Muir','Muir, Pennsylvania',6600,44);
INSERT INTO "django_geo_db_city" VALUES(5469,'New Philadelphia','New Philadelphia, Pennsylvania',6601,44);
INSERT INTO "django_geo_db_city" VALUES(5470,'New Ringgold','New Ringgold, Pennsylvania',6602,44);
INSERT INTO "django_geo_db_city" VALUES(5471,'Orwigsburg','Orwigsburg, Pennsylvania',6603,44);
INSERT INTO "django_geo_db_city" VALUES(5472,'Pine Grove','Pine Grove, Pennsylvania',6604,44);
INSERT INTO "django_geo_db_city" VALUES(5473,'Pitman','Pitman, Pennsylvania',6605,44);
INSERT INTO "django_geo_db_city" VALUES(5474,'Port Carbon','Port Carbon, Pennsylvania',6606,44);
INSERT INTO "django_geo_db_city" VALUES(5475,'Ravine','Ravine, Pennsylvania',6589,44);
INSERT INTO "django_geo_db_city" VALUES(5476,'Ringtown','Ringtown, Pennsylvania',6607,44);
INSERT INTO "django_geo_db_city" VALUES(5477,'Sacramento','Sacramento, Pennsylvania',6608,44);
INSERT INTO "django_geo_db_city" VALUES(5478,'Saint Clair','Saint Clair, Pennsylvania',6609,44);
INSERT INTO "django_geo_db_city" VALUES(5479,'Schuylkill Haven','Schuylkill Haven, Pennsylvania',6610,44);
INSERT INTO "django_geo_db_city" VALUES(5480,'Seltzer','Seltzer, Pennsylvania',6611,44);
INSERT INTO "django_geo_db_city" VALUES(5481,'Shenandoah','Shenandoah, Pennsylvania',6612,44);
INSERT INTO "django_geo_db_city" VALUES(5482,'Spring Glen','Spring Glen, Pennsylvania',6613,44);
INSERT INTO "django_geo_db_city" VALUES(5483,'Summit Station','Summit Station, Pennsylvania',6614,44);
INSERT INTO "django_geo_db_city" VALUES(5484,'Tower City','Tower City, Pennsylvania',6615,44);
INSERT INTO "django_geo_db_city" VALUES(5485,'Tremont','Tremont, Pennsylvania',6616,44);
INSERT INTO "django_geo_db_city" VALUES(5486,'Tuscarora','Tuscarora, Pennsylvania',6617,44);
INSERT INTO "django_geo_db_city" VALUES(5487,'Valley View','Valley View, Pennsylvania',6618,44);
INSERT INTO "django_geo_db_city" VALUES(5488,'Zion Grove','Zion Grove, Pennsylvania',6619,44);
INSERT INTO "django_geo_db_city" VALUES(5489,'Lehigh Valley','Lehigh Valley, Pennsylvania',6620,44);
INSERT INTO "django_geo_db_city" VALUES(5490,'Ackermanville','Ackermanville, Pennsylvania',6620,44);
INSERT INTO "django_geo_db_city" VALUES(5491,'Alburtis','Alburtis, Pennsylvania',6622,44);
INSERT INTO "django_geo_db_city" VALUES(5492,'Aquashicola','Aquashicola, Pennsylvania',6623,44);
INSERT INTO "django_geo_db_city" VALUES(5493,'Bangor','Bangor, Pennsylvania',6624,44);
INSERT INTO "django_geo_db_city" VALUES(5494,'Bath','Bath, Pennsylvania',6625,44);
INSERT INTO "django_geo_db_city" VALUES(5495,'Bethlehem','Bethlehem, Pennsylvania',6626,44);
INSERT INTO "django_geo_db_city" VALUES(5496,'Hazleton','Hazleton, Pennsylvania',6630,44);
INSERT INTO "django_geo_db_city" VALUES(5497,'Bowmanstown','Bowmanstown, Pennsylvania',6632,44);
INSERT INTO "django_geo_db_city" VALUES(5498,'Breinigsville','Breinigsville, Pennsylvania',6633,44);
INSERT INTO "django_geo_db_city" VALUES(5499,'Catasauqua','Catasauqua, Pennsylvania',6634,44);
INSERT INTO "django_geo_db_city" VALUES(5500,'Center Valley','Center Valley, Pennsylvania',6635,44);
INSERT INTO "django_geo_db_city" VALUES(5501,'Cherryville','Cherryville, Pennsylvania',6636,44);
INSERT INTO "django_geo_db_city" VALUES(5502,'Coopersburg','Coopersburg, Pennsylvania',6637,44);
INSERT INTO "django_geo_db_city" VALUES(5503,'Coplay','Coplay, Pennsylvania',6638,44);
INSERT INTO "django_geo_db_city" VALUES(5504,'Danielsville','Danielsville, Pennsylvania',6639,44);
INSERT INTO "django_geo_db_city" VALUES(5505,'Durham','Durham, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5506,'Easton','Easton, Pennsylvania',6641,44);
INSERT INTO "django_geo_db_city" VALUES(5507,'East Greenville','East Greenville, Pennsylvania',6642,44);
INSERT INTO "django_geo_db_city" VALUES(5508,'East Texas','East Texas, Pennsylvania',6646,44);
INSERT INTO "django_geo_db_city" VALUES(5509,'Emmaus','Emmaus, Pennsylvania',6647,44);
INSERT INTO "django_geo_db_city" VALUES(5510,'Flicksville','Flicksville, Pennsylvania',6620,44);
INSERT INTO "django_geo_db_city" VALUES(5511,'Fogelsville','Fogelsville, Pennsylvania',6648,44);
INSERT INTO "django_geo_db_city" VALUES(5512,'Whitehall','Whitehall, Pennsylvania',6649,44);
INSERT INTO "django_geo_db_city" VALUES(5513,'Germansville','Germansville, Pennsylvania',6650,44);
INSERT INTO "django_geo_db_city" VALUES(5514,'Green Lane','Green Lane, Pennsylvania',6651,44);
INSERT INTO "django_geo_db_city" VALUES(5515,'Hellertown','Hellertown, Pennsylvania',6652,44);
INSERT INTO "django_geo_db_city" VALUES(5516,'Hereford','Hereford, Pennsylvania',6653,44);
INSERT INTO "django_geo_db_city" VALUES(5517,'Kunkletown','Kunkletown, Pennsylvania',6654,44);
INSERT INTO "django_geo_db_city" VALUES(5518,'Laurys Station','Laurys Station, Pennsylvania',6655,44);
INSERT INTO "django_geo_db_city" VALUES(5519,'Limeport','Limeport, Pennsylvania',6656,44);
INSERT INTO "django_geo_db_city" VALUES(5520,'Macungie','Macungie, Pennsylvania',6657,44);
INSERT INTO "django_geo_db_city" VALUES(5521,'Martins Creek','Martins Creek, Pennsylvania',6658,44);
INSERT INTO "django_geo_db_city" VALUES(5522,'Nazareth','Nazareth, Pennsylvania',6659,44);
INSERT INTO "django_geo_db_city" VALUES(5523,'Neffs','Neffs, Pennsylvania',6660,44);
INSERT INTO "django_geo_db_city" VALUES(5524,'New Tripoli','New Tripoli, Pennsylvania',6661,44);
INSERT INTO "django_geo_db_city" VALUES(5525,'Northampton','Northampton, Pennsylvania',6662,44);
INSERT INTO "django_geo_db_city" VALUES(5526,'Old Zionsville','Old Zionsville, Pennsylvania',6620,44);
INSERT INTO "django_geo_db_city" VALUES(5527,'Orefield','Orefield, Pennsylvania',6663,44);
INSERT INTO "django_geo_db_city" VALUES(5528,'Palm','Palm, Pennsylvania',6664,44);
INSERT INTO "django_geo_db_city" VALUES(5529,'Palmerton','Palmerton, Pennsylvania',6665,44);
INSERT INTO "django_geo_db_city" VALUES(5530,'Pen Argyl','Pen Argyl, Pennsylvania',6666,44);
INSERT INTO "django_geo_db_city" VALUES(5531,'Pennsburg','Pennsburg, Pennsylvania',6667,44);
INSERT INTO "django_geo_db_city" VALUES(5532,'Perkiomenville','Perkiomenville, Pennsylvania',6668,44);
INSERT INTO "django_geo_db_city" VALUES(5533,'Red Hill','Red Hill, Pennsylvania',6669,44);
INSERT INTO "django_geo_db_city" VALUES(5534,'Riegelsville','Riegelsville, Pennsylvania',6670,44);
INSERT INTO "django_geo_db_city" VALUES(5535,'Schnecksville','Schnecksville, Pennsylvania',6671,44);
INSERT INTO "django_geo_db_city" VALUES(5536,'Slatedale','Slatedale, Pennsylvania',6672,44);
INSERT INTO "django_geo_db_city" VALUES(5537,'Slatington','Slatington, Pennsylvania',6673,44);
INSERT INTO "django_geo_db_city" VALUES(5538,'Springtown','Springtown, Pennsylvania',6674,44);
INSERT INTO "django_geo_db_city" VALUES(5539,'Stockertown','Stockertown, Pennsylvania',6675,44);
INSERT INTO "django_geo_db_city" VALUES(5540,'Sumneytown','Sumneytown, Pennsylvania',6676,44);
INSERT INTO "django_geo_db_city" VALUES(5541,'Tatamy','Tatamy, Pennsylvania',6677,44);
INSERT INTO "django_geo_db_city" VALUES(5542,'Treichlers','Treichlers, Pennsylvania',6678,44);
INSERT INTO "django_geo_db_city" VALUES(5543,'Trexlertown','Trexlertown, Pennsylvania',6679,44);
INSERT INTO "django_geo_db_city" VALUES(5544,'Walnutport','Walnutport, Pennsylvania',6680,44);
INSERT INTO "django_geo_db_city" VALUES(5545,'Wind Gap','Wind Gap, Pennsylvania',6681,44);
INSERT INTO "django_geo_db_city" VALUES(5546,'Zionsville','Zionsville, Pennsylvania',6682,44);
INSERT INTO "django_geo_db_city" VALUES(5547,'South Whitehall','South Whitehall, Pennsylvania',6683,44);
INSERT INTO "django_geo_db_city" VALUES(5548,'Allentown','Allentown, Pennsylvania',6684,44);
INSERT INTO "django_geo_db_city" VALUES(5549,'Tunkhannock','Tunkhannock, Pennsylvania',6689,44);
INSERT INTO "django_geo_db_city" VALUES(5550,'Albrightsville','Albrightsville, Pennsylvania',6694,44);
INSERT INTO "django_geo_db_city" VALUES(5551,'Andreas','Andreas, Pennsylvania',6695,44);
INSERT INTO "django_geo_db_city" VALUES(5552,'Ashfield','Ashfield, Pennsylvania',6696,44);
INSERT INTO "django_geo_db_city" VALUES(5553,'Barnesville','Barnesville, Pennsylvania',6697,44);
INSERT INTO "django_geo_db_city" VALUES(5554,'Beaver Meadows','Beaver Meadows, Pennsylvania',6698,44);
INSERT INTO "django_geo_db_city" VALUES(5555,'Coaldale','Coaldale, Pennsylvania',6699,44);
INSERT INTO "django_geo_db_city" VALUES(5556,'Conyngham','Conyngham, Pennsylvania',6700,44);
INSERT INTO "django_geo_db_city" VALUES(5557,'Delano','Delano, Pennsylvania',6701,44);
INSERT INTO "django_geo_db_city" VALUES(5558,'Drifton','Drifton, Pennsylvania',6702,44);
INSERT INTO "django_geo_db_city" VALUES(5559,'Drums','Drums, Pennsylvania',6703,44);
INSERT INTO "django_geo_db_city" VALUES(5560,'Ebervale','Ebervale, Pennsylvania',6704,44);
INSERT INTO "django_geo_db_city" VALUES(5561,'Freeland','Freeland, Pennsylvania',6705,44);
INSERT INTO "django_geo_db_city" VALUES(5562,'Harleigh','Harleigh, Pennsylvania',6706,44);
INSERT INTO "django_geo_db_city" VALUES(5563,'Jim Thorpe','Jim Thorpe, Pennsylvania',6707,44);
INSERT INTO "django_geo_db_city" VALUES(5564,'Junedale','Junedale, Pennsylvania',6708,44);
INSERT INTO "django_geo_db_city" VALUES(5565,'Kelayres','Kelayres, Pennsylvania',6709,44);
INSERT INTO "django_geo_db_city" VALUES(5566,'Lansford','Lansford, Pennsylvania',6710,44);
INSERT INTO "django_geo_db_city" VALUES(5567,'Lattimer Mines','Lattimer Mines, Pennsylvania',6711,44);
INSERT INTO "django_geo_db_city" VALUES(5568,'Lehighton','Lehighton, Pennsylvania',6712,44);
INSERT INTO "django_geo_db_city" VALUES(5569,'Mcadoo','Mcadoo, Pennsylvania',6713,44);
INSERT INTO "django_geo_db_city" VALUES(5570,'Milnesville','Milnesville, Pennsylvania',6714,44);
INSERT INTO "django_geo_db_city" VALUES(5571,'Nesquehoning','Nesquehoning, Pennsylvania',6715,44);
INSERT INTO "django_geo_db_city" VALUES(5572,'Nuremberg','Nuremberg, Pennsylvania',6716,44);
INSERT INTO "django_geo_db_city" VALUES(5573,'Oneida','Oneida, Pennsylvania',6717,44);
INSERT INTO "django_geo_db_city" VALUES(5574,'Pardeesville','Pardeesville, Pennsylvania',6718,44);
INSERT INTO "django_geo_db_city" VALUES(5575,'Parryville','Parryville, Pennsylvania',6719,44);
INSERT INTO "django_geo_db_city" VALUES(5576,'Quakake','Quakake, Pennsylvania',6720,44);
INSERT INTO "django_geo_db_city" VALUES(5577,'Rock Glen','Rock Glen, Pennsylvania',6721,44);
INSERT INTO "django_geo_db_city" VALUES(5578,'Saint Johns','Saint Johns, Pennsylvania',6722,44);
INSERT INTO "django_geo_db_city" VALUES(5579,'Sheppton','Sheppton, Pennsylvania',6723,44);
INSERT INTO "django_geo_db_city" VALUES(5580,'Sugarloaf','Sugarloaf, Pennsylvania',6724,44);
INSERT INTO "django_geo_db_city" VALUES(5581,'Summit Hill','Summit Hill, Pennsylvania',6725,44);
INSERT INTO "django_geo_db_city" VALUES(5582,'Sybertsville','Sybertsville, Pennsylvania',6726,44);
INSERT INTO "django_geo_db_city" VALUES(5583,'Tamaqua','Tamaqua, Pennsylvania',6727,44);
INSERT INTO "django_geo_db_city" VALUES(5584,'Tresckow','Tresckow, Pennsylvania',6728,44);
INSERT INTO "django_geo_db_city" VALUES(5585,'Weatherly','Weatherly, Pennsylvania',6729,44);
INSERT INTO "django_geo_db_city" VALUES(5586,'Weston','Weston, Pennsylvania',6730,44);
INSERT INTO "django_geo_db_city" VALUES(5587,'East Stroudsburg','East Stroudsburg, Pennsylvania',6731,44);
INSERT INTO "django_geo_db_city" VALUES(5588,'Analomink','Analomink, Pennsylvania',6732,44);
INSERT INTO "django_geo_db_city" VALUES(5589,'Bartonsville','Bartonsville, Pennsylvania',6733,44);
INSERT INTO "django_geo_db_city" VALUES(5590,'Brodheadsville','Brodheadsville, Pennsylvania',6734,44);
INSERT INTO "django_geo_db_city" VALUES(5591,'Buck Hill Falls','Buck Hill Falls, Pennsylvania',6735,44);
INSERT INTO "django_geo_db_city" VALUES(5592,'Bushkill','Bushkill, Pennsylvania',6736,44);
INSERT INTO "django_geo_db_city" VALUES(5593,'Canadensis','Canadensis, Pennsylvania',6737,44);
INSERT INTO "django_geo_db_city" VALUES(5594,'Cresco','Cresco, Pennsylvania',6738,44);
INSERT INTO "django_geo_db_city" VALUES(5595,'Delaware Water Gap','Delaware Water Gap, Pennsylvania',6739,44);
INSERT INTO "django_geo_db_city" VALUES(5596,'Dingmans Ferry','Dingmans Ferry, Pennsylvania',6740,44);
INSERT INTO "django_geo_db_city" VALUES(5597,'Effort','Effort, Pennsylvania',6741,44);
INSERT INTO "django_geo_db_city" VALUES(5598,'Gilbert','Gilbert, Pennsylvania',6742,44);
INSERT INTO "django_geo_db_city" VALUES(5599,'Henryville','Henryville, Pennsylvania',6743,44);
INSERT INTO "django_geo_db_city" VALUES(5600,'Kresgeville','Kresgeville, Pennsylvania',6744,44);
INSERT INTO "django_geo_db_city" VALUES(5601,'Long Pond','Long Pond, Pennsylvania',6745,44);
INSERT INTO "django_geo_db_city" VALUES(5602,'Marshalls Creek','Marshalls Creek, Pennsylvania',6746,44);
INSERT INTO "django_geo_db_city" VALUES(5603,'Matamoras','Matamoras, Pennsylvania',6747,44);
INSERT INTO "django_geo_db_city" VALUES(5604,'Milford','Milford, Pennsylvania',6748,44);
INSERT INTO "django_geo_db_city" VALUES(5605,'Millrift','Millrift, Pennsylvania',6749,44);
INSERT INTO "django_geo_db_city" VALUES(5606,'Minisink Hills','Minisink Hills, Pennsylvania',6750,44);
INSERT INTO "django_geo_db_city" VALUES(5607,'Mountainhome','Mountainhome, Pennsylvania',6751,44);
INSERT INTO "django_geo_db_city" VALUES(5608,'Mount Bethel','Mount Bethel, Pennsylvania',6752,44);
INSERT INTO "django_geo_db_city" VALUES(5609,'Mount Pocono','Mount Pocono, Pennsylvania',6753,44);
INSERT INTO "django_geo_db_city" VALUES(5610,'Pocono Summit','Pocono Summit, Pennsylvania',6754,44);
INSERT INTO "django_geo_db_city" VALUES(5611,'Pocono Lake','Pocono Lake, Pennsylvania',6755,44);
INSERT INTO "django_geo_db_city" VALUES(5612,'Pocono Lake Preserve','Pocono Lake Preserve, Pennsylvania',6756,44);
INSERT INTO "django_geo_db_city" VALUES(5613,'Pocono Manor','Pocono Manor, Pennsylvania',6757,44);
INSERT INTO "django_geo_db_city" VALUES(5614,'Pocono Pines','Pocono Pines, Pennsylvania',6758,44);
INSERT INTO "django_geo_db_city" VALUES(5615,'Portland','Portland, Pennsylvania',6759,44);
INSERT INTO "django_geo_db_city" VALUES(5616,'Reeders','Reeders, Pennsylvania',6760,44);
INSERT INTO "django_geo_db_city" VALUES(5617,'Saylorsburg','Saylorsburg, Pennsylvania',6761,44);
INSERT INTO "django_geo_db_city" VALUES(5618,'Sciota','Sciota, Pennsylvania',6762,44);
INSERT INTO "django_geo_db_city" VALUES(5619,'Scotrun','Scotrun, Pennsylvania',6763,44);
INSERT INTO "django_geo_db_city" VALUES(5620,'Shawnee On Delaware','Shawnee On Delaware, Pennsylvania',6764,44);
INSERT INTO "django_geo_db_city" VALUES(5621,'Skytop','Skytop, Pennsylvania',6765,44);
INSERT INTO "django_geo_db_city" VALUES(5622,'Stroudsburg','Stroudsburg, Pennsylvania',6766,44);
INSERT INTO "django_geo_db_city" VALUES(5623,'Swiftwater','Swiftwater, Pennsylvania',6767,44);
INSERT INTO "django_geo_db_city" VALUES(5624,'Tamiment','Tamiment, Pennsylvania',6768,44);
INSERT INTO "django_geo_db_city" VALUES(5625,'Tannersville','Tannersville, Pennsylvania',6769,44);
INSERT INTO "django_geo_db_city" VALUES(5626,'Unity House','Unity House, Pennsylvania',6768,44);
INSERT INTO "django_geo_db_city" VALUES(5627,'Dingman','Dingman, Pennsylvania',6770,44);
INSERT INTO "django_geo_db_city" VALUES(5628,'Aldenville','Aldenville, Pennsylvania',6771,44);
INSERT INTO "django_geo_db_city" VALUES(5629,'Archbald','Archbald, Pennsylvania',6772,44);
INSERT INTO "django_geo_db_city" VALUES(5630,'Beach Lake','Beach Lake, Pennsylvania',6773,44);
INSERT INTO "django_geo_db_city" VALUES(5631,'Carbondale','Carbondale, Pennsylvania',6774,44);
INSERT INTO "django_geo_db_city" VALUES(5632,'Chinchilla','Chinchilla, Pennsylvania',6775,44);
INSERT INTO "django_geo_db_city" VALUES(5633,'Clarks Summit','Clarks Summit, Pennsylvania',6776,44);
INSERT INTO "django_geo_db_city" VALUES(5634,'Clifford','Clifford, Pennsylvania',6777,44);
INSERT INTO "django_geo_db_city" VALUES(5635,'Dalton','Dalton, Pennsylvania',6778,44);
INSERT INTO "django_geo_db_city" VALUES(5636,'Damascus','Damascus, Pennsylvania',6779,44);
INSERT INTO "django_geo_db_city" VALUES(5637,'Elmhurst','Elmhurst, Pennsylvania',6780,44);
INSERT INTO "django_geo_db_city" VALUES(5638,'Equinunk','Equinunk, Pennsylvania',6781,44);
INSERT INTO "django_geo_db_city" VALUES(5639,'Factoryville','Factoryville, Pennsylvania',6782,44);
INSERT INTO "django_geo_db_city" VALUES(5640,'Fleetville','Fleetville, Pennsylvania',6783,44);
INSERT INTO "django_geo_db_city" VALUES(5641,'Forest City','Forest City, Pennsylvania',6784,44);
INSERT INTO "django_geo_db_city" VALUES(5642,'Gouldsboro','Gouldsboro, Pennsylvania',6785,44);
INSERT INTO "django_geo_db_city" VALUES(5643,'Greeley','Greeley, Pennsylvania',6786,44);
INSERT INTO "django_geo_db_city" VALUES(5644,'Greentown','Greentown, Pennsylvania',6787,44);
INSERT INTO "django_geo_db_city" VALUES(5645,'Hamlin','Hamlin, Pennsylvania',6788,44);
INSERT INTO "django_geo_db_city" VALUES(5646,'Hawley','Hawley, Pennsylvania',6789,44);
INSERT INTO "django_geo_db_city" VALUES(5647,'Herrick Center','Herrick Center, Pennsylvania',6790,44);
INSERT INTO "django_geo_db_city" VALUES(5648,'Honesdale','Honesdale, Pennsylvania',6791,44);
INSERT INTO "django_geo_db_city" VALUES(5649,'Jermyn','Jermyn, Pennsylvania',6792,44);
INSERT INTO "django_geo_db_city" VALUES(5650,'Jessup','Jessup, Pennsylvania',6793,44);
INSERT INTO "django_geo_db_city" VALUES(5651,'Lackawaxen','Lackawaxen, Pennsylvania',6794,44);
INSERT INTO "django_geo_db_city" VALUES(5652,'Lake Ariel','Lake Ariel, Pennsylvania',6795,44);
INSERT INTO "django_geo_db_city" VALUES(5653,'Lake Como','Lake Como, Pennsylvania',6796,44);
INSERT INTO "django_geo_db_city" VALUES(5654,'Lakeville','Lakeville, Pennsylvania',6797,44);
INSERT INTO "django_geo_db_city" VALUES(5655,'Lakewood','Lakewood, Pennsylvania',6798,44);
INSERT INTO "django_geo_db_city" VALUES(5656,'La Plume','La Plume, Pennsylvania',6799,44);
INSERT INTO "django_geo_db_city" VALUES(5657,'Lenoxville','Lenoxville, Pennsylvania',6800,44);
INSERT INTO "django_geo_db_city" VALUES(5658,'Milanville','Milanville, Pennsylvania',6801,44);
INSERT INTO "django_geo_db_city" VALUES(5659,'Moscow','Moscow, Pennsylvania',6802,44);
INSERT INTO "django_geo_db_city" VALUES(5660,'Newfoundland','Newfoundland, Pennsylvania',6803,44);
INSERT INTO "django_geo_db_city" VALUES(5661,'Nicholson','Nicholson, Pennsylvania',6804,44);
INSERT INTO "django_geo_db_city" VALUES(5662,'Olyphant','Olyphant, Pennsylvania',6805,44);
INSERT INTO "django_geo_db_city" VALUES(5663,'Orson','Orson, Pennsylvania',6771,44);
INSERT INTO "django_geo_db_city" VALUES(5664,'Paupack','Paupack, Pennsylvania',6807,44);
INSERT INTO "django_geo_db_city" VALUES(5665,'Peckville','Peckville, Pennsylvania',6808,44);
INSERT INTO "django_geo_db_city" VALUES(5666,'Pleasant Mount','Pleasant Mount, Pennsylvania',6809,44);
INSERT INTO "django_geo_db_city" VALUES(5667,'Poyntelle','Poyntelle, Pennsylvania',6771,44);
INSERT INTO "django_geo_db_city" VALUES(5668,'Preston Park','Preston Park, Pennsylvania',6810,44);
INSERT INTO "django_geo_db_city" VALUES(5669,'Prompton','Prompton, Pennsylvania',6811,44);
INSERT INTO "django_geo_db_city" VALUES(5670,'Rowland','Rowland, Pennsylvania',6812,44);
INSERT INTO "django_geo_db_city" VALUES(5671,'Shohola','Shohola, Pennsylvania',6813,44);
INSERT INTO "django_geo_db_city" VALUES(5672,'South Canaan','South Canaan, Pennsylvania',6814,44);
INSERT INTO "django_geo_db_city" VALUES(5673,'South Sterling','South Sterling, Pennsylvania',6815,44);
INSERT INTO "django_geo_db_city" VALUES(5674,'Starlight','Starlight, Pennsylvania',6816,44);
INSERT INTO "django_geo_db_city" VALUES(5675,'Starrucca','Starrucca, Pennsylvania',6817,44);
INSERT INTO "django_geo_db_city" VALUES(5676,'Sterling','Sterling, Pennsylvania',6818,44);
INSERT INTO "django_geo_db_city" VALUES(5677,'Tafton','Tafton, Pennsylvania',6819,44);
INSERT INTO "django_geo_db_city" VALUES(5678,'Thompson','Thompson, Pennsylvania',6820,44);
INSERT INTO "django_geo_db_city" VALUES(5679,'Tobyhanna','Tobyhanna, Pennsylvania',6821,44);
INSERT INTO "django_geo_db_city" VALUES(5680,'Tyler Hill','Tyler Hill, Pennsylvania',6822,44);
INSERT INTO "django_geo_db_city" VALUES(5681,'Union Dale','Union Dale, Pennsylvania',6823,44);
INSERT INTO "django_geo_db_city" VALUES(5682,'Waverly','Waverly, Pennsylvania',6824,44);
INSERT INTO "django_geo_db_city" VALUES(5683,'Waymart','Waymart, Pennsylvania',6825,44);
INSERT INTO "django_geo_db_city" VALUES(5684,'White Mills','White Mills, Pennsylvania',6826,44);
INSERT INTO "django_geo_db_city" VALUES(5685,'Scranton','Scranton, Pennsylvania',6827,44);
INSERT INTO "django_geo_db_city" VALUES(5686,'Moosic','Moosic, Pennsylvania',6832,44);
INSERT INTO "django_geo_db_city" VALUES(5687,'Taylor','Taylor, Pennsylvania',6838,44);
INSERT INTO "django_geo_db_city" VALUES(5688,'Old Forge','Old Forge, Pennsylvania',6839,44);
INSERT INTO "django_geo_db_city" VALUES(5689,'Dickson City','Dickson City, Pennsylvania',6840,44);
INSERT INTO "django_geo_db_city" VALUES(5690,'Beach Haven','Beach Haven, Pennsylvania',6841,44);
INSERT INTO "django_geo_db_city" VALUES(5691,'Bear Creek','Bear Creek, Pennsylvania',6842,44);
INSERT INTO "django_geo_db_city" VALUES(5692,'Berwick','Berwick, Pennsylvania',6843,44);
INSERT INTO "django_geo_db_city" VALUES(5693,'Blakeslee','Blakeslee, Pennsylvania',6844,44);
INSERT INTO "django_geo_db_city" VALUES(5694,'Cambra','Cambra, Pennsylvania',6845,44);
INSERT INTO "django_geo_db_city" VALUES(5695,'Dallas','Dallas, Pennsylvania',6846,44);
INSERT INTO "django_geo_db_city" VALUES(5696,'Dushore','Dushore, Pennsylvania',6847,44);
INSERT INTO "django_geo_db_city" VALUES(5697,'Falls','Falls, Pennsylvania',6848,44);
INSERT INTO "django_geo_db_city" VALUES(5698,'Forksville','Forksville, Pennsylvania',6849,44);
INSERT INTO "django_geo_db_city" VALUES(5699,'Glen Lyon','Glen Lyon, Pennsylvania',6850,44);
INSERT INTO "django_geo_db_city" VALUES(5700,'Harveys Lake','Harveys Lake, Pennsylvania',6851,44);
INSERT INTO "django_geo_db_city" VALUES(5701,'Hillsgrove','Hillsgrove, Pennsylvania',6852,44);
INSERT INTO "django_geo_db_city" VALUES(5702,'Hunlock Creek','Hunlock Creek, Pennsylvania',6853,44);
INSERT INTO "django_geo_db_city" VALUES(5703,'Huntington Mills','Huntington Mills, Pennsylvania',6854,44);
INSERT INTO "django_geo_db_city" VALUES(5704,'Laceyville','Laceyville, Pennsylvania',6855,44);
INSERT INTO "django_geo_db_city" VALUES(5705,'Lake Harmony','Lake Harmony, Pennsylvania',6856,44);
INSERT INTO "django_geo_db_city" VALUES(5706,'Lake Winola','Lake Winola, Pennsylvania',6857,44);
INSERT INTO "django_geo_db_city" VALUES(5707,'Laporte','Laporte, Pennsylvania',6858,44);
INSERT INTO "django_geo_db_city" VALUES(5708,'Lehman','Lehman, Pennsylvania',6859,44);
INSERT INTO "django_geo_db_city" VALUES(5709,'Lopez','Lopez, Pennsylvania',6860,44);
INSERT INTO "django_geo_db_city" VALUES(5710,'Mehoopany','Mehoopany, Pennsylvania',6861,44);
INSERT INTO "django_geo_db_city" VALUES(5711,'Meshoppen','Meshoppen, Pennsylvania',6862,44);
INSERT INTO "django_geo_db_city" VALUES(5712,'Mifflinville','Mifflinville, Pennsylvania',6863,44);
INSERT INTO "django_geo_db_city" VALUES(5713,'Mildred','Mildred, Pennsylvania',6864,44);
INSERT INTO "django_geo_db_city" VALUES(5714,'Nanticoke','Nanticoke, Pennsylvania',6865,44);
INSERT INTO "django_geo_db_city" VALUES(5715,'Nescopeck','Nescopeck, Pennsylvania',6866,44);
INSERT INTO "django_geo_db_city" VALUES(5716,'Noxen','Noxen, Pennsylvania',6867,44);
INSERT INTO "django_geo_db_city" VALUES(5717,'Solebury','Solebury, Pennsylvania',6868,44);
INSERT INTO "django_geo_db_city" VALUES(5718,'Pittston','Pittston, Pennsylvania',6869,44);
INSERT INTO "django_geo_db_city" VALUES(5719,'Duryea','Duryea, Pennsylvania',6871,44);
INSERT INTO "django_geo_db_city" VALUES(5720,'Wyoming','Wyoming, Pennsylvania',6873,44);
INSERT INTO "django_geo_db_city" VALUES(5721,'Plymouth','Plymouth, Pennsylvania',6874,44);
INSERT INTO "django_geo_db_city" VALUES(5722,'Ransom','Ransom, Pennsylvania',6875,44);
INSERT INTO "django_geo_db_city" VALUES(5723,'Shawanese','Shawanese, Pennsylvania',6876,44);
INSERT INTO "django_geo_db_city" VALUES(5724,'Shickshinny','Shickshinny, Pennsylvania',6877,44);
INSERT INTO "django_geo_db_city" VALUES(5725,'Sweet Valley','Sweet Valley, Pennsylvania',6878,44);
INSERT INTO "django_geo_db_city" VALUES(5726,'Wapwallopen','Wapwallopen, Pennsylvania',6880,44);
INSERT INTO "django_geo_db_city" VALUES(5727,'White Haven','White Haven, Pennsylvania',6881,44);
INSERT INTO "django_geo_db_city" VALUES(5728,'Bridgeton','Bridgeton, Pennsylvania',6882,44);
INSERT INTO "django_geo_db_city" VALUES(5729,'Wilkes Barre','Wilkes Barre, Pennsylvania',6883,44);
INSERT INTO "django_geo_db_city" VALUES(5730,'Kingston','Kingston, Pennsylvania',6886,44);
INSERT INTO "django_geo_db_city" VALUES(5731,'Mountain Top','Mountain Top, Pennsylvania',6889,44);
INSERT INTO "django_geo_db_city" VALUES(5732,'Shavertown','Shavertown, Pennsylvania',6890,44);
INSERT INTO "django_geo_db_city" VALUES(5733,'Luzerne','Luzerne, Pennsylvania',6891,44);
INSERT INTO "django_geo_db_city" VALUES(5734,'Almedia','Almedia, Pennsylvania',6892,44);
INSERT INTO "django_geo_db_city" VALUES(5735,'Montrose','Montrose, Pennsylvania',6894,44);
INSERT INTO "django_geo_db_city" VALUES(5736,'Athens','Athens, Pennsylvania',6895,44);
INSERT INTO "django_geo_db_city" VALUES(5737,'Brackney','Brackney, Pennsylvania',6896,44);
INSERT INTO "django_geo_db_city" VALUES(5738,'Brooklyn','Brooklyn, Pennsylvania',6897,44);
INSERT INTO "django_geo_db_city" VALUES(5739,'Burlington','Burlington, Pennsylvania',6898,44);
INSERT INTO "django_geo_db_city" VALUES(5740,'Camptown','Camptown, Pennsylvania',6133,44);
INSERT INTO "django_geo_db_city" VALUES(5741,'Dimock','Dimock, Pennsylvania',6899,44);
INSERT INTO "django_geo_db_city" VALUES(5742,'East Smithfield','East Smithfield, Pennsylvania',6900,44);
INSERT INTO "django_geo_db_city" VALUES(5743,'Friendsville','Friendsville, Pennsylvania',6901,44);
INSERT INTO "django_geo_db_city" VALUES(5744,'Gibson','Gibson, Pennsylvania',6902,44);
INSERT INTO "django_geo_db_city" VALUES(5745,'Great Bend','Great Bend, Pennsylvania',6903,44);
INSERT INTO "django_geo_db_city" VALUES(5746,'Hallstead','Hallstead, Pennsylvania',6904,44);
INSERT INTO "django_geo_db_city" VALUES(5747,'Harford','Harford, Pennsylvania',6905,44);
INSERT INTO "django_geo_db_city" VALUES(5748,'Hop Bottom','Hop Bottom, Pennsylvania',6906,44);
INSERT INTO "django_geo_db_city" VALUES(5749,'Jackson','Jackson, Pennsylvania',6907,44);
INSERT INTO "django_geo_db_city" VALUES(5750,'Kingsley','Kingsley, Pennsylvania',6908,44);
INSERT INTO "django_geo_db_city" VALUES(5751,'Lanesboro','Lanesboro, Pennsylvania',6909,44);
INSERT INTO "django_geo_db_city" VALUES(5752,'Lawton','Lawton, Pennsylvania',6910,44);
INSERT INTO "django_geo_db_city" VALUES(5753,'Le Raysville','Le Raysville, Pennsylvania',6911,44);
INSERT INTO "django_geo_db_city" VALUES(5754,'Little Meadows','Little Meadows, Pennsylvania',6912,44);
INSERT INTO "django_geo_db_city" VALUES(5755,'Milan','Milan, Pennsylvania',6913,44);
INSERT INTO "django_geo_db_city" VALUES(5756,'Monroeton','Monroeton, Pennsylvania',6914,44);
INSERT INTO "django_geo_db_city" VALUES(5757,'New Albany','New Albany, Pennsylvania',6915,44);
INSERT INTO "django_geo_db_city" VALUES(5758,'New Milford','New Milford, Pennsylvania',6916,44);
INSERT INTO "django_geo_db_city" VALUES(5759,'Rome','Rome, Pennsylvania',6917,44);
INSERT INTO "django_geo_db_city" VALUES(5760,'Rushville','Rushville, Pennsylvania',6918,44);
INSERT INTO "django_geo_db_city" VALUES(5761,'Sayre','Sayre, Pennsylvania',6919,44);
INSERT INTO "django_geo_db_city" VALUES(5762,'South Gibson','South Gibson, Pennsylvania',6920,44);
INSERT INTO "django_geo_db_city" VALUES(5763,'South Montrose','South Montrose, Pennsylvania',6921,44);
INSERT INTO "django_geo_db_city" VALUES(5764,'Springville','Springville, Pennsylvania',6922,44);
INSERT INTO "django_geo_db_city" VALUES(5765,'Stevensville','Stevensville, Pennsylvania',6923,44);
INSERT INTO "django_geo_db_city" VALUES(5766,'Sugar Run','Sugar Run, Pennsylvania',6924,44);
INSERT INTO "django_geo_db_city" VALUES(5767,'Susquehanna','Susquehanna, Pennsylvania',6925,44);
INSERT INTO "django_geo_db_city" VALUES(5768,'Towanda','Towanda, Pennsylvania',6926,44);
INSERT INTO "django_geo_db_city" VALUES(5769,'Ulster','Ulster, Pennsylvania',6927,44);
INSERT INTO "django_geo_db_city" VALUES(5770,'Warren Center','Warren Center, Pennsylvania',6928,44);
INSERT INTO "django_geo_db_city" VALUES(5771,'Wyalusing','Wyalusing, Pennsylvania',6929,44);
INSERT INTO "django_geo_db_city" VALUES(5772,'Wysox','Wysox, Pennsylvania',6930,44);
INSERT INTO "django_geo_db_city" VALUES(5773,'Doylestown','Doylestown, Pennsylvania',6931,44);
INSERT INTO "django_geo_db_city" VALUES(5774,'Bedminster','Bedminster, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5775,'Blooming Glen','Blooming Glen, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5776,'Buckingham','Buckingham, Pennsylvania',6933,44);
INSERT INTO "django_geo_db_city" VALUES(5777,'Carversville','Carversville, Pennsylvania',6934,44);
INSERT INTO "django_geo_db_city" VALUES(5778,'Chalfont','Chalfont, Pennsylvania',6935,44);
INSERT INTO "django_geo_db_city" VALUES(5779,'Colmar','Colmar, Pennsylvania',6936,44);
INSERT INTO "django_geo_db_city" VALUES(5780,'Danboro','Danboro, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5781,'Dublin','Dublin, Pennsylvania',6937,44);
INSERT INTO "django_geo_db_city" VALUES(5782,'Earlington','Earlington, Pennsylvania',6938,44);
INSERT INTO "django_geo_db_city" VALUES(5783,'Erwinna','Erwinna, Pennsylvania',6939,44);
INSERT INTO "django_geo_db_city" VALUES(5784,'Ferndale','Ferndale, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5785,'Forest Grove','Forest Grove, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5786,'Fountainville','Fountainville, Pennsylvania',6940,44);
INSERT INTO "django_geo_db_city" VALUES(5787,'Franconia','Franconia, Pennsylvania',6941,44);
INSERT INTO "django_geo_db_city" VALUES(5788,'Furlong','Furlong, Pennsylvania',6942,44);
INSERT INTO "django_geo_db_city" VALUES(5789,'Gardenville','Gardenville, Pennsylvania',6943,44);
INSERT INTO "django_geo_db_city" VALUES(5790,'Hilltown','Hilltown, Pennsylvania',6944,44);
INSERT INTO "django_geo_db_city" VALUES(5791,'Holicong','Holicong, Pennsylvania',6945,44);
INSERT INTO "django_geo_db_city" VALUES(5792,'Jamison','Jamison, Pennsylvania',6946,44);
INSERT INTO "django_geo_db_city" VALUES(5793,'Kintnersville','Kintnersville, Pennsylvania',6947,44);
INSERT INTO "django_geo_db_city" VALUES(5794,'Lahaska','Lahaska, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5795,'Line Lexington','Line Lexington, Pennsylvania',6948,44);
INSERT INTO "django_geo_db_city" VALUES(5796,'Lumberville','Lumberville, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5797,'Mechanicsville','Mechanicsville, Pennsylvania',6949,44);
INSERT INTO "django_geo_db_city" VALUES(5798,'Milford Square','Milford Square, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5799,'Montgomeryville','Montgomeryville, Pennsylvania',6950,44);
INSERT INTO "django_geo_db_city" VALUES(5800,'New Hope','New Hope, Pennsylvania',6951,44);
INSERT INTO "django_geo_db_city" VALUES(5801,'Newtown','Newtown, Pennsylvania',6952,44);
INSERT INTO "django_geo_db_city" VALUES(5802,'Ottsville','Ottsville, Pennsylvania',6953,44);
INSERT INTO "django_geo_db_city" VALUES(5803,'Penns Park','Penns Park, Pennsylvania',6954,44);
INSERT INTO "django_geo_db_city" VALUES(5804,'Perkasie','Perkasie, Pennsylvania',6955,44);
INSERT INTO "django_geo_db_city" VALUES(5805,'Plumstead','Plumstead, Pennsylvania',6956,44);
INSERT INTO "django_geo_db_city" VALUES(5806,'Pineville','Pineville, Pennsylvania',6957,44);
INSERT INTO "django_geo_db_city" VALUES(5807,'Pipersville','Pipersville, Pennsylvania',6958,44);
INSERT INTO "django_geo_db_city" VALUES(5808,'Plumsteadville','Plumsteadville, Pennsylvania',6959,44);
INSERT INTO "django_geo_db_city" VALUES(5809,'Point Pleasant','Point Pleasant, Pennsylvania',6960,44);
INSERT INTO "django_geo_db_city" VALUES(5810,'Quakertown','Quakertown, Pennsylvania',6961,44);
INSERT INTO "django_geo_db_city" VALUES(5811,'Revere','Revere, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5812,'Richboro','Richboro, Pennsylvania',6962,44);
INSERT INTO "django_geo_db_city" VALUES(5813,'Richlandtown','Richlandtown, Pennsylvania',6963,44);
INSERT INTO "django_geo_db_city" VALUES(5814,'Rushland','Rushland, Pennsylvania',6964,44);
INSERT INTO "django_geo_db_city" VALUES(5815,'Salford','Salford, Pennsylvania',6965,44);
INSERT INTO "django_geo_db_city" VALUES(5816,'Salfordville','Salfordville, Pennsylvania',6966,44);
INSERT INTO "django_geo_db_city" VALUES(5817,'Sellersville','Sellersville, Pennsylvania',6967,44);
INSERT INTO "django_geo_db_city" VALUES(5818,'Silverdale','Silverdale, Pennsylvania',6968,44);
INSERT INTO "django_geo_db_city" VALUES(5819,'Souderton','Souderton, Pennsylvania',6969,44);
INSERT INTO "django_geo_db_city" VALUES(5820,'Spinnerstown','Spinnerstown, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5821,'Telford','Telford, Pennsylvania',6971,44);
INSERT INTO "django_geo_db_city" VALUES(5822,'Trumbauersville','Trumbauersville, Pennsylvania',6972,44);
INSERT INTO "django_geo_db_city" VALUES(5823,'Tylersport','Tylersport, Pennsylvania',6973,44);
INSERT INTO "django_geo_db_city" VALUES(5824,'Upper Black Eddy','Upper Black Eddy, Pennsylvania',6974,44);
INSERT INTO "django_geo_db_city" VALUES(5825,'Warminster','Warminster, Pennsylvania',6975,44);
INSERT INTO "django_geo_db_city" VALUES(5826,'Warrington','Warrington, Pennsylvania',6976,44);
INSERT INTO "django_geo_db_city" VALUES(5827,'Washington Crossing','Washington Crossing, Pennsylvania',6977,44);
INSERT INTO "django_geo_db_city" VALUES(5828,'Woxall','Woxall, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5829,'Wycombe','Wycombe, Pennsylvania',6979,44);
INSERT INTO "django_geo_db_city" VALUES(5830,'Zionhill','Zionhill, Pennsylvania',6640,44);
INSERT INTO "django_geo_db_city" VALUES(5831,'Abington','Abington, Pennsylvania',6980,44);
INSERT INTO "django_geo_db_city" VALUES(5832,'Ambler','Ambler, Pennsylvania',6981,44);
INSERT INTO "django_geo_db_city" VALUES(5833,'Ardmore','Ardmore, Pennsylvania',6982,44);
INSERT INTO "django_geo_db_city" VALUES(5834,'Bala Cynwyd','Bala Cynwyd, Pennsylvania',6983,44);
INSERT INTO "django_geo_db_city" VALUES(5835,'Huntingdon Valley','Huntingdon Valley, Pennsylvania',6984,44);
INSERT INTO "django_geo_db_city" VALUES(5836,'Bristol','Bristol, Pennsylvania',6985,44);
INSERT INTO "django_geo_db_city" VALUES(5837,'Broomall','Broomall, Pennsylvania',6986,44);
INSERT INTO "django_geo_db_city" VALUES(5838,'Bryn Athyn','Bryn Athyn, Pennsylvania',6987,44);
INSERT INTO "django_geo_db_city" VALUES(5839,'Bryn Mawr','Bryn Mawr, Pennsylvania',6988,44);
INSERT INTO "django_geo_db_city" VALUES(5840,'Cheltenham','Cheltenham, Pennsylvania',6989,44);
INSERT INTO "django_geo_db_city" VALUES(5841,'Chester','Chester, Pennsylvania',6990,44);
INSERT INTO "django_geo_db_city" VALUES(5842,'Aston','Aston, Pennsylvania',6991,44);
INSERT INTO "django_geo_db_city" VALUES(5843,'Brookhaven','Brookhaven, Pennsylvania',6992,44);
INSERT INTO "django_geo_db_city" VALUES(5844,'Chester Heights','Chester Heights, Pennsylvania',6994,44);
INSERT INTO "django_geo_db_city" VALUES(5845,'Primos','Primos, Pennsylvania',6995,44);
INSERT INTO "django_geo_db_city" VALUES(5846,'Philadelphia','Philadelphia, Pennsylvania',6996,44);
INSERT INTO "django_geo_db_city" VALUES(5847,'Bensalem','Bensalem, Pennsylvania',6997,44);
INSERT INTO "django_geo_db_city" VALUES(5848,'Croydon','Croydon, Pennsylvania',6998,44);
INSERT INTO "django_geo_db_city" VALUES(5849,'Crum Lynne','Crum Lynne, Pennsylvania',6999,44);
INSERT INTO "django_geo_db_city" VALUES(5850,'Darby','Darby, Pennsylvania',7000,44);
INSERT INTO "django_geo_db_city" VALUES(5851,'Dresher','Dresher, Pennsylvania',7001,44);
INSERT INTO "django_geo_db_city" VALUES(5852,'Drexel Hill','Drexel Hill, Pennsylvania',7002,44);
INSERT INTO "django_geo_db_city" VALUES(5853,'Elkins Park','Elkins Park, Pennsylvania',7003,44);
INSERT INTO "django_geo_db_city" VALUES(5854,'Edgemont','Edgemont, Pennsylvania',6993,44);
INSERT INTO "django_geo_db_city" VALUES(5855,'Essington','Essington, Pennsylvania',7004,44);
INSERT INTO "django_geo_db_city" VALUES(5856,'Fairless Hills','Fairless Hills, Pennsylvania',7005,44);
INSERT INTO "django_geo_db_city" VALUES(5857,'Flourtown','Flourtown, Pennsylvania',7006,44);
INSERT INTO "django_geo_db_city" VALUES(5858,'Folcroft','Folcroft, Pennsylvania',7007,44);
INSERT INTO "django_geo_db_city" VALUES(5859,'Folsom','Folsom, Pennsylvania',7008,44);
INSERT INTO "django_geo_db_city" VALUES(5860,'Fort Washington','Fort Washington, Pennsylvania',7009,44);
INSERT INTO "django_geo_db_city" VALUES(5861,'Gladwyne','Gladwyne, Pennsylvania',7010,44);
INSERT INTO "django_geo_db_city" VALUES(5862,'Glenolden','Glenolden, Pennsylvania',7011,44);
INSERT INTO "django_geo_db_city" VALUES(5863,'Glen Riddle Lima','Glen Riddle Lima, Pennsylvania',6993,44);
INSERT INTO "django_geo_db_city" VALUES(5864,'Glenside','Glenside, Pennsylvania',7012,44);
INSERT INTO "django_geo_db_city" VALUES(5865,'Gradyville','Gradyville, Pennsylvania',7013,44);
INSERT INTO "django_geo_db_city" VALUES(5866,'Hatboro','Hatboro, Pennsylvania',7014,44);
INSERT INTO "django_geo_db_city" VALUES(5867,'Haverford','Haverford, Pennsylvania',7015,44);
INSERT INTO "django_geo_db_city" VALUES(5868,'Holmes','Holmes, Pennsylvania',7016,44);
INSERT INTO "django_geo_db_city" VALUES(5869,'Horsham','Horsham, Pennsylvania',7017,44);
INSERT INTO "django_geo_db_city" VALUES(5870,'Jenkintown','Jenkintown, Pennsylvania',7018,44);
INSERT INTO "django_geo_db_city" VALUES(5871,'Langhorne','Langhorne, Pennsylvania',7019,44);
INSERT INTO "django_geo_db_city" VALUES(5872,'Lansdowne','Lansdowne, Pennsylvania',7021,44);
INSERT INTO "django_geo_db_city" VALUES(5873,'Lenni','Lenni, Pennsylvania',7022,44);
INSERT INTO "django_geo_db_city" VALUES(5874,'Feasterville Trevose','Feasterville Trevose, Pennsylvania',7023,44);
INSERT INTO "django_geo_db_city" VALUES(5875,'Levittown','Levittown, Pennsylvania',7024,44);
INSERT INTO "django_geo_db_city" VALUES(5876,'Marcus Hook','Marcus Hook, Pennsylvania',7028,44);
INSERT INTO "django_geo_db_city" VALUES(5877,'Media','Media, Pennsylvania',7029,44);
INSERT INTO "django_geo_db_city" VALUES(5878,'Springfield','Springfield, Pennsylvania',7030,44);
INSERT INTO "django_geo_db_city" VALUES(5879,'Merion Station','Merion Station, Pennsylvania',7032,44);
INSERT INTO "django_geo_db_city" VALUES(5880,'Morrisville','Morrisville, Pennsylvania',7033,44);
INSERT INTO "django_geo_db_city" VALUES(5881,'Morton','Morton, Pennsylvania',7034,44);
INSERT INTO "django_geo_db_city" VALUES(5882,'Narberth','Narberth, Pennsylvania',7035,44);
INSERT INTO "django_geo_db_city" VALUES(5883,'Newtown Square','Newtown Square, Pennsylvania',7036,44);
INSERT INTO "django_geo_db_city" VALUES(5884,'Norwood','Norwood, Pennsylvania',7037,44);
INSERT INTO "django_geo_db_city" VALUES(5885,'Oreland','Oreland, Pennsylvania',7038,44);
INSERT INTO "django_geo_db_city" VALUES(5886,'Prospect Park','Prospect Park, Pennsylvania',7039,44);
INSERT INTO "django_geo_db_city" VALUES(5887,'Ridley Park','Ridley Park, Pennsylvania',7040,44);
INSERT INTO "django_geo_db_city" VALUES(5888,'Sharon Hill','Sharon Hill, Pennsylvania',7041,44);
INSERT INTO "django_geo_db_city" VALUES(5889,'Wayne','Wayne, Pennsylvania',7042,44);
INSERT INTO "django_geo_db_city" VALUES(5890,'Swarthmore','Swarthmore, Pennsylvania',7043,44);
INSERT INTO "django_geo_db_city" VALUES(5891,'Upper Darby','Upper Darby, Pennsylvania',7044,44);
INSERT INTO "django_geo_db_city" VALUES(5892,'Havertown','Havertown, Pennsylvania',7045,44);
INSERT INTO "django_geo_db_city" VALUES(5893,'Villanova','Villanova, Pennsylvania',7046,44);
INSERT INTO "django_geo_db_city" VALUES(5894,'Wallingford','Wallingford, Pennsylvania',7047,44);
INSERT INTO "django_geo_db_city" VALUES(5895,'Willow Grove','Willow Grove, Pennsylvania',7050,44);
INSERT INTO "django_geo_db_city" VALUES(5896,'Woodlyn','Woodlyn, Pennsylvania',7051,44);
INSERT INTO "django_geo_db_city" VALUES(5897,'Wyncote','Wyncote, Pennsylvania',7052,44);
INSERT INTO "django_geo_db_city" VALUES(5898,'Wynnewood','Wynnewood, Pennsylvania',7053,44);
INSERT INTO "django_geo_db_city" VALUES(5899,'Centerport','Centerport, Pennsylvania',7106,44);
INSERT INTO "django_geo_db_city" VALUES(5900,'Paoli','Paoli, Pennsylvania',7110,44);
INSERT INTO "django_geo_db_city" VALUES(5901,'Atglen','Atglen, Pennsylvania',7111,44);
INSERT INTO "django_geo_db_city" VALUES(5902,'Avondale','Avondale, Pennsylvania',7112,44);
INSERT INTO "django_geo_db_city" VALUES(5903,'Berwyn','Berwyn, Pennsylvania',7113,44);
INSERT INTO "django_geo_db_city" VALUES(5904,'Brandamore','Brandamore, Pennsylvania',7114,44);
INSERT INTO "django_geo_db_city" VALUES(5905,'Chadds Ford','Chadds Ford, Pennsylvania',7115,44);
INSERT INTO "django_geo_db_city" VALUES(5906,'Chatham','Chatham, Pennsylvania',7116,44);
INSERT INTO "django_geo_db_city" VALUES(5907,'Cheyney','Cheyney, Pennsylvania',7117,44);
INSERT INTO "django_geo_db_city" VALUES(5908,'Coatesville','Coatesville, Pennsylvania',7118,44);
INSERT INTO "django_geo_db_city" VALUES(5909,'Cochranville','Cochranville, Pennsylvania',7119,44);
INSERT INTO "django_geo_db_city" VALUES(5910,'Concordville','Concordville, Pennsylvania',7120,44);
INSERT INTO "django_geo_db_city" VALUES(5911,'Devon','Devon, Pennsylvania',7121,44);
INSERT INTO "django_geo_db_city" VALUES(5912,'Downingtown','Downingtown, Pennsylvania',7122,44);
INSERT INTO "django_geo_db_city" VALUES(5913,'Exton','Exton, Pennsylvania',7123,44);
INSERT INTO "django_geo_db_city" VALUES(5914,'Glen Mills','Glen Mills, Pennsylvania',7124,44);
INSERT INTO "django_geo_db_city" VALUES(5915,'Glenmoore','Glenmoore, Pennsylvania',7125,44);
INSERT INTO "django_geo_db_city" VALUES(5916,'Honey Brook','Honey Brook, Pennsylvania',7126,44);
INSERT INTO "django_geo_db_city" VALUES(5917,'Immaculata','Immaculata, Pennsylvania',7127,44);
INSERT INTO "django_geo_db_city" VALUES(5918,'Kelton','Kelton, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5919,'Kemblesville','Kemblesville, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5920,'Kennett Square','Kennett Square, Pennsylvania',7129,44);
INSERT INTO "django_geo_db_city" VALUES(5921,'Landenberg','Landenberg, Pennsylvania',7130,44);
INSERT INTO "django_geo_db_city" VALUES(5922,'Lewisville','Lewisville, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5923,'Lincoln University','Lincoln University, Pennsylvania',7131,44);
INSERT INTO "django_geo_db_city" VALUES(5924,'Lionville','Lionville, Pennsylvania',7132,44);
INSERT INTO "django_geo_db_city" VALUES(5925,'Lyndell','Lyndell, Pennsylvania',7133,44);
INSERT INTO "django_geo_db_city" VALUES(5926,'Malvern','Malvern, Pennsylvania',7134,44);
INSERT INTO "django_geo_db_city" VALUES(5927,'Mendenhall','Mendenhall, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5928,'Modena','Modena, Pennsylvania',7135,44);
INSERT INTO "django_geo_db_city" VALUES(5929,'New London','New London, Pennsylvania',7136,44);
INSERT INTO "django_geo_db_city" VALUES(5930,'Nottingham','Nottingham, Pennsylvania',7137,44);
INSERT INTO "django_geo_db_city" VALUES(5931,'Oxford','Oxford, Pennsylvania',7138,44);
INSERT INTO "django_geo_db_city" VALUES(5932,'Parkesburg','Parkesburg, Pennsylvania',7139,44);
INSERT INTO "django_geo_db_city" VALUES(5933,'Pocopson','Pocopson, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5934,'Pomeroy','Pomeroy, Pennsylvania',7140,44);
INSERT INTO "django_geo_db_city" VALUES(5935,'Sadsburyville','Sadsburyville, Pennsylvania',7141,44);
INSERT INTO "django_geo_db_city" VALUES(5936,'Steelville','Steelville, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5937,'Suplee','Suplee, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5938,'Thorndale','Thorndale, Pennsylvania',7142,44);
INSERT INTO "django_geo_db_city" VALUES(5939,'Thornton','Thornton, Pennsylvania',7143,44);
INSERT INTO "django_geo_db_city" VALUES(5940,'Toughkenamon','Toughkenamon, Pennsylvania',7144,44);
INSERT INTO "django_geo_db_city" VALUES(5941,'Unionville','Unionville, Pennsylvania',7145,44);
INSERT INTO "django_geo_db_city" VALUES(5942,'Wagontown','Wagontown, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5943,'West Chester','West Chester, Pennsylvania',7146,44);
INSERT INTO "django_geo_db_city" VALUES(5944,'West Grove','West Grove, Pennsylvania',7149,44);
INSERT INTO "django_geo_db_city" VALUES(5945,'Westtown','Westtown, Pennsylvania',7150,44);
INSERT INTO "django_geo_db_city" VALUES(5946,'Southeastern','Southeastern, Pennsylvania',7128,44);
INSERT INTO "django_geo_db_city" VALUES(5947,'Norristown','Norristown, Pennsylvania',7151,44);
INSERT INTO "django_geo_db_city" VALUES(5948,'Bridgeport','Bridgeport, Pennsylvania',7153,44);
INSERT INTO "django_geo_db_city" VALUES(5949,'King Of Prussia','King Of Prussia, Pennsylvania',7154,44);
INSERT INTO "django_geo_db_city" VALUES(5950,'Audubon','Audubon, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5951,'Eagleville','Eagleville, Pennsylvania',7155,44);
INSERT INTO "django_geo_db_city" VALUES(5952,'Fairview Village','Fairview Village, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5953,'Arcola','Arcola, Pennsylvania',7156,44);
INSERT INTO "django_geo_db_city" VALUES(5954,'Birchrunville','Birchrunville, Pennsylvania',7157,44);
INSERT INTO "django_geo_db_city" VALUES(5955,'Blue Bell','Blue Bell, Pennsylvania',7158,44);
INSERT INTO "django_geo_db_city" VALUES(5956,'Cedars','Cedars, Pennsylvania',7159,44);
INSERT INTO "django_geo_db_city" VALUES(5957,'Chester Springs','Chester Springs, Pennsylvania',7160,44);
INSERT INTO "django_geo_db_city" VALUES(5958,'Collegeville','Collegeville, Pennsylvania',7161,44);
INSERT INTO "django_geo_db_city" VALUES(5959,'Conshohocken','Conshohocken, Pennsylvania',7162,44);
INSERT INTO "django_geo_db_city" VALUES(5960,'Creamery','Creamery, Pennsylvania',7163,44);
INSERT INTO "django_geo_db_city" VALUES(5961,'Devault','Devault, Pennsylvania',7164,44);
INSERT INTO "django_geo_db_city" VALUES(5962,'Frederick','Frederick, Pennsylvania',7165,44);
INSERT INTO "django_geo_db_city" VALUES(5963,'Gwynedd','Gwynedd, Pennsylvania',7166,44);
INSERT INTO "django_geo_db_city" VALUES(5964,'Gwynedd Valley','Gwynedd Valley, Pennsylvania',7167,44);
INSERT INTO "django_geo_db_city" VALUES(5965,'Harleysville','Harleysville, Pennsylvania',7168,44);
INSERT INTO "django_geo_db_city" VALUES(5966,'Hatfield','Hatfield, Pennsylvania',7169,44);
INSERT INTO "django_geo_db_city" VALUES(5967,'Kimberton','Kimberton, Pennsylvania',7170,44);
INSERT INTO "django_geo_db_city" VALUES(5968,'Kulpsville','Kulpsville, Pennsylvania',7171,44);
INSERT INTO "django_geo_db_city" VALUES(5969,'Lafayette Hill','Lafayette Hill, Pennsylvania',7172,44);
INSERT INTO "django_geo_db_city" VALUES(5970,'Lansdale','Lansdale, Pennsylvania',7173,44);
INSERT INTO "django_geo_db_city" VALUES(5971,'Lederach','Lederach, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5972,'Mainland','Mainland, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5973,'Miquon','Miquon, Pennsylvania',6978,44);
INSERT INTO "django_geo_db_city" VALUES(5974,'Mont Clare','Mont Clare, Pennsylvania',7174,44);
INSERT INTO "django_geo_db_city" VALUES(5975,'North Wales','North Wales, Pennsylvania',7175,44);
INSERT INTO "django_geo_db_city" VALUES(5976,'Oaks','Oaks, Pennsylvania',7176,44);
INSERT INTO "django_geo_db_city" VALUES(5977,'Parker Ford','Parker Ford, Pennsylvania',7177,44);
INSERT INTO "django_geo_db_city" VALUES(5978,'Phoenixville','Phoenixville, Pennsylvania',7178,44);
INSERT INTO "django_geo_db_city" VALUES(5979,'Plymouth Meeting','Plymouth Meeting, Pennsylvania',7179,44);
INSERT INTO "django_geo_db_city" VALUES(5980,'Pottstown','Pottstown, Pennsylvania',7180,44);
INSERT INTO "django_geo_db_city" VALUES(5981,'Royersford','Royersford, Pennsylvania',7182,44);
INSERT INTO "django_geo_db_city" VALUES(5982,'Saint Peters','Saint Peters, Pennsylvania',7183,44);
INSERT INTO "django_geo_db_city" VALUES(5983,'Sassamansville','Sassamansville, Pennsylvania',7184,44);
INSERT INTO "django_geo_db_city" VALUES(5984,'Schwenksville','Schwenksville, Pennsylvania',7185,44);
INSERT INTO "django_geo_db_city" VALUES(5985,'Skippack','Skippack, Pennsylvania',7186,44);
INSERT INTO "django_geo_db_city" VALUES(5986,'Spring City','Spring City, Pennsylvania',7187,44);
INSERT INTO "django_geo_db_city" VALUES(5987,'Spring House','Spring House, Pennsylvania',7188,44);
INSERT INTO "django_geo_db_city" VALUES(5988,'Spring Mount','Spring Mount, Pennsylvania',7189,44);
INSERT INTO "django_geo_db_city" VALUES(5989,'Uwchland','Uwchland, Pennsylvania',7190,44);
INSERT INTO "django_geo_db_city" VALUES(5990,'Valley Forge','Valley Forge, Pennsylvania',7191,44);
INSERT INTO "django_geo_db_city" VALUES(5991,'West Point','West Point, Pennsylvania',7193,44);
INSERT INTO "django_geo_db_city" VALUES(5992,'Worcester','Worcester, Pennsylvania',7194,44);
INSERT INTO "django_geo_db_city" VALUES(5993,'Zieglerville','Zieglerville, Pennsylvania',7195,44);
INSERT INTO "django_geo_db_city" VALUES(5994,'Adamstown','Adamstown, Pennsylvania',7196,44);
INSERT INTO "django_geo_db_city" VALUES(5995,'Bally','Bally, Pennsylvania',7197,44);
INSERT INTO "django_geo_db_city" VALUES(5996,'Barto','Barto, Pennsylvania',7198,44);
INSERT INTO "django_geo_db_city" VALUES(5997,'Bechtelsville','Bechtelsville, Pennsylvania',7199,44);
INSERT INTO "django_geo_db_city" VALUES(5998,'Bernville','Bernville, Pennsylvania',7200,44);
INSERT INTO "django_geo_db_city" VALUES(5999,'Bethel','Bethel, Pennsylvania',7201,44);
INSERT INTO "django_geo_db_city" VALUES(6000,'Birdsboro','Birdsboro, Pennsylvania',7202,44);
INSERT INTO "django_geo_db_city" VALUES(6001,'Blandon','Blandon, Pennsylvania',7203,44);
INSERT INTO "django_geo_db_city" VALUES(6002,'Bowers','Bowers, Pennsylvania',7204,44);
INSERT INTO "django_geo_db_city" VALUES(6003,'Boyertown','Boyertown, Pennsylvania',7205,44);
INSERT INTO "django_geo_db_city" VALUES(6004,'Dauberville','Dauberville, Pennsylvania',7207,44);
INSERT INTO "django_geo_db_city" VALUES(6005,'Douglassville','Douglassville, Pennsylvania',7208,44);
INSERT INTO "django_geo_db_city" VALUES(6006,'Earlville','Earlville, Pennsylvania',7209,44);
INSERT INTO "django_geo_db_city" VALUES(6007,'Elverson','Elverson, Pennsylvania',7210,44);
INSERT INTO "django_geo_db_city" VALUES(6008,'Fleetwood','Fleetwood, Pennsylvania',7211,44);
INSERT INTO "django_geo_db_city" VALUES(6009,'Geigertown','Geigertown, Pennsylvania',7212,44);
INSERT INTO "django_geo_db_city" VALUES(6010,'Robeson','Robeson, Pennsylvania',7213,44);
INSERT INTO "django_geo_db_city" VALUES(6011,'Gilbertsville','Gilbertsville, Pennsylvania',7214,44);
INSERT INTO "django_geo_db_city" VALUES(6012,'Hamburg','Hamburg, Pennsylvania',7215,44);
INSERT INTO "django_geo_db_city" VALUES(6013,'Kempton','Kempton, Pennsylvania',7216,44);
INSERT INTO "django_geo_db_city" VALUES(6014,'Kutztown','Kutztown, Pennsylvania',7217,44);
INSERT INTO "django_geo_db_city" VALUES(6015,'Leesport','Leesport, Pennsylvania',7218,44);
INSERT INTO "django_geo_db_city" VALUES(6016,'Lenhartsville','Lenhartsville, Pennsylvania',7219,44);
INSERT INTO "django_geo_db_city" VALUES(6017,'Limekiln','Limekiln, Pennsylvania',7220,44);
INSERT INTO "django_geo_db_city" VALUES(6018,'Lyon Station','Lyon Station, Pennsylvania',7221,44);
INSERT INTO "django_geo_db_city" VALUES(6019,'Maxatawny','Maxatawny, Pennsylvania',7222,44);
INSERT INTO "django_geo_db_city" VALUES(6020,'Mertztown','Mertztown, Pennsylvania',7223,44);
INSERT INTO "django_geo_db_city" VALUES(6021,'Mohnton','Mohnton, Pennsylvania',7224,44);
INSERT INTO "django_geo_db_city" VALUES(6022,'Mohrsville','Mohrsville, Pennsylvania',7225,44);
INSERT INTO "django_geo_db_city" VALUES(6023,'Monocacy Station','Monocacy Station, Pennsylvania',7226,44);
INSERT INTO "django_geo_db_city" VALUES(6024,'Morgantown','Morgantown, Pennsylvania',7227,44);
INSERT INTO "django_geo_db_city" VALUES(6025,'Mount Aetna','Mount Aetna, Pennsylvania',7228,44);
INSERT INTO "django_geo_db_city" VALUES(6026,'New Berlinville','New Berlinville, Pennsylvania',7229,44);
INSERT INTO "django_geo_db_city" VALUES(6027,'Cumru','Cumru, Pennsylvania',7230,44);
INSERT INTO "django_geo_db_city" VALUES(6028,'Oley','Oley, Pennsylvania',7231,44);
INSERT INTO "django_geo_db_city" VALUES(6029,'Pine Forge','Pine Forge, Pennsylvania',7207,44);
INSERT INTO "django_geo_db_city" VALUES(6030,'Port Clinton','Port Clinton, Pennsylvania',7232,44);
INSERT INTO "django_geo_db_city" VALUES(6031,'Rehrersburg','Rehrersburg, Pennsylvania',7233,44);
INSERT INTO "django_geo_db_city" VALUES(6032,'Robesonia','Robesonia, Pennsylvania',7234,44);
INSERT INTO "django_geo_db_city" VALUES(6033,'Shartlesville','Shartlesville, Pennsylvania',7235,44);
INSERT INTO "django_geo_db_city" VALUES(6034,'Shoemakersville','Shoemakersville, Pennsylvania',7236,44);
INSERT INTO "django_geo_db_city" VALUES(6035,'Stony Run','Stony Run, Pennsylvania',7237,44);
INSERT INTO "django_geo_db_city" VALUES(6036,'Strausstown','Strausstown, Pennsylvania',7238,44);
INSERT INTO "django_geo_db_city" VALUES(6037,'Temple','Temple, Pennsylvania',7239,44);
INSERT INTO "django_geo_db_city" VALUES(6038,'Topton','Topton, Pennsylvania',7240,44);
INSERT INTO "django_geo_db_city" VALUES(6039,'Virginville','Virginville, Pennsylvania',7241,44);
INSERT INTO "django_geo_db_city" VALUES(6040,'Wernersville','Wernersville, Pennsylvania',7242,44);
INSERT INTO "django_geo_db_city" VALUES(6041,'Womelsdorf','Womelsdorf, Pennsylvania',7243,44);
INSERT INTO "django_geo_db_city" VALUES(6042,'Reading','Reading, Pennsylvania',7244,44);
INSERT INTO "django_geo_db_city" VALUES(6043,'Alsace','Alsace, Pennsylvania',7256,44);
INSERT INTO "django_geo_db_city" VALUES(6044,'Muhlenberg','Muhlenberg, Pennsylvania',7257,44);
INSERT INTO "django_geo_db_city" VALUES(6045,'Delaware City','Delaware City, Delaware',7258,9);
INSERT INTO "django_geo_db_city" VALUES(6046,'Bear','Bear, Delaware',7259,9);
INSERT INTO "django_geo_db_city" VALUES(6047,'Newark','Newark, Delaware',7260,9);
INSERT INTO "django_geo_db_city" VALUES(6048,'Claymont','Claymont, Delaware',7261,9);
INSERT INTO "django_geo_db_city" VALUES(6049,'Hockessin','Hockessin, Delaware',7263,9);
INSERT INTO "django_geo_db_city" VALUES(6050,'Kirkwood','Kirkwood, Delaware',7264,9);
INSERT INTO "django_geo_db_city" VALUES(6051,'Middletown','Middletown, Delaware',7265,9);
INSERT INTO "django_geo_db_city" VALUES(6052,'Montchanin','Montchanin, Delaware',7266,9);
INSERT INTO "django_geo_db_city" VALUES(6053,'New Castle','New Castle, Delaware',7270,9);
INSERT INTO "django_geo_db_city" VALUES(6054,'Odessa','Odessa, Delaware',7271,9);
INSERT INTO "django_geo_db_city" VALUES(6055,'Port Penn','Port Penn, Delaware',7272,9);
INSERT INTO "django_geo_db_city" VALUES(6056,'Rockland','Rockland, Delaware',7273,9);
INSERT INTO "django_geo_db_city" VALUES(6057,'Saint Georges','Saint Georges, Delaware',7274,9);
INSERT INTO "django_geo_db_city" VALUES(6058,'Townsend','Townsend, Delaware',7275,9);
INSERT INTO "django_geo_db_city" VALUES(6059,'Winterthur','Winterthur, Delaware',7276,9);
INSERT INTO "django_geo_db_city" VALUES(6060,'Yorklyn','Yorklyn, Delaware',7277,9);
INSERT INTO "django_geo_db_city" VALUES(6061,'Wilmington','Wilmington, Delaware',7280,9);
INSERT INTO "django_geo_db_city" VALUES(6062,'Newport','Newport, Delaware',7290,9);
INSERT INTO "django_geo_db_city" VALUES(6063,'Schuylkill','Schuylkill, Pennsylvania',7292,44);
INSERT INTO "django_geo_db_city" VALUES(6064,'Dover','Dover, Delaware',7294,9);
INSERT INTO "django_geo_db_city" VALUES(6065,'Dover AFB','Dover AFB, Delaware',7295,9);
INSERT INTO "django_geo_db_city" VALUES(6066,'Upper Uwchlan','Upper Uwchlan, Pennsylvania',7298,44);
INSERT INTO "django_geo_db_city" VALUES(6067,'Bethany Beach','Bethany Beach, Delaware',7299,9);
INSERT INTO "django_geo_db_city" VALUES(6068,'Bethel','Bethel, Delaware',7300,9);
INSERT INTO "django_geo_db_city" VALUES(6069,'Bridgeville','Bridgeville, Delaware',7301,9);
INSERT INTO "django_geo_db_city" VALUES(6070,'Camden Wyoming','Camden Wyoming, Delaware',7302,9);
INSERT INTO "django_geo_db_city" VALUES(6071,'Cheswold','Cheswold, Delaware',7303,9);
INSERT INTO "django_geo_db_city" VALUES(6072,'Clayton','Clayton, Delaware',7304,9);
INSERT INTO "django_geo_db_city" VALUES(6073,'Dagsboro','Dagsboro, Delaware',7305,9);
INSERT INTO "django_geo_db_city" VALUES(6074,'Delmar','Delmar, Delaware',7306,9);
INSERT INTO "django_geo_db_city" VALUES(6075,'Ellendale','Ellendale, Delaware',7307,9);
INSERT INTO "django_geo_db_city" VALUES(6076,'Farmington','Farmington, Delaware',7308,9);
INSERT INTO "django_geo_db_city" VALUES(6077,'Felton','Felton, Delaware',7309,9);
INSERT INTO "django_geo_db_city" VALUES(6078,'Fenwick Island','Fenwick Island, Delaware',7310,9);
INSERT INTO "django_geo_db_city" VALUES(6079,'Frankford','Frankford, Delaware',7311,9);
INSERT INTO "django_geo_db_city" VALUES(6080,'Frederica','Frederica, Delaware',7312,9);
INSERT INTO "django_geo_db_city" VALUES(6081,'Georgetown','Georgetown, Delaware',7313,9);
INSERT INTO "django_geo_db_city" VALUES(6082,'Greenwood','Greenwood, Delaware',7314,9);
INSERT INTO "django_geo_db_city" VALUES(6083,'Harbeson','Harbeson, Delaware',7315,9);
INSERT INTO "django_geo_db_city" VALUES(6084,'Harrington','Harrington, Delaware',7316,9);
INSERT INTO "django_geo_db_city" VALUES(6085,'Hartly','Hartly, Delaware',7317,9);
INSERT INTO "django_geo_db_city" VALUES(6086,'Houston','Houston, Delaware',7318,9);
INSERT INTO "django_geo_db_city" VALUES(6087,'Kenton','Kenton, Delaware',7319,9);
INSERT INTO "django_geo_db_city" VALUES(6088,'Laurel','Laurel, Delaware',7320,9);
INSERT INTO "django_geo_db_city" VALUES(6089,'Lewes','Lewes, Delaware',7321,9);
INSERT INTO "django_geo_db_city" VALUES(6090,'Lincoln','Lincoln, Delaware',7322,9);
INSERT INTO "django_geo_db_city" VALUES(6091,'Little Creek','Little Creek, Delaware',7323,9);
INSERT INTO "django_geo_db_city" VALUES(6092,'Magnolia','Magnolia, Delaware',7324,9);
INSERT INTO "django_geo_db_city" VALUES(6093,'Milford','Milford, Delaware',7325,9);
INSERT INTO "django_geo_db_city" VALUES(6094,'Marydel','Marydel, Delaware',7326,9);
INSERT INTO "django_geo_db_city" VALUES(6095,'Millsboro','Millsboro, Delaware',7327,9);
INSERT INTO "django_geo_db_city" VALUES(6096,'Millville','Millville, Delaware',7328,9);
INSERT INTO "django_geo_db_city" VALUES(6097,'Milton','Milton, Delaware',7329,9);
INSERT INTO "django_geo_db_city" VALUES(6098,'Nassau','Nassau, Delaware',7330,9);
INSERT INTO "django_geo_db_city" VALUES(6099,'Ocean View','Ocean View, Delaware',7331,9);
INSERT INTO "django_geo_db_city" VALUES(6100,'Rehoboth Beach','Rehoboth Beach, Delaware',7332,9);
INSERT INTO "django_geo_db_city" VALUES(6101,'Seaford','Seaford, Delaware',7333,9);
INSERT INTO "django_geo_db_city" VALUES(6102,'Selbyville','Selbyville, Delaware',7334,9);
INSERT INTO "django_geo_db_city" VALUES(6103,'Smyrna','Smyrna, Delaware',7335,9);
INSERT INTO "django_geo_db_city" VALUES(6104,'Viola','Viola, Delaware',7336,9);
INSERT INTO "django_geo_db_city" VALUES(6105,'Woodside','Woodside, Delaware',7337,9);
INSERT INTO "django_geo_db_city" VALUES(6106,'Washington','Washington, District of Columbia',7339,10);
INSERT INTO "django_geo_db_city" VALUES(6107,'Dulles','Dulles, Virginia',7372,54);
INSERT INTO "django_geo_db_city" VALUES(6108,'Aldie','Aldie, Virginia',7375,54);
INSERT INTO "django_geo_db_city" VALUES(6109,'Amissville','Amissville, Virginia',7376,54);
INSERT INTO "django_geo_db_city" VALUES(6110,'Arcola','Arcola, Virginia',7377,54);
INSERT INTO "django_geo_db_city" VALUES(6111,'Manassas','Manassas, Virginia',7378,54);
INSERT INTO "django_geo_db_city" VALUES(6112,'Marshall','Marshall, Virginia',7384,54);
INSERT INTO "django_geo_db_city" VALUES(6113,'Middleburg','Middleburg, Virginia',7386,54);
INSERT INTO "django_geo_db_city" VALUES(6114,'Catlett','Catlett, Virginia',7388,54);
INSERT INTO "django_geo_db_city" VALUES(6115,'Centreville','Centreville, Virginia',7389,54);
INSERT INTO "django_geo_db_city" VALUES(6116,'Clifton','Clifton, Virginia',7392,54);
INSERT INTO "django_geo_db_city" VALUES(6117,'Orlean','Orlean, Virginia',7393,54);
INSERT INTO "django_geo_db_city" VALUES(6118,'Paeonian Springs','Paeonian Springs, Virginia',7394,54);
INSERT INTO "django_geo_db_city" VALUES(6119,'Paris','Paris, Virginia',7395,54);
INSERT INTO "django_geo_db_city" VALUES(6120,'Philomont','Philomont, Virginia',7396,54);
INSERT INTO "django_geo_db_city" VALUES(6121,'Purcellville','Purcellville, Virginia',7397,54);
INSERT INTO "django_geo_db_city" VALUES(6122,'Bluemont','Bluemont, Virginia',7399,54);
INSERT INTO "django_geo_db_city" VALUES(6123,'Bristow','Bristow, Virginia',7400,54);
INSERT INTO "django_geo_db_city" VALUES(6124,'Broad Run','Broad Run, Virginia',7401,54);
INSERT INTO "django_geo_db_city" VALUES(6125,'Calverton','Calverton, Virginia',7402,54);
INSERT INTO "django_geo_db_city" VALUES(6126,'Casanova','Casanova, Virginia',7403,54);
INSERT INTO "django_geo_db_city" VALUES(6127,'Rectortown','Rectortown, Virginia',7404,54);
INSERT INTO "django_geo_db_city" VALUES(6128,'Round Hill','Round Hill, Virginia',7405,54);
INSERT INTO "django_geo_db_city" VALUES(6129,'Catharpin','Catharpin, Virginia',7407,54);
INSERT INTO "django_geo_db_city" VALUES(6130,'Delaplane','Delaplane, Virginia',7408,54);
INSERT INTO "django_geo_db_city" VALUES(6131,'Ashburn','Ashburn, Virginia',7373,54);
INSERT INTO "django_geo_db_city" VALUES(6132,'Chantilly','Chantilly, Virginia',7411,54);
INSERT INTO "django_geo_db_city" VALUES(6133,'Gainesville','Gainesville, Virginia',7413,54);
INSERT INTO "django_geo_db_city" VALUES(6134,'Hamilton','Hamilton, Virginia',7415,54);
INSERT INTO "django_geo_db_city" VALUES(6135,'Lincoln','Lincoln, Virginia',7417,54);
INSERT INTO "django_geo_db_city" VALUES(6136,'Sterling','Sterling, Virginia',7373,54);
INSERT INTO "django_geo_db_city" VALUES(6137,'Haymarket','Haymarket, Virginia',7414,54);
INSERT INTO "django_geo_db_city" VALUES(6138,'Herndon','Herndon, Virginia',7422,54);
INSERT INTO "django_geo_db_city" VALUES(6139,'Leesburg','Leesburg, Virginia',7424,54);
INSERT INTO "django_geo_db_city" VALUES(6140,'Lovettsville','Lovettsville, Virginia',7428,54);
INSERT INTO "django_geo_db_city" VALUES(6141,'Nokesville','Nokesville, Virginia',7429,54);
INSERT INTO "django_geo_db_city" VALUES(6142,'Upperville','Upperville, Virginia',7431,54);
INSERT INTO "django_geo_db_city" VALUES(6143,'Warrenton','Warrenton, Virginia',7433,54);
INSERT INTO "django_geo_db_city" VALUES(6144,'Reston','Reston, Virginia',7436,54);
INSERT INTO "django_geo_db_city" VALUES(6145,'Waterford','Waterford, Virginia',7439,54);
INSERT INTO "django_geo_db_city" VALUES(6146,'The Plains','The Plains, Virginia',7440,54);
INSERT INTO "django_geo_db_city" VALUES(6147,'Waldorf','Waldorf, Maryland',7506,38);
INSERT INTO "django_geo_db_city" VALUES(6148,'Abell','Abell, Maryland',7510,38);
INSERT INTO "django_geo_db_city" VALUES(6149,'Accokeek','Accokeek, Maryland',7511,38);
INSERT INTO "django_geo_db_city" VALUES(6150,'Aquasco','Aquasco, Maryland',7512,38);
INSERT INTO "django_geo_db_city" VALUES(6151,'Avenue','Avenue, Maryland',7513,38);
INSERT INTO "django_geo_db_city" VALUES(6152,'Barstow','Barstow, Maryland',7514,38);
INSERT INTO "django_geo_db_city" VALUES(6153,'Bel Alton','Bel Alton, Maryland',7515,38);
INSERT INTO "django_geo_db_city" VALUES(6154,'Benedict','Benedict, Maryland',7516,38);
INSERT INTO "django_geo_db_city" VALUES(6155,'Brandywine','Brandywine, Maryland',7517,38);
INSERT INTO "django_geo_db_city" VALUES(6156,'Broomes Island','Broomes Island, Maryland',7518,38);
INSERT INTO "django_geo_db_city" VALUES(6157,'Bryans Road','Bryans Road, Maryland',7519,38);
INSERT INTO "django_geo_db_city" VALUES(6158,'Bryantown','Bryantown, Maryland',7520,38);
INSERT INTO "django_geo_db_city" VALUES(6159,'Bushwood','Bushwood, Maryland',7521,38);
INSERT INTO "django_geo_db_city" VALUES(6160,'California','California, Maryland',7522,38);
INSERT INTO "django_geo_db_city" VALUES(6161,'Callaway','Callaway, Maryland',7523,38);
INSERT INTO "django_geo_db_city" VALUES(6162,'Chaptico','Chaptico, Maryland',7524,38);
INSERT INTO "django_geo_db_city" VALUES(6163,'Charlotte Hall','Charlotte Hall, Maryland',7525,38);
INSERT INTO "django_geo_db_city" VALUES(6164,'Cheltenham','Cheltenham, Maryland',7526,38);
INSERT INTO "django_geo_db_city" VALUES(6165,'Clements','Clements, Maryland',7527,38);
INSERT INTO "django_geo_db_city" VALUES(6166,'Cobb Island','Cobb Island, Maryland',7528,38);
INSERT INTO "django_geo_db_city" VALUES(6167,'Coltons Point','Coltons Point, Maryland',7529,38);
INSERT INTO "django_geo_db_city" VALUES(6168,'Compton','Compton, Maryland',7530,38);
INSERT INTO "django_geo_db_city" VALUES(6169,'Dameron','Dameron, Maryland',7531,38);
INSERT INTO "django_geo_db_city" VALUES(6170,'Dowell','Dowell, Maryland',7532,38);
INSERT INTO "django_geo_db_city" VALUES(6171,'Drayden','Drayden, Maryland',7533,38);
INSERT INTO "django_geo_db_city" VALUES(6172,'Faulkner','Faulkner, Maryland',7534,38);
INSERT INTO "django_geo_db_city" VALUES(6173,'Great Mills','Great Mills, Maryland',7535,38);
INSERT INTO "django_geo_db_city" VALUES(6174,'Helen','Helen, Maryland',7536,38);
INSERT INTO "django_geo_db_city" VALUES(6175,'Hollywood','Hollywood, Maryland',7537,38);
INSERT INTO "django_geo_db_city" VALUES(6176,'Hughesville','Hughesville, Maryland',7538,38);
INSERT INTO "django_geo_db_city" VALUES(6177,'Huntingtown','Huntingtown, Maryland',7539,38);
INSERT INTO "django_geo_db_city" VALUES(6178,'Indian Head','Indian Head, Maryland',7540,38);
INSERT INTO "django_geo_db_city" VALUES(6179,'Ironsides','Ironsides, Maryland',7541,38);
INSERT INTO "django_geo_db_city" VALUES(6180,'Issue','Issue, Maryland',7542,38);
INSERT INTO "django_geo_db_city" VALUES(6181,'La Plata','La Plata, Maryland',7543,38);
INSERT INTO "django_geo_db_city" VALUES(6182,'Leonardtown','Leonardtown, Maryland',7544,38);
INSERT INTO "django_geo_db_city" VALUES(6183,'Lexington Park','Lexington Park, Maryland',7545,38);
INSERT INTO "django_geo_db_city" VALUES(6184,'Loveville','Loveville, Maryland',7546,38);
INSERT INTO "django_geo_db_city" VALUES(6185,'Lusby','Lusby, Maryland',7547,38);
INSERT INTO "django_geo_db_city" VALUES(6186,'Marbury','Marbury, Maryland',7548,38);
INSERT INTO "django_geo_db_city" VALUES(6187,'Mechanicsville','Mechanicsville, Maryland',7549,38);
INSERT INTO "django_geo_db_city" VALUES(6188,'Morganza','Morganza, Maryland',7550,38);
INSERT INTO "django_geo_db_city" VALUES(6189,'Mount Victoria','Mount Victoria, Maryland',7551,38);
INSERT INTO "django_geo_db_city" VALUES(6190,'Nanjemoy','Nanjemoy, Maryland',7552,38);
INSERT INTO "django_geo_db_city" VALUES(6191,'Newburg','Newburg, Maryland',7553,38);
INSERT INTO "django_geo_db_city" VALUES(6192,'Park Hall','Park Hall, Maryland',7554,38);
INSERT INTO "django_geo_db_city" VALUES(6193,'Patuxent River','Patuxent River, Maryland',7555,38);
INSERT INTO "django_geo_db_city" VALUES(6194,'Piney Point','Piney Point, Maryland',7556,38);
INSERT INTO "django_geo_db_city" VALUES(6195,'Pomfret','Pomfret, Maryland',7557,38);
INSERT INTO "django_geo_db_city" VALUES(6196,'Port Republic','Port Republic, Maryland',7558,38);
INSERT INTO "django_geo_db_city" VALUES(6197,'Port Tobacco','Port Tobacco, Maryland',7559,38);
INSERT INTO "django_geo_db_city" VALUES(6198,'Prince Frederick','Prince Frederick, Maryland',7560,38);
INSERT INTO "django_geo_db_city" VALUES(6199,'Ridge','Ridge, Maryland',7561,38);
INSERT INTO "django_geo_db_city" VALUES(6200,'Rock Point','Rock Point, Maryland',7562,38);
INSERT INTO "django_geo_db_city" VALUES(6201,'Saint Inigoes','Saint Inigoes, Maryland',7563,38);
INSERT INTO "django_geo_db_city" VALUES(6202,'Saint Leonard','Saint Leonard, Maryland',7564,38);
INSERT INTO "django_geo_db_city" VALUES(6203,'Saint Marys City','Saint Marys City, Maryland',7565,38);
INSERT INTO "django_geo_db_city" VALUES(6204,'Scotland','Scotland, Maryland',7566,38);
INSERT INTO "django_geo_db_city" VALUES(6205,'Solomons','Solomons, Maryland',7567,38);
INSERT INTO "django_geo_db_city" VALUES(6206,'Sunderland','Sunderland, Maryland',7568,38);
INSERT INTO "django_geo_db_city" VALUES(6207,'Tall Timbers','Tall Timbers, Maryland',7569,38);
INSERT INTO "django_geo_db_city" VALUES(6208,'Valley Lee','Valley Lee, Maryland',7570,38);
INSERT INTO "django_geo_db_city" VALUES(6209,'Welcome','Welcome, Maryland',7571,38);
INSERT INTO "django_geo_db_city" VALUES(6210,'White Plains','White Plains, Maryland',7572,38);
INSERT INTO "django_geo_db_city" VALUES(6211,'Southern Md Facility','Southern Md Facility, Maryland',7573,38);
INSERT INTO "django_geo_db_city" VALUES(6212,'Annapolis Junction','Annapolis Junction, Maryland',7574,38);
INSERT INTO "django_geo_db_city" VALUES(6213,'Lanham','Lanham, Maryland',7573,38);
INSERT INTO "django_geo_db_city" VALUES(6214,'Beltsville','Beltsville, Maryland',7573,38);
INSERT INTO "django_geo_db_city" VALUES(6215,'Laurel','Laurel, Maryland',7577,38);
INSERT INTO "django_geo_db_city" VALUES(6216,'Bladensburg','Bladensburg, Maryland',7579,38);
INSERT INTO "django_geo_db_city" VALUES(6217,'Lothian','Lothian, Maryland',7580,38);
INSERT INTO "django_geo_db_city" VALUES(6218,'Mount Rainier','Mount Rainier, Maryland',7581,38);
INSERT INTO "django_geo_db_city" VALUES(6219,'North Beach','North Beach, Maryland',7582,38);
INSERT INTO "django_geo_db_city" VALUES(6220,'Bowie','Bowie, Maryland',7583,38);
INSERT INTO "django_geo_db_city" VALUES(6221,'Brentwood','Brentwood, Maryland',7587,38);
INSERT INTO "django_geo_db_city" VALUES(6222,'Capitol Heights','Capitol Heights, Maryland',7573,38);
INSERT INTO "django_geo_db_city" VALUES(6223,'Chesapeake Beach','Chesapeake Beach, Maryland',7590,38);
INSERT INTO "django_geo_db_city" VALUES(6224,'Churchton','Churchton, Maryland',7591,38);
INSERT INTO "django_geo_db_city" VALUES(6225,'Clinton','Clinton, Maryland',7592,38);
INSERT INTO "django_geo_db_city" VALUES(6226,'Owings','Owings, Maryland',7593,38);
INSERT INTO "django_geo_db_city" VALUES(6227,'Riverdale','Riverdale, Maryland',7594,38);
INSERT INTO "django_geo_db_city" VALUES(6228,'College Park','College Park, Maryland',7595,38);
INSERT INTO "django_geo_db_city" VALUES(6229,'Fort Washington','Fort Washington, Maryland',7597,38);
INSERT INTO "django_geo_db_city" VALUES(6230,'Oxon Hill','Oxon Hill, Maryland',7598,38);
INSERT INTO "django_geo_db_city" VALUES(6231,'Suitland','Suitland, Maryland',7599,38);
INSERT INTO "django_geo_db_city" VALUES(6232,'District Heights','District Heights, Maryland',7600,38);
INSERT INTO "django_geo_db_city" VALUES(6233,'Temple Hills','Temple Hills, Maryland',7601,38);
INSERT INTO "django_geo_db_city" VALUES(6234,'Deale','Deale, Maryland',7602,38);
INSERT INTO "django_geo_db_city" VALUES(6235,'Dunkirk','Dunkirk, Maryland',7603,38);
INSERT INTO "django_geo_db_city" VALUES(6236,'Fort George G Meade','Fort George G Meade, Maryland',7604,38);
INSERT INTO "django_geo_db_city" VALUES(6237,'Friendship','Friendship, Maryland',7605,38);
INSERT INTO "django_geo_db_city" VALUES(6238,'Fulton','Fulton, Maryland',7606,38);
INSERT INTO "django_geo_db_city" VALUES(6239,'Andrews Air Force Base','Andrews Air Force Base, Maryland',7607,38);
INSERT INTO "django_geo_db_city" VALUES(6240,'Savage','Savage, Maryland',7608,38);
INSERT INTO "django_geo_db_city" VALUES(6241,'Shady Side','Shady Side, Maryland',7609,38);
INSERT INTO "django_geo_db_city" VALUES(6242,'Galesville','Galesville, Maryland',7610,38);
INSERT INTO "django_geo_db_city" VALUES(6243,'Greenbelt','Greenbelt, Maryland',7573,38);
INSERT INTO "django_geo_db_city" VALUES(6244,'Glenn Dale','Glenn Dale, Maryland',7611,38);
INSERT INTO "django_geo_db_city" VALUES(6245,'Upper Marlboro','Upper Marlboro, Maryland',7613,38);
INSERT INTO "django_geo_db_city" VALUES(6246,'Harwood','Harwood, Maryland',7615,38);
INSERT INTO "django_geo_db_city" VALUES(6247,'Highland','Highland, Maryland',7616,38);
INSERT INTO "django_geo_db_city" VALUES(6248,'West River','West River, Maryland',7617,38);
INSERT INTO "django_geo_db_city" VALUES(6249,'Tracys Landing','Tracys Landing, Maryland',7618,38);
INSERT INTO "django_geo_db_city" VALUES(6250,'Hyattsville','Hyattsville, Maryland',7619,38);
INSERT INTO "django_geo_db_city" VALUES(6251,'Jessup','Jessup, Maryland',7626,38);
INSERT INTO "django_geo_db_city" VALUES(6252,'Glen Echo','Glen Echo, Maryland',7627,38);
INSERT INTO "django_geo_db_city" VALUES(6253,'Bethesda','Bethesda, Maryland',7628,38);
INSERT INTO "django_geo_db_city" VALUES(6254,'Chevy Chase','Chevy Chase, Maryland',7630,38);
INSERT INTO "django_geo_db_city" VALUES(6255,'Cabin John','Cabin John, Maryland',7633,38);
INSERT INTO "django_geo_db_city" VALUES(6256,'Olney','Olney, Maryland',7634,38);
INSERT INTO "django_geo_db_city" VALUES(6257,'Brookeville','Brookeville, Maryland',7637,38);
INSERT INTO "django_geo_db_city" VALUES(6258,'Poolesville','Poolesville, Maryland',7638,38);
INSERT INTO "django_geo_db_city" VALUES(6259,'Barnesville','Barnesville, Maryland',7639,38);
INSERT INTO "django_geo_db_city" VALUES(6260,'Beallsville','Beallsville, Maryland',7640,38);
INSERT INTO "django_geo_db_city" VALUES(6261,'Boyds','Boyds, Maryland',7641,38);
INSERT INTO "django_geo_db_city" VALUES(6262,'Dickerson','Dickerson, Maryland',7642,38);
INSERT INTO "django_geo_db_city" VALUES(6263,'Rockville','Rockville, Maryland',7628,38);
INSERT INTO "django_geo_db_city" VALUES(6264,'Potomac','Potomac, Maryland',7647,38);
INSERT INTO "django_geo_db_city" VALUES(6265,'Derwood','Derwood, Maryland',7648,38);
INSERT INTO "django_geo_db_city" VALUES(6266,'Sandy Spring','Sandy Spring, Maryland',7649,38);
INSERT INTO "django_geo_db_city" VALUES(6267,'Ashton','Ashton, Maryland',7650,38);
INSERT INTO "django_geo_db_city" VALUES(6268,'Brinklow','Brinklow, Maryland',7651,38);
INSERT INTO "django_geo_db_city" VALUES(6269,'Burtonsville','Burtonsville, Maryland',7652,38);
INSERT INTO "django_geo_db_city" VALUES(6270,'Spencerville','Spencerville, Maryland',7653,38);
INSERT INTO "django_geo_db_city" VALUES(6271,'Clarksburg','Clarksburg, Maryland',7654,38);
INSERT INTO "django_geo_db_city" VALUES(6272,'Damascus','Damascus, Maryland',7655,38);
INSERT INTO "django_geo_db_city" VALUES(6273,'Germantown','Germantown, Maryland',7656,38);
INSERT INTO "django_geo_db_city" VALUES(6274,'Gaithersburg','Gaithersburg, Maryland',7658,38);
INSERT INTO "django_geo_db_city" VALUES(6275,'Washington Grove','Washington Grove, Maryland',7661,38);
INSERT INTO "django_geo_db_city" VALUES(6276,'Montgomery Village','Montgomery Village, Maryland',7664,38);
INSERT INTO "django_geo_db_city" VALUES(6277,'Kensington','Kensington, Maryland',7628,38);
INSERT INTO "django_geo_db_city" VALUES(6278,'Garrett Park','Garrett Park, Maryland',7667,38);
INSERT INTO "django_geo_db_city" VALUES(6279,'Suburb Maryland Fac','Suburb Maryland Fac, Maryland',7628,38);
INSERT INTO "django_geo_db_city" VALUES(6280,'Silver Spring','Silver Spring, Maryland',7669,38);
INSERT INTO "django_geo_db_city" VALUES(6281,'Takoma Park','Takoma Park, Maryland',7676,38);
INSERT INTO "django_geo_db_city" VALUES(6282,'Aberdeen','Aberdeen, Maryland',7677,38);
INSERT INTO "django_geo_db_city" VALUES(6283,'Perryman','Perryman, Maryland',7678,38);
INSERT INTO "django_geo_db_city" VALUES(6284,'Bel Air South','Bel Air South, Maryland',7679,38);
INSERT INTO "django_geo_db_city" VALUES(6285,'Aberdeen Proving Ground','Aberdeen Proving Ground, Maryland',7680,38);
INSERT INTO "django_geo_db_city" VALUES(6286,'Abingdon','Abingdon, Maryland',7681,38);
INSERT INTO "django_geo_db_city" VALUES(6287,'Gunpowder','Gunpowder, Maryland',7682,38);
INSERT INTO "django_geo_db_city" VALUES(6288,'Arnold','Arnold, Maryland',7683,38);
INSERT INTO "django_geo_db_city" VALUES(6289,'Baldwin','Baldwin, Maryland',7684,38);
INSERT INTO "django_geo_db_city" VALUES(6290,'Bel Air','Bel Air, Maryland',7685,38);
INSERT INTO "django_geo_db_city" VALUES(6291,'Belcamp','Belcamp, Maryland',7687,38);
INSERT INTO "django_geo_db_city" VALUES(6292,'Benson','Benson, Maryland',7688,38);
INSERT INTO "django_geo_db_city" VALUES(6293,'Boring','Boring, Maryland',7689,38);
INSERT INTO "django_geo_db_city" VALUES(6294,'Brooklandville','Brooklandville, Maryland',7690,38);
INSERT INTO "django_geo_db_city" VALUES(6295,'Butler','Butler, Maryland',7691,38);
INSERT INTO "django_geo_db_city" VALUES(6296,'Chase','Chase, Maryland',7692,38);
INSERT INTO "django_geo_db_city" VALUES(6297,'Churchville','Churchville, Maryland',7693,38);
INSERT INTO "django_geo_db_city" VALUES(6298,'Clarksville','Clarksville, Maryland',7694,38);
INSERT INTO "django_geo_db_city" VALUES(6299,'Cockeysville','Cockeysville, Maryland',7695,38);
INSERT INTO "django_geo_db_city" VALUES(6300,'Hunt Valley','Hunt Valley, Maryland',7696,38);
INSERT INTO "django_geo_db_city" VALUES(6301,'Crownsville','Crownsville, Maryland',7697,38);
INSERT INTO "django_geo_db_city" VALUES(6302,'Darlington','Darlington, Maryland',7698,38);
INSERT INTO "django_geo_db_city" VALUES(6303,'Davidsonville','Davidsonville, Maryland',7699,38);
INSERT INTO "django_geo_db_city" VALUES(6304,'Dayton','Dayton, Maryland',7700,38);
INSERT INTO "django_geo_db_city" VALUES(6305,'Edgewater','Edgewater, Maryland',7701,38);
INSERT INTO "django_geo_db_city" VALUES(6306,'Edgewood','Edgewood, Maryland',7702,38);
INSERT INTO "django_geo_db_city" VALUES(6307,'Ellicott City','Ellicott City, Maryland',7703,38);
INSERT INTO "django_geo_db_city" VALUES(6308,'Columbia','Columbia, Maryland',7706,38);
INSERT INTO "django_geo_db_city" VALUES(6309,'Fallston','Fallston, Maryland',7709,38);
INSERT INTO "django_geo_db_city" VALUES(6310,'Finksburg','Finksburg, Maryland',7710,38);
INSERT INTO "django_geo_db_city" VALUES(6311,'Forest Hill','Forest Hill, Maryland',7711,38);
INSERT INTO "django_geo_db_city" VALUES(6312,'Fork','Fork, Maryland',7712,38);
INSERT INTO "django_geo_db_city" VALUES(6313,'Fort Howard','Fort Howard, Maryland',7713,38);
INSERT INTO "django_geo_db_city" VALUES(6314,'Freeland','Freeland, Maryland',7714,38);
INSERT INTO "django_geo_db_city" VALUES(6315,'Gambrills','Gambrills, Maryland',7715,38);
INSERT INTO "django_geo_db_city" VALUES(6316,'Garrison','Garrison, Maryland',7692,38);
INSERT INTO "django_geo_db_city" VALUES(6317,'Gibson Island','Gibson Island, Maryland',7716,38);
INSERT INTO "django_geo_db_city" VALUES(6318,'Glen Arm','Glen Arm, Maryland',7717,38);
INSERT INTO "django_geo_db_city" VALUES(6319,'Glen Burnie','Glen Burnie, Maryland',7718,38);
INSERT INTO "django_geo_db_city" VALUES(6320,'Glyndon','Glyndon, Maryland',7721,38);
INSERT INTO "django_geo_db_city" VALUES(6321,'Hampstead','Hampstead, Maryland',7722,38);
INSERT INTO "django_geo_db_city" VALUES(6322,'Elkridge','Elkridge, Maryland',7723,38);
INSERT INTO "django_geo_db_city" VALUES(6323,'Hanover','Hanover, Maryland',7724,38);
INSERT INTO "django_geo_db_city" VALUES(6324,'Harmans','Harmans, Maryland',7725,38);
INSERT INTO "django_geo_db_city" VALUES(6325,'Havre De Grace','Havre De Grace, Maryland',7726,38);
INSERT INTO "django_geo_db_city" VALUES(6326,'Henryton','Henryton, Maryland',7727,38);
INSERT INTO "django_geo_db_city" VALUES(6327,'Hydes','Hydes, Maryland',7728,38);
INSERT INTO "django_geo_db_city" VALUES(6328,'Jarrettsville','Jarrettsville, Maryland',7729,38);
INSERT INTO "django_geo_db_city" VALUES(6329,'Joppa','Joppa, Maryland',7730,38);
INSERT INTO "django_geo_db_city" VALUES(6330,'Kingsville','Kingsville, Maryland',7731,38);
INSERT INTO "django_geo_db_city" VALUES(6331,'Lineboro','Lineboro, Maryland',7727,38);
INSERT INTO "django_geo_db_city" VALUES(6332,'Linthicum Heights','Linthicum Heights, Maryland',7732,38);
INSERT INTO "django_geo_db_city" VALUES(6333,'Long Green','Long Green, Maryland',7692,38);
INSERT INTO "django_geo_db_city" VALUES(6334,'Lutherville Timonium','Lutherville Timonium, Maryland',7733,38);
INSERT INTO "django_geo_db_city" VALUES(6335,'Manchester','Manchester, Maryland',7734,38);
INSERT INTO "django_geo_db_city" VALUES(6336,'Marriottsville','Marriottsville, Maryland',7735,38);
INSERT INTO "django_geo_db_city" VALUES(6337,'Maryland Line','Maryland Line, Maryland',7736,38);
INSERT INTO "django_geo_db_city" VALUES(6338,'Mayo','Mayo, Maryland',7737,38);
INSERT INTO "django_geo_db_city" VALUES(6339,'Millersville','Millersville, Maryland',7738,38);
INSERT INTO "django_geo_db_city" VALUES(6340,'Monkton','Monkton, Maryland',7739,38);
INSERT INTO "django_geo_db_city" VALUES(6341,'Odenton','Odenton, Maryland',7740,38);
INSERT INTO "django_geo_db_city" VALUES(6342,'Crofton','Crofton, Maryland',7741,38);
INSERT INTO "django_geo_db_city" VALUES(6343,'Owings Mills','Owings Mills, Maryland',7742,38);
INSERT INTO "django_geo_db_city" VALUES(6344,'Parkton','Parkton, Maryland',7743,38);
INSERT INTO "django_geo_db_city" VALUES(6345,'Pasadena','Pasadena, Maryland',7744,38);
INSERT INTO "django_geo_db_city" VALUES(6346,'Perry Hall','Perry Hall, Maryland',7745,38);
INSERT INTO "django_geo_db_city" VALUES(6347,'Phoenix','Phoenix, Maryland',7747,38);
INSERT INTO "django_geo_db_city" VALUES(6348,'Pylesville','Pylesville, Maryland',7748,38);
INSERT INTO "django_geo_db_city" VALUES(6349,'Randallstown','Randallstown, Maryland',7749,38);
INSERT INTO "django_geo_db_city" VALUES(6350,'Reisterstown','Reisterstown, Maryland',7750,38);
INSERT INTO "django_geo_db_city" VALUES(6351,'Riderwood','Riderwood, Maryland',7692,38);
INSERT INTO "django_geo_db_city" VALUES(6352,'Riva','Riva, Maryland',7751,38);
INSERT INTO "django_geo_db_city" VALUES(6353,'Severn','Severn, Maryland',7752,38);
INSERT INTO "django_geo_db_city" VALUES(6354,'Severna Park','Severna Park, Maryland',7753,38);
INSERT INTO "django_geo_db_city" VALUES(6355,'Simpsonville','Simpsonville, Maryland',7703,38);
INSERT INTO "django_geo_db_city" VALUES(6356,'Sparks Glencoe','Sparks Glencoe, Maryland',7754,38);
INSERT INTO "django_geo_db_city" VALUES(6357,'Stevenson','Stevenson, Maryland',7755,38);
INSERT INTO "django_geo_db_city" VALUES(6358,'Street','Street, Maryland',7756,38);
INSERT INTO "django_geo_db_city" VALUES(6359,'Upperco','Upperco, Maryland',7757,38);
INSERT INTO "django_geo_db_city" VALUES(6360,'Upper Falls','Upper Falls, Maryland',7758,38);
INSERT INTO "django_geo_db_city" VALUES(6361,'Westminster','Westminster, Maryland',7759,38);
INSERT INTO "django_geo_db_city" VALUES(6362,'Whiteford','Whiteford, Maryland',7761,38);
INSERT INTO "django_geo_db_city" VALUES(6363,'White Hall','White Hall, Maryland',7762,38);
INSERT INTO "django_geo_db_city" VALUES(6364,'White Marsh','White Marsh, Maryland',7763,38);
INSERT INTO "django_geo_db_city" VALUES(6365,'Woodstock','Woodstock, Maryland',7764,38);
INSERT INTO "django_geo_db_city" VALUES(6366,'New Windsor','New Windsor, Maryland',7765,38);
INSERT INTO "django_geo_db_city" VALUES(6367,'Baltimore','Baltimore, Maryland',7766,38);
INSERT INTO "django_geo_db_city" VALUES(6368,'Towson','Towson, Maryland',7769,38);
INSERT INTO "django_geo_db_city" VALUES(6369,'Gwynn Oak','Gwynn Oak, Maryland',7772,38);
INSERT INTO "django_geo_db_city" VALUES(6370,'Pikesville','Pikesville, Maryland',7773,38);
INSERT INTO "django_geo_db_city" VALUES(6371,'Sparrows Point','Sparrows Point, Maryland',7784,38);
INSERT INTO "django_geo_db_city" VALUES(6372,'Middle River','Middle River, Maryland',7785,38);
INSERT INTO "django_geo_db_city" VALUES(6373,'Essex','Essex, Maryland',7786,38);
INSERT INTO "django_geo_db_city" VALUES(6374,'Dundalk','Dundalk, Maryland',7787,38);
INSERT INTO "django_geo_db_city" VALUES(6375,'Brooklyn','Brooklyn, Maryland',7790,38);
INSERT INTO "django_geo_db_city" VALUES(6376,'Curtis Bay','Curtis Bay, Maryland',7791,38);
INSERT INTO "django_geo_db_city" VALUES(6377,'Halethorpe','Halethorpe, Maryland',7792,38);
INSERT INTO "django_geo_db_city" VALUES(6378,'Catonsville','Catonsville, Maryland',7793,38);
INSERT INTO "django_geo_db_city" VALUES(6379,'Parkville','Parkville, Maryland',7797,38);
INSERT INTO "django_geo_db_city" VALUES(6380,'Nottingham','Nottingham, Maryland',7798,38);
INSERT INTO "django_geo_db_city" VALUES(6381,'Rosedale','Rosedale, Maryland',7799,38);
INSERT INTO "django_geo_db_city" VALUES(6382,'Windsor Mill','Windsor Mill, Maryland',7802,38);
INSERT INTO "django_geo_db_city" VALUES(6383,'Annapolis','Annapolis, Maryland',7808,38);
INSERT INTO "django_geo_db_city" VALUES(6384,'Cumberland','Cumberland, Maryland',7812,38);
INSERT INTO "django_geo_db_city" VALUES(6385,'Accident','Accident, Maryland',7815,38);
INSERT INTO "django_geo_db_city" VALUES(6386,'Barton','Barton, Maryland',7816,38);
INSERT INTO "django_geo_db_city" VALUES(6387,'Bittinger','Bittinger, Maryland',7817,38);
INSERT INTO "django_geo_db_city" VALUES(6388,'Bloomington','Bloomington, Maryland',7818,38);
INSERT INTO "django_geo_db_city" VALUES(6389,'Corriganville','Corriganville, Maryland',7819,38);
INSERT INTO "django_geo_db_city" VALUES(6390,'Eckhart Mines','Eckhart Mines, Maryland',7820,38);
INSERT INTO "django_geo_db_city" VALUES(6391,'Ellerslie','Ellerslie, Maryland',7821,38);
INSERT INTO "django_geo_db_city" VALUES(6392,'Flintstone','Flintstone, Maryland',7822,38);
INSERT INTO "django_geo_db_city" VALUES(6393,'Friendsville','Friendsville, Maryland',7823,38);
INSERT INTO "django_geo_db_city" VALUES(6394,'Frostburg','Frostburg, Maryland',7824,38);
INSERT INTO "django_geo_db_city" VALUES(6395,'Grantsville','Grantsville, Maryland',7825,38);
INSERT INTO "django_geo_db_city" VALUES(6396,'Kitzmiller','Kitzmiller, Maryland',7826,38);
INSERT INTO "django_geo_db_city" VALUES(6397,'Lonaconing','Lonaconing, Maryland',7827,38);
INSERT INTO "django_geo_db_city" VALUES(6398,'Luke','Luke, Maryland',7828,38);
INSERT INTO "django_geo_db_city" VALUES(6399,'McHenry','McHenry, Maryland',7829,38);
INSERT INTO "django_geo_db_city" VALUES(6400,'Midland','Midland, Maryland',7830,38);
INSERT INTO "django_geo_db_city" VALUES(6401,'Midlothian','Midlothian, Maryland',7831,38);
INSERT INTO "django_geo_db_city" VALUES(6402,'Mount Savage','Mount Savage, Maryland',7832,38);
INSERT INTO "django_geo_db_city" VALUES(6403,'Oakland','Oakland, Maryland',7833,38);
INSERT INTO "django_geo_db_city" VALUES(6404,'Oldtown','Oldtown, Maryland',7834,38);
INSERT INTO "django_geo_db_city" VALUES(6405,'Pinto','Pinto, Maryland',7835,38);
INSERT INTO "django_geo_db_city" VALUES(6406,'Rawlings','Rawlings, Maryland',7836,38);
INSERT INTO "django_geo_db_city" VALUES(6407,'Spring Gap','Spring Gap, Maryland',7837,38);
INSERT INTO "django_geo_db_city" VALUES(6408,'Swanton','Swanton, Maryland',7838,38);
INSERT INTO "django_geo_db_city" VALUES(6409,'Westernport','Westernport, Maryland',7839,38);
INSERT INTO "django_geo_db_city" VALUES(6410,'Easton','Easton, Maryland',7840,38);
INSERT INTO "django_geo_db_city" VALUES(6411,'Barclay','Barclay, Maryland',7842,38);
INSERT INTO "django_geo_db_city" VALUES(6412,'Bethlehem','Bethlehem, Maryland',7843,38);
INSERT INTO "django_geo_db_city" VALUES(6413,'Betterton','Betterton, Maryland',7844,38);
INSERT INTO "django_geo_db_city" VALUES(6414,'Bozman','Bozman, Maryland',7845,38);
INSERT INTO "django_geo_db_city" VALUES(6415,'Cambridge','Cambridge, Maryland',7846,38);
INSERT INTO "django_geo_db_city" VALUES(6416,'Centreville','Centreville, Maryland',7847,38);
INSERT INTO "django_geo_db_city" VALUES(6417,'Chester','Chester, Maryland',7848,38);
INSERT INTO "django_geo_db_city" VALUES(6418,'Chestertown','Chestertown, Maryland',7849,38);
INSERT INTO "django_geo_db_city" VALUES(6419,'Church Creek','Church Creek, Maryland',7850,38);
INSERT INTO "django_geo_db_city" VALUES(6420,'Church Hill','Church Hill, Maryland',7851,38);
INSERT INTO "django_geo_db_city" VALUES(6421,'Claiborne','Claiborne, Maryland',7852,38);
INSERT INTO "django_geo_db_city" VALUES(6422,'Cordova','Cordova, Maryland',7853,38);
INSERT INTO "django_geo_db_city" VALUES(6423,'Crapo','Crapo, Maryland',7854,38);
INSERT INTO "django_geo_db_city" VALUES(6424,'Crocheron','Crocheron, Maryland',7855,38);
INSERT INTO "django_geo_db_city" VALUES(6425,'Crumpton','Crumpton, Maryland',7856,38);
INSERT INTO "django_geo_db_city" VALUES(6426,'Denton','Denton, Maryland',7857,38);
INSERT INTO "django_geo_db_city" VALUES(6427,'East New Market','East New Market, Maryland',7858,38);
INSERT INTO "django_geo_db_city" VALUES(6428,'Federalsburg','Federalsburg, Maryland',7859,38);
INSERT INTO "django_geo_db_city" VALUES(6429,'Fishing Creek','Fishing Creek, Maryland',7860,38);
INSERT INTO "django_geo_db_city" VALUES(6430,'Galena','Galena, Maryland',7861,38);
INSERT INTO "django_geo_db_city" VALUES(6431,'Goldsboro','Goldsboro, Maryland',7862,38);
INSERT INTO "django_geo_db_city" VALUES(6432,'Grasonville','Grasonville, Maryland',7863,38);
INSERT INTO "django_geo_db_city" VALUES(6433,'Greensboro','Greensboro, Maryland',7864,38);
INSERT INTO "django_geo_db_city" VALUES(6434,'Henderson','Henderson, Maryland',7865,38);
INSERT INTO "django_geo_db_city" VALUES(6435,'Hillsboro','Hillsboro, Maryland',7866,38);
INSERT INTO "django_geo_db_city" VALUES(6436,'Hurlock','Hurlock, Maryland',7867,38);
INSERT INTO "django_geo_db_city" VALUES(6437,'Ingleside','Ingleside, Maryland',7868,38);
INSERT INTO "django_geo_db_city" VALUES(6438,'Kennedyville','Kennedyville, Maryland',7869,38);
INSERT INTO "django_geo_db_city" VALUES(6439,'Mcdaniel','Mcdaniel, Maryland',7870,38);
INSERT INTO "django_geo_db_city" VALUES(6440,'Madison','Madison, Maryland',7871,38);
INSERT INTO "django_geo_db_city" VALUES(6441,'Marydel','Marydel, Maryland',7872,38);
INSERT INTO "django_geo_db_city" VALUES(6442,'Massey','Massey, Maryland',7873,38);
INSERT INTO "django_geo_db_city" VALUES(6443,'Millington','Millington, Maryland',7874,38);
INSERT INTO "django_geo_db_city" VALUES(6444,'Neavitt','Neavitt, Maryland',7875,38);
INSERT INTO "django_geo_db_city" VALUES(6445,'Newcomb','Newcomb, Maryland',7876,38);
INSERT INTO "django_geo_db_city" VALUES(6446,'Oxford','Oxford, Maryland',7877,38);
INSERT INTO "django_geo_db_city" VALUES(6447,'Preston','Preston, Maryland',7878,38);
INSERT INTO "django_geo_db_city" VALUES(6448,'Price','Price, Maryland',7879,38);
INSERT INTO "django_geo_db_city" VALUES(6449,'Queen Anne','Queen Anne, Maryland',7880,38);
INSERT INTO "django_geo_db_city" VALUES(6450,'Queenstown','Queenstown, Maryland',7881,38);
INSERT INTO "django_geo_db_city" VALUES(6451,'Rhodesdale','Rhodesdale, Maryland',7882,38);
INSERT INTO "django_geo_db_city" VALUES(6452,'Ridgely','Ridgely, Maryland',7883,38);
INSERT INTO "django_geo_db_city" VALUES(6453,'Rock Hall','Rock Hall, Maryland',7884,38);
INSERT INTO "django_geo_db_city" VALUES(6454,'Royal Oak','Royal Oak, Maryland',7885,38);
INSERT INTO "django_geo_db_city" VALUES(6455,'Saint Michaels','Saint Michaels, Maryland',7886,38);
INSERT INTO "django_geo_db_city" VALUES(6456,'Secretary','Secretary, Maryland',7887,38);
INSERT INTO "django_geo_db_city" VALUES(6457,'Sherwood','Sherwood, Maryland',7888,38);
INSERT INTO "django_geo_db_city" VALUES(6458,'Stevensville','Stevensville, Maryland',7889,38);
INSERT INTO "django_geo_db_city" VALUES(6459,'Still Pond','Still Pond, Maryland',7890,38);
INSERT INTO "django_geo_db_city" VALUES(6460,'Sudlersville','Sudlersville, Maryland',7891,38);
INSERT INTO "django_geo_db_city" VALUES(6461,'Taylors Island','Taylors Island, Maryland',7892,38);
INSERT INTO "django_geo_db_city" VALUES(6462,'Templeville','Templeville, Maryland',7893,38);
INSERT INTO "django_geo_db_city" VALUES(6463,'Tilghman','Tilghman, Maryland',7894,38);
INSERT INTO "django_geo_db_city" VALUES(6464,'Toddville','Toddville, Maryland',7895,38);
INSERT INTO "django_geo_db_city" VALUES(6465,'Trappe','Trappe, Maryland',7896,38);
INSERT INTO "django_geo_db_city" VALUES(6466,'Wingate','Wingate, Maryland',7897,38);
INSERT INTO "django_geo_db_city" VALUES(6467,'Wittman','Wittman, Maryland',7898,38);
INSERT INTO "django_geo_db_city" VALUES(6468,'Woolford','Woolford, Maryland',7899,38);
INSERT INTO "django_geo_db_city" VALUES(6469,'Worton','Worton, Maryland',7900,38);
INSERT INTO "django_geo_db_city" VALUES(6470,'Wye Mills','Wye Mills, Maryland',7901,38);
INSERT INTO "django_geo_db_city" VALUES(6471,'Frederick','Frederick, Maryland',7902,38);
INSERT INTO "django_geo_db_city" VALUES(6472,'Adamstown','Adamstown, Maryland',7907,38);
INSERT INTO "django_geo_db_city" VALUES(6473,'Big Pool','Big Pool, Maryland',7908,38);
INSERT INTO "django_geo_db_city" VALUES(6474,'Boonsboro','Boonsboro, Maryland',7909,38);
INSERT INTO "django_geo_db_city" VALUES(6475,'Braddock Heights','Braddock Heights, Maryland',7910,38);
INSERT INTO "django_geo_db_city" VALUES(6476,'Brownsville','Brownsville, Maryland',7911,38);
INSERT INTO "django_geo_db_city" VALUES(6477,'Brunswick','Brunswick, Maryland',7912,38);
INSERT INTO "django_geo_db_city" VALUES(6478,'Buckeystown','Buckeystown, Maryland',7913,38);
INSERT INTO "django_geo_db_city" VALUES(6479,'Burkittsville','Burkittsville, Maryland',7914,38);
INSERT INTO "django_geo_db_city" VALUES(6480,'Cascade','Cascade, Maryland',7915,38);
INSERT INTO "django_geo_db_city" VALUES(6481,'Cavetown','Cavetown, Maryland',7916,38);
INSERT INTO "django_geo_db_city" VALUES(6482,'Chewsville','Chewsville, Maryland',7917,38);
INSERT INTO "django_geo_db_city" VALUES(6483,'Clear Spring','Clear Spring, Maryland',7918,38);
INSERT INTO "django_geo_db_city" VALUES(6484,'Cooksville','Cooksville, Maryland',7919,38);
INSERT INTO "django_geo_db_city" VALUES(6485,'Emmitsburg','Emmitsburg, Maryland',7920,38);
INSERT INTO "django_geo_db_city" VALUES(6486,'Fairplay','Fairplay, Maryland',7921,38);
INSERT INTO "django_geo_db_city" VALUES(6487,'Funkstown','Funkstown, Maryland',7922,38);
INSERT INTO "django_geo_db_city" VALUES(6488,'Gapland','Gapland, Maryland',7923,38);
INSERT INTO "django_geo_db_city" VALUES(6489,'Glenelg','Glenelg, Maryland',7924,38);
INSERT INTO "django_geo_db_city" VALUES(6490,'Glenwood','Glenwood, Maryland',7925,38);
INSERT INTO "django_geo_db_city" VALUES(6491,'Hagerstown','Hagerstown, Maryland',7926,38);
INSERT INTO "django_geo_db_city" VALUES(6492,'Hancock','Hancock, Maryland',7930,38);
INSERT INTO "django_geo_db_city" VALUES(6493,'Ijamsville','Ijamsville, Maryland',7931,38);
INSERT INTO "django_geo_db_city" VALUES(6494,'Jefferson','Jefferson, Maryland',7932,38);
INSERT INTO "django_geo_db_city" VALUES(6495,'Keedysville','Keedysville, Maryland',7933,38);
INSERT INTO "django_geo_db_city" VALUES(6496,'Keymar','Keymar, Maryland',7934,38);
INSERT INTO "django_geo_db_city" VALUES(6497,'Knoxville','Knoxville, Maryland',7935,38);
INSERT INTO "django_geo_db_city" VALUES(6498,'Ladiesburg','Ladiesburg, Maryland',7936,38);
INSERT INTO "django_geo_db_city" VALUES(6499,'Libertytown','Libertytown, Maryland',7937,38);
INSERT INTO "django_geo_db_city" VALUES(6500,'Linwood','Linwood, Maryland',7727,38);
INSERT INTO "django_geo_db_city" VALUES(6501,'Lisbon','Lisbon, Maryland',7938,38);
INSERT INTO "django_geo_db_city" VALUES(6502,'Little Orleans','Little Orleans, Maryland',7939,38);
INSERT INTO "django_geo_db_city" VALUES(6503,'Maugansville','Maugansville, Maryland',7940,38);
INSERT INTO "django_geo_db_city" VALUES(6504,'Middletown','Middletown, Maryland',7941,38);
INSERT INTO "django_geo_db_city" VALUES(6505,'Monrovia','Monrovia, Maryland',7942,38);
INSERT INTO "django_geo_db_city" VALUES(6506,'Mount Airy','Mount Airy, Maryland',7943,38);
INSERT INTO "django_geo_db_city" VALUES(6507,'Myersville','Myersville, Maryland',7944,38);
INSERT INTO "django_geo_db_city" VALUES(6508,'New Market','New Market, Maryland',7945,38);
INSERT INTO "django_geo_db_city" VALUES(6509,'New Midway','New Midway, Maryland',7946,38);
INSERT INTO "django_geo_db_city" VALUES(6510,'Point Of Rocks','Point Of Rocks, Maryland',7948,38);
INSERT INTO "django_geo_db_city" VALUES(6511,'Rocky Ridge','Rocky Ridge, Maryland',7949,38);
INSERT INTO "django_geo_db_city" VALUES(6512,'Rohrersville','Rohrersville, Maryland',7950,38);
INSERT INTO "django_geo_db_city" VALUES(6513,'Sabillasville','Sabillasville, Maryland',7951,38);
INSERT INTO "django_geo_db_city" VALUES(6514,'Saint James','Saint James, Maryland',7952,38);
INSERT INTO "django_geo_db_city" VALUES(6515,'Sharpsburg','Sharpsburg, Maryland',7953,38);
INSERT INTO "django_geo_db_city" VALUES(6516,'Smithsburg','Smithsburg, Maryland',7954,38);
INSERT INTO "django_geo_db_city" VALUES(6517,'Sykesville','Sykesville, Maryland',7955,38);
INSERT INTO "django_geo_db_city" VALUES(6518,'Taneytown','Taneytown, Maryland',7956,38);
INSERT INTO "django_geo_db_city" VALUES(6519,'Thurmont','Thurmont, Maryland',7957,38);
INSERT INTO "django_geo_db_city" VALUES(6520,'Tuscarora','Tuscarora, Maryland',7958,38);
INSERT INTO "django_geo_db_city" VALUES(6521,'Union Bridge','Union Bridge, Maryland',7959,38);
INSERT INTO "django_geo_db_city" VALUES(6522,'Unionville','Unionville, Maryland',7906,38);
INSERT INTO "django_geo_db_city" VALUES(6523,'Walkersville','Walkersville, Maryland',7960,38);
INSERT INTO "django_geo_db_city" VALUES(6524,'West Friendship','West Friendship, Maryland',7961,38);
INSERT INTO "django_geo_db_city" VALUES(6525,'Williamsport','Williamsport, Maryland',7962,38);
INSERT INTO "django_geo_db_city" VALUES(6526,'Woodbine','Woodbine, Maryland',7963,38);
INSERT INTO "django_geo_db_city" VALUES(6527,'Woodsboro','Woodsboro, Maryland',7964,38);
INSERT INTO "django_geo_db_city" VALUES(6528,'Salisbury','Salisbury, Maryland',7965,38);
INSERT INTO "django_geo_db_city" VALUES(6529,'Allen','Allen, Maryland',7968,38);
INSERT INTO "django_geo_db_city" VALUES(6530,'Berlin','Berlin, Maryland',7969,38);
INSERT INTO "django_geo_db_city" VALUES(6531,'Bishopville','Bishopville, Maryland',7970,38);
INSERT INTO "django_geo_db_city" VALUES(6532,'Bivalve','Bivalve, Maryland',7971,38);
INSERT INTO "django_geo_db_city" VALUES(6533,'Crisfield','Crisfield, Maryland',7972,38);
INSERT INTO "django_geo_db_city" VALUES(6534,'Deal Island','Deal Island, Maryland',7973,38);
INSERT INTO "django_geo_db_city" VALUES(6535,'Eden','Eden, Maryland',7974,38);
INSERT INTO "django_geo_db_city" VALUES(6536,'Ewell','Ewell, Maryland',7975,38);
INSERT INTO "django_geo_db_city" VALUES(6537,'Fruitland','Fruitland, Maryland',7976,38);
INSERT INTO "django_geo_db_city" VALUES(6538,'Girdletree','Girdletree, Maryland',7977,38);
INSERT INTO "django_geo_db_city" VALUES(6539,'Hebron','Hebron, Maryland',7978,38);
INSERT INTO "django_geo_db_city" VALUES(6540,'Linkwood','Linkwood, Maryland',7980,38);
INSERT INTO "django_geo_db_city" VALUES(6541,'Manokin','Manokin, Maryland',7981,38);
INSERT INTO "django_geo_db_city" VALUES(6542,'Mardela Springs','Mardela Springs, Maryland',7982,38);
INSERT INTO "django_geo_db_city" VALUES(6543,'Marion Station','Marion Station, Maryland',7983,38);
INSERT INTO "django_geo_db_city" VALUES(6544,'Nanticoke','Nanticoke, Maryland',7984,38);
INSERT INTO "django_geo_db_city" VALUES(6545,'Newark','Newark, Maryland',7985,38);
INSERT INTO "django_geo_db_city" VALUES(6546,'Ocean City','Ocean City, Maryland',7986,38);
INSERT INTO "django_geo_db_city" VALUES(6547,'Parsonsburg','Parsonsburg, Maryland',7988,38);
INSERT INTO "django_geo_db_city" VALUES(6548,'Pittsville','Pittsville, Maryland',7989,38);
INSERT INTO "django_geo_db_city" VALUES(6549,'Pocomoke City','Pocomoke City, Maryland',7990,38);
INSERT INTO "django_geo_db_city" VALUES(6550,'Powellville','Powellville, Maryland',7966,38);
INSERT INTO "django_geo_db_city" VALUES(6551,'Princess Anne','Princess Anne, Maryland',7991,38);
INSERT INTO "django_geo_db_city" VALUES(6552,'Quantico','Quantico, Maryland',7992,38);
INSERT INTO "django_geo_db_city" VALUES(6553,'Rehobeth','Rehobeth, Maryland',7993,38);
INSERT INTO "django_geo_db_city" VALUES(6554,'Sharptown','Sharptown, Maryland',7994,38);
INSERT INTO "django_geo_db_city" VALUES(6555,'Showell','Showell, Maryland',7995,38);
INSERT INTO "django_geo_db_city" VALUES(6556,'Snow Hill','Snow Hill, Maryland',7996,38);
INSERT INTO "django_geo_db_city" VALUES(6557,'Stockton','Stockton, Maryland',7997,38);
INSERT INTO "django_geo_db_city" VALUES(6558,'Tyaskin','Tyaskin, Maryland',7998,38);
INSERT INTO "django_geo_db_city" VALUES(6559,'Tylerton','Tylerton, Maryland',7999,38);
INSERT INTO "django_geo_db_city" VALUES(6560,'Upper Fairmount','Upper Fairmount, Maryland',8000,38);
INSERT INTO "django_geo_db_city" VALUES(6561,'Fairmount','Fairmount, Maryland',8001,38);
INSERT INTO "django_geo_db_city" VALUES(6562,'Vienna','Vienna, Maryland',8002,38);
INSERT INTO "django_geo_db_city" VALUES(6563,'Wenona','Wenona, Maryland',7993,38);
INSERT INTO "django_geo_db_city" VALUES(6564,'Westover','Westover, Maryland',8003,38);
INSERT INTO "django_geo_db_city" VALUES(6565,'Whaleyville','Whaleyville, Maryland',8004,38);
INSERT INTO "django_geo_db_city" VALUES(6566,'Willards','Willards, Maryland',8005,38);
INSERT INTO "django_geo_db_city" VALUES(6567,'Delmar','Delmar, Maryland',8006,38);
INSERT INTO "django_geo_db_city" VALUES(6568,'North East','North East, Maryland',8007,38);
INSERT INTO "django_geo_db_city" VALUES(6569,'Perry Point','Perry Point, Maryland',8008,38);
INSERT INTO "django_geo_db_city" VALUES(6570,'Perryville','Perryville, Maryland',8009,38);
INSERT INTO "django_geo_db_city" VALUES(6571,'Port Deposit','Port Deposit, Maryland',8010,38);
INSERT INTO "django_geo_db_city" VALUES(6572,'Rising Sun','Rising Sun, Maryland',8011,38);
INSERT INTO "django_geo_db_city" VALUES(6573,'Warwick','Warwick, Maryland',8012,38);
INSERT INTO "django_geo_db_city" VALUES(6574,'Cecilton','Cecilton, Maryland',8013,38);
INSERT INTO "django_geo_db_city" VALUES(6575,'Charlestown','Charlestown, Maryland',8014,38);
INSERT INTO "django_geo_db_city" VALUES(6576,'Chesapeake City','Chesapeake City, Maryland',8015,38);
INSERT INTO "django_geo_db_city" VALUES(6577,'Childs','Childs, Maryland',8016,38);
INSERT INTO "django_geo_db_city" VALUES(6578,'Colora','Colora, Maryland',8017,38);
INSERT INTO "django_geo_db_city" VALUES(6579,'Conowingo','Conowingo, Maryland',8018,38);
INSERT INTO "django_geo_db_city" VALUES(6580,'Earleville','Earleville, Maryland',8019,38);
INSERT INTO "django_geo_db_city" VALUES(6581,'Elk Mills','Elk Mills, Maryland',8020,38);
INSERT INTO "django_geo_db_city" VALUES(6582,'Elkton','Elkton, Maryland',8021,38);
INSERT INTO "django_geo_db_city" VALUES(6583,'Georgetown','Georgetown, Maryland',8023,38);
INSERT INTO "django_geo_db_city" VALUES(6584,'Annandale','Annandale, Virginia',8025,54);
INSERT INTO "django_geo_db_city" VALUES(6585,'Burke','Burke, Virginia',7391,54);
INSERT INTO "django_geo_db_city" VALUES(6586,'Dumfries','Dumfries, Virginia',8027,54);
INSERT INTO "django_geo_db_city" VALUES(6587,'Dunn Loring','Dunn Loring, Virginia',8028,54);
INSERT INTO "django_geo_db_city" VALUES(6588,'Fairfax','Fairfax, Virginia',8029,54);
INSERT INTO "django_geo_db_city" VALUES(6589,'Fairfax Station','Fairfax Station, Virginia',8036,54);
INSERT INTO "django_geo_db_city" VALUES(6590,'Falls Church','Falls Church, Virginia',8037,54);
INSERT INTO "django_geo_db_city" VALUES(6591,'Fort Belvoir','Fort Belvoir, Virginia',8043,54);
INSERT INTO "django_geo_db_city" VALUES(6592,'Great Falls','Great Falls, Virginia',8044,54);
INSERT INTO "django_geo_db_city" VALUES(6593,'Greenway','Greenway, Virginia',8045,54);
INSERT INTO "django_geo_db_city" VALUES(6594,'Lorton','Lorton, Virginia',8046,54);
INSERT INTO "django_geo_db_city" VALUES(6595,'Merrifield','Merrifield, Virginia',8047,54);
INSERT INTO "django_geo_db_city" VALUES(6596,'McLean','McLean, Virginia',8048,54);
INSERT INTO "django_geo_db_city" VALUES(6597,'West Mclean','West Mclean, Virginia',7391,54);
INSERT INTO "django_geo_db_city" VALUES(6598,'Mount Vernon','Mount Vernon, Virginia',8052,54);
INSERT INTO "django_geo_db_city" VALUES(6599,'Newington','Newington, Virginia',7391,54);
INSERT INTO "django_geo_db_city" VALUES(6600,'Oakton','Oakton, Virginia',8053,54);
INSERT INTO "django_geo_db_city" VALUES(6601,'Occoquan','Occoquan, Virginia',8054,54);
INSERT INTO "django_geo_db_city" VALUES(6602,'Quantico','Quantico, Virginia',8055,54);
INSERT INTO "django_geo_db_city" VALUES(6603,'Springfield','Springfield, Virginia',8056,54);
INSERT INTO "django_geo_db_city" VALUES(6604,'Triangle','Triangle, Virginia',8061,54);
INSERT INTO "django_geo_db_city" VALUES(6605,'Vienna','Vienna, Virginia',8062,54);
INSERT INTO "django_geo_db_city" VALUES(6606,'Woodbridge','Woodbridge, Virginia',8065,54);
INSERT INTO "django_geo_db_city" VALUES(6607,'Arlington','Arlington, Virginia',8068,54);
INSERT INTO "django_geo_db_city" VALUES(6608,'Ft Myer','Ft Myer, Virginia',8077,54);
INSERT INTO "django_geo_db_city" VALUES(6609,'Alexandria','Alexandria, Virginia',8087,54);
INSERT INTO "django_geo_db_city" VALUES(6610,'Fishersville','Fishersville, Virginia',8105,54);
INSERT INTO "django_geo_db_city" VALUES(6611,'Fredericksburg','Fredericksburg, Virginia',8106,54);
INSERT INTO "django_geo_db_city" VALUES(6612,'Bowling Green','Bowling Green, Virginia',8115,54);
INSERT INTO "django_geo_db_city" VALUES(6613,'Brooke','Brooke, Virginia',8117,54);
INSERT INTO "django_geo_db_city" VALUES(6614,'Burgess','Burgess, Virginia',8118,54);
INSERT INTO "django_geo_db_city" VALUES(6615,'Burr Hill','Burr Hill, Virginia',8119,54);
INSERT INTO "django_geo_db_city" VALUES(6616,'Callao','Callao, Virginia',8120,54);
INSERT INTO "django_geo_db_city" VALUES(6617,'Caret','Caret, Virginia',8121,54);
INSERT INTO "django_geo_db_city" VALUES(6618,'Center Cross','Center Cross, Virginia',8122,54);
INSERT INTO "django_geo_db_city" VALUES(6619,'Champlain','Champlain, Virginia',8123,54);
INSERT INTO "django_geo_db_city" VALUES(6620,'Coles Point','Coles Point, Virginia',8124,54);
INSERT INTO "django_geo_db_city" VALUES(6621,'Colonial Beach','Colonial Beach, Virginia',8125,54);
INSERT INTO "django_geo_db_city" VALUES(6622,'Corbin','Corbin, Virginia',8126,54);
INSERT INTO "django_geo_db_city" VALUES(6623,'Dahlgren','Dahlgren, Virginia',8127,54);
INSERT INTO "django_geo_db_city" VALUES(6624,'Dogue','Dogue, Virginia',8128,54);
INSERT INTO "django_geo_db_city" VALUES(6625,'Dunnsville','Dunnsville, Virginia',8129,54);
INSERT INTO "django_geo_db_city" VALUES(6626,'Edwardsville','Edwardsville, Virginia',8130,54);
INSERT INTO "django_geo_db_city" VALUES(6627,'Farnham','Farnham, Virginia',8131,54);
INSERT INTO "django_geo_db_city" VALUES(6628,'Garrisonville','Garrisonville, Virginia',8132,54);
INSERT INTO "django_geo_db_city" VALUES(6629,'Hague','Hague, Virginia',8133,54);
INSERT INTO "django_geo_db_city" VALUES(6630,'Hartwood','Hartwood, Virginia',8134,54);
INSERT INTO "django_geo_db_city" VALUES(6631,'Haynesville','Haynesville, Virginia',8135,54);
INSERT INTO "django_geo_db_city" VALUES(6632,'Heathsville','Heathsville, Virginia',8136,54);
INSERT INTO "django_geo_db_city" VALUES(6633,'Hustle','Hustle, Virginia',8137,54);
INSERT INTO "django_geo_db_city" VALUES(6634,'Irvington','Irvington, Virginia',8138,54);
INSERT INTO "django_geo_db_city" VALUES(6635,'Jersey','Jersey, Virginia',8128,54);
INSERT INTO "django_geo_db_city" VALUES(6636,'Kilmarnock','Kilmarnock, Virginia',8139,54);
INSERT INTO "django_geo_db_city" VALUES(6637,'King George','King George, Virginia',8140,54);
INSERT INTO "django_geo_db_city" VALUES(6638,'Kinsale','Kinsale, Virginia',8142,54);
INSERT INTO "django_geo_db_city" VALUES(6639,'Ladysmith','Ladysmith, Virginia',8143,54);
INSERT INTO "django_geo_db_city" VALUES(6640,'Lancaster','Lancaster, Virginia',8144,54);
INSERT INTO "django_geo_db_city" VALUES(6641,'Laneview','Laneview, Virginia',8145,54);
INSERT INTO "django_geo_db_city" VALUES(6642,'Lively','Lively, Virginia',8146,54);
INSERT INTO "django_geo_db_city" VALUES(6643,'Locust Grove','Locust Grove, Virginia',8147,54);
INSERT INTO "django_geo_db_city" VALUES(6644,'Loretto','Loretto, Virginia',8148,54);
INSERT INTO "django_geo_db_city" VALUES(6645,'Lottsburg','Lottsburg, Virginia',8149,54);
INSERT INTO "django_geo_db_city" VALUES(6646,'Merry Point','Merry Point, Virginia',8150,54);
INSERT INTO "django_geo_db_city" VALUES(6647,'Milford','Milford, Virginia',8151,54);
INSERT INTO "django_geo_db_city" VALUES(6648,'Mollusk','Mollusk, Virginia',8152,54);
INSERT INTO "django_geo_db_city" VALUES(6649,'Montross','Montross, Virginia',8153,54);
INSERT INTO "django_geo_db_city" VALUES(6650,'Morattico','Morattico, Virginia',8154,54);
INSERT INTO "django_geo_db_city" VALUES(6651,'Mount Holly','Mount Holly, Virginia',8155,54);
INSERT INTO "django_geo_db_city" VALUES(6652,'Ninde','Ninde, Virginia',8128,54);
INSERT INTO "django_geo_db_city" VALUES(6653,'Nuttsville','Nuttsville, Virginia',8156,54);
INSERT INTO "django_geo_db_city" VALUES(6654,'Oldhams','Oldhams, Virginia',8157,54);
INSERT INTO "django_geo_db_city" VALUES(6655,'Ophelia','Ophelia, Virginia',8158,54);
INSERT INTO "django_geo_db_city" VALUES(6656,'Partlow','Partlow, Virginia',8159,54);
INSERT INTO "django_geo_db_city" VALUES(6657,'Port Royal','Port Royal, Virginia',8160,54);
INSERT INTO "django_geo_db_city" VALUES(6658,'Rappahannock Academy','Rappahannock Academy, Virginia',8161,54);
INSERT INTO "django_geo_db_city" VALUES(6659,'Reedville','Reedville, Virginia',8162,54);
INSERT INTO "django_geo_db_city" VALUES(6660,'Rhoadesville','Rhoadesville, Virginia',8163,54);
INSERT INTO "django_geo_db_city" VALUES(6661,'Rollins Fork','Rollins Fork, Virginia',8128,54);
INSERT INTO "django_geo_db_city" VALUES(6662,'Ruby','Ruby, Virginia',8164,54);
INSERT INTO "django_geo_db_city" VALUES(6663,'Ruther Glen','Ruther Glen, Virginia',8165,54);
INSERT INTO "django_geo_db_city" VALUES(6664,'Sealston','Sealston, Virginia',8128,54);
INSERT INTO "django_geo_db_city" VALUES(6665,'Sharps','Sharps, Virginia',8166,54);
INSERT INTO "django_geo_db_city" VALUES(6666,'Sparta','Sparta, Virginia',8167,54);
INSERT INTO "django_geo_db_city" VALUES(6667,'Spotsylvania','Spotsylvania, Virginia',8168,54);
INSERT INTO "django_geo_db_city" VALUES(6668,'Stafford','Stafford, Virginia',8169,54);
INSERT INTO "django_geo_db_city" VALUES(6669,'Stratford','Stratford, Virginia',8124,54);
INSERT INTO "django_geo_db_city" VALUES(6670,'Tappahannock','Tappahannock, Virginia',8170,54);
INSERT INTO "django_geo_db_city" VALUES(6671,'Thornburg','Thornburg, Virginia',8171,54);
INSERT INTO "django_geo_db_city" VALUES(6672,'Unionville','Unionville, Virginia',8172,54);
INSERT INTO "django_geo_db_city" VALUES(6673,'Village','Village, Virginia',8173,54);
INSERT INTO "django_geo_db_city" VALUES(6674,'Warsaw','Warsaw, Virginia',8174,54);
INSERT INTO "django_geo_db_city" VALUES(6675,'Weems','Weems, Virginia',8175,54);
INSERT INTO "django_geo_db_city" VALUES(6676,'Sandy Point','Sandy Point, Virginia',8176,54);
INSERT INTO "django_geo_db_city" VALUES(6677,'White Stone','White Stone, Virginia',8177,54);
INSERT INTO "django_geo_db_city" VALUES(6678,'Wicomico Church','Wicomico Church, Virginia',8178,54);
INSERT INTO "django_geo_db_city" VALUES(6679,'Woodford','Woodford, Virginia',8179,54);
INSERT INTO "django_geo_db_city" VALUES(6680,'Zacata','Zacata, Virginia',8124,54);
INSERT INTO "django_geo_db_city" VALUES(6681,'Winchester','Winchester, Virginia',8180,54);
INSERT INTO "django_geo_db_city" VALUES(6682,'Newport News','Newport News, Virginia',8184,54);
INSERT INTO "django_geo_db_city" VALUES(6683,'Bentonville','Bentonville, Virginia',8185,54);
INSERT INTO "django_geo_db_city" VALUES(6684,'Berryville','Berryville, Virginia',8186,54);
INSERT INTO "django_geo_db_city" VALUES(6685,'Boyce','Boyce, Virginia',8187,54);
INSERT INTO "django_geo_db_city" VALUES(6686,'Brucetown','Brucetown, Virginia',8188,54);
INSERT INTO "django_geo_db_city" VALUES(6687,'Chester Gap','Chester Gap, Virginia',8189,54);
INSERT INTO "django_geo_db_city" VALUES(6688,'Clear Brook','Clear Brook, Virginia',8190,54);
INSERT INTO "django_geo_db_city" VALUES(6689,'Cross Junction','Cross Junction, Virginia',8191,54);
INSERT INTO "django_geo_db_city" VALUES(6690,'Fishers Hill','Fishers Hill, Virginia',8192,54);
INSERT INTO "django_geo_db_city" VALUES(6691,'Flint Hill','Flint Hill, Virginia',8193,54);
INSERT INTO "django_geo_db_city" VALUES(6692,'Front Royal','Front Royal, Virginia',8194,54);
INSERT INTO "django_geo_db_city" VALUES(6693,'Gore','Gore, Virginia',8195,54);
INSERT INTO "django_geo_db_city" VALUES(6694,'Hume','Hume, Virginia',8197,54);
INSERT INTO "django_geo_db_city" VALUES(6695,'Huntly','Huntly, Virginia',8198,54);
INSERT INTO "django_geo_db_city" VALUES(6696,'Strasburg','Strasburg, Virginia',8199,54);
INSERT INTO "django_geo_db_city" VALUES(6697,'Linden','Linden, Virginia',8200,54);
INSERT INTO "django_geo_db_city" VALUES(6698,'Markham','Markham, Virginia',8201,54);
INSERT INTO "django_geo_db_city" VALUES(6699,'Maurertown','Maurertown, Virginia',8202,54);
INSERT INTO "django_geo_db_city" VALUES(6700,'Middletown','Middletown, Virginia',8203,54);
INSERT INTO "django_geo_db_city" VALUES(6701,'Millwood','Millwood, Virginia',8204,54);
INSERT INTO "django_geo_db_city" VALUES(6702,'Rileyville','Rileyville, Virginia',8206,54);
INSERT INTO "django_geo_db_city" VALUES(6703,'Fort Valley','Fort Valley, Virginia',8208,54);
INSERT INTO "django_geo_db_city" VALUES(6704,'Star Tannery','Star Tannery, Virginia',8209,54);
INSERT INTO "django_geo_db_city" VALUES(6705,'Stephens City','Stephens City, Virginia',8210,54);
INSERT INTO "django_geo_db_city" VALUES(6706,'Stephenson','Stephenson, Virginia',8211,54);
INSERT INTO "django_geo_db_city" VALUES(6707,'Toms Brook','Toms Brook, Virginia',8213,54);
INSERT INTO "django_geo_db_city" VALUES(6708,'White Post','White Post, Virginia',8214,54);
INSERT INTO "django_geo_db_city" VALUES(6709,'Woodstock','Woodstock, Virginia',8215,54);
INSERT INTO "django_geo_db_city" VALUES(6710,'Culpeper','Culpeper, Virginia',8216,54);
INSERT INTO "django_geo_db_city" VALUES(6711,'Aroda','Aroda, Virginia',8217,54);
INSERT INTO "django_geo_db_city" VALUES(6712,'Banco','Banco, Virginia',8218,54);
INSERT INTO "django_geo_db_city" VALUES(6713,'Bealeton','Bealeton, Virginia',8219,54);
INSERT INTO "django_geo_db_city" VALUES(6714,'Boston','Boston, Virginia',8220,54);
INSERT INTO "django_geo_db_city" VALUES(6715,'Brandy Station','Brandy Station, Virginia',8221,54);
INSERT INTO "django_geo_db_city" VALUES(6716,'Brightwood','Brightwood, Virginia',8222,54);
INSERT INTO "django_geo_db_city" VALUES(6717,'Castleton','Castleton, Virginia',8223,54);
INSERT INTO "django_geo_db_city" VALUES(6718,'Elkwood','Elkwood, Virginia',8224,54);
INSERT INTO "django_geo_db_city" VALUES(6719,'Etlan','Etlan, Virginia',8225,54);
INSERT INTO "django_geo_db_city" VALUES(6720,'Goldvein','Goldvein, Virginia',8226,54);
INSERT INTO "django_geo_db_city" VALUES(6721,'Graves Mill','Graves Mill, Virginia',8227,54);
INSERT INTO "django_geo_db_city" VALUES(6722,'Haywood','Haywood, Virginia',8228,54);
INSERT INTO "django_geo_db_city" VALUES(6723,'Hood','Hood, Virginia',8229,54);
INSERT INTO "django_geo_db_city" VALUES(6724,'Jeffersonton','Jeffersonton, Virginia',8230,54);
INSERT INTO "django_geo_db_city" VALUES(6725,'Leon','Leon, Virginia',8227,54);
INSERT INTO "django_geo_db_city" VALUES(6726,'Lignum','Lignum, Virginia',8231,54);
INSERT INTO "django_geo_db_city" VALUES(6727,'Madison','Madison, Virginia',8232,54);
INSERT INTO "django_geo_db_city" VALUES(6728,'Midland','Midland, Virginia',8233,54);
INSERT INTO "django_geo_db_city" VALUES(6729,'Mitchells','Mitchells, Virginia',8234,54);
INSERT INTO "django_geo_db_city" VALUES(6730,'Oakpark','Oakpark, Virginia',8235,54);
INSERT INTO "django_geo_db_city" VALUES(6731,'Pratts','Pratts, Virginia',8236,54);
INSERT INTO "django_geo_db_city" VALUES(6732,'Radiant','Radiant, Virginia',8237,54);
INSERT INTO "django_geo_db_city" VALUES(6733,'Rapidan','Rapidan, Virginia',8238,54);
INSERT INTO "django_geo_db_city" VALUES(6734,'Remington','Remington, Virginia',8239,54);
INSERT INTO "django_geo_db_city" VALUES(6735,'Reva','Reva, Virginia',8240,54);
INSERT INTO "django_geo_db_city" VALUES(6736,'Richardsville','Richardsville, Virginia',8241,54);
INSERT INTO "django_geo_db_city" VALUES(6737,'Rixeyville','Rixeyville, Virginia',8242,54);
INSERT INTO "django_geo_db_city" VALUES(6738,'Rochelle','Rochelle, Virginia',8243,54);
INSERT INTO "django_geo_db_city" VALUES(6739,'Somerville','Somerville, Virginia',8244,54);
INSERT INTO "django_geo_db_city" VALUES(6740,'Sperryville','Sperryville, Virginia',8245,54);
INSERT INTO "django_geo_db_city" VALUES(6741,'Stevensburg','Stevensburg, Virginia',8246,54);
INSERT INTO "django_geo_db_city" VALUES(6742,'Sumerduck','Sumerduck, Virginia',8247,54);
INSERT INTO "django_geo_db_city" VALUES(6743,'Syria','Syria, Virginia',8248,54);
INSERT INTO "django_geo_db_city" VALUES(6744,'Viewtown','Viewtown, Virginia',8249,54);
INSERT INTO "django_geo_db_city" VALUES(6745,'Washington','Washington, Virginia',8250,54);
INSERT INTO "django_geo_db_city" VALUES(6746,'Wolftown','Wolftown, Virginia',8251,54);
INSERT INTO "django_geo_db_city" VALUES(6747,'Woodville','Woodville, Virginia',8252,54);
INSERT INTO "django_geo_db_city" VALUES(6748,'Harrisonburg','Harrisonburg, Virginia',8253,54);
INSERT INTO "django_geo_db_city" VALUES(6749,'Basye','Basye, Virginia',8256,54);
INSERT INTO "django_geo_db_city" VALUES(6750,'Bergton','Bergton, Virginia',8257,54);
INSERT INTO "django_geo_db_city" VALUES(6751,'Bridgewater','Bridgewater, Virginia',8258,54);
INSERT INTO "django_geo_db_city" VALUES(6752,'Broadway','Broadway, Virginia',8259,54);
INSERT INTO "django_geo_db_city" VALUES(6753,'Criders','Criders, Virginia',8260,54);
INSERT INTO "django_geo_db_city" VALUES(6754,'Dayton','Dayton, Virginia',8261,54);
INSERT INTO "django_geo_db_city" VALUES(6755,'Edinburg','Edinburg, Virginia',8262,54);
INSERT INTO "django_geo_db_city" VALUES(6756,'Elkton','Elkton, Virginia',8263,54);
INSERT INTO "django_geo_db_city" VALUES(6757,'Fulks Run','Fulks Run, Virginia',8264,54);
INSERT INTO "django_geo_db_city" VALUES(6758,'Hinton','Hinton, Virginia',8265,54);
INSERT INTO "django_geo_db_city" VALUES(6759,'Keezletown','Keezletown, Virginia',8266,54);
INSERT INTO "django_geo_db_city" VALUES(6760,'Lacey Spring','Lacey Spring, Virginia',8267,54);
INSERT INTO "django_geo_db_city" VALUES(6761,'Linville','Linville, Virginia',8268,54);
INSERT INTO "django_geo_db_city" VALUES(6762,'Luray','Luray, Virginia',8269,54);
INSERT INTO "django_geo_db_city" VALUES(6763,'McGaheysville','McGaheysville, Virginia',8270,54);
INSERT INTO "django_geo_db_city" VALUES(6764,'Mount Crawford','Mount Crawford, Virginia',8271,54);
INSERT INTO "django_geo_db_city" VALUES(6765,'Mount Jackson','Mount Jackson, Virginia',8272,54);
INSERT INTO "django_geo_db_city" VALUES(6766,'Mount Solon','Mount Solon, Virginia',8273,54);
INSERT INTO "django_geo_db_city" VALUES(6767,'New Market','New Market, Virginia',8274,54);
INSERT INTO "django_geo_db_city" VALUES(6768,'Orkney Springs','Orkney Springs, Virginia',8275,54);
INSERT INTO "django_geo_db_city" VALUES(6769,'Penn Laird','Penn Laird, Virginia',8276,54);
INSERT INTO "django_geo_db_city" VALUES(6770,'Quicksburg','Quicksburg, Virginia',8277,54);
INSERT INTO "django_geo_db_city" VALUES(6771,'Pleasant Valley','Pleasant Valley, Virginia',8278,54);
INSERT INTO "django_geo_db_city" VALUES(6772,'Shenandoah','Shenandoah, Virginia',8279,54);
INSERT INTO "django_geo_db_city" VALUES(6773,'Singers Glen','Singers Glen, Virginia',8280,54);
INSERT INTO "django_geo_db_city" VALUES(6774,'Stanley','Stanley, Virginia',8281,54);
INSERT INTO "django_geo_db_city" VALUES(6775,'Timberville','Timberville, Virginia',8282,54);
INSERT INTO "django_geo_db_city" VALUES(6776,'Waynesboro','Waynesboro, Virginia',8285,54);
INSERT INTO "django_geo_db_city" VALUES(6777,'Charlottesville','Charlottesville, Virginia',8286,54);
INSERT INTO "django_geo_db_city" VALUES(6778,'Afton','Afton, Virginia',8292,54);
INSERT INTO "django_geo_db_city" VALUES(6779,'Arrington','Arrington, Virginia',8293,54);
INSERT INTO "django_geo_db_city" VALUES(6780,'Barboursville','Barboursville, Virginia',8294,54);
INSERT INTO "django_geo_db_city" VALUES(6781,'Batesville','Batesville, Virginia',8295,54);
INSERT INTO "django_geo_db_city" VALUES(6782,'Covesville','Covesville, Virginia',8296,54);
INSERT INTO "django_geo_db_city" VALUES(6783,'Crozet','Crozet, Virginia',8297,54);
INSERT INTO "django_geo_db_city" VALUES(6784,'Dyke','Dyke, Virginia',8298,54);
INSERT INTO "django_geo_db_city" VALUES(6785,'Earlysville','Earlysville, Virginia',8299,54);
INSERT INTO "django_geo_db_city" VALUES(6786,'Esmont','Esmont, Virginia',8300,54);
INSERT INTO "django_geo_db_city" VALUES(6787,'Faber','Faber, Virginia',8301,54);
INSERT INTO "django_geo_db_city" VALUES(6788,'Free Union','Free Union, Virginia',8303,54);
INSERT INTO "django_geo_db_city" VALUES(6789,'Gordonsville','Gordonsville, Virginia',8304,54);
INSERT INTO "django_geo_db_city" VALUES(6790,'Greenwood','Greenwood, Virginia',8305,54);
INSERT INTO "django_geo_db_city" VALUES(6791,'Ivy','Ivy, Virginia',8306,54);
INSERT INTO "django_geo_db_city" VALUES(6792,'Keene','Keene, Virginia',8307,54);
INSERT INTO "django_geo_db_city" VALUES(6793,'Keswick','Keswick, Virginia',8308,54);
INSERT INTO "django_geo_db_city" VALUES(6794,'Locust Dale','Locust Dale, Virginia',8309,54);
INSERT INTO "django_geo_db_city" VALUES(6795,'Lovingston','Lovingston, Virginia',8310,54);
INSERT INTO "django_geo_db_city" VALUES(6796,'Lyndhurst','Lyndhurst, Virginia',8311,54);
INSERT INTO "django_geo_db_city" VALUES(6797,'Madison Mills','Madison Mills, Virginia',8227,54);
INSERT INTO "django_geo_db_city" VALUES(6798,'Massies Mill','Massies Mill, Virginia',8312,54);
INSERT INTO "django_geo_db_city" VALUES(6799,'Montpelier Station','Montpelier Station, Virginia',8313,54);
INSERT INTO "django_geo_db_city" VALUES(6800,'Nellysford','Nellysford, Virginia',8314,54);
INSERT INTO "django_geo_db_city" VALUES(6801,'North Garden','North Garden, Virginia',8315,54);
INSERT INTO "django_geo_db_city" VALUES(6802,'Orange','Orange, Virginia',8316,54);
INSERT INTO "django_geo_db_city" VALUES(6803,'Palmyra','Palmyra, Virginia',8317,54);
INSERT INTO "django_geo_db_city" VALUES(6804,'Piney River','Piney River, Virginia',8318,54);
INSERT INTO "django_geo_db_city" VALUES(6805,'Quinque','Quinque, Virginia',8319,54);
INSERT INTO "django_geo_db_city" VALUES(6806,'Roseland','Roseland, Virginia',8320,54);
INSERT INTO "django_geo_db_city" VALUES(6807,'Ruckersville','Ruckersville, Virginia',8321,54);
INSERT INTO "django_geo_db_city" VALUES(6808,'Schuyler','Schuyler, Virginia',8322,54);
INSERT INTO "django_geo_db_city" VALUES(6809,'Shipman','Shipman, Virginia',8323,54);
INSERT INTO "django_geo_db_city" VALUES(6810,'Somerset','Somerset, Virginia',8324,54);
INSERT INTO "django_geo_db_city" VALUES(6811,'Stanardsville','Stanardsville, Virginia',8325,54);
INSERT INTO "django_geo_db_city" VALUES(6812,'Troy','Troy, Virginia',8326,54);
INSERT INTO "django_geo_db_city" VALUES(6813,'Tyro','Tyro, Virginia',8327,54);
INSERT INTO "django_geo_db_city" VALUES(6814,'White Hall','White Hall, Virginia',8329,54);
INSERT INTO "django_geo_db_city" VALUES(6815,'Woodberry Forest','Woodberry Forest, Virginia',8330,54);
INSERT INTO "django_geo_db_city" VALUES(6816,'Achilles','Achilles, Virginia',8331,54);
INSERT INTO "django_geo_db_city" VALUES(6817,'Amelia Court House','Amelia Court House, Virginia',8332,54);
INSERT INTO "django_geo_db_city" VALUES(6818,'Ark','Ark, Virginia',8333,54);
INSERT INTO "django_geo_db_city" VALUES(6819,'Arvonia','Arvonia, Virginia',8334,54);
INSERT INTO "django_geo_db_city" VALUES(6820,'Ashland','Ashland, Virginia',8335,54);
INSERT INTO "django_geo_db_city" VALUES(6821,'Aylett','Aylett, Virginia',8336,54);
INSERT INTO "django_geo_db_city" VALUES(6822,'Barhamsville','Barhamsville, Virginia',8337,54);
INSERT INTO "django_geo_db_city" VALUES(6823,'Beaumont','Beaumont, Virginia',8338,54);
INSERT INTO "django_geo_db_city" VALUES(6824,'Beaverdam','Beaverdam, Virginia',8339,54);
INSERT INTO "django_geo_db_city" VALUES(6825,'Bellamy','Bellamy, Virginia',8340,54);
INSERT INTO "django_geo_db_city" VALUES(6826,'Bena','Bena, Virginia',8340,54);
INSERT INTO "django_geo_db_city" VALUES(6827,'Bohannon','Bohannon, Virginia',8341,54);
INSERT INTO "django_geo_db_city" VALUES(6828,'Bremo Bluff','Bremo Bluff, Virginia',8342,54);
INSERT INTO "django_geo_db_city" VALUES(6829,'Bruington','Bruington, Virginia',8343,54);
INSERT INTO "django_geo_db_city" VALUES(6830,'Bumpass','Bumpass, Virginia',8344,54);
INSERT INTO "django_geo_db_city" VALUES(6831,'Cardinal','Cardinal, Virginia',8345,54);
INSERT INTO "django_geo_db_city" VALUES(6832,'Cartersville','Cartersville, Virginia',8346,54);
INSERT INTO "django_geo_db_city" VALUES(6833,'Charles City','Charles City, Virginia',8347,54);
INSERT INTO "django_geo_db_city" VALUES(6834,'Christchurch','Christchurch, Virginia',8348,54);
INSERT INTO "django_geo_db_city" VALUES(6835,'Church View','Church View, Virginia',8349,54);
INSERT INTO "django_geo_db_city" VALUES(6836,'Cobbs Creek','Cobbs Creek, Virginia',8350,54);
INSERT INTO "django_geo_db_city" VALUES(6837,'Columbia','Columbia, Virginia',8351,54);
INSERT INTO "django_geo_db_city" VALUES(6838,'Crozier','Crozier, Virginia',8352,54);
INSERT INTO "django_geo_db_city" VALUES(6839,'Cumberland','Cumberland, Virginia',8353,54);
INSERT INTO "django_geo_db_city" VALUES(6840,'Deltaville','Deltaville, Virginia',8354,54);
INSERT INTO "django_geo_db_city" VALUES(6841,'Diggs','Diggs, Virginia',8355,54);
INSERT INTO "django_geo_db_city" VALUES(6842,'Doswell','Doswell, Virginia',8356,54);
INSERT INTO "django_geo_db_city" VALUES(6843,'Dutton','Dutton, Virginia',8357,54);
INSERT INTO "django_geo_db_city" VALUES(6844,'Fife','Fife, Virginia',8338,54);
INSERT INTO "django_geo_db_city" VALUES(6845,'Fork Union','Fork Union, Virginia',8358,54);
INSERT INTO "django_geo_db_city" VALUES(6846,'Foster','Foster, Virginia',8359,54);
INSERT INTO "django_geo_db_city" VALUES(6847,'Glen Allen','Glen Allen, Virginia',8360,54);
INSERT INTO "django_geo_db_city" VALUES(6848,'Gloucester','Gloucester, Virginia',8363,54);
INSERT INTO "django_geo_db_city" VALUES(6849,'Gloucester Point','Gloucester Point, Virginia',8364,54);
INSERT INTO "django_geo_db_city" VALUES(6850,'Goochland','Goochland, Virginia',8365,54);
INSERT INTO "django_geo_db_city" VALUES(6851,'Grimstead','Grimstead, Virginia',8366,54);
INSERT INTO "django_geo_db_city" VALUES(6852,'Gum Spring','Gum Spring, Virginia',8367,54);
INSERT INTO "django_geo_db_city" VALUES(6853,'Gwynn','Gwynn, Virginia',8368,54);
INSERT INTO "django_geo_db_city" VALUES(6854,'Hadensville','Hadensville, Virginia',8369,54);
INSERT INTO "django_geo_db_city" VALUES(6855,'Hallieford','Hallieford, Virginia',8370,54);
INSERT INTO "django_geo_db_city" VALUES(6856,'Hanover','Hanover, Virginia',8371,54);
INSERT INTO "django_geo_db_city" VALUES(6857,'Hardyville','Hardyville, Virginia',8372,54);
INSERT INTO "django_geo_db_city" VALUES(6858,'Hartfield','Hartfield, Virginia',8373,54);
INSERT INTO "django_geo_db_city" VALUES(6859,'Hayes','Hayes, Virginia',8374,54);
INSERT INTO "django_geo_db_city" VALUES(6860,'Highland Springs','Highland Springs, Virginia',8375,54);
INSERT INTO "django_geo_db_city" VALUES(6861,'Hudgins','Hudgins, Virginia',8376,54);
INSERT INTO "django_geo_db_city" VALUES(6862,'Jamaica','Jamaica, Virginia',8377,54);
INSERT INTO "django_geo_db_city" VALUES(6863,'Jamestown','Jamestown, Virginia',8378,54);
INSERT INTO "django_geo_db_city" VALUES(6864,'Jetersville','Jetersville, Virginia',8379,54);
INSERT INTO "django_geo_db_city" VALUES(6865,'Kents Store','Kents Store, Virginia',8380,54);
INSERT INTO "django_geo_db_city" VALUES(6866,'King And Queen Court Hous','King And Queen Court Hous, Virginia',8381,54);
INSERT INTO "django_geo_db_city" VALUES(6867,'King William','King William, Virginia',8382,54);
INSERT INTO "django_geo_db_city" VALUES(6868,'Lanexa','Lanexa, Virginia',8383,54);
INSERT INTO "django_geo_db_city" VALUES(6869,'Lightfoot','Lightfoot, Virginia',8384,54);
INSERT INTO "django_geo_db_city" VALUES(6870,'Little Plymouth','Little Plymouth, Virginia',8385,54);
INSERT INTO "django_geo_db_city" VALUES(6871,'Locust Hill','Locust Hill, Virginia',8386,54);
INSERT INTO "django_geo_db_city" VALUES(6872,'Louisa','Louisa, Virginia',8387,54);
INSERT INTO "django_geo_db_city" VALUES(6873,'Macon','Macon, Virginia',8388,54);
INSERT INTO "django_geo_db_city" VALUES(6874,'Maidens','Maidens, Virginia',8389,54);
INSERT INTO "django_geo_db_city" VALUES(6875,'Manakin Sabot','Manakin Sabot, Virginia',8390,54);
INSERT INTO "django_geo_db_city" VALUES(6876,'Mannboro','Mannboro, Virginia',8392,54);
INSERT INTO "django_geo_db_city" VALUES(6877,'Manquin','Manquin, Virginia',8393,54);
INSERT INTO "django_geo_db_city" VALUES(6878,'Maryus','Maryus, Virginia',8394,54);
INSERT INTO "django_geo_db_city" VALUES(6879,'Mascot','Mascot, Virginia',8395,54);
INSERT INTO "django_geo_db_city" VALUES(6880,'Mathews','Mathews, Virginia',8396,54);
INSERT INTO "django_geo_db_city" VALUES(6881,'Mattaponi','Mattaponi, Virginia',8397,54);
INSERT INTO "django_geo_db_city" VALUES(6882,'Mechanicsville','Mechanicsville, Virginia',8398,54);
INSERT INTO "django_geo_db_city" VALUES(6883,'Midlothian','Midlothian, Virginia',8399,54);
INSERT INTO "django_geo_db_city" VALUES(6884,'Millers Tavern','Millers Tavern, Virginia',8401,54);
INSERT INTO "django_geo_db_city" VALUES(6885,'Mineral','Mineral, Virginia',8403,54);
INSERT INTO "django_geo_db_city" VALUES(6886,'Moon','Moon, Virginia',8404,54);
INSERT INTO "django_geo_db_city" VALUES(6887,'Moseley','Moseley, Virginia',8405,54);
INSERT INTO "django_geo_db_city" VALUES(6888,'New Canton','New Canton, Virginia',8406,54);
INSERT INTO "django_geo_db_city" VALUES(6889,'New Kent','New Kent, Virginia',8407,54);
INSERT INTO "django_geo_db_city" VALUES(6890,'New Point','New Point, Virginia',8408,54);
INSERT INTO "django_geo_db_city" VALUES(6891,'Newtown','Newtown, Virginia',8409,54);
INSERT INTO "django_geo_db_city" VALUES(6892,'Norge','Norge, Virginia',8410,54);
INSERT INTO "django_geo_db_city" VALUES(6893,'North','North, Virginia',8411,54);
INSERT INTO "django_geo_db_city" VALUES(6894,'Oilville','Oilville, Virginia',8412,54);
INSERT INTO "django_geo_db_city" VALUES(6895,'Onemo','Onemo, Virginia',8413,54);
INSERT INTO "django_geo_db_city" VALUES(6896,'Ordinary','Ordinary, Virginia',8414,54);
INSERT INTO "django_geo_db_city" VALUES(6897,'Port Haywood','Port Haywood, Virginia',8415,54);
INSERT INTO "django_geo_db_city" VALUES(6898,'Powhatan','Powhatan, Virginia',8416,54);
INSERT INTO "django_geo_db_city" VALUES(6899,'Providence Forge','Providence Forge, Virginia',8417,54);
INSERT INTO "django_geo_db_city" VALUES(6900,'Quinton','Quinton, Virginia',8418,54);
INSERT INTO "django_geo_db_city" VALUES(6901,'Rockville','Rockville, Virginia',8419,54);
INSERT INTO "django_geo_db_city" VALUES(6902,'Ruthville','Ruthville, Virginia',8420,54);
INSERT INTO "django_geo_db_city" VALUES(6903,'Saint Stephens Church','Saint Stephens Church, Virginia',8421,54);
INSERT INTO "django_geo_db_city" VALUES(6904,'Saluda','Saluda, Virginia',8422,54);
INSERT INTO "django_geo_db_city" VALUES(6905,'Sandston','Sandston, Virginia',8423,54);
INSERT INTO "django_geo_db_city" VALUES(6906,'Sandy Hook','Sandy Hook, Virginia',8424,54);
INSERT INTO "django_geo_db_city" VALUES(6907,'Schley','Schley, Virginia',8340,54);
INSERT INTO "django_geo_db_city" VALUES(6908,'Severn','Severn, Virginia',8340,54);
INSERT INTO "django_geo_db_city" VALUES(6909,'Shacklefords','Shacklefords, Virginia',8425,54);
INSERT INTO "django_geo_db_city" VALUES(6910,'State Farm','State Farm, Virginia',8338,54);
INSERT INTO "django_geo_db_city" VALUES(6911,'Stevensville','Stevensville, Virginia',8426,54);
INSERT INTO "django_geo_db_city" VALUES(6912,'Studley','Studley, Virginia',8427,54);
INSERT INTO "django_geo_db_city" VALUES(6913,'Susan','Susan, Virginia',8428,54);
INSERT INTO "django_geo_db_city" VALUES(6914,'Toano','Toano, Virginia',8429,54);
INSERT INTO "django_geo_db_city" VALUES(6915,'Topping','Topping, Virginia',8430,54);
INSERT INTO "django_geo_db_city" VALUES(6916,'Trevilians','Trevilians, Virginia',8431,54);
INSERT INTO "django_geo_db_city" VALUES(6917,'University Of Richmond','University Of Richmond, Virginia',8432,54);
INSERT INTO "django_geo_db_city" VALUES(6918,'Urbanna','Urbanna, Virginia',8433,54);
INSERT INTO "django_geo_db_city" VALUES(6919,'Wake','Wake, Virginia',8434,54);
INSERT INTO "django_geo_db_city" VALUES(6920,'Walkerton','Walkerton, Virginia',8435,54);
INSERT INTO "django_geo_db_city" VALUES(6921,'Ware Neck','Ware Neck, Virginia',8436,54);
INSERT INTO "django_geo_db_city" VALUES(6922,'Water View','Water View, Virginia',8437,54);
INSERT INTO "django_geo_db_city" VALUES(6923,'West Point','West Point, Virginia',8438,54);
INSERT INTO "django_geo_db_city" VALUES(6924,'White Marsh','White Marsh, Virginia',8439,54);
INSERT INTO "django_geo_db_city" VALUES(6925,'Wicomico','Wicomico, Virginia',8440,54);
INSERT INTO "django_geo_db_city" VALUES(6926,'Williamsburg','Williamsburg, Virginia',8441,54);
INSERT INTO "django_geo_db_city" VALUES(6927,'Woods Cross Roads','Woods Cross Roads, Virginia',8444,54);
INSERT INTO "django_geo_db_city" VALUES(6928,'Zanoni','Zanoni, Virginia',8340,54);
INSERT INTO "django_geo_db_city" VALUES(6929,'Montpelier','Montpelier, Virginia',8445,54);
INSERT INTO "django_geo_db_city" VALUES(6930,'Richmond','Richmond, Virginia',8446,54);
INSERT INTO "django_geo_db_city" VALUES(6931,'Accomac','Accomac, Virginia',8473,54);
INSERT INTO "django_geo_db_city" VALUES(6932,'Assawoman','Assawoman, Virginia',8474,54);
INSERT INTO "django_geo_db_city" VALUES(6933,'Atlantic','Atlantic, Virginia',8475,54);
INSERT INTO "django_geo_db_city" VALUES(6934,'Battery Park','Battery Park, Virginia',8476,54);
INSERT INTO "django_geo_db_city" VALUES(6935,'Belle Haven','Belle Haven, Virginia',8477,54);
INSERT INTO "django_geo_db_city" VALUES(6936,'Birdsnest','Birdsnest, Virginia',8478,54);
INSERT INTO "django_geo_db_city" VALUES(6937,'Bloxom','Bloxom, Virginia',8479,54);
INSERT INTO "django_geo_db_city" VALUES(6938,'Cape Charles','Cape Charles, Virginia',8480,54);
INSERT INTO "django_geo_db_city" VALUES(6939,'Capeville','Capeville, Virginia',8481,54);
INSERT INTO "django_geo_db_city" VALUES(6940,'Carrollton','Carrollton, Virginia',8482,54);
INSERT INTO "django_geo_db_city" VALUES(6941,'Carrsville','Carrsville, Virginia',8483,54);
INSERT INTO "django_geo_db_city" VALUES(6942,'Cheriton','Cheriton, Virginia',8484,54);
INSERT INTO "django_geo_db_city" VALUES(6943,'Chesapeake','Chesapeake, Virginia',8485,54);
INSERT INTO "django_geo_db_city" VALUES(6944,'Chincoteague Island','Chincoteague Island, Virginia',8493,54);
INSERT INTO "django_geo_db_city" VALUES(6945,'Wallops Island','Wallops Island, Virginia',8494,54);
INSERT INTO "django_geo_db_city" VALUES(6946,'Craddockville','Craddockville, Virginia',8495,54);
INSERT INTO "django_geo_db_city" VALUES(6947,'Davis Wharf','Davis Wharf, Virginia',8496,54);
INSERT INTO "django_geo_db_city" VALUES(6948,'Eastville','Eastville, Virginia',8497,54);
INSERT INTO "django_geo_db_city" VALUES(6949,'Exmore','Exmore, Virginia',8498,54);
INSERT INTO "django_geo_db_city" VALUES(6950,'Franktown','Franktown, Virginia',8500,54);
INSERT INTO "django_geo_db_city" VALUES(6951,'Greenbackville','Greenbackville, Virginia',8501,54);
INSERT INTO "django_geo_db_city" VALUES(6952,'Greenbush','Greenbush, Virginia',8502,54);
INSERT INTO "django_geo_db_city" VALUES(6953,'Hacksneck','Hacksneck, Virginia',8503,54);
INSERT INTO "django_geo_db_city" VALUES(6954,'Hallwood','Hallwood, Virginia',8504,54);
INSERT INTO "django_geo_db_city" VALUES(6955,'Harborton','Harborton, Virginia',8506,54);
INSERT INTO "django_geo_db_city" VALUES(6956,'Horntown','Horntown, Virginia',8507,54);
INSERT INTO "django_geo_db_city" VALUES(6957,'Oak Hall','Oak Hall, Virginia',8508,54);
INSERT INTO "django_geo_db_city" VALUES(6958,'Isle Of Wight','Isle Of Wight, Virginia',8509,54);
INSERT INTO "django_geo_db_city" VALUES(6959,'Jamesville','Jamesville, Virginia',8510,54);
INSERT INTO "django_geo_db_city" VALUES(6960,'Jenkins Bridge','Jenkins Bridge, Virginia',8511,54);
INSERT INTO "django_geo_db_city" VALUES(6961,'Keller','Keller, Virginia',8512,54);
INSERT INTO "django_geo_db_city" VALUES(6962,'Locustville','Locustville, Virginia',8513,54);
INSERT INTO "django_geo_db_city" VALUES(6963,'Machipongo','Machipongo, Virginia',8514,54);
INSERT INTO "django_geo_db_city" VALUES(6964,'Mappsville','Mappsville, Virginia',8515,54);
INSERT INTO "django_geo_db_city" VALUES(6965,'Marionville','Marionville, Virginia',8516,54);
INSERT INTO "django_geo_db_city" VALUES(6966,'Mears','Mears, Virginia',8517,54);
INSERT INTO "django_geo_db_city" VALUES(6967,'Melfa','Melfa, Virginia',8518,54);
INSERT INTO "django_geo_db_city" VALUES(6968,'Modest Town','Modest Town, Virginia',8519,54);
INSERT INTO "django_geo_db_city" VALUES(6969,'Nassawadox','Nassawadox, Virginia',8520,54);
INSERT INTO "django_geo_db_city" VALUES(6970,'Nelsonia','Nelsonia, Virginia',8521,54);
INSERT INTO "django_geo_db_city" VALUES(6971,'New Church','New Church, Virginia',8522,54);
INSERT INTO "django_geo_db_city" VALUES(6972,'Onancock','Onancock, Virginia',8524,54);
INSERT INTO "django_geo_db_city" VALUES(6973,'Onley','Onley, Virginia',8525,54);
INSERT INTO "django_geo_db_city" VALUES(6974,'Oyster','Oyster, Virginia',8526,54);
INSERT INTO "django_geo_db_city" VALUES(6975,'Painter','Painter, Virginia',8527,54);
INSERT INTO "django_geo_db_city" VALUES(6976,'Parksley','Parksley, Virginia',8528,54);
INSERT INTO "django_geo_db_city" VALUES(6977,'Pungoteague','Pungoteague, Virginia',8529,54);
INSERT INTO "django_geo_db_city" VALUES(6978,'Quinby','Quinby, Virginia',8530,54);
INSERT INTO "django_geo_db_city" VALUES(6979,'Rescue','Rescue, Virginia',8531,54);
INSERT INTO "django_geo_db_city" VALUES(6980,'Sanford','Sanford, Virginia',8532,54);
INSERT INTO "django_geo_db_city" VALUES(6981,'Saxis','Saxis, Virginia',8533,54);
INSERT INTO "django_geo_db_city" VALUES(6982,'Seaview','Seaview, Virginia',8534,54);
INSERT INTO "django_geo_db_city" VALUES(6983,'Smithfield','Smithfield, Virginia',8535,54);
INSERT INTO "django_geo_db_city" VALUES(6984,'Suffolk','Suffolk, Virginia',8536,54);
INSERT INTO "django_geo_db_city" VALUES(6985,'Tangier','Tangier, Virginia',8544,54);
INSERT INTO "django_geo_db_city" VALUES(6986,'Tasley','Tasley, Virginia',8545,54);
INSERT INTO "django_geo_db_city" VALUES(6987,'Temperanceville','Temperanceville, Virginia',8546,54);
INSERT INTO "django_geo_db_city" VALUES(6988,'Townsend','Townsend, Virginia',8547,54);
INSERT INTO "django_geo_db_city" VALUES(6989,'Virginia Beach','Virginia Beach, Virginia',8548,54);
INSERT INTO "django_geo_db_city" VALUES(6990,'Wachapreague','Wachapreague, Virginia',8566,54);
INSERT INTO "django_geo_db_city" VALUES(6991,'Wardtown','Wardtown, Virginia',8567,54);
INSERT INTO "django_geo_db_city" VALUES(6992,'Wattsville','Wattsville, Virginia',8568,54);
INSERT INTO "django_geo_db_city" VALUES(6993,'Willis Wharf','Willis Wharf, Virginia',8569,54);
INSERT INTO "django_geo_db_city" VALUES(6994,'Windsor','Windsor, Virginia',8570,54);
INSERT INTO "django_geo_db_city" VALUES(6995,'Withams','Withams, Virginia',8571,54);
INSERT INTO "django_geo_db_city" VALUES(6996,'Norfolk','Norfolk, Virginia',8572,54);
INSERT INTO "django_geo_db_city" VALUES(6997,'Fort Eustis','Fort Eustis, Virginia',8591,54);
INSERT INTO "django_geo_db_city" VALUES(6998,'Franklin','Franklin, Virginia',8597,54);
INSERT INTO "django_geo_db_city" VALUES(6999,'Hampton','Hampton, Virginia',8598,54);
INSERT INTO "django_geo_db_city" VALUES(7000,'Fort Monroe','Fort Monroe, Virginia',8600,54);
INSERT INTO "django_geo_db_city" VALUES(7001,'Poquoson','Poquoson, Virginia',8602,54);
INSERT INTO "django_geo_db_city" VALUES(7002,'Yorktown','Yorktown, Virginia',8610,54);
INSERT INTO "django_geo_db_city" VALUES(7003,'Lackey','Lackey, Virginia',8614,54);
INSERT INTO "django_geo_db_city" VALUES(7004,'Seaford','Seaford, Virginia',8615,54);
INSERT INTO "django_geo_db_city" VALUES(7005,'Portsmouth','Portsmouth, Virginia',8616,54);
INSERT INTO "django_geo_db_city" VALUES(7006,'Fort Lee','Fort Lee, Virginia',8623,54);
INSERT INTO "django_geo_db_city" VALUES(7007,'Petersburg','Petersburg, Virginia',8624,54);
INSERT INTO "django_geo_db_city" VALUES(7008,'Alberta','Alberta, Virginia',8629,54);
INSERT INTO "django_geo_db_city" VALUES(7009,'Ammon','Ammon, Virginia',8630,54);
INSERT INTO "django_geo_db_city" VALUES(7010,'Blackstone','Blackstone, Virginia',8631,54);
INSERT INTO "django_geo_db_city" VALUES(7011,'Boykins','Boykins, Virginia',8632,54);
INSERT INTO "django_geo_db_city" VALUES(7012,'Branchville','Branchville, Virginia',8633,54);
INSERT INTO "django_geo_db_city" VALUES(7013,'Capron','Capron, Virginia',8634,54);
INSERT INTO "django_geo_db_city" VALUES(7014,'Carson','Carson, Virginia',8635,54);
INSERT INTO "django_geo_db_city" VALUES(7015,'Chester','Chester, Virginia',8636,54);
INSERT INTO "django_geo_db_city" VALUES(7016,'Chesterfield','Chesterfield, Virginia',8637,54);
INSERT INTO "django_geo_db_city" VALUES(7017,'Church Road','Church Road, Virginia',8638,54);
INSERT INTO "django_geo_db_city" VALUES(7018,'Colonial Heights','Colonial Heights, Virginia',8639,54);
INSERT INTO "django_geo_db_city" VALUES(7019,'Courtland','Courtland, Virginia',8641,54);
INSERT INTO "django_geo_db_city" VALUES(7020,'Dendron','Dendron, Virginia',8643,54);
INSERT INTO "django_geo_db_city" VALUES(7021,'Dewitt','Dewitt, Virginia',8644,54);
INSERT INTO "django_geo_db_city" VALUES(7022,'Dinwiddie','Dinwiddie, Virginia',8645,54);
INSERT INTO "django_geo_db_city" VALUES(7023,'Disputanta','Disputanta, Virginia',8646,54);
INSERT INTO "django_geo_db_city" VALUES(7024,'Dolphin','Dolphin, Virginia',8647,54);
INSERT INTO "django_geo_db_city" VALUES(7025,'Drewryville','Drewryville, Virginia',8648,54);
INSERT INTO "django_geo_db_city" VALUES(7026,'Ebony','Ebony, Virginia',8649,54);
INSERT INTO "django_geo_db_city" VALUES(7027,'Elberon','Elberon, Virginia',8650,54);
INSERT INTO "django_geo_db_city" VALUES(7028,'Emporia','Emporia, Virginia',8651,54);
INSERT INTO "django_geo_db_city" VALUES(7029,'Ford','Ford, Virginia',8652,54);
INSERT INTO "django_geo_db_city" VALUES(7030,'Freeman','Freeman, Virginia',8654,54);
INSERT INTO "django_geo_db_city" VALUES(7031,'Gasburg','Gasburg, Virginia',8655,54);
INSERT INTO "django_geo_db_city" VALUES(7032,'Hopewell','Hopewell, Virginia',8656,54);
INSERT INTO "django_geo_db_city" VALUES(7033,'Ivor','Ivor, Virginia',8657,54);
INSERT INTO "django_geo_db_city" VALUES(7034,'Jarratt','Jarratt, Virginia',8658,54);
INSERT INTO "django_geo_db_city" VALUES(7035,'Lawrenceville','Lawrenceville, Virginia',8659,54);
INSERT INTO "django_geo_db_city" VALUES(7036,'McKenney','McKenney, Virginia',8661,54);
INSERT INTO "django_geo_db_city" VALUES(7037,'Meredithville','Meredithville, Virginia',8662,54);
INSERT INTO "django_geo_db_city" VALUES(7038,'Newsoms','Newsoms, Virginia',8663,54);
INSERT INTO "django_geo_db_city" VALUES(7039,'Prince George','Prince George, Virginia',8664,54);
INSERT INTO "django_geo_db_city" VALUES(7040,'Rawlings','Rawlings, Virginia',8665,54);
INSERT INTO "django_geo_db_city" VALUES(7041,'Sedley','Sedley, Virginia',8666,54);
INSERT INTO "django_geo_db_city" VALUES(7042,'Skippers','Skippers, Virginia',8667,54);
INSERT INTO "django_geo_db_city" VALUES(7043,'Spring Grove','Spring Grove, Virginia',8668,54);
INSERT INTO "django_geo_db_city" VALUES(7044,'Stony Creek','Stony Creek, Virginia',8669,54);
INSERT INTO "django_geo_db_city" VALUES(7045,'Surry','Surry, Virginia',8670,54);
INSERT INTO "django_geo_db_city" VALUES(7046,'Sussex','Sussex, Virginia',8671,54);
INSERT INTO "django_geo_db_city" VALUES(7047,'Sutherland','Sutherland, Virginia',8672,54);
INSERT INTO "django_geo_db_city" VALUES(7048,'Valentines','Valentines, Virginia',8673,54);
INSERT INTO "django_geo_db_city" VALUES(7049,'Wakefield','Wakefield, Virginia',8674,54);
INSERT INTO "django_geo_db_city" VALUES(7050,'Warfield','Warfield, Virginia',8675,54);
INSERT INTO "django_geo_db_city" VALUES(7051,'Waverly','Waverly, Virginia',8676,54);
INSERT INTO "django_geo_db_city" VALUES(7052,'White Plains','White Plains, Virginia',8678,54);
INSERT INTO "django_geo_db_city" VALUES(7053,'Wilsons','Wilsons, Virginia',8679,54);
INSERT INTO "django_geo_db_city" VALUES(7054,'Yale','Yale, Virginia',8680,54);
INSERT INTO "django_geo_db_city" VALUES(7055,'Zuni','Zuni, Virginia',8681,54);
INSERT INTO "django_geo_db_city" VALUES(7056,'Claremont','Claremont, Virginia',8682,54);
INSERT INTO "django_geo_db_city" VALUES(7057,'Farmville','Farmville, Virginia',8683,54);
INSERT INTO "django_geo_db_city" VALUES(7058,'Baskerville','Baskerville, Virginia',8685,54);
INSERT INTO "django_geo_db_city" VALUES(7059,'Boydton','Boydton, Virginia',8686,54);
INSERT INTO "django_geo_db_city" VALUES(7060,'Bracey','Bracey, Virginia',8687,54);
INSERT INTO "django_geo_db_city" VALUES(7061,'Brodnax','Brodnax, Virginia',8688,54);
INSERT INTO "django_geo_db_city" VALUES(7062,'Buckingham','Buckingham, Virginia',8689,54);
INSERT INTO "django_geo_db_city" VALUES(7063,'Burkeville','Burkeville, Virginia',8690,54);
INSERT INTO "django_geo_db_city" VALUES(7064,'Charlotte Court House','Charlotte Court House, Virginia',8691,54);
INSERT INTO "django_geo_db_city" VALUES(7065,'Chase City','Chase City, Virginia',8692,54);
INSERT INTO "django_geo_db_city" VALUES(7066,'Clarksville','Clarksville, Virginia',8693,54);
INSERT INTO "django_geo_db_city" VALUES(7067,'Crewe','Crewe, Virginia',8694,54);
INSERT INTO "django_geo_db_city" VALUES(7068,'Cullen','Cullen, Virginia',8695,54);
INSERT INTO "django_geo_db_city" VALUES(7069,'Dillwyn','Dillwyn, Virginia',8696,54);
INSERT INTO "django_geo_db_city" VALUES(7070,'Drakes Branch','Drakes Branch, Virginia',8697,54);
INSERT INTO "django_geo_db_city" VALUES(7071,'Dundas','Dundas, Virginia',8698,54);
INSERT INTO "django_geo_db_city" VALUES(7072,'Evergreen','Evergreen, Virginia',8699,54);
INSERT INTO "django_geo_db_city" VALUES(7073,'Fort Mitchell','Fort Mitchell, Virginia',8700,54);
INSERT INTO "django_geo_db_city" VALUES(7074,'Green Bay','Green Bay, Virginia',8701,54);
INSERT INTO "django_geo_db_city" VALUES(7075,'Hampden Sydney','Hampden Sydney, Virginia',8702,54);
INSERT INTO "django_geo_db_city" VALUES(7076,'Kenbridge','Kenbridge, Virginia',8703,54);
INSERT INTO "django_geo_db_city" VALUES(7077,'Keysville','Keysville, Virginia',8704,54);
INSERT INTO "django_geo_db_city" VALUES(7078,'La Crosse','La Crosse, Virginia',8705,54);
INSERT INTO "django_geo_db_city" VALUES(7079,'Lunenburg','Lunenburg, Virginia',8706,54);
INSERT INTO "django_geo_db_city" VALUES(7080,'Meherrin','Meherrin, Virginia',8707,54);
INSERT INTO "django_geo_db_city" VALUES(7081,'Nottoway','Nottoway, Virginia',8708,54);
INSERT INTO "django_geo_db_city" VALUES(7082,'Pamplin','Pamplin, Virginia',8709,54);
INSERT INTO "django_geo_db_city" VALUES(7083,'Phenix','Phenix, Virginia',8710,54);
INSERT INTO "django_geo_db_city" VALUES(7084,'Prospect','Prospect, Virginia',8711,54);
INSERT INTO "django_geo_db_city" VALUES(7085,'Randolph','Randolph, Virginia',8712,54);
INSERT INTO "django_geo_db_city" VALUES(7086,'Red House','Red House, Virginia',8713,54);
INSERT INTO "django_geo_db_city" VALUES(7087,'Red Oak','Red Oak, Virginia',8714,54);
INSERT INTO "django_geo_db_city" VALUES(7088,'Rice','Rice, Virginia',8715,54);
INSERT INTO "django_geo_db_city" VALUES(7089,'Saxe','Saxe, Virginia',8716,54);
INSERT INTO "django_geo_db_city" VALUES(7090,'Skipwith','Skipwith, Virginia',8717,54);
INSERT INTO "django_geo_db_city" VALUES(7091,'South Hill','South Hill, Virginia',8718,54);
INSERT INTO "django_geo_db_city" VALUES(7092,'Victoria','Victoria, Virginia',8719,54);
INSERT INTO "django_geo_db_city" VALUES(7093,'Wylliesburg','Wylliesburg, Virginia',8720,54);
INSERT INTO "django_geo_db_city" VALUES(7094,'Roanoke','Roanoke, Virginia',8722,54);
INSERT INTO "django_geo_db_city" VALUES(7095,'Ararat','Ararat, Virginia',8739,54);
INSERT INTO "django_geo_db_city" VALUES(7096,'Axton','Axton, Virginia',8740,54);
INSERT INTO "django_geo_db_city" VALUES(7097,'Bassett','Bassett, Virginia',8741,54);
INSERT INTO "django_geo_db_city" VALUES(7098,'Belspring','Belspring, Virginia',8742,54);
INSERT INTO "django_geo_db_city" VALUES(7099,'Bent Mountain','Bent Mountain, Virginia',8743,54);
INSERT INTO "django_geo_db_city" VALUES(7100,'Blacksburg','Blacksburg, Virginia',8744,54);
INSERT INTO "django_geo_db_city" VALUES(7101,'Blue Ridge','Blue Ridge, Virginia',8747,54);
INSERT INTO "django_geo_db_city" VALUES(7102,'Boones Mill','Boones Mill, Virginia',8748,54);
INSERT INTO "django_geo_db_city" VALUES(7103,'Buchanan','Buchanan, Virginia',8749,54);
INSERT INTO "django_geo_db_city" VALUES(7104,'Callaway','Callaway, Virginia',8750,54);
INSERT INTO "django_geo_db_city" VALUES(7105,'Christiansburg','Christiansburg, Virginia',8751,54);
INSERT INTO "django_geo_db_city" VALUES(7106,'Cascade','Cascade, Virginia',8752,54);
INSERT INTO "django_geo_db_city" VALUES(7107,'Catawba','Catawba, Virginia',8753,54);
INSERT INTO "django_geo_db_city" VALUES(7108,'Check','Check, Virginia',8754,54);
INSERT INTO "django_geo_db_city" VALUES(7109,'Claudville','Claudville, Virginia',8756,54);
INSERT INTO "django_geo_db_city" VALUES(7110,'Cloverdale','Cloverdale, Virginia',8757,54);
INSERT INTO "django_geo_db_city" VALUES(7111,'Collinsville','Collinsville, Virginia',8758,54);
INSERT INTO "django_geo_db_city" VALUES(7112,'Copper Hill','Copper Hill, Virginia',8759,54);
INSERT INTO "django_geo_db_city" VALUES(7113,'Critz','Critz, Virginia',8760,54);
INSERT INTO "django_geo_db_city" VALUES(7114,'Daleville','Daleville, Virginia',8761,54);
INSERT INTO "django_geo_db_city" VALUES(7115,'Dublin','Dublin, Virginia',8762,54);
INSERT INTO "django_geo_db_city" VALUES(7116,'Eagle Rock','Eagle Rock, Virginia',8763,54);
INSERT INTO "django_geo_db_city" VALUES(7117,'Eggleston','Eggleston, Virginia',8764,54);
INSERT INTO "django_geo_db_city" VALUES(7118,'Elliston','Elliston, Virginia',8765,54);
INSERT INTO "django_geo_db_city" VALUES(7119,'Ferrum','Ferrum, Virginia',8766,54);
INSERT INTO "django_geo_db_city" VALUES(7120,'Fieldale','Fieldale, Virginia',8767,54);
INSERT INTO "django_geo_db_city" VALUES(7121,'Fincastle','Fincastle, Virginia',8768,54);
INSERT INTO "django_geo_db_city" VALUES(7122,'Floyd','Floyd, Virginia',8769,54);
INSERT INTO "django_geo_db_city" VALUES(7123,'Glade Hill','Glade Hill, Virginia',8770,54);
INSERT INTO "django_geo_db_city" VALUES(7124,'Glen Lyn','Glen Lyn, Virginia',8771,54);
INSERT INTO "django_geo_db_city" VALUES(7125,'Goldbond','Goldbond, Virginia',8772,54);
INSERT INTO "django_geo_db_city" VALUES(7126,'Goodview','Goodview, Virginia',8773,54);
INSERT INTO "django_geo_db_city" VALUES(7127,'Hardy','Hardy, Virginia',8774,54);
INSERT INTO "django_geo_db_city" VALUES(7128,'Henry','Henry, Virginia',8775,54);
INSERT INTO "django_geo_db_city" VALUES(7129,'Huddleston','Huddleston, Virginia',8776,54);
INSERT INTO "django_geo_db_city" VALUES(7130,'Indian Valley','Indian Valley, Virginia',8777,54);
INSERT INTO "django_geo_db_city" VALUES(7131,'McCoy','McCoy, Virginia',8746,54);
INSERT INTO "django_geo_db_city" VALUES(7132,'Martinsville','Martinsville, Virginia',8778,54);
INSERT INTO "django_geo_db_city" VALUES(7133,'Meadows Of Dan','Meadows Of Dan, Virginia',8780,54);
INSERT INTO "django_geo_db_city" VALUES(7134,'Moneta','Moneta, Virginia',8781,54);
INSERT INTO "django_geo_db_city" VALUES(7135,'Montvale','Montvale, Virginia',8782,54);
INSERT INTO "django_geo_db_city" VALUES(7136,'Narrows','Narrows, Virginia',8783,54);
INSERT INTO "django_geo_db_city" VALUES(7137,'Newbern','Newbern, Virginia',8784,54);
INSERT INTO "django_geo_db_city" VALUES(7138,'New Castle','New Castle, Virginia',8785,54);
INSERT INTO "django_geo_db_city" VALUES(7139,'Newport','Newport, Virginia',8786,54);
INSERT INTO "django_geo_db_city" VALUES(7140,'New River','New River, Virginia',8787,54);
INSERT INTO "django_geo_db_city" VALUES(7141,'Oriskany','Oriskany, Virginia',8738,54);
INSERT INTO "django_geo_db_city" VALUES(7142,'Paint Bank','Paint Bank, Virginia',8788,54);
INSERT INTO "django_geo_db_city" VALUES(7143,'Parrott','Parrott, Virginia',8789,54);
INSERT INTO "django_geo_db_city" VALUES(7144,'Patrick Springs','Patrick Springs, Virginia',8790,54);
INSERT INTO "django_geo_db_city" VALUES(7145,'Pearisburg','Pearisburg, Virginia',8791,54);
INSERT INTO "django_geo_db_city" VALUES(7146,'Pembroke','Pembroke, Virginia',8792,54);
INSERT INTO "django_geo_db_city" VALUES(7147,'Penhook','Penhook, Virginia',8793,54);
INSERT INTO "django_geo_db_city" VALUES(7148,'Pilot','Pilot, Virginia',8794,54);
INSERT INTO "django_geo_db_city" VALUES(7149,'Pittsville','Pittsville, Virginia',8795,54);
INSERT INTO "django_geo_db_city" VALUES(7150,'Radford','Radford, Virginia',8796,54);
INSERT INTO "django_geo_db_city" VALUES(7151,'Redwood','Redwood, Virginia',8799,54);
INSERT INTO "django_geo_db_city" VALUES(7152,'Rich Creek','Rich Creek, Virginia',8800,54);
INSERT INTO "django_geo_db_city" VALUES(7153,'Ridgeway','Ridgeway, Virginia',8801,54);
INSERT INTO "django_geo_db_city" VALUES(7154,'Riner','Riner, Virginia',8802,54);
INSERT INTO "django_geo_db_city" VALUES(7155,'Ripplemead','Ripplemead, Virginia',8803,54);
INSERT INTO "django_geo_db_city" VALUES(7156,'Rocky Mount','Rocky Mount, Virginia',8804,54);
INSERT INTO "django_geo_db_city" VALUES(7157,'Salem','Salem, Virginia',8805,54);
INSERT INTO "django_geo_db_city" VALUES(7158,'Sandy Level','Sandy Level, Virginia',8807,54);
INSERT INTO "django_geo_db_city" VALUES(7159,'Shawsville','Shawsville, Virginia',8808,54);
INSERT INTO "django_geo_db_city" VALUES(7160,'Spencer','Spencer, Virginia',8809,54);
INSERT INTO "django_geo_db_city" VALUES(7161,'Staffordsville','Staffordsville, Virginia',8810,54);
INSERT INTO "django_geo_db_city" VALUES(7162,'Stanleytown','Stanleytown, Virginia',8811,54);
INSERT INTO "django_geo_db_city" VALUES(7163,'Stuart','Stuart, Virginia',8812,54);
INSERT INTO "django_geo_db_city" VALUES(7164,'Thaxton','Thaxton, Virginia',8813,54);
INSERT INTO "django_geo_db_city" VALUES(7165,'Troutville','Troutville, Virginia',8814,54);
INSERT INTO "django_geo_db_city" VALUES(7166,'Union Hall','Union Hall, Virginia',8815,54);
INSERT INTO "django_geo_db_city" VALUES(7167,'Vesta','Vesta, Virginia',8816,54);
INSERT INTO "django_geo_db_city" VALUES(7168,'Villamont','Villamont, Virginia',8817,54);
INSERT INTO "django_geo_db_city" VALUES(7169,'Vinton','Vinton, Virginia',8818,54);
INSERT INTO "django_geo_db_city" VALUES(7170,'Wirtz','Wirtz, Virginia',8819,54);
INSERT INTO "django_geo_db_city" VALUES(7171,'Woolwine','Woolwine, Virginia',8820,54);
INSERT INTO "django_geo_db_city" VALUES(7172,'Bristol','Bristol, Virginia',8821,54);
INSERT INTO "django_geo_db_city" VALUES(7173,'Abingdon','Abingdon, Virginia',8824,54);
INSERT INTO "django_geo_db_city" VALUES(7174,'Andover','Andover, Virginia',8827,54);
INSERT INTO "django_geo_db_city" VALUES(7175,'Appalachia','Appalachia, Virginia',8828,54);
INSERT INTO "django_geo_db_city" VALUES(7176,'Bee','Bee, Virginia',8829,54);
INSERT INTO "django_geo_db_city" VALUES(7177,'Ben Hur','Ben Hur, Virginia',8830,54);
INSERT INTO "django_geo_db_city" VALUES(7178,'Big Stone Gap','Big Stone Gap, Virginia',8831,54);
INSERT INTO "django_geo_db_city" VALUES(7179,'Birchleaf','Birchleaf, Virginia',8832,54);
INSERT INTO "django_geo_db_city" VALUES(7180,'Blackwater','Blackwater, Virginia',8833,54);
INSERT INTO "django_geo_db_city" VALUES(7181,'Castlewood','Castlewood, Virginia',8834,54);
INSERT INTO "django_geo_db_city" VALUES(7182,'Cleveland','Cleveland, Virginia',8835,54);
INSERT INTO "django_geo_db_city" VALUES(7183,'Clinchco','Clinchco, Virginia',8836,54);
INSERT INTO "django_geo_db_city" VALUES(7184,'Clintwood','Clintwood, Virginia',8837,54);
INSERT INTO "django_geo_db_city" VALUES(7185,'Coeburn','Coeburn, Virginia',8838,54);
INSERT INTO "django_geo_db_city" VALUES(7186,'Damascus','Damascus, Virginia',8839,54);
INSERT INTO "django_geo_db_city" VALUES(7187,'Dante','Dante, Virginia',8840,54);
INSERT INTO "django_geo_db_city" VALUES(7188,'Davenport','Davenport, Virginia',8841,54);
INSERT INTO "django_geo_db_city" VALUES(7189,'Dryden','Dryden, Virginia',8842,54);
INSERT INTO "django_geo_db_city" VALUES(7190,'Duffield','Duffield, Virginia',8843,54);
INSERT INTO "django_geo_db_city" VALUES(7191,'Dungannon','Dungannon, Virginia',8844,54);
INSERT INTO "django_geo_db_city" VALUES(7192,'East Stone Gap','East Stone Gap, Virginia',8845,54);
INSERT INTO "django_geo_db_city" VALUES(7193,'Ewing','Ewing, Virginia',8846,54);
INSERT INTO "django_geo_db_city" VALUES(7194,'Fort Blackmore','Fort Blackmore, Virginia',8847,54);
INSERT INTO "django_geo_db_city" VALUES(7195,'Gate City','Gate City, Virginia',8848,54);
INSERT INTO "django_geo_db_city" VALUES(7196,'Haysi','Haysi, Virginia',8849,54);
INSERT INTO "django_geo_db_city" VALUES(7197,'Hiltons','Hiltons, Virginia',8850,54);
INSERT INTO "django_geo_db_city" VALUES(7198,'Honaker','Honaker, Virginia',8851,54);
INSERT INTO "django_geo_db_city" VALUES(7199,'Jonesville','Jonesville, Virginia',8852,54);
INSERT INTO "django_geo_db_city" VALUES(7200,'Keokee','Keokee, Virginia',8853,54);
INSERT INTO "django_geo_db_city" VALUES(7201,'Lebanon','Lebanon, Virginia',8854,54);
INSERT INTO "django_geo_db_city" VALUES(7202,'McClure','McClure, Virginia',8855,54);
INSERT INTO "django_geo_db_city" VALUES(7203,'Mendota','Mendota, Virginia',8856,54);
INSERT INTO "django_geo_db_city" VALUES(7204,'Nickelsville','Nickelsville, Virginia',8857,54);
INSERT INTO "django_geo_db_city" VALUES(7205,'Nora','Nora, Virginia',8858,54);
INSERT INTO "django_geo_db_city" VALUES(7206,'Norton','Norton, Virginia',8859,54);
INSERT INTO "django_geo_db_city" VALUES(7207,'Pound','Pound, Virginia',8860,54);
INSERT INTO "django_geo_db_city" VALUES(7208,'Pennington Gap','Pennington Gap, Virginia',8861,54);
INSERT INTO "django_geo_db_city" VALUES(7209,'Rosedale','Rosedale, Virginia',8863,54);
INSERT INTO "django_geo_db_city" VALUES(7210,'Rose Hill','Rose Hill, Virginia',8864,54);
INSERT INTO "django_geo_db_city" VALUES(7211,'Saint Charles','Saint Charles, Virginia',8865,54);
INSERT INTO "django_geo_db_city" VALUES(7212,'Saint Paul','Saint Paul, Virginia',8866,54);
INSERT INTO "django_geo_db_city" VALUES(7213,'Stonega','Stonega, Virginia',8867,54);
INSERT INTO "django_geo_db_city" VALUES(7214,'Trammel','Trammel, Virginia',8868,54);
INSERT INTO "django_geo_db_city" VALUES(7215,'Weber City','Weber City, Virginia',8869,54);
INSERT INTO "django_geo_db_city" VALUES(7216,'Whitetop','Whitetop, Virginia',8870,54);
INSERT INTO "django_geo_db_city" VALUES(7217,'Wise','Wise, Virginia',8871,54);
INSERT INTO "django_geo_db_city" VALUES(7218,'Pulaski','Pulaski, Virginia',8872,54);
INSERT INTO "django_geo_db_city" VALUES(7219,'Atkins','Atkins, Virginia',8873,54);
INSERT INTO "django_geo_db_city" VALUES(7220,'Austinville','Austinville, Virginia',8874,54);
INSERT INTO "django_geo_db_city" VALUES(7221,'Barren Springs','Barren Springs, Virginia',8875,54);
INSERT INTO "django_geo_db_city" VALUES(7222,'Bastian','Bastian, Virginia',8876,54);
INSERT INTO "django_geo_db_city" VALUES(7223,'Bland','Bland, Virginia',8877,54);
INSERT INTO "django_geo_db_city" VALUES(7224,'Broadford','Broadford, Virginia',8878,54);
INSERT INTO "django_geo_db_city" VALUES(7225,'Cana','Cana, Virginia',8879,54);
INSERT INTO "django_geo_db_city" VALUES(7226,'Ceres','Ceres, Virginia',8880,54);
INSERT INTO "django_geo_db_city" VALUES(7227,'Chilhowie','Chilhowie, Virginia',8881,54);
INSERT INTO "django_geo_db_city" VALUES(7228,'Cripple Creek','Cripple Creek, Virginia',8882,54);
INSERT INTO "django_geo_db_city" VALUES(7229,'Crockett','Crockett, Virginia',8883,54);
INSERT INTO "django_geo_db_city" VALUES(7230,'Draper','Draper, Virginia',8884,54);
INSERT INTO "django_geo_db_city" VALUES(7231,'Dugspur','Dugspur, Virginia',8885,54);
INSERT INTO "django_geo_db_city" VALUES(7232,'Elk Creek','Elk Creek, Virginia',8886,54);
INSERT INTO "django_geo_db_city" VALUES(7233,'Emory','Emory, Virginia',8887,54);
INSERT INTO "django_geo_db_city" VALUES(7234,'Fancy Gap','Fancy Gap, Virginia',8888,54);
INSERT INTO "django_geo_db_city" VALUES(7235,'Fries','Fries, Virginia',8889,54);
INSERT INTO "django_geo_db_city" VALUES(7236,'Galax','Galax, Virginia',8890,54);
INSERT INTO "django_geo_db_city" VALUES(7237,'Glade Spring','Glade Spring, Virginia',8892,54);
INSERT INTO "django_geo_db_city" VALUES(7238,'Hillsville','Hillsville, Virginia',8893,54);
INSERT INTO "django_geo_db_city" VALUES(7239,'Hiwassee','Hiwassee, Virginia',8894,54);
INSERT INTO "django_geo_db_city" VALUES(7240,'Independence','Independence, Virginia',8895,54);
INSERT INTO "django_geo_db_city" VALUES(7241,'Ivanhoe','Ivanhoe, Virginia',8896,54);
INSERT INTO "django_geo_db_city" VALUES(7242,'Lambsburg','Lambsburg, Virginia',8897,54);
INSERT INTO "django_geo_db_city" VALUES(7243,'Laurel Fork','Laurel Fork, Virginia',8898,54);
INSERT INTO "django_geo_db_city" VALUES(7244,'Marion','Marion, Virginia',8899,54);
INSERT INTO "django_geo_db_city" VALUES(7245,'Max Meadows','Max Meadows, Virginia',8900,54);
INSERT INTO "django_geo_db_city" VALUES(7246,'Meadowview','Meadowview, Virginia',8901,54);
INSERT INTO "django_geo_db_city" VALUES(7247,'Mouth Of Wilson','Mouth Of Wilson, Virginia',8902,54);
INSERT INTO "django_geo_db_city" VALUES(7248,'Rocky Gap','Rocky Gap, Virginia',8903,54);
INSERT INTO "django_geo_db_city" VALUES(7249,'Rural Retreat','Rural Retreat, Virginia',8904,54);
INSERT INTO "django_geo_db_city" VALUES(7250,'Saltville','Saltville, Virginia',8905,54);
INSERT INTO "django_geo_db_city" VALUES(7251,'Seven Mile Ford','Seven Mile Ford, Virginia',8906,54);
INSERT INTO "django_geo_db_city" VALUES(7252,'Speedwell','Speedwell, Virginia',8907,54);
INSERT INTO "django_geo_db_city" VALUES(7253,'Sugar Grove','Sugar Grove, Virginia',8908,54);
INSERT INTO "django_geo_db_city" VALUES(7254,'Tannersville','Tannersville, Virginia',8909,54);
INSERT INTO "django_geo_db_city" VALUES(7255,'Trout Dale','Trout Dale, Virginia',8910,54);
INSERT INTO "django_geo_db_city" VALUES(7256,'Volney','Volney, Virginia',8911,54);
INSERT INTO "django_geo_db_city" VALUES(7257,'Willis','Willis, Virginia',8912,54);
INSERT INTO "django_geo_db_city" VALUES(7258,'Woodlawn','Woodlawn, Virginia',8913,54);
INSERT INTO "django_geo_db_city" VALUES(7259,'Wytheville','Wytheville, Virginia',8914,54);
INSERT INTO "django_geo_db_city" VALUES(7260,'Staunton','Staunton, Virginia',8915,54);
INSERT INTO "django_geo_db_city" VALUES(7261,'Augusta Springs','Augusta Springs, Virginia',8918,54);
INSERT INTO "django_geo_db_city" VALUES(7262,'Bacova','Bacova, Virginia',8919,54);
INSERT INTO "django_geo_db_city" VALUES(7263,'Blue Grass','Blue Grass, Virginia',8920,54);
INSERT INTO "django_geo_db_city" VALUES(7264,'Brownsburg','Brownsburg, Virginia',8921,54);
INSERT INTO "django_geo_db_city" VALUES(7265,'Buena Vista','Buena Vista, Virginia',8922,54);
INSERT INTO "django_geo_db_city" VALUES(7266,'Churchville','Churchville, Virginia',8923,54);
INSERT INTO "django_geo_db_city" VALUES(7267,'Clifton Forge','Clifton Forge, Virginia',8924,54);
INSERT INTO "django_geo_db_city" VALUES(7268,'Covington','Covington, Virginia',8925,54);
INSERT INTO "django_geo_db_city" VALUES(7269,'Craigsville','Craigsville, Virginia',8926,54);
INSERT INTO "django_geo_db_city" VALUES(7270,'Crimora','Crimora, Virginia',8927,54);
INSERT INTO "django_geo_db_city" VALUES(7271,'Deerfield','Deerfield, Virginia',8928,54);
INSERT INTO "django_geo_db_city" VALUES(7272,'Doe Hill','Doe Hill, Virginia',8929,54);
INSERT INTO "django_geo_db_city" VALUES(7273,'Fairfield','Fairfield, Virginia',8930,54);
INSERT INTO "django_geo_db_city" VALUES(7274,'Fort Defiance','Fort Defiance, Virginia',8931,54);
INSERT INTO "django_geo_db_city" VALUES(7275,'Glen Wilton','Glen Wilton, Virginia',8738,54);
INSERT INTO "django_geo_db_city" VALUES(7276,'Goshen','Goshen, Virginia',8932,54);
INSERT INTO "django_geo_db_city" VALUES(7277,'Greenville','Greenville, Virginia',8933,54);
INSERT INTO "django_geo_db_city" VALUES(7278,'Grottoes','Grottoes, Virginia',8934,54);
INSERT INTO "django_geo_db_city" VALUES(7279,'Head Waters','Head Waters, Virginia',8935,54);
INSERT INTO "django_geo_db_city" VALUES(7280,'Iron Gate','Iron Gate, Virginia',8936,54);
INSERT INTO "django_geo_db_city" VALUES(7281,'Hot Springs','Hot Springs, Virginia',8937,54);
INSERT INTO "django_geo_db_city" VALUES(7282,'Lexington','Lexington, Virginia',8939,54);
INSERT INTO "django_geo_db_city" VALUES(7283,'Low Moor','Low Moor, Virginia',8940,54);
INSERT INTO "django_geo_db_city" VALUES(7284,'McDowell','McDowell, Virginia',8941,54);
INSERT INTO "django_geo_db_city" VALUES(7285,'Middlebrook','Middlebrook, Virginia',8942,54);
INSERT INTO "django_geo_db_city" VALUES(7286,'Millboro','Millboro, Virginia',8943,54);
INSERT INTO "django_geo_db_city" VALUES(7287,'Mint Spring','Mint Spring, Virginia',8944,54);
INSERT INTO "django_geo_db_city" VALUES(7288,'Montebello','Montebello, Virginia',8945,54);
INSERT INTO "django_geo_db_city" VALUES(7289,'Monterey','Monterey, Virginia',8946,54);
INSERT INTO "django_geo_db_city" VALUES(7290,'Mount Sidney','Mount Sidney, Virginia',8947,54);
INSERT INTO "django_geo_db_city" VALUES(7291,'Mustoe','Mustoe, Virginia',8948,54);
INSERT INTO "django_geo_db_city" VALUES(7292,'New Hope','New Hope, Virginia',8917,54);
INSERT INTO "django_geo_db_city" VALUES(7293,'Port Republic','Port Republic, Virginia',8949,54);
INSERT INTO "django_geo_db_city" VALUES(7294,'Raphine','Raphine, Virginia',8950,54);
INSERT INTO "django_geo_db_city" VALUES(7295,'Rockbridge Baths','Rockbridge Baths, Virginia',8951,54);
INSERT INTO "django_geo_db_city" VALUES(7296,'Selma','Selma, Virginia',8952,54);
INSERT INTO "django_geo_db_city" VALUES(7297,'Spottswood','Spottswood, Virginia',8953,54);
INSERT INTO "django_geo_db_city" VALUES(7298,'Steeles Tavern','Steeles Tavern, Virginia',8917,54);
INSERT INTO "django_geo_db_city" VALUES(7299,'Stuarts Draft','Stuarts Draft, Virginia',8954,54);
INSERT INTO "django_geo_db_city" VALUES(7300,'Swoope','Swoope, Virginia',8955,54);
INSERT INTO "django_geo_db_city" VALUES(7301,'Verona','Verona, Virginia',8956,54);
INSERT INTO "django_geo_db_city" VALUES(7302,'Vesuvius','Vesuvius, Virginia',8957,54);
INSERT INTO "django_geo_db_city" VALUES(7303,'Warm Springs','Warm Springs, Virginia',8958,54);
INSERT INTO "django_geo_db_city" VALUES(7304,'West Augusta','West Augusta, Virginia',8959,54);
INSERT INTO "django_geo_db_city" VALUES(7305,'Weyers Cave','Weyers Cave, Virginia',8960,54);
INSERT INTO "django_geo_db_city" VALUES(7306,'Williamsville','Williamsville, Virginia',8961,54);
INSERT INTO "django_geo_db_city" VALUES(7307,'Lynchburg','Lynchburg, Virginia',8962,54);
INSERT INTO "django_geo_db_city" VALUES(7308,'Altavista','Altavista, Virginia',8970,54);
INSERT INTO "django_geo_db_city" VALUES(7309,'Alton','Alton, Virginia',8971,54);
INSERT INTO "django_geo_db_city" VALUES(7310,'Amherst','Amherst, Virginia',8972,54);
INSERT INTO "django_geo_db_city" VALUES(7311,'Appomattox','Appomattox, Virginia',8973,54);
INSERT INTO "django_geo_db_city" VALUES(7312,'Bedford','Bedford, Virginia',8974,54);
INSERT INTO "django_geo_db_city" VALUES(7313,'Big Island','Big Island, Virginia',8975,54);
INSERT INTO "django_geo_db_city" VALUES(7314,'Blairs','Blairs, Virginia',8976,54);
INSERT INTO "django_geo_db_city" VALUES(7315,'Brookneal','Brookneal, Virginia',8977,54);
INSERT INTO "django_geo_db_city" VALUES(7316,'Buffalo Junction','Buffalo Junction, Virginia',8978,54);
INSERT INTO "django_geo_db_city" VALUES(7317,'Callands','Callands, Virginia',8979,54);
INSERT INTO "django_geo_db_city" VALUES(7318,'Chatham','Chatham, Virginia',8980,54);
INSERT INTO "django_geo_db_city" VALUES(7319,'Clifford','Clifford, Virginia',8981,54);
INSERT INTO "django_geo_db_city" VALUES(7320,'Clover','Clover, Virginia',8982,54);
INSERT INTO "django_geo_db_city" VALUES(7321,'Cluster Springs','Cluster Springs, Virginia',8983,54);
INSERT INTO "django_geo_db_city" VALUES(7322,'Coleman Falls','Coleman Falls, Virginia',8984,54);
INSERT INTO "django_geo_db_city" VALUES(7323,'Concord','Concord, Virginia',8985,54);
INSERT INTO "django_geo_db_city" VALUES(7324,'Crystal Hill','Crystal Hill, Virginia',8986,54);
INSERT INTO "django_geo_db_city" VALUES(7325,'Danville','Danville, Virginia',8987,54);
INSERT INTO "django_geo_db_city" VALUES(7326,'Dry Fork','Dry Fork, Virginia',8991,54);
INSERT INTO "django_geo_db_city" VALUES(7327,'Evington','Evington, Virginia',8992,54);
INSERT INTO "django_geo_db_city" VALUES(7328,'Forest','Forest, Virginia',8993,54);
INSERT INTO "django_geo_db_city" VALUES(7329,'Gladstone','Gladstone, Virginia',8994,54);
INSERT INTO "django_geo_db_city" VALUES(7330,'Gladys','Gladys, Virginia',8995,54);
INSERT INTO "django_geo_db_city" VALUES(7331,'Glasgow','Glasgow, Virginia',8996,54);
INSERT INTO "django_geo_db_city" VALUES(7332,'Goode','Goode, Virginia',8997,54);
INSERT INTO "django_geo_db_city" VALUES(7333,'Gretna','Gretna, Virginia',8998,54);
INSERT INTO "django_geo_db_city" VALUES(7334,'Halifax','Halifax, Virginia',8999,54);
INSERT INTO "django_geo_db_city" VALUES(7335,'Howardsville','Howardsville, Virginia',9000,54);
INSERT INTO "django_geo_db_city" VALUES(7336,'Hurt','Hurt, Virginia',9001,54);
INSERT INTO "django_geo_db_city" VALUES(7337,'Java','Java, Virginia',9002,54);
INSERT INTO "django_geo_db_city" VALUES(7338,'Keeling','Keeling, Virginia',9003,54);
INSERT INTO "django_geo_db_city" VALUES(7339,'Long Island','Long Island, Virginia',9004,54);
INSERT INTO "django_geo_db_city" VALUES(7340,'Lowry','Lowry, Virginia',9005,54);
INSERT INTO "django_geo_db_city" VALUES(7341,'Lynch Station','Lynch Station, Virginia',9006,54);
INSERT INTO "django_geo_db_city" VALUES(7342,'Madison Heights','Madison Heights, Virginia',9007,54);
INSERT INTO "django_geo_db_city" VALUES(7343,'Monroe','Monroe, Virginia',9008,54);
INSERT INTO "django_geo_db_city" VALUES(7344,'Naruna','Naruna, Virginia',8969,54);
INSERT INTO "django_geo_db_city" VALUES(7345,'Nathalie','Nathalie, Virginia',9009,54);
INSERT INTO "django_geo_db_city" VALUES(7346,'Natural Bridge','Natural Bridge, Virginia',9010,54);
INSERT INTO "django_geo_db_city" VALUES(7347,'Natural Bridge Station','Natural Bridge Station, Virginia',9011,54);
INSERT INTO "django_geo_db_city" VALUES(7348,'Nelson','Nelson, Virginia',9012,54);
INSERT INTO "django_geo_db_city" VALUES(7349,'Norwood','Norwood, Virginia',9013,54);
INSERT INTO "django_geo_db_city" VALUES(7350,'Republican Grove','Republican Grove, Virginia',9014,54);
INSERT INTO "django_geo_db_city" VALUES(7351,'Ringgold','Ringgold, Virginia',9015,54);
INSERT INTO "django_geo_db_city" VALUES(7352,'Rustburg','Rustburg, Virginia',9016,54);
INSERT INTO "django_geo_db_city" VALUES(7353,'Scottsburg','Scottsburg, Virginia',9017,54);
INSERT INTO "django_geo_db_city" VALUES(7354,'Scottsville','Scottsville, Virginia',9018,54);
INSERT INTO "django_geo_db_city" VALUES(7355,'South Boston','South Boston, Virginia',9019,54);
INSERT INTO "django_geo_db_city" VALUES(7356,'Spout Spring','Spout Spring, Virginia',9020,54);
INSERT INTO "django_geo_db_city" VALUES(7357,'Sutherlin','Sutherlin, Virginia',9021,54);
INSERT INTO "django_geo_db_city" VALUES(7358,'Sweet Briar','Sweet Briar, Virginia',9022,54);
INSERT INTO "django_geo_db_city" VALUES(7359,'Vernon Hill','Vernon Hill, Virginia',9023,54);
INSERT INTO "django_geo_db_city" VALUES(7360,'Virgilina','Virgilina, Virginia',9024,54);
INSERT INTO "django_geo_db_city" VALUES(7361,'Wingina','Wingina, Virginia',9025,54);
INSERT INTO "django_geo_db_city" VALUES(7362,'Amonate','Amonate, Virginia',9026,54);
INSERT INTO "django_geo_db_city" VALUES(7363,'Bandy','Bandy, Virginia',9027,54);
INSERT INTO "django_geo_db_city" VALUES(7364,'Big Rock','Big Rock, Virginia',9028,54);
INSERT INTO "django_geo_db_city" VALUES(7365,'Bishop','Bishop, Virginia',9029,54);
INSERT INTO "django_geo_db_city" VALUES(7366,'Bluefield','Bluefield, Virginia',9030,54);
INSERT INTO "django_geo_db_city" VALUES(7367,'Boissevain','Boissevain, Virginia',9031,54);
INSERT INTO "django_geo_db_city" VALUES(7368,'Breaks','Breaks, Virginia',9032,54);
INSERT INTO "django_geo_db_city" VALUES(7369,'Burkes Garden','Burkes Garden, Virginia',9033,54);
INSERT INTO "django_geo_db_city" VALUES(7370,'Cedar Bluff','Cedar Bluff, Virginia',9034,54);
INSERT INTO "django_geo_db_city" VALUES(7371,'Doran','Doran, Virginia',9035,54);
INSERT INTO "django_geo_db_city" VALUES(7372,'Falls Mills','Falls Mills, Virginia',9036,54);
INSERT INTO "django_geo_db_city" VALUES(7373,'Grundy','Grundy, Virginia',9037,54);
INSERT INTO "django_geo_db_city" VALUES(7374,'Harman','Harman, Virginia',9038,54);
INSERT INTO "django_geo_db_city" VALUES(7375,'Horsepen','Horsepen, Virginia',9033,54);
INSERT INTO "django_geo_db_city" VALUES(7376,'Hurley','Hurley, Virginia',9039,54);
INSERT INTO "django_geo_db_city" VALUES(7377,'Jewell Ridge','Jewell Ridge, Virginia',9040,54);
INSERT INTO "django_geo_db_city" VALUES(7378,'Keen Mountain','Keen Mountain, Virginia',9041,54);
INSERT INTO "django_geo_db_city" VALUES(7379,'Mavisdale','Mavisdale, Virginia',9038,54);
INSERT INTO "django_geo_db_city" VALUES(7380,'Maxie','Maxie, Virginia',9042,54);
INSERT INTO "django_geo_db_city" VALUES(7381,'North Tazewell','North Tazewell, Virginia',9043,54);
INSERT INTO "django_geo_db_city" VALUES(7382,'Oakwood','Oakwood, Virginia',9044,54);
INSERT INTO "django_geo_db_city" VALUES(7383,'Pilgrims Knob','Pilgrims Knob, Virginia',9045,54);
INSERT INTO "django_geo_db_city" VALUES(7384,'Pocahontas','Pocahontas, Virginia',9046,54);
INSERT INTO "django_geo_db_city" VALUES(7385,'Pounding Mill','Pounding Mill, Virginia',9047,54);
INSERT INTO "django_geo_db_city" VALUES(7386,'Raven','Raven, Virginia',9048,54);
INSERT INTO "django_geo_db_city" VALUES(7387,'Red Ash','Red Ash, Virginia',9033,54);
INSERT INTO "django_geo_db_city" VALUES(7388,'Richlands','Richlands, Virginia',9049,54);
INSERT INTO "django_geo_db_city" VALUES(7389,'Rowe','Rowe, Virginia',9050,54);
INSERT INTO "django_geo_db_city" VALUES(7390,'Shortt Gap','Shortt Gap, Virginia',9038,54);
INSERT INTO "django_geo_db_city" VALUES(7391,'Swords Creek','Swords Creek, Virginia',9051,54);
INSERT INTO "django_geo_db_city" VALUES(7392,'Tazewell','Tazewell, Virginia',9052,54);
INSERT INTO "django_geo_db_city" VALUES(7393,'Vansant','Vansant, Virginia',9053,54);
INSERT INTO "django_geo_db_city" VALUES(7394,'Whitewood','Whitewood, Virginia',9054,54);
INSERT INTO "django_geo_db_city" VALUES(7395,'Wolford','Wolford, Virginia',9038,54);
INSERT INTO "django_geo_db_city" VALUES(7396,'Bluefield','Bluefield, West Virginia',9055,57);
INSERT INTO "django_geo_db_city" VALUES(7397,'Athens','Athens, West Virginia',9057,57);
INSERT INTO "django_geo_db_city" VALUES(7398,'Beeson','Beeson, West Virginia',9058,57);
INSERT INTO "django_geo_db_city" VALUES(7399,'Bramwell','Bramwell, West Virginia',9059,57);
INSERT INTO "django_geo_db_city" VALUES(7400,'Bud','Bud, West Virginia',9060,57);
INSERT INTO "django_geo_db_city" VALUES(7401,'Covel','Covel, West Virginia',9061,57);
INSERT INTO "django_geo_db_city" VALUES(7402,'Freeman','Freeman, West Virginia',9062,57);
INSERT INTO "django_geo_db_city" VALUES(7403,'Herndon','Herndon, West Virginia',9063,57);
INSERT INTO "django_geo_db_city" VALUES(7404,'Hiawatha','Hiawatha, West Virginia',9064,57);
INSERT INTO "django_geo_db_city" VALUES(7405,'Kegley','Kegley, West Virginia',9065,57);
INSERT INTO "django_geo_db_city" VALUES(7406,'Kellysville','Kellysville, West Virginia',9064,57);
INSERT INTO "django_geo_db_city" VALUES(7407,'Lashmeet','Lashmeet, West Virginia',9066,57);
INSERT INTO "django_geo_db_city" VALUES(7408,'Matoaka','Matoaka, West Virginia',9067,57);
INSERT INTO "django_geo_db_city" VALUES(7409,'Montcalm','Montcalm, West Virginia',9068,57);
INSERT INTO "django_geo_db_city" VALUES(7410,'Nemours','Nemours, West Virginia',9064,57);
INSERT INTO "django_geo_db_city" VALUES(7411,'Oakvale','Oakvale, West Virginia',9069,57);
INSERT INTO "django_geo_db_city" VALUES(7412,'Princeton','Princeton, West Virginia',9070,57);
INSERT INTO "django_geo_db_city" VALUES(7413,'Rock','Rock, West Virginia',9071,57);
INSERT INTO "django_geo_db_city" VALUES(7414,'Wolfe','Wolfe, West Virginia',9064,57);
INSERT INTO "django_geo_db_city" VALUES(7415,'Welch','Welch, West Virginia',9072,57);
INSERT INTO "django_geo_db_city" VALUES(7416,'Anawalt','Anawalt, West Virginia',9073,57);
INSERT INTO "django_geo_db_city" VALUES(7417,'Avondale','Avondale, West Virginia',9074,57);
INSERT INTO "django_geo_db_city" VALUES(7418,'Bartley','Bartley, West Virginia',9075,57);
INSERT INTO "django_geo_db_city" VALUES(7419,'Berwind','Berwind, West Virginia',9076,57);
INSERT INTO "django_geo_db_city" VALUES(7420,'Big Sandy','Big Sandy, West Virginia',9077,57);
INSERT INTO "django_geo_db_city" VALUES(7421,'Bradshaw','Bradshaw, West Virginia',9078,57);
INSERT INTO "django_geo_db_city" VALUES(7422,'Brenton','Brenton, West Virginia',9079,57);
INSERT INTO "django_geo_db_city" VALUES(7423,'Capels','Capels, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7424,'Caretta','Caretta, West Virginia',9081,57);
INSERT INTO "django_geo_db_city" VALUES(7425,'Clear Fork','Clear Fork, West Virginia',9082,57);
INSERT INTO "django_geo_db_city" VALUES(7426,'Coal Mountain','Coal Mountain, West Virginia',9083,57);
INSERT INTO "django_geo_db_city" VALUES(7427,'Coalwood','Coalwood, West Virginia',9084,57);
INSERT INTO "django_geo_db_city" VALUES(7428,'Crumpler','Crumpler, West Virginia',9085,57);
INSERT INTO "django_geo_db_city" VALUES(7429,'Cucumber','Cucumber, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7430,'Cyclone','Cyclone, West Virginia',9086,57);
INSERT INTO "django_geo_db_city" VALUES(7431,'Davy','Davy, West Virginia',9087,57);
INSERT INTO "django_geo_db_city" VALUES(7432,'Eckman','Eckman, West Virginia',9088,57);
INSERT INTO "django_geo_db_city" VALUES(7433,'Elbert','Elbert, West Virginia',9089,57);
INSERT INTO "django_geo_db_city" VALUES(7434,'Elkhorn','Elkhorn, West Virginia',9090,57);
INSERT INTO "django_geo_db_city" VALUES(7435,'English','English, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7436,'Fanrock','Fanrock, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7437,'Gary','Gary, West Virginia',9092,57);
INSERT INTO "django_geo_db_city" VALUES(7438,'Hanover','Hanover, West Virginia',9093,57);
INSERT INTO "django_geo_db_city" VALUES(7439,'Havaco','Havaco, West Virginia',9094,57);
INSERT INTO "django_geo_db_city" VALUES(7440,'Hemphill','Hemphill, West Virginia',9095,57);
INSERT INTO "django_geo_db_city" VALUES(7441,'Hensley','Hensley, West Virginia',9096,57);
INSERT INTO "django_geo_db_city" VALUES(7442,'Iaeger','Iaeger, West Virginia',9097,57);
INSERT INTO "django_geo_db_city" VALUES(7443,'Ikes Fork','Ikes Fork, West Virginia',9098,57);
INSERT INTO "django_geo_db_city" VALUES(7444,'Isaban','Isaban, West Virginia',9099,57);
INSERT INTO "django_geo_db_city" VALUES(7445,'Itmann','Itmann, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7446,'Jenkinjones','Jenkinjones, West Virginia',9100,57);
INSERT INTO "django_geo_db_city" VALUES(7447,'Jesse','Jesse, West Virginia',9101,57);
INSERT INTO "django_geo_db_city" VALUES(7448,'Jolo','Jolo, West Virginia',9102,57);
INSERT INTO "django_geo_db_city" VALUES(7449,'Justice','Justice, West Virginia',9103,57);
INSERT INTO "django_geo_db_city" VALUES(7450,'Keystone','Keystone, West Virginia',9104,57);
INSERT INTO "django_geo_db_city" VALUES(7451,'Kimball','Kimball, West Virginia',9105,57);
INSERT INTO "django_geo_db_city" VALUES(7452,'Kopperston','Kopperston, West Virginia',9106,57);
INSERT INTO "django_geo_db_city" VALUES(7453,'Kyle','Kyle, West Virginia',9107,57);
INSERT INTO "django_geo_db_city" VALUES(7454,'Leckie','Leckie, West Virginia',9108,57);
INSERT INTO "django_geo_db_city" VALUES(7455,'Lynco','Lynco, West Virginia',9109,57);
INSERT INTO "django_geo_db_city" VALUES(7456,'Marianna','Marianna, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7457,'Matheny','Matheny, West Virginia',9110,57);
INSERT INTO "django_geo_db_city" VALUES(7458,'Maybeury','Maybeury, West Virginia',9111,57);
INSERT INTO "django_geo_db_city" VALUES(7459,'Mohawk','Mohawk, West Virginia',9112,57);
INSERT INTO "django_geo_db_city" VALUES(7460,'Newhall','Newhall, West Virginia',9113,57);
INSERT INTO "django_geo_db_city" VALUES(7461,'New Richmond','New Richmond, West Virginia',9114,57);
INSERT INTO "django_geo_db_city" VALUES(7462,'Northfork','Northfork, West Virginia',9115,57);
INSERT INTO "django_geo_db_city" VALUES(7463,'North Spring','North Spring, West Virginia',9116,57);
INSERT INTO "django_geo_db_city" VALUES(7464,'Oceana','Oceana, West Virginia',9117,57);
INSERT INTO "django_geo_db_city" VALUES(7465,'Pageton','Pageton, West Virginia',9118,57);
INSERT INTO "django_geo_db_city" VALUES(7466,'Panther','Panther, West Virginia',9119,57);
INSERT INTO "django_geo_db_city" VALUES(7467,'Paynesville','Paynesville, West Virginia',9120,57);
INSERT INTO "django_geo_db_city" VALUES(7468,'Pineville','Pineville, West Virginia',9121,57);
INSERT INTO "django_geo_db_city" VALUES(7469,'Powhatan','Powhatan, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7470,'Premier','Premier, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7471,'Raysal','Raysal, West Virginia',9122,57);
INSERT INTO "django_geo_db_city" VALUES(7472,'Rock View','Rock View, West Virginia',9123,57);
INSERT INTO "django_geo_db_city" VALUES(7473,'Roderfield','Roderfield, West Virginia',9124,57);
INSERT INTO "django_geo_db_city" VALUES(7474,'Simon','Simon, West Virginia',9125,57);
INSERT INTO "django_geo_db_city" VALUES(7475,'Skygusty','Skygusty, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7476,'Squire','Squire, West Virginia',9126,57);
INSERT INTO "django_geo_db_city" VALUES(7477,'Switchback','Switchback, West Virginia',9127,57);
INSERT INTO "django_geo_db_city" VALUES(7478,'Thorpe','Thorpe, West Virginia',9128,57);
INSERT INTO "django_geo_db_city" VALUES(7479,'Twin Branch','Twin Branch, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7480,'War','War, West Virginia',9129,57);
INSERT INTO "django_geo_db_city" VALUES(7481,'Warriormine','Warriormine, West Virginia',9130,57);
INSERT INTO "django_geo_db_city" VALUES(7482,'Wilcoe','Wilcoe, West Virginia',9131,57);
INSERT INTO "django_geo_db_city" VALUES(7483,'Wolf Pen','Wolf Pen, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7484,'Worth','Worth, West Virginia',9132,57);
INSERT INTO "django_geo_db_city" VALUES(7485,'Wyoming','Wyoming, West Virginia',9133,57);
INSERT INTO "django_geo_db_city" VALUES(7486,'Yukon','Yukon, West Virginia',9080,57);
INSERT INTO "django_geo_db_city" VALUES(7487,'Lewisburg','Lewisburg, West Virginia',9134,57);
INSERT INTO "django_geo_db_city" VALUES(7488,'Fairlea','Fairlea, West Virginia',9135,57);
INSERT INTO "django_geo_db_city" VALUES(7489,'Alderson','Alderson, West Virginia',9136,57);
INSERT INTO "django_geo_db_city" VALUES(7490,'Arbovale','Arbovale, West Virginia',9137,57);
INSERT INTO "django_geo_db_city" VALUES(7491,'Asbury','Asbury, West Virginia',9138,57);
INSERT INTO "django_geo_db_city" VALUES(7492,'Auto','Auto, West Virginia',9139,57);
INSERT INTO "django_geo_db_city" VALUES(7493,'Ballard','Ballard, West Virginia',9140,57);
INSERT INTO "django_geo_db_city" VALUES(7494,'Ballengee','Ballengee, West Virginia',9141,57);
INSERT INTO "django_geo_db_city" VALUES(7495,'Bartow','Bartow, West Virginia',9142,57);
INSERT INTO "django_geo_db_city" VALUES(7496,'Buckeye','Buckeye, West Virginia',9143,57);
INSERT INTO "django_geo_db_city" VALUES(7497,'Caldwell','Caldwell, West Virginia',9144,57);
INSERT INTO "django_geo_db_city" VALUES(7498,'Cass','Cass, West Virginia',9145,57);
INSERT INTO "django_geo_db_city" VALUES(7499,'Crawley','Crawley, West Virginia',9146,57);
INSERT INTO "django_geo_db_city" VALUES(7500,'Dunmore','Dunmore, West Virginia',9147,57);
INSERT INTO "django_geo_db_city" VALUES(7501,'Forest Hill','Forest Hill, West Virginia',9148,57);
INSERT INTO "django_geo_db_city" VALUES(7502,'Fort Spring','Fort Spring, West Virginia',9149,57);
INSERT INTO "django_geo_db_city" VALUES(7503,'Frankford','Frankford, West Virginia',9150,57);
INSERT INTO "django_geo_db_city" VALUES(7504,'Gap Mills','Gap Mills, West Virginia',9151,57);
INSERT INTO "django_geo_db_city" VALUES(7505,'Glace','Glace, West Virginia',9152,57);
INSERT INTO "django_geo_db_city" VALUES(7506,'Grassy Meadows','Grassy Meadows, West Virginia',9153,57);
INSERT INTO "django_geo_db_city" VALUES(7507,'Green Bank','Green Bank, West Virginia',9154,57);
INSERT INTO "django_geo_db_city" VALUES(7508,'Greenville','Greenville, West Virginia',9155,57);
INSERT INTO "django_geo_db_city" VALUES(7509,'Hillsboro','Hillsboro, West Virginia',9156,57);
INSERT INTO "django_geo_db_city" VALUES(7510,'Kieffer','Kieffer, West Virginia',9157,57);
INSERT INTO "django_geo_db_city" VALUES(7511,'Lindside','Lindside, West Virginia',9158,57);
INSERT INTO "django_geo_db_city" VALUES(7512,'Marlinton','Marlinton, West Virginia',9159,57);
INSERT INTO "django_geo_db_city" VALUES(7513,'Maxwelton','Maxwelton, West Virginia',9160,57);
INSERT INTO "django_geo_db_city" VALUES(7514,'Meadow Bluff','Meadow Bluff, West Virginia',9139,57);
INSERT INTO "django_geo_db_city" VALUES(7515,'Neola','Neola, West Virginia',9139,57);
INSERT INTO "django_geo_db_city" VALUES(7516,'Pence Springs','Pence Springs, West Virginia',9161,57);
INSERT INTO "django_geo_db_city" VALUES(7517,'Peterstown','Peterstown, West Virginia',9162,57);
INSERT INTO "django_geo_db_city" VALUES(7518,'Renick','Renick, West Virginia',9163,57);
INSERT INTO "django_geo_db_city" VALUES(7519,'Ronceverte','Ronceverte, West Virginia',9164,57);
INSERT INTO "django_geo_db_city" VALUES(7520,'Secondcreek','Secondcreek, West Virginia',9166,57);
INSERT INTO "django_geo_db_city" VALUES(7521,'Sinks Grove','Sinks Grove, West Virginia',9167,57);
INSERT INTO "django_geo_db_city" VALUES(7522,'Smoot','Smoot, West Virginia',9168,57);
INSERT INTO "django_geo_db_city" VALUES(7523,'Talcott','Talcott, West Virginia',9169,57);
INSERT INTO "django_geo_db_city" VALUES(7524,'Union','Union, West Virginia',9170,57);
INSERT INTO "django_geo_db_city" VALUES(7525,'Waiteville','Waiteville, West Virginia',9171,57);
INSERT INTO "django_geo_db_city" VALUES(7526,'Wayside','Wayside, West Virginia',9172,57);
INSERT INTO "django_geo_db_city" VALUES(7527,'White Sulphur Springs','White Sulphur Springs, West Virginia',9173,57);
INSERT INTO "django_geo_db_city" VALUES(7528,'Williamsburg','Williamsburg, West Virginia',9174,57);
INSERT INTO "django_geo_db_city" VALUES(7529,'Wolfcreek','Wolfcreek, West Virginia',9152,57);
INSERT INTO "django_geo_db_city" VALUES(7530,'Alloy','Alloy, West Virginia',9175,57);
INSERT INTO "django_geo_db_city" VALUES(7531,'Alum Creek','Alum Creek, West Virginia',9176,57);
INSERT INTO "django_geo_db_city" VALUES(7532,'Ameagle','Ameagle, West Virginia',9177,57);
INSERT INTO "django_geo_db_city" VALUES(7533,'Amma','Amma, West Virginia',9178,57);
INSERT INTO "django_geo_db_city" VALUES(7534,'Arnett','Arnett, West Virginia',9179,57);
INSERT INTO "django_geo_db_city" VALUES(7535,'Artie','Artie, West Virginia',9180,57);
INSERT INTO "django_geo_db_city" VALUES(7536,'Ashford','Ashford, West Virginia',9181,57);
INSERT INTO "django_geo_db_city" VALUES(7537,'Bald Knob','Bald Knob, West Virginia',9182,57);
INSERT INTO "django_geo_db_city" VALUES(7538,'Bancroft','Bancroft, West Virginia',9183,57);
INSERT INTO "django_geo_db_city" VALUES(7539,'Belle','Belle, West Virginia',9184,57);
INSERT INTO "django_geo_db_city" VALUES(7540,'Bentree','Bentree, West Virginia',9185,57);
INSERT INTO "django_geo_db_city" VALUES(7541,'Bickmore','Bickmore, West Virginia',9186,57);
INSERT INTO "django_geo_db_city" VALUES(7542,'Bim','Bim, West Virginia',9187,57);
INSERT INTO "django_geo_db_city" VALUES(7543,'Blair','Blair, West Virginia',9188,57);
INSERT INTO "django_geo_db_city" VALUES(7544,'Bloomingrose','Bloomingrose, West Virginia',9189,57);
INSERT INTO "django_geo_db_city" VALUES(7545,'Blount','Blount, West Virginia',9190,57);
INSERT INTO "django_geo_db_city" VALUES(7546,'Blue Creek','Blue Creek, West Virginia',9191,57);
INSERT INTO "django_geo_db_city" VALUES(7547,'Bob White','Bob White, West Virginia',9192,57);
INSERT INTO "django_geo_db_city" VALUES(7548,'Bomont','Bomont, West Virginia',9193,57);
INSERT INTO "django_geo_db_city" VALUES(7549,'Boomer','Boomer, West Virginia',9194,57);
INSERT INTO "django_geo_db_city" VALUES(7550,'Buffalo','Buffalo, West Virginia',9195,57);
INSERT INTO "django_geo_db_city" VALUES(7551,'Cabin Creek','Cabin Creek, West Virginia',9196,57);
INSERT INTO "django_geo_db_city" VALUES(7552,'Cannelton','Cannelton, West Virginia',9197,57);
INSERT INTO "django_geo_db_city" VALUES(7553,'Cedar Grove','Cedar Grove, West Virginia',9198,57);
INSERT INTO "django_geo_db_city" VALUES(7554,'Charlton Heights','Charlton Heights, West Virginia',9199,57);
INSERT INTO "django_geo_db_city" VALUES(7555,'Clay','Clay, West Virginia',9200,57);
INSERT INTO "django_geo_db_city" VALUES(7556,'Clear Creek','Clear Creek, West Virginia',9201,57);
INSERT INTO "django_geo_db_city" VALUES(7557,'Clendenin','Clendenin, West Virginia',9202,57);
INSERT INTO "django_geo_db_city" VALUES(7558,'Clio','Clio, West Virginia',9203,57);
INSERT INTO "django_geo_db_city" VALUES(7559,'Clothier','Clothier, West Virginia',9204,57);
INSERT INTO "django_geo_db_city" VALUES(7560,'Colcord','Colcord, West Virginia',9205,57);
INSERT INTO "django_geo_db_city" VALUES(7561,'Comfort','Comfort, West Virginia',9206,57);
INSERT INTO "django_geo_db_city" VALUES(7562,'Costa','Costa, West Virginia',9207,57);
INSERT INTO "django_geo_db_city" VALUES(7563,'Danville','Danville, West Virginia',9208,57);
INSERT INTO "django_geo_db_city" VALUES(7564,'Dawes','Dawes, West Virginia',9209,57);
INSERT INTO "django_geo_db_city" VALUES(7565,'Deep Water','Deep Water, West Virginia',9210,57);
INSERT INTO "django_geo_db_city" VALUES(7566,'Dixie','Dixie, West Virginia',9211,57);
INSERT INTO "django_geo_db_city" VALUES(7567,'Dorothy','Dorothy, West Virginia',9212,57);
INSERT INTO "django_geo_db_city" VALUES(7568,'Drybranch','Drybranch, West Virginia',9213,57);
INSERT INTO "django_geo_db_city" VALUES(7569,'Dry Creek','Dry Creek, West Virginia',9214,57);
INSERT INTO "django_geo_db_city" VALUES(7570,'Duck','Duck, West Virginia',9215,57);
INSERT INTO "django_geo_db_city" VALUES(7571,'Dunbar','Dunbar, West Virginia',9216,57);
INSERT INTO "django_geo_db_city" VALUES(7572,'East Bank','East Bank, West Virginia',9217,57);
INSERT INTO "django_geo_db_city" VALUES(7573,'Eleanor','Eleanor, West Virginia',9218,57);
INSERT INTO "django_geo_db_city" VALUES(7574,'Elkview','Elkview, West Virginia',9219,57);
INSERT INTO "django_geo_db_city" VALUES(7575,'Eskdale','Eskdale, West Virginia',9220,57);
INSERT INTO "django_geo_db_city" VALUES(7576,'Ethel','Ethel, West Virginia',9221,57);
INSERT INTO "django_geo_db_city" VALUES(7577,'Falling Rock','Falling Rock, West Virginia',9222,57);
INSERT INTO "django_geo_db_city" VALUES(7578,'Foster','Foster, West Virginia',9223,57);
INSERT INTO "django_geo_db_city" VALUES(7579,'Fraziers Bottom','Fraziers Bottom, West Virginia',9224,57);
INSERT INTO "django_geo_db_city" VALUES(7580,'Gallagher','Gallagher, West Virginia',9225,57);
INSERT INTO "django_geo_db_city" VALUES(7581,'Gauley Bridge','Gauley Bridge, West Virginia',9226,57);
INSERT INTO "django_geo_db_city" VALUES(7582,'Glasgow','Glasgow, West Virginia',9227,57);
INSERT INTO "django_geo_db_city" VALUES(7583,'Glen','Glen, West Virginia',9228,57);
INSERT INTO "django_geo_db_city" VALUES(7584,'Glen Ferris','Glen Ferris, West Virginia',9229,57);
INSERT INTO "django_geo_db_city" VALUES(7585,'Gordon','Gordon, West Virginia',9230,57);
INSERT INTO "django_geo_db_city" VALUES(7586,'Grimms Landing','Grimms Landing, West Virginia',9231,57);
INSERT INTO "django_geo_db_city" VALUES(7587,'Handley','Handley, West Virginia',9232,57);
INSERT INTO "django_geo_db_city" VALUES(7588,'Hansford','Hansford, West Virginia',9233,57);
INSERT INTO "django_geo_db_city" VALUES(7589,'Henderson','Henderson, West Virginia',9234,57);
INSERT INTO "django_geo_db_city" VALUES(7590,'Hernshaw','Hernshaw, West Virginia',9235,57);
INSERT INTO "django_geo_db_city" VALUES(7591,'Hewett','Hewett, West Virginia',9236,57);
INSERT INTO "django_geo_db_city" VALUES(7592,'Hometown','Hometown, West Virginia',9237,57);
INSERT INTO "django_geo_db_city" VALUES(7593,'Hugheston','Hugheston, West Virginia',9238,57);
INSERT INTO "django_geo_db_city" VALUES(7594,'Indore','Indore, West Virginia',9239,57);
INSERT INTO "django_geo_db_city" VALUES(7595,'Institute','Institute, West Virginia',9240,57);
INSERT INTO "django_geo_db_city" VALUES(7596,'Ivydale','Ivydale, West Virginia',9241,57);
INSERT INTO "django_geo_db_city" VALUES(7597,'Jeffrey','Jeffrey, West Virginia',9242,57);
INSERT INTO "django_geo_db_city" VALUES(7598,'Kanawha Falls','Kanawha Falls, West Virginia',9243,57);
INSERT INTO "django_geo_db_city" VALUES(7599,'Kimberly','Kimberly, West Virginia',9244,57);
INSERT INTO "django_geo_db_city" VALUES(7600,'Kincaid','Kincaid, West Virginia',9245,57);
INSERT INTO "django_geo_db_city" VALUES(7601,'Lake','Lake, West Virginia',9246,57);
INSERT INTO "django_geo_db_city" VALUES(7602,'Leewood','Leewood, West Virginia',9213,57);
INSERT INTO "django_geo_db_city" VALUES(7603,'Leon','Leon, West Virginia',9247,57);
INSERT INTO "django_geo_db_city" VALUES(7604,'Liberty','Liberty, West Virginia',9248,57);
INSERT INTO "django_geo_db_city" VALUES(7605,'Lizemores','Lizemores, West Virginia',9249,57);
INSERT INTO "django_geo_db_city" VALUES(7606,'London','London, West Virginia',9250,57);
INSERT INTO "django_geo_db_city" VALUES(7607,'Madison','Madison, West Virginia',9251,57);
INSERT INTO "django_geo_db_city" VALUES(7608,'Mammoth','Mammoth, West Virginia',9252,57);
INSERT INTO "django_geo_db_city" VALUES(7609,'Maysel','Maysel, West Virginia',9253,57);
INSERT INTO "django_geo_db_city" VALUES(7610,'Miami','Miami, West Virginia',9254,57);
INSERT INTO "django_geo_db_city" VALUES(7611,'Montgomery','Montgomery, West Virginia',9255,57);
INSERT INTO "django_geo_db_city" VALUES(7612,'Mount Carbon','Mount Carbon, West Virginia',9256,57);
INSERT INTO "django_geo_db_city" VALUES(7613,'Naoma','Naoma, West Virginia',9257,57);
INSERT INTO "django_geo_db_city" VALUES(7614,'Nebo','Nebo, West Virginia',9258,57);
INSERT INTO "django_geo_db_city" VALUES(7615,'Nellis','Nellis, West Virginia',9230,57);
INSERT INTO "django_geo_db_city" VALUES(7616,'Nitro','Nitro, West Virginia',9259,57);
INSERT INTO "django_geo_db_city" VALUES(7617,'Ohley','Ohley, West Virginia',9213,57);
INSERT INTO "django_geo_db_city" VALUES(7618,'Orgas','Orgas, West Virginia',9260,57);
INSERT INTO "django_geo_db_city" VALUES(7619,'Ottawa','Ottawa, West Virginia',9261,57);
INSERT INTO "django_geo_db_city" VALUES(7620,'Ovapa','Ovapa, West Virginia',9262,57);
INSERT INTO "django_geo_db_city" VALUES(7621,'Page','Page, West Virginia',9263,57);
INSERT INTO "django_geo_db_city" VALUES(7622,'Peytona','Peytona, West Virginia',9264,57);
INSERT INTO "django_geo_db_city" VALUES(7623,'Pinch','Pinch, West Virginia',9265,57);
INSERT INTO "django_geo_db_city" VALUES(7624,'Poca','Poca, West Virginia',9266,57);
INSERT INTO "django_geo_db_city" VALUES(7625,'Pond Gap','Pond Gap, West Virginia',9267,57);
INSERT INTO "django_geo_db_city" VALUES(7626,'Powellton','Powellton, West Virginia',9268,57);
INSERT INTO "django_geo_db_city" VALUES(7627,'Pratt','Pratt, West Virginia',9269,57);
INSERT INTO "django_geo_db_city" VALUES(7628,'Procious','Procious, West Virginia',9270,57);
INSERT INTO "django_geo_db_city" VALUES(7629,'Racine','Racine, West Virginia',9271,57);
INSERT INTO "django_geo_db_city" VALUES(7630,'Red House','Red House, West Virginia',9272,57);
INSERT INTO "django_geo_db_city" VALUES(7631,'Ridgeview','Ridgeview, West Virginia',9273,57);
INSERT INTO "django_geo_db_city" VALUES(7632,'Robson','Robson, West Virginia',9274,57);
INSERT INTO "django_geo_db_city" VALUES(7633,'Rock Creek','Rock Creek, West Virginia',9275,57);
INSERT INTO "django_geo_db_city" VALUES(7634,'Saint Albans','Saint Albans, West Virginia',9276,57);
INSERT INTO "django_geo_db_city" VALUES(7635,'Saxon','Saxon, West Virginia',9277,57);
INSERT INTO "django_geo_db_city" VALUES(7636,'Seth','Seth, West Virginia',9278,57);
INSERT INTO "django_geo_db_city" VALUES(7637,'Sharon','Sharon, West Virginia',9213,57);
INSERT INTO "django_geo_db_city" VALUES(7638,'Sharples','Sharples, West Virginia',9279,57);
INSERT INTO "django_geo_db_city" VALUES(7639,'Mount Olive','Mount Olive, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7640,'Smithers','Smithers, West Virginia',9281,57);
INSERT INTO "django_geo_db_city" VALUES(7641,'Southside','Southside, West Virginia',9282,57);
INSERT INTO "django_geo_db_city" VALUES(7642,'Sylvester','Sylvester, West Virginia',9283,57);
INSERT INTO "django_geo_db_city" VALUES(7643,'Tad','Tad, West Virginia',9213,57);
INSERT INTO "django_geo_db_city" VALUES(7644,'Tornado','Tornado, West Virginia',9284,57);
INSERT INTO "django_geo_db_city" VALUES(7645,'Turtle Creek','Turtle Creek, West Virginia',9285,57);
INSERT INTO "django_geo_db_city" VALUES(7646,'Twilight','Twilight, West Virginia',9286,57);
INSERT INTO "django_geo_db_city" VALUES(7647,'Uneeda','Uneeda, West Virginia',9287,57);
INSERT INTO "django_geo_db_city" VALUES(7648,'Van','Van, West Virginia',9288,57);
INSERT INTO "django_geo_db_city" VALUES(7649,'Wharton','Wharton, West Virginia',9289,57);
INSERT INTO "django_geo_db_city" VALUES(7650,'Whitesville','Whitesville, West Virginia',9290,57);
INSERT INTO "django_geo_db_city" VALUES(7651,'Widen','Widen, West Virginia',9291,57);
INSERT INTO "django_geo_db_city" VALUES(7652,'Winfield','Winfield, West Virginia',9292,57);
INSERT INTO "django_geo_db_city" VALUES(7653,'Winifrede','Winifrede, West Virginia',9293,57);
INSERT INTO "django_geo_db_city" VALUES(7654,'Advent','Advent, West Virginia',9294,57);
INSERT INTO "django_geo_db_city" VALUES(7655,'Arnoldsburg','Arnoldsburg, West Virginia',9295,57);
INSERT INTO "django_geo_db_city" VALUES(7656,'Chloe','Chloe, West Virginia',9296,57);
INSERT INTO "django_geo_db_city" VALUES(7657,'Cottageville','Cottageville, West Virginia',9297,57);
INSERT INTO "django_geo_db_city" VALUES(7658,'Evans','Evans, West Virginia',9298,57);
INSERT INTO "django_geo_db_city" VALUES(7659,'Gandeeville','Gandeeville, West Virginia',9299,57);
INSERT INTO "django_geo_db_city" VALUES(7660,'Gay','Gay, West Virginia',9300,57);
INSERT INTO "django_geo_db_city" VALUES(7661,'Given','Given, West Virginia',9301,57);
INSERT INTO "django_geo_db_city" VALUES(7662,'Hartford','Hartford, West Virginia',9302,57);
INSERT INTO "django_geo_db_city" VALUES(7663,'Kenna','Kenna, West Virginia',9303,57);
INSERT INTO "django_geo_db_city" VALUES(7664,'Lakin','Lakin, West Virginia',9231,57);
INSERT INTO "django_geo_db_city" VALUES(7665,'Left Hand','Left Hand, West Virginia',9304,57);
INSERT INTO "django_geo_db_city" VALUES(7666,'Le Roy','Le Roy, West Virginia',9305,57);
INSERT INTO "django_geo_db_city" VALUES(7667,'Letart','Letart, West Virginia',9306,57);
INSERT INTO "django_geo_db_city" VALUES(7668,'Linden','Linden, West Virginia',9203,57);
INSERT INTO "django_geo_db_city" VALUES(7669,'Lockney','Lockney, West Virginia',9307,57);
INSERT INTO "django_geo_db_city" VALUES(7670,'Looneyville','Looneyville, West Virginia',9308,57);
INSERT INTO "django_geo_db_city" VALUES(7671,'Mason','Mason, West Virginia',9309,57);
INSERT INTO "django_geo_db_city" VALUES(7672,'Millstone','Millstone, West Virginia',9310,57);
INSERT INTO "django_geo_db_city" VALUES(7673,'Millwood','Millwood, West Virginia',9311,57);
INSERT INTO "django_geo_db_city" VALUES(7674,'Mount Alto','Mount Alto, West Virginia',9312,57);
INSERT INTO "django_geo_db_city" VALUES(7675,'New Haven','New Haven, West Virginia',9313,57);
INSERT INTO "django_geo_db_city" VALUES(7676,'Newton','Newton, West Virginia',9314,57);
INSERT INTO "django_geo_db_city" VALUES(7677,'Normantown','Normantown, West Virginia',9315,57);
INSERT INTO "django_geo_db_city" VALUES(7678,'Orma','Orma, West Virginia',9316,57);
INSERT INTO "django_geo_db_city" VALUES(7679,'Reedy','Reedy, West Virginia',9317,57);
INSERT INTO "django_geo_db_city" VALUES(7680,'Ripley','Ripley, West Virginia',9318,57);
INSERT INTO "django_geo_db_city" VALUES(7681,'Sandyville','Sandyville, West Virginia',9319,57);
INSERT INTO "django_geo_db_city" VALUES(7682,'Spencer','Spencer, West Virginia',9320,57);
INSERT INTO "django_geo_db_city" VALUES(7683,'Statts Mills','Statts Mills, West Virginia',9321,57);
INSERT INTO "django_geo_db_city" VALUES(7684,'Tariff','Tariff, West Virginia',9322,57);
INSERT INTO "django_geo_db_city" VALUES(7685,'Valley Fork','Valley Fork, West Virginia',9323,57);
INSERT INTO "django_geo_db_city" VALUES(7686,'Wallback','Wallback, West Virginia',9324,57);
INSERT INTO "django_geo_db_city" VALUES(7687,'Walton','Walton, West Virginia',9325,57);
INSERT INTO "django_geo_db_city" VALUES(7688,'West Columbia','West Columbia, West Virginia',9326,57);
INSERT INTO "django_geo_db_city" VALUES(7689,'Charleston','Charleston, West Virginia',9327,57);
INSERT INTO "django_geo_db_city" VALUES(7690,'Martinsburg','Martinsburg, West Virginia',9343,57);
INSERT INTO "django_geo_db_city" VALUES(7691,'Bakerton','Bakerton, West Virginia',9345,57);
INSERT INTO "django_geo_db_city" VALUES(7692,'Berkeley Springs','Berkeley Springs, West Virginia',9346,57);
INSERT INTO "django_geo_db_city" VALUES(7693,'Bunker Hill','Bunker Hill, West Virginia',9347,57);
INSERT INTO "django_geo_db_city" VALUES(7694,'Charles Town','Charles Town, West Virginia',9348,57);
INSERT INTO "django_geo_db_city" VALUES(7695,'Falling Waters','Falling Waters, West Virginia',9349,57);
INSERT INTO "django_geo_db_city" VALUES(7696,'Gerrardstown','Gerrardstown, West Virginia',9350,57);
INSERT INTO "django_geo_db_city" VALUES(7697,'Glengary','Glengary, West Virginia',9351,57);
INSERT INTO "django_geo_db_city" VALUES(7698,'Great Cacapon','Great Cacapon, West Virginia',9352,57);
INSERT INTO "django_geo_db_city" VALUES(7699,'Halltown','Halltown, West Virginia',9345,57);
INSERT INTO "django_geo_db_city" VALUES(7700,'Harpers Ferry','Harpers Ferry, West Virginia',9353,57);
INSERT INTO "django_geo_db_city" VALUES(7701,'Hedgesville','Hedgesville, West Virginia',9354,57);
INSERT INTO "django_geo_db_city" VALUES(7702,'Inwood','Inwood, West Virginia',9355,57);
INSERT INTO "django_geo_db_city" VALUES(7703,'Kearneysville','Kearneysville, West Virginia',9356,57);
INSERT INTO "django_geo_db_city" VALUES(7704,'Levels','Levels, West Virginia',9358,57);
INSERT INTO "django_geo_db_city" VALUES(7705,'Millville','Millville, West Virginia',9345,57);
INSERT INTO "django_geo_db_city" VALUES(7706,'Paw Paw','Paw Paw, West Virginia',9359,57);
INSERT INTO "django_geo_db_city" VALUES(7707,'Points','Points, West Virginia',9360,57);
INSERT INTO "django_geo_db_city" VALUES(7708,'Ranson','Ranson, West Virginia',9361,57);
INSERT INTO "django_geo_db_city" VALUES(7709,'Ridgeway','Ridgeway, West Virginia',9362,57);
INSERT INTO "django_geo_db_city" VALUES(7710,'Rippon','Rippon, West Virginia',9363,57);
INSERT INTO "django_geo_db_city" VALUES(7711,'Shenandoah Junction','Shenandoah Junction, West Virginia',9364,57);
INSERT INTO "django_geo_db_city" VALUES(7712,'Shepherdstown','Shepherdstown, West Virginia',9365,57);
INSERT INTO "django_geo_db_city" VALUES(7713,'Slanesville','Slanesville, West Virginia',9366,57);
INSERT INTO "django_geo_db_city" VALUES(7714,'Summit Point','Summit Point, West Virginia',9367,57);
INSERT INTO "django_geo_db_city" VALUES(7715,'Alkol','Alkol, West Virginia',9368,57);
INSERT INTO "django_geo_db_city" VALUES(7716,'Apple Grove','Apple Grove, West Virginia',9369,57);
INSERT INTO "django_geo_db_city" VALUES(7717,'Ashton','Ashton, West Virginia',9370,57);
INSERT INTO "django_geo_db_city" VALUES(7718,'Barboursville','Barboursville, West Virginia',9371,57);
INSERT INTO "django_geo_db_city" VALUES(7719,'Big Creek','Big Creek, West Virginia',9372,57);
INSERT INTO "django_geo_db_city" VALUES(7720,'Branchland','Branchland, West Virginia',9373,57);
INSERT INTO "django_geo_db_city" VALUES(7721,'Ceredo','Ceredo, West Virginia',9374,57);
INSERT INTO "django_geo_db_city" VALUES(7722,'Chapmanville','Chapmanville, West Virginia',9375,57);
INSERT INTO "django_geo_db_city" VALUES(7723,'Culloden','Culloden, West Virginia',9376,57);
INSERT INTO "django_geo_db_city" VALUES(7724,'Dunlow','Dunlow, West Virginia',9377,57);
INSERT INTO "django_geo_db_city" VALUES(7725,'East Lynn','East Lynn, West Virginia',9378,57);
INSERT INTO "django_geo_db_city" VALUES(7726,'Fort Gay','Fort Gay, West Virginia',9379,57);
INSERT INTO "django_geo_db_city" VALUES(7727,'Gallipolis Ferry','Gallipolis Ferry, West Virginia',9380,57);
INSERT INTO "django_geo_db_city" VALUES(7728,'Genoa','Genoa, West Virginia',9381,57);
INSERT INTO "django_geo_db_city" VALUES(7729,'Glenhayes','Glenhayes, West Virginia',9382,57);
INSERT INTO "django_geo_db_city" VALUES(7730,'Glenwood','Glenwood, West Virginia',9383,57);
INSERT INTO "django_geo_db_city" VALUES(7731,'Griffithsville','Griffithsville, West Virginia',9384,57);
INSERT INTO "django_geo_db_city" VALUES(7732,'Hamlin','Hamlin, West Virginia',9385,57);
INSERT INTO "django_geo_db_city" VALUES(7733,'Harts','Harts, West Virginia',9386,57);
INSERT INTO "django_geo_db_city" VALUES(7734,'Hurricane','Hurricane, West Virginia',9387,57);
INSERT INTO "django_geo_db_city" VALUES(7735,'Julian','Julian, West Virginia',9388,57);
INSERT INTO "django_geo_db_city" VALUES(7736,'Kenova','Kenova, West Virginia',9389,57);
INSERT INTO "django_geo_db_city" VALUES(7737,'Kiahsville','Kiahsville, West Virginia',9390,57);
INSERT INTO "django_geo_db_city" VALUES(7738,'Lavalette','Lavalette, West Virginia',9391,57);
INSERT INTO "django_geo_db_city" VALUES(7739,'Lesage','Lesage, West Virginia',9392,57);
INSERT INTO "django_geo_db_city" VALUES(7740,'Midkiff','Midkiff, West Virginia',9393,57);
INSERT INTO "django_geo_db_city" VALUES(7741,'Milton','Milton, West Virginia',9394,57);
INSERT INTO "django_geo_db_city" VALUES(7742,'Myra','Myra, West Virginia',9396,57);
INSERT INTO "django_geo_db_city" VALUES(7743,'Ona','Ona, West Virginia',9397,57);
INSERT INTO "django_geo_db_city" VALUES(7744,'Pecks Mill','Pecks Mill, West Virginia',9398,57);
INSERT INTO "django_geo_db_city" VALUES(7745,'Point Pleasant','Point Pleasant, West Virginia',9399,57);
INSERT INTO "django_geo_db_city" VALUES(7746,'Prichard','Prichard, West Virginia',9400,57);
INSERT INTO "django_geo_db_city" VALUES(7747,'Ranger','Ranger, West Virginia',9401,57);
INSERT INTO "django_geo_db_city" VALUES(7748,'Salt Rock','Salt Rock, West Virginia',9402,57);
INSERT INTO "django_geo_db_city" VALUES(7749,'Scott Depot','Scott Depot, West Virginia',9403,57);
INSERT INTO "django_geo_db_city" VALUES(7750,'Shoals','Shoals, West Virginia',9404,57);
INSERT INTO "django_geo_db_city" VALUES(7751,'Sod','Sod, West Virginia',9405,57);
INSERT INTO "django_geo_db_city" VALUES(7752,'Spurlockville','Spurlockville, West Virginia',9406,57);
INSERT INTO "django_geo_db_city" VALUES(7753,'Sumerco','Sumerco, West Virginia',9407,57);
INSERT INTO "django_geo_db_city" VALUES(7754,'Teays','Teays, West Virginia',9408,57);
INSERT INTO "django_geo_db_city" VALUES(7755,'Wayne','Wayne, West Virginia',9409,57);
INSERT INTO "django_geo_db_city" VALUES(7756,'West Hamlin','West Hamlin, West Virginia',9410,57);
INSERT INTO "django_geo_db_city" VALUES(7757,'Woodville','Woodville, West Virginia',9411,57);
INSERT INTO "django_geo_db_city" VALUES(7758,'Yawkey','Yawkey, West Virginia',9412,57);
INSERT INTO "django_geo_db_city" VALUES(7759,'Logan','Logan, West Virginia',9413,57);
INSERT INTO "django_geo_db_city" VALUES(7760,'Accoville','Accoville, West Virginia',9414,57);
INSERT INTO "django_geo_db_city" VALUES(7761,'Amherstdale','Amherstdale, West Virginia',9415,57);
INSERT INTO "django_geo_db_city" VALUES(7762,'Baisden','Baisden, West Virginia',9416,57);
INSERT INTO "django_geo_db_city" VALUES(7763,'Bruno','Bruno, West Virginia',9417,57);
INSERT INTO "django_geo_db_city" VALUES(7764,'Chauncey','Chauncey, West Virginia',9418,57);
INSERT INTO "django_geo_db_city" VALUES(7765,'Cora','Cora, West Virginia',9419,57);
INSERT INTO "django_geo_db_city" VALUES(7766,'Davin','Davin, West Virginia',9420,57);
INSERT INTO "django_geo_db_city" VALUES(7767,'Gilbert','Gilbert, West Virginia',9421,57);
INSERT INTO "django_geo_db_city" VALUES(7768,'Hampden','Hampden, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7769,'Henlawson','Henlawson, West Virginia',9423,57);
INSERT INTO "django_geo_db_city" VALUES(7770,'Holden','Holden, West Virginia',9424,57);
INSERT INTO "django_geo_db_city" VALUES(7771,'Kistler','Kistler, West Virginia',9425,57);
INSERT INTO "django_geo_db_city" VALUES(7772,'Lorado','Lorado, West Virginia',9426,57);
INSERT INTO "django_geo_db_city" VALUES(7773,'Amherstdale-Robinette','Amherstdale-Robinette, West Virginia',9427,57);
INSERT INTO "django_geo_db_city" VALUES(7774,'Lyburn','Lyburn, West Virginia',9428,57);
INSERT INTO "django_geo_db_city" VALUES(7775,'Mallory','Mallory, West Virginia',9429,57);
INSERT INTO "django_geo_db_city" VALUES(7776,'Man','Man, West Virginia',9430,57);
INSERT INTO "django_geo_db_city" VALUES(7777,'Monaville','Monaville, West Virginia',9431,57);
INSERT INTO "django_geo_db_city" VALUES(7778,'Mount Gay','Mount Gay, West Virginia',9432,57);
INSERT INTO "django_geo_db_city" VALUES(7779,'Omar','Omar, West Virginia',9433,57);
INSERT INTO "django_geo_db_city" VALUES(7780,'Peach Creek','Peach Creek, West Virginia',9434,57);
INSERT INTO "django_geo_db_city" VALUES(7781,'Sarah Ann','Sarah Ann, West Virginia',9435,57);
INSERT INTO "django_geo_db_city" VALUES(7782,'Stirrat','Stirrat, West Virginia',9419,57);
INSERT INTO "django_geo_db_city" VALUES(7783,'Stollings','Stollings, West Virginia',9436,57);
INSERT INTO "django_geo_db_city" VALUES(7784,'Switzer','Switzer, West Virginia',9437,57);
INSERT INTO "django_geo_db_city" VALUES(7785,'Verdunville','Verdunville, West Virginia',9438,57);
INSERT INTO "django_geo_db_city" VALUES(7786,'Verner','Verner, West Virginia',9439,57);
INSERT INTO "django_geo_db_city" VALUES(7787,'Wharncliffe','Wharncliffe, West Virginia',9440,57);
INSERT INTO "django_geo_db_city" VALUES(7788,'Whitman','Whitman, West Virginia',9441,57);
INSERT INTO "django_geo_db_city" VALUES(7789,'Wilkinson','Wilkinson, West Virginia',9442,57);
INSERT INTO "django_geo_db_city" VALUES(7790,'Yolyn','Yolyn, West Virginia',9443,57);
INSERT INTO "django_geo_db_city" VALUES(7791,'Williamson','Williamson, West Virginia',9444,57);
INSERT INTO "django_geo_db_city" VALUES(7792,'Borderland','Borderland, West Virginia',9445,57);
INSERT INTO "django_geo_db_city" VALUES(7793,'Breeden','Breeden, West Virginia',9446,57);
INSERT INTO "django_geo_db_city" VALUES(7794,'Chattaroy','Chattaroy, West Virginia',9447,57);
INSERT INTO "django_geo_db_city" VALUES(7795,'Crum','Crum, West Virginia',9448,57);
INSERT INTO "django_geo_db_city" VALUES(7796,'Delbarton','Delbarton, West Virginia',9449,57);
INSERT INTO "django_geo_db_city" VALUES(7797,'Dingess','Dingess, West Virginia',9450,57);
INSERT INTO "django_geo_db_city" VALUES(7798,'Edgarton','Edgarton, West Virginia',9451,57);
INSERT INTO "django_geo_db_city" VALUES(7799,'Kermit','Kermit, West Virginia',9452,57);
INSERT INTO "django_geo_db_city" VALUES(7800,'Lenore','Lenore, West Virginia',9453,57);
INSERT INTO "django_geo_db_city" VALUES(7801,'Matewan','Matewan, West Virginia',9454,57);
INSERT INTO "django_geo_db_city" VALUES(7802,'Meador','Meador, West Virginia',9455,57);
INSERT INTO "django_geo_db_city" VALUES(7803,'Naugatuck','Naugatuck, West Virginia',9456,57);
INSERT INTO "django_geo_db_city" VALUES(7804,'Newtown','Newtown, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7805,'Nolan','Nolan, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7806,'North Matewan','North Matewan, West Virginia',9457,57);
INSERT INTO "django_geo_db_city" VALUES(7807,'Ragland','Ragland, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7808,'Rawl','Rawl, West Virginia',9458,57);
INSERT INTO "django_geo_db_city" VALUES(7809,'Red Jacket','Red Jacket, West Virginia',9459,57);
INSERT INTO "django_geo_db_city" VALUES(7810,'Thacker','Thacker, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7811,'Varney','Varney, West Virginia',9460,57);
INSERT INTO "django_geo_db_city" VALUES(7812,'Vulcan','Vulcan, West Virginia',9422,57);
INSERT INTO "django_geo_db_city" VALUES(7813,'Wilsondale','Wilsondale, West Virginia',9461,57);
INSERT INTO "django_geo_db_city" VALUES(7814,'Huntington','Huntington, West Virginia',9462,57);
INSERT INTO "django_geo_db_city" VALUES(7815,'Beckley','Beckley, West Virginia',9469,57);
INSERT INTO "django_geo_db_city" VALUES(7816,'Allen Junction','Allen Junction, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7817,'Amigo','Amigo, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7818,'Ansted','Ansted, West Virginia',9471,57);
INSERT INTO "django_geo_db_city" VALUES(7819,'Beaver','Beaver, West Virginia',9472,57);
INSERT INTO "django_geo_db_city" VALUES(7820,'Blue Jay','Blue Jay, West Virginia',9473,57);
INSERT INTO "django_geo_db_city" VALUES(7821,'Bolt','Bolt, West Virginia',9474,57);
INSERT INTO "django_geo_db_city" VALUES(7822,'Bradley','Bradley, West Virginia',9475,57);
INSERT INTO "django_geo_db_city" VALUES(7823,'Camp Creek','Camp Creek, West Virginia',9476,57);
INSERT INTO "django_geo_db_city" VALUES(7824,'Coal City','Coal City, West Virginia',9477,57);
INSERT INTO "django_geo_db_city" VALUES(7825,'Cool Ridge','Cool Ridge, West Virginia',9478,57);
INSERT INTO "django_geo_db_city" VALUES(7826,'Corinne','Corinne, West Virginia',9479,57);
INSERT INTO "django_geo_db_city" VALUES(7827,'Crab Orchard','Crab Orchard, West Virginia',9480,57);
INSERT INTO "django_geo_db_city" VALUES(7828,'Danese','Danese, West Virginia',9481,57);
INSERT INTO "django_geo_db_city" VALUES(7829,'Daniels','Daniels, West Virginia',9482,57);
INSERT INTO "django_geo_db_city" VALUES(7830,'Dothan','Dothan, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7831,'Eccles','Eccles, West Virginia',9483,57);
INSERT INTO "django_geo_db_city" VALUES(7832,'Edmond','Edmond, West Virginia',9484,57);
INSERT INTO "django_geo_db_city" VALUES(7833,'Fairdale','Fairdale, West Virginia',9485,57);
INSERT INTO "django_geo_db_city" VALUES(7834,'Fayetteville','Fayetteville, West Virginia',9486,57);
INSERT INTO "django_geo_db_city" VALUES(7835,'Flat Top','Flat Top, West Virginia',9487,57);
INSERT INTO "django_geo_db_city" VALUES(7836,'Ghent','Ghent, West Virginia',9488,57);
INSERT INTO "django_geo_db_city" VALUES(7837,'Glen Daniel','Glen Daniel, West Virginia',9489,57);
INSERT INTO "django_geo_db_city" VALUES(7838,'Glen Fork','Glen Fork, West Virginia',9490,57);
INSERT INTO "django_geo_db_city" VALUES(7839,'Glen Jean','Glen Jean, West Virginia',9491,57);
INSERT INTO "django_geo_db_city" VALUES(7840,'Glen Morgan','Glen Morgan, West Virginia',9492,57);
INSERT INTO "django_geo_db_city" VALUES(7841,'Glen Rogers','Glen Rogers, West Virginia',9493,57);
INSERT INTO "django_geo_db_city" VALUES(7842,'Glen White','Glen White, West Virginia',9494,57);
INSERT INTO "django_geo_db_city" VALUES(7843,'Harper','Harper, West Virginia',9495,57);
INSERT INTO "django_geo_db_city" VALUES(7844,'Helen','Helen, West Virginia',9496,57);
INSERT INTO "django_geo_db_city" VALUES(7845,'Hico','Hico, West Virginia',9497,57);
INSERT INTO "django_geo_db_city" VALUES(7846,'Hilltop','Hilltop, West Virginia',9498,57);
INSERT INTO "django_geo_db_city" VALUES(7847,'Jonben','Jonben, West Virginia',9499,57);
INSERT INTO "django_geo_db_city" VALUES(7848,'Josephine','Josephine, West Virginia',9500,57);
INSERT INTO "django_geo_db_city" VALUES(7849,'Kilsyth','Kilsyth, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7850,'Lanark','Lanark, West Virginia',9470,57);
INSERT INTO "django_geo_db_city" VALUES(7851,'Lansing','Lansing, West Virginia',9501,57);
INSERT INTO "django_geo_db_city" VALUES(7852,'Layland','Layland, West Virginia',9502,57);
INSERT INTO "django_geo_db_city" VALUES(7853,'Lester','Lester, West Virginia',9503,57);
INSERT INTO "django_geo_db_city" VALUES(7854,'Lochgelly','Lochgelly, West Virginia',9504,57);
INSERT INTO "django_geo_db_city" VALUES(7855,'Lookout','Lookout, West Virginia',9505,57);
INSERT INTO "django_geo_db_city" VALUES(7856,'Maben','Maben, West Virginia',9506,57);
INSERT INTO "django_geo_db_city" VALUES(7857,'Mabscott','Mabscott, West Virginia',9507,57);
INSERT INTO "django_geo_db_city" VALUES(7858,'Mac Arthur','Mac Arthur, West Virginia',9508,57);
INSERT INTO "django_geo_db_city" VALUES(7859,'McGraws','McGraws, West Virginia',9509,57);
INSERT INTO "django_geo_db_city" VALUES(7860,'Saulsville','Saulsville, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7861,'Midway','Midway, West Virginia',9510,57);
INSERT INTO "django_geo_db_city" VALUES(7862,'Minden','Minden, West Virginia',9511,57);
INSERT INTO "django_geo_db_city" VALUES(7863,'Mount Hope','Mount Hope, West Virginia',9512,57);
INSERT INTO "django_geo_db_city" VALUES(7864,'Mullens','Mullens, West Virginia',9513,57);
INSERT INTO "django_geo_db_city" VALUES(7865,'Shady Spring','Shady Spring, West Virginia',9514,57);
INSERT INTO "django_geo_db_city" VALUES(7866,'Oak Hill','Oak Hill, West Virginia',9515,57);
INSERT INTO "django_geo_db_city" VALUES(7867,'Odd','Odd, West Virginia',9516,57);
INSERT INTO "django_geo_db_city" VALUES(7868,'Pax','Pax, West Virginia',9517,57);
INSERT INTO "django_geo_db_city" VALUES(7869,'Piney View','Piney View, West Virginia',9518,57);
INSERT INTO "django_geo_db_city" VALUES(7870,'Prince','Prince, West Virginia',9519,57);
INSERT INTO "django_geo_db_city" VALUES(7871,'Princewick','Princewick, West Virginia',9520,57);
INSERT INTO "django_geo_db_city" VALUES(7872,'Prosperity','Prosperity, West Virginia',9521,57);
INSERT INTO "django_geo_db_city" VALUES(7873,'Raleigh','Raleigh, West Virginia',9522,57);
INSERT INTO "django_geo_db_city" VALUES(7874,'Ramsey','Ramsey, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7875,'Ravencliff','Ravencliff, West Virginia',9523,57);
INSERT INTO "django_geo_db_city" VALUES(7876,'Redstar','Redstar, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7877,'Rhodell','Rhodell, West Virginia',9524,57);
INSERT INTO "django_geo_db_city" VALUES(7878,'Sabine','Sabine, West Virginia',9525,57);
INSERT INTO "django_geo_db_city" VALUES(7879,'Scarbro','Scarbro, West Virginia',9526,57);
INSERT INTO "django_geo_db_city" VALUES(7880,'Skelton','Skelton, West Virginia',9528,57);
INSERT INTO "django_geo_db_city" VALUES(7881,'Slab Fork','Slab Fork, West Virginia',9529,57);
INSERT INTO "django_geo_db_city" VALUES(7882,'Sophia','Sophia, West Virginia',9530,57);
INSERT INTO "django_geo_db_city" VALUES(7883,'Spanishburg','Spanishburg, West Virginia',9531,57);
INSERT INTO "django_geo_db_city" VALUES(7884,'Sprague','Sprague, West Virginia',9532,57);
INSERT INTO "django_geo_db_city" VALUES(7885,'Stanaford','Stanaford, West Virginia',9470,57);
INSERT INTO "django_geo_db_city" VALUES(7886,'Stephenson','Stephenson, West Virginia',9533,57);
INSERT INTO "django_geo_db_city" VALUES(7887,'Summerlee','Summerlee, West Virginia',9280,57);
INSERT INTO "django_geo_db_city" VALUES(7888,'Surveyor','Surveyor, West Virginia',9534,57);
INSERT INTO "django_geo_db_city" VALUES(7889,'Terry','Terry, West Virginia',9535,57);
INSERT INTO "django_geo_db_city" VALUES(7890,'Thurmond','Thurmond, West Virginia',9536,57);
INSERT INTO "django_geo_db_city" VALUES(7891,'Victor','Victor, West Virginia',9537,57);
INSERT INTO "django_geo_db_city" VALUES(7892,'Winona','Winona, West Virginia',9538,57);
INSERT INTO "django_geo_db_city" VALUES(7893,'Wyco','Wyco, West Virginia',9091,57);
INSERT INTO "django_geo_db_city" VALUES(7894,'Hinton','Hinton, West Virginia',9539,57);
INSERT INTO "django_geo_db_city" VALUES(7895,'Charmco','Charmco, West Virginia',9540,57);
INSERT INTO "django_geo_db_city" VALUES(7896,'Crichton','Crichton, West Virginia',9139,57);
INSERT INTO "django_geo_db_city" VALUES(7897,'Rainelle','Rainelle, West Virginia',9541,57);
INSERT INTO "django_geo_db_city" VALUES(7898,'Elton','Elton, West Virginia',9542,57);
INSERT INTO "django_geo_db_city" VALUES(7899,'Green Sulphur Springs','Green Sulphur Springs, West Virginia',9543,57);
INSERT INTO "django_geo_db_city" VALUES(7900,'Hines','Hines, West Virginia',9139,57);
INSERT INTO "django_geo_db_city" VALUES(7901,'Jumping Branch','Jumping Branch, West Virginia',9544,57);
INSERT INTO "django_geo_db_city" VALUES(7902,'Lerona','Lerona, West Virginia',9545,57);
INSERT INTO "django_geo_db_city" VALUES(7903,'Leslie','Leslie, West Virginia',9546,57);
INSERT INTO "django_geo_db_city" VALUES(7904,'Meadow Bridge','Meadow Bridge, West Virginia',9547,57);
INSERT INTO "django_geo_db_city" VALUES(7905,'Meadow Creek','Meadow Creek, West Virginia',9548,57);
INSERT INTO "django_geo_db_city" VALUES(7906,'Nimitz','Nimitz, West Virginia',9549,57);
INSERT INTO "django_geo_db_city" VALUES(7907,'Pipestem','Pipestem, West Virginia',9550,57);
INSERT INTO "django_geo_db_city" VALUES(7908,'Quinwood','Quinwood, West Virginia',9551,57);
INSERT INTO "django_geo_db_city" VALUES(7909,'Rupert','Rupert, West Virginia',9552,57);
INSERT INTO "django_geo_db_city" VALUES(7910,'Sandstone','Sandstone, West Virginia',9553,57);
INSERT INTO "django_geo_db_city" VALUES(7911,'Spring Dale','Spring Dale, West Virginia',9554,57);
INSERT INTO "django_geo_db_city" VALUES(7912,'True','True, West Virginia',9542,57);
INSERT INTO "django_geo_db_city" VALUES(7913,'White Oak','White Oak, West Virginia',9555,57);
INSERT INTO "django_geo_db_city" VALUES(7914,'Wheeling','Wheeling, West Virginia',9556,57);
INSERT INTO "django_geo_db_city" VALUES(7915,'Beech Bottom','Beech Bottom, West Virginia',9557,57);
INSERT INTO "django_geo_db_city" VALUES(7916,'Benwood','Benwood, West Virginia',9558,57);
INSERT INTO "django_geo_db_city" VALUES(7917,'Bethany','Bethany, West Virginia',9559,57);
INSERT INTO "django_geo_db_city" VALUES(7918,'Cameron','Cameron, West Virginia',9560,57);
INSERT INTO "django_geo_db_city" VALUES(7919,'Chester','Chester, West Virginia',9561,57);
INSERT INTO "django_geo_db_city" VALUES(7920,'Colliers','Colliers, West Virginia',9562,57);
INSERT INTO "django_geo_db_city" VALUES(7921,'Dallas','Dallas, West Virginia',9563,57);
INSERT INTO "django_geo_db_city" VALUES(7922,'Follansbee','Follansbee, West Virginia',9564,57);
INSERT INTO "django_geo_db_city" VALUES(7923,'Glen Dale','Glen Dale, West Virginia',9565,57);
INSERT INTO "django_geo_db_city" VALUES(7924,'Glen Easton','Glen Easton, West Virginia',9566,57);
INSERT INTO "django_geo_db_city" VALUES(7925,'McMechen','McMechen, West Virginia',9567,57);
INSERT INTO "django_geo_db_city" VALUES(7926,'Moundsville','Moundsville, West Virginia',9568,57);
INSERT INTO "django_geo_db_city" VALUES(7927,'New Cumberland','New Cumberland, West Virginia',9569,57);
INSERT INTO "django_geo_db_city" VALUES(7928,'Newell','Newell, West Virginia',9570,57);
INSERT INTO "django_geo_db_city" VALUES(7929,'Proctor','Proctor, West Virginia',9571,57);
INSERT INTO "django_geo_db_city" VALUES(7930,'New Manchester','New Manchester, West Virginia',9572,57);
INSERT INTO "django_geo_db_city" VALUES(7931,'Short Creek','Short Creek, West Virginia',9573,57);
INSERT INTO "django_geo_db_city" VALUES(7932,'Triadelphia','Triadelphia, West Virginia',9574,57);
INSERT INTO "django_geo_db_city" VALUES(7933,'Valley Grove','Valley Grove, West Virginia',9575,57);
INSERT INTO "django_geo_db_city" VALUES(7934,'Weirton','Weirton, West Virginia',9576,57);
INSERT INTO "django_geo_db_city" VALUES(7935,'Wellsburg','Wellsburg, West Virginia',9577,57);
INSERT INTO "django_geo_db_city" VALUES(7936,'West Liberty','West Liberty, West Virginia',9578,57);
INSERT INTO "django_geo_db_city" VALUES(7937,'Windsor Heights','Windsor Heights, West Virginia',9579,57);
INSERT INTO "django_geo_db_city" VALUES(7938,'Parkersburg','Parkersburg, West Virginia',9580,57);
INSERT INTO "django_geo_db_city" VALUES(7939,'Vienna','Vienna, West Virginia',9584,57);
INSERT INTO "django_geo_db_city" VALUES(7940,'Mineral Wells','Mineral Wells, West Virginia',9581,57);
INSERT INTO "django_geo_db_city" VALUES(7941,'Belleville','Belleville, West Virginia',9585,57);
INSERT INTO "django_geo_db_city" VALUES(7942,'Belmont','Belmont, West Virginia',9586,57);
INSERT INTO "django_geo_db_city" VALUES(7943,'Bens Run','Bens Run, West Virginia',9587,57);
INSERT INTO "django_geo_db_city" VALUES(7944,'Big Bend','Big Bend, West Virginia',9588,57);
INSERT INTO "django_geo_db_city" VALUES(7945,'Big Springs','Big Springs, West Virginia',9589,57);
INSERT INTO "django_geo_db_city" VALUES(7946,'Brohard','Brohard, West Virginia',9590,57);
INSERT INTO "django_geo_db_city" VALUES(7947,'Creston','Creston, West Virginia',9591,57);
INSERT INTO "django_geo_db_city" VALUES(7948,'Davisville','Davisville, West Virginia',9592,57);
INSERT INTO "django_geo_db_city" VALUES(7949,'Elizabeth','Elizabeth, West Virginia',9593,57);
INSERT INTO "django_geo_db_city" VALUES(7950,'Pennsboro','Pennsboro, West Virginia',9594,57);
INSERT INTO "django_geo_db_city" VALUES(7951,'Friendly','Friendly, West Virginia',9595,57);
INSERT INTO "django_geo_db_city" VALUES(7952,'Grantsville','Grantsville, West Virginia',9596,57);
INSERT INTO "django_geo_db_city" VALUES(7953,'Macfarlan','Macfarlan, West Virginia',9597,57);
INSERT INTO "django_geo_db_city" VALUES(7954,'Middlebourne','Middlebourne, West Virginia',9598,57);
INSERT INTO "django_geo_db_city" VALUES(7955,'Mount Zion','Mount Zion, West Virginia',9600,57);
INSERT INTO "django_geo_db_city" VALUES(7956,'Munday','Munday, West Virginia',9601,57);
INSERT INTO "django_geo_db_city" VALUES(7957,'New Martinsville','New Martinsville, West Virginia',9602,57);
INSERT INTO "django_geo_db_city" VALUES(7958,'Paden City','Paden City, West Virginia',9603,57);
INSERT INTO "django_geo_db_city" VALUES(7959,'Palestine','Palestine, West Virginia',9604,57);
INSERT INTO "django_geo_db_city" VALUES(7960,'Petroleum','Petroleum, West Virginia',9605,57);
INSERT INTO "django_geo_db_city" VALUES(7961,'Porters Falls','Porters Falls, West Virginia',9606,57);
INSERT INTO "django_geo_db_city" VALUES(7962,'Ravenswood','Ravenswood, West Virginia',9607,57);
INSERT INTO "django_geo_db_city" VALUES(7963,'Reader','Reader, West Virginia',9608,57);
INSERT INTO "django_geo_db_city" VALUES(7964,'Rockport','Rockport, West Virginia',9609,57);
INSERT INTO "django_geo_db_city" VALUES(7965,'Saint Marys','Saint Marys, West Virginia',9610,57);
INSERT INTO "django_geo_db_city" VALUES(7966,'Sherman','Sherman, West Virginia',9611,57);
INSERT INTO "django_geo_db_city" VALUES(7967,'Sistersville','Sistersville, West Virginia',9612,57);
INSERT INTO "django_geo_db_city" VALUES(7968,'Smithville','Smithville, West Virginia',9613,57);
INSERT INTO "django_geo_db_city" VALUES(7969,'Walker','Walker, West Virginia',9614,57);
INSERT INTO "django_geo_db_city" VALUES(7970,'Washington','Washington, West Virginia',9615,57);
INSERT INTO "django_geo_db_city" VALUES(7971,'Waverly','Waverly, West Virginia',9616,57);
INSERT INTO "django_geo_db_city" VALUES(7972,'Wileyville','Wileyville, West Virginia',9617,57);
INSERT INTO "django_geo_db_city" VALUES(7973,'Williamstown','Williamstown, West Virginia',9618,57);
INSERT INTO "django_geo_db_city" VALUES(7974,'Buckhannon','Buckhannon, West Virginia',9619,57);
INSERT INTO "django_geo_db_city" VALUES(7975,'Fenwick','Fenwick, West Virginia',9620,57);
INSERT INTO "django_geo_db_city" VALUES(7976,'Erbacon','Erbacon, West Virginia',9621,57);
INSERT INTO "django_geo_db_city" VALUES(7977,'Craigsville','Craigsville, West Virginia',9622,57);
INSERT INTO "django_geo_db_city" VALUES(7978,'Cowen','Cowen, West Virginia',9623,57);
INSERT INTO "django_geo_db_city" VALUES(7979,'Camden On Gauley','Camden On Gauley, West Virginia',9624,57);
INSERT INTO "django_geo_db_city" VALUES(7980,'Snowshoe','Snowshoe, West Virginia',9625,57);
INSERT INTO "django_geo_db_city" VALUES(7981,'Adrian','Adrian, West Virginia',9626,57);
INSERT INTO "django_geo_db_city" VALUES(7982,'Cleveland','Cleveland, West Virginia',9627,57);
INSERT INTO "django_geo_db_city" VALUES(7983,'Diana','Diana, West Virginia',9628,57);
INSERT INTO "django_geo_db_city" VALUES(7984,'French Creek','French Creek, West Virginia',9629,57);
INSERT INTO "django_geo_db_city" VALUES(7985,'Frenchton','Frenchton, West Virginia',9630,57);
INSERT INTO "django_geo_db_city" VALUES(7986,'Hacker Valley','Hacker Valley, West Virginia',9631,57);
INSERT INTO "django_geo_db_city" VALUES(7987,'Helvetia','Helvetia, West Virginia',9632,57);
INSERT INTO "django_geo_db_city" VALUES(7988,'Kanawha Head','Kanawha Head, West Virginia',9633,57);
INSERT INTO "django_geo_db_city" VALUES(7989,'Lorentz','Lorentz, West Virginia',9630,57);
INSERT INTO "django_geo_db_city" VALUES(7990,'Pickens','Pickens, West Virginia',9634,57);
INSERT INTO "django_geo_db_city" VALUES(7991,'Rock Cave','Rock Cave, West Virginia',9635,57);
INSERT INTO "django_geo_db_city" VALUES(7992,'Selbyville','Selbyville, West Virginia',9636,57);
INSERT INTO "django_geo_db_city" VALUES(7993,'Tallmansville','Tallmansville, West Virginia',9637,57);
INSERT INTO "django_geo_db_city" VALUES(7994,'Volga','Volga, West Virginia',9638,57);
INSERT INTO "django_geo_db_city" VALUES(7995,'Elkins','Elkins, West Virginia',9639,57);
INSERT INTO "django_geo_db_city" VALUES(7996,'Belington','Belington, West Virginia',9640,57);
INSERT INTO "django_geo_db_city" VALUES(7997,'Beverly','Beverly, West Virginia',9641,57);
INSERT INTO "django_geo_db_city" VALUES(7998,'Bowden','Bowden, West Virginia',9642,57);
INSERT INTO "django_geo_db_city" VALUES(7999,'Coalton','Coalton, West Virginia',9643,57);
INSERT INTO "django_geo_db_city" VALUES(8000,'Dailey','Dailey, West Virginia',9644,57);
INSERT INTO "django_geo_db_city" VALUES(8001,'Davis','Davis, West Virginia',9645,57);
INSERT INTO "django_geo_db_city" VALUES(8002,'Richwood','Richwood, West Virginia',9646,57);
INSERT INTO "django_geo_db_city" VALUES(8003,'Dryfork','Dryfork, West Virginia',9647,57);
INSERT INTO "django_geo_db_city" VALUES(8004,'Durbin','Durbin, West Virginia',9648,57);
INSERT INTO "django_geo_db_city" VALUES(8005,'Upperglade','Upperglade, West Virginia',9649,57);
INSERT INTO "django_geo_db_city" VALUES(8006,'Ellamore','Ellamore, West Virginia',9650,57);
INSERT INTO "django_geo_db_city" VALUES(8007,'Glady','Glady, West Virginia',9651,57);
INSERT INTO "django_geo_db_city" VALUES(8008,'Hambleton','Hambleton, West Virginia',9652,57);
INSERT INTO "django_geo_db_city" VALUES(8009,'Harman','Harman, West Virginia',9653,57);
INSERT INTO "django_geo_db_city" VALUES(8010,'Hendricks','Hendricks, West Virginia',9654,57);
INSERT INTO "django_geo_db_city" VALUES(8011,'Huttonsville','Huttonsville, West Virginia',9655,57);
INSERT INTO "django_geo_db_city" VALUES(8012,'Junior','Junior, West Virginia',9656,57);
INSERT INTO "django_geo_db_city" VALUES(8013,'Kerens','Kerens, West Virginia',9657,57);
INSERT INTO "django_geo_db_city" VALUES(8014,'Mabie','Mabie, West Virginia',9658,57);
INSERT INTO "django_geo_db_city" VALUES(8015,'Mill Creek','Mill Creek, West Virginia',9659,57);
INSERT INTO "django_geo_db_city" VALUES(8016,'Monterville','Monterville, West Virginia',9660,57);
INSERT INTO "django_geo_db_city" VALUES(8017,'Montrose','Montrose, West Virginia',9661,57);
INSERT INTO "django_geo_db_city" VALUES(8018,'Norton','Norton, West Virginia',9662,57);
INSERT INTO "django_geo_db_city" VALUES(8019,'Parsons','Parsons, West Virginia',9663,57);
INSERT INTO "django_geo_db_city" VALUES(8020,'Webster Springs','Webster Springs, West Virginia',9664,57);
INSERT INTO "django_geo_db_city" VALUES(8021,'Red Creek','Red Creek, West Virginia',9665,57);
INSERT INTO "django_geo_db_city" VALUES(8022,'Slatyfork','Slatyfork, West Virginia',9666,57);
INSERT INTO "django_geo_db_city" VALUES(8023,'Thomas','Thomas, West Virginia',9667,57);
INSERT INTO "django_geo_db_city" VALUES(8024,'Valley Bend','Valley Bend, West Virginia',9668,57);
INSERT INTO "django_geo_db_city" VALUES(8025,'Valley Head','Valley Head, West Virginia',9669,57);
INSERT INTO "django_geo_db_city" VALUES(8026,'Whitmer','Whitmer, West Virginia',9670,57);
INSERT INTO "django_geo_db_city" VALUES(8027,'Bergoo','Bergoo, West Virginia',9671,57);
INSERT INTO "django_geo_db_city" VALUES(8028,'Clarksburg','Clarksburg, West Virginia',9672,57);
INSERT INTO "django_geo_db_city" VALUES(8029,'Alma','Alma, West Virginia',9675,57);
INSERT INTO "django_geo_db_city" VALUES(8030,'Alum Bridge','Alum Bridge, West Virginia',9676,57);
INSERT INTO "django_geo_db_city" VALUES(8031,'Anmoore','Anmoore, West Virginia',9677,57);
INSERT INTO "django_geo_db_city" VALUES(8032,'Auburn','Auburn, West Virginia',9678,57);
INSERT INTO "django_geo_db_city" VALUES(8033,'Berea','Berea, West Virginia',9679,57);
INSERT INTO "django_geo_db_city" VALUES(8034,'Blandville','Blandville, West Virginia',9680,57);
INSERT INTO "django_geo_db_city" VALUES(8035,'Bridgeport','Bridgeport, West Virginia',9681,57);
INSERT INTO "django_geo_db_city" VALUES(8036,'Bristol','Bristol, West Virginia',9682,57);
INSERT INTO "django_geo_db_city" VALUES(8037,'Burnsville','Burnsville, West Virginia',9683,57);
INSERT INTO "django_geo_db_city" VALUES(8038,'Brownton','Brownton, West Virginia',9684,57);
INSERT INTO "django_geo_db_city" VALUES(8039,'Cairo','Cairo, West Virginia',9686,57);
INSERT INTO "django_geo_db_city" VALUES(8040,'Camden','Camden, West Virginia',9687,57);
INSERT INTO "django_geo_db_city" VALUES(8041,'Center Point','Center Point, West Virginia',9688,57);
INSERT INTO "django_geo_db_city" VALUES(8042,'Coxs Mills','Coxs Mills, West Virginia',9689,57);
INSERT INTO "django_geo_db_city" VALUES(8043,'Crawford','Crawford, West Virginia',9690,57);
INSERT INTO "django_geo_db_city" VALUES(8044,'Ellenboro','Ellenboro, West Virginia',9691,57);
INSERT INTO "django_geo_db_city" VALUES(8045,'Flemington','Flemington, West Virginia',9692,57);
INSERT INTO "django_geo_db_city" VALUES(8046,'Folsom','Folsom, West Virginia',9693,57);
INSERT INTO "django_geo_db_city" VALUES(8047,'Galloway','Galloway, West Virginia',9694,57);
INSERT INTO "django_geo_db_city" VALUES(8048,'Gilmer','Gilmer, West Virginia',9307,57);
INSERT INTO "django_geo_db_city" VALUES(8049,'Glenville','Glenville, West Virginia',9695,57);
INSERT INTO "django_geo_db_city" VALUES(8050,'Grafton','Grafton, West Virginia',9696,57);
INSERT INTO "django_geo_db_city" VALUES(8051,'Gypsy','Gypsy, West Virginia',9697,57);
INSERT INTO "django_geo_db_city" VALUES(8052,'Harrisville','Harrisville, West Virginia',9698,57);
INSERT INTO "django_geo_db_city" VALUES(8053,'Haywood','Haywood, West Virginia',9699,57);
INSERT INTO "django_geo_db_city" VALUES(8054,'Hepzibah','Hepzibah, West Virginia',9700,57);
INSERT INTO "django_geo_db_city" VALUES(8055,'Horner','Horner, West Virginia',9701,57);
INSERT INTO "django_geo_db_city" VALUES(8056,'Independence','Independence, West Virginia',9702,57);
INSERT INTO "django_geo_db_city" VALUES(8057,'Industrial','Industrial, West Virginia',9703,57);
INSERT INTO "django_geo_db_city" VALUES(8058,'Ireland','Ireland, West Virginia',9704,57);
INSERT INTO "django_geo_db_city" VALUES(8059,'Jacksonburg','Jacksonburg, West Virginia',9705,57);
INSERT INTO "django_geo_db_city" VALUES(8060,'Jane Lew','Jane Lew, West Virginia',9706,57);
INSERT INTO "django_geo_db_city" VALUES(8061,'Linn','Linn, West Virginia',9707,57);
INSERT INTO "django_geo_db_city" VALUES(8062,'Lost Creek','Lost Creek, West Virginia',9708,57);
INSERT INTO "django_geo_db_city" VALUES(8063,'Lumberport','Lumberport, West Virginia',9709,57);
INSERT INTO "django_geo_db_city" VALUES(8064,'Meadowbrook','Meadowbrook, West Virginia',9710,57);
INSERT INTO "django_geo_db_city" VALUES(8065,'Moatsville','Moatsville, West Virginia',9711,57);
INSERT INTO "django_geo_db_city" VALUES(8066,'Mountain','Mountain, West Virginia',9712,57);
INSERT INTO "django_geo_db_city" VALUES(8067,'Mount Clare','Mount Clare, West Virginia',9713,57);
INSERT INTO "django_geo_db_city" VALUES(8068,'Newburg','Newburg, West Virginia',9714,57);
INSERT INTO "django_geo_db_city" VALUES(8069,'New Milton','New Milton, West Virginia',9715,57);
INSERT INTO "django_geo_db_city" VALUES(8070,'Orlando','Orlando, West Virginia',9716,57);
INSERT INTO "django_geo_db_city" VALUES(8071,'Philippi','Philippi, West Virginia',9718,57);
INSERT INTO "django_geo_db_city" VALUES(8072,'Pine Grove','Pine Grove, West Virginia',9719,57);
INSERT INTO "django_geo_db_city" VALUES(8073,'Pullman','Pullman, West Virginia',9720,57);
INSERT INTO "django_geo_db_city" VALUES(8074,'Reynoldsville','Reynoldsville, West Virginia',9721,57);
INSERT INTO "django_geo_db_city" VALUES(8075,'Rosemont','Rosemont, West Virginia',9722,57);
INSERT INTO "django_geo_db_city" VALUES(8076,'Rowlesburg','Rowlesburg, West Virginia',9723,57);
INSERT INTO "django_geo_db_city" VALUES(8077,'Salem','Salem, West Virginia',9724,57);
INSERT INTO "django_geo_db_city" VALUES(8078,'Sand Fork','Sand Fork, West Virginia',9725,57);
INSERT INTO "django_geo_db_city" VALUES(8079,'Shinnston','Shinnston, West Virginia',9726,57);
INSERT INTO "django_geo_db_city" VALUES(8080,'Shirley','Shirley, West Virginia',9587,57);
INSERT INTO "django_geo_db_city" VALUES(8081,'Simpson','Simpson, West Virginia',9727,57);
INSERT INTO "django_geo_db_city" VALUES(8082,'Smithburg','Smithburg, West Virginia',9728,57);
INSERT INTO "django_geo_db_city" VALUES(8083,'Smithfield','Smithfield, West Virginia',9729,57);
INSERT INTO "django_geo_db_city" VALUES(8084,'Spelter','Spelter, West Virginia',9730,57);
INSERT INTO "django_geo_db_city" VALUES(8085,'Thornton','Thornton, West Virginia',9731,57);
INSERT INTO "django_geo_db_city" VALUES(8086,'Troy','Troy, West Virginia',9732,57);
INSERT INTO "django_geo_db_city" VALUES(8087,'Tunnelton','Tunnelton, West Virginia',9733,57);
INSERT INTO "django_geo_db_city" VALUES(8088,'Walkersville','Walkersville, West Virginia',9734,57);
INSERT INTO "django_geo_db_city" VALUES(8089,'Wallace','Wallace, West Virginia',9735,57);
INSERT INTO "django_geo_db_city" VALUES(8090,'West Milford','West Milford, West Virginia',9736,57);
INSERT INTO "django_geo_db_city" VALUES(8091,'Weston','Weston, West Virginia',9737,57);
INSERT INTO "django_geo_db_city" VALUES(8092,'West Union','West Union, West Virginia',9738,57);
INSERT INTO "django_geo_db_city" VALUES(8093,'Wilsonburg','Wilsonburg, West Virginia',9674,57);
INSERT INTO "django_geo_db_city" VALUES(8094,'Wyatt','Wyatt, West Virginia',9740,57);
INSERT INTO "django_geo_db_city" VALUES(8095,'Morgantown','Morgantown, West Virginia',9741,57);
INSERT INTO "django_geo_db_city" VALUES(8096,'Albright','Albright, West Virginia',9749,57);
INSERT INTO "django_geo_db_city" VALUES(8097,'Arthurdale','Arthurdale, West Virginia',9750,57);
INSERT INTO "django_geo_db_city" VALUES(8098,'Blacksville','Blacksville, West Virginia',9751,57);
INSERT INTO "django_geo_db_city" VALUES(8099,'Booth','Booth, West Virginia',9744,57);
INSERT INTO "django_geo_db_city" VALUES(8100,'Bretz','Bretz, West Virginia',9752,57);
INSERT INTO "django_geo_db_city" VALUES(8101,'Bruceton Mills','Bruceton Mills, West Virginia',9753,57);
INSERT INTO "django_geo_db_city" VALUES(8102,'Cassville','Cassville, West Virginia',9744,57);
INSERT INTO "django_geo_db_city" VALUES(8103,'Core','Core, West Virginia',9754,57);
INSERT INTO "django_geo_db_city" VALUES(8104,'Dellslow','Dellslow, West Virginia',9755,57);
INSERT INTO "django_geo_db_city" VALUES(8105,'Everettville','Everettville, West Virginia',9744,57);
INSERT INTO "django_geo_db_city" VALUES(8106,'Granville','Granville, West Virginia',9756,57);
INSERT INTO "django_geo_db_city" VALUES(8107,'Hazelton','Hazelton, West Virginia',9752,57);
INSERT INTO "django_geo_db_city" VALUES(8108,'Kingwood','Kingwood, West Virginia',9757,57);
INSERT INTO "django_geo_db_city" VALUES(8109,'Maidsville','Maidsville, West Virginia',9758,57);
INSERT INTO "django_geo_db_city" VALUES(8110,'Masontown','Masontown, West Virginia',9759,57);
INSERT INTO "django_geo_db_city" VALUES(8111,'Osage','Osage, West Virginia',9760,57);
INSERT INTO "django_geo_db_city" VALUES(8112,'Pentress','Pentress, West Virginia',9761,57);
INSERT INTO "django_geo_db_city" VALUES(8113,'Pursglove','Pursglove, West Virginia',9762,57);
INSERT INTO "django_geo_db_city" VALUES(8114,'Reedsville','Reedsville, West Virginia',9763,57);
INSERT INTO "django_geo_db_city" VALUES(8115,'Fairmont','Fairmont, West Virginia',9764,57);
INSERT INTO "django_geo_db_city" VALUES(8116,'Barrackville','Barrackville, West Virginia',9766,57);
INSERT INTO "django_geo_db_city" VALUES(8117,'Baxter','Baxter, West Virginia',9765,57);
INSERT INTO "django_geo_db_city" VALUES(8118,'Big Run','Big Run, West Virginia',9767,57);
INSERT INTO "django_geo_db_city" VALUES(8119,'Burton','Burton, West Virginia',9768,57);
INSERT INTO "django_geo_db_city" VALUES(8120,'Carolina','Carolina, West Virginia',9769,57);
INSERT INTO "django_geo_db_city" VALUES(8121,'Colfax','Colfax, West Virginia',9765,57);
INSERT INTO "django_geo_db_city" VALUES(8122,'Enterprise','Enterprise, West Virginia',9770,57);
INSERT INTO "django_geo_db_city" VALUES(8123,'Fairview','Fairview, West Virginia',9771,57);
INSERT INTO "django_geo_db_city" VALUES(8124,'Farmington','Farmington, West Virginia',9772,57);
INSERT INTO "django_geo_db_city" VALUES(8125,'Four States','Four States, West Virginia',9773,57);
INSERT INTO "django_geo_db_city" VALUES(8126,'Grant Town','Grant Town, West Virginia',9774,57);
INSERT INTO "django_geo_db_city" VALUES(8127,'Hundred','Hundred, West Virginia',9775,57);
INSERT INTO "django_geo_db_city" VALUES(8128,'Idamay','Idamay, West Virginia',9776,57);
INSERT INTO "django_geo_db_city" VALUES(8129,'Kingmont','Kingmont, West Virginia',9777,57);
INSERT INTO "django_geo_db_city" VALUES(8130,'Littleton','Littleton, West Virginia',9778,57);
INSERT INTO "django_geo_db_city" VALUES(8131,'Mannington','Mannington, West Virginia',9779,57);
INSERT INTO "django_geo_db_city" VALUES(8132,'Metz','Metz, West Virginia',9780,57);
INSERT INTO "django_geo_db_city" VALUES(8133,'Montana Mines','Montana Mines, West Virginia',9781,57);
INSERT INTO "django_geo_db_city" VALUES(8134,'Rachel','Rachel, West Virginia',9782,57);
INSERT INTO "django_geo_db_city" VALUES(8135,'Rivesville','Rivesville, West Virginia',9783,57);
INSERT INTO "django_geo_db_city" VALUES(8136,'Wadestown','Wadestown, West Virginia',9784,57);
INSERT INTO "django_geo_db_city" VALUES(8137,'Wana','Wana, West Virginia',9785,57);
INSERT INTO "django_geo_db_city" VALUES(8138,'Worthington','Worthington, West Virginia',9786,57);
INSERT INTO "django_geo_db_city" VALUES(8139,'Sutton','Sutton, West Virginia',9787,57);
INSERT INTO "django_geo_db_city" VALUES(8140,'Birch River','Birch River, West Virginia',9788,57);
INSERT INTO "django_geo_db_city" VALUES(8141,'Cedarville','Cedarville, West Virginia',9789,57);
INSERT INTO "django_geo_db_city" VALUES(8142,'Centralia','Centralia, West Virginia',9790,57);
INSERT INTO "django_geo_db_city" VALUES(8143,'Copen','Copen, West Virginia',9791,57);
INSERT INTO "django_geo_db_city" VALUES(8144,'Dille','Dille, West Virginia',9792,57);
INSERT INTO "django_geo_db_city" VALUES(8145,'Elmira','Elmira, West Virginia',9793,57);
INSERT INTO "django_geo_db_city" VALUES(8146,'Exchange','Exchange, West Virginia',9794,57);
INSERT INTO "django_geo_db_city" VALUES(8147,'Flatwoods','Flatwoods, West Virginia',9795,57);
INSERT INTO "django_geo_db_city" VALUES(8148,'Frametown','Frametown, West Virginia',9796,57);
INSERT INTO "django_geo_db_city" VALUES(8149,'Gassaway','Gassaway, West Virginia',9797,57);
INSERT INTO "django_geo_db_city" VALUES(8150,'Heaters','Heaters, West Virginia',9798,57);
INSERT INTO "django_geo_db_city" VALUES(8151,'Little Birch','Little Birch, West Virginia',9799,57);
INSERT INTO "django_geo_db_city" VALUES(8152,'Napier','Napier, West Virginia',9801,57);
INSERT INTO "django_geo_db_city" VALUES(8153,'Perkins','Perkins, West Virginia',9802,57);
INSERT INTO "django_geo_db_city" VALUES(8154,'Rosedale','Rosedale, West Virginia',9803,57);
INSERT INTO "django_geo_db_city" VALUES(8155,'Shock','Shock, West Virginia',9804,57);
INSERT INTO "django_geo_db_city" VALUES(8156,'Strange Creek','Strange Creek, West Virginia',9805,57);
INSERT INTO "django_geo_db_city" VALUES(8157,'Wilsie','Wilsie, West Virginia',9806,57);
INSERT INTO "django_geo_db_city" VALUES(8158,'Summersville','Summersville, West Virginia',9807,57);
INSERT INTO "django_geo_db_city" VALUES(8159,'Belva','Belva, West Virginia',9808,57);
INSERT INTO "django_geo_db_city" VALUES(8160,'Calvin','Calvin, West Virginia',9809,57);
INSERT INTO "django_geo_db_city" VALUES(8161,'Canvas','Canvas, West Virginia',9810,57);
INSERT INTO "django_geo_db_city" VALUES(8162,'Drennen','Drennen, West Virginia',9811,57);
INSERT INTO "django_geo_db_city" VALUES(8163,'Gilboa','Gilboa, West Virginia',9812,57);
INSERT INTO "django_geo_db_city" VALUES(8164,'Jodie','Jodie, West Virginia',9813,57);
INSERT INTO "django_geo_db_city" VALUES(8165,'Keslers Cross Lanes','Keslers Cross Lanes, West Virginia',9814,57);
INSERT INTO "django_geo_db_city" VALUES(8166,'Leivasy','Leivasy, West Virginia',9815,57);
INSERT INTO "django_geo_db_city" VALUES(8167,'Mount Lookout','Mount Lookout, West Virginia',9816,57);
INSERT INTO "django_geo_db_city" VALUES(8168,'Mount Nebo','Mount Nebo, West Virginia',9817,57);
INSERT INTO "django_geo_db_city" VALUES(8169,'Nallen','Nallen, West Virginia',9818,57);
INSERT INTO "django_geo_db_city" VALUES(8170,'Nettie','Nettie, West Virginia',9819,57);
INSERT INTO "django_geo_db_city" VALUES(8171,'Pool','Pool, West Virginia',9820,57);
INSERT INTO "django_geo_db_city" VALUES(8172,'Swiss','Swiss, West Virginia',9821,57);
INSERT INTO "django_geo_db_city" VALUES(8173,'Tioga','Tioga, West Virginia',9822,57);
INSERT INTO "django_geo_db_city" VALUES(8174,'Augusta','Augusta, West Virginia',9823,57);
INSERT INTO "django_geo_db_city" VALUES(8175,'Aurora','Aurora, West Virginia',9824,57);
INSERT INTO "django_geo_db_city" VALUES(8176,'Bayard','Bayard, West Virginia',9825,57);
INSERT INTO "django_geo_db_city" VALUES(8177,'Burlington','Burlington, West Virginia',9826,57);
INSERT INTO "django_geo_db_city" VALUES(8178,'Capon Bridge','Capon Bridge, West Virginia',9827,57);
INSERT INTO "django_geo_db_city" VALUES(8179,'Delray','Delray, West Virginia',9828,57);
INSERT INTO "django_geo_db_city" VALUES(8180,'Eglon','Eglon, West Virginia',9829,57);
INSERT INTO "django_geo_db_city" VALUES(8181,'Elk Garden','Elk Garden, West Virginia',9830,57);
INSERT INTO "django_geo_db_city" VALUES(8182,'Fort Ashby','Fort Ashby, West Virginia',9831,57);
INSERT INTO "django_geo_db_city" VALUES(8183,'Gormania','Gormania, West Virginia',9832,57);
INSERT INTO "django_geo_db_city" VALUES(8184,'Green Spring','Green Spring, West Virginia',9833,57);
INSERT INTO "django_geo_db_city" VALUES(8185,'Keyser','Keyser, West Virginia',9834,57);
INSERT INTO "django_geo_db_city" VALUES(8186,'Lahmansville','Lahmansville, West Virginia',9835,57);
INSERT INTO "django_geo_db_city" VALUES(8187,'Medley','Medley, West Virginia',9836,57);
INSERT INTO "django_geo_db_city" VALUES(8188,'Mount Storm','Mount Storm, West Virginia',9837,57);
INSERT INTO "django_geo_db_city" VALUES(8189,'New Creek','New Creek, West Virginia',9838,57);
INSERT INTO "django_geo_db_city" VALUES(8190,'Piedmont','Piedmont, West Virginia',9839,57);
INSERT INTO "django_geo_db_city" VALUES(8191,'Ridgeley','Ridgeley, West Virginia',9840,57);
INSERT INTO "django_geo_db_city" VALUES(8192,'Rio','Rio, West Virginia',9841,57);
INSERT INTO "django_geo_db_city" VALUES(8193,'Romney','Romney, West Virginia',9842,57);
INSERT INTO "django_geo_db_city" VALUES(8194,'Shanks','Shanks, West Virginia',9843,57);
INSERT INTO "django_geo_db_city" VALUES(8195,'Springfield','Springfield, West Virginia',9844,57);
INSERT INTO "django_geo_db_city" VALUES(8196,'Terra Alta','Terra Alta, West Virginia',9845,57);
INSERT INTO "django_geo_db_city" VALUES(8197,'Wiley Ford','Wiley Ford, West Virginia',9846,57);
INSERT INTO "django_geo_db_city" VALUES(8198,'Baker','Baker, West Virginia',9847,57);
INSERT INTO "django_geo_db_city" VALUES(8199,'Brandywine','Brandywine, West Virginia',9848,57);
INSERT INTO "django_geo_db_city" VALUES(8200,'Circleville','Circleville, West Virginia',9849,57);
INSERT INTO "django_geo_db_city" VALUES(8201,'Franklin','Franklin, West Virginia',9850,57);
INSERT INTO "django_geo_db_city" VALUES(8202,'High View','High View, West Virginia',9851,57);
INSERT INTO "django_geo_db_city" VALUES(8203,'Lost City','Lost City, West Virginia',9852,57);
INSERT INTO "django_geo_db_city" VALUES(8204,'Mathias','Mathias, West Virginia',9853,57);
INSERT INTO "django_geo_db_city" VALUES(8205,'Riverton','Riverton, West Virginia',9854,57);
INSERT INTO "django_geo_db_city" VALUES(8206,'Sugar Grove','Sugar Grove, West Virginia',9855,57);
INSERT INTO "django_geo_db_city" VALUES(8207,'Bloomery','Bloomery, West Virginia',9856,57);
INSERT INTO "django_geo_db_city" VALUES(8208,'Fisher','Fisher, West Virginia',9857,57);
INSERT INTO "django_geo_db_city" VALUES(8209,'Capon Springs','Capon Springs, West Virginia',9858,57);
INSERT INTO "django_geo_db_city" VALUES(8210,'Junction','Junction, West Virginia',9859,57);
INSERT INTO "django_geo_db_city" VALUES(8211,'Maysville','Maysville, West Virginia',9860,57);
INSERT INTO "django_geo_db_city" VALUES(8212,'Moorefield','Moorefield, West Virginia',9861,57);
INSERT INTO "django_geo_db_city" VALUES(8213,'Milam','Milam, West Virginia',9862,57);
INSERT INTO "django_geo_db_city" VALUES(8214,'Old Fields','Old Fields, West Virginia',9863,57);
INSERT INTO "django_geo_db_city" VALUES(8215,'Petersburg','Petersburg, West Virginia',9864,57);
INSERT INTO "django_geo_db_city" VALUES(8216,'Wardensville','Wardensville, West Virginia',9865,57);
INSERT INTO "django_geo_db_city" VALUES(8217,'Purgitsville','Purgitsville, West Virginia',9866,57);
INSERT INTO "django_geo_db_city" VALUES(8218,'Cabins','Cabins, West Virginia',9867,57);
INSERT INTO "django_geo_db_city" VALUES(8219,'Yellow Spring','Yellow Spring, West Virginia',9868,57);
INSERT INTO "django_geo_db_city" VALUES(8220,'Upper Tract','Upper Tract, West Virginia',9869,57);
INSERT INTO "django_geo_db_city" VALUES(8221,'Seneca Rocks','Seneca Rocks, West Virginia',9870,57);
INSERT INTO "django_geo_db_city" VALUES(8222,'Onego','Onego, West Virginia',9871,57);
INSERT INTO "django_geo_db_city" VALUES(8223,'Advance','Advance, North Carolina',9873,33);
INSERT INTO "django_geo_db_city" VALUES(8224,'Ararat','Ararat, North Carolina',9874,33);
INSERT INTO "django_geo_db_city" VALUES(8225,'Belews Creek','Belews Creek, North Carolina',9875,33);
INSERT INTO "django_geo_db_city" VALUES(8226,'Bethania','Bethania, North Carolina',9876,33);
INSERT INTO "django_geo_db_city" VALUES(8227,'Boonville','Boonville, North Carolina',9877,33);
INSERT INTO "django_geo_db_city" VALUES(8228,'Clemmons','Clemmons, North Carolina',9878,33);
INSERT INTO "django_geo_db_city" VALUES(8229,'Cleveland','Cleveland, North Carolina',9879,33);
INSERT INTO "django_geo_db_city" VALUES(8230,'Cooleemee','Cooleemee, North Carolina',9880,33);
INSERT INTO "django_geo_db_city" VALUES(8231,'Danbury','Danbury, North Carolina',9881,33);
INSERT INTO "django_geo_db_city" VALUES(8232,'Dobson','Dobson, North Carolina',9882,33);
INSERT INTO "django_geo_db_city" VALUES(8233,'East Bend','East Bend, North Carolina',9883,33);
INSERT INTO "django_geo_db_city" VALUES(8234,'Germanton','Germanton, North Carolina',9884,33);
INSERT INTO "django_geo_db_city" VALUES(8235,'Hamptonville','Hamptonville, North Carolina',9885,33);
INSERT INTO "django_geo_db_city" VALUES(8236,'King','King, North Carolina',9886,33);
INSERT INTO "django_geo_db_city" VALUES(8237,'Lawsonville','Lawsonville, North Carolina',9887,33);
INSERT INTO "django_geo_db_city" VALUES(8238,'Lewisville','Lewisville, North Carolina',9888,33);
INSERT INTO "django_geo_db_city" VALUES(8239,'Lowgap','Lowgap, North Carolina',9889,33);
INSERT INTO "django_geo_db_city" VALUES(8240,'Madison','Madison, North Carolina',9890,33);
INSERT INTO "django_geo_db_city" VALUES(8241,'Mayodan','Mayodan, North Carolina',9891,33);
INSERT INTO "django_geo_db_city" VALUES(8242,'Mocksville','Mocksville, North Carolina',9892,33);
INSERT INTO "django_geo_db_city" VALUES(8243,'Mount Airy','Mount Airy, North Carolina',9893,33);
INSERT INTO "django_geo_db_city" VALUES(8244,'White Plains','White Plains, North Carolina',9894,33);
INSERT INTO "django_geo_db_city" VALUES(8245,'Pfafftown','Pfafftown, North Carolina',9895,33);
INSERT INTO "django_geo_db_city" VALUES(8246,'Pilot Mountain','Pilot Mountain, North Carolina',9896,33);
INSERT INTO "django_geo_db_city" VALUES(8247,'Pine Hall','Pine Hall, North Carolina',9897,33);
INSERT INTO "django_geo_db_city" VALUES(8248,'Pinnacle','Pinnacle, North Carolina',9898,33);
INSERT INTO "django_geo_db_city" VALUES(8249,'Rural Hall','Rural Hall, North Carolina',9899,33);
INSERT INTO "django_geo_db_city" VALUES(8250,'Sandy Ridge','Sandy Ridge, North Carolina',9900,33);
INSERT INTO "django_geo_db_city" VALUES(8251,'Siloam','Siloam, North Carolina',9901,33);
INSERT INTO "django_geo_db_city" VALUES(8252,'Stoneville','Stoneville, North Carolina',9902,33);
INSERT INTO "django_geo_db_city" VALUES(8253,'Toast','Toast, North Carolina',9903,33);
INSERT INTO "django_geo_db_city" VALUES(8254,'Tobaccoville','Tobaccoville, North Carolina',9904,33);
INSERT INTO "django_geo_db_city" VALUES(8255,'Walkertown','Walkertown, North Carolina',9905,33);
INSERT INTO "django_geo_db_city" VALUES(8256,'Walnut Cove','Walnut Cove, North Carolina',9906,33);
INSERT INTO "django_geo_db_city" VALUES(8257,'Westfield','Westfield, North Carolina',9907,33);
INSERT INTO "django_geo_db_city" VALUES(8258,'Woodleaf','Woodleaf, North Carolina',9908,33);
INSERT INTO "django_geo_db_city" VALUES(8259,'Yadkinville','Yadkinville, North Carolina',9909,33);
INSERT INTO "django_geo_db_city" VALUES(8260,'Winston Salem','Winston Salem, North Carolina',9911,33);
INSERT INTO "django_geo_db_city" VALUES(8261,'Salisbury','Salisbury, North Carolina',9920,33);
INSERT INTO "django_geo_db_city" VALUES(8262,'Alamance','Alamance, North Carolina',9921,33);
INSERT INTO "django_geo_db_city" VALUES(8263,'Altamahaw','Altamahaw, North Carolina',9922,33);
INSERT INTO "django_geo_db_city" VALUES(8264,'Asheboro','Asheboro, North Carolina',9923,33);
INSERT INTO "django_geo_db_city" VALUES(8265,'Bear Creek','Bear Creek, North Carolina',9926,33);
INSERT INTO "django_geo_db_city" VALUES(8266,'Bennett','Bennett, North Carolina',9927,33);
INSERT INTO "django_geo_db_city" VALUES(8267,'Biscoe','Biscoe, North Carolina',9928,33);
INSERT INTO "django_geo_db_city" VALUES(8268,'Blanch','Blanch, North Carolina',9929,33);
INSERT INTO "django_geo_db_city" VALUES(8269,'Bonlee','Bonlee, North Carolina',9930,33);
INSERT INTO "django_geo_db_city" VALUES(8270,'Browns Summit','Browns Summit, North Carolina',9931,33);
INSERT INTO "django_geo_db_city" VALUES(8271,'Burlington','Burlington, North Carolina',9932,33);
INSERT INTO "django_geo_db_city" VALUES(8272,'Bynum','Bynum, North Carolina',9936,33);
INSERT INTO "django_geo_db_city" VALUES(8273,'Candor','Candor, North Carolina',9937,33);
INSERT INTO "django_geo_db_city" VALUES(8274,'Cedar Falls','Cedar Falls, North Carolina',9938,33);
INSERT INTO "django_geo_db_city" VALUES(8275,'Cedar Grove','Cedar Grove, North Carolina',9939,33);
INSERT INTO "django_geo_db_city" VALUES(8276,'Climax','Climax, North Carolina',9940,33);
INSERT INTO "django_geo_db_city" VALUES(8277,'Colfax','Colfax, North Carolina',9941,33);
INSERT INTO "django_geo_db_city" VALUES(8278,'Cumnock','Cumnock, North Carolina',9942,33);
INSERT INTO "django_geo_db_city" VALUES(8279,'Denton','Denton, North Carolina',9943,33);
INSERT INTO "django_geo_db_city" VALUES(8280,'Eagle Springs','Eagle Springs, North Carolina',9944,33);
INSERT INTO "django_geo_db_city" VALUES(8281,'Efland','Efland, North Carolina',9945,33);
INSERT INTO "django_geo_db_city" VALUES(8282,'Elon College','Elon College, North Carolina',9946,33);
INSERT INTO "django_geo_db_city" VALUES(8283,'Ether','Ether, North Carolina',9947,33);
INSERT INTO "django_geo_db_city" VALUES(8284,'Franklinville','Franklinville, North Carolina',9948,33);
INSERT INTO "django_geo_db_city" VALUES(8285,'Gibsonville','Gibsonville, North Carolina',9949,33);
INSERT INTO "django_geo_db_city" VALUES(8286,'Goldston','Goldston, North Carolina',9950,33);
INSERT INTO "django_geo_db_city" VALUES(8287,'Graham','Graham, North Carolina',9951,33);
INSERT INTO "django_geo_db_city" VALUES(8288,'Gulf','Gulf, North Carolina',9952,33);
INSERT INTO "django_geo_db_city" VALUES(8289,'Haw River','Haw River, North Carolina',9953,33);
INSERT INTO "django_geo_db_city" VALUES(8290,'Highfalls','Highfalls, North Carolina',9954,33);
INSERT INTO "django_geo_db_city" VALUES(8291,'High Point','High Point, North Carolina',9955,33);
INSERT INTO "django_geo_db_city" VALUES(8292,'Hillsborough','Hillsborough, North Carolina',9960,33);
INSERT INTO "django_geo_db_city" VALUES(8293,'Jackson Springs','Jackson Springs, North Carolina',9961,33);
INSERT INTO "django_geo_db_city" VALUES(8294,'Jamestown','Jamestown, North Carolina',9962,33);
INSERT INTO "django_geo_db_city" VALUES(8295,'Julian','Julian, North Carolina',9963,33);
INSERT INTO "django_geo_db_city" VALUES(8296,'Kernersville','Kernersville, North Carolina',9964,33);
INSERT INTO "django_geo_db_city" VALUES(8297,'Eden','Eden, North Carolina',9965,33);
INSERT INTO "django_geo_db_city" VALUES(8298,'Leasburg','Leasburg, North Carolina',9967,33);
INSERT INTO "django_geo_db_city" VALUES(8299,'Lexington','Lexington, North Carolina',9968,33);
INSERT INTO "django_geo_db_city" VALUES(8300,'Liberty','Liberty, North Carolina',9971,33);
INSERT INTO "django_geo_db_city" VALUES(8301,'Linwood','Linwood, North Carolina',9972,33);
INSERT INTO "django_geo_db_city" VALUES(8302,'McLeansville','McLeansville, North Carolina',9973,33);
INSERT INTO "django_geo_db_city" VALUES(8303,'Mebane','Mebane, North Carolina',9974,33);
INSERT INTO "django_geo_db_city" VALUES(8304,'Milton','Milton, North Carolina',9975,33);
INSERT INTO "django_geo_db_city" VALUES(8305,'Mount Gilead','Mount Gilead, North Carolina',9976,33);
INSERT INTO "django_geo_db_city" VALUES(8306,'Oak Ridge','Oak Ridge, North Carolina',9977,33);
INSERT INTO "django_geo_db_city" VALUES(8307,'Pelham','Pelham, North Carolina',9978,33);
INSERT INTO "django_geo_db_city" VALUES(8308,'Pittsboro','Pittsboro, North Carolina',9979,33);
INSERT INTO "django_geo_db_city" VALUES(8309,'Pleasant Garden','Pleasant Garden, North Carolina',9980,33);
INSERT INTO "django_geo_db_city" VALUES(8310,'Prospect Hill','Prospect Hill, North Carolina',9981,33);
INSERT INTO "django_geo_db_city" VALUES(8311,'Providence','Providence, North Carolina',9982,33);
INSERT INTO "django_geo_db_city" VALUES(8312,'Ramseur','Ramseur, North Carolina',9983,33);
INSERT INTO "django_geo_db_city" VALUES(8313,'Randleman','Randleman, North Carolina',9984,33);
INSERT INTO "django_geo_db_city" VALUES(8314,'Reidsville','Reidsville, North Carolina',9985,33);
INSERT INTO "django_geo_db_city" VALUES(8315,'Robbins','Robbins, North Carolina',9987,33);
INSERT INTO "django_geo_db_city" VALUES(8316,'Ruffin','Ruffin, North Carolina',9988,33);
INSERT INTO "django_geo_db_city" VALUES(8317,'Sanford','Sanford, North Carolina',9989,33);
INSERT INTO "django_geo_db_city" VALUES(8318,'Saxapahaw','Saxapahaw, North Carolina',9992,33);
INSERT INTO "django_geo_db_city" VALUES(8319,'Seagrove','Seagrove, North Carolina',9993,33);
INSERT INTO "django_geo_db_city" VALUES(8320,'Sedalia','Sedalia, North Carolina',9994,33);
INSERT INTO "django_geo_db_city" VALUES(8321,'Semora','Semora, North Carolina',9995,33);
INSERT INTO "django_geo_db_city" VALUES(8322,'Siler City','Siler City, North Carolina',9996,33);
INSERT INTO "django_geo_db_city" VALUES(8323,'Snow Camp','Snow Camp, North Carolina',9997,33);
INSERT INTO "django_geo_db_city" VALUES(8324,'Sophia','Sophia, North Carolina',9998,33);
INSERT INTO "django_geo_db_city" VALUES(8325,'Southmont','Southmont, North Carolina',9999,33);
INSERT INTO "django_geo_db_city" VALUES(8326,'Staley','Staley, North Carolina',10000,33);
INSERT INTO "django_geo_db_city" VALUES(8327,'Star','Star, North Carolina',10001,33);
INSERT INTO "django_geo_db_city" VALUES(8328,'Stokesdale','Stokesdale, North Carolina',10002,33);
INSERT INTO "django_geo_db_city" VALUES(8329,'Summerfield','Summerfield, North Carolina',10003,33);
INSERT INTO "django_geo_db_city" VALUES(8330,'Swepsonville','Swepsonville, North Carolina',10004,33);
INSERT INTO "django_geo_db_city" VALUES(8331,'Thomasville','Thomasville, North Carolina',10005,33);
INSERT INTO "django_geo_db_city" VALUES(8332,'Trinity','Trinity, North Carolina',10006,33);
INSERT INTO "django_geo_db_city" VALUES(8333,'Troy','Troy, North Carolina',10007,33);
INSERT INTO "django_geo_db_city" VALUES(8334,'Wallburg','Wallburg, North Carolina',9969,33);
INSERT INTO "django_geo_db_city" VALUES(8335,'Welcome','Welcome, North Carolina',10008,33);
INSERT INTO "django_geo_db_city" VALUES(8336,'Wentworth','Wentworth, North Carolina',9966,33);
INSERT INTO "django_geo_db_city" VALUES(8337,'West End','West End, North Carolina',10009,33);
INSERT INTO "django_geo_db_city" VALUES(8338,'Whitsett','Whitsett, North Carolina',10010,33);
INSERT INTO "django_geo_db_city" VALUES(8339,'Yanceyville','Yanceyville, North Carolina',10011,33);
INSERT INTO "django_geo_db_city" VALUES(8340,'Greensboro','Greensboro, North Carolina',10014,33);
INSERT INTO "django_geo_db_city" VALUES(8341,'Angier','Angier, North Carolina',10026,33);
INSERT INTO "django_geo_db_city" VALUES(8342,'Apex','Apex, North Carolina',10027,33);
INSERT INTO "django_geo_db_city" VALUES(8343,'Bahama','Bahama, North Carolina',10028,33);
INSERT INTO "django_geo_db_city" VALUES(8344,'Benson','Benson, North Carolina',10029,33);
INSERT INTO "django_geo_db_city" VALUES(8345,'Broadway','Broadway, North Carolina',10030,33);
INSERT INTO "django_geo_db_city" VALUES(8346,'Buies Creek','Buies Creek, North Carolina',10031,33);
INSERT INTO "django_geo_db_city" VALUES(8347,'Bullock','Bullock, North Carolina',10032,33);
INSERT INTO "django_geo_db_city" VALUES(8348,'Bunn','Bunn, North Carolina',10033,33);
INSERT INTO "django_geo_db_city" VALUES(8349,'Butner','Butner, North Carolina',10034,33);
INSERT INTO "django_geo_db_city" VALUES(8350,'Carrboro','Carrboro, North Carolina',10035,33);
INSERT INTO "django_geo_db_city" VALUES(8351,'Cary','Cary, North Carolina',10036,33);
INSERT INTO "django_geo_db_city" VALUES(8352,'Chapel Hill','Chapel Hill, North Carolina',10039,33);
INSERT INTO "django_geo_db_city" VALUES(8353,'Clayton','Clayton, North Carolina',10045,33);
INSERT INTO "django_geo_db_city" VALUES(8354,'Coats','Coats, North Carolina',10046,33);
INSERT INTO "django_geo_db_city" VALUES(8355,'Creedmoor','Creedmoor, North Carolina',10047,33);
INSERT INTO "django_geo_db_city" VALUES(8356,'Eagle Rock','Eagle Rock, North Carolina',10043,33);
INSERT INTO "django_geo_db_city" VALUES(8357,'Four Oaks','Four Oaks, North Carolina',10048,33);
INSERT INTO "django_geo_db_city" VALUES(8358,'Franklinton','Franklinton, North Carolina',10049,33);
INSERT INTO "django_geo_db_city" VALUES(8359,'Fuquay Varina','Fuquay Varina, North Carolina',10050,33);
INSERT INTO "django_geo_db_city" VALUES(8360,'Garner','Garner, North Carolina',10051,33);
INSERT INTO "django_geo_db_city" VALUES(8361,'Goldsboro','Goldsboro, North Carolina',10052,33);
INSERT INTO "django_geo_db_city" VALUES(8362,'Henderson','Henderson, North Carolina',10056,33);
INSERT INTO "django_geo_db_city" VALUES(8363,'Holly Springs','Holly Springs, North Carolina',10059,33);
INSERT INTO "django_geo_db_city" VALUES(8364,'Hurdle Mills','Hurdle Mills, North Carolina',10060,33);
INSERT INTO "django_geo_db_city" VALUES(8365,'Kenly','Kenly, North Carolina',10061,33);
INSERT INTO "django_geo_db_city" VALUES(8366,'Kipling','Kipling, North Carolina',10062,33);
INSERT INTO "django_geo_db_city" VALUES(8367,'Kittrell','Kittrell, North Carolina',10063,33);
INSERT INTO "django_geo_db_city" VALUES(8368,'Knightdale','Knightdale, North Carolina',10064,33);
INSERT INTO "django_geo_db_city" VALUES(8369,'Lillington','Lillington, North Carolina',10065,33);
INSERT INTO "django_geo_db_city" VALUES(8370,'Louisburg','Louisburg, North Carolina',10066,33);
INSERT INTO "django_geo_db_city" VALUES(8371,'Macon','Macon, North Carolina',10067,33);
INSERT INTO "django_geo_db_city" VALUES(8372,'Mamers','Mamers, North Carolina',10068,33);
INSERT INTO "django_geo_db_city" VALUES(8373,'Manson','Manson, North Carolina',10069,33);
INSERT INTO "django_geo_db_city" VALUES(8374,'Micro','Micro, North Carolina',10070,33);
INSERT INTO "django_geo_db_city" VALUES(8375,'Middleburg','Middleburg, North Carolina',10071,33);
INSERT INTO "django_geo_db_city" VALUES(8376,'Middlesex','Middlesex, North Carolina',10072,33);
INSERT INTO "django_geo_db_city" VALUES(8377,'Moncure','Moncure, North Carolina',10073,33);
INSERT INTO "django_geo_db_city" VALUES(8378,'Morrisville','Morrisville, North Carolina',10074,33);
INSERT INTO "django_geo_db_city" VALUES(8379,'Raleigh','Raleigh, North Carolina',10075,33);
INSERT INTO "django_geo_db_city" VALUES(8380,'New Hill','New Hill, North Carolina',10076,33);
INSERT INTO "django_geo_db_city" VALUES(8381,'Norlina','Norlina, North Carolina',10077,33);
INSERT INTO "django_geo_db_city" VALUES(8382,'Oxford','Oxford, North Carolina',10079,33);
INSERT INTO "django_geo_db_city" VALUES(8383,'Pine Level','Pine Level, North Carolina',10080,33);
INSERT INTO "django_geo_db_city" VALUES(8384,'Princeton','Princeton, North Carolina',10081,33);
INSERT INTO "django_geo_db_city" VALUES(8385,'Ridgeway','Ridgeway, North Carolina',10082,33);
INSERT INTO "django_geo_db_city" VALUES(8386,'Rolesville','Rolesville, North Carolina',10083,33);
INSERT INTO "django_geo_db_city" VALUES(8387,'Rougemont','Rougemont, North Carolina',10084,33);
INSERT INTO "django_geo_db_city" VALUES(8388,'Roxboro','Roxboro, North Carolina',10085,33);
INSERT INTO "django_geo_db_city" VALUES(8389,'Selma','Selma, North Carolina',10087,33);
INSERT INTO "django_geo_db_city" VALUES(8390,'Smithfield','Smithfield, North Carolina',10088,33);
INSERT INTO "django_geo_db_city" VALUES(8391,'Stem','Stem, North Carolina',10089,33);
INSERT INTO "django_geo_db_city" VALUES(8392,'Stovall','Stovall, North Carolina',10090,33);
INSERT INTO "django_geo_db_city" VALUES(8393,'Timberlake','Timberlake, North Carolina',10091,33);
INSERT INTO "django_geo_db_city" VALUES(8394,'Townsville','Townsville, North Carolina',10092,33);
INSERT INTO "django_geo_db_city" VALUES(8395,'Vaughan','Vaughan, North Carolina',10093,33);
INSERT INTO "django_geo_db_city" VALUES(8396,'Wake Forest','Wake Forest, North Carolina',10094,33);
INSERT INTO "django_geo_db_city" VALUES(8397,'Warrenton','Warrenton, North Carolina',10096,33);
INSERT INTO "django_geo_db_city" VALUES(8398,'Wendell','Wendell, North Carolina',10097,33);
INSERT INTO "django_geo_db_city" VALUES(8399,'Willow Spring','Willow Spring, North Carolina',10098,33);
INSERT INTO "django_geo_db_city" VALUES(8400,'Wilsons Mills','Wilsons Mills, North Carolina',10099,33);
INSERT INTO "django_geo_db_city" VALUES(8401,'Wise','Wise, North Carolina',10093,33);
INSERT INTO "django_geo_db_city" VALUES(8402,'Youngsville','Youngsville, North Carolina',10100,33);
INSERT INTO "django_geo_db_city" VALUES(8403,'Zebulon','Zebulon, North Carolina',10101,33);
INSERT INTO "django_geo_db_city" VALUES(8404,'Durham','Durham, North Carolina',10122,33);
INSERT INTO "django_geo_db_city" VALUES(8405,'Rocky Mount','Rocky Mount, North Carolina',10132,33);
INSERT INTO "django_geo_db_city" VALUES(8406,'Aulander','Aulander, North Carolina',10136,33);
INSERT INTO "django_geo_db_city" VALUES(8407,'Aurora','Aurora, North Carolina',10137,33);
INSERT INTO "django_geo_db_city" VALUES(8408,'Bailey','Bailey, North Carolina',10138,33);
INSERT INTO "django_geo_db_city" VALUES(8409,'Bath','Bath, North Carolina',10139,33);
INSERT INTO "django_geo_db_city" VALUES(8410,'Battleboro','Battleboro, North Carolina',10140,33);
INSERT INTO "django_geo_db_city" VALUES(8411,'Belhaven','Belhaven, North Carolina',10141,33);
INSERT INTO "django_geo_db_city" VALUES(8412,'Bellarthur','Bellarthur, North Carolina',10142,33);
INSERT INTO "django_geo_db_city" VALUES(8413,'Bethel','Bethel, North Carolina',10143,33);
INSERT INTO "django_geo_db_city" VALUES(8414,'Black Creek','Black Creek, North Carolina',10144,33);
INSERT INTO "django_geo_db_city" VALUES(8415,'Blounts Creek','Blounts Creek, North Carolina',10145,33);
INSERT INTO "django_geo_db_city" VALUES(8416,'Castalia','Castalia, North Carolina',10146,33);
INSERT INTO "django_geo_db_city" VALUES(8417,'Chocowinity','Chocowinity, North Carolina',10147,33);
INSERT INTO "django_geo_db_city" VALUES(8418,'Como','Como, North Carolina',10148,33);
INSERT INTO "django_geo_db_city" VALUES(8419,'Conetoe','Conetoe, North Carolina',10149,33);
INSERT INTO "django_geo_db_city" VALUES(8420,'Conway','Conway, North Carolina',10150,33);
INSERT INTO "django_geo_db_city" VALUES(8421,'Edward','Edward, North Carolina',10151,33);
INSERT INTO "django_geo_db_city" VALUES(8422,'Elm City','Elm City, North Carolina',10152,33);
INSERT INTO "django_geo_db_city" VALUES(8423,'Enfield','Enfield, North Carolina',10153,33);
INSERT INTO "django_geo_db_city" VALUES(8424,'Engelhard','Engelhard, North Carolina',10154,33);
INSERT INTO "django_geo_db_city" VALUES(8425,'Everetts','Everetts, North Carolina',10155,33);
INSERT INTO "django_geo_db_city" VALUES(8426,'Fairfield','Fairfield, North Carolina',10156,33);
INSERT INTO "django_geo_db_city" VALUES(8427,'Falkland','Falkland, North Carolina',10157,33);
INSERT INTO "django_geo_db_city" VALUES(8428,'Farmville','Farmville, North Carolina',10158,33);
INSERT INTO "django_geo_db_city" VALUES(8429,'Fountain','Fountain, North Carolina',10159,33);
INSERT INTO "django_geo_db_city" VALUES(8430,'Fremont','Fremont, North Carolina',10160,33);
INSERT INTO "django_geo_db_city" VALUES(8431,'Garysburg','Garysburg, North Carolina',10161,33);
INSERT INTO "django_geo_db_city" VALUES(8432,'Gaston','Gaston, North Carolina',10162,33);
INSERT INTO "django_geo_db_city" VALUES(8433,'Greenville','Greenville, North Carolina',10163,33);
INSERT INTO "django_geo_db_city" VALUES(8434,'Grimesland','Grimesland, North Carolina',10166,33);
INSERT INTO "django_geo_db_city" VALUES(8435,'Gumberry','Gumberry, North Carolina',10167,33);
INSERT INTO "django_geo_db_city" VALUES(8436,'Halifax','Halifax, North Carolina',10168,33);
INSERT INTO "django_geo_db_city" VALUES(8437,'Hamilton','Hamilton, North Carolina',10169,33);
INSERT INTO "django_geo_db_city" VALUES(8438,'Hassell','Hassell, North Carolina',10170,33);
INSERT INTO "django_geo_db_city" VALUES(8439,'Henrico','Henrico, North Carolina',10171,33);
INSERT INTO "django_geo_db_city" VALUES(8440,'Hobgood','Hobgood, North Carolina',10172,33);
INSERT INTO "django_geo_db_city" VALUES(8441,'Hollister','Hollister, North Carolina',10173,33);
INSERT INTO "django_geo_db_city" VALUES(8442,'Jackson','Jackson, North Carolina',10174,33);
INSERT INTO "django_geo_db_city" VALUES(8443,'Jamesville','Jamesville, North Carolina',10175,33);
INSERT INTO "django_geo_db_city" VALUES(8444,'Kelford','Kelford, North Carolina',10176,33);
INSERT INTO "django_geo_db_city" VALUES(8445,'Lewiston Woodville','Lewiston Woodville, North Carolina',10177,33);
INSERT INTO "django_geo_db_city" VALUES(8446,'Littleton','Littleton, North Carolina',10178,33);
INSERT INTO "django_geo_db_city" VALUES(8447,'Lucama','Lucama, North Carolina',10179,33);
INSERT INTO "django_geo_db_city" VALUES(8448,'Macclesfield','Macclesfield, North Carolina',10180,33);
INSERT INTO "django_geo_db_city" VALUES(8449,'Margarettsville','Margarettsville, North Carolina',10181,33);
INSERT INTO "django_geo_db_city" VALUES(8450,'Milwaukee','Milwaukee, North Carolina',10182,33);
INSERT INTO "django_geo_db_city" VALUES(8451,'Murfreesboro','Murfreesboro, North Carolina',10183,33);
INSERT INTO "django_geo_db_city" VALUES(8452,'Nashville','Nashville, North Carolina',10184,33);
INSERT INTO "django_geo_db_city" VALUES(8453,'Oak City','Oak City, North Carolina',10185,33);
INSERT INTO "django_geo_db_city" VALUES(8454,'Palmyra','Palmyra, North Carolina',10187,33);
INSERT INTO "django_geo_db_city" VALUES(8455,'Pantego','Pantego, North Carolina',10188,33);
INSERT INTO "django_geo_db_city" VALUES(8456,'Parmele','Parmele, North Carolina',10189,33);
INSERT INTO "django_geo_db_city" VALUES(8457,'Pendleton','Pendleton, North Carolina',10190,33);
INSERT INTO "django_geo_db_city" VALUES(8458,'Pikeville','Pikeville, North Carolina',10191,33);
INSERT INTO "django_geo_db_city" VALUES(8459,'Pinetops','Pinetops, North Carolina',10192,33);
INSERT INTO "django_geo_db_city" VALUES(8460,'Pinetown','Pinetown, North Carolina',10193,33);
INSERT INTO "django_geo_db_city" VALUES(8461,'Pleasant Hill','Pleasant Hill, North Carolina',10194,33);
INSERT INTO "django_geo_db_city" VALUES(8462,'Potecasi','Potecasi, North Carolina',10167,33);
INSERT INTO "django_geo_db_city" VALUES(8463,'Red Oak','Red Oak, North Carolina',10195,33);
INSERT INTO "django_geo_db_city" VALUES(8464,'Rich Square','Rich Square, North Carolina',10196,33);
INSERT INTO "django_geo_db_city" VALUES(8465,'Roanoke Rapids','Roanoke Rapids, North Carolina',10197,33);
INSERT INTO "django_geo_db_city" VALUES(8466,'Robersonville','Robersonville, North Carolina',10198,33);
INSERT INTO "django_geo_db_city" VALUES(8467,'Roxobel','Roxobel, North Carolina',10199,33);
INSERT INTO "django_geo_db_city" VALUES(8468,'Saratoga','Saratoga, North Carolina',10200,33);
INSERT INTO "django_geo_db_city" VALUES(8469,'Scotland Neck','Scotland Neck, North Carolina',10201,33);
INSERT INTO "django_geo_db_city" VALUES(8470,'Scranton','Scranton, North Carolina',10202,33);
INSERT INTO "django_geo_db_city" VALUES(8471,'Seaboard','Seaboard, North Carolina',10203,33);
INSERT INTO "django_geo_db_city" VALUES(8472,'Severn','Severn, North Carolina',10204,33);
INSERT INTO "django_geo_db_city" VALUES(8473,'Sharpsburg','Sharpsburg, North Carolina',10205,33);
INSERT INTO "django_geo_db_city" VALUES(8474,'Simpson','Simpson, North Carolina',10206,33);
INSERT INTO "django_geo_db_city" VALUES(8475,'Sims','Sims, North Carolina',10207,33);
INSERT INTO "django_geo_db_city" VALUES(8476,'Speed','Speed, North Carolina',10208,33);
INSERT INTO "django_geo_db_city" VALUES(8477,'Spring Hope','Spring Hope, North Carolina',10209,33);
INSERT INTO "django_geo_db_city" VALUES(8478,'Stantonsburg','Stantonsburg, North Carolina',10210,33);
INSERT INTO "django_geo_db_city" VALUES(8479,'Stokes','Stokes, North Carolina',10211,33);
INSERT INTO "django_geo_db_city" VALUES(8480,'Swanquarter','Swanquarter, North Carolina',10212,33);
INSERT INTO "django_geo_db_city" VALUES(8481,'Tarboro','Tarboro, North Carolina',10213,33);
INSERT INTO "django_geo_db_city" VALUES(8482,'Tillery','Tillery, North Carolina',10214,33);
INSERT INTO "django_geo_db_city" VALUES(8483,'Walstonburg','Walstonburg, North Carolina',10215,33);
INSERT INTO "django_geo_db_city" VALUES(8484,'Washington','Washington, North Carolina',10216,33);
INSERT INTO "django_geo_db_city" VALUES(8485,'Weldon','Weldon, North Carolina',10217,33);
INSERT INTO "django_geo_db_city" VALUES(8486,'Whitakers','Whitakers, North Carolina',10218,33);
INSERT INTO "django_geo_db_city" VALUES(8487,'Williamston','Williamston, North Carolina',10219,33);
INSERT INTO "django_geo_db_city" VALUES(8488,'Wilson','Wilson, North Carolina',10220,33);
INSERT INTO "django_geo_db_city" VALUES(8489,'Woodland','Woodland, North Carolina',10224,33);
INSERT INTO "django_geo_db_city" VALUES(8490,'Elizabeth City','Elizabeth City, North Carolina',10225,33);
INSERT INTO "django_geo_db_city" VALUES(8491,'Ahoskie','Ahoskie, North Carolina',10228,33);
INSERT INTO "django_geo_db_city" VALUES(8492,'Avon','Avon, North Carolina',10229,33);
INSERT INTO "django_geo_db_city" VALUES(8493,'Aydlett','Aydlett, North Carolina',10230,33);
INSERT INTO "django_geo_db_city" VALUES(8494,'Barco','Barco, North Carolina',10231,33);
INSERT INTO "django_geo_db_city" VALUES(8495,'Belvidere','Belvidere, North Carolina',10232,33);
INSERT INTO "django_geo_db_city" VALUES(8496,'Buxton','Buxton, North Carolina',10233,33);
INSERT INTO "django_geo_db_city" VALUES(8497,'Camden','Camden, North Carolina',10234,33);
INSERT INTO "django_geo_db_city" VALUES(8498,'Cofield','Cofield, North Carolina',10235,33);
INSERT INTO "django_geo_db_city" VALUES(8499,'Coinjock','Coinjock, North Carolina',10236,33);
INSERT INTO "django_geo_db_city" VALUES(8500,'Colerain','Colerain, North Carolina',10237,33);
INSERT INTO "django_geo_db_city" VALUES(8501,'Columbia','Columbia, North Carolina',10238,33);
INSERT INTO "django_geo_db_city" VALUES(8502,'Corapeake','Corapeake, North Carolina',10239,33);
INSERT INTO "django_geo_db_city" VALUES(8503,'Corolla','Corolla, North Carolina',10240,33);
INSERT INTO "django_geo_db_city" VALUES(8504,'Creswell','Creswell, North Carolina',10241,33);
INSERT INTO "django_geo_db_city" VALUES(8505,'Currituck','Currituck, North Carolina',10242,33);
INSERT INTO "django_geo_db_city" VALUES(8506,'Durants Neck','Durants Neck, North Carolina',10243,33);
INSERT INTO "django_geo_db_city" VALUES(8507,'Edenton','Edenton, North Carolina',10244,33);
INSERT INTO "django_geo_db_city" VALUES(8508,'Eure','Eure, North Carolina',10245,33);
INSERT INTO "django_geo_db_city" VALUES(8509,'Frisco','Frisco, North Carolina',10246,33);
INSERT INTO "django_geo_db_city" VALUES(8510,'Gates','Gates, North Carolina',10247,33);
INSERT INTO "django_geo_db_city" VALUES(8511,'Gatesville','Gatesville, North Carolina',10248,33);
INSERT INTO "django_geo_db_city" VALUES(8512,'Grandy','Grandy, North Carolina',10249,33);
INSERT INTO "django_geo_db_city" VALUES(8513,'Harbinger','Harbinger, North Carolina',10250,33);
INSERT INTO "django_geo_db_city" VALUES(8514,'Harrellsville','Harrellsville, North Carolina',10251,33);
INSERT INTO "django_geo_db_city" VALUES(8515,'Hatteras','Hatteras, North Carolina',10252,33);
INSERT INTO "django_geo_db_city" VALUES(8516,'Hertford','Hertford, North Carolina',10253,33);
INSERT INTO "django_geo_db_city" VALUES(8517,'Hobbsville','Hobbsville, North Carolina',10254,33);
INSERT INTO "django_geo_db_city" VALUES(8518,'Jarvisburg','Jarvisburg, North Carolina',10255,33);
INSERT INTO "django_geo_db_city" VALUES(8519,'Kill Devil Hills','Kill Devil Hills, North Carolina',10256,33);
INSERT INTO "django_geo_db_city" VALUES(8520,'Kitty Hawk','Kitty Hawk, North Carolina',10257,33);
INSERT INTO "django_geo_db_city" VALUES(8521,'Knotts Island','Knotts Island, North Carolina',10258,33);
INSERT INTO "django_geo_db_city" VALUES(8522,'Manns Harbor','Manns Harbor, North Carolina',10259,33);
INSERT INTO "django_geo_db_city" VALUES(8523,'Manteo','Manteo, North Carolina',10260,33);
INSERT INTO "django_geo_db_city" VALUES(8524,'Maple','Maple, North Carolina',10261,33);
INSERT INTO "django_geo_db_city" VALUES(8525,'Merry Hill','Merry Hill, North Carolina',10262,33);
INSERT INTO "django_geo_db_city" VALUES(8526,'Moyock','Moyock, North Carolina',10263,33);
INSERT INTO "django_geo_db_city" VALUES(8527,'Nags Head','Nags Head, North Carolina',10264,33);
INSERT INTO "django_geo_db_city" VALUES(8528,'Ocracoke','Ocracoke, North Carolina',10265,33);
INSERT INTO "django_geo_db_city" VALUES(8529,'Plymouth','Plymouth, North Carolina',10266,33);
INSERT INTO "django_geo_db_city" VALUES(8530,'Point Harbor','Point Harbor, North Carolina',10267,33);
INSERT INTO "django_geo_db_city" VALUES(8531,'Poplar Branch','Poplar Branch, North Carolina',10268,33);
INSERT INTO "django_geo_db_city" VALUES(8532,'Powells Point','Powells Point, North Carolina',10269,33);
INSERT INTO "django_geo_db_city" VALUES(8533,'Powellsville','Powellsville, North Carolina',10270,33);
INSERT INTO "django_geo_db_city" VALUES(8534,'Rodanthe','Rodanthe, North Carolina',10271,33);
INSERT INTO "django_geo_db_city" VALUES(8535,'Roduco','Roduco, North Carolina',10272,33);
INSERT INTO "django_geo_db_city" VALUES(8536,'Roper','Roper, North Carolina',10273,33);
INSERT INTO "django_geo_db_city" VALUES(8537,'Salvo','Salvo, North Carolina',10274,33);
INSERT INTO "django_geo_db_city" VALUES(8538,'Shawboro','Shawboro, North Carolina',10275,33);
INSERT INTO "django_geo_db_city" VALUES(8539,'Shiloh','Shiloh, North Carolina',10276,33);
INSERT INTO "django_geo_db_city" VALUES(8540,'South Mills','South Mills, North Carolina',10277,33);
INSERT INTO "django_geo_db_city" VALUES(8541,'Stumpy Point','Stumpy Point, North Carolina',10278,33);
INSERT INTO "django_geo_db_city" VALUES(8542,'Sunbury','Sunbury, North Carolina',10279,33);
INSERT INTO "django_geo_db_city" VALUES(8543,'Tyner','Tyner, North Carolina',10280,33);
INSERT INTO "django_geo_db_city" VALUES(8544,'Wanchese','Wanchese, North Carolina',10281,33);
INSERT INTO "django_geo_db_city" VALUES(8545,'Waves','Waves, North Carolina',10282,33);
INSERT INTO "django_geo_db_city" VALUES(8546,'Windsor','Windsor, North Carolina',10283,33);
INSERT INTO "django_geo_db_city" VALUES(8547,'Winfall','Winfall, North Carolina',10284,33);
INSERT INTO "django_geo_db_city" VALUES(8548,'Winton','Winton, North Carolina',10285,33);
INSERT INTO "django_geo_db_city" VALUES(8549,'Albemarle','Albemarle, North Carolina',10286,33);
INSERT INTO "django_geo_db_city" VALUES(8550,'Marshville','Marshville, North Carolina',10288,33);
INSERT INTO "django_geo_db_city" VALUES(8551,'Alexis','Alexis, North Carolina',10289,33);
INSERT INTO "django_geo_db_city" VALUES(8552,'Ansonville','Ansonville, North Carolina',10290,33);
INSERT INTO "django_geo_db_city" VALUES(8553,'Badin','Badin, North Carolina',10291,33);
INSERT INTO "django_geo_db_city" VALUES(8554,'Barium Springs','Barium Springs, North Carolina',10292,33);
INSERT INTO "django_geo_db_city" VALUES(8555,'Belmont','Belmont, North Carolina',10293,33);
INSERT INTO "django_geo_db_city" VALUES(8556,'Bessemer City','Bessemer City, North Carolina',10294,33);
INSERT INTO "django_geo_db_city" VALUES(8557,'Boiling Springs','Boiling Springs, North Carolina',10295,33);
INSERT INTO "django_geo_db_city" VALUES(8558,'Bostic','Bostic, North Carolina',10296,33);
INSERT INTO "django_geo_db_city" VALUES(8559,'Caroleen','Caroleen, North Carolina',10297,33);
INSERT INTO "django_geo_db_city" VALUES(8560,'Casar','Casar, North Carolina',10298,33);
INSERT INTO "django_geo_db_city" VALUES(8561,'Cherryville','Cherryville, North Carolina',10299,33);
INSERT INTO "django_geo_db_city" VALUES(8562,'China Grove','China Grove, North Carolina',10300,33);
INSERT INTO "django_geo_db_city" VALUES(8563,'Cliffside','Cliffside, North Carolina',10301,33);
INSERT INTO "django_geo_db_city" VALUES(8564,'Concord','Concord, North Carolina',10302,33);
INSERT INTO "django_geo_db_city" VALUES(8565,'Cornelius','Cornelius, North Carolina',10305,33);
INSERT INTO "django_geo_db_city" VALUES(8566,'Cramerton','Cramerton, North Carolina',10306,33);
INSERT INTO "django_geo_db_city" VALUES(8567,'Crouse','Crouse, North Carolina',10307,33);
INSERT INTO "django_geo_db_city" VALUES(8568,'Dallas','Dallas, North Carolina',10308,33);
INSERT INTO "django_geo_db_city" VALUES(8569,'Davidson','Davidson, North Carolina',10309,33);
INSERT INTO "django_geo_db_city" VALUES(8570,'Denver','Denver, North Carolina',10310,33);
INSERT INTO "django_geo_db_city" VALUES(8571,'Earl','Earl, North Carolina',10311,33);
INSERT INTO "django_geo_db_city" VALUES(8572,'East Spencer','East Spencer, North Carolina',10312,33);
INSERT INTO "django_geo_db_city" VALUES(8573,'Ellenboro','Ellenboro, North Carolina',10313,33);
INSERT INTO "django_geo_db_city" VALUES(8574,'Faith','Faith, North Carolina',10314,33);
INSERT INTO "django_geo_db_city" VALUES(8575,'Fallston','Fallston, North Carolina',10315,33);
INSERT INTO "django_geo_db_city" VALUES(8576,'Forest City','Forest City, North Carolina',10316,33);
INSERT INTO "django_geo_db_city" VALUES(8577,'Gastonia','Gastonia, North Carolina',10317,33);
INSERT INTO "django_geo_db_city" VALUES(8578,'Huntersville','Huntersville, North Carolina',10322,33);
INSERT INTO "django_geo_db_city" VALUES(8579,'Gold Hill','Gold Hill, North Carolina',10323,33);
INSERT INTO "django_geo_db_city" VALUES(8580,'Granite Quarry','Granite Quarry, North Carolina',10324,33);
INSERT INTO "django_geo_db_city" VALUES(8581,'Grover','Grover, North Carolina',10325,33);
INSERT INTO "django_geo_db_city" VALUES(8582,'Harris','Harris, North Carolina',10326,33);
INSERT INTO "django_geo_db_city" VALUES(8583,'Harrisburg','Harrisburg, North Carolina',10327,33);
INSERT INTO "django_geo_db_city" VALUES(8584,'Henrietta','Henrietta, North Carolina',10328,33);
INSERT INTO "django_geo_db_city" VALUES(8585,'High Shoals','High Shoals, North Carolina',10329,33);
INSERT INTO "django_geo_db_city" VALUES(8586,'Indian Trail','Indian Trail, North Carolina',10331,33);
INSERT INTO "django_geo_db_city" VALUES(8587,'Iron Station','Iron Station, North Carolina',10332,33);
INSERT INTO "django_geo_db_city" VALUES(8588,'Kannapolis','Kannapolis, North Carolina',10333,33);
INSERT INTO "django_geo_db_city" VALUES(8589,'Kings Mountain','Kings Mountain, North Carolina',10335,33);
INSERT INTO "django_geo_db_city" VALUES(8590,'Landis','Landis, North Carolina',10336,33);
INSERT INTO "django_geo_db_city" VALUES(8591,'Lattimore','Lattimore, North Carolina',10337,33);
INSERT INTO "django_geo_db_city" VALUES(8592,'Lawndale','Lawndale, North Carolina',10338,33);
INSERT INTO "django_geo_db_city" VALUES(8593,'Lilesville','Lilesville, North Carolina',10339,33);
INSERT INTO "django_geo_db_city" VALUES(8594,'Lincolnton','Lincolnton, North Carolina',10340,33);
INSERT INTO "django_geo_db_city" VALUES(8595,'Locust','Locust, North Carolina',10342,33);
INSERT INTO "django_geo_db_city" VALUES(8596,'Lowell','Lowell, North Carolina',10343,33);
INSERT INTO "django_geo_db_city" VALUES(8597,'McAdenville','McAdenville, North Carolina',10344,33);
INSERT INTO "django_geo_db_city" VALUES(8598,'McFarlan','McFarlan, North Carolina',10345,33);
INSERT INTO "django_geo_db_city" VALUES(8599,'Matthews','Matthews, North Carolina',10347,33);
INSERT INTO "django_geo_db_city" VALUES(8600,'Midland','Midland, North Carolina',10350,33);
INSERT INTO "django_geo_db_city" VALUES(8601,'Mineral Springs','Mineral Springs, North Carolina',10351,33);
INSERT INTO "django_geo_db_city" VALUES(8602,'Misenheimer','Misenheimer, North Carolina',10352,33);
INSERT INTO "django_geo_db_city" VALUES(8603,'Monroe','Monroe, North Carolina',10353,33);
INSERT INTO "django_geo_db_city" VALUES(8604,'Mooresboro','Mooresboro, North Carolina',10356,33);
INSERT INTO "django_geo_db_city" VALUES(8605,'Mooresville','Mooresville, North Carolina',10357,33);
INSERT INTO "django_geo_db_city" VALUES(8606,'Morven','Morven, North Carolina',10359,33);
INSERT INTO "django_geo_db_city" VALUES(8607,'Mount Holly','Mount Holly, North Carolina',10360,33);
INSERT INTO "django_geo_db_city" VALUES(8608,'Mount Mourne','Mount Mourne, North Carolina',10361,33);
INSERT INTO "django_geo_db_city" VALUES(8609,'Mount Pleasant','Mount Pleasant, North Carolina',10362,33);
INSERT INTO "django_geo_db_city" VALUES(8610,'Mount Ulla','Mount Ulla, North Carolina',10363,33);
INSERT INTO "django_geo_db_city" VALUES(8611,'Newell','Newell, North Carolina',10364,33);
INSERT INTO "django_geo_db_city" VALUES(8612,'New London','New London, North Carolina',10365,33);
INSERT INTO "django_geo_db_city" VALUES(8613,'Norwood','Norwood, North Carolina',10366,33);
INSERT INTO "django_geo_db_city" VALUES(8614,'Oakboro','Oakboro, North Carolina',10367,33);
INSERT INTO "django_geo_db_city" VALUES(8615,'Paw Creek','Paw Creek, North Carolina',10349,33);
INSERT INTO "django_geo_db_city" VALUES(8616,'Peachland','Peachland, North Carolina',10368,33);
INSERT INTO "django_geo_db_city" VALUES(8617,'Pineville','Pineville, North Carolina',10369,33);
INSERT INTO "django_geo_db_city" VALUES(8618,'Polkton','Polkton, North Carolina',10370,33);
INSERT INTO "django_geo_db_city" VALUES(8619,'Polkville','Polkville, North Carolina',10371,33);
INSERT INTO "django_geo_db_city" VALUES(8620,'Richfield','Richfield, North Carolina',10372,33);
INSERT INTO "django_geo_db_city" VALUES(8621,'Rockwell','Rockwell, North Carolina',10373,33);
INSERT INTO "django_geo_db_city" VALUES(8622,'Rutherfordton','Rutherfordton, North Carolina',10374,33);
INSERT INTO "django_geo_db_city" VALUES(8623,'Shelby','Shelby, North Carolina',10379,33);
INSERT INTO "django_geo_db_city" VALUES(8624,'Spencer','Spencer, North Carolina',10382,33);
INSERT INTO "django_geo_db_city" VALUES(8625,'Spindale','Spindale, North Carolina',10383,33);
INSERT INTO "django_geo_db_city" VALUES(8626,'Stanfield','Stanfield, North Carolina',10384,33);
INSERT INTO "django_geo_db_city" VALUES(8627,'Stanley','Stanley, North Carolina',10385,33);
INSERT INTO "django_geo_db_city" VALUES(8628,'Troutman','Troutman, North Carolina',10386,33);
INSERT INTO "django_geo_db_city" VALUES(8629,'Union Mills','Union Mills, North Carolina',10387,33);
INSERT INTO "django_geo_db_city" VALUES(8630,'Vale','Vale, North Carolina',10388,33);
INSERT INTO "django_geo_db_city" VALUES(8631,'Waco','Waco, North Carolina',10389,33);
INSERT INTO "django_geo_db_city" VALUES(8632,'Wadesboro','Wadesboro, North Carolina',10390,33);
INSERT INTO "django_geo_db_city" VALUES(8633,'Waxhaw','Waxhaw, North Carolina',10391,33);
INSERT INTO "django_geo_db_city" VALUES(8634,'Wingate','Wingate, North Carolina',10392,33);
INSERT INTO "django_geo_db_city" VALUES(8635,'Charlotte','Charlotte, North Carolina',10349,33);
INSERT INTO "django_geo_db_city" VALUES(8636,'Fayetteville','Fayetteville, North Carolina',10425,33);
INSERT INTO "django_geo_db_city" VALUES(8637,'Fort Bragg','Fort Bragg, North Carolina',10431,33);
INSERT INTO "django_geo_db_city" VALUES(8638,'Pope A F B','Pope A F B, North Carolina',10432,33);
INSERT INTO "django_geo_db_city" VALUES(8639,'Aberdeen','Aberdeen, North Carolina',10437,33);
INSERT INTO "django_geo_db_city" VALUES(8640,'Autryville','Autryville, North Carolina',10438,33);
INSERT INTO "django_geo_db_city" VALUES(8641,'Barnesville','Barnesville, North Carolina',10439,33);
INSERT INTO "django_geo_db_city" VALUES(8642,'Bladenboro','Bladenboro, North Carolina',10440,33);
INSERT INTO "django_geo_db_city" VALUES(8643,'Bunnlevel','Bunnlevel, North Carolina',10441,33);
INSERT INTO "django_geo_db_city" VALUES(8644,'Calypso','Calypso, North Carolina',10442,33);
INSERT INTO "django_geo_db_city" VALUES(8645,'Cameron','Cameron, North Carolina',10443,33);
INSERT INTO "django_geo_db_city" VALUES(8646,'Carthage','Carthage, North Carolina',10444,33);
INSERT INTO "django_geo_db_city" VALUES(8647,'Clinton','Clinton, North Carolina',10445,33);
INSERT INTO "django_geo_db_city" VALUES(8648,'Cordova','Cordova, North Carolina',10447,33);
INSERT INTO "django_geo_db_city" VALUES(8649,'Cumberland','Cumberland, North Carolina',10448,33);
INSERT INTO "django_geo_db_city" VALUES(8650,'Dublin','Dublin, North Carolina',10449,33);
INSERT INTO "django_geo_db_city" VALUES(8651,'Dudley','Dudley, North Carolina',10450,33);
INSERT INTO "django_geo_db_city" VALUES(8652,'Dunn','Dunn, North Carolina',10451,33);
INSERT INTO "django_geo_db_city" VALUES(8653,'Elizabethtown','Elizabethtown, North Carolina',10453,33);
INSERT INTO "django_geo_db_city" VALUES(8654,'Ellerbe','Ellerbe, North Carolina',10454,33);
INSERT INTO "django_geo_db_city" VALUES(8655,'Erwin','Erwin, North Carolina',10455,33);
INSERT INTO "django_geo_db_city" VALUES(8656,'Fairmont','Fairmont, North Carolina',10456,33);
INSERT INTO "django_geo_db_city" VALUES(8657,'Faison','Faison, North Carolina',10457,33);
INSERT INTO "django_geo_db_city" VALUES(8658,'Falcon','Falcon, North Carolina',10458,33);
INSERT INTO "django_geo_db_city" VALUES(8659,'Gibson','Gibson, North Carolina',10459,33);
INSERT INTO "django_geo_db_city" VALUES(8660,'Godwin','Godwin, North Carolina',10460,33);
INSERT INTO "django_geo_db_city" VALUES(8661,'Hamlet','Hamlet, North Carolina',10461,33);
INSERT INTO "django_geo_db_city" VALUES(8662,'Hoffman','Hoffman, North Carolina',10462,33);
INSERT INTO "django_geo_db_city" VALUES(8663,'Hope Mills','Hope Mills, North Carolina',10463,33);
INSERT INTO "django_geo_db_city" VALUES(8664,'Kenansville','Kenansville, North Carolina',10464,33);
INSERT INTO "django_geo_db_city" VALUES(8665,'Lakeview','Lakeview, North Carolina',10465,33);
INSERT INTO "django_geo_db_city" VALUES(8666,'Laurel Hill','Laurel Hill, North Carolina',10466,33);
INSERT INTO "django_geo_db_city" VALUES(8667,'Laurinburg','Laurinburg, North Carolina',10467,33);
INSERT INTO "django_geo_db_city" VALUES(8668,'Lemon Springs','Lemon Springs, North Carolina',9942,33);
INSERT INTO "django_geo_db_city" VALUES(8669,'Linden','Linden, North Carolina',10469,33);
INSERT INTO "django_geo_db_city" VALUES(8670,'Lumber Bridge','Lumber Bridge, North Carolina',10470,33);
INSERT INTO "django_geo_db_city" VALUES(8671,'Lumberton','Lumberton, North Carolina',10471,33);
INSERT INTO "django_geo_db_city" VALUES(8672,'Mccain','Mccain, North Carolina',10474,33);
INSERT INTO "django_geo_db_city" VALUES(8673,'Marietta','Marietta, North Carolina',10475,33);
INSERT INTO "django_geo_db_city" VALUES(8674,'Marston','Marston, North Carolina',10476,33);
INSERT INTO "django_geo_db_city" VALUES(8675,'Maxton','Maxton, North Carolina',10477,33);
INSERT INTO "django_geo_db_city" VALUES(8676,'Mount Olive','Mount Olive, North Carolina',10478,33);
INSERT INTO "django_geo_db_city" VALUES(8677,'Newton Grove','Newton Grove, North Carolina',10479,33);
INSERT INTO "django_geo_db_city" VALUES(8678,'Norman','Norman, North Carolina',10480,33);
INSERT INTO "django_geo_db_city" VALUES(8679,'Olivia','Olivia, North Carolina',10481,33);
INSERT INTO "django_geo_db_city" VALUES(8680,'Orrum','Orrum, North Carolina',10482,33);
INSERT INTO "django_geo_db_city" VALUES(8681,'Pinehurst','Pinehurst, North Carolina',10483,33);
INSERT INTO "django_geo_db_city" VALUES(8682,'Parkton','Parkton, North Carolina',10484,33);
INSERT INTO "django_geo_db_city" VALUES(8683,'Pembroke','Pembroke, North Carolina',10485,33);
INSERT INTO "django_geo_db_city" VALUES(8684,'Pinebluff','Pinebluff, North Carolina',10486,33);
INSERT INTO "django_geo_db_city" VALUES(8685,'Proctorville','Proctorville, North Carolina',10488,33);
INSERT INTO "django_geo_db_city" VALUES(8686,'Raeford','Raeford, North Carolina',10489,33);
INSERT INTO "django_geo_db_city" VALUES(8687,'Red Springs','Red Springs, North Carolina',10490,33);
INSERT INTO "django_geo_db_city" VALUES(8688,'Rex','Rex, North Carolina',10491,33);
INSERT INTO "django_geo_db_city" VALUES(8689,'Rockingham','Rockingham, North Carolina',10492,33);
INSERT INTO "django_geo_db_city" VALUES(8690,'Roseboro','Roseboro, North Carolina',10494,33);
INSERT INTO "django_geo_db_city" VALUES(8691,'Rowland','Rowland, North Carolina',10495,33);
INSERT INTO "django_geo_db_city" VALUES(8692,'Saint Pauls','Saint Pauls, North Carolina',10496,33);
INSERT INTO "django_geo_db_city" VALUES(8693,'Salemburg','Salemburg, North Carolina',10497,33);
INSERT INTO "django_geo_db_city" VALUES(8694,'Shannon','Shannon, North Carolina',10498,33);
INSERT INTO "django_geo_db_city" VALUES(8695,'Southern Pines','Southern Pines, North Carolina',10499,33);
INSERT INTO "django_geo_db_city" VALUES(8696,'Spring Lake','Spring Lake, North Carolina',10501,33);
INSERT INTO "django_geo_db_city" VALUES(8697,'Stedman','Stedman, North Carolina',10502,33);
INSERT INTO "django_geo_db_city" VALUES(8698,'Tar Heel','Tar Heel, North Carolina',10503,33);
INSERT INTO "django_geo_db_city" VALUES(8699,'Turkey','Turkey, North Carolina',10504,33);
INSERT INTO "django_geo_db_city" VALUES(8700,'Vass','Vass, North Carolina',10505,33);
INSERT INTO "django_geo_db_city" VALUES(8701,'Wade','Wade, North Carolina',10506,33);
INSERT INTO "django_geo_db_city" VALUES(8702,'Wagram','Wagram, North Carolina',10507,33);
INSERT INTO "django_geo_db_city" VALUES(8703,'Warsaw','Warsaw, North Carolina',10509,33);
INSERT INTO "django_geo_db_city" VALUES(8704,'White Oak','White Oak, North Carolina',10510,33);
INSERT INTO "django_geo_db_city" VALUES(8705,'Wilmington','Wilmington, North Carolina',10511,33);
INSERT INTO "django_geo_db_city" VALUES(8706,'Ash','Ash, North Carolina',10521,33);
INSERT INTO "django_geo_db_city" VALUES(8707,'Atkinson','Atkinson, North Carolina',10522,33);
INSERT INTO "django_geo_db_city" VALUES(8708,'Bolivia','Bolivia, North Carolina',10523,33);
INSERT INTO "django_geo_db_city" VALUES(8709,'Bolton','Bolton, North Carolina',10524,33);
INSERT INTO "django_geo_db_city" VALUES(8710,'Brunswick','Brunswick, North Carolina',10525,33);
INSERT INTO "django_geo_db_city" VALUES(8711,'Burgaw','Burgaw, North Carolina',10526,33);
INSERT INTO "django_geo_db_city" VALUES(8712,'Carolina Beach','Carolina Beach, North Carolina',10527,33);
INSERT INTO "django_geo_db_city" VALUES(8713,'Castle Hayne','Castle Hayne, North Carolina',10528,33);
INSERT INTO "django_geo_db_city" VALUES(8714,'Cerro Gordo','Cerro Gordo, North Carolina',10529,33);
INSERT INTO "django_geo_db_city" VALUES(8715,'Chadbourn','Chadbourn, North Carolina',10530,33);
INSERT INTO "django_geo_db_city" VALUES(8716,'Clarendon','Clarendon, North Carolina',10531,33);
INSERT INTO "django_geo_db_city" VALUES(8717,'Clarkton','Clarkton, North Carolina',10532,33);
INSERT INTO "django_geo_db_city" VALUES(8718,'Council','Council, North Carolina',10533,33);
INSERT INTO "django_geo_db_city" VALUES(8719,'Currie','Currie, North Carolina',10534,33);
INSERT INTO "django_geo_db_city" VALUES(8720,'Delco','Delco, North Carolina',10535,33);
INSERT INTO "django_geo_db_city" VALUES(8721,'Evergreen','Evergreen, North Carolina',10536,33);
INSERT INTO "django_geo_db_city" VALUES(8722,'Fair Bluff','Fair Bluff, North Carolina',10537,33);
INSERT INTO "django_geo_db_city" VALUES(8723,'Garland','Garland, North Carolina',10538,33);
INSERT INTO "django_geo_db_city" VALUES(8724,'Hallsboro','Hallsboro, North Carolina',10539,33);
INSERT INTO "django_geo_db_city" VALUES(8725,'Hampstead','Hampstead, North Carolina',10540,33);
INSERT INTO "django_geo_db_city" VALUES(8726,'Harrells','Harrells, North Carolina',10541,33);
INSERT INTO "django_geo_db_city" VALUES(8727,'Holly Ridge','Holly Ridge, North Carolina',10542,33);
INSERT INTO "django_geo_db_city" VALUES(8728,'Ingold','Ingold, North Carolina',10543,33);
INSERT INTO "django_geo_db_city" VALUES(8729,'Ivanhoe','Ivanhoe, North Carolina',10544,33);
INSERT INTO "django_geo_db_city" VALUES(8730,'Kelly','Kelly, North Carolina',10545,33);
INSERT INTO "django_geo_db_city" VALUES(8731,'Kure Beach','Kure Beach, North Carolina',10546,33);
INSERT INTO "django_geo_db_city" VALUES(8732,'Lake Waccamaw','Lake Waccamaw, North Carolina',10547,33);
INSERT INTO "django_geo_db_city" VALUES(8733,'Leland','Leland, North Carolina',10548,33);
INSERT INTO "django_geo_db_city" VALUES(8734,'Longwood','Longwood, North Carolina',10549,33);
INSERT INTO "django_geo_db_city" VALUES(8735,'Magnolia','Magnolia, North Carolina',10550,33);
INSERT INTO "django_geo_db_city" VALUES(8736,'Maple Hill','Maple Hill, North Carolina',10551,33);
INSERT INTO "django_geo_db_city" VALUES(8737,'Nakina','Nakina, North Carolina',10552,33);
INSERT INTO "django_geo_db_city" VALUES(8738,'Riegelwood','Riegelwood, North Carolina',10553,33);
INSERT INTO "django_geo_db_city" VALUES(8739,'Rocky Point','Rocky Point, North Carolina',10554,33);
INSERT INTO "django_geo_db_city" VALUES(8740,'Rose Hill','Rose Hill, North Carolina',10555,33);
INSERT INTO "django_geo_db_city" VALUES(8741,'Shallotte','Shallotte, North Carolina',10556,33);
INSERT INTO "django_geo_db_city" VALUES(8742,'Sneads Ferry','Sneads Ferry, North Carolina',10557,33);
INSERT INTO "django_geo_db_city" VALUES(8743,'Southport','Southport, North Carolina',10558,33);
INSERT INTO "django_geo_db_city" VALUES(8744,'Supply','Supply, North Carolina',10559,33);
INSERT INTO "django_geo_db_city" VALUES(8745,'Tabor City','Tabor City, North Carolina',10560,33);
INSERT INTO "django_geo_db_city" VALUES(8746,'Teachey','Teachey, North Carolina',10561,33);
INSERT INTO "django_geo_db_city" VALUES(8747,'Oak Island','Oak Island, North Carolina',10562,33);
INSERT INTO "django_geo_db_city" VALUES(8748,'Wallace','Wallace, North Carolina',10563,33);
INSERT INTO "django_geo_db_city" VALUES(8749,'Calabash','Calabash, North Carolina',10564,33);
INSERT INTO "django_geo_db_city" VALUES(8750,'Sunset Beach','Sunset Beach, North Carolina',10565,33);
INSERT INTO "django_geo_db_city" VALUES(8751,'Ocean Isle Beach','Ocean Isle Beach, North Carolina',10566,33);
INSERT INTO "django_geo_db_city" VALUES(8752,'South Brunswick','South Brunswick, North Carolina',10567,33);
INSERT INTO "django_geo_db_city" VALUES(8753,'Watha','Watha, North Carolina',10568,33);
INSERT INTO "django_geo_db_city" VALUES(8754,'Whiteville','Whiteville, North Carolina',10569,33);
INSERT INTO "django_geo_db_city" VALUES(8755,'Willard','Willard, North Carolina',10570,33);
INSERT INTO "django_geo_db_city" VALUES(8756,'Winnabow','Winnabow, North Carolina',10571,33);
INSERT INTO "django_geo_db_city" VALUES(8757,'Wrightsville Beach','Wrightsville Beach, North Carolina',10572,33);
INSERT INTO "django_geo_db_city" VALUES(8758,'Kinston','Kinston, North Carolina',10573,33);
INSERT INTO "django_geo_db_city" VALUES(8759,'Albertson','Albertson, North Carolina',10577,33);
INSERT INTO "django_geo_db_city" VALUES(8760,'Alliance','Alliance, North Carolina',10578,33);
INSERT INTO "django_geo_db_city" VALUES(8761,'Arapahoe','Arapahoe, North Carolina',10579,33);
INSERT INTO "django_geo_db_city" VALUES(8762,'Atlantic','Atlantic, North Carolina',10580,33);
INSERT INTO "django_geo_db_city" VALUES(8763,'Atlantic Beach','Atlantic Beach, North Carolina',10581,33);
INSERT INTO "django_geo_db_city" VALUES(8764,'Ayden','Ayden, North Carolina',10582,33);
INSERT INTO "django_geo_db_city" VALUES(8765,'Bayboro','Bayboro, North Carolina',10583,33);
INSERT INTO "django_geo_db_city" VALUES(8766,'Beaufort','Beaufort, North Carolina',10584,33);
INSERT INTO "django_geo_db_city" VALUES(8767,'Beulaville','Beulaville, North Carolina',10585,33);
INSERT INTO "django_geo_db_city" VALUES(8768,'Bridgeton','Bridgeton, North Carolina',10586,33);
INSERT INTO "django_geo_db_city" VALUES(8769,'Cedar Island','Cedar Island, North Carolina',10587,33);
INSERT INTO "django_geo_db_city" VALUES(8770,'Chinquapin','Chinquapin, North Carolina',10588,33);
INSERT INTO "django_geo_db_city" VALUES(8771,'Comfort','Comfort, North Carolina',10589,33);
INSERT INTO "django_geo_db_city" VALUES(8772,'Cove City','Cove City, North Carolina',10590,33);
INSERT INTO "django_geo_db_city" VALUES(8773,'Davis','Davis, North Carolina',10591,33);
INSERT INTO "django_geo_db_city" VALUES(8774,'Deep Run','Deep Run, North Carolina',10592,33);
INSERT INTO "django_geo_db_city" VALUES(8775,'Dover','Dover, North Carolina',10593,33);
INSERT INTO "django_geo_db_city" VALUES(8776,'Ernul','Ernul, North Carolina',10594,33);
INSERT INTO "django_geo_db_city" VALUES(8777,'Gloucester','Gloucester, North Carolina',10595,33);
INSERT INTO "django_geo_db_city" VALUES(8778,'Grantsboro','Grantsboro, North Carolina',10596,33);
INSERT INTO "django_geo_db_city" VALUES(8779,'Grifton','Grifton, North Carolina',10597,33);
INSERT INTO "django_geo_db_city" VALUES(8780,'Harkers Island','Harkers Island, North Carolina',10598,33);
INSERT INTO "django_geo_db_city" VALUES(8781,'Havelock','Havelock, North Carolina',10599,33);
INSERT INTO "django_geo_db_city" VALUES(8782,'Cherry Point','Cherry Point, North Carolina',10600,33);
INSERT INTO "django_geo_db_city" VALUES(8783,'Hobucken','Hobucken, North Carolina',10601,33);
INSERT INTO "django_geo_db_city" VALUES(8784,'Hookerton','Hookerton, North Carolina',10602,33);
INSERT INTO "django_geo_db_city" VALUES(8785,'Hubert','Hubert, North Carolina',10603,33);
INSERT INTO "django_geo_db_city" VALUES(8786,'Jacksonville','Jacksonville, North Carolina',10604,33);
INSERT INTO "django_geo_db_city" VALUES(8787,'Camp Lejeune','Camp Lejeune, North Carolina',10606,33);
INSERT INTO "django_geo_db_city" VALUES(8788,'Tarawa Terrace','Tarawa Terrace, North Carolina',10607,33);
INSERT INTO "django_geo_db_city" VALUES(8789,'Midway Park','Midway Park, North Carolina',10608,33);
INSERT INTO "django_geo_db_city" VALUES(8790,'Mccutcheon Field','Mccutcheon Field, North Carolina',10605,33);
INSERT INTO "django_geo_db_city" VALUES(8791,'La Grange','La Grange, North Carolina',10611,33);
INSERT INTO "django_geo_db_city" VALUES(8792,'Lowland','Lowland, North Carolina',10612,33);
INSERT INTO "django_geo_db_city" VALUES(8793,'Marshallberg','Marshallberg, North Carolina',10613,33);
INSERT INTO "django_geo_db_city" VALUES(8794,'Maury','Maury, North Carolina',10614,33);
INSERT INTO "django_geo_db_city" VALUES(8795,'Maysville','Maysville, North Carolina',10615,33);
INSERT INTO "django_geo_db_city" VALUES(8796,'Merritt','Merritt, North Carolina',10616,33);
INSERT INTO "django_geo_db_city" VALUES(8797,'Morehead City','Morehead City, North Carolina',10617,33);
INSERT INTO "django_geo_db_city" VALUES(8798,'Fairplains','Fairplains, North Carolina',10618,33);
INSERT INTO "django_geo_db_city" VALUES(8799,'New Bern','New Bern, North Carolina',10619,33);
INSERT INTO "django_geo_db_city" VALUES(8800,'Newport','Newport, North Carolina',10623,33);
INSERT INTO "django_geo_db_city" VALUES(8801,'Oriental','Oriental, North Carolina',10624,33);
INSERT INTO "django_geo_db_city" VALUES(8802,'Pink Hill','Pink Hill, North Carolina',10625,33);
INSERT INTO "django_geo_db_city" VALUES(8803,'Pollocksville','Pollocksville, North Carolina',10626,33);
INSERT INTO "django_geo_db_city" VALUES(8804,'Richlands','Richlands, North Carolina',10627,33);
INSERT INTO "django_geo_db_city" VALUES(8805,'Salter Path','Salter Path, North Carolina',10628,33);
INSERT INTO "django_geo_db_city" VALUES(8806,'Sealevel','Sealevel, North Carolina',10629,33);
INSERT INTO "django_geo_db_city" VALUES(8807,'Seven Springs','Seven Springs, North Carolina',10630,33);
INSERT INTO "django_geo_db_city" VALUES(8808,'Smyrna','Smyrna, North Carolina',10631,33);
INSERT INTO "django_geo_db_city" VALUES(8809,'Snow Hill','Snow Hill, North Carolina',10632,33);
INSERT INTO "django_geo_db_city" VALUES(8810,'Stacy','Stacy, North Carolina',10633,33);
INSERT INTO "django_geo_db_city" VALUES(8811,'Stella','Stella, North Carolina',10634,33);
INSERT INTO "django_geo_db_city" VALUES(8812,'Stonewall','Stonewall, North Carolina',10578,33);
INSERT INTO "django_geo_db_city" VALUES(8813,'Swansboro','Swansboro, North Carolina',10635,33);
INSERT INTO "django_geo_db_city" VALUES(8814,'Trenton','Trenton, North Carolina',10636,33);
INSERT INTO "django_geo_db_city" VALUES(8815,'Vanceboro','Vanceboro, North Carolina',10637,33);
INSERT INTO "django_geo_db_city" VALUES(8816,'Vandemere','Vandemere, North Carolina',10638,33);
INSERT INTO "django_geo_db_city" VALUES(8817,'Williston','Williston, North Carolina',10639,33);
INSERT INTO "django_geo_db_city" VALUES(8818,'Winterville','Winterville, North Carolina',10640,33);
INSERT INTO "django_geo_db_city" VALUES(8819,'Emerald Isle','Emerald Isle, North Carolina',10641,33);
INSERT INTO "django_geo_db_city" VALUES(8820,'Hickory','Hickory, North Carolina',10643,33);
INSERT INTO "django_geo_db_city" VALUES(8821,'Banner Elk','Banner Elk, North Carolina',10646,33);
INSERT INTO "django_geo_db_city" VALUES(8822,'Blowing Rock','Blowing Rock, North Carolina',10647,33);
INSERT INTO "django_geo_db_city" VALUES(8823,'Boomer','Boomer, North Carolina',10648,33);
INSERT INTO "django_geo_db_city" VALUES(8824,'Boone','Boone, North Carolina',10649,33);
INSERT INTO "django_geo_db_city" VALUES(8825,'Catawba','Catawba, North Carolina',10651,33);
INSERT INTO "django_geo_db_city" VALUES(8826,'Claremont','Claremont, North Carolina',10652,33);
INSERT INTO "django_geo_db_city" VALUES(8827,'Collettsville','Collettsville, North Carolina',10653,33);
INSERT INTO "django_geo_db_city" VALUES(8828,'Connellys Springs','Connellys Springs, North Carolina',10654,33);
INSERT INTO "django_geo_db_city" VALUES(8829,'Conover','Conover, North Carolina',10655,33);
INSERT INTO "django_geo_db_city" VALUES(8830,'Creston','Creston, North Carolina',10656,33);
INSERT INTO "django_geo_db_city" VALUES(8831,'Crossnore','Crossnore, North Carolina',10657,33);
INSERT INTO "django_geo_db_city" VALUES(8832,'Crumpler','Crumpler, North Carolina',10658,33);
INSERT INTO "django_geo_db_city" VALUES(8833,'Deep Gap','Deep Gap, North Carolina',10659,33);
INSERT INTO "django_geo_db_city" VALUES(8834,'Drexel','Drexel, North Carolina',10660,33);
INSERT INTO "django_geo_db_city" VALUES(8835,'Elkin','Elkin, North Carolina',10662,33);
INSERT INTO "django_geo_db_city" VALUES(8836,'Elk Park','Elk Park, North Carolina',10663,33);
INSERT INTO "django_geo_db_city" VALUES(8837,'Ennice','Ennice, North Carolina',10664,33);
INSERT INTO "django_geo_db_city" VALUES(8838,'Ferguson','Ferguson, North Carolina',10665,33);
INSERT INTO "django_geo_db_city" VALUES(8839,'Statesville','Statesville, North Carolina',10666,33);
INSERT INTO "django_geo_db_city" VALUES(8840,'Fleetwood','Fleetwood, North Carolina',10667,33);
INSERT INTO "django_geo_db_city" VALUES(8841,'Glade Valley','Glade Valley, North Carolina',10668,33);
INSERT INTO "django_geo_db_city" VALUES(8842,'Glen Alpine','Glen Alpine, North Carolina',10669,33);
INSERT INTO "django_geo_db_city" VALUES(8843,'Glendale Springs','Glendale Springs, North Carolina',10670,33);
INSERT INTO "django_geo_db_city" VALUES(8844,'Granite Falls','Granite Falls, North Carolina',10671,33);
INSERT INTO "django_geo_db_city" VALUES(8845,'Grassy Creek','Grassy Creek, North Carolina',10672,33);
INSERT INTO "django_geo_db_city" VALUES(8846,'Lenoir','Lenoir, North Carolina',10673,33);
INSERT INTO "django_geo_db_city" VALUES(8847,'Harmony','Harmony, North Carolina',10674,33);
INSERT INTO "django_geo_db_city" VALUES(8848,'Hays','Hays, North Carolina',10675,33);
INSERT INTO "django_geo_db_city" VALUES(8849,'Hiddenite','Hiddenite, North Carolina',10676,33);
INSERT INTO "django_geo_db_city" VALUES(8850,'Hildebran','Hildebran, North Carolina',10677,33);
INSERT INTO "django_geo_db_city" VALUES(8851,'Hudson','Hudson, North Carolina',10678,33);
INSERT INTO "django_geo_db_city" VALUES(8852,'Jefferson','Jefferson, North Carolina',10679,33);
INSERT INTO "django_geo_db_city" VALUES(8853,'Jonas Ridge','Jonas Ridge, North Carolina',10680,33);
INSERT INTO "django_geo_db_city" VALUES(8854,'Jonesville','Jonesville, North Carolina',10681,33);
INSERT INTO "django_geo_db_city" VALUES(8855,'Lansing','Lansing, North Carolina',10682,33);
INSERT INTO "django_geo_db_city" VALUES(8856,'Laurel Springs','Laurel Springs, North Carolina',10683,33);
INSERT INTO "django_geo_db_city" VALUES(8857,'Linville','Linville, North Carolina',10685,33);
INSERT INTO "django_geo_db_city" VALUES(8858,'Linville Falls','Linville Falls, North Carolina',10686,33);
INSERT INTO "django_geo_db_city" VALUES(8859,'McGrady','McGrady, North Carolina',10687,33);
INSERT INTO "django_geo_db_city" VALUES(8860,'Maiden','Maiden, North Carolina',10688,33);
INSERT INTO "django_geo_db_city" VALUES(8861,'Millers Creek','Millers Creek, North Carolina',10689,33);
INSERT INTO "django_geo_db_city" VALUES(8862,'Minneapolis','Minneapolis, North Carolina',10690,33);
INSERT INTO "django_geo_db_city" VALUES(8863,'Montezuma','Montezuma, North Carolina',10691,33);
INSERT INTO "django_geo_db_city" VALUES(8864,'Moravian Falls','Moravian Falls, North Carolina',10692,33);
INSERT INTO "django_geo_db_city" VALUES(8865,'Morganton','Morganton, North Carolina',10693,33);
INSERT INTO "django_geo_db_city" VALUES(8866,'North Wilkesboro','North Wilkesboro, North Carolina',10694,33);
INSERT INTO "django_geo_db_city" VALUES(8867,'Newland','Newland, North Carolina',10695,33);
INSERT INTO "django_geo_db_city" VALUES(8868,'Newton','Newton, North Carolina',10696,33);
INSERT INTO "django_geo_db_city" VALUES(8869,'Olin','Olin, North Carolina',10698,33);
INSERT INTO "django_geo_db_city" VALUES(8870,'Patterson','Patterson, North Carolina',10699,33);
INSERT INTO "django_geo_db_city" VALUES(8871,'Pineola','Pineola, North Carolina',10700,33);
INSERT INTO "django_geo_db_city" VALUES(8872,'Piney Creek','Piney Creek, North Carolina',10701,33);
INSERT INTO "django_geo_db_city" VALUES(8873,'Plumtree','Plumtree, North Carolina',10702,33);
INSERT INTO "django_geo_db_city" VALUES(8874,'Purlear','Purlear, North Carolina',10703,33);
INSERT INTO "django_geo_db_city" VALUES(8875,'Icard','Icard, North Carolina',10704,33);
INSERT INTO "django_geo_db_city" VALUES(8876,'Rhodhiss','Rhodhiss, North Carolina',10705,33);
INSERT INTO "django_geo_db_city" VALUES(8877,'Roaring Gap','Roaring Gap, North Carolina',10706,33);
INSERT INTO "django_geo_db_city" VALUES(8878,'Roaring River','Roaring River, North Carolina',10707,33);
INSERT INTO "django_geo_db_city" VALUES(8879,'Ronda','Ronda, North Carolina',10708,33);
INSERT INTO "django_geo_db_city" VALUES(8880,'Rutherford College','Rutherford College, North Carolina',10709,33);
INSERT INTO "django_geo_db_city" VALUES(8881,'Scottville','Scottville, North Carolina',10710,33);
INSERT INTO "django_geo_db_city" VALUES(8882,'Sherrills Ford','Sherrills Ford, North Carolina',10711,33);
INSERT INTO "django_geo_db_city" VALUES(8883,'Sparta','Sparta, North Carolina',10713,33);
INSERT INTO "django_geo_db_city" VALUES(8884,'State Road','State Road, North Carolina',10714,33);
INSERT INTO "django_geo_db_city" VALUES(8885,'Stony Point','Stony Point, North Carolina',10716,33);
INSERT INTO "django_geo_db_city" VALUES(8886,'Sugar Grove','Sugar Grove, North Carolina',10717,33);
INSERT INTO "django_geo_db_city" VALUES(8887,'Taylorsville','Taylorsville, North Carolina',10719,33);
INSERT INTO "django_geo_db_city" VALUES(8888,'Terrell','Terrell, North Carolina',10720,33);
INSERT INTO "django_geo_db_city" VALUES(8889,'Thurmond','Thurmond, North Carolina',10721,33);
INSERT INTO "django_geo_db_city" VALUES(8890,'Todd','Todd, North Carolina',10722,33);
INSERT INTO "django_geo_db_city" VALUES(8891,'Traphill','Traphill, North Carolina',10723,33);
INSERT INTO "django_geo_db_city" VALUES(8892,'Turnersburg','Turnersburg, North Carolina',10361,33);
INSERT INTO "django_geo_db_city" VALUES(8893,'Union Grove','Union Grove, North Carolina',10724,33);
INSERT INTO "django_geo_db_city" VALUES(8894,'Valdese','Valdese, North Carolina',10725,33);
INSERT INTO "django_geo_db_city" VALUES(8895,'Valle Crucis','Valle Crucis, North Carolina',10726,33);
INSERT INTO "django_geo_db_city" VALUES(8896,'Vilas','Vilas, North Carolina',10727,33);
INSERT INTO "django_geo_db_city" VALUES(8897,'Warrensville','Warrensville, North Carolina',10728,33);
INSERT INTO "django_geo_db_city" VALUES(8898,'West Jefferson','West Jefferson, North Carolina',10729,33);
INSERT INTO "django_geo_db_city" VALUES(8899,'Wilkesboro','Wilkesboro, North Carolina',10730,33);
INSERT INTO "django_geo_db_city" VALUES(8900,'Zionville','Zionville, North Carolina',10731,33);
INSERT INTO "django_geo_db_city" VALUES(8901,'Scotts','Scotts, North Carolina',10732,33);
INSERT INTO "django_geo_db_city" VALUES(8902,'Alexander','Alexander, North Carolina',10733,33);
INSERT INTO "django_geo_db_city" VALUES(8903,'Almond','Almond, North Carolina',10734,33);
INSERT INTO "django_geo_db_city" VALUES(8904,'Arden','Arden, North Carolina',10735,33);
INSERT INTO "django_geo_db_city" VALUES(8905,'Bakersville','Bakersville, North Carolina',10736,33);
INSERT INTO "django_geo_db_city" VALUES(8906,'Balsam','Balsam, North Carolina',10737,33);
INSERT INTO "django_geo_db_city" VALUES(8907,'Balsam Grove','Balsam Grove, North Carolina',10738,33);
INSERT INTO "django_geo_db_city" VALUES(8908,'Barnardsville','Barnardsville, North Carolina',10739,33);
INSERT INTO "django_geo_db_city" VALUES(8909,'Bat Cave','Bat Cave, North Carolina',10740,33);
INSERT INTO "django_geo_db_city" VALUES(8910,'Black Mountain','Black Mountain, North Carolina',10741,33);
INSERT INTO "django_geo_db_city" VALUES(8911,'Brevard','Brevard, North Carolina',10742,33);
INSERT INTO "django_geo_db_city" VALUES(8912,'Bryson City','Bryson City, North Carolina',10743,33);
INSERT INTO "django_geo_db_city" VALUES(8913,'Burnsville','Burnsville, North Carolina',10744,33);
INSERT INTO "django_geo_db_city" VALUES(8914,'Candler','Candler, North Carolina',10745,33);
INSERT INTO "django_geo_db_city" VALUES(8915,'Canton','Canton, North Carolina',10746,33);
INSERT INTO "django_geo_db_city" VALUES(8916,'Cashiers','Cashiers, North Carolina',10747,33);
INSERT INTO "django_geo_db_city" VALUES(8917,'Cedar Mountain','Cedar Mountain, North Carolina',10748,33);
INSERT INTO "django_geo_db_city" VALUES(8918,'Cherokee','Cherokee, North Carolina',10749,33);
INSERT INTO "django_geo_db_city" VALUES(8919,'Chimney Rock','Chimney Rock, North Carolina',10750,33);
INSERT INTO "django_geo_db_city" VALUES(8920,'Clyde','Clyde, North Carolina',10751,33);
INSERT INTO "django_geo_db_city" VALUES(8921,'Columbus','Columbus, North Carolina',10752,33);
INSERT INTO "django_geo_db_city" VALUES(8922,'Cullowhee','Cullowhee, North Carolina',10753,33);
INSERT INTO "django_geo_db_city" VALUES(8923,'Dana','Dana, North Carolina',10754,33);
INSERT INTO "django_geo_db_city" VALUES(8924,'Dillsboro','Dillsboro, North Carolina',10755,33);
INSERT INTO "django_geo_db_city" VALUES(8925,'East Flat Rock','East Flat Rock, North Carolina',10756,33);
INSERT INTO "django_geo_db_city" VALUES(8926,'Edneyville','Edneyville, North Carolina',10757,33);
INSERT INTO "django_geo_db_city" VALUES(8927,'Enka','Enka, North Carolina',10758,33);
INSERT INTO "django_geo_db_city" VALUES(8928,'Etowah','Etowah, North Carolina',10759,33);
INSERT INTO "django_geo_db_city" VALUES(8929,'Fairview','Fairview, North Carolina',10760,33);
INSERT INTO "django_geo_db_city" VALUES(8930,'Flat Rock','Flat Rock, North Carolina',10761,33);
INSERT INTO "django_geo_db_city" VALUES(8931,'Fletcher','Fletcher, North Carolina',10762,33);
INSERT INTO "django_geo_db_city" VALUES(8932,'Fontana Dam','Fontana Dam, North Carolina',10763,33);
INSERT INTO "django_geo_db_city" VALUES(8933,'Franklin','Franklin, North Carolina',10764,33);
INSERT INTO "django_geo_db_city" VALUES(8934,'Gerton','Gerton, North Carolina',10765,33);
INSERT INTO "django_geo_db_city" VALUES(8935,'Glenville','Glenville, North Carolina',10766,33);
INSERT INTO "django_geo_db_city" VALUES(8936,'Glenwood','Glenwood, North Carolina',10767,33);
INSERT INTO "django_geo_db_city" VALUES(8937,'Hazelwood','Hazelwood, North Carolina',10768,33);
INSERT INTO "django_geo_db_city" VALUES(8938,'Hendersonville','Hendersonville, North Carolina',10769,33);
INSERT INTO "django_geo_db_city" VALUES(8939,'Greenmountain','Greenmountain, North Carolina',10770,33);
INSERT INTO "django_geo_db_city" VALUES(8940,'Highlands','Highlands, North Carolina',10771,33);
INSERT INTO "django_geo_db_city" VALUES(8941,'Horse Shoe','Horse Shoe, North Carolina',10772,33);
INSERT INTO "django_geo_db_city" VALUES(8942,'Hot Springs','Hot Springs, North Carolina',10773,33);
INSERT INTO "django_geo_db_city" VALUES(8943,'Lake Junaluska','Lake Junaluska, North Carolina',10775,33);
INSERT INTO "django_geo_db_city" VALUES(8944,'Lake Lure','Lake Lure, North Carolina',10776,33);
INSERT INTO "django_geo_db_city" VALUES(8945,'Lake Toxaway','Lake Toxaway, North Carolina',10777,33);
INSERT INTO "django_geo_db_city" VALUES(8946,'Leicester','Leicester, North Carolina',10778,33);
INSERT INTO "django_geo_db_city" VALUES(8947,'Little Switzerland','Little Switzerland, North Carolina',10779,33);
INSERT INTO "django_geo_db_city" VALUES(8948,'Lynn','Lynn, North Carolina',10780,33);
INSERT INTO "django_geo_db_city" VALUES(8949,'Maggie Valley','Maggie Valley, North Carolina',10781,33);
INSERT INTO "django_geo_db_city" VALUES(8950,'Marion','Marion, North Carolina',10782,33);
INSERT INTO "django_geo_db_city" VALUES(8951,'Marshall','Marshall, North Carolina',10783,33);
INSERT INTO "django_geo_db_city" VALUES(8952,'Mars Hill','Mars Hill, North Carolina',10784,33);
INSERT INTO "django_geo_db_city" VALUES(8953,'Micaville','Micaville, North Carolina',10785,33);
INSERT INTO "django_geo_db_city" VALUES(8954,'Mill Spring','Mill Spring, North Carolina',10786,33);
INSERT INTO "django_geo_db_city" VALUES(8955,'Montreat','Montreat, North Carolina',10787,33);
INSERT INTO "django_geo_db_city" VALUES(8956,'Mountain Home','Mountain Home, North Carolina',10788,33);
INSERT INTO "django_geo_db_city" VALUES(8957,'Naples','Naples, North Carolina',10789,33);
INSERT INTO "django_geo_db_city" VALUES(8958,'Nebo','Nebo, North Carolina',10790,33);
INSERT INTO "django_geo_db_city" VALUES(8959,'Old Fort','Old Fort, North Carolina',10791,33);
INSERT INTO "django_geo_db_city" VALUES(8960,'Otto','Otto, North Carolina',10792,33);
INSERT INTO "django_geo_db_city" VALUES(8961,'Penland','Penland, North Carolina',10793,33);
INSERT INTO "django_geo_db_city" VALUES(8962,'Penrose','Penrose, North Carolina',10794,33);
INSERT INTO "django_geo_db_city" VALUES(8963,'Pisgah Forest','Pisgah Forest, North Carolina',10796,33);
INSERT INTO "django_geo_db_city" VALUES(8964,'Ridgecrest','Ridgecrest, North Carolina',10797,33);
INSERT INTO "django_geo_db_city" VALUES(8965,'Robbinsville','Robbinsville, North Carolina',10798,33);
INSERT INTO "django_geo_db_city" VALUES(8966,'Rosman','Rosman, North Carolina',10799,33);
INSERT INTO "django_geo_db_city" VALUES(8967,'Saluda','Saluda, North Carolina',10800,33);
INSERT INTO "django_geo_db_city" VALUES(8968,'Sapphire','Sapphire, North Carolina',10801,33);
INSERT INTO "django_geo_db_city" VALUES(8969,'Scaly Mountain','Scaly Mountain, North Carolina',10802,33);
INSERT INTO "django_geo_db_city" VALUES(8970,'Skyland','Skyland, North Carolina',10803,33);
INSERT INTO "django_geo_db_city" VALUES(8971,'Spruce Pine','Spruce Pine, North Carolina',10804,33);
INSERT INTO "django_geo_db_city" VALUES(8972,'Swannanoa','Swannanoa, North Carolina',10805,33);
INSERT INTO "django_geo_db_city" VALUES(8973,'Sylva','Sylva, North Carolina',10806,33);
INSERT INTO "django_geo_db_city" VALUES(8974,'Topton','Topton, North Carolina',10807,33);
INSERT INTO "django_geo_db_city" VALUES(8975,'Tryon','Tryon, North Carolina',10808,33);
INSERT INTO "django_geo_db_city" VALUES(8976,'Tuckasegee','Tuckasegee, North Carolina',10809,33);
INSERT INTO "django_geo_db_city" VALUES(8977,'Tuxedo','Tuxedo, North Carolina',10810,33);
INSERT INTO "django_geo_db_city" VALUES(8978,'Waynesville','Waynesville, North Carolina',10812,33);
INSERT INTO "django_geo_db_city" VALUES(8979,'Weaverville','Weaverville, North Carolina',10813,33);
INSERT INTO "django_geo_db_city" VALUES(8980,'Webster','Webster, North Carolina',10814,33);
INSERT INTO "django_geo_db_city" VALUES(8981,'Whittier','Whittier, North Carolina',10815,33);
INSERT INTO "django_geo_db_city" VALUES(8982,'Zirconia','Zirconia, North Carolina',10816,33);
INSERT INTO "django_geo_db_city" VALUES(8983,'Asheville','Asheville, North Carolina',10821,33);
INSERT INTO "django_geo_db_city" VALUES(8984,'Wrightsboro','Wrightsboro, North Carolina',10833,33);
INSERT INTO "django_geo_db_city" VALUES(8985,'Andrews','Andrews, North Carolina',10835,33);
INSERT INTO "django_geo_db_city" VALUES(8986,'Brasstown','Brasstown, North Carolina',10836,33);
INSERT INTO "django_geo_db_city" VALUES(8987,'Culberson','Culberson, North Carolina',10837,33);
INSERT INTO "django_geo_db_city" VALUES(8988,'Hayesville','Hayesville, North Carolina',10838,33);
INSERT INTO "django_geo_db_city" VALUES(8989,'Marble','Marble, North Carolina',10839,33);
INSERT INTO "django_geo_db_city" VALUES(8990,'Murphy','Murphy, North Carolina',10840,33);
INSERT INTO "django_geo_db_city" VALUES(8991,'Warne','Warne, North Carolina',10841,33);
INSERT INTO "django_geo_db_city" VALUES(8992,'Alcolu','Alcolu, South Carolina',10846,48);
INSERT INTO "django_geo_db_city" VALUES(8993,'Ballentine','Ballentine, South Carolina',10847,48);
INSERT INTO "django_geo_db_city" VALUES(8994,'Bamberg','Bamberg, South Carolina',10848,48);
INSERT INTO "django_geo_db_city" VALUES(8995,'Batesburg','Batesburg, South Carolina',10849,48);
INSERT INTO "django_geo_db_city" VALUES(8996,'Bethune','Bethune, South Carolina',10850,48);
INSERT INTO "django_geo_db_city" VALUES(8997,'Bishopville','Bishopville, South Carolina',10851,48);
INSERT INTO "django_geo_db_city" VALUES(8998,'Blackstock','Blackstock, South Carolina',10852,48);
INSERT INTO "django_geo_db_city" VALUES(8999,'Blair','Blair, South Carolina',10853,48);
INSERT INTO "django_geo_db_city" VALUES(9000,'Blythewood','Blythewood, South Carolina',10854,48);
INSERT INTO "django_geo_db_city" VALUES(9001,'Bowman','Bowman, South Carolina',10855,48);
INSERT INTO "django_geo_db_city" VALUES(9002,'Camden','Camden, South Carolina',10856,48);
INSERT INTO "django_geo_db_city" VALUES(9003,'Cameron','Cameron, South Carolina',10857,48);
INSERT INTO "django_geo_db_city" VALUES(9004,'Carlisle','Carlisle, South Carolina',10858,48);
INSERT INTO "django_geo_db_city" VALUES(9005,'Cassatt','Cassatt, South Carolina',10859,48);
INSERT INTO "django_geo_db_city" VALUES(9006,'Cayce','Cayce, South Carolina',10860,48);
INSERT INTO "django_geo_db_city" VALUES(9007,'Chapin','Chapin, South Carolina',10861,48);
INSERT INTO "django_geo_db_city" VALUES(9008,'Chappells','Chappells, South Carolina',10862,48);
INSERT INTO "django_geo_db_city" VALUES(9009,'Cope','Cope, South Carolina',10863,48);
INSERT INTO "django_geo_db_city" VALUES(9010,'Cordova','Cordova, South Carolina',10864,48);
INSERT INTO "django_geo_db_city" VALUES(9011,'Dalzell','Dalzell, South Carolina',10865,48);
INSERT INTO "django_geo_db_city" VALUES(9012,'Davis Station','Davis Station, South Carolina',10866,48);
INSERT INTO "django_geo_db_city" VALUES(9013,'Denmark','Denmark, South Carolina',10867,48);
INSERT INTO "django_geo_db_city" VALUES(9014,'Eastover','Eastover, South Carolina',10868,48);
INSERT INTO "django_geo_db_city" VALUES(9015,'Elgin','Elgin, South Carolina',10869,48);
INSERT INTO "django_geo_db_city" VALUES(9016,'Elliott','Elliott, South Carolina',10870,48);
INSERT INTO "django_geo_db_city" VALUES(9017,'Elloree','Elloree, South Carolina',10871,48);
INSERT INTO "django_geo_db_city" VALUES(9018,'Eutawville','Eutawville, South Carolina',10872,48);
INSERT INTO "django_geo_db_city" VALUES(9019,'Gable','Gable, South Carolina',10873,48);
INSERT INTO "django_geo_db_city" VALUES(9020,'Gadsden','Gadsden, South Carolina',10874,48);
INSERT INTO "django_geo_db_city" VALUES(9021,'Gaston','Gaston, South Carolina',10875,48);
INSERT INTO "django_geo_db_city" VALUES(9022,'Gilbert','Gilbert, South Carolina',10876,48);
INSERT INTO "django_geo_db_city" VALUES(9023,'Great Falls','Great Falls, South Carolina',10877,48);
INSERT INTO "django_geo_db_city" VALUES(9024,'Greeleyville','Greeleyville, South Carolina',10878,48);
INSERT INTO "django_geo_db_city" VALUES(9025,'Heath Springs','Heath Springs, South Carolina',10879,48);
INSERT INTO "django_geo_db_city" VALUES(9026,'Holly Hill','Holly Hill, South Carolina',10880,48);
INSERT INTO "django_geo_db_city" VALUES(9027,'Hopkins','Hopkins, South Carolina',10881,48);
INSERT INTO "django_geo_db_city" VALUES(9028,'Horatio','Horatio, South Carolina',10882,48);
INSERT INTO "django_geo_db_city" VALUES(9029,'Irmo','Irmo, South Carolina',10883,48);
INSERT INTO "django_geo_db_city" VALUES(9030,'Jenkinsville','Jenkinsville, South Carolina',10884,48);
INSERT INTO "django_geo_db_city" VALUES(9031,'Batesburg-Leesville','Batesburg-Leesville, South Carolina',10885,48);
INSERT INTO "django_geo_db_city" VALUES(9032,'Kershaw','Kershaw, South Carolina',10886,48);
INSERT INTO "django_geo_db_city" VALUES(9033,'Lamar','Lamar, South Carolina',10887,48);
INSERT INTO "django_geo_db_city" VALUES(9034,'Leesville','Leesville, South Carolina',10888,48);
INSERT INTO "django_geo_db_city" VALUES(9035,'Lexington','Lexington, South Carolina',10889,48);
INSERT INTO "django_geo_db_city" VALUES(9036,'Liberty Hill','Liberty Hill, South Carolina',10892,48);
INSERT INTO "django_geo_db_city" VALUES(9037,'Little Mountain','Little Mountain, South Carolina',10893,48);
INSERT INTO "django_geo_db_city" VALUES(9038,'Lugoff','Lugoff, South Carolina',10894,48);
INSERT INTO "django_geo_db_city" VALUES(9039,'Lydia','Lydia, South Carolina',10895,48);
INSERT INTO "django_geo_db_city" VALUES(9040,'Lynchburg','Lynchburg, South Carolina',10896,48);
INSERT INTO "django_geo_db_city" VALUES(9041,'Ehrhardt','Ehrhardt, South Carolina',10897,48);
INSERT INTO "django_geo_db_city" VALUES(9042,'Lodge','Lodge, South Carolina',10898,48);
INSERT INTO "django_geo_db_city" VALUES(9043,'McBee','McBee, South Carolina',10899,48);
INSERT INTO "django_geo_db_city" VALUES(9044,'Manning','Manning, South Carolina',10900,48);
INSERT INTO "django_geo_db_city" VALUES(9045,'Mayesville','Mayesville, South Carolina',10901,48);
INSERT INTO "django_geo_db_city" VALUES(9046,'Monetta','Monetta, South Carolina',10903,48);
INSERT INTO "django_geo_db_city" VALUES(9047,'Monticello','Monticello, South Carolina',10904,48);
INSERT INTO "django_geo_db_city" VALUES(9048,'Neeses','Neeses, South Carolina',10905,48);
INSERT INTO "django_geo_db_city" VALUES(9049,'Newberry','Newberry, South Carolina',10906,48);
INSERT INTO "django_geo_db_city" VALUES(9050,'New Zion','New Zion, South Carolina',10907,48);
INSERT INTO "django_geo_db_city" VALUES(9051,'North','North, South Carolina',10908,48);
INSERT INTO "django_geo_db_city" VALUES(9052,'Norway','Norway, South Carolina',10909,48);
INSERT INTO "django_geo_db_city" VALUES(9053,'Olanta','Olanta, South Carolina',10910,48);
INSERT INTO "django_geo_db_city" VALUES(9054,'Orangeburg','Orangeburg, South Carolina',10911,48);
INSERT INTO "django_geo_db_city" VALUES(9055,'Peak','Peak, South Carolina',10915,48);
INSERT INTO "django_geo_db_city" VALUES(9056,'Pelion','Pelion, South Carolina',10916,48);
INSERT INTO "django_geo_db_city" VALUES(9057,'Perry','Perry, South Carolina',10917,48);
INSERT INTO "django_geo_db_city" VALUES(9058,'Pinewood','Pinewood, South Carolina',10918,48);
INSERT INTO "django_geo_db_city" VALUES(9059,'Pomaria','Pomaria, South Carolina',10919,48);
INSERT INTO "django_geo_db_city" VALUES(9060,'Prosperity','Prosperity, South Carolina',10920,48);
INSERT INTO "django_geo_db_city" VALUES(9061,'Rembert','Rembert, South Carolina',10921,48);
INSERT INTO "django_geo_db_city" VALUES(9062,'Ridge Spring','Ridge Spring, South Carolina',10922,48);
INSERT INTO "django_geo_db_city" VALUES(9063,'Ridgeway','Ridgeway, South Carolina',10923,48);
INSERT INTO "django_geo_db_city" VALUES(9064,'Rion','Rion, South Carolina',10924,48);
INSERT INTO "django_geo_db_city" VALUES(9065,'Rowesville','Rowesville, South Carolina',10925,48);
INSERT INTO "django_geo_db_city" VALUES(9066,'Saint Matthews','Saint Matthews, South Carolina',10926,48);
INSERT INTO "django_geo_db_city" VALUES(9067,'Salley','Salley, South Carolina',10927,48);
INSERT INTO "django_geo_db_city" VALUES(9068,'Saluda','Saluda, South Carolina',10928,48);
INSERT INTO "django_geo_db_city" VALUES(9069,'Santee','Santee, South Carolina',10929,48);
INSERT INTO "django_geo_db_city" VALUES(9070,'Sardinia','Sardinia, South Carolina',10866,48);
INSERT INTO "django_geo_db_city" VALUES(9071,'Silverstreet','Silverstreet, South Carolina',10930,48);
INSERT INTO "django_geo_db_city" VALUES(9072,'Springfield','Springfield, South Carolina',10931,48);
INSERT INTO "django_geo_db_city" VALUES(9073,'State Park','State Park, South Carolina',10932,48);
INSERT INTO "django_geo_db_city" VALUES(9074,'Summerton','Summerton, South Carolina',10933,48);
INSERT INTO "django_geo_db_city" VALUES(9075,'Sumter','Sumter, South Carolina',10934,48);
INSERT INTO "django_geo_db_city" VALUES(9076,'Shaw A F B','Shaw A F B, South Carolina',10936,48);
INSERT INTO "django_geo_db_city" VALUES(9077,'Swansea','Swansea, South Carolina',10939,48);
INSERT INTO "django_geo_db_city" VALUES(9078,'Timmonsville','Timmonsville, South Carolina',10940,48);
INSERT INTO "django_geo_db_city" VALUES(9079,'Turbeville','Turbeville, South Carolina',10941,48);
INSERT INTO "django_geo_db_city" VALUES(9080,'Vance','Vance, South Carolina',10942,48);
INSERT INTO "django_geo_db_city" VALUES(9081,'Wagener','Wagener, South Carolina',10943,48);
INSERT INTO "django_geo_db_city" VALUES(9082,'Ward','Ward, South Carolina',10944,48);
INSERT INTO "django_geo_db_city" VALUES(9083,'Wedgefield','Wedgefield, South Carolina',10945,48);
INSERT INTO "django_geo_db_city" VALUES(9084,'West Columbia','West Columbia, South Carolina',10946,48);
INSERT INTO "django_geo_db_city" VALUES(9085,'Westville','Westville, South Carolina',10949,48);
INSERT INTO "django_geo_db_city" VALUES(9086,'White Oak','White Oak, South Carolina',10904,48);
INSERT INTO "django_geo_db_city" VALUES(9087,'White Rock','White Rock, South Carolina',10950,48);
INSERT INTO "django_geo_db_city" VALUES(9088,'Whitmire','Whitmire, South Carolina',10951,48);
INSERT INTO "django_geo_db_city" VALUES(9089,'Winnsboro','Winnsboro, South Carolina',10952,48);
INSERT INTO "django_geo_db_city" VALUES(9090,'Columbia','Columbia, South Carolina',10953,48);
INSERT INTO "django_geo_db_city" VALUES(9091,'Clinton','Clinton, South Carolina',10969,48);
INSERT INTO "django_geo_db_city" VALUES(9092,'Spartanburg','Spartanburg, South Carolina',10970,48);
INSERT INTO "django_geo_db_city" VALUES(9093,'Arcadia','Arcadia, South Carolina',10979,48);
INSERT INTO "django_geo_db_city" VALUES(9094,'Buffalo','Buffalo, South Carolina',10980,48);
INSERT INTO "django_geo_db_city" VALUES(9095,'Campobello','Campobello, South Carolina',10981,48);
INSERT INTO "django_geo_db_city" VALUES(9096,'Chesnee','Chesnee, South Carolina',10982,48);
INSERT INTO "django_geo_db_city" VALUES(9097,'Clifton','Clifton, South Carolina',10983,48);
INSERT INTO "django_geo_db_city" VALUES(9098,'Converse','Converse, South Carolina',10985,48);
INSERT INTO "django_geo_db_city" VALUES(9099,'Cowpens','Cowpens, South Carolina',10986,48);
INSERT INTO "django_geo_db_city" VALUES(9100,'Cross Anchor','Cross Anchor, South Carolina',10987,48);
INSERT INTO "django_geo_db_city" VALUES(9101,'Cross Hill','Cross Hill, South Carolina',10988,48);
INSERT INTO "django_geo_db_city" VALUES(9102,'Drayton','Drayton, South Carolina',10989,48);
INSERT INTO "django_geo_db_city" VALUES(9103,'Duncan','Duncan, South Carolina',10990,48);
INSERT INTO "django_geo_db_city" VALUES(9104,'Enoree','Enoree, South Carolina',10991,48);
INSERT INTO "django_geo_db_city" VALUES(9105,'Fairforest','Fairforest, South Carolina',10978,48);
INSERT INTO "django_geo_db_city" VALUES(9106,'Fingerville','Fingerville, South Carolina',10992,48);
INSERT INTO "django_geo_db_city" VALUES(9107,'Gaffney','Gaffney, South Carolina',10993,48);
INSERT INTO "django_geo_db_city" VALUES(9108,'Glendale','Glendale, South Carolina',10996,48);
INSERT INTO "django_geo_db_city" VALUES(9109,'Gramling','Gramling, South Carolina',10978,48);
INSERT INTO "django_geo_db_city" VALUES(9110,'Inman','Inman, South Carolina',10997,48);
INSERT INTO "django_geo_db_city" VALUES(9111,'Joanna','Joanna, South Carolina',10998,48);
INSERT INTO "django_geo_db_city" VALUES(9112,'Jonesville','Jonesville, South Carolina',10999,48);
INSERT INTO "django_geo_db_city" VALUES(9113,'Kinards','Kinards, South Carolina',11000,48);
INSERT INTO "django_geo_db_city" VALUES(9114,'Landrum','Landrum, South Carolina',11001,48);
INSERT INTO "django_geo_db_city" VALUES(9115,'Laurens','Laurens, South Carolina',11002,48);
INSERT INTO "django_geo_db_city" VALUES(9116,'Lake View','Lake View, South Carolina',11003,48);
INSERT INTO "django_geo_db_city" VALUES(9117,'Lockhart','Lockhart, South Carolina',11004,48);
INSERT INTO "django_geo_db_city" VALUES(9118,'Lyman','Lyman, South Carolina',11005,48);
INSERT INTO "django_geo_db_city" VALUES(9119,'Mayo','Mayo, South Carolina',11006,48);
INSERT INTO "django_geo_db_city" VALUES(9120,'Moore','Moore, South Carolina',11007,48);
INSERT INTO "django_geo_db_city" VALUES(9121,'Mountville','Mountville, South Carolina',11008,48);
INSERT INTO "django_geo_db_city" VALUES(9122,'Pacolet','Pacolet, South Carolina',11009,48);
INSERT INTO "django_geo_db_city" VALUES(9123,'Pacolet Mills','Pacolet Mills, South Carolina',11010,48);
INSERT INTO "django_geo_db_city" VALUES(9124,'Pauline','Pauline, South Carolina',11011,48);
INSERT INTO "django_geo_db_city" VALUES(9125,'Reidville','Reidville, South Carolina',11012,48);
INSERT INTO "django_geo_db_city" VALUES(9126,'Roebuck','Roebuck, South Carolina',11013,48);
INSERT INTO "django_geo_db_city" VALUES(9127,'Startex','Startex, South Carolina',11014,48);
INSERT INTO "django_geo_db_city" VALUES(9128,'Una','Una, South Carolina',11015,48);
INSERT INTO "django_geo_db_city" VALUES(9129,'Union','Union, South Carolina',11016,48);
INSERT INTO "django_geo_db_city" VALUES(9130,'Waterloo','Waterloo, South Carolina',11017,48);
INSERT INTO "django_geo_db_city" VALUES(9131,'Wellford','Wellford, South Carolina',11018,48);
INSERT INTO "django_geo_db_city" VALUES(9132,'White Stone','White Stone, South Carolina',10978,48);
INSERT INTO "django_geo_db_city" VALUES(9133,'Woodruff','Woodruff, South Carolina',11019,48);
INSERT INTO "django_geo_db_city" VALUES(9134,'Charleston','Charleston, South Carolina',11020,48);
INSERT INTO "django_geo_db_city" VALUES(9135,'Charleston AFB','Charleston AFB, South Carolina',11023,48);
INSERT INTO "django_geo_db_city" VALUES(9136,'North Charleston','North Charleston, South Carolina',11024,48);
INSERT INTO "django_geo_db_city" VALUES(9137,'Adams Run','Adams Run, South Carolina',11035,48);
INSERT INTO "django_geo_db_city" VALUES(9138,'Awendaw','Awendaw, South Carolina',11036,48);
INSERT INTO "django_geo_db_city" VALUES(9139,'Bethera','Bethera, South Carolina',11037,48);
INSERT INTO "django_geo_db_city" VALUES(9140,'Bonneau','Bonneau, South Carolina',11038,48);
INSERT INTO "django_geo_db_city" VALUES(9141,'Branchville','Branchville, South Carolina',11039,48);
INSERT INTO "django_geo_db_city" VALUES(9142,'Canadys','Canadys, South Carolina',11040,48);
INSERT INTO "django_geo_db_city" VALUES(9143,'Cordesville','Cordesville, South Carolina',11041,48);
INSERT INTO "django_geo_db_city" VALUES(9144,'Cottageville','Cottageville, South Carolina',11042,48);
INSERT INTO "django_geo_db_city" VALUES(9145,'Cross','Cross, South Carolina',11043,48);
INSERT INTO "django_geo_db_city" VALUES(9146,'Dorchester','Dorchester, South Carolina',11044,48);
INSERT INTO "django_geo_db_city" VALUES(9147,'Edisto Island','Edisto Island, South Carolina',11045,48);
INSERT INTO "django_geo_db_city" VALUES(9148,'Folly Beach','Folly Beach, South Carolina',11046,48);
INSERT INTO "django_geo_db_city" VALUES(9149,'Georgetown','Georgetown, South Carolina',11047,48);
INSERT INTO "django_geo_db_city" VALUES(9150,'Goose Creek','Goose Creek, South Carolina',11049,48);
INSERT INTO "django_geo_db_city" VALUES(9151,'Green Pond','Green Pond, South Carolina',11050,48);
INSERT INTO "django_geo_db_city" VALUES(9152,'Grover','Grover, South Carolina',11051,48);
INSERT INTO "django_geo_db_city" VALUES(9153,'Harleyville','Harleyville, South Carolina',11052,48);
INSERT INTO "django_geo_db_city" VALUES(9154,'Hollywood','Hollywood, South Carolina',11053,48);
INSERT INTO "django_geo_db_city" VALUES(9155,'Huger','Huger, South Carolina',11054,48);
INSERT INTO "django_geo_db_city" VALUES(9156,'Isle Of Palms','Isle Of Palms, South Carolina',11055,48);
INSERT INTO "django_geo_db_city" VALUES(9157,'Jacksonboro','Jacksonboro, South Carolina',11056,48);
INSERT INTO "django_geo_db_city" VALUES(9158,'Jamestown','Jamestown, South Carolina',11057,48);
INSERT INTO "django_geo_db_city" VALUES(9159,'Johns Island','Johns Island, South Carolina',11058,48);
INSERT INTO "django_geo_db_city" VALUES(9160,'Ladson','Ladson, South Carolina',11059,48);
INSERT INTO "django_geo_db_city" VALUES(9161,'McClellanville','McClellanville, South Carolina',11060,48);
INSERT INTO "django_geo_db_city" VALUES(9162,'Moncks Corner','Moncks Corner, South Carolina',11061,48);
INSERT INTO "django_geo_db_city" VALUES(9163,'Mount Pleasant','Mount Pleasant, South Carolina',11062,48);
INSERT INTO "django_geo_db_city" VALUES(9164,'Pineville','Pineville, South Carolina',11064,48);
INSERT INTO "django_geo_db_city" VALUES(9165,'Pinopolis','Pinopolis, South Carolina',11065,48);
INSERT INTO "django_geo_db_city" VALUES(9166,'Ravenel','Ravenel, South Carolina',11066,48);
INSERT INTO "django_geo_db_city" VALUES(9167,'Reevesville','Reevesville, South Carolina',11067,48);
INSERT INTO "django_geo_db_city" VALUES(9168,'Ridgeville','Ridgeville, South Carolina',11068,48);
INSERT INTO "django_geo_db_city" VALUES(9169,'Round O','Round O, South Carolina',11069,48);
INSERT INTO "django_geo_db_city" VALUES(9170,'Ruffin','Ruffin, South Carolina',11070,48);
INSERT INTO "django_geo_db_city" VALUES(9171,'Russellville','Russellville, South Carolina',11071,48);
INSERT INTO "django_geo_db_city" VALUES(9172,'Saint George','Saint George, South Carolina',11072,48);
INSERT INTO "django_geo_db_city" VALUES(9173,'Saint Stephen','Saint Stephen, South Carolina',11073,48);
INSERT INTO "django_geo_db_city" VALUES(9174,'Smoaks','Smoaks, South Carolina',11074,48);
INSERT INTO "django_geo_db_city" VALUES(9175,'Sullivans Island','Sullivans Island, South Carolina',11075,48);
INSERT INTO "django_geo_db_city" VALUES(9176,'Summerville','Summerville, South Carolina',11076,48);
INSERT INTO "django_geo_db_city" VALUES(9177,'Wadmalaw Island','Wadmalaw Island, South Carolina',11079,48);
INSERT INTO "django_geo_db_city" VALUES(9178,'Walterboro','Walterboro, South Carolina',11080,48);
INSERT INTO "django_geo_db_city" VALUES(9179,'Williams','Williams, South Carolina',11082,48);
INSERT INTO "django_geo_db_city" VALUES(9180,'Florence','Florence, South Carolina',11084,48);
INSERT INTO "django_geo_db_city" VALUES(9181,'Andrews','Andrews, South Carolina',11090,48);
INSERT INTO "django_geo_db_city" VALUES(9182,'Aynor','Aynor, South Carolina',11091,48);
INSERT INTO "django_geo_db_city" VALUES(9183,'Bennettsville','Bennettsville, South Carolina',11092,48);
INSERT INTO "django_geo_db_city" VALUES(9184,'Blenheim','Blenheim, South Carolina',11093,48);
INSERT INTO "django_geo_db_city" VALUES(9185,'Cades','Cades, South Carolina',11094,48);
INSERT INTO "django_geo_db_city" VALUES(9186,'Centenary','Centenary, South Carolina',11095,48);
INSERT INTO "django_geo_db_city" VALUES(9187,'Cheraw','Cheraw, South Carolina',11096,48);
INSERT INTO "django_geo_db_city" VALUES(9188,'Clio','Clio, South Carolina',11097,48);
INSERT INTO "django_geo_db_city" VALUES(9189,'Conway','Conway, South Carolina',11098,48);
INSERT INTO "django_geo_db_city" VALUES(9190,'Coward','Coward, South Carolina',11101,48);
INSERT INTO "django_geo_db_city" VALUES(9191,'Darlington','Darlington, South Carolina',11102,48);
INSERT INTO "django_geo_db_city" VALUES(9192,'McCormick','McCormick, South Carolina',11103,48);
INSERT INTO "django_geo_db_city" VALUES(9193,'Dillon','Dillon, South Carolina',11104,48);
INSERT INTO "django_geo_db_city" VALUES(9194,'Effingham','Effingham, South Carolina',11106,48);
INSERT INTO "django_geo_db_city" VALUES(9195,'Floyd Dale','Floyd Dale, South Carolina',11107,48);
INSERT INTO "django_geo_db_city" VALUES(9196,'Fork','Fork, South Carolina',11108,48);
INSERT INTO "django_geo_db_city" VALUES(9197,'Galivants Ferry','Galivants Ferry, South Carolina',11109,48);
INSERT INTO "django_geo_db_city" VALUES(9198,'Green Sea','Green Sea, South Carolina',11110,48);
INSERT INTO "django_geo_db_city" VALUES(9199,'Gresham','Gresham, South Carolina',11111,48);
INSERT INTO "django_geo_db_city" VALUES(9200,'Hamer','Hamer, South Carolina',11112,48);
INSERT INTO "django_geo_db_city" VALUES(9201,'Myrtle Beach','Myrtle Beach, South Carolina',11113,48);
INSERT INTO "django_geo_db_city" VALUES(9202,'Hartsville','Hartsville, South Carolina',11114,48);
INSERT INTO "django_geo_db_city" VALUES(9203,'Hemingway','Hemingway, South Carolina',11116,48);
INSERT INTO "django_geo_db_city" VALUES(9204,'Johnsonville','Johnsonville, South Carolina',11117,48);
INSERT INTO "django_geo_db_city" VALUES(9205,'Kingstree','Kingstree, South Carolina',11118,48);
INSERT INTO "django_geo_db_city" VALUES(9206,'Lake City','Lake City, South Carolina',11119,48);
INSERT INTO "django_geo_db_city" VALUES(9207,'Latta','Latta, South Carolina',11120,48);
INSERT INTO "django_geo_db_city" VALUES(9208,'Lane','Lane, South Carolina',11122,48);
INSERT INTO "django_geo_db_city" VALUES(9209,'Little River','Little River, South Carolina',11124,48);
INSERT INTO "django_geo_db_city" VALUES(9210,'Little Rock','Little Rock, South Carolina',11125,48);
INSERT INTO "django_geo_db_city" VALUES(9211,'Longs','Longs, South Carolina',11126,48);
INSERT INTO "django_geo_db_city" VALUES(9212,'Loris','Loris, South Carolina',11127,48);
INSERT INTO "django_geo_db_city" VALUES(9213,'McColl','McColl, South Carolina',11128,48);
INSERT INTO "django_geo_db_city" VALUES(9214,'Marion','Marion, South Carolina',11129,48);
INSERT INTO "django_geo_db_city" VALUES(9215,'Minturn','Minturn, South Carolina',11131,48);
INSERT INTO "django_geo_db_city" VALUES(9216,'Mullins','Mullins, South Carolina',11132,48);
INSERT INTO "django_geo_db_city" VALUES(9217,'Murrells Inlet','Murrells Inlet, South Carolina',11134,48);
INSERT INTO "django_geo_db_city" VALUES(9218,'Nesmith','Nesmith, South Carolina',11138,48);
INSERT INTO "django_geo_db_city" VALUES(9219,'Nichols','Nichols, South Carolina',11139,48);
INSERT INTO "django_geo_db_city" VALUES(9220,'North Myrtle Beach','North Myrtle Beach, South Carolina',11140,48);
INSERT INTO "django_geo_db_city" VALUES(9221,'Pamplico','Pamplico, South Carolina',11141,48);
INSERT INTO "django_geo_db_city" VALUES(9222,'Patrick','Patrick, South Carolina',11142,48);
INSERT INTO "django_geo_db_city" VALUES(9223,'Pawleys Island','Pawleys Island, South Carolina',11143,48);
INSERT INTO "django_geo_db_city" VALUES(9224,'Rains','Rains, South Carolina',11146,48);
INSERT INTO "django_geo_db_city" VALUES(9225,'Salters','Salters, South Carolina',11147,48);
INSERT INTO "django_geo_db_city" VALUES(9226,'Scranton','Scranton, South Carolina',11148,48);
INSERT INTO "django_geo_db_city" VALUES(9227,'Sellers','Sellers, South Carolina',11149,48);
INSERT INTO "django_geo_db_city" VALUES(9228,'Society Hill','Society Hill, South Carolina',11150,48);
INSERT INTO "django_geo_db_city" VALUES(9229,'Tatum','Tatum, South Carolina',11151,48);
INSERT INTO "django_geo_db_city" VALUES(9230,'Wallace','Wallace, South Carolina',11152,48);
INSERT INTO "django_geo_db_city" VALUES(9231,'Socastee','Socastee, South Carolina',11154,48);
INSERT INTO "django_geo_db_city" VALUES(9232,'Greenville','Greenville, South Carolina',11155,48);
INSERT INTO "django_geo_db_city" VALUES(9233,'Abbeville','Abbeville, South Carolina',11167,48);
INSERT INTO "django_geo_db_city" VALUES(9234,'Anderson','Anderson, South Carolina',11168,48);
INSERT INTO "django_geo_db_city" VALUES(9235,'Belton','Belton, South Carolina',11174,48);
INSERT INTO "django_geo_db_city" VALUES(9236,'Calhoun Falls','Calhoun Falls, South Carolina',11175,48);
INSERT INTO "django_geo_db_city" VALUES(9237,'Central','Central, South Carolina',11176,48);
INSERT INTO "django_geo_db_city" VALUES(9238,'Clemson','Clemson, South Carolina',11177,48);
INSERT INTO "django_geo_db_city" VALUES(9239,'Cleveland','Cleveland, South Carolina',11179,48);
INSERT INTO "django_geo_db_city" VALUES(9240,'Conestee','Conestee, South Carolina',11158,48);
INSERT INTO "django_geo_db_city" VALUES(9241,'Donalds','Donalds, South Carolina',11180,48);
INSERT INTO "django_geo_db_city" VALUES(9242,'Due West','Due West, South Carolina',11181,48);
INSERT INTO "django_geo_db_city" VALUES(9243,'Easley','Easley, South Carolina',11182,48);
INSERT INTO "django_geo_db_city" VALUES(9244,'Fair Play','Fair Play, South Carolina',11185,48);
INSERT INTO "django_geo_db_city" VALUES(9245,'Fountain Inn','Fountain Inn, South Carolina',11186,48);
INSERT INTO "django_geo_db_city" VALUES(9246,'Gray Court','Gray Court, South Carolina',11187,48);
INSERT INTO "django_geo_db_city" VALUES(9247,'Greenwood','Greenwood, South Carolina',11188,48);
INSERT INTO "django_geo_db_city" VALUES(9248,'Greer','Greer, South Carolina',11192,48);
INSERT INTO "django_geo_db_city" VALUES(9249,'Hodges','Hodges, South Carolina',11194,48);
INSERT INTO "django_geo_db_city" VALUES(9250,'Honea Path','Honea Path, South Carolina',11195,48);
INSERT INTO "django_geo_db_city" VALUES(9251,'Iva','Iva, South Carolina',11196,48);
INSERT INTO "django_geo_db_city" VALUES(9252,'La France','La France, South Carolina',11197,48);
INSERT INTO "django_geo_db_city" VALUES(9253,'Liberty','Liberty, South Carolina',11198,48);
INSERT INTO "django_geo_db_city" VALUES(9254,'Long Creek','Long Creek, South Carolina',11199,48);
INSERT INTO "django_geo_db_city" VALUES(9255,'Lowndesville','Lowndesville, South Carolina',11200,48);
INSERT INTO "django_geo_db_city" VALUES(9256,'Marietta','Marietta, South Carolina',11201,48);
INSERT INTO "django_geo_db_city" VALUES(9257,'Mauldin','Mauldin, South Carolina',11202,48);
INSERT INTO "django_geo_db_city" VALUES(9258,'Mountain Rest','Mountain Rest, South Carolina',11203,48);
INSERT INTO "django_geo_db_city" VALUES(9259,'Newry','Newry, South Carolina',11204,48);
INSERT INTO "django_geo_db_city" VALUES(9260,'Ninety Six','Ninety Six, South Carolina',11205,48);
INSERT INTO "django_geo_db_city" VALUES(9261,'Norris','Norris, South Carolina',11206,48);
INSERT INTO "django_geo_db_city" VALUES(9262,'Pelzer','Pelzer, South Carolina',11207,48);
INSERT INTO "django_geo_db_city" VALUES(9263,'Pendleton','Pendleton, South Carolina',11208,48);
INSERT INTO "django_geo_db_city" VALUES(9264,'Pickens','Pickens, South Carolina',11209,48);
INSERT INTO "django_geo_db_city" VALUES(9265,'Seneca','Seneca, South Carolina',11210,48);
INSERT INTO "django_geo_db_city" VALUES(9266,'Piedmont','Piedmont, South Carolina',11211,48);
INSERT INTO "django_geo_db_city" VALUES(9267,'Richland','Richland, South Carolina',11212,48);
INSERT INTO "django_geo_db_city" VALUES(9268,'Salem','Salem, South Carolina',11213,48);
INSERT INTO "django_geo_db_city" VALUES(9269,'Sandy Springs','Sandy Springs, South Carolina',11214,48);
INSERT INTO "django_geo_db_city" VALUES(9270,'Simpsonville','Simpsonville, South Carolina',11217,48);
INSERT INTO "django_geo_db_city" VALUES(9271,'Six Mile','Six Mile, South Carolina',11219,48);
INSERT INTO "django_geo_db_city" VALUES(9272,'Slater','Slater, South Carolina',11220,48);
INSERT INTO "django_geo_db_city" VALUES(9273,'Starr','Starr, South Carolina',11221,48);
INSERT INTO "django_geo_db_city" VALUES(9274,'Sunset','Sunset, South Carolina',11222,48);
INSERT INTO "django_geo_db_city" VALUES(9275,'Tamassee','Tamassee, South Carolina',11223,48);
INSERT INTO "django_geo_db_city" VALUES(9276,'Taylors','Taylors, South Carolina',11224,48);
INSERT INTO "django_geo_db_city" VALUES(9277,'Tigerville','Tigerville, South Carolina',11225,48);
INSERT INTO "django_geo_db_city" VALUES(9278,'Townville','Townville, South Carolina',11226,48);
INSERT INTO "django_geo_db_city" VALUES(9279,'Travelers Rest','Travelers Rest, South Carolina',11227,48);
INSERT INTO "django_geo_db_city" VALUES(9280,'Walhalla','Walhalla, South Carolina',11228,48);
INSERT INTO "django_geo_db_city" VALUES(9281,'Ware Shoals','Ware Shoals, South Carolina',11229,48);
INSERT INTO "django_geo_db_city" VALUES(9282,'Westminster','Westminster, South Carolina',11230,48);
INSERT INTO "django_geo_db_city" VALUES(9283,'West Union','West Union, South Carolina',11232,48);
INSERT INTO "django_geo_db_city" VALUES(9284,'Williamston','Williamston, South Carolina',11233,48);
INSERT INTO "django_geo_db_city" VALUES(9285,'Blacksburg','Blacksburg, South Carolina',11234,48);
INSERT INTO "django_geo_db_city" VALUES(9286,'Bowling Green','Bowling Green, South Carolina',11235,48);
INSERT INTO "django_geo_db_city" VALUES(9287,'Catawba','Catawba, South Carolina',11236,48);
INSERT INTO "django_geo_db_city" VALUES(9288,'Chester','Chester, South Carolina',11237,48);
INSERT INTO "django_geo_db_city" VALUES(9289,'Fort Mill','Fort Mill, South Carolina',11238,48);
INSERT INTO "django_geo_db_city" VALUES(9290,'Chesterfield','Chesterfield, South Carolina',11239,48);
INSERT INTO "django_geo_db_city" VALUES(9291,'Clover','Clover, South Carolina',11240,48);
INSERT INTO "django_geo_db_city" VALUES(9292,'Edgemoor','Edgemoor, South Carolina',11241,48);
INSERT INTO "django_geo_db_city" VALUES(9293,'Fort Lawn','Fort Lawn, South Carolina',11242,48);
INSERT INTO "django_geo_db_city" VALUES(9294,'Hickory Grove','Hickory Grove, South Carolina',11245,48);
INSERT INTO "django_geo_db_city" VALUES(9295,'Jefferson','Jefferson, South Carolina',11246,48);
INSERT INTO "django_geo_db_city" VALUES(9296,'Lancaster','Lancaster, South Carolina',11247,48);
INSERT INTO "django_geo_db_city" VALUES(9297,'Lando','Lando, South Carolina',11250,48);
INSERT INTO "django_geo_db_city" VALUES(9298,'McConnells','McConnells, South Carolina',11251,48);
INSERT INTO "django_geo_db_city" VALUES(9299,'Mount Croghan','Mount Croghan, South Carolina',11252,48);
INSERT INTO "django_geo_db_city" VALUES(9300,'Pageland','Pageland, South Carolina',11253,48);
INSERT INTO "django_geo_db_city" VALUES(9301,'Richburg','Richburg, South Carolina',11254,48);
INSERT INTO "django_geo_db_city" VALUES(9302,'Rock Hill','Rock Hill, South Carolina',11255,48);
INSERT INTO "django_geo_db_city" VALUES(9303,'Ruby','Ruby, South Carolina',11257,48);
INSERT INTO "django_geo_db_city" VALUES(9304,'Sharon','Sharon, South Carolina',11258,48);
INSERT INTO "django_geo_db_city" VALUES(9305,'Smyrna','Smyrna, South Carolina',11259,48);
INSERT INTO "django_geo_db_city" VALUES(9306,'Van Wyck','Van Wyck, South Carolina',11260,48);
INSERT INTO "django_geo_db_city" VALUES(9307,'York','York, South Carolina',11261,48);
INSERT INTO "django_geo_db_city" VALUES(9308,'Garden City','Garden City, South Carolina',11262,48);
INSERT INTO "django_geo_db_city" VALUES(9309,'Aiken','Aiken, South Carolina',11263,48);
INSERT INTO "django_geo_db_city" VALUES(9310,'New Ellenton','New Ellenton, South Carolina',11268,48);
INSERT INTO "django_geo_db_city" VALUES(9311,'Allendale','Allendale, South Carolina',11269,48);
INSERT INTO "django_geo_db_city" VALUES(9312,'Barnwell','Barnwell, South Carolina',11270,48);
INSERT INTO "django_geo_db_city" VALUES(9313,'Hilda','Hilda, South Carolina',11271,48);
INSERT INTO "django_geo_db_city" VALUES(9314,'Bath','Bath, South Carolina',11272,48);
INSERT INTO "django_geo_db_city" VALUES(9315,'Blackville','Blackville, South Carolina',11273,48);
INSERT INTO "django_geo_db_city" VALUES(9316,'Bradley','Bradley, South Carolina',11274,48);
INSERT INTO "django_geo_db_city" VALUES(9317,'Clarks Hill','Clarks Hill, South Carolina',11275,48);
INSERT INTO "django_geo_db_city" VALUES(9318,'Clearwater','Clearwater, South Carolina',11276,48);
INSERT INTO "django_geo_db_city" VALUES(9319,'Edgefield','Edgefield, South Carolina',11277,48);
INSERT INTO "django_geo_db_city" VALUES(9320,'Elko','Elko, South Carolina',11278,48);
INSERT INTO "django_geo_db_city" VALUES(9321,'Fairfax','Fairfax, South Carolina',11279,48);
INSERT INTO "django_geo_db_city" VALUES(9322,'Gloverville','Gloverville, South Carolina',11280,48);
INSERT INTO "django_geo_db_city" VALUES(9323,'Graniteville','Graniteville, South Carolina',11281,48);
INSERT INTO "django_geo_db_city" VALUES(9324,'Jackson','Jackson, South Carolina',11282,48);
INSERT INTO "django_geo_db_city" VALUES(9325,'Johnston','Johnston, South Carolina',11283,48);
INSERT INTO "django_geo_db_city" VALUES(9326,'Langley','Langley, South Carolina',11284,48);
INSERT INTO "django_geo_db_city" VALUES(9327,'Martin','Martin, South Carolina',11286,48);
INSERT INTO "django_geo_db_city" VALUES(9328,'Modoc','Modoc, South Carolina',11287,48);
INSERT INTO "django_geo_db_city" VALUES(9329,'Montmorenci','Montmorenci, South Carolina',11288,48);
INSERT INTO "django_geo_db_city" VALUES(9330,'Mount Carmel','Mount Carmel, South Carolina',11289,48);
INSERT INTO "django_geo_db_city" VALUES(9331,'North Augusta','North Augusta, South Carolina',11290,48);
INSERT INTO "django_geo_db_city" VALUES(9332,'Beech Island','Beech Island, South Carolina',11291,48);
INSERT INTO "django_geo_db_city" VALUES(9333,'Olar','Olar, South Carolina',11292,48);
INSERT INTO "django_geo_db_city" VALUES(9334,'Parksville','Parksville, South Carolina',11293,48);
INSERT INTO "django_geo_db_city" VALUES(9335,'Plum Branch','Plum Branch, South Carolina',11294,48);
INSERT INTO "django_geo_db_city" VALUES(9336,'Sycamore','Sycamore, South Carolina',11295,48);
INSERT INTO "django_geo_db_city" VALUES(9337,'Trenton','Trenton, South Carolina',11296,48);
INSERT INTO "django_geo_db_city" VALUES(9338,'Troy','Troy, South Carolina',11297,48);
INSERT INTO "django_geo_db_city" VALUES(9339,'Ulmer','Ulmer, South Carolina',11298,48);
INSERT INTO "django_geo_db_city" VALUES(9340,'Vaucluse','Vaucluse, South Carolina',11299,48);
INSERT INTO "django_geo_db_city" VALUES(9341,'Warrenville','Warrenville, South Carolina',11300,48);
INSERT INTO "django_geo_db_city" VALUES(9342,'Williston','Williston, South Carolina',11301,48);
INSERT INTO "django_geo_db_city" VALUES(9343,'Windsor','Windsor, South Carolina',11302,48);
INSERT INTO "django_geo_db_city" VALUES(9344,'Beaufort','Beaufort, South Carolina',11306,48);
INSERT INTO "django_geo_db_city" VALUES(9345,'Hilton Head Island','Hilton Head Island, South Carolina',11313,48);
INSERT INTO "django_geo_db_city" VALUES(9346,'Bluffton','Bluffton, South Carolina',11314,48);
INSERT INTO "django_geo_db_city" VALUES(9347,'Brunson','Brunson, South Carolina',11315,48);
INSERT INTO "django_geo_db_city" VALUES(9348,'Coosawatchie','Coosawatchie, South Carolina',11316,48);
INSERT INTO "django_geo_db_city" VALUES(9349,'Crocketville','Crocketville, South Carolina',11317,48);
INSERT INTO "django_geo_db_city" VALUES(9350,'Dale','Dale, South Carolina',11318,48);
INSERT INTO "django_geo_db_city" VALUES(9351,'Daufuskie Island','Daufuskie Island, South Carolina',11319,48);
INSERT INTO "django_geo_db_city" VALUES(9352,'Early Branch','Early Branch, South Carolina',11320,48);
INSERT INTO "django_geo_db_city" VALUES(9353,'Estill','Estill, South Carolina',11321,48);
INSERT INTO "django_geo_db_city" VALUES(9354,'Saint Helena Island','Saint Helena Island, South Carolina',11322,48);
INSERT INTO "django_geo_db_city" VALUES(9355,'Furman','Furman, South Carolina',11323,48);
INSERT INTO "django_geo_db_city" VALUES(9356,'Garnett','Garnett, South Carolina',11324,48);
INSERT INTO "django_geo_db_city" VALUES(9357,'Gifford','Gifford, South Carolina',11325,48);
INSERT INTO "django_geo_db_city" VALUES(9358,'Hampton','Hampton, South Carolina',11326,48);
INSERT INTO "django_geo_db_city" VALUES(9359,'Hardeeville','Hardeeville, South Carolina',11329,48);
INSERT INTO "django_geo_db_city" VALUES(9360,'Islandton','Islandton, South Carolina',11331,48);
INSERT INTO "django_geo_db_city" VALUES(9361,'Lobeco','Lobeco, South Carolina',11332,48);
INSERT INTO "django_geo_db_city" VALUES(9362,'Luray','Luray, South Carolina',11333,48);
INSERT INTO "django_geo_db_city" VALUES(9363,'Miley','Miley, South Carolina',11334,48);
INSERT INTO "django_geo_db_city" VALUES(9364,'Pineland','Pineland, South Carolina',11335,48);
INSERT INTO "django_geo_db_city" VALUES(9365,'Port Royal','Port Royal, South Carolina',11336,48);
INSERT INTO "django_geo_db_city" VALUES(9366,'Ridgeland','Ridgeland, South Carolina',11337,48);
INSERT INTO "django_geo_db_city" VALUES(9367,'Scotia','Scotia, South Carolina',11338,48);
INSERT INTO "django_geo_db_city" VALUES(9368,'Seabrook','Seabrook, South Carolina',11339,48);
INSERT INTO "django_geo_db_city" VALUES(9369,'Sheldon','Sheldon, South Carolina',11340,48);
INSERT INTO "django_geo_db_city" VALUES(9370,'Tillman','Tillman, South Carolina',11342,48);
INSERT INTO "django_geo_db_city" VALUES(9371,'Varnville','Varnville, South Carolina',11343,48);
INSERT INTO "django_geo_db_city" VALUES(9372,'Yemassee','Yemassee, South Carolina',11344,48);
INSERT INTO "django_geo_db_city" VALUES(9373,'Avondale Estates','Avondale Estates, Georgia',11346,13);
INSERT INTO "django_geo_db_city" VALUES(9374,'Norcross','Norcross, Georgia',11347,13);
INSERT INTO "django_geo_db_city" VALUES(9375,'Alpharetta','Alpharetta, Georgia',11348,13);
INSERT INTO "django_geo_db_city" VALUES(9376,'Marietta','Marietta, Georgia',11350,13);
INSERT INTO "django_geo_db_city" VALUES(9377,'Auburn','Auburn, Georgia',11353,13);
INSERT INTO "django_geo_db_city" VALUES(9378,'Conyers','Conyers, Georgia',11354,13);
INSERT INTO "django_geo_db_city" VALUES(9379,'Covington','Covington, Georgia',11356,13);
INSERT INTO "django_geo_db_city" VALUES(9380,'Grayson','Grayson, Georgia',11359,13);
INSERT INTO "django_geo_db_city" VALUES(9381,'Jersey','Jersey, Georgia',11360,13);
INSERT INTO "django_geo_db_city" VALUES(9382,'Dacula','Dacula, Georgia',11361,13);
INSERT INTO "django_geo_db_city" VALUES(9383,'Clarkston','Clarkston, Georgia',11362,13);
INSERT INTO "django_geo_db_city" VALUES(9384,'Suwanee','Suwanee, Georgia',11364,13);
INSERT INTO "django_geo_db_city" VALUES(9385,'Social Circle','Social Circle, Georgia',11365,13);
INSERT INTO "django_geo_db_city" VALUES(9386,'Duluth','Duluth, Georgia',11366,13);
INSERT INTO "django_geo_db_city" VALUES(9387,'Cumming','Cumming, Georgia',11367,13);
INSERT INTO "django_geo_db_city" VALUES(9388,'Decatur','Decatur, Georgia',11368,13);
INSERT INTO "django_geo_db_city" VALUES(9389,'Lithonia','Lithonia, Georgia',11374,13);
INSERT INTO "django_geo_db_city" VALUES(9390,'Snellville','Snellville, Georgia',11375,13);
INSERT INTO "django_geo_db_city" VALUES(9391,'Lawrenceville','Lawrenceville, Georgia',11378,13);
INSERT INTO "django_geo_db_city" VALUES(9392,'Lilburn','Lilburn, Georgia',11382,13);
INSERT INTO "django_geo_db_city" VALUES(9393,'Loganville','Loganville, Georgia',11383,13);
INSERT INTO "django_geo_db_city" VALUES(9394,'Oxford','Oxford, Georgia',11384,13);
INSERT INTO "django_geo_db_city" VALUES(9395,'Mansfield','Mansfield, Georgia',11385,13);
INSERT INTO "django_geo_db_city" VALUES(9396,'Newborn','Newborn, Georgia',11386,13);
INSERT INTO "django_geo_db_city" VALUES(9397,'Porterdale','Porterdale, Georgia',11396,13);
INSERT INTO "django_geo_db_city" VALUES(9398,'Pine Lake','Pine Lake, Georgia',11398,13);
INSERT INTO "django_geo_db_city" VALUES(9399,'Redan','Redan, Georgia',11369,13);
INSERT INTO "django_geo_db_city" VALUES(9400,'Roswell','Roswell, Georgia',11399,13);
INSERT INTO "django_geo_db_city" VALUES(9401,'Scottdale','Scottdale, Georgia',11402,13);
INSERT INTO "django_geo_db_city" VALUES(9402,'Smyrna','Smyrna, Georgia',11403,13);
INSERT INTO "django_geo_db_city" VALUES(9403,'Stone Mountain','Stone Mountain, Georgia',11406,13);
INSERT INTO "django_geo_db_city" VALUES(9404,'Tucker','Tucker, Georgia',11407,13);
INSERT INTO "django_geo_db_city" VALUES(9405,'Acworth','Acworth, Georgia',11418,13);
INSERT INTO "django_geo_db_city" VALUES(9406,'Adairsville','Adairsville, Georgia',11420,13);
INSERT INTO "django_geo_db_city" VALUES(9407,'Aragon','Aragon, Georgia',11421,13);
INSERT INTO "django_geo_db_city" VALUES(9408,'Armuchee','Armuchee, Georgia',11422,13);
INSERT INTO "django_geo_db_city" VALUES(9409,'Austell','Austell, Georgia',11423,13);
INSERT INTO "django_geo_db_city" VALUES(9410,'Ball Ground','Ball Ground, Georgia',11424,13);
INSERT INTO "django_geo_db_city" VALUES(9411,'Bowdon','Bowdon, Georgia',11425,13);
INSERT INTO "django_geo_db_city" VALUES(9412,'Bowdon Junction','Bowdon Junction, Georgia',11426,13);
INSERT INTO "django_geo_db_city" VALUES(9413,'Bremen','Bremen, Georgia',11427,13);
INSERT INTO "django_geo_db_city" VALUES(9414,'Clarkdale','Clarkdale, Georgia',11350,13);
INSERT INTO "django_geo_db_city" VALUES(9415,'Buchanan','Buchanan, Georgia',11428,13);
INSERT INTO "django_geo_db_city" VALUES(9416,'Canton','Canton, Georgia',11429,13);
INSERT INTO "django_geo_db_city" VALUES(9417,'Carrollton','Carrollton, Georgia',11431,13);
INSERT INTO "django_geo_db_city" VALUES(9418,'Cartersville','Cartersville, Georgia',11435,13);
INSERT INTO "django_geo_db_city" VALUES(9419,'Lithia Springs','Lithia Springs, Georgia',11437,13);
INSERT INTO "django_geo_db_city" VALUES(9420,'Cassville','Cassville, Georgia',11438,13);
INSERT INTO "django_geo_db_city" VALUES(9421,'Cave Spring','Cave Spring, Georgia',11439,13);
INSERT INTO "django_geo_db_city" VALUES(9422,'Cedartown','Cedartown, Georgia',11440,13);
INSERT INTO "django_geo_db_city" VALUES(9423,'Mableton','Mableton, Georgia',11441,13);
INSERT INTO "django_geo_db_city" VALUES(9424,'Powder Springs','Powder Springs, Georgia',11442,13);
INSERT INTO "django_geo_db_city" VALUES(9425,'Coosa','Coosa, Georgia',11443,13);
INSERT INTO "django_geo_db_city" VALUES(9426,'Dallas','Dallas, Georgia',11444,13);
INSERT INTO "django_geo_db_city" VALUES(9427,'Douglasville','Douglasville, Georgia',11445,13);
INSERT INTO "django_geo_db_city" VALUES(9428,'Emerson','Emerson, Georgia',11448,13);
INSERT INTO "django_geo_db_city" VALUES(9429,'Esom Hill','Esom Hill, Georgia',11449,13);
INSERT INTO "django_geo_db_city" VALUES(9430,'Fairmount','Fairmount, Georgia',11450,13);
INSERT INTO "django_geo_db_city" VALUES(9431,'Felton','Felton, Georgia',11451,13);
INSERT INTO "django_geo_db_city" VALUES(9432,'Hiram','Hiram, Georgia',11452,13);
INSERT INTO "django_geo_db_city" VALUES(9433,'Holly Springs','Holly Springs, Georgia',11453,13);
INSERT INTO "django_geo_db_city" VALUES(9434,'Jasper','Jasper, Georgia',11454,13);
INSERT INTO "django_geo_db_city" VALUES(9435,'Kennesaw','Kennesaw, Georgia',11455,13);
INSERT INTO "django_geo_db_city" VALUES(9436,'Kingston','Kingston, Georgia',11456,13);
INSERT INTO "django_geo_db_city" VALUES(9437,'Lebanon','Lebanon, Georgia',11453,13);
INSERT INTO "django_geo_db_city" VALUES(9438,'Lindale','Lindale, Georgia',11457,13);
INSERT INTO "django_geo_db_city" VALUES(9439,'Marble Hill','Marble Hill, Georgia',11458,13);
INSERT INTO "django_geo_db_city" VALUES(9440,'Mount Berry','Mount Berry, Georgia',11459,13);
INSERT INTO "django_geo_db_city" VALUES(9441,'Mount Zion','Mount Zion, Georgia',11460,13);
INSERT INTO "django_geo_db_city" VALUES(9442,'Nelson','Nelson, Georgia',11453,13);
INSERT INTO "django_geo_db_city" VALUES(9443,'Rockmart','Rockmart, Georgia',11462,13);
INSERT INTO "django_geo_db_city" VALUES(9444,'Rome','Rome, Georgia',11464,13);
INSERT INTO "django_geo_db_city" VALUES(9445,'Roopville','Roopville, Georgia',11469,13);
INSERT INTO "django_geo_db_city" VALUES(9446,'Rydal','Rydal, Georgia',11470,13);
INSERT INTO "django_geo_db_city" VALUES(9447,'Shannon','Shannon, Georgia',11443,13);
INSERT INTO "django_geo_db_city" VALUES(9448,'Silver Creek','Silver Creek, Georgia',11471,13);
INSERT INTO "django_geo_db_city" VALUES(9449,'Talking Rock','Talking Rock, Georgia',11472,13);
INSERT INTO "django_geo_db_city" VALUES(9450,'Tallapoosa','Tallapoosa, Georgia',11473,13);
INSERT INTO "django_geo_db_city" VALUES(9451,'Tate','Tate, Georgia',11474,13);
INSERT INTO "django_geo_db_city" VALUES(9452,'Taylorsville','Taylorsville, Georgia',11475,13);
INSERT INTO "django_geo_db_city" VALUES(9453,'Temple','Temple, Georgia',11476,13);
INSERT INTO "django_geo_db_city" VALUES(9454,'Villa Rica','Villa Rica, Georgia',11477,13);
INSERT INTO "django_geo_db_city" VALUES(9455,'Waco','Waco, Georgia',11478,13);
INSERT INTO "django_geo_db_city" VALUES(9456,'Waleska','Waleska, Georgia',11479,13);
INSERT INTO "django_geo_db_city" VALUES(9457,'White','White, Georgia',11480,13);
INSERT INTO "django_geo_db_city" VALUES(9458,'Whitesburg','Whitesburg, Georgia',11481,13);
INSERT INTO "django_geo_db_city" VALUES(9459,'Winston','Winston, Georgia',11482,13);
INSERT INTO "django_geo_db_city" VALUES(9460,'Woodstock','Woodstock, Georgia',11483,13);
INSERT INTO "django_geo_db_city" VALUES(9461,'Brooks','Brooks, Georgia',11486,13);
INSERT INTO "django_geo_db_city" VALUES(9462,'Barnesville','Barnesville, Georgia',11487,13);
INSERT INTO "django_geo_db_city" VALUES(9463,'Concord','Concord, Georgia',11489,13);
INSERT INTO "django_geo_db_city" VALUES(9464,'Experiment','Experiment, Georgia',11490,13);
INSERT INTO "django_geo_db_city" VALUES(9465,'Fairburn','Fairburn, Georgia',11491,13);
INSERT INTO "django_geo_db_city" VALUES(9466,'Fayetteville','Fayetteville, Georgia',11492,13);
INSERT INTO "django_geo_db_city" VALUES(9467,'Flovilla','Flovilla, Georgia',11494,13);
INSERT INTO "django_geo_db_city" VALUES(9468,'Franklin','Franklin, Georgia',11495,13);
INSERT INTO "django_geo_db_city" VALUES(9469,'Gay','Gay, Georgia',11496,13);
INSERT INTO "django_geo_db_city" VALUES(9470,'Glenn','Glenn, Georgia',11497,13);
INSERT INTO "django_geo_db_city" VALUES(9471,'Grantville','Grantville, Georgia',11498,13);
INSERT INTO "django_geo_db_city" VALUES(9472,'Greenville','Greenville, Georgia',11499,13);
INSERT INTO "django_geo_db_city" VALUES(9473,'Griffin','Griffin, Georgia',11500,13);
INSERT INTO "django_geo_db_city" VALUES(9474,'Hampton','Hampton, Georgia',11502,13);
INSERT INTO "django_geo_db_city" VALUES(9475,'Haralson','Haralson, Georgia',11503,13);
INSERT INTO "django_geo_db_city" VALUES(9476,'Hogansville','Hogansville, Georgia',11504,13);
INSERT INTO "django_geo_db_city" VALUES(9477,'Inman','Inman, Georgia',11505,13);
INSERT INTO "django_geo_db_city" VALUES(9478,'Jackson','Jackson, Georgia',11506,13);
INSERT INTO "django_geo_db_city" VALUES(9479,'Jenkinsburg','Jenkinsburg, Georgia',11507,13);
INSERT INTO "django_geo_db_city" VALUES(9480,'Jonesboro','Jonesboro, Georgia',11508,13);
INSERT INTO "django_geo_db_city" VALUES(9481,'Lagrange','Lagrange, Georgia',11511,13);
INSERT INTO "django_geo_db_city" VALUES(9482,'Locust Grove','Locust Grove, Georgia',11513,13);
INSERT INTO "django_geo_db_city" VALUES(9483,'Lovejoy','Lovejoy, Georgia',11514,13);
INSERT INTO "django_geo_db_city" VALUES(9484,'Luthersville','Luthersville, Georgia',11515,13);
INSERT INTO "django_geo_db_city" VALUES(9485,'Mcdonough','Mcdonough, Georgia',11516,13);
INSERT INTO "django_geo_db_city" VALUES(9486,'Meansville','Meansville, Georgia',11518,13);
INSERT INTO "django_geo_db_city" VALUES(9487,'Milner','Milner, Georgia',11519,13);
INSERT INTO "django_geo_db_city" VALUES(9488,'Molena','Molena, Georgia',11520,13);
INSERT INTO "django_geo_db_city" VALUES(9489,'Moreland','Moreland, Georgia',11521,13);
INSERT INTO "django_geo_db_city" VALUES(9490,'Morrow','Morrow, Georgia',11522,13);
INSERT INTO "django_geo_db_city" VALUES(9491,'Newnan','Newnan, Georgia',11524,13);
INSERT INTO "django_geo_db_city" VALUES(9492,'Orchard Hill','Orchard Hill, Georgia',11527,13);
INSERT INTO "django_geo_db_city" VALUES(9493,'Palmetto','Palmetto, Georgia',11528,13);
INSERT INTO "django_geo_db_city" VALUES(9494,'Peachtree City','Peachtree City, Georgia',11529,13);
INSERT INTO "django_geo_db_city" VALUES(9495,'Red Oak','Red Oak, Georgia',11531,13);
INSERT INTO "django_geo_db_city" VALUES(9496,'Rex','Rex, Georgia',11532,13);
INSERT INTO "django_geo_db_city" VALUES(9497,'Riverdale','Riverdale, Georgia',11533,13);
INSERT INTO "django_geo_db_city" VALUES(9498,'Sargent','Sargent, Georgia',11534,13);
INSERT INTO "django_geo_db_city" VALUES(9499,'Senoia','Senoia, Georgia',11535,13);
INSERT INTO "django_geo_db_city" VALUES(9500,'Sharpsburg','Sharpsburg, Georgia',11536,13);
INSERT INTO "django_geo_db_city" VALUES(9501,'Stockbridge','Stockbridge, Georgia',11537,13);
INSERT INTO "django_geo_db_city" VALUES(9502,'Sunny Side','Sunny Side, Georgia',11539,13);
INSERT INTO "django_geo_db_city" VALUES(9503,'The Rock','The Rock, Georgia',11540,13);
INSERT INTO "django_geo_db_city" VALUES(9504,'Thomaston','Thomaston, Georgia',11541,13);
INSERT INTO "django_geo_db_city" VALUES(9505,'Conley','Conley, Georgia',11542,13);
INSERT INTO "django_geo_db_city" VALUES(9506,'Turin','Turin, Georgia',11543,13);
INSERT INTO "django_geo_db_city" VALUES(9507,'Tyrone','Tyrone, Georgia',11544,13);
INSERT INTO "django_geo_db_city" VALUES(9508,'Union City','Union City, Georgia',11545,13);
INSERT INTO "django_geo_db_city" VALUES(9509,'Williamson','Williamson, Georgia',11546,13);
INSERT INTO "django_geo_db_city" VALUES(9510,'Woodbury','Woodbury, Georgia',11547,13);
INSERT INTO "django_geo_db_city" VALUES(9511,'Ellenwood','Ellenwood, Georgia',11548,13);
INSERT INTO "django_geo_db_city" VALUES(9512,'Zebulon','Zebulon, Georgia',11549,13);
INSERT INTO "django_geo_db_city" VALUES(9513,'Forest Park','Forest Park, Georgia',11551,13);
INSERT INTO "django_geo_db_city" VALUES(9514,'Atlanta','Atlanta, Georgia',11352,13);
INSERT INTO "django_geo_db_city" VALUES(9515,'Swainsboro','Swainsboro, Georgia',11597,13);
INSERT INTO "django_geo_db_city" VALUES(9516,'Ailey','Ailey, Georgia',11598,13);
INSERT INTO "django_geo_db_city" VALUES(9517,'Alamo','Alamo, Georgia',11599,13);
INSERT INTO "django_geo_db_city" VALUES(9518,'Alston','Alston, Georgia',11600,13);
INSERT INTO "django_geo_db_city" VALUES(9519,'Bartow','Bartow, Georgia',11601,13);
INSERT INTO "django_geo_db_city" VALUES(9520,'Bellville','Bellville, Georgia',11602,13);
INSERT INTO "django_geo_db_city" VALUES(9521,'Brooklet','Brooklet, Georgia',11603,13);
INSERT INTO "django_geo_db_city" VALUES(9522,'Claxton','Claxton, Georgia',11604,13);
INSERT INTO "django_geo_db_city" VALUES(9523,'Cobbtown','Cobbtown, Georgia',11605,13);
INSERT INTO "django_geo_db_city" VALUES(9524,'Collins','Collins, Georgia',11606,13);
INSERT INTO "django_geo_db_city" VALUES(9525,'Daisy','Daisy, Georgia',11607,13);
INSERT INTO "django_geo_db_city" VALUES(9526,'Dover','Dover, Georgia',11608,13);
INSERT INTO "django_geo_db_city" VALUES(9527,'Garfield','Garfield, Georgia',11609,13);
INSERT INTO "django_geo_db_city" VALUES(9528,'Girard','Girard, Georgia',11610,13);
INSERT INTO "django_geo_db_city" VALUES(9529,'Glennville','Glennville, Georgia',11611,13);
INSERT INTO "django_geo_db_city" VALUES(9530,'Glenwood','Glenwood, Georgia',11612,13);
INSERT INTO "django_geo_db_city" VALUES(9531,'Hagan','Hagan, Georgia',11613,13);
INSERT INTO "django_geo_db_city" VALUES(9532,'Louisville','Louisville, Georgia',11614,13);
INSERT INTO "django_geo_db_city" VALUES(9533,'Lyons','Lyons, Georgia',11615,13);
INSERT INTO "django_geo_db_city" VALUES(9534,'Manassas','Manassas, Georgia',11616,13);
INSERT INTO "django_geo_db_city" VALUES(9535,'Metter','Metter, Georgia',11617,13);
INSERT INTO "django_geo_db_city" VALUES(9536,'Midville','Midville, Georgia',11618,13);
INSERT INTO "django_geo_db_city" VALUES(9537,'Millen','Millen, Georgia',11619,13);
INSERT INTO "django_geo_db_city" VALUES(9538,'East Point','East Point, Georgia',11620,13);
INSERT INTO "django_geo_db_city" VALUES(9539,'Mount Vernon','Mount Vernon, Georgia',11621,13);
INSERT INTO "django_geo_db_city" VALUES(9540,'Newington','Newington, Georgia',11622,13);
INSERT INTO "django_geo_db_city" VALUES(9541,'Norristown','Norristown, Georgia',11623,13);
INSERT INTO "django_geo_db_city" VALUES(9542,'Nunez','Nunez, Georgia',11624,13);
INSERT INTO "django_geo_db_city" VALUES(9543,'Oliver','Oliver, Georgia',11625,13);
INSERT INTO "django_geo_db_city" VALUES(9544,'Portal','Portal, Georgia',11626,13);
INSERT INTO "django_geo_db_city" VALUES(9545,'Pulaski','Pulaski, Georgia',11627,13);
INSERT INTO "django_geo_db_city" VALUES(9546,'Register','Register, Georgia',11628,13);
INSERT INTO "django_geo_db_city" VALUES(9547,'Reidsville','Reidsville, Georgia',11629,13);
INSERT INTO "django_geo_db_city" VALUES(9548,'Rockledge','Rockledge, Georgia',11630,13);
INSERT INTO "django_geo_db_city" VALUES(9549,'Rocky Ford','Rocky Ford, Georgia',11631,13);
INSERT INTO "django_geo_db_city" VALUES(9550,'Sardis','Sardis, Georgia',11632,13);
INSERT INTO "django_geo_db_city" VALUES(9551,'Soperton','Soperton, Georgia',11633,13);
INSERT INTO "django_geo_db_city" VALUES(9552,'Statesboro','Statesboro, Georgia',11634,13);
INSERT INTO "django_geo_db_city" VALUES(9553,'Stillmore','Stillmore, Georgia',11638,13);
INSERT INTO "django_geo_db_city" VALUES(9554,'Summertown','Summertown, Georgia',11639,13);
INSERT INTO "django_geo_db_city" VALUES(9555,'Sylvania','Sylvania, Georgia',11640,13);
INSERT INTO "django_geo_db_city" VALUES(9556,'Tarrytown','Tarrytown, Georgia',11641,13);
INSERT INTO "django_geo_db_city" VALUES(9557,'Twin City','Twin City, Georgia',11642,13);
INSERT INTO "django_geo_db_city" VALUES(9558,'Uvalda','Uvalda, Georgia',11643,13);
INSERT INTO "django_geo_db_city" VALUES(9559,'Vidalia','Vidalia, Georgia',11644,13);
INSERT INTO "django_geo_db_city" VALUES(9560,'Wadley','Wadley, Georgia',11646,13);
INSERT INTO "django_geo_db_city" VALUES(9561,'Gainesville','Gainesville, Georgia',11648,13);
INSERT INTO "django_geo_db_city" VALUES(9562,'Chestnut Mountain','Chestnut Mountain, Georgia',11649,13);
INSERT INTO "django_geo_db_city" VALUES(9563,'Alto','Alto, Georgia',11655,13);
INSERT INTO "django_geo_db_city" VALUES(9564,'Baldwin','Baldwin, Georgia',11656,13);
INSERT INTO "django_geo_db_city" VALUES(9565,'Blairsville','Blairsville, Georgia',11657,13);
INSERT INTO "django_geo_db_city" VALUES(9566,'Blue Ridge','Blue Ridge, Georgia',11658,13);
INSERT INTO "django_geo_db_city" VALUES(9567,'Buford','Buford, Georgia',11347,13);
INSERT INTO "django_geo_db_city" VALUES(9568,'Bowersville','Bowersville, Georgia',11660,13);
INSERT INTO "django_geo_db_city" VALUES(9569,'Braselton','Braselton, Georgia',11661,13);
INSERT INTO "django_geo_db_city" VALUES(9570,'Canon','Canon, Georgia',11664,13);
INSERT INTO "django_geo_db_city" VALUES(9571,'Carnesville','Carnesville, Georgia',11665,13);
INSERT INTO "django_geo_db_city" VALUES(9572,'Cherrylog','Cherrylog, Georgia',11666,13);
INSERT INTO "django_geo_db_city" VALUES(9573,'Clarkesville','Clarkesville, Georgia',11667,13);
INSERT INTO "django_geo_db_city" VALUES(9574,'Clayton','Clayton, Georgia',11668,13);
INSERT INTO "django_geo_db_city" VALUES(9575,'Clermont','Clermont, Georgia',11669,13);
INSERT INTO "django_geo_db_city" VALUES(9576,'Cleveland','Cleveland, Georgia',11670,13);
INSERT INTO "django_geo_db_city" VALUES(9577,'Commerce','Commerce, Georgia',11671,13);
INSERT INTO "django_geo_db_city" VALUES(9578,'Cornelia','Cornelia, Georgia',11673,13);
INSERT INTO "django_geo_db_city" VALUES(9579,'Dahlonega','Dahlonega, Georgia',11674,13);
INSERT INTO "django_geo_db_city" VALUES(9580,'Dawsonville','Dawsonville, Georgia',11675,13);
INSERT INTO "django_geo_db_city" VALUES(9581,'Demorest','Demorest, Georgia',11676,13);
INSERT INTO "django_geo_db_city" VALUES(9582,'Dillard','Dillard, Georgia',11677,13);
INSERT INTO "django_geo_db_city" VALUES(9583,'Eastanollee','Eastanollee, Georgia',11678,13);
INSERT INTO "django_geo_db_city" VALUES(9584,'East Ellijay','East Ellijay, Georgia',11679,13);
INSERT INTO "django_geo_db_city" VALUES(9585,'Ellijay','Ellijay, Georgia',11680,13);
INSERT INTO "django_geo_db_city" VALUES(9586,'Epworth','Epworth, Georgia',11681,13);
INSERT INTO "django_geo_db_city" VALUES(9587,'Flowery Branch','Flowery Branch, Georgia',11682,13);
INSERT INTO "django_geo_db_city" VALUES(9588,'Gillsville','Gillsville, Georgia',11683,13);
INSERT INTO "django_geo_db_city" VALUES(9589,'Helen','Helen, Georgia',11685,13);
INSERT INTO "django_geo_db_city" VALUES(9590,'Hiawassee','Hiawassee, Georgia',11686,13);
INSERT INTO "django_geo_db_city" VALUES(9591,'Homer','Homer, Georgia',11687,13);
INSERT INTO "django_geo_db_city" VALUES(9592,'Hoschton','Hoschton, Georgia',11688,13);
INSERT INTO "django_geo_db_city" VALUES(9593,'Jefferson','Jefferson, Georgia',11689,13);
INSERT INTO "django_geo_db_city" VALUES(9594,'Lakemont','Lakemont, Georgia',11690,13);
INSERT INTO "django_geo_db_city" VALUES(9595,'Lavonia','Lavonia, Georgia',11691,13);
INSERT INTO "django_geo_db_city" VALUES(9596,'Lula','Lula, Georgia',11692,13);
INSERT INTO "django_geo_db_city" VALUES(9597,'McCaysville','McCaysville, Georgia',11693,13);
INSERT INTO "django_geo_db_city" VALUES(9598,'Martin','Martin, Georgia',11694,13);
INSERT INTO "django_geo_db_city" VALUES(9599,'Maysville','Maysville, Georgia',11695,13);
INSERT INTO "django_geo_db_city" VALUES(9600,'Mineral Bluff','Mineral Bluff, Georgia',11696,13);
INSERT INTO "django_geo_db_city" VALUES(9601,'Morganton','Morganton, Georgia',11697,13);
INSERT INTO "django_geo_db_city" VALUES(9602,'Mountain City','Mountain City, Georgia',11698,13);
INSERT INTO "django_geo_db_city" VALUES(9603,'Mount Airy','Mount Airy, Georgia',11699,13);
INSERT INTO "django_geo_db_city" VALUES(9604,'Murrayville','Murrayville, Georgia',11700,13);
INSERT INTO "django_geo_db_city" VALUES(9605,'Nicholson','Nicholson, Georgia',11701,13);
INSERT INTO "django_geo_db_city" VALUES(9606,'Oakwood','Oakwood, Georgia',11702,13);
INSERT INTO "django_geo_db_city" VALUES(9607,'Pendergrass','Pendergrass, Georgia',11703,13);
INSERT INTO "django_geo_db_city" VALUES(9608,'Rabun Gap','Rabun Gap, Georgia',11704,13);
INSERT INTO "django_geo_db_city" VALUES(9609,'Sautee Nacoochee','Sautee Nacoochee, Georgia',11705,13);
INSERT INTO "django_geo_db_city" VALUES(9610,'Suches','Suches, Georgia',11706,13);
INSERT INTO "django_geo_db_city" VALUES(9611,'Tallulah Falls','Tallulah Falls, Georgia',11707,13);
INSERT INTO "django_geo_db_city" VALUES(9612,'Talmo','Talmo, Georgia',11708,13);
INSERT INTO "django_geo_db_city" VALUES(9613,'Tiger','Tiger, Georgia',11709,13);
INSERT INTO "django_geo_db_city" VALUES(9614,'Toccoa','Toccoa, Georgia',11710,13);
INSERT INTO "django_geo_db_city" VALUES(9615,'Turnerville','Turnerville, Georgia',11711,13);
INSERT INTO "django_geo_db_city" VALUES(9616,'Wiley','Wiley, Georgia',11712,13);
INSERT INTO "django_geo_db_city" VALUES(9617,'Young Harris','Young Harris, Georgia',11713,13);
INSERT INTO "django_geo_db_city" VALUES(9618,'Athens','Athens, Georgia',11718,13);
INSERT INTO "django_geo_db_city" VALUES(9619,'Arnoldsville','Arnoldsville, Georgia',11727,13);
INSERT INTO "django_geo_db_city" VALUES(9620,'Bethlehem','Bethlehem, Georgia',11728,13);
INSERT INTO "django_geo_db_city" VALUES(9621,'Bishop','Bishop, Georgia',11729,13);
INSERT INTO "django_geo_db_city" VALUES(9622,'Bogart','Bogart, Georgia',11730,13);
INSERT INTO "django_geo_db_city" VALUES(9623,'Bostwick','Bostwick, Georgia',11731,13);
INSERT INTO "django_geo_db_city" VALUES(9624,'Bowman','Bowman, Georgia',11732,13);
INSERT INTO "django_geo_db_city" VALUES(9625,'Buckhead','Buckhead, Georgia',11733,13);
INSERT INTO "django_geo_db_city" VALUES(9626,'Carlton','Carlton, Georgia',11734,13);
INSERT INTO "django_geo_db_city" VALUES(9627,'Colbert','Colbert, Georgia',11735,13);
INSERT INTO "django_geo_db_city" VALUES(9628,'Comer','Comer, Georgia',11736,13);
INSERT INTO "django_geo_db_city" VALUES(9629,'Crawford','Crawford, Georgia',11737,13);
INSERT INTO "django_geo_db_city" VALUES(9630,'Crawfordville','Crawfordville, Georgia',11738,13);
INSERT INTO "django_geo_db_city" VALUES(9631,'Danielsville','Danielsville, Georgia',11739,13);
INSERT INTO "django_geo_db_city" VALUES(9632,'Dewy Rose','Dewy Rose, Georgia',11740,13);
INSERT INTO "django_geo_db_city" VALUES(9633,'Elberton','Elberton, Georgia',11741,13);
INSERT INTO "django_geo_db_city" VALUES(9634,'Farmington','Farmington, Georgia',11742,13);
INSERT INTO "django_geo_db_city" VALUES(9635,'Franklin Springs','Franklin Springs, Georgia',11743,13);
INSERT INTO "django_geo_db_city" VALUES(9636,'Good Hope','Good Hope, Georgia',11744,13);
INSERT INTO "django_geo_db_city" VALUES(9637,'Greensboro','Greensboro, Georgia',11745,13);
INSERT INTO "django_geo_db_city" VALUES(9638,'Hartwell','Hartwell, Georgia',11746,13);
INSERT INTO "django_geo_db_city" VALUES(9639,'High Shoals','High Shoals, Georgia',11747,13);
INSERT INTO "django_geo_db_city" VALUES(9640,'Hull','Hull, Georgia',11748,13);
INSERT INTO "django_geo_db_city" VALUES(9641,'Ila','Ila, Georgia',11749,13);
INSERT INTO "django_geo_db_city" VALUES(9642,'Lexington','Lexington, Georgia',11750,13);
INSERT INTO "django_geo_db_city" VALUES(9643,'Madison','Madison, Georgia',11751,13);
INSERT INTO "django_geo_db_city" VALUES(9644,'Monroe','Monroe, Georgia',11753,13);
INSERT INTO "django_geo_db_city" VALUES(9645,'Rayle','Rayle, Georgia',11755,13);
INSERT INTO "django_geo_db_city" VALUES(9646,'Royston','Royston, Georgia',11756,13);
INSERT INTO "django_geo_db_city" VALUES(9647,'Rutledge','Rutledge, Georgia',11757,13);
INSERT INTO "django_geo_db_city" VALUES(9648,'Sharon','Sharon, Georgia',11758,13);
INSERT INTO "django_geo_db_city" VALUES(9649,'Siloam','Siloam, Georgia',11759,13);
INSERT INTO "django_geo_db_city" VALUES(9650,'Statham','Statham, Georgia',11760,13);
INSERT INTO "django_geo_db_city" VALUES(9651,'Stephens','Stephens, Georgia',11761,13);
INSERT INTO "django_geo_db_city" VALUES(9652,'Tignall','Tignall, Georgia',11762,13);
INSERT INTO "django_geo_db_city" VALUES(9653,'Union Point','Union Point, Georgia',11763,13);
INSERT INTO "django_geo_db_city" VALUES(9654,'Maxeys','Maxeys, Georgia',11764,13);
INSERT INTO "django_geo_db_city" VALUES(9655,'Washington','Washington, Georgia',11765,13);
INSERT INTO "django_geo_db_city" VALUES(9656,'Watkinsville','Watkinsville, Georgia',11766,13);
INSERT INTO "django_geo_db_city" VALUES(9657,'White Plains','White Plains, Georgia',11767,13);
INSERT INTO "django_geo_db_city" VALUES(9658,'Winder','Winder, Georgia',11768,13);
INSERT INTO "django_geo_db_city" VALUES(9659,'Winterville','Winterville, Georgia',11769,13);
INSERT INTO "django_geo_db_city" VALUES(9660,'Calhoun','Calhoun, Georgia',11770,13);
INSERT INTO "django_geo_db_city" VALUES(9661,'Chatsworth','Chatsworth, Georgia',11772,13);
INSERT INTO "django_geo_db_city" VALUES(9662,'Chickamauga','Chickamauga, Georgia',11773,13);
INSERT INTO "django_geo_db_city" VALUES(9663,'Cisco','Cisco, Georgia',11774,13);
INSERT INTO "django_geo_db_city" VALUES(9664,'Cohutta','Cohutta, Georgia',11775,13);
INSERT INTO "django_geo_db_city" VALUES(9665,'Crandall','Crandall, Georgia',11776,13);
INSERT INTO "django_geo_db_city" VALUES(9666,'Dalton','Dalton, Georgia',11778,13);
INSERT INTO "django_geo_db_city" VALUES(9667,'Eton','Eton, Georgia',11782,13);
INSERT INTO "django_geo_db_city" VALUES(9668,'Flintstone','Flintstone, Georgia',11783,13);
INSERT INTO "django_geo_db_city" VALUES(9669,'Graysville','Graysville, Georgia',11784,13);
INSERT INTO "django_geo_db_city" VALUES(9670,'La Fayette','La Fayette, Georgia',11785,13);
INSERT INTO "django_geo_db_city" VALUES(9671,'Lyerly','Lyerly, Georgia',11786,13);
INSERT INTO "django_geo_db_city" VALUES(9672,'Menlo','Menlo, Georgia',11787,13);
INSERT INTO "django_geo_db_city" VALUES(9673,'Oakman','Oakman, Georgia',11788,13);
INSERT INTO "django_geo_db_city" VALUES(9674,'Plainville','Plainville, Georgia',11789,13);
INSERT INTO "django_geo_db_city" VALUES(9675,'Ranger','Ranger, Georgia',11790,13);
INSERT INTO "django_geo_db_city" VALUES(9676,'Resaca','Resaca, Georgia',11791,13);
INSERT INTO "django_geo_db_city" VALUES(9677,'Ringgold','Ringgold, Georgia',11792,13);
INSERT INTO "django_geo_db_city" VALUES(9678,'Rising Fawn','Rising Fawn, Georgia',11793,13);
INSERT INTO "django_geo_db_city" VALUES(9679,'Rock Spring','Rock Spring, Georgia',11794,13);
INSERT INTO "django_geo_db_city" VALUES(9680,'Rocky Face','Rocky Face, Georgia',11795,13);
INSERT INTO "django_geo_db_city" VALUES(9681,'Rossville','Rossville, Georgia',11796,13);
INSERT INTO "django_geo_db_city" VALUES(9682,'Fort Oglethorpe','Fort Oglethorpe, Georgia',11797,13);
INSERT INTO "django_geo_db_city" VALUES(9683,'Sugar Valley','Sugar Valley, Georgia',11798,13);
INSERT INTO "django_geo_db_city" VALUES(9684,'Summerville','Summerville, Georgia',11799,13);
INSERT INTO "django_geo_db_city" VALUES(9685,'Lookout Mountain','Lookout Mountain, Georgia',11800,13);
INSERT INTO "django_geo_db_city" VALUES(9686,'Tennga','Tennga, Georgia',11801,13);
INSERT INTO "django_geo_db_city" VALUES(9687,'Trenton','Trenton, Georgia',11802,13);
INSERT INTO "django_geo_db_city" VALUES(9688,'Trion','Trion, Georgia',11803,13);
INSERT INTO "django_geo_db_city" VALUES(9689,'Tunnel Hill','Tunnel Hill, Georgia',11805,13);
INSERT INTO "django_geo_db_city" VALUES(9690,'Varnell','Varnell, Georgia',11806,13);
INSERT INTO "django_geo_db_city" VALUES(9691,'Wildwood','Wildwood, Georgia',11807,13);
INSERT INTO "django_geo_db_city" VALUES(9692,'Appling','Appling, Georgia',11808,13);
INSERT INTO "django_geo_db_city" VALUES(9693,'Avera','Avera, Georgia',11809,13);
INSERT INTO "django_geo_db_city" VALUES(9694,'Blythe','Blythe, Georgia',11810,13);
INSERT INTO "django_geo_db_city" VALUES(9695,'Boneville','Boneville, Georgia',11811,13);
INSERT INTO "django_geo_db_city" VALUES(9696,'Camak','Camak, Georgia',11812,13);
INSERT INTO "django_geo_db_city" VALUES(9697,'Dearing','Dearing, Georgia',11813,13);
INSERT INTO "django_geo_db_city" VALUES(9698,'Evans','Evans, Georgia',11814,13);
INSERT INTO "django_geo_db_city" VALUES(9699,'Gibson','Gibson, Georgia',11815,13);
INSERT INTO "django_geo_db_city" VALUES(9700,'Gough','Gough, Georgia',11816,13);
INSERT INTO "django_geo_db_city" VALUES(9701,'Gracewood','Gracewood, Georgia',11817,13);
INSERT INTO "django_geo_db_city" VALUES(9702,'Grovetown','Grovetown, Georgia',11818,13);
INSERT INTO "django_geo_db_city" VALUES(9703,'Harlem','Harlem, Georgia',11819,13);
INSERT INTO "django_geo_db_city" VALUES(9704,'Hephzibah','Hephzibah, Georgia',11820,13);
INSERT INTO "django_geo_db_city" VALUES(9705,'Keysville','Keysville, Georgia',11821,13);
INSERT INTO "django_geo_db_city" VALUES(9706,'Lincolnton','Lincolnton, Georgia',11822,13);
INSERT INTO "django_geo_db_city" VALUES(9707,'Matthews','Matthews, Georgia',11823,13);
INSERT INTO "django_geo_db_city" VALUES(9708,'Mesena','Mesena, Georgia',11824,13);
INSERT INTO "django_geo_db_city" VALUES(9709,'Mitchell','Mitchell, Georgia',11825,13);
INSERT INTO "django_geo_db_city" VALUES(9710,'Norwood','Norwood, Georgia',11826,13);
INSERT INTO "django_geo_db_city" VALUES(9711,'Perkins','Perkins, Georgia',11827,13);
INSERT INTO "django_geo_db_city" VALUES(9712,'Stapleton','Stapleton, Georgia',11828,13);
INSERT INTO "django_geo_db_city" VALUES(9713,'Thomson','Thomson, Georgia',11829,13);
INSERT INTO "django_geo_db_city" VALUES(9714,'Warrenton','Warrenton, Georgia',11830,13);
INSERT INTO "django_geo_db_city" VALUES(9715,'Waynesboro','Waynesboro, Georgia',11831,13);
INSERT INTO "django_geo_db_city" VALUES(9716,'Wrens','Wrens, Georgia',11832,13);
INSERT INTO "django_geo_db_city" VALUES(9717,'Augusta','Augusta, Georgia',11834,13);
INSERT INTO "django_geo_db_city" VALUES(9718,'Abbeville','Abbeville, Georgia',11841,13);
INSERT INTO "django_geo_db_city" VALUES(9719,'Adrian','Adrian, Georgia',11842,13);
INSERT INTO "django_geo_db_city" VALUES(9720,'Allentown','Allentown, Georgia',11843,13);
INSERT INTO "django_geo_db_city" VALUES(9721,'Bolingbroke','Bolingbroke, Georgia',11844,13);
INSERT INTO "django_geo_db_city" VALUES(9722,'Bonaire','Bonaire, Georgia',11845,13);
INSERT INTO "django_geo_db_city" VALUES(9723,'Butler','Butler, Georgia',11846,13);
INSERT INTO "django_geo_db_city" VALUES(9724,'Byromville','Byromville, Georgia',11847,13);
INSERT INTO "django_geo_db_city" VALUES(9725,'Byron','Byron, Georgia',11848,13);
INSERT INTO "django_geo_db_city" VALUES(9726,'Cadwell','Cadwell, Georgia',11849,13);
INSERT INTO "django_geo_db_city" VALUES(9727,'Cordele','Cordele, Georgia',11850,13);
INSERT INTO "django_geo_db_city" VALUES(9728,'Chauncey','Chauncey, Georgia',11851,13);
INSERT INTO "django_geo_db_city" VALUES(9729,'Chester','Chester, Georgia',11852,13);
INSERT INTO "django_geo_db_city" VALUES(9730,'Clinchfield','Clinchfield, Georgia',11853,13);
INSERT INTO "django_geo_db_city" VALUES(9731,'Cochran','Cochran, Georgia',11854,13);
INSERT INTO "django_geo_db_city" VALUES(9732,'Culloden','Culloden, Georgia',11856,13);
INSERT INTO "django_geo_db_city" VALUES(9733,'Danville','Danville, Georgia',11857,13);
INSERT INTO "django_geo_db_city" VALUES(9734,'Davisboro','Davisboro, Georgia',11858,13);
INSERT INTO "django_geo_db_city" VALUES(9735,'Dexter','Dexter, Georgia',11859,13);
INSERT INTO "django_geo_db_city" VALUES(9736,'Dry Branch','Dry Branch, Georgia',11860,13);
INSERT INTO "django_geo_db_city" VALUES(9737,'Dublin','Dublin, Georgia',11861,13);
INSERT INTO "django_geo_db_city" VALUES(9738,'Dudley','Dudley, Georgia',11862,13);
INSERT INTO "django_geo_db_city" VALUES(9739,'Eastman','Eastman, Georgia',11863,13);
INSERT INTO "django_geo_db_city" VALUES(9740,'Eatonton','Eatonton, Georgia',11864,13);
INSERT INTO "django_geo_db_city" VALUES(9741,'Elko','Elko, Georgia',11865,13);
INSERT INTO "django_geo_db_city" VALUES(9742,'Centerville','Centerville, Georgia',11867,13);
INSERT INTO "django_geo_db_city" VALUES(9743,'Forsyth','Forsyth, Georgia',11868,13);
INSERT INTO "django_geo_db_city" VALUES(9744,'Fort Valley','Fort Valley, Georgia',11869,13);
INSERT INTO "django_geo_db_city" VALUES(9745,'Gordon','Gordon, Georgia',11870,13);
INSERT INTO "django_geo_db_city" VALUES(9746,'Gray','Gray, Georgia',11871,13);
INSERT INTO "django_geo_db_city" VALUES(9747,'Haddock','Haddock, Georgia',11872,13);
INSERT INTO "django_geo_db_city" VALUES(9748,'Hardwick','Hardwick, Georgia',11873,13);
INSERT INTO "django_geo_db_city" VALUES(9749,'Harrison','Harrison, Georgia',11874,13);
INSERT INTO "django_geo_db_city" VALUES(9750,'Hawkinsville','Hawkinsville, Georgia',11875,13);
INSERT INTO "django_geo_db_city" VALUES(9751,'Helena','Helena, Georgia',11876,13);
INSERT INTO "django_geo_db_city" VALUES(9752,'Hillsboro','Hillsboro, Georgia',11877,13);
INSERT INTO "django_geo_db_city" VALUES(9753,'Howard','Howard, Georgia',11878,13);
INSERT INTO "django_geo_db_city" VALUES(9754,'Ideal','Ideal, Georgia',11880,13);
INSERT INTO "django_geo_db_city" VALUES(9755,'Irwinton','Irwinton, Georgia',11881,13);
INSERT INTO "django_geo_db_city" VALUES(9756,'Jeffersonville','Jeffersonville, Georgia',11882,13);
INSERT INTO "django_geo_db_city" VALUES(9757,'Jewell','Jewell, Georgia',11883,13);
INSERT INTO "django_geo_db_city" VALUES(9758,'Juliette','Juliette, Georgia',11884,13);
INSERT INTO "django_geo_db_city" VALUES(9759,'Kathleen','Kathleen, Georgia',11885,13);
INSERT INTO "django_geo_db_city" VALUES(9760,'Kite','Kite, Georgia',11886,13);
INSERT INTO "django_geo_db_city" VALUES(9761,'Knoxville','Knoxville, Georgia',11887,13);
INSERT INTO "django_geo_db_city" VALUES(9762,'Lilly','Lilly, Georgia',11888,13);
INSERT INTO "django_geo_db_city" VALUES(9763,'Lizella','Lizella, Georgia',11889,13);
INSERT INTO "django_geo_db_city" VALUES(9764,'McIntyre','McIntyre, Georgia',11890,13);
INSERT INTO "django_geo_db_city" VALUES(9765,'McRae','McRae, Georgia',11891,13);
INSERT INTO "django_geo_db_city" VALUES(9766,'Marshallville','Marshallville, Georgia',11892,13);
INSERT INTO "django_geo_db_city" VALUES(9767,'Mauk','Mauk, Georgia',11893,13);
INSERT INTO "django_geo_db_city" VALUES(9768,'Milan','Milan, Georgia',11894,13);
INSERT INTO "django_geo_db_city" VALUES(9769,'Milledgeville','Milledgeville, Georgia',11895,13);
INSERT INTO "django_geo_db_city" VALUES(9770,'Montezuma','Montezuma, Georgia',11897,13);
INSERT INTO "django_geo_db_city" VALUES(9771,'Monticello','Monticello, Georgia',11898,13);
INSERT INTO "django_geo_db_city" VALUES(9772,'Montrose','Montrose, Georgia',11899,13);
INSERT INTO "django_geo_db_city" VALUES(9773,'Musella','Musella, Georgia',11900,13);
INSERT INTO "django_geo_db_city" VALUES(9774,'Oconee','Oconee, Georgia',11901,13);
INSERT INTO "django_geo_db_city" VALUES(9775,'Oglethorpe','Oglethorpe, Georgia',11902,13);
INSERT INTO "django_geo_db_city" VALUES(9776,'Perry','Perry, Georgia',11903,13);
INSERT INTO "django_geo_db_city" VALUES(9777,'Pinehurst','Pinehurst, Georgia',11904,13);
INSERT INTO "django_geo_db_city" VALUES(9778,'Pineview','Pineview, Georgia',11905,13);
INSERT INTO "django_geo_db_city" VALUES(9779,'Pitts','Pitts, Georgia',11906,13);
INSERT INTO "django_geo_db_city" VALUES(9780,'Plainfield','Plainfield, Georgia',11907,13);
INSERT INTO "django_geo_db_city" VALUES(9781,'Rentz','Rentz, Georgia',11908,13);
INSERT INTO "django_geo_db_city" VALUES(9782,'Reynolds','Reynolds, Georgia',11909,13);
INSERT INTO "django_geo_db_city" VALUES(9783,'Rhine','Rhine, Georgia',11910,13);
INSERT INTO "django_geo_db_city" VALUES(9784,'Roberta','Roberta, Georgia',11911,13);
INSERT INTO "django_geo_db_city" VALUES(9785,'Rochelle','Rochelle, Georgia',11912,13);
INSERT INTO "django_geo_db_city" VALUES(9786,'Rupert','Rupert, Georgia',11913,13);
INSERT INTO "django_geo_db_city" VALUES(9787,'Sandersville','Sandersville, Georgia',11914,13);
INSERT INTO "django_geo_db_city" VALUES(9788,'Scotland','Scotland, Georgia',11915,13);
INSERT INTO "django_geo_db_city" VALUES(9789,'Seville','Seville, Georgia',11916,13);
INSERT INTO "django_geo_db_city" VALUES(9790,'Shady Dale','Shady Dale, Georgia',11917,13);
INSERT INTO "django_geo_db_city" VALUES(9791,'Smarr','Smarr, Georgia',11918,13);
INSERT INTO "django_geo_db_city" VALUES(9792,'Sparta','Sparta, Georgia',11919,13);
INSERT INTO "django_geo_db_city" VALUES(9793,'Warner Robins','Warner Robins, Georgia',11920,13);
INSERT INTO "django_geo_db_city" VALUES(9794,'Tennille','Tennille, Georgia',11921,13);
INSERT INTO "django_geo_db_city" VALUES(9795,'Toomsboro','Toomsboro, Georgia',11922,13);
INSERT INTO "django_geo_db_city" VALUES(9796,'Unadilla','Unadilla, Georgia',11923,13);
INSERT INTO "django_geo_db_city" VALUES(9797,'Vienna','Vienna, Georgia',11924,13);
INSERT INTO "django_geo_db_city" VALUES(9798,'Warthen','Warthen, Georgia',11926,13);
INSERT INTO "django_geo_db_city" VALUES(9799,'Wrightsville','Wrightsville, Georgia',11928,13);
INSERT INTO "django_geo_db_city" VALUES(9800,'Yatesville','Yatesville, Georgia',11929,13);
INSERT INTO "django_geo_db_city" VALUES(9801,'Macon','Macon, Georgia',11932,13);
INSERT INTO "django_geo_db_city" VALUES(9802,'Cecil','Cecil, Georgia',11943,13);
INSERT INTO "django_geo_db_city" VALUES(9803,'Allenhurst','Allenhurst, Georgia',11947,13);
INSERT INTO "django_geo_db_city" VALUES(9804,'Bloomingdale','Bloomingdale, Georgia',11948,13);
INSERT INTO "django_geo_db_city" VALUES(9805,'Clyo','Clyo, Georgia',11949,13);
INSERT INTO "django_geo_db_city" VALUES(9806,'Crescent','Crescent, Georgia',11950,13);
INSERT INTO "django_geo_db_city" VALUES(9807,'Darien','Darien, Georgia',11951,13);
INSERT INTO "django_geo_db_city" VALUES(9808,'Eden','Eden, Georgia',11952,13);
INSERT INTO "django_geo_db_city" VALUES(9809,'Ellabell','Ellabell, Georgia',11953,13);
INSERT INTO "django_geo_db_city" VALUES(9810,'Fleming','Fleming, Georgia',11954,13);
INSERT INTO "django_geo_db_city" VALUES(9811,'Hinesville','Hinesville, Georgia',11955,13);
INSERT INTO "django_geo_db_city" VALUES(9812,'Guyton','Guyton, Georgia',11956,13);
INSERT INTO "django_geo_db_city" VALUES(9813,'Fort Stewart','Fort Stewart, Georgia',11958,13);
INSERT INTO "django_geo_db_city" VALUES(9814,'Ludowici','Ludowici, Georgia',11960,13);
INSERT INTO "django_geo_db_city" VALUES(9815,'Meldrim','Meldrim, Georgia',11961,13);
INSERT INTO "django_geo_db_city" VALUES(9816,'Meridian','Meridian, Georgia',11962,13);
INSERT INTO "django_geo_db_city" VALUES(9817,'Midway','Midway, Georgia',11963,13);
INSERT INTO "django_geo_db_city" VALUES(9818,'Pembroke','Pembroke, Georgia',11964,13);
INSERT INTO "django_geo_db_city" VALUES(9819,'Pooler','Pooler, Georgia',11965,13);
INSERT INTO "django_geo_db_city" VALUES(9820,'Riceboro','Riceboro, Georgia',11966,13);
INSERT INTO "django_geo_db_city" VALUES(9821,'Richmond Hill','Richmond Hill, Georgia',11967,13);
INSERT INTO "django_geo_db_city" VALUES(9822,'Rincon','Rincon, Georgia',11968,13);
INSERT INTO "django_geo_db_city" VALUES(9823,'Sapelo Island','Sapelo Island, Georgia',11969,13);
INSERT INTO "django_geo_db_city" VALUES(9824,'Tybee Island','Tybee Island, Georgia',11970,13);
INSERT INTO "django_geo_db_city" VALUES(9825,'Springfield','Springfield, Georgia',11971,13);
INSERT INTO "django_geo_db_city" VALUES(9826,'Townsend','Townsend, Georgia',11972,13);
INSERT INTO "django_geo_db_city" VALUES(9827,'Valona','Valona, Georgia',11950,13);
INSERT INTO "django_geo_db_city" VALUES(9828,'Walthourville','Walthourville, Georgia',11973,13);
INSERT INTO "django_geo_db_city" VALUES(9829,'Lenox','Lenox, Georgia',11974,13);
INSERT INTO "django_geo_db_city" VALUES(9830,'Savannah','Savannah, Georgia',11975,13);
INSERT INTO "django_geo_db_city" VALUES(9831,'Waycross','Waycross, Georgia',11989,13);
INSERT INTO "django_geo_db_city" VALUES(9832,'Alma','Alma, Georgia',11993,13);
INSERT INTO "django_geo_db_city" VALUES(9833,'Ambrose','Ambrose, Georgia',11994,13);
INSERT INTO "django_geo_db_city" VALUES(9834,'Baxley','Baxley, Georgia',11995,13);
INSERT INTO "django_geo_db_city" VALUES(9835,'Blackshear','Blackshear, Georgia',11997,13);
INSERT INTO "django_geo_db_city" VALUES(9836,'Bristol','Bristol, Georgia',11998,13);
INSERT INTO "django_geo_db_city" VALUES(9837,'Broxton','Broxton, Georgia',11999,13);
INSERT INTO "django_geo_db_city" VALUES(9838,'Brunswick','Brunswick, Georgia',12000,13);
INSERT INTO "django_geo_db_city" VALUES(9839,'Saint Simons Island','Saint Simons Island, Georgia',12002,13);
INSERT INTO "django_geo_db_city" VALUES(9840,'Jekyll Island','Jekyll Island, Georgia',12006,13);
INSERT INTO "django_geo_db_city" VALUES(9841,'Denton','Denton, Georgia',12007,13);
INSERT INTO "django_geo_db_city" VALUES(9842,'Douglas','Douglas, Georgia',12008,13);
INSERT INTO "django_geo_db_city" VALUES(9843,'Folkston','Folkston, Georgia',12011,13);
INSERT INTO "django_geo_db_city" VALUES(9844,'Hazlehurst','Hazlehurst, Georgia',12012,13);
INSERT INTO "django_geo_db_city" VALUES(9845,'Hoboken','Hoboken, Georgia',12013,13);
INSERT INTO "django_geo_db_city" VALUES(9846,'Hortense','Hortense, Georgia',12014,13);
INSERT INTO "django_geo_db_city" VALUES(9847,'Jacksonville','Jacksonville, Georgia',12015,13);
INSERT INTO "django_geo_db_city" VALUES(9848,'Jesup','Jesup, Georgia',12016,13);
INSERT INTO "django_geo_db_city" VALUES(9849,'Kings Bay','Kings Bay, Georgia',12018,13);
INSERT INTO "django_geo_db_city" VALUES(9850,'Kingsland','Kingsland, Georgia',12019,13);
INSERT INTO "django_geo_db_city" VALUES(9851,'Lumber City','Lumber City, Georgia',12020,13);
INSERT INTO "django_geo_db_city" VALUES(9852,'Manor','Manor, Georgia',12021,13);
INSERT INTO "django_geo_db_city" VALUES(9853,'Mershon','Mershon, Georgia',12022,13);
INSERT INTO "django_geo_db_city" VALUES(9854,'Millwood','Millwood, Georgia',12023,13);
INSERT INTO "django_geo_db_city" VALUES(9855,'Nahunta','Nahunta, Georgia',12024,13);
INSERT INTO "django_geo_db_city" VALUES(9856,'Nicholls','Nicholls, Georgia',12025,13);
INSERT INTO "django_geo_db_city" VALUES(9857,'Odum','Odum, Georgia',12026,13);
INSERT INTO "django_geo_db_city" VALUES(9858,'Offerman','Offerman, Georgia',12027,13);
INSERT INTO "django_geo_db_city" VALUES(9859,'Patterson','Patterson, Georgia',12028,13);
INSERT INTO "django_geo_db_city" VALUES(9860,'Saint Marys','Saint Marys, Georgia',12029,13);
INSERT INTO "django_geo_db_city" VALUES(9861,'Screven','Screven, Georgia',12030,13);
INSERT INTO "django_geo_db_city" VALUES(9862,'Sea Island','Sea Island, Georgia',12031,13);
INSERT INTO "django_geo_db_city" VALUES(9863,'Surrency','Surrency, Georgia',12032,13);
INSERT INTO "django_geo_db_city" VALUES(9864,'Waresboro','Waresboro, Georgia',11990,13);
INSERT INTO "django_geo_db_city" VALUES(9865,'Waverly','Waverly, Georgia',12033,13);
INSERT INTO "django_geo_db_city" VALUES(9866,'Waynesville','Waynesville, Georgia',12034,13);
INSERT INTO "django_geo_db_city" VALUES(9867,'West Green','West Green, Georgia',12035,13);
INSERT INTO "django_geo_db_city" VALUES(9868,'White Oak','White Oak, Georgia',12036,13);
INSERT INTO "django_geo_db_city" VALUES(9869,'Woodbine','Woodbine, Georgia',12037,13);
INSERT INTO "django_geo_db_city" VALUES(9870,'Valdosta','Valdosta, Georgia',12039,13);
INSERT INTO "django_geo_db_city" VALUES(9871,'Sparks','Sparks, Georgia',12045,13);
INSERT INTO "django_geo_db_city" VALUES(9872,'Adel','Adel, Georgia',12046,13);
INSERT INTO "django_geo_db_city" VALUES(9873,'Alapaha','Alapaha, Georgia',12047,13);
INSERT INTO "django_geo_db_city" VALUES(9874,'Argyle','Argyle, Georgia',12048,13);
INSERT INTO "django_geo_db_city" VALUES(9875,'Axson','Axson, Georgia',12049,13);
INSERT INTO "django_geo_db_city" VALUES(9876,'Barney','Barney, Georgia',12050,13);
INSERT INTO "django_geo_db_city" VALUES(9877,'Boston','Boston, Georgia',12051,13);
INSERT INTO "django_geo_db_city" VALUES(9878,'Dixie','Dixie, Georgia',12053,13);
INSERT INTO "django_geo_db_city" VALUES(9879,'Du Pont','Du Pont, Georgia',12054,13);
INSERT INTO "django_geo_db_city" VALUES(9880,'Fargo','Fargo, Georgia',12055,13);
INSERT INTO "django_geo_db_city" VALUES(9881,'Hahira','Hahira, Georgia',12056,13);
INSERT INTO "django_geo_db_city" VALUES(9882,'Homerville','Homerville, Georgia',12057,13);
INSERT INTO "django_geo_db_city" VALUES(9883,'Lakeland','Lakeland, Georgia',12058,13);
INSERT INTO "django_geo_db_city" VALUES(9884,'Lake Park','Lake Park, Georgia',12059,13);
INSERT INTO "django_geo_db_city" VALUES(9885,'Morven','Morven, Georgia',12061,13);
INSERT INTO "django_geo_db_city" VALUES(9886,'Nashville','Nashville, Georgia',12062,13);
INSERT INTO "django_geo_db_city" VALUES(9887,'Naylor','Naylor, Georgia',12063,13);
INSERT INTO "django_geo_db_city" VALUES(9888,'Pearson','Pearson, Georgia',12064,13);
INSERT INTO "django_geo_db_city" VALUES(9889,'Quitman','Quitman, Georgia',12065,13);
INSERT INTO "django_geo_db_city" VALUES(9890,'Ray City','Ray City, Georgia',12066,13);
INSERT INTO "django_geo_db_city" VALUES(9891,'Saint George','Saint George, Georgia',12067,13);
INSERT INTO "django_geo_db_city" VALUES(9892,'Statenville','Statenville, Georgia',12069,13);
INSERT INTO "django_geo_db_city" VALUES(9893,'Stockton','Stockton, Georgia',12070,13);
INSERT INTO "django_geo_db_city" VALUES(9894,'Willacoochee','Willacoochee, Georgia',12071,13);
INSERT INTO "django_geo_db_city" VALUES(9895,'Albany','Albany, Georgia',12075,13);
INSERT INTO "django_geo_db_city" VALUES(9896,'Americus','Americus, Georgia',12084,13);
INSERT INTO "django_geo_db_city" VALUES(9897,'Andersonville','Andersonville, Georgia',12086,13);
INSERT INTO "django_geo_db_city" VALUES(9898,'Arabi','Arabi, Georgia',12087,13);
INSERT INTO "django_geo_db_city" VALUES(9899,'Arlington','Arlington, Georgia',12088,13);
INSERT INTO "django_geo_db_city" VALUES(9900,'Ashburn','Ashburn, Georgia',12089,13);
INSERT INTO "django_geo_db_city" VALUES(9901,'Attapulgus','Attapulgus, Georgia',12090,13);
INSERT INTO "django_geo_db_city" VALUES(9902,'Baconton','Baconton, Georgia',12091,13);
INSERT INTO "django_geo_db_city" VALUES(9903,'Bainbridge','Bainbridge, Georgia',12092,13);
INSERT INTO "django_geo_db_city" VALUES(9904,'Barwick','Barwick, Georgia',12095,13);
INSERT INTO "django_geo_db_city" VALUES(9905,'Berlin','Berlin, Georgia',12097,13);
INSERT INTO "django_geo_db_city" VALUES(9906,'Blakely','Blakely, Georgia',12098,13);
INSERT INTO "django_geo_db_city" VALUES(9907,'Bluffton','Bluffton, Georgia',12099,13);
INSERT INTO "django_geo_db_city" VALUES(9908,'Brinson','Brinson, Georgia',12100,13);
INSERT INTO "django_geo_db_city" VALUES(9909,'Bronwood','Bronwood, Georgia',12101,13);
INSERT INTO "django_geo_db_city" VALUES(9910,'Brookfield','Brookfield, Georgia',12102,13);
INSERT INTO "django_geo_db_city" VALUES(9911,'Cairo','Cairo, Georgia',12103,13);
INSERT INTO "django_geo_db_city" VALUES(9912,'Calvary','Calvary, Georgia',12104,13);
INSERT INTO "django_geo_db_city" VALUES(9913,'Camilla','Camilla, Georgia',12105,13);
INSERT INTO "django_geo_db_city" VALUES(9914,'Cedar Springs','Cedar Springs, Georgia',12106,13);
INSERT INTO "django_geo_db_city" VALUES(9915,'Chula','Chula, Georgia',12107,13);
INSERT INTO "django_geo_db_city" VALUES(9916,'Climax','Climax, Georgia',12108,13);
INSERT INTO "django_geo_db_city" VALUES(9917,'Cobb','Cobb, Georgia',12109,13);
INSERT INTO "django_geo_db_city" VALUES(9918,'Coleman','Coleman, Georgia',12110,13);
INSERT INTO "django_geo_db_city" VALUES(9919,'Colquitt','Colquitt, Georgia',12111,13);
INSERT INTO "django_geo_db_city" VALUES(9920,'Coolidge','Coolidge, Georgia',12112,13);
INSERT INTO "django_geo_db_city" VALUES(9921,'Cotton','Cotton, Georgia',12113,13);
INSERT INTO "django_geo_db_city" VALUES(9922,'Cuthbert','Cuthbert, Georgia',12114,13);
INSERT INTO "django_geo_db_city" VALUES(9923,'Damascus','Damascus, Georgia',12115,13);
INSERT INTO "django_geo_db_city" VALUES(9924,'Dawson','Dawson, Georgia',12116,13);
INSERT INTO "django_geo_db_city" VALUES(9925,'De Soto','De Soto, Georgia',12117,13);
INSERT INTO "django_geo_db_city" VALUES(9926,'Doerun','Doerun, Georgia',12118,13);
INSERT INTO "django_geo_db_city" VALUES(9927,'Donalsonville','Donalsonville, Georgia',12119,13);
INSERT INTO "django_geo_db_city" VALUES(9928,'Edison','Edison, Georgia',12120,13);
INSERT INTO "django_geo_db_city" VALUES(9929,'Ellenton','Ellenton, Georgia',12121,13);
INSERT INTO "django_geo_db_city" VALUES(9930,'Enigma','Enigma, Georgia',12122,13);
INSERT INTO "django_geo_db_city" VALUES(9931,'Fitzgerald','Fitzgerald, Georgia',12123,13);
INSERT INTO "django_geo_db_city" VALUES(9932,'Fort Gaines','Fort Gaines, Georgia',12124,13);
INSERT INTO "django_geo_db_city" VALUES(9933,'Fowlstown','Fowlstown, Georgia',12125,13);
INSERT INTO "django_geo_db_city" VALUES(9934,'Funston','Funston, Georgia',12126,13);
INSERT INTO "django_geo_db_city" VALUES(9935,'Georgetown','Georgetown, Georgia',12127,13);
INSERT INTO "django_geo_db_city" VALUES(9936,'Hartsfield','Hartsfield, Georgia',12128,13);
INSERT INTO "django_geo_db_city" VALUES(9937,'Thomasville','Thomasville, Georgia',12129,13);
INSERT INTO "django_geo_db_city" VALUES(9938,'Iron City','Iron City, Georgia',12131,13);
INSERT INTO "django_geo_db_city" VALUES(9939,'Irwinville','Irwinville, Georgia',12132,13);
INSERT INTO "django_geo_db_city" VALUES(9940,'Jakin','Jakin, Georgia',12133,13);
INSERT INTO "django_geo_db_city" VALUES(9941,'Leary','Leary, Georgia',12134,13);
INSERT INTO "django_geo_db_city" VALUES(9942,'Leesburg','Leesburg, Georgia',12135,13);
INSERT INTO "django_geo_db_city" VALUES(9943,'Leslie','Leslie, Georgia',12136,13);
INSERT INTO "django_geo_db_city" VALUES(9944,'Meigs','Meigs, Georgia',12137,13);
INSERT INTO "django_geo_db_city" VALUES(9945,'Morgan','Morgan, Georgia',12138,13);
INSERT INTO "django_geo_db_city" VALUES(9946,'Morris','Morris, Georgia',12139,13);
INSERT INTO "django_geo_db_city" VALUES(9947,'Moultrie','Moultrie, Georgia',12140,13);
INSERT INTO "django_geo_db_city" VALUES(9948,'Mystic','Mystic, Georgia',12141,13);
INSERT INTO "django_geo_db_city" VALUES(9949,'Newton','Newton, Georgia',12142,13);
INSERT INTO "django_geo_db_city" VALUES(9950,'Norman Park','Norman Park, Georgia',12143,13);
INSERT INTO "django_geo_db_city" VALUES(9951,'Oakfield','Oakfield, Georgia',12144,13);
INSERT INTO "django_geo_db_city" VALUES(9952,'Ochlocknee','Ochlocknee, Georgia',12145,13);
INSERT INTO "django_geo_db_city" VALUES(9953,'Ocilla','Ocilla, Georgia',12146,13);
INSERT INTO "django_geo_db_city" VALUES(9954,'Omega','Omega, Georgia',12147,13);
INSERT INTO "django_geo_db_city" VALUES(9955,'Parrott','Parrott, Georgia',12149,13);
INSERT INTO "django_geo_db_city" VALUES(9956,'Pavo','Pavo, Georgia',12150,13);
INSERT INTO "django_geo_db_city" VALUES(9957,'Pelham','Pelham, Georgia',12151,13);
INSERT INTO "django_geo_db_city" VALUES(9958,'Plains','Plains, Georgia',12152,13);
INSERT INTO "django_geo_db_city" VALUES(9959,'Poulan','Poulan, Georgia',12153,13);
INSERT INTO "django_geo_db_city" VALUES(9960,'Putney','Putney, Georgia',12078,13);
INSERT INTO "django_geo_db_city" VALUES(9961,'Rebecca','Rebecca, Georgia',12154,13);
INSERT INTO "django_geo_db_city" VALUES(9962,'Sale City','Sale City, Georgia',12155,13);
INSERT INTO "django_geo_db_city" VALUES(9963,'Sasser','Sasser, Georgia',12156,13);
INSERT INTO "django_geo_db_city" VALUES(9964,'Shellman','Shellman, Georgia',12157,13);
INSERT INTO "django_geo_db_city" VALUES(9965,'Smithville','Smithville, Georgia',12158,13);
INSERT INTO "django_geo_db_city" VALUES(9966,'White House','White House, Tennessee',12159,50);
INSERT INTO "django_geo_db_city" VALUES(9967,'Sumner','Sumner, Georgia',12160,13);
INSERT INTO "django_geo_db_city" VALUES(9968,'Sycamore','Sycamore, Georgia',12161,13);
INSERT INTO "django_geo_db_city" VALUES(9969,'Sylvester','Sylvester, Georgia',12162,13);
INSERT INTO "django_geo_db_city" VALUES(9970,'Tifton','Tifton, Georgia',12164,13);
INSERT INTO "django_geo_db_city" VALUES(9971,'Ty Ty','Ty Ty, Georgia',12166,13);
INSERT INTO "django_geo_db_city" VALUES(9972,'Warwick','Warwick, Georgia',12167,13);
INSERT INTO "django_geo_db_city" VALUES(9973,'Whigham','Whigham, Georgia',12168,13);
INSERT INTO "django_geo_db_city" VALUES(9974,'Wray','Wray, Georgia',12169,13);
INSERT INTO "django_geo_db_city" VALUES(9975,'Box Springs','Box Springs, Georgia',12171,13);
INSERT INTO "django_geo_db_city" VALUES(9976,'Buena Vista','Buena Vista, Georgia',12172,13);
INSERT INTO "django_geo_db_city" VALUES(9977,'Cataula','Cataula, Georgia',12173,13);
INSERT INTO "django_geo_db_city" VALUES(9978,'Cusseta','Cusseta, Georgia',12174,13);
INSERT INTO "django_geo_db_city" VALUES(9979,'Ellaville','Ellaville, Georgia',12175,13);
INSERT INTO "django_geo_db_city" VALUES(9980,'Ellerslie','Ellerslie, Georgia',12176,13);
INSERT INTO "django_geo_db_city" VALUES(9981,'Fortson','Fortson, Georgia',12177,13);
INSERT INTO "django_geo_db_city" VALUES(9982,'Geneva','Geneva, Georgia',12178,13);
INSERT INTO "django_geo_db_city" VALUES(9983,'Hamilton','Hamilton, Georgia',12179,13);
INSERT INTO "django_geo_db_city" VALUES(9984,'Junction City','Junction City, Georgia',12180,13);
INSERT INTO "django_geo_db_city" VALUES(9985,'Louvale','Louvale, Georgia',12181,13);
INSERT INTO "django_geo_db_city" VALUES(9986,'Lumpkin','Lumpkin, Georgia',12182,13);
INSERT INTO "django_geo_db_city" VALUES(9987,'Manchester','Manchester, Georgia',12183,13);
INSERT INTO "django_geo_db_city" VALUES(9988,'Midland','Midland, Georgia',12184,13);
INSERT INTO "django_geo_db_city" VALUES(9989,'Omaha','Omaha, Georgia',12185,13);
INSERT INTO "django_geo_db_city" VALUES(9990,'Pine Mountain','Pine Mountain, Georgia',12186,13);
INSERT INTO "django_geo_db_city" VALUES(9991,'Pine Mountain Valley','Pine Mountain Valley, Georgia',12187,13);
INSERT INTO "django_geo_db_city" VALUES(9992,'Preston','Preston, Georgia',12188,13);
INSERT INTO "django_geo_db_city" VALUES(9993,'Richland','Richland, Georgia',12189,13);
INSERT INTO "django_geo_db_city" VALUES(9994,'Shiloh','Shiloh, Georgia',12190,13);
INSERT INTO "django_geo_db_city" VALUES(9995,'Talbotton','Talbotton, Georgia',12191,13);
INSERT INTO "django_geo_db_city" VALUES(9996,'Upatoi','Upatoi, Georgia',12192,13);
INSERT INTO "django_geo_db_city" VALUES(9997,'Warm Springs','Warm Springs, Georgia',12193,13);
INSERT INTO "django_geo_db_city" VALUES(9998,'Waverly Hall','Waverly Hall, Georgia',12194,13);
INSERT INTO "django_geo_db_city" VALUES(9999,'Weston','Weston, Georgia',12195,13);
INSERT INTO "django_geo_db_city" VALUES(10000,'West Point','West Point, Georgia',12196,13);
INSERT INTO "django_geo_db_city" VALUES(10001,'Woodland','Woodland, Georgia',12197,13);
INSERT INTO "django_geo_db_city" VALUES(10002,'Columbus','Columbus, Georgia',12198,13);
INSERT INTO "django_geo_db_city" VALUES(10003,'Fort Benning','Fort Benning, Georgia',12202,13);
INSERT INTO "django_geo_db_city" VALUES(10004,'Ponte Vedra Beach','Ponte Vedra Beach, Florida',12210,11);
INSERT INTO "django_geo_db_city" VALUES(10005,'Bostwick','Bostwick, Florida',12211,11);
INSERT INTO "django_geo_db_city" VALUES(10006,'Branford','Branford, Florida',12212,11);
INSERT INTO "django_geo_db_city" VALUES(10007,'Bryceville','Bryceville, Florida',12213,11);
INSERT INTO "django_geo_db_city" VALUES(10008,'Callahan','Callahan, Florida',12214,11);
INSERT INTO "django_geo_db_city" VALUES(10009,'Day','Day, Florida',12215,11);
INSERT INTO "django_geo_db_city" VALUES(10010,'Lake City','Lake City, Florida',12216,11);
INSERT INTO "django_geo_db_city" VALUES(10011,'Doctors Inlet','Doctors Inlet, Florida',12218,11);
INSERT INTO "django_geo_db_city" VALUES(10012,'Elkton','Elkton, Florida',12219,11);
INSERT INTO "django_geo_db_city" VALUES(10013,'Fernandina Beach','Fernandina Beach, Florida',12220,11);
INSERT INTO "django_geo_db_city" VALUES(10014,'Fort White','Fort White, Florida',12222,11);
INSERT INTO "django_geo_db_city" VALUES(10015,'Glen Saint Mary','Glen Saint Mary, Florida',12223,11);
INSERT INTO "django_geo_db_city" VALUES(10016,'Yulee','Yulee, Florida',12224,11);
INSERT INTO "django_geo_db_city" VALUES(10017,'Graham','Graham, Florida',12225,11);
INSERT INTO "django_geo_db_city" VALUES(10018,'Green Cove Springs','Green Cove Springs, Florida',12226,11);
INSERT INTO "django_geo_db_city" VALUES(10019,'Hampton','Hampton, Florida',12227,11);
INSERT INTO "django_geo_db_city" VALUES(10020,'Hilliard','Hilliard, Florida',12228,11);
INSERT INTO "django_geo_db_city" VALUES(10021,'Middleburg','Middleburg, Florida',12230,11);
INSERT INTO "django_geo_db_city" VALUES(10022,'Jasper','Jasper, Florida',12231,11);
INSERT INTO "django_geo_db_city" VALUES(10023,'Jennings','Jennings, Florida',12232,11);
INSERT INTO "django_geo_db_city" VALUES(10024,'Lake Butler','Lake Butler, Florida',12233,11);
INSERT INTO "django_geo_db_city" VALUES(10025,'Lawtey','Lawtey, Florida',12236,11);
INSERT INTO "django_geo_db_city" VALUES(10026,'Lee','Lee, Florida',12237,11);
INSERT INTO "django_geo_db_city" VALUES(10027,'Live Oak','Live Oak, Florida',12238,11);
INSERT INTO "django_geo_db_city" VALUES(10028,'Lulu','Lulu, Florida',12239,11);
INSERT INTO "django_geo_db_city" VALUES(10029,'McAlpin','McAlpin, Florida',12240,11);
INSERT INTO "django_geo_db_city" VALUES(10030,'Macclenny','Macclenny, Florida',12241,11);
INSERT INTO "django_geo_db_city" VALUES(10031,'Orange Park','Orange Park, Florida',12243,11);
INSERT INTO "django_geo_db_city" VALUES(10032,'Mayo','Mayo, Florida',12244,11);
INSERT INTO "django_geo_db_city" VALUES(10033,'O Brien','O Brien, Florida',12247,11);
INSERT INTO "django_geo_db_city" VALUES(10034,'Olustee','Olustee, Florida',12248,11);
INSERT INTO "django_geo_db_city" VALUES(10035,'Penney Farms','Penney Farms, Florida',12250,11);
INSERT INTO "django_geo_db_city" VALUES(10036,'St. Augustine','St. Augustine, Florida',12251,11);
INSERT INTO "django_geo_db_city" VALUES(10037,'Pomona Park','Pomona Park, Florida',12252,11);
INSERT INTO "django_geo_db_city" VALUES(10038,'Raiford','Raiford, Florida',12254,11);
INSERT INTO "django_geo_db_city" VALUES(10039,'Saint Augustine','Saint Augustine, Florida',12255,11);
INSERT INTO "django_geo_db_city" VALUES(10040,'Sanderson','Sanderson, Florida',12257,11);
INSERT INTO "django_geo_db_city" VALUES(10041,'Starke','Starke, Florida',12258,11);
INSERT INTO "django_geo_db_city" VALUES(10042,'Wellborn','Wellborn, Florida',12260,11);
INSERT INTO "django_geo_db_city" VALUES(10043,'White Springs','White Springs, Florida',12262,11);
INSERT INTO "django_geo_db_city" VALUES(10044,'Palm Valley','Palm Valley, Florida',12264,11);
INSERT INTO "django_geo_db_city" VALUES(10045,'Jacksonville','Jacksonville, Florida',12265,11);
INSERT INTO "django_geo_db_city" VALUES(10046,'Astor','Astor, Florida',12266,11);
INSERT INTO "django_geo_db_city" VALUES(10047,'Barberville','Barberville, Florida',12267,11);
INSERT INTO "django_geo_db_city" VALUES(10048,'Bunnell','Bunnell, Florida',12268,11);
INSERT INTO "django_geo_db_city" VALUES(10049,'Candler','Candler, Florida',12269,11);
INSERT INTO "django_geo_db_city" VALUES(10050,'Crescent City','Crescent City, Florida',12270,11);
INSERT INTO "django_geo_db_city" VALUES(10051,'Citra','Citra, Florida',12271,11);
INSERT INTO "django_geo_db_city" VALUES(10052,'Daytona Beach','Daytona Beach, Florida',12272,11);
INSERT INTO "django_geo_db_city" VALUES(10053,'Port Orange','Port Orange, Florida',12280,11);
INSERT INTO "django_geo_db_city" VALUES(10054,'De Leon Springs','De Leon Springs, Florida',12281,11);
INSERT INTO "django_geo_db_city" VALUES(10055,'East Palatka','East Palatka, Florida',12282,11);
INSERT INTO "django_geo_db_city" VALUES(10056,'Edgewater','Edgewater, Florida',12283,11);
INSERT INTO "django_geo_db_city" VALUES(10057,'Eastlake Weir','Eastlake Weir, Florida',12284,11);
INSERT INTO "django_geo_db_city" VALUES(10058,'Fort McCoy','Fort McCoy, Florida',12285,11);
INSERT INTO "django_geo_db_city" VALUES(10059,'Palm Coast','Palm Coast, Florida',12286,11);
INSERT INTO "django_geo_db_city" VALUES(10060,'Flagler Beach','Flagler Beach, Florida',12287,11);
INSERT INTO "django_geo_db_city" VALUES(10061,'Grandin','Grandin, Florida',12289,11);
INSERT INTO "django_geo_db_city" VALUES(10062,'Georgetown','Georgetown, Florida',12290,11);
INSERT INTO "django_geo_db_city" VALUES(10063,'Florahome','Florahome, Florida',12291,11);
INSERT INTO "django_geo_db_city" VALUES(10064,'Hastings','Hastings, Florida',12293,11);
INSERT INTO "django_geo_db_city" VALUES(10065,'Hollister','Hollister, Florida',12294,11);
INSERT INTO "django_geo_db_city" VALUES(10066,'Interlachen','Interlachen, Florida',12295,11);
INSERT INTO "django_geo_db_city" VALUES(10067,'Lake Como','Lake Como, Florida',12297,11);
INSERT INTO "django_geo_db_city" VALUES(10068,'Lady Lake','Lady Lake, Florida',12298,11);
INSERT INTO "django_geo_db_city" VALUES(10069,'Lake Geneva','Lake Geneva, Florida',12300,11);
INSERT INTO "django_geo_db_city" VALUES(10070,'The Villages','The Villages, Florida',12301,11);
INSERT INTO "django_geo_db_city" VALUES(10071,'New Smyrna Beach','New Smyrna Beach, Florida',12303,11);
INSERT INTO "django_geo_db_city" VALUES(10072,'Ormond Beach','Ormond Beach, Florida',12273,11);
INSERT INTO "django_geo_db_city" VALUES(10073,'Palatka','Palatka, Florida',12307,11);
INSERT INTO "django_geo_db_city" VALUES(10074,'Ocklawaha','Ocklawaha, Florida',12309,11);
INSERT INTO "django_geo_db_city" VALUES(10075,'Pierson','Pierson, Florida',12310,11);
INSERT INTO "django_geo_db_city" VALUES(10076,'Orange Springs','Orange Springs, Florida',12312,11);
INSERT INTO "django_geo_db_city" VALUES(10077,'Putnam Hall','Putnam Hall, Florida',12314,11);
INSERT INTO "django_geo_db_city" VALUES(10078,'San Mateo','San Mateo, Florida',12315,11);
INSERT INTO "django_geo_db_city" VALUES(10079,'Satsuma','Satsuma, Florida',12316,11);
INSERT INTO "django_geo_db_city" VALUES(10080,'Seville','Seville, Florida',12317,11);
INSERT INTO "django_geo_db_city" VALUES(10081,'Sparr','Sparr, Florida',12318,11);
INSERT INTO "django_geo_db_city" VALUES(10082,'Welaka','Welaka, Florida',12319,11);
INSERT INTO "django_geo_db_city" VALUES(10083,'Weirsdale','Weirsdale, Florida',12320,11);
INSERT INTO "django_geo_db_city" VALUES(10084,'Atlantic Beach','Atlantic Beach, Florida',12348,11);
INSERT INTO "django_geo_db_city" VALUES(10085,'Jacksonville Beach','Jacksonville Beach, Florida',12333,11);
INSERT INTO "django_geo_db_city" VALUES(10086,'Neptune Beach','Neptune Beach, Florida',12359,11);
INSERT INTO "django_geo_db_city" VALUES(10087,'Tallahassee','Tallahassee, Florida',12362,11);
INSERT INTO "django_geo_db_city" VALUES(10088,'Wakulla Springs','Wakulla Springs, Florida',12366,11);
INSERT INTO "django_geo_db_city" VALUES(10089,'Miccosukee Cpo','Miccosukee Cpo, Florida',12370,11);
INSERT INTO "django_geo_db_city" VALUES(10090,'Apalachicola','Apalachicola, Florida',12374,11);
INSERT INTO "django_geo_db_city" VALUES(10091,'Bristol','Bristol, Florida',12375,11);
INSERT INTO "django_geo_db_city" VALUES(10092,'Carrabelle','Carrabelle, Florida',12376,11);
INSERT INTO "django_geo_db_city" VALUES(10093,'Lanark Village','Lanark Village, Florida',12377,11);
INSERT INTO "django_geo_db_city" VALUES(10094,'Chattahoochee','Chattahoochee, Florida',12378,11);
INSERT INTO "django_geo_db_city" VALUES(10095,'Crawfordville','Crawfordville, Florida',12379,11);
INSERT INTO "django_geo_db_city" VALUES(10096,'Eastpoint','Eastpoint, Florida',12381,11);
INSERT INTO "django_geo_db_city" VALUES(10097,'Greensboro','Greensboro, Florida',12383,11);
INSERT INTO "django_geo_db_city" VALUES(10098,'Greenville','Greenville, Florida',12384,11);
INSERT INTO "django_geo_db_city" VALUES(10099,'Gretna','Gretna, Florida',12385,11);
INSERT INTO "django_geo_db_city" VALUES(10100,'Havana','Havana, Florida',12386,11);
INSERT INTO "django_geo_db_city" VALUES(10101,'Hosford','Hosford, Florida',12387,11);
INSERT INTO "django_geo_db_city" VALUES(10102,'Sumatra','Sumatra, Florida',12388,11);
INSERT INTO "django_geo_db_city" VALUES(10103,'Lamont','Lamont, Florida',12389,11);
INSERT INTO "django_geo_db_city" VALUES(10104,'Lloyd','Lloyd, Florida',12390,11);
INSERT INTO "django_geo_db_city" VALUES(10105,'Madison','Madison, Florida',12391,11);
INSERT INTO "django_geo_db_city" VALUES(10106,'Midway','Midway, Florida',12393,11);
INSERT INTO "django_geo_db_city" VALUES(10107,'Monticello','Monticello, Florida',12395,11);
INSERT INTO "django_geo_db_city" VALUES(10108,'Panacea','Panacea, Florida',12397,11);
INSERT INTO "django_geo_db_city" VALUES(10109,'Perry','Perry, Florida',12398,11);
INSERT INTO "django_geo_db_city" VALUES(10110,'Pinetta','Pinetta, Florida',12401,11);
INSERT INTO "django_geo_db_city" VALUES(10111,'Quincy','Quincy, Florida',12402,11);
INSERT INTO "django_geo_db_city" VALUES(10112,'Mount Pleasant','Mount Pleasant, Florida',12403,11);
INSERT INTO "django_geo_db_city" VALUES(10113,'Saint Marks','Saint Marks, Florida',12405,11);
INSERT INTO "django_geo_db_city" VALUES(10114,'Salem','Salem, Florida',12406,11);
INSERT INTO "django_geo_db_city" VALUES(10115,'Shady Grove','Shady Grove, Florida',12407,11);
INSERT INTO "django_geo_db_city" VALUES(10116,'Sopchoppy','Sopchoppy, Florida',12408,11);
INSERT INTO "django_geo_db_city" VALUES(10117,'Steinhatchee','Steinhatchee, Florida',12409,11);
INSERT INTO "django_geo_db_city" VALUES(10118,'Telogia','Telogia, Florida',12410,11);
INSERT INTO "django_geo_db_city" VALUES(10119,'Wacissa','Wacissa, Florida',12411,11);
INSERT INTO "django_geo_db_city" VALUES(10120,'Woodville','Woodville, Florida',12412,11);
INSERT INTO "django_geo_db_city" VALUES(10121,'Panama City','Panama City, Florida',12414,11);
INSERT INTO "django_geo_db_city" VALUES(10122,'Panama City Beach','Panama City Beach, Florida',12419,11);
INSERT INTO "django_geo_db_city" VALUES(10123,'Mexico Beach','Mexico Beach, Florida',12422,11);
INSERT INTO "django_geo_db_city" VALUES(10124,'Alford','Alford, Florida',12425,11);
INSERT INTO "django_geo_db_city" VALUES(10125,'Altha','Altha, Florida',12426,11);
INSERT INTO "django_geo_db_city" VALUES(10126,'Argyle','Argyle, Florida',12427,11);
INSERT INTO "django_geo_db_city" VALUES(10127,'Bascom','Bascom, Florida',12428,11);
INSERT INTO "django_geo_db_city" VALUES(10128,'Blountstown','Blountstown, Florida',12429,11);
INSERT INTO "django_geo_db_city" VALUES(10129,'Bonifay','Bonifay, Florida',12430,11);
INSERT INTO "django_geo_db_city" VALUES(10130,'Campbellton','Campbellton, Florida',12431,11);
INSERT INTO "django_geo_db_city" VALUES(10131,'Caryville','Caryville, Florida',12432,11);
INSERT INTO "django_geo_db_city" VALUES(10132,'Chipley','Chipley, Florida',12433,11);
INSERT INTO "django_geo_db_city" VALUES(10133,'Clarksville','Clarksville, Florida',12434,11);
INSERT INTO "django_geo_db_city" VALUES(10134,'Cottondale','Cottondale, Florida',12435,11);
INSERT INTO "django_geo_db_city" VALUES(10135,'Cypress','Cypress, Florida',12436,11);
INSERT INTO "django_geo_db_city" VALUES(10136,'Defuniak Springs','Defuniak Springs, Florida',12437,11);
INSERT INTO "django_geo_db_city" VALUES(10137,'Mossy Head','Mossy Head, Florida',12438,11);
INSERT INTO "django_geo_db_city" VALUES(10138,'Wewahitchka','Wewahitchka, Florida',12440,11);
INSERT INTO "django_geo_db_city" VALUES(10139,'Ebro','Ebro, Florida',12441,11);
INSERT INTO "django_geo_db_city" VALUES(10140,'Fountain','Fountain, Florida',12442,11);
INSERT INTO "django_geo_db_city" VALUES(10141,'Freeport','Freeport, Florida',12443,11);
INSERT INTO "django_geo_db_city" VALUES(10142,'Graceville','Graceville, Florida',12444,11);
INSERT INTO "django_geo_db_city" VALUES(10143,'Grand Ridge','Grand Ridge, Florida',12445,11);
INSERT INTO "django_geo_db_city" VALUES(10144,'Greenwood','Greenwood, Florida',12446,11);
INSERT INTO "django_geo_db_city" VALUES(10145,'Lynn Haven','Lynn Haven, Florida',12447,11);
INSERT INTO "django_geo_db_city" VALUES(10146,'Malone','Malone, Florida',12448,11);
INSERT INTO "django_geo_db_city" VALUES(10147,'Marianna','Marianna, Florida',12449,11);
INSERT INTO "django_geo_db_city" VALUES(10148,'Kinard','Kinard, Florida',12452,11);
INSERT INTO "django_geo_db_city" VALUES(10149,'Noma','Noma, Florida',12453,11);
INSERT INTO "django_geo_db_city" VALUES(10150,'Point Washington','Point Washington, Florida',12439,11);
INSERT INTO "django_geo_db_city" VALUES(10151,'Ponce De Leon','Ponce De Leon, Florida',12454,11);
INSERT INTO "django_geo_db_city" VALUES(10152,'Port Saint Joe','Port Saint Joe, Florida',12455,11);
INSERT INTO "django_geo_db_city" VALUES(10153,'Santa Rosa Beach','Santa Rosa Beach, Florida',12457,11);
INSERT INTO "django_geo_db_city" VALUES(10154,'Sneads','Sneads, Florida',12458,11);
INSERT INTO "django_geo_db_city" VALUES(10155,'Sunnyside','Sunnyside, Florida',12459,11);
INSERT INTO "django_geo_db_city" VALUES(10156,'Vernon','Vernon, Florida',12460,11);
INSERT INTO "django_geo_db_city" VALUES(10157,'Wausau','Wausau, Florida',12461,11);
INSERT INTO "django_geo_db_city" VALUES(10158,'Westville','Westville, Florida',12462,11);
INSERT INTO "django_geo_db_city" VALUES(10159,'Youngstown','Youngstown, Florida',12464,11);
INSERT INTO "django_geo_db_city" VALUES(10160,'Lake Mary','Lake Mary, Florida',12465,11);
INSERT INTO "django_geo_db_city" VALUES(10161,'Pensacola','Pensacola, Florida',12467,11);
INSERT INTO "django_geo_db_city" VALUES(10162,'Bagdad','Bagdad, Florida',12482,11);
INSERT INTO "django_geo_db_city" VALUES(10163,'Baker','Baker, Florida',12483,11);
INSERT INTO "django_geo_db_city" VALUES(10164,'Cantonment','Cantonment, Florida',12484,11);
INSERT INTO "django_geo_db_city" VALUES(10165,'Century','Century, Florida',12486,11);
INSERT INTO "django_geo_db_city" VALUES(10166,'Crestview','Crestview, Florida',12487,11);
INSERT INTO "django_geo_db_city" VALUES(10167,'Milligan','Milligan, Florida',12488,11);
INSERT INTO "django_geo_db_city" VALUES(10168,'Paxton','Paxton, Florida',12489,11);
INSERT INTO "django_geo_db_city" VALUES(10169,'Destin','Destin, Florida',12491,11);
INSERT INTO "django_geo_db_city" VALUES(10170,'Eglin AFB','Eglin AFB, Florida',12493,11);
INSERT INTO "django_geo_db_city" VALUES(10171,'Hurlburt Field','Hurlburt Field, Florida',12494,11);
INSERT INTO "django_geo_db_city" VALUES(10172,'Myrtle Grove','Myrtle Grove, Florida',12495,11);
INSERT INTO "django_geo_db_city" VALUES(10173,'Fort Walton Beach','Fort Walton Beach, Florida',12496,11);
INSERT INTO "django_geo_db_city" VALUES(10174,'Miramar Beach','Miramar Beach, Florida',12498,11);
INSERT INTO "django_geo_db_city" VALUES(10175,'Gonzalez','Gonzalez, Florida',12500,11);
INSERT INTO "django_geo_db_city" VALUES(10176,'Gulf Breeze','Gulf Breeze, Florida',12501,11);
INSERT INTO "django_geo_db_city" VALUES(10177,'Harold','Harold, Florida',12502,11);
INSERT INTO "django_geo_db_city" VALUES(10178,'Holt','Holt, Florida',12503,11);
INSERT INTO "django_geo_db_city" VALUES(10179,'Jay','Jay, Florida',12504,11);
INSERT INTO "django_geo_db_city" VALUES(10180,'Laurel Hill','Laurel Hill, Florida',12506,11);
INSERT INTO "django_geo_db_city" VALUES(10181,'McDavid','McDavid, Florida',12507,11);
INSERT INTO "django_geo_db_city" VALUES(10182,'Mary Esther','Mary Esther, Florida',12508,11);
INSERT INTO "django_geo_db_city" VALUES(10183,'Milton','Milton, Florida',12509,11);
INSERT INTO "django_geo_db_city" VALUES(10184,'Molino','Molino, Florida',12511,11);
INSERT INTO "django_geo_db_city" VALUES(10185,'Niceville','Niceville, Florida',12512,11);
INSERT INTO "django_geo_db_city" VALUES(10186,'Shalimar','Shalimar, Florida',12513,11);
INSERT INTO "django_geo_db_city" VALUES(10187,'Valparaiso','Valparaiso, Florida',12514,11);
INSERT INTO "django_geo_db_city" VALUES(10188,'Gainesville','Gainesville, Florida',12517,11);
INSERT INTO "django_geo_db_city" VALUES(10189,'Alachua','Alachua, Florida',12527,11);
INSERT INTO "django_geo_db_city" VALUES(10190,'Anthony','Anthony, Florida',12529,11);
INSERT INTO "django_geo_db_city" VALUES(10191,'Archer','Archer, Florida',12530,11);
INSERT INTO "django_geo_db_city" VALUES(10192,'Bell','Bell, Florida',12531,11);
INSERT INTO "django_geo_db_city" VALUES(10193,'Bronson','Bronson, Florida',12532,11);
INSERT INTO "django_geo_db_city" VALUES(10194,'Brooker','Brooker, Florida',12533,11);
INSERT INTO "django_geo_db_city" VALUES(10195,'Cedar Key','Cedar Key, Florida',12534,11);
INSERT INTO "django_geo_db_city" VALUES(10196,'Chiefland','Chiefland, Florida',12535,11);
INSERT INTO "django_geo_db_city" VALUES(10197,'Cross City','Cross City, Florida',12536,11);
INSERT INTO "django_geo_db_city" VALUES(10198,'Earleton','Earleton, Florida',12537,11);
INSERT INTO "django_geo_db_city" VALUES(10199,'Evinston','Evinston, Florida',12526,11);
INSERT INTO "django_geo_db_city" VALUES(10200,'Fairfield','Fairfield, Florida',12538,11);
INSERT INTO "django_geo_db_city" VALUES(10201,'Trenton','Trenton, Florida',12539,11);
INSERT INTO "django_geo_db_city" VALUES(10202,'Gulf Hammock','Gulf Hammock, Florida',12540,11);
INSERT INTO "django_geo_db_city" VALUES(10203,'Hawthorne','Hawthorne, Florida',12541,11);
INSERT INTO "django_geo_db_city" VALUES(10204,'High Springs','High Springs, Florida',12543,11);
INSERT INTO "django_geo_db_city" VALUES(10205,'Horseshoe Beach','Horseshoe Beach, Florida',12545,11);
INSERT INTO "django_geo_db_city" VALUES(10206,'Island Grove','Island Grove, Florida',12547,11);
INSERT INTO "django_geo_db_city" VALUES(10207,'Keystone Heights','Keystone Heights, Florida',12549,11);
INSERT INTO "django_geo_db_city" VALUES(10208,'La Crosse','La Crosse, Florida',12550,11);
INSERT INTO "django_geo_db_city" VALUES(10209,'Lochloosa','Lochloosa, Florida',12551,11);
INSERT INTO "django_geo_db_city" VALUES(10210,'Lowell','Lowell, Florida',12552,11);
INSERT INTO "django_geo_db_city" VALUES(10211,'McIntosh','McIntosh, Florida',12553,11);
INSERT INTO "django_geo_db_city" VALUES(10212,'Melrose','Melrose, Florida',12554,11);
INSERT INTO "django_geo_db_city" VALUES(10213,'Micanopy','Micanopy, Florida',12555,11);
INSERT INTO "django_geo_db_city" VALUES(10214,'Morriston','Morriston, Florida',12556,11);
INSERT INTO "django_geo_db_city" VALUES(10215,'Newberry','Newberry, Florida',12557,11);
INSERT INTO "django_geo_db_city" VALUES(10216,'Old Town','Old Town, Florida',12558,11);
INSERT INTO "django_geo_db_city" VALUES(10217,'Orange Lake','Orange Lake, Florida',12559,11);
INSERT INTO "django_geo_db_city" VALUES(10218,'Otter Creek','Otter Creek, Florida',12560,11);
INSERT INTO "django_geo_db_city" VALUES(10219,'Reddick','Reddick, Florida',12561,11);
INSERT INTO "django_geo_db_city" VALUES(10220,'Suwannee','Suwannee, Florida',12562,11);
INSERT INTO "django_geo_db_city" VALUES(10221,'Waldo','Waldo, Florida',12564,11);
INSERT INTO "django_geo_db_city" VALUES(10222,'Williston','Williston, Florida',12565,11);
INSERT INTO "django_geo_db_city" VALUES(10223,'Worthington Springs','Worthington Springs, Florida',12566,11);
INSERT INTO "django_geo_db_city" VALUES(10224,'Altamonte Springs','Altamonte Springs, Florida',12568,11);
INSERT INTO "django_geo_db_city" VALUES(10225,'Altoona','Altoona, Florida',12569,11);
INSERT INTO "django_geo_db_city" VALUES(10226,'Apopka','Apopka, Florida',12570,11);
INSERT INTO "django_geo_db_city" VALUES(10227,'Cassadaga','Cassadaga, Florida',12572,11);
INSERT INTO "django_geo_db_city" VALUES(10228,'Casselberry','Casselberry, Florida',12573,11);
INSERT INTO "django_geo_db_city" VALUES(10229,'Winter Springs','Winter Springs, Florida',12574,11);
INSERT INTO "django_geo_db_city" VALUES(10230,'Christmas','Christmas, Florida',12575,11);
INSERT INTO "django_geo_db_city" VALUES(10231,'Clarcona','Clarcona, Florida',12571,11);
INSERT INTO "django_geo_db_city" VALUES(10232,'Debary','Debary, Florida',12577,11);
INSERT INTO "django_geo_db_city" VALUES(10233,'Deland','Deland, Florida',12580,11);
INSERT INTO "django_geo_db_city" VALUES(10234,'Glenwood','Glenwood, Florida',12273,11);
INSERT INTO "django_geo_db_city" VALUES(10235,'Deltona','Deltona, Florida',12583,11);
INSERT INTO "django_geo_db_city" VALUES(10236,'Eustis','Eustis, Florida',12584,11);
INSERT INTO "django_geo_db_city" VALUES(10237,'Geneva','Geneva, Florida',12587,11);
INSERT INTO "django_geo_db_city" VALUES(10238,'Goldenrod','Goldenrod, Florida',12588,11);
INSERT INTO "django_geo_db_city" VALUES(10239,'Grand Island','Grand Island, Florida',12589,11);
INSERT INTO "django_geo_db_city" VALUES(10240,'Lake Helen','Lake Helen, Florida',12592,11);
INSERT INTO "django_geo_db_city" VALUES(10241,'Heathrow','Heathrow, Florida',12593,11);
INSERT INTO "django_geo_db_city" VALUES(10242,'Lake Monroe','Lake Monroe, Florida',12595,11);
INSERT INTO "django_geo_db_city" VALUES(10243,'Longwood','Longwood, Florida',12596,11);
INSERT INTO "django_geo_db_city" VALUES(10244,'Maitland','Maitland, Florida',12597,11);
INSERT INTO "django_geo_db_city" VALUES(10245,'Mims','Mims, Florida',12598,11);
INSERT INTO "django_geo_db_city" VALUES(10246,'Mount Dora','Mount Dora, Florida',12298,11);
INSERT INTO "django_geo_db_city" VALUES(10247,'Oak Hill','Oak Hill, Florida',12600,11);
INSERT INTO "django_geo_db_city" VALUES(10248,'Oviedo','Oviedo, Florida',12579,11);
INSERT INTO "django_geo_db_city" VALUES(10249,'Orange City','Orange City, Florida',12601,11);
INSERT INTO "django_geo_db_city" VALUES(10250,'Osteen','Osteen, Florida',12602,11);
INSERT INTO "django_geo_db_city" VALUES(10251,'Paisley','Paisley, Florida',12605,11);
INSERT INTO "django_geo_db_city" VALUES(10252,'Plymouth','Plymouth, Florida',12606,11);
INSERT INTO "django_geo_db_city" VALUES(10253,'Sanford','Sanford, Florida',12608,11);
INSERT INTO "django_geo_db_city" VALUES(10254,'Scottsmoor','Scottsmoor, Florida',12611,11);
INSERT INTO "django_geo_db_city" VALUES(10255,'Sorrento','Sorrento, Florida',12612,11);
INSERT INTO "django_geo_db_city" VALUES(10256,'Tangerine','Tangerine, Florida',12571,11);
INSERT INTO "django_geo_db_city" VALUES(10257,'Tavares','Tavares, Florida',12613,11);
INSERT INTO "django_geo_db_city" VALUES(10258,'Titusville','Titusville, Florida',12615,11);
INSERT INTO "django_geo_db_city" VALUES(10259,'Umatilla','Umatilla, Florida',12617,11);
INSERT INTO "django_geo_db_city" VALUES(10260,'Winter Park','Winter Park, Florida',12618,11);
INSERT INTO "django_geo_db_city" VALUES(10261,'Zellwood','Zellwood, Florida',12621,11);
INSERT INTO "django_geo_db_city" VALUES(10262,'Mid Florida','Mid Florida, Florida',12579,11);
INSERT INTO "django_geo_db_city" VALUES(10263,'Orlando','Orlando, Florida',12622,11);
INSERT INTO "django_geo_db_city" VALUES(10264,'Melbourne','Melbourne, Florida',12659,11);
INSERT INTO "django_geo_db_city" VALUES(10265,'Indialantic','Indialantic, Florida',12660,11);
INSERT INTO "django_geo_db_city" VALUES(10266,'Palm Bay','Palm Bay, Florida',12662,11);
INSERT INTO "django_geo_db_city" VALUES(10267,'Cape Canaveral','Cape Canaveral, Florida',12667,11);
INSERT INTO "django_geo_db_city" VALUES(10268,'Cocoa','Cocoa, Florida',12668,11);
INSERT INTO "django_geo_db_city" VALUES(10269,'Patrick AFB','Patrick AFB, Florida',12670,11);
INSERT INTO "django_geo_db_city" VALUES(10270,'Cocoa Beach','Cocoa Beach, Florida',12673,11);
INSERT INTO "django_geo_db_city" VALUES(10271,'Satellite Beach','Satellite Beach, Florida',12676,11);
INSERT INTO "django_geo_db_city" VALUES(10272,'Fellsmere','Fellsmere, Florida',12679,11);
INSERT INTO "django_geo_db_city" VALUES(10273,'Grant','Grant, Florida',12680,11);
INSERT INTO "django_geo_db_city" VALUES(10274,'Malabar','Malabar, Florida',12681,11);
INSERT INTO "django_geo_db_city" VALUES(10275,'Melbourne Beach','Melbourne Beach, Florida',12682,11);
INSERT INTO "django_geo_db_city" VALUES(10276,'Merritt Island','Merritt Island, Florida',12683,11);
INSERT INTO "django_geo_db_city" VALUES(10277,'Rockledge','Rockledge, Florida',12686,11);
INSERT INTO "django_geo_db_city" VALUES(10278,'Roseland','Roseland, Florida',12688,11);
INSERT INTO "django_geo_db_city" VALUES(10279,'Sebastian','Sebastian, Florida',12689,11);
INSERT INTO "django_geo_db_city" VALUES(10280,'Sharpes','Sharpes, Florida',12616,11);
INSERT INTO "django_geo_db_city" VALUES(10281,'Vero Beach','Vero Beach, Florida',12690,11);
INSERT INTO "django_geo_db_city" VALUES(10282,'Wabasso','Wabasso, Florida',12697,11);
INSERT INTO "django_geo_db_city" VALUES(10283,'Winter Beach','Winter Beach, Florida',12688,11);
INSERT INTO "django_geo_db_city" VALUES(10284,'Long Key','Long Key, Florida',12700,11);
INSERT INTO "django_geo_db_city" VALUES(10285,'Hialeah','Hialeah, Florida',12701,11);
INSERT INTO "django_geo_db_city" VALUES(10286,'Florida City','Florida City, Florida',12702,11);
INSERT INTO "django_geo_db_city" VALUES(10287,'Dania','Dania, Florida',12703,11);
INSERT INTO "django_geo_db_city" VALUES(10288,'Hallandale','Hallandale, Florida',12704,11);
INSERT INTO "django_geo_db_city" VALUES(10289,'Hollywood','Hollywood, Florida',12713,11);
INSERT INTO "django_geo_db_city" VALUES(10290,'Pembroke Pines','Pembroke Pines, Florida',12722,11);
INSERT INTO "django_geo_db_city" VALUES(10291,'Homestead','Homestead, Florida',12724,11);
INSERT INTO "django_geo_db_city" VALUES(10292,'Islamorada','Islamorada, Florida',12730,11);
INSERT INTO "django_geo_db_city" VALUES(10293,'Key Largo','Key Largo, Florida',12731,11);
INSERT INTO "django_geo_db_city" VALUES(10294,'Key West','Key West, Florida',12732,11);
INSERT INTO "django_geo_db_city" VALUES(10295,'Summerland Key','Summerland Key, Florida',12734,11);
INSERT INTO "django_geo_db_city" VALUES(10296,'Big Pine Key','Big Pine Key, Florida',12735,11);
INSERT INTO "django_geo_db_city" VALUES(10297,'Sugarloaf Shores','Sugarloaf Shores, Florida',12736,11);
INSERT INTO "django_geo_db_city" VALUES(10298,'West Little River','West Little River, Florida',12737,11);
INSERT INTO "django_geo_db_city" VALUES(10299,'Marathon','Marathon, Florida',12738,11);
INSERT INTO "django_geo_db_city" VALUES(10300,'Key Colony Beach','Key Colony Beach, Florida',12739,11);
INSERT INTO "django_geo_db_city" VALUES(10301,'Marathon Shores','Marathon Shores, Florida',12740,11);
INSERT INTO "django_geo_db_city" VALUES(10302,'Opa Locka','Opa Locka, Florida',12741,11);
INSERT INTO "django_geo_db_city" VALUES(10303,'Lake Lucerne','Lake Lucerne, Florida',12744,11);
INSERT INTO "django_geo_db_city" VALUES(10304,'Pompano Beach','Pompano Beach, Florida',12745,11);
INSERT INTO "django_geo_db_city" VALUES(10305,'Tavernier','Tavernier, Florida',12755,11);
INSERT INTO "django_geo_db_city" VALUES(10306,'Miami','Miami, Florida',12761,11);
INSERT INTO "django_geo_db_city" VALUES(10307,'Miami Beach','Miami Beach, Florida',12762,11);
INSERT INTO "django_geo_db_city" VALUES(10308,'Key Biscayne','Key Biscayne, Florida',12789,11);
INSERT INTO "django_geo_db_city" VALUES(10309,'North Miami Beach','North Miami Beach, Florida',12799,11);
INSERT INTO "django_geo_db_city" VALUES(10310,'Fort Lauderdale','Fort Lauderdale, Florida',12832,11);
INSERT INTO "django_geo_db_city" VALUES(10311,'Weston','Weston, Florida',12855,11);
INSERT INTO "django_geo_db_city" VALUES(10312,'Pine Island Ridge','Pine Island Ridge, Florida',12866,11);
INSERT INTO "django_geo_db_city" VALUES(10313,'Winter Haven','Winter Haven, Florida',12867,11);
INSERT INTO "django_geo_db_city" VALUES(10314,'West Palm Beach','West Palm Beach, Florida',12870,11);
INSERT INTO "django_geo_db_city" VALUES(10315,'North Palm Beach','North Palm Beach, Florida',12877,11);
INSERT INTO "django_geo_db_city" VALUES(10316,'Boynton Beach','Boynton Beach, Florida',12871,11);
INSERT INTO "django_geo_db_city" VALUES(10317,'Boca Raton','Boca Raton, Florida',12889,11);
INSERT INTO "django_geo_db_city" VALUES(10318,'Belle Glade','Belle Glade, Florida',12891,11);
INSERT INTO "django_geo_db_city" VALUES(10319,'Canal Point','Canal Point, Florida',12899,11);
INSERT INTO "django_geo_db_city" VALUES(10320,'Bryant','Bryant, Florida',12871,11);
INSERT INTO "django_geo_db_city" VALUES(10321,'Clewiston','Clewiston, Florida',12900,11);
INSERT INTO "django_geo_db_city" VALUES(10322,'Deerfield Beach','Deerfield Beach, Florida',12901,11);
INSERT INTO "django_geo_db_city" VALUES(10323,'Delray Beach','Delray Beach, Florida',12903,11);
INSERT INTO "django_geo_db_city" VALUES(10324,'Lantana','Lantana, Florida',12906,11);
INSERT INTO "django_geo_db_city" VALUES(10325,'Lake Worth','Lake Worth, Florida',12871,11);
INSERT INTO "django_geo_db_city" VALUES(10326,'Hobe Sound','Hobe Sound, Florida',12907,11);
INSERT INTO "django_geo_db_city" VALUES(10327,'Jupiter','Jupiter, Florida',12908,11);
INSERT INTO "django_geo_db_city" VALUES(10328,'Lake Harbor','Lake Harbor, Florida',12871,11);
INSERT INTO "django_geo_db_city" VALUES(10329,'Loxahatchee','Loxahatchee, Florida',12916,11);
INSERT INTO "django_geo_db_city" VALUES(10330,'Moore Haven','Moore Haven, Florida',12917,11);
INSERT INTO "django_geo_db_city" VALUES(10331,'Pahokee','Pahokee, Florida',12919,11);
INSERT INTO "django_geo_db_city" VALUES(10332,'Palm Beach','Palm Beach, Florida',12922,11);
INSERT INTO "django_geo_db_city" VALUES(10333,'South Bay','South Bay, Florida',12927,11);
INSERT INTO "django_geo_db_city" VALUES(10334,'Brandon','Brandon, Florida',12930,11);
INSERT INTO "django_geo_db_city" VALUES(10335,'Balm','Balm, Florida',12931,11);
INSERT INTO "django_geo_db_city" VALUES(10336,'Bushnell','Bushnell, Florida',12935,11);
INSERT INTO "django_geo_db_city" VALUES(10337,'Center Hill','Center Hill, Florida',12936,11);
INSERT INTO "django_geo_db_city" VALUES(10338,'Coleman','Coleman, Florida',12938,11);
INSERT INTO "django_geo_db_city" VALUES(10339,'Dade City','Dade City, Florida',12939,11);
INSERT INTO "django_geo_db_city" VALUES(10340,'Crystal Springs','Crystal Springs, Florida',12940,11);
INSERT INTO "django_geo_db_city" VALUES(10341,'Dover','Dover, Florida',12943,11);
INSERT INTO "django_geo_db_city" VALUES(10342,'Lake Panasoffkee','Lake Panasoffkee, Florida',12944,11);
INSERT INTO "django_geo_db_city" VALUES(10343,'Durant','Durant, Florida',12945,11);
INSERT INTO "django_geo_db_city" VALUES(10344,'Gibsonton','Gibsonton, Florida',12946,11);
INSERT INTO "django_geo_db_city" VALUES(10345,'Lacoochee','Lacoochee, Florida',12947,11);
INSERT INTO "django_geo_db_city" VALUES(10346,'Zephyrhills','Zephyrhills, Florida',12949,11);
INSERT INTO "django_geo_db_city" VALUES(10347,'Lithia','Lithia, Florida',12955,11);
INSERT INTO "django_geo_db_city" VALUES(10348,'Lutz','Lutz, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10349,'Mango','Mango, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10350,'Odessa','Odessa, Florida',12958,11);
INSERT INTO "django_geo_db_city" VALUES(10351,'Land O'' Lakes','Land O'' Lakes, Florida',12959,11);
INSERT INTO "django_geo_db_city" VALUES(10352,'Plant City','Plant City, Florida',12961,11);
INSERT INTO "django_geo_db_city" VALUES(10353,'Riverview','Riverview, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10354,'Ruskin','Ruskin, Florida',12967,11);
INSERT INTO "django_geo_db_city" VALUES(10355,'Sun City Center','Sun City Center, Florida',12968,11);
INSERT INTO "django_geo_db_city" VALUES(10356,'Apollo Beach','Apollo Beach, Florida',12969,11);
INSERT INTO "django_geo_db_city" VALUES(10357,'Saint Leo','Saint Leo, Florida',12971,11);
INSERT INTO "django_geo_db_city" VALUES(10358,'San Antonio','San Antonio, Florida',12972,11);
INSERT INTO "django_geo_db_city" VALUES(10359,'St. Leo','St. Leo, Florida',12973,11);
INSERT INTO "django_geo_db_city" VALUES(10360,'Seffner','Seffner, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10361,'Sumterville','Sumterville, Florida',12975,11);
INSERT INTO "django_geo_db_city" VALUES(10362,'Sun City','Sun City, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10363,'Sydney','Sydney, Florida',12956,11);
INSERT INTO "django_geo_db_city" VALUES(10364,'Thonotosassa','Thonotosassa, Florida',12976,11);
INSERT INTO "django_geo_db_city" VALUES(10365,'Trilby','Trilby, Florida',12947,11);
INSERT INTO "django_geo_db_city" VALUES(10366,'Valrico','Valrico, Florida',12977,11);
INSERT INTO "django_geo_db_city" VALUES(10367,'Webster','Webster, Florida',12978,11);
INSERT INTO "django_geo_db_city" VALUES(10368,'Wimauma','Wimauma, Florida',12979,11);
INSERT INTO "django_geo_db_city" VALUES(10369,'Punta Gorda','Punta Gorda, Florida',12980,11);
INSERT INTO "django_geo_db_city" VALUES(10370,'Tampa','Tampa, Florida',12981,11);
INSERT INTO "django_geo_db_city" VALUES(10371,'Palm River-Clair Mel','Palm River-Clair Mel, Florida',13011,11);
INSERT INTO "django_geo_db_city" VALUES(10372,'Saint Petersburg','Saint Petersburg, Florida',13012,11);
INSERT INTO "django_geo_db_city" VALUES(10373,'Bay Pines','Bay Pines, Florida',13028,11);
INSERT INTO "django_geo_db_city" VALUES(10374,'Clearwater','Clearwater, Florida',13031,11);
INSERT INTO "django_geo_db_city" VALUES(10375,'Clearwater Beach','Clearwater Beach, Florida',13040,11);
INSERT INTO "django_geo_db_city" VALUES(10376,'Largo','Largo, Florida',13041,11);
INSERT INTO "django_geo_db_city" VALUES(10377,'Seminole','Seminole, Florida',13043,11);
INSERT INTO "django_geo_db_city" VALUES(10378,'Pinellas Park','Pinellas Park, Florida',13028,11);
INSERT INTO "django_geo_db_city" VALUES(10379,'Indian Rocks Beach','Indian Rocks Beach, Florida',13052,11);
INSERT INTO "django_geo_db_city" VALUES(10380,'Belleair Beach','Belleair Beach, Florida',13053,11);
INSERT INTO "django_geo_db_city" VALUES(10381,'Lakeland','Lakeland, Florida',13054,11);
INSERT INTO "django_geo_db_city" VALUES(10382,'Alturas','Alturas, Florida',13057,11);
INSERT INTO "django_geo_db_city" VALUES(10383,'Auburndale','Auburndale, Florida',13064,11);
INSERT INTO "django_geo_db_city" VALUES(10384,'Avon Park','Avon Park, Florida',13065,11);
INSERT INTO "django_geo_db_city" VALUES(10385,'Babson Park','Babson Park, Florida',13067,11);
INSERT INTO "django_geo_db_city" VALUES(10386,'Bartow','Bartow, Florida',13068,11);
INSERT INTO "django_geo_db_city" VALUES(10387,'Bowling Green','Bowling Green, Florida',13070,11);
INSERT INTO "django_geo_db_city" VALUES(10388,'Bradley','Bradley, Florida',13071,11);
INSERT INTO "django_geo_db_city" VALUES(10389,'Davenport','Davenport, Florida',13072,11);
INSERT INTO "django_geo_db_city" VALUES(10390,'Dundee','Dundee, Florida',13074,11);
INSERT INTO "django_geo_db_city" VALUES(10391,'Eagle Lake','Eagle Lake, Florida',13075,11);
INSERT INTO "django_geo_db_city" VALUES(10392,'Eaton Park','Eaton Park, Florida',13076,11);
INSERT INTO "django_geo_db_city" VALUES(10393,'Fort Meade','Fort Meade, Florida',13077,11);
INSERT INTO "django_geo_db_city" VALUES(10394,'Frostproof','Frostproof, Florida',13078,11);
INSERT INTO "django_geo_db_city" VALUES(10395,'Haines City','Haines City, Florida',13079,11);
INSERT INTO "django_geo_db_city" VALUES(10396,'Highland City','Highland City, Florida',13080,11);
INSERT INTO "django_geo_db_city" VALUES(10397,'Homeland','Homeland, Florida',13081,11);
INSERT INTO "django_geo_db_city" VALUES(10398,'Intercession City','Intercession City, Florida',13082,11);
INSERT INTO "django_geo_db_city" VALUES(10399,'Kathleen','Kathleen, Florida',13083,11);
INSERT INTO "django_geo_db_city" VALUES(10400,'Lake Alfred','Lake Alfred, Florida',13084,11);
INSERT INTO "django_geo_db_city" VALUES(10401,'Lake Hamilton','Lake Hamilton, Florida',13085,11);
INSERT INTO "django_geo_db_city" VALUES(10402,'Lake Placid','Lake Placid, Florida',13086,11);
INSERT INTO "django_geo_db_city" VALUES(10403,'Lake Wales','Lake Wales, Florida',13087,11);
INSERT INTO "django_geo_db_city" VALUES(10404,'Fedhaven','Fedhaven, Florida',13057,11);
INSERT INTO "django_geo_db_city" VALUES(10405,'Indian Lake Estates','Indian Lake Estates, Florida',13088,11);
INSERT INTO "django_geo_db_city" VALUES(10406,'Nalcrest','Nalcrest, Florida',13089,11);
INSERT INTO "django_geo_db_city" VALUES(10407,'Lorida','Lorida, Florida',13090,11);
INSERT INTO "django_geo_db_city" VALUES(10408,'Loughman','Loughman, Florida',13091,11);
INSERT INTO "django_geo_db_city" VALUES(10409,'Mulberry','Mulberry, Florida',13093,11);
INSERT INTO "django_geo_db_city" VALUES(10410,'Nichols','Nichols, Florida',13057,11);
INSERT INTO "django_geo_db_city" VALUES(10411,'Ona','Ona, Florida',13095,11);
INSERT INTO "django_geo_db_city" VALUES(10412,'River Ranch','River Ranch, Florida',13096,11);
INSERT INTO "django_geo_db_city" VALUES(10413,'Polk City','Polk City, Florida',13097,11);
INSERT INTO "django_geo_db_city" VALUES(10414,'Sebring','Sebring, Florida',13098,11);
INSERT INTO "django_geo_db_city" VALUES(10415,'Wauchula','Wauchula, Florida',13101,11);
INSERT INTO "django_geo_db_city" VALUES(10416,'Waverly','Waverly, Florida',13104,11);
INSERT INTO "django_geo_db_city" VALUES(10417,'Zolfo Springs','Zolfo Springs, Florida',13110,11);
INSERT INTO "django_geo_db_city" VALUES(10418,'Citrus Ridge','Citrus Ridge, Florida',13112,11);
INSERT INTO "django_geo_db_city" VALUES(10419,'Highland Park','Highland Park, Florida',13113,11);
INSERT INTO "django_geo_db_city" VALUES(10420,'Fort Myers','Fort Myers, Florida',13114,11);
INSERT INTO "django_geo_db_city" VALUES(10421,'North Fort Myers','North Fort Myers, Florida',13116,11);
INSERT INTO "django_geo_db_city" VALUES(10422,'Cape Coral','Cape Coral, Florida',13117,11);
INSERT INTO "django_geo_db_city" VALUES(10423,'Alva','Alva, Florida',13132,11);
INSERT INTO "django_geo_db_city" VALUES(10424,'Boca Grande','Boca Grande, Florida',13133,11);
INSERT INTO "django_geo_db_city" VALUES(10425,'Bokeelia','Bokeelia, Florida',13134,11);
INSERT INTO "django_geo_db_city" VALUES(10426,'Captiva','Captiva, Florida',13135,11);
INSERT INTO "django_geo_db_city" VALUES(10427,'Estero','Estero, Florida',13137,11);
INSERT INTO "django_geo_db_city" VALUES(10428,'Felda','Felda, Florida',13138,11);
INSERT INTO "django_geo_db_city" VALUES(10429,'Fort Myers Beach','Fort Myers Beach, Florida',13139,11);
INSERT INTO "django_geo_db_city" VALUES(10430,'Labelle','Labelle, Florida',13140,11);
INSERT INTO "django_geo_db_city" VALUES(10431,'Lehigh Acres','Lehigh Acres, Florida',13141,11);
INSERT INTO "django_geo_db_city" VALUES(10432,'Murdock','Murdock, Florida',13136,11);
INSERT INTO "django_geo_db_city" VALUES(10433,'Palmdale','Palmdale, Florida',13142,11);
INSERT INTO "django_geo_db_city" VALUES(10434,'Pineland','Pineland, Florida',13143,11);
INSERT INTO "django_geo_db_city" VALUES(10435,'Placida','Placida, Florida',13144,11);
INSERT INTO "django_geo_db_city" VALUES(10436,'Rotonda West','Rotonda West, Florida',13145,11);
INSERT INTO "django_geo_db_city" VALUES(10437,'Port Charlotte','Port Charlotte, Florida',13146,11);
INSERT INTO "django_geo_db_city" VALUES(10438,'Saint James City','Saint James City, Florida',13154,11);
INSERT INTO "django_geo_db_city" VALUES(10439,'Sanibel','Sanibel, Florida',13155,11);
INSERT INTO "django_geo_db_city" VALUES(10440,'Venus','Venus, Florida',13156,11);
INSERT INTO "django_geo_db_city" VALUES(10441,'Naples','Naples, Florida',13169,11);
INSERT INTO "django_geo_db_city" VALUES(10442,'Vanderbilt Beach','Vanderbilt Beach, Florida',13174,11);
INSERT INTO "django_geo_db_city" VALUES(10443,'Bonita Springs','Bonita Springs, Florida',13119,11);
INSERT INTO "django_geo_db_city" VALUES(10444,'Copeland','Copeland, Florida',13187,11);
INSERT INTO "django_geo_db_city" VALUES(10445,'Chokoloskee','Chokoloskee, Florida',13188,11);
INSERT INTO "django_geo_db_city" VALUES(10446,'Everglades City','Everglades City, Florida',13189,11);
INSERT INTO "django_geo_db_city" VALUES(10447,'Goodland','Goodland, Florida',13174,11);
INSERT INTO "django_geo_db_city" VALUES(10448,'Ochopee','Ochopee, Florida',13190,11);
INSERT INTO "django_geo_db_city" VALUES(10449,'Immokalee','Immokalee, Florida',13191,11);
INSERT INTO "django_geo_db_city" VALUES(10450,'Marco Island','Marco Island, Florida',13193,11);
INSERT INTO "django_geo_db_city" VALUES(10451,'Bradenton','Bradenton, Florida',13196,11);
INSERT INTO "django_geo_db_city" VALUES(10452,'Memphis','Memphis, Florida',13205,11);
INSERT INTO "django_geo_db_city" VALUES(10453,'Cortez','Cortez, Florida',13206,11);
INSERT INTO "django_geo_db_city" VALUES(10454,'Anna Maria','Anna Maria, Florida',13207,11);
INSERT INTO "django_geo_db_city" VALUES(10455,'Bradenton Beach','Bradenton Beach, Florida',13208,11);
INSERT INTO "django_geo_db_city" VALUES(10456,'Holmes Beach','Holmes Beach, Florida',13209,11);
INSERT INTO "django_geo_db_city" VALUES(10457,'Parrish','Parrish, Florida',13210,11);
INSERT INTO "django_geo_db_city" VALUES(10458,'Palmetto','Palmetto, Florida',13199,11);
INSERT INTO "django_geo_db_city" VALUES(10459,'Ellenton','Ellenton, Florida',13212,11);
INSERT INTO "django_geo_db_city" VALUES(10460,'Englewood','Englewood, Florida',13213,11);
INSERT INTO "django_geo_db_city" VALUES(10461,'Longboat Key','Longboat Key, Florida',13215,11);
INSERT INTO "django_geo_db_city" VALUES(10462,'Osprey','Osprey, Florida',13216,11);
INSERT INTO "django_geo_db_city" VALUES(10463,'Sarasota','Sarasota, Florida',13217,11);
INSERT INTO "django_geo_db_city" VALUES(10464,'Terra Ceia','Terra Ceia, Florida',13231,11);
INSERT INTO "django_geo_db_city" VALUES(10465,'Myakka City','Myakka City, Florida',13232,11);
INSERT INTO "django_geo_db_city" VALUES(10466,'Manasota','Manasota, Florida',13199,11);
INSERT INTO "django_geo_db_city" VALUES(10467,'Oneco','Oneco, Florida',13199,11);
INSERT INTO "django_geo_db_city" VALUES(10468,'Arcadia','Arcadia, Florida',13233,11);
INSERT INTO "django_geo_db_city" VALUES(10469,'Fort Ogden','Fort Ogden, Florida',13233,11);
INSERT INTO "django_geo_db_city" VALUES(10470,'Nocatee','Nocatee, Florida',13235,11);
INSERT INTO "django_geo_db_city" VALUES(10471,'Tallevast','Tallevast, Florida',13236,11);
INSERT INTO "django_geo_db_city" VALUES(10472,'Laurel','Laurel, Florida',13237,11);
INSERT INTO "django_geo_db_city" VALUES(10473,'Nokomis','Nokomis, Florida',13238,11);
INSERT INTO "django_geo_db_city" VALUES(10474,'Venice','Venice, Florida',13240,11);
INSERT INTO "django_geo_db_city" VALUES(10475,'North Port','North Port, Florida',13243,11);
INSERT INTO "django_geo_db_city" VALUES(10476,'Grove City','Grove City, Florida',13250,11);
INSERT INTO "django_geo_db_city" VALUES(10477,'Belleview','Belleview, Florida',13251,11);
INSERT INTO "django_geo_db_city" VALUES(10478,'Crystal River','Crystal River, Florida',13253,11);
INSERT INTO "django_geo_db_city" VALUES(10479,'Pine Ridge','Pine Ridge, Florida',13255,11);
INSERT INTO "django_geo_db_city" VALUES(10480,'Dunnellon','Dunnellon, Florida',13252,11);
INSERT INTO "django_geo_db_city" VALUES(10481,'Floral City','Floral City, Florida',13262,11);
INSERT INTO "django_geo_db_city" VALUES(10482,'Hernando','Hernando, Florida',13263,11);
INSERT INTO "django_geo_db_city" VALUES(10483,'Holder','Holder, Florida',13264,11);
INSERT INTO "django_geo_db_city" VALUES(10484,'Homosassa','Homosassa, Florida',13265,11);
INSERT INTO "django_geo_db_city" VALUES(10485,'Homosassa Springs','Homosassa Springs, Florida',13266,11);
INSERT INTO "django_geo_db_city" VALUES(10486,'Inglis','Inglis, Florida',13268,11);
INSERT INTO "django_geo_db_city" VALUES(10487,'Inverness','Inverness, Florida',13269,11);
INSERT INTO "django_geo_db_city" VALUES(10488,'Lecanto','Lecanto, Florida',13273,11);
INSERT INTO "django_geo_db_city" VALUES(10489,'Beverly Hills','Beverly Hills, Florida',13273,11);
INSERT INTO "django_geo_db_city" VALUES(10490,'Ocala','Ocala, Florida',13276,11);
INSERT INTO "django_geo_db_city" VALUES(10491,'Oxford','Oxford, Florida',13288,11);
INSERT INTO "django_geo_db_city" VALUES(10492,'Silver Springs','Silver Springs, Florida',13289,11);
INSERT INTO "django_geo_db_city" VALUES(10493,'Summerfield','Summerfield, Florida',13291,11);
INSERT INTO "django_geo_db_city" VALUES(10494,'Yankeetown','Yankeetown, Florida',13293,11);
INSERT INTO "django_geo_db_city" VALUES(10495,'Port St. Lucie','Port St. Lucie, Florida',13294,11);
INSERT INTO "django_geo_db_city" VALUES(10496,'Brooksville','Brooksville, Florida',13295,11);
INSERT INTO "django_geo_db_city" VALUES(10497,'Spring Hill','Spring Hill, Florida',13298,11);
INSERT INTO "django_geo_db_city" VALUES(10498,'Istachatta','Istachatta, Florida',13307,11);
INSERT INTO "django_geo_db_city" VALUES(10499,'Land O Lakes','Land O Lakes, Florida',13308,11);
INSERT INTO "django_geo_db_city" VALUES(10500,'New Port Richey','New Port Richey, Florida',13309,11);
INSERT INTO "django_geo_db_city" VALUES(10501,'Ozona','Ozona, Florida',13313,11);
INSERT INTO "django_geo_db_city" VALUES(10502,'Nobleton','Nobleton, Florida',13314,11);
INSERT INTO "django_geo_db_city" VALUES(10503,'Hudson','Hudson, Florida',13315,11);
INSERT INTO "django_geo_db_city" VALUES(10504,'Port Richey','Port Richey, Florida',13316,11);
INSERT INTO "django_geo_db_city" VALUES(10505,'Oldsmar','Oldsmar, Florida',13318,11);
INSERT INTO "django_geo_db_city" VALUES(10506,'Palm Harbor','Palm Harbor, Florida',13319,11);
INSERT INTO "django_geo_db_city" VALUES(10507,'Aripeka','Aripeka, Florida',13320,11);
INSERT INTO "django_geo_db_city" VALUES(10508,'Elfers','Elfers, Florida',12947,11);
INSERT INTO "django_geo_db_city" VALUES(10509,'Crystal Beach','Crystal Beach, Florida',13321,11);
INSERT INTO "django_geo_db_city" VALUES(10510,'Tarpon Springs','Tarpon Springs, Florida',13028,11);
INSERT INTO "django_geo_db_city" VALUES(10511,'Holiday','Holiday, Florida',13326,11);
INSERT INTO "django_geo_db_city" VALUES(10512,'Safety Harbor','Safety Harbor, Florida',13328,11);
INSERT INTO "django_geo_db_city" VALUES(10513,'Dunedin','Dunedin, Florida',13028,11);
INSERT INTO "django_geo_db_city" VALUES(10514,'Astatula','Astatula, Florida',13330,11);
INSERT INTO "django_geo_db_city" VALUES(10515,'Clermont','Clermont, Florida',13332,11);
INSERT INTO "django_geo_db_city" VALUES(10516,'Ferndale','Ferndale, Florida',12298,11);
INSERT INTO "django_geo_db_city" VALUES(10517,'Fruitland Park','Fruitland Park, Florida',13333,11);
INSERT INTO "django_geo_db_city" VALUES(10518,'Gotha','Gotha, Florida',13334,11);
INSERT INTO "django_geo_db_city" VALUES(10519,'Groveland','Groveland, Florida',13335,11);
INSERT INTO "django_geo_db_city" VALUES(10520,'Howey In The Hills','Howey In The Hills, Florida',13336,11);
INSERT INTO "django_geo_db_city" VALUES(10521,'Kenansville','Kenansville, Florida',13337,11);
INSERT INTO "django_geo_db_city" VALUES(10522,'Killarney','Killarney, Florida',13338,11);
INSERT INTO "django_geo_db_city" VALUES(10523,'Kissimmee','Kissimmee, Florida',13339,11);
INSERT INTO "django_geo_db_city" VALUES(10524,'Leesburg','Leesburg, Florida',13345,11);
INSERT INTO "django_geo_db_city" VALUES(10525,'Mascotte','Mascotte, Florida',13346,11);
INSERT INTO "django_geo_db_city" VALUES(10526,'Minneola','Minneola, Florida',13347,11);
INSERT INTO "django_geo_db_city" VALUES(10527,'Montverde','Montverde, Florida',13348,11);
INSERT INTO "django_geo_db_city" VALUES(10528,'Oakland','Oakland, Florida',13351,11);
INSERT INTO "django_geo_db_city" VALUES(10529,'Ocoee','Ocoee, Florida',13352,11);
INSERT INTO "django_geo_db_city" VALUES(10530,'Okahumpka','Okahumpka, Florida',13353,11);
INSERT INTO "django_geo_db_city" VALUES(10531,'Saint Cloud','Saint Cloud, Florida',13354,11);
INSERT INTO "django_geo_db_city" VALUES(10532,'Winter Garden','Winter Garden, Florida',13358,11);
INSERT INTO "django_geo_db_city" VALUES(10533,'Wildwood','Wildwood, Florida',13359,11);
INSERT INTO "django_geo_db_city" VALUES(10534,'Windermere','Windermere, Florida',13360,11);
INSERT INTO "django_geo_db_city" VALUES(10535,'Yalaha','Yalaha, Florida',13363,11);
INSERT INTO "django_geo_db_city" VALUES(10536,'Hunters Creek','Hunters Creek, Florida',13365,11);
INSERT INTO "django_geo_db_city" VALUES(10537,'Lake Butter','Lake Butter, Florida',13367,11);
INSERT INTO "django_geo_db_city" VALUES(10538,'Okeechobee','Okeechobee, Florida',13368,11);
INSERT INTO "django_geo_db_city" VALUES(10539,'Fort Pierce','Fort Pierce, Florida',13369,11);
INSERT INTO "django_geo_db_city" VALUES(10540,'Port Saint Lucie','Port Saint Lucie, Florida',13376,11);
INSERT INTO "django_geo_db_city" VALUES(10541,'Indiantown','Indiantown, Florida',13378,11);
INSERT INTO "django_geo_db_city" VALUES(10542,'Jensen Beach','Jensen Beach, Florida',13379,11);
INSERT INTO "django_geo_db_city" VALUES(10543,'Palm City','Palm City, Florida',13391,11);
INSERT INTO "django_geo_db_city" VALUES(10544,'Port Salerno','Port Salerno, Florida',12918,11);
INSERT INTO "django_geo_db_city" VALUES(10545,'Stuart','Stuart, Florida',13392,11);
INSERT INTO "django_geo_db_city" VALUES(10546,'Moody','Moody, Alabama',13396,1);
INSERT INTO "django_geo_db_city" VALUES(10547,'Adamsville','Adamsville, Alabama',13397,1);
INSERT INTO "django_geo_db_city" VALUES(10548,'Adger','Adger, Alabama',13398,1);
INSERT INTO "django_geo_db_city" VALUES(10549,'Alabaster','Alabaster, Alabama',13399,1);
INSERT INTO "django_geo_db_city" VALUES(10550,'Alexander City','Alexander City, Alabama',13400,1);
INSERT INTO "django_geo_db_city" VALUES(10551,'Allgood','Allgood, Alabama',13402,1);
INSERT INTO "django_geo_db_city" VALUES(10552,'Alpine','Alpine, Alabama',13403,1);
INSERT INTO "django_geo_db_city" VALUES(10553,'Alton','Alton, Alabama',13404,1);
INSERT INTO "django_geo_db_city" VALUES(10554,'Arab','Arab, Alabama',13405,1);
INSERT INTO "django_geo_db_city" VALUES(10555,'Baileyton','Baileyton, Alabama',13406,1);
INSERT INTO "django_geo_db_city" VALUES(10556,'Bessemer','Bessemer, Alabama',13407,1);
INSERT INTO "django_geo_db_city" VALUES(10557,'Clanton','Clanton, Alabama',13410,1);
INSERT INTO "django_geo_db_city" VALUES(10558,'Blountsville','Blountsville, Alabama',13411,1);
INSERT INTO "django_geo_db_city" VALUES(10559,'Bon Air','Bon Air, Alabama',13412,1);
INSERT INTO "django_geo_db_city" VALUES(10560,'Bremen','Bremen, Alabama',13413,1);
INSERT INTO "django_geo_db_city" VALUES(10561,'Brent','Brent, Alabama',13414,1);
INSERT INTO "django_geo_db_city" VALUES(10562,'Brierfield','Brierfield, Alabama',13415,1);
INSERT INTO "django_geo_db_city" VALUES(10563,'Brookside','Brookside, Alabama',13416,1);
INSERT INTO "django_geo_db_city" VALUES(10564,'Burnwell','Burnwell, Alabama',13417,1);
INSERT INTO "django_geo_db_city" VALUES(10565,'Calera','Calera, Alabama',13419,1);
INSERT INTO "django_geo_db_city" VALUES(10566,'Cardiff','Cardiff, Alabama',13420,1);
INSERT INTO "django_geo_db_city" VALUES(10567,'Centreville','Centreville, Alabama',13421,1);
INSERT INTO "django_geo_db_city" VALUES(10568,'Chelsea','Chelsea, Alabama',13422,1);
INSERT INTO "django_geo_db_city" VALUES(10569,'Childersburg','Childersburg, Alabama',13423,1);
INSERT INTO "django_geo_db_city" VALUES(10570,'Clay','Clay, Alabama',13404,1);
INSERT INTO "django_geo_db_city" VALUES(10571,'Cleveland','Cleveland, Alabama',13426,1);
INSERT INTO "django_geo_db_city" VALUES(10572,'Columbiana','Columbiana, Alabama',13427,1);
INSERT INTO "django_geo_db_city" VALUES(10573,'Cook Springs','Cook Springs, Alabama',13429,1);
INSERT INTO "django_geo_db_city" VALUES(10574,'Crane Hill','Crane Hill, Alabama',13430,1);
INSERT INTO "django_geo_db_city" VALUES(10575,'Cropwell','Cropwell, Alabama',13431,1);
INSERT INTO "django_geo_db_city" VALUES(10576,'Cullman','Cullman, Alabama',13432,1);
INSERT INTO "django_geo_db_city" VALUES(10577,'Docena','Docena, Alabama',13436,1);
INSERT INTO "django_geo_db_city" VALUES(10578,'Dolomite','Dolomite, Alabama',13437,1);
INSERT INTO "django_geo_db_city" VALUES(10579,'Dora','Dora, Alabama',13438,1);
INSERT INTO "django_geo_db_city" VALUES(10580,'Empire','Empire, Alabama',13439,1);
INSERT INTO "django_geo_db_city" VALUES(10581,'Fairfield','Fairfield, Alabama',13440,1);
INSERT INTO "django_geo_db_city" VALUES(10582,'Fultondale','Fultondale, Alabama',13441,1);
INSERT INTO "django_geo_db_city" VALUES(10583,'Garden City','Garden City, Alabama',13442,1);
INSERT INTO "django_geo_db_city" VALUES(10584,'Gardendale','Gardendale, Alabama',13443,1);
INSERT INTO "django_geo_db_city" VALUES(10585,'Goodwater','Goodwater, Alabama',13444,1);
INSERT INTO "django_geo_db_city" VALUES(10586,'Graysville','Graysville, Alabama',13445,1);
INSERT INTO "django_geo_db_city" VALUES(10587,'Green Pond','Green Pond, Alabama',13446,1);
INSERT INTO "django_geo_db_city" VALUES(10588,'Hanceville','Hanceville, Alabama',13447,1);
INSERT INTO "django_geo_db_city" VALUES(10589,'Harpersville','Harpersville, Alabama',13448,1);
INSERT INTO "django_geo_db_city" VALUES(10590,'Hayden','Hayden, Alabama',13449,1);
INSERT INTO "django_geo_db_city" VALUES(10591,'Helena','Helena, Alabama',13450,1);
INSERT INTO "django_geo_db_city" VALUES(10592,'Hollins','Hollins, Alabama',13451,1);
INSERT INTO "django_geo_db_city" VALUES(10593,'Holly Pond','Holly Pond, Alabama',13452,1);
INSERT INTO "django_geo_db_city" VALUES(10594,'Jemison','Jemison, Alabama',13453,1);
INSERT INTO "django_geo_db_city" VALUES(10595,'Joppa','Joppa, Alabama',13454,1);
INSERT INTO "django_geo_db_city" VALUES(10596,'Kellyton','Kellyton, Alabama',13455,1);
INSERT INTO "django_geo_db_city" VALUES(10597,'Kimberly','Kimberly, Alabama',13456,1);
INSERT INTO "django_geo_db_city" VALUES(10598,'Leeds','Leeds, Alabama',13457,1);
INSERT INTO "django_geo_db_city" VALUES(10599,'Lincoln','Lincoln, Alabama',13458,1);
INSERT INTO "django_geo_db_city" VALUES(10600,'Locust Fork','Locust Fork, Alabama',13459,1);
INSERT INTO "django_geo_db_city" VALUES(10601,'Logan','Logan, Alabama',13460,1);
INSERT INTO "django_geo_db_city" VALUES(10602,'McCalla','McCalla, Alabama',13461,1);
INSERT INTO "django_geo_db_city" VALUES(10603,'Margaret','Margaret, Alabama',13462,1);
INSERT INTO "django_geo_db_city" VALUES(10604,'Maylene','Maylene, Alabama',13463,1);
INSERT INTO "django_geo_db_city" VALUES(10605,'Montevallo','Montevallo, Alabama',13464,1);
INSERT INTO "django_geo_db_city" VALUES(10606,'Morris','Morris, Alabama',13465,1);
INSERT INTO "django_geo_db_city" VALUES(10607,'Mount Olive','Mount Olive, Alabama',13466,1);
INSERT INTO "django_geo_db_city" VALUES(10608,'Mulga','Mulga, Alabama',13467,1);
INSERT INTO "django_geo_db_city" VALUES(10609,'New Castle','New Castle, Alabama',13468,1);
INSERT INTO "django_geo_db_city" VALUES(10610,'Odenville','Odenville, Alabama',13469,1);
INSERT INTO "django_geo_db_city" VALUES(10611,'Oneonta','Oneonta, Alabama',13470,1);
INSERT INTO "django_geo_db_city" VALUES(10612,'Palmerdale','Palmerdale, Alabama',13404,1);
INSERT INTO "django_geo_db_city" VALUES(10613,'Pelham','Pelham, Alabama',13471,1);
INSERT INTO "django_geo_db_city" VALUES(10614,'Pell City','Pell City, Alabama',13472,1);
INSERT INTO "django_geo_db_city" VALUES(10615,'Pinson','Pinson, Alabama',13473,1);
INSERT INTO "django_geo_db_city" VALUES(10616,'Pleasant Grove','Pleasant Grove, Alabama',13474,1);
INSERT INTO "django_geo_db_city" VALUES(10617,'Quinton','Quinton, Alabama',13476,1);
INSERT INTO "django_geo_db_city" VALUES(10618,'Ragland','Ragland, Alabama',13477,1);
INSERT INTO "django_geo_db_city" VALUES(10619,'Remlap','Remlap, Alabama',13478,1);
INSERT INTO "django_geo_db_city" VALUES(10620,'Riverside','Riverside, Alabama',13479,1);
INSERT INTO "django_geo_db_city" VALUES(10621,'Rockford','Rockford, Alabama',13480,1);
INSERT INTO "django_geo_db_city" VALUES(10622,'Saginaw','Saginaw, Alabama',13481,1);
INSERT INTO "django_geo_db_city" VALUES(10623,'Sayre','Sayre, Alabama',13482,1);
INSERT INTO "django_geo_db_city" VALUES(10624,'Shannon','Shannon, Alabama',13483,1);
INSERT INTO "django_geo_db_city" VALUES(10625,'Shelby','Shelby, Alabama',13484,1);
INSERT INTO "django_geo_db_city" VALUES(10626,'Siluria','Siluria, Alabama',13485,1);
INSERT INTO "django_geo_db_city" VALUES(10627,'Springville','Springville, Alabama',13486,1);
INSERT INTO "django_geo_db_city" VALUES(10628,'Sterrett','Sterrett, Alabama',13487,1);
INSERT INTO "django_geo_db_city" VALUES(10629,'Sumiton','Sumiton, Alabama',13488,1);
INSERT INTO "django_geo_db_city" VALUES(10630,'Sycamore','Sycamore, Alabama',13489,1);
INSERT INTO "django_geo_db_city" VALUES(10631,'Sylacauga','Sylacauga, Alabama',13490,1);
INSERT INTO "django_geo_db_city" VALUES(10632,'Talladega','Talladega, Alabama',13492,1);
INSERT INTO "django_geo_db_city" VALUES(10633,'Thorsby','Thorsby, Alabama',13494,1);
INSERT INTO "django_geo_db_city" VALUES(10634,'Trafford','Trafford, Alabama',13495,1);
INSERT INTO "django_geo_db_city" VALUES(10635,'Trussville','Trussville, Alabama',13496,1);
INSERT INTO "django_geo_db_city" VALUES(10636,'Union Grove','Union Grove, Alabama',13497,1);
INSERT INTO "django_geo_db_city" VALUES(10637,'Vandiver','Vandiver, Alabama',13498,1);
INSERT INTO "django_geo_db_city" VALUES(10638,'Vincent','Vincent, Alabama',13499,1);
INSERT INTO "django_geo_db_city" VALUES(10639,'Vinemont','Vinemont, Alabama',13500,1);
INSERT INTO "django_geo_db_city" VALUES(10640,'Warrior','Warrior, Alabama',13501,1);
INSERT INTO "django_geo_db_city" VALUES(10641,'Watson','Watson, Alabama',13404,1);
INSERT INTO "django_geo_db_city" VALUES(10642,'Wattsville','Wattsville, Alabama',13502,1);
INSERT INTO "django_geo_db_city" VALUES(10643,'Weogufka','Weogufka, Alabama',13503,1);
INSERT INTO "django_geo_db_city" VALUES(10644,'West Blocton','West Blocton, Alabama',13504,1);
INSERT INTO "django_geo_db_city" VALUES(10645,'Westover','Westover, Alabama',13505,1);
INSERT INTO "django_geo_db_city" VALUES(10646,'Wilsonville','Wilsonville, Alabama',13506,1);
INSERT INTO "django_geo_db_city" VALUES(10647,'Wilton','Wilton, Alabama',13507,1);
INSERT INTO "django_geo_db_city" VALUES(10648,'Woodstock','Woodstock, Alabama',13508,1);
INSERT INTO "django_geo_db_city" VALUES(10649,'Birmingham','Birmingham, Alabama',13509,1);
INSERT INTO "django_geo_db_city" VALUES(10650,'Tuscaloosa','Tuscaloosa, Alabama',13544,1);
INSERT INTO "django_geo_db_city" VALUES(10651,'Abernant','Abernant, Alabama',13550,1);
INSERT INTO "django_geo_db_city" VALUES(10652,'Akron','Akron, Alabama',13551,1);
INSERT INTO "django_geo_db_city" VALUES(10653,'Aliceville','Aliceville, Alabama',13552,1);
INSERT INTO "django_geo_db_city" VALUES(10654,'Boligee','Boligee, Alabama',13553,1);
INSERT INTO "django_geo_db_city" VALUES(10655,'Brookwood','Brookwood, Alabama',13554,1);
INSERT INTO "django_geo_db_city" VALUES(10656,'Buhl','Buhl, Alabama',13555,1);
INSERT INTO "django_geo_db_city" VALUES(10657,'Carrollton','Carrollton, Alabama',13556,1);
INSERT INTO "django_geo_db_city" VALUES(10658,'Clinton','Clinton, Alabama',13557,1);
INSERT INTO "django_geo_db_city" VALUES(10659,'Coaling','Coaling, Alabama',13558,1);
INSERT INTO "django_geo_db_city" VALUES(10660,'Coker','Coker, Alabama',13559,1);
INSERT INTO "django_geo_db_city" VALUES(10661,'Cottondale','Cottondale, Alabama',13560,1);
INSERT INTO "django_geo_db_city" VALUES(10662,'Duncanville','Duncanville, Alabama',13561,1);
INSERT INTO "django_geo_db_city" VALUES(10663,'Echola','Echola, Alabama',13562,1);
INSERT INTO "django_geo_db_city" VALUES(10664,'Elrod','Elrod, Alabama',13563,1);
INSERT INTO "django_geo_db_city" VALUES(10665,'Emelle','Emelle, Alabama',13564,1);
INSERT INTO "django_geo_db_city" VALUES(10666,'Epes','Epes, Alabama',13565,1);
INSERT INTO "django_geo_db_city" VALUES(10667,'Ethelsville','Ethelsville, Alabama',13566,1);
INSERT INTO "django_geo_db_city" VALUES(10668,'Eutaw','Eutaw, Alabama',13567,1);
INSERT INTO "django_geo_db_city" VALUES(10669,'Fosters','Fosters, Alabama',13568,1);
INSERT INTO "django_geo_db_city" VALUES(10670,'Gainesville','Gainesville, Alabama',13569,1);
INSERT INTO "django_geo_db_city" VALUES(10671,'Gordo','Gordo, Alabama',13570,1);
INSERT INTO "django_geo_db_city" VALUES(10672,'Kellerman','Kellerman, Alabama',13545,1);
INSERT INTO "django_geo_db_city" VALUES(10673,'Knoxville','Knoxville, Alabama',13571,1);
INSERT INTO "django_geo_db_city" VALUES(10674,'Livingston','Livingston, Alabama',13572,1);
INSERT INTO "django_geo_db_city" VALUES(10675,'McShan','McShan, Alabama',13573,1);
INSERT INTO "django_geo_db_city" VALUES(10676,'Northport','Northport, Alabama',13574,1);
INSERT INTO "django_geo_db_city" VALUES(10677,'Moundville','Moundville, Alabama',13575,1);
INSERT INTO "django_geo_db_city" VALUES(10678,'Panola','Panola, Alabama',13578,1);
INSERT INTO "django_geo_db_city" VALUES(10679,'Peterson','Peterson, Alabama',13545,1);
INSERT INTO "django_geo_db_city" VALUES(10680,'Ralph','Ralph, Alabama',13579,1);
INSERT INTO "django_geo_db_city" VALUES(10681,'Reform','Reform, Alabama',13580,1);
INSERT INTO "django_geo_db_city" VALUES(10682,'Samantha','Samantha, Alabama',13545,1);
INSERT INTO "django_geo_db_city" VALUES(10683,'Vance','Vance, Alabama',13583,1);
INSERT INTO "django_geo_db_city" VALUES(10684,'West Greene','West Greene, Alabama',13557,1);
INSERT INTO "django_geo_db_city" VALUES(10685,'Jasper','Jasper, Alabama',13584,1);
INSERT INTO "django_geo_db_city" VALUES(10686,'Addison','Addison, Alabama',13588,1);
INSERT INTO "django_geo_db_city" VALUES(10687,'Arley','Arley, Alabama',13589,1);
INSERT INTO "django_geo_db_city" VALUES(10688,'Bankston','Bankston, Alabama',13590,1);
INSERT INTO "django_geo_db_city" VALUES(10689,'Bear Creek','Bear Creek, Alabama',13591,1);
INSERT INTO "django_geo_db_city" VALUES(10690,'Beaverton','Beaverton, Alabama',13592,1);
INSERT INTO "django_geo_db_city" VALUES(10691,'Belk','Belk, Alabama',13593,1);
INSERT INTO "django_geo_db_city" VALUES(10692,'Berry','Berry, Alabama',13594,1);
INSERT INTO "django_geo_db_city" VALUES(10693,'Brilliant','Brilliant, Alabama',13595,1);
INSERT INTO "django_geo_db_city" VALUES(10694,'Carbon Hill','Carbon Hill, Alabama',13596,1);
INSERT INTO "django_geo_db_city" VALUES(10695,'Cordova','Cordova, Alabama',13597,1);
INSERT INTO "django_geo_db_city" VALUES(10696,'Delmar','Delmar, Alabama',13598,1);
INSERT INTO "django_geo_db_city" VALUES(10697,'Detroit','Detroit, Alabama',13599,1);
INSERT INTO "django_geo_db_city" VALUES(10698,'Double Springs','Double Springs, Alabama',13600,1);
INSERT INTO "django_geo_db_city" VALUES(10699,'Eldridge','Eldridge, Alabama',13601,1);
INSERT INTO "django_geo_db_city" VALUES(10700,'Fayette','Fayette, Alabama',13602,1);
INSERT INTO "django_geo_db_city" VALUES(10701,'Glen Allen','Glen Allen, Alabama',13603,1);
INSERT INTO "django_geo_db_city" VALUES(10702,'Goodsprings','Goodsprings, Alabama',13604,1);
INSERT INTO "django_geo_db_city" VALUES(10703,'Guin','Guin, Alabama',13605,1);
INSERT INTO "django_geo_db_city" VALUES(10704,'Hackleburg','Hackleburg, Alabama',13606,1);
INSERT INTO "django_geo_db_city" VALUES(10705,'Haleyville','Haleyville, Alabama',13607,1);
INSERT INTO "django_geo_db_city" VALUES(10706,'Hamilton','Hamilton, Alabama',13608,1);
INSERT INTO "django_geo_db_city" VALUES(10707,'Hodges','Hodges, Alabama',13609,1);
INSERT INTO "django_geo_db_city" VALUES(10708,'Houston','Houston, Alabama',13610,1);
INSERT INTO "django_geo_db_city" VALUES(10709,'Kansas','Kansas, Alabama',13611,1);
INSERT INTO "django_geo_db_city" VALUES(10710,'Kennedy','Kennedy, Alabama',13612,1);
INSERT INTO "django_geo_db_city" VALUES(10711,'Lynn','Lynn, Alabama',13613,1);
INSERT INTO "django_geo_db_city" VALUES(10712,'Millport','Millport, Alabama',13614,1);
INSERT INTO "django_geo_db_city" VALUES(10713,'Natural Bridge','Natural Bridge, Alabama',13615,1);
INSERT INTO "django_geo_db_city" VALUES(10714,'Nauvoo','Nauvoo, Alabama',13616,1);
INSERT INTO "django_geo_db_city" VALUES(10715,'Oakman','Oakman, Alabama',13617,1);
INSERT INTO "django_geo_db_city" VALUES(10716,'Parrish','Parrish, Alabama',13618,1);
INSERT INTO "django_geo_db_city" VALUES(10717,'Phil Campbell','Phil Campbell, Alabama',13619,1);
INSERT INTO "django_geo_db_city" VALUES(10718,'Red Bay','Red Bay, Alabama',13620,1);
INSERT INTO "django_geo_db_city" VALUES(10719,'Sipsey','Sipsey, Alabama',13621,1);
INSERT INTO "django_geo_db_city" VALUES(10720,'Spruce Pine','Spruce Pine, Alabama',13622,1);
INSERT INTO "django_geo_db_city" VALUES(10721,'Sulligent','Sulligent, Alabama',13623,1);
INSERT INTO "django_geo_db_city" VALUES(10722,'Townley','Townley, Alabama',13624,1);
INSERT INTO "django_geo_db_city" VALUES(10723,'Vernon','Vernon, Alabama',13625,1);
INSERT INTO "django_geo_db_city" VALUES(10724,'Vina','Vina, Alabama',13626,1);
INSERT INTO "django_geo_db_city" VALUES(10725,'Winfield','Winfield, Alabama',13627,1);
INSERT INTO "django_geo_db_city" VALUES(10726,'Decatur','Decatur, Alabama',13628,1);
INSERT INTO "django_geo_db_city" VALUES(10727,'Anderson','Anderson, Alabama',13632,1);
INSERT INTO "django_geo_db_city" VALUES(10728,'Athens','Athens, Alabama',13633,1);
INSERT INTO "django_geo_db_city" VALUES(10729,'Belle Mina','Belle Mina, Alabama',13634,1);
INSERT INTO "django_geo_db_city" VALUES(10730,'Cherokee','Cherokee, Alabama',13637,1);
INSERT INTO "django_geo_db_city" VALUES(10731,'Cloverdale','Cloverdale, Alabama',13638,1);
INSERT INTO "django_geo_db_city" VALUES(10732,'Courtland','Courtland, Alabama',13639,1);
INSERT INTO "django_geo_db_city" VALUES(10733,'Danville','Danville, Alabama',13640,1);
INSERT INTO "django_geo_db_city" VALUES(10734,'Elkmont','Elkmont, Alabama',13641,1);
INSERT INTO "django_geo_db_city" VALUES(10735,'Eva','Eva, Alabama',13642,1);
INSERT INTO "django_geo_db_city" VALUES(10736,'Falkville','Falkville, Alabama',13643,1);
INSERT INTO "django_geo_db_city" VALUES(10737,'Florence','Florence, Alabama',13644,1);
INSERT INTO "django_geo_db_city" VALUES(10738,'Hartselle','Hartselle, Alabama',13647,1);
INSERT INTO "django_geo_db_city" VALUES(10739,'Hillsboro','Hillsboro, Alabama',13648,1);
INSERT INTO "django_geo_db_city" VALUES(10740,'Killen','Killen, Alabama',13649,1);
INSERT INTO "django_geo_db_city" VALUES(10741,'Leighton','Leighton, Alabama',13650,1);
INSERT INTO "django_geo_db_city" VALUES(10742,'Lester','Lester, Alabama',13651,1);
INSERT INTO "django_geo_db_city" VALUES(10743,'Lexington','Lexington, Alabama',13652,1);
INSERT INTO "django_geo_db_city" VALUES(10744,'Mooresville','Mooresville, Alabama',13653,1);
INSERT INTO "django_geo_db_city" VALUES(10745,'Moulton','Moulton, Alabama',13654,1);
INSERT INTO "django_geo_db_city" VALUES(10746,'Mount Hope','Mount Hope, Alabama',13655,1);
INSERT INTO "django_geo_db_city" VALUES(10747,'Rogersville','Rogersville, Alabama',13656,1);
INSERT INTO "django_geo_db_city" VALUES(10748,'Russellville','Russellville, Alabama',13657,1);
INSERT INTO "django_geo_db_city" VALUES(10749,'Sheffield','Sheffield, Alabama',13660,1);
INSERT INTO "django_geo_db_city" VALUES(10750,'Muscle Shoals','Muscle Shoals, Alabama',13661,1);
INSERT INTO "django_geo_db_city" VALUES(10751,'Somerville','Somerville, Alabama',13663,1);
INSERT INTO "django_geo_db_city" VALUES(10752,'Tanner','Tanner, Alabama',13664,1);
INSERT INTO "django_geo_db_city" VALUES(10753,'Town Creek','Town Creek, Alabama',13665,1);
INSERT INTO "django_geo_db_city" VALUES(10754,'Trinity','Trinity, Alabama',13666,1);
INSERT INTO "django_geo_db_city" VALUES(10755,'Tuscumbia','Tuscumbia, Alabama',13667,1);
INSERT INTO "django_geo_db_city" VALUES(10756,'Waterloo','Waterloo, Alabama',13668,1);
INSERT INTO "django_geo_db_city" VALUES(10757,'Ardmore','Ardmore, Alabama',13670,1);
INSERT INTO "django_geo_db_city" VALUES(10758,'Bridgeport','Bridgeport, Alabama',13671,1);
INSERT INTO "django_geo_db_city" VALUES(10759,'Brownsboro','Brownsboro, Alabama',13672,1);
INSERT INTO "django_geo_db_city" VALUES(10760,'Capshaw','Capshaw, Alabama',13673,1);
INSERT INTO "django_geo_db_city" VALUES(10761,'Dutton','Dutton, Alabama',13674,1);
INSERT INTO "django_geo_db_city" VALUES(10762,'Estillfork','Estillfork, Alabama',13675,1);
INSERT INTO "django_geo_db_city" VALUES(10763,'Fackler','Fackler, Alabama',13676,1);
INSERT INTO "django_geo_db_city" VALUES(10764,'Grant','Grant, Alabama',13677,1);
INSERT INTO "django_geo_db_city" VALUES(10765,'Gurley','Gurley, Alabama',13678,1);
INSERT INTO "django_geo_db_city" VALUES(10766,'Harvest','Harvest, Alabama',13679,1);
INSERT INTO "django_geo_db_city" VALUES(10767,'Hazel Green','Hazel Green, Alabama',13680,1);
INSERT INTO "django_geo_db_city" VALUES(10768,'Hollytree','Hollytree, Alabama',13681,1);
INSERT INTO "django_geo_db_city" VALUES(10769,'Hollywood','Hollywood, Alabama',13682,1);
INSERT INTO "django_geo_db_city" VALUES(10770,'Laceys Spring','Laceys Spring, Alabama',13683,1);
INSERT INTO "django_geo_db_city" VALUES(10771,'Langston','Langston, Alabama',13684,1);
INSERT INTO "django_geo_db_city" VALUES(10772,'Madison','Madison, Alabama',13685,1);
INSERT INTO "django_geo_db_city" VALUES(10773,'Meridianville','Meridianville, Alabama',13688,1);
INSERT INTO "django_geo_db_city" VALUES(10774,'New Hope','New Hope, Alabama',13689,1);
INSERT INTO "django_geo_db_city" VALUES(10775,'New Market','New Market, Alabama',13690,1);
INSERT INTO "django_geo_db_city" VALUES(10776,'Normal','Normal, Alabama',13691,1);
INSERT INTO "django_geo_db_city" VALUES(10777,'Owens Cross Roads','Owens Cross Roads, Alabama',13692,1);
INSERT INTO "django_geo_db_city" VALUES(10778,'Paint Rock','Paint Rock, Alabama',13693,1);
INSERT INTO "django_geo_db_city" VALUES(10779,'Pisgah','Pisgah, Alabama',13694,1);
INSERT INTO "django_geo_db_city" VALUES(10780,'Princeton','Princeton, Alabama',13695,1);
INSERT INTO "django_geo_db_city" VALUES(10781,'Ryland','Ryland, Alabama',13691,1);
INSERT INTO "django_geo_db_city" VALUES(10782,'Scottsboro','Scottsboro, Alabama',13696,1);
INSERT INTO "django_geo_db_city" VALUES(10783,'Section','Section, Alabama',13698,1);
INSERT INTO "django_geo_db_city" VALUES(10784,'Stevenson','Stevenson, Alabama',13699,1);
INSERT INTO "django_geo_db_city" VALUES(10785,'Toney','Toney, Alabama',13700,1);
INSERT INTO "django_geo_db_city" VALUES(10786,'Trenton','Trenton, Alabama',13701,1);
INSERT INTO "django_geo_db_city" VALUES(10787,'Valhermoso Springs','Valhermoso Springs, Alabama',13702,1);
INSERT INTO "django_geo_db_city" VALUES(10788,'Woodville','Woodville, Alabama',13703,1);
INSERT INTO "django_geo_db_city" VALUES(10789,'Huntsville','Huntsville, Alabama',13704,1);
INSERT INTO "django_geo_db_city" VALUES(10790,'Gadsden','Gadsden, Alabama',13716,1);
INSERT INTO "django_geo_db_city" VALUES(10791,'Rainbow City','Rainbow City, Alabama',13721,1);
INSERT INTO "django_geo_db_city" VALUES(10792,'Albertville','Albertville, Alabama',13723,1);
INSERT INTO "django_geo_db_city" VALUES(10793,'Altoona','Altoona, Alabama',13725,1);
INSERT INTO "django_geo_db_city" VALUES(10794,'Ashville','Ashville, Alabama',13726,1);
INSERT INTO "django_geo_db_city" VALUES(10795,'Attalla','Attalla, Alabama',13727,1);
INSERT INTO "django_geo_db_city" VALUES(10796,'Boaz','Boaz, Alabama',13728,1);
INSERT INTO "django_geo_db_city" VALUES(10797,'Bryant','Bryant, Alabama',13730,1);
INSERT INTO "django_geo_db_city" VALUES(10798,'Cedar Bluff','Cedar Bluff, Alabama',13731,1);
INSERT INTO "django_geo_db_city" VALUES(10799,'Centre','Centre, Alabama',13732,1);
INSERT INTO "django_geo_db_city" VALUES(10800,'Collinsville','Collinsville, Alabama',13733,1);
INSERT INTO "django_geo_db_city" VALUES(10801,'Crossville','Crossville, Alabama',13734,1);
INSERT INTO "django_geo_db_city" VALUES(10802,'Dawson','Dawson, Alabama',13735,1);
INSERT INTO "django_geo_db_city" VALUES(10803,'Douglas','Douglas, Alabama',13736,1);
INSERT INTO "django_geo_db_city" VALUES(10804,'Flat Rock','Flat Rock, Alabama',13737,1);
INSERT INTO "django_geo_db_city" VALUES(10805,'Fort Payne','Fort Payne, Alabama',13738,1);
INSERT INTO "django_geo_db_city" VALUES(10806,'Fyffe','Fyffe, Alabama',13741,1);
INSERT INTO "django_geo_db_city" VALUES(10807,'Gallant','Gallant, Alabama',13742,1);
INSERT INTO "django_geo_db_city" VALUES(10808,'Gaylesville','Gaylesville, Alabama',13743,1);
INSERT INTO "django_geo_db_city" VALUES(10809,'Geraldine','Geraldine, Alabama',13744,1);
INSERT INTO "django_geo_db_city" VALUES(10810,'Groveoak','Groveoak, Alabama',13745,1);
INSERT INTO "django_geo_db_city" VALUES(10811,'Guntersville','Guntersville, Alabama',13746,1);
INSERT INTO "django_geo_db_city" VALUES(10812,'Henagar','Henagar, Alabama',13747,1);
INSERT INTO "django_geo_db_city" VALUES(10813,'Higdon','Higdon, Alabama',13748,1);
INSERT INTO "django_geo_db_city" VALUES(10814,'Horton','Horton, Alabama',13749,1);
INSERT INTO "django_geo_db_city" VALUES(10815,'Ider','Ider, Alabama',13750,1);
INSERT INTO "django_geo_db_city" VALUES(10816,'Leesburg','Leesburg, Alabama',13751,1);
INSERT INTO "django_geo_db_city" VALUES(10817,'Mentone','Mentone, Alabama',13752,1);
INSERT INTO "django_geo_db_city" VALUES(10818,'Rainsville','Rainsville, Alabama',13753,1);
INSERT INTO "django_geo_db_city" VALUES(10819,'Steele','Steele, Alabama',13754,1);
INSERT INTO "django_geo_db_city" VALUES(10820,'Sylvania','Sylvania, Alabama',13755,1);
INSERT INTO "django_geo_db_city" VALUES(10821,'Valley Head','Valley Head, Alabama',13756,1);
INSERT INTO "django_geo_db_city" VALUES(10822,'Walnut Grove','Walnut Grove, Alabama',13757,1);
INSERT INTO "django_geo_db_city" VALUES(10823,'Autaugaville','Autaugaville, Alabama',13758,1);
INSERT INTO "django_geo_db_city" VALUES(10824,'Banks','Banks, Alabama',13759,1);
INSERT INTO "django_geo_db_city" VALUES(10825,'Billingsley','Billingsley, Alabama',13760,1);
INSERT INTO "django_geo_db_city" VALUES(10826,'Booth','Booth, Alabama',13761,1);
INSERT INTO "django_geo_db_city" VALUES(10827,'Brantley','Brantley, Alabama',13762,1);
INSERT INTO "django_geo_db_city" VALUES(10828,'Brundidge','Brundidge, Alabama',13763,1);
INSERT INTO "django_geo_db_city" VALUES(10829,'Cecil','Cecil, Alabama',13764,1);
INSERT INTO "django_geo_db_city" VALUES(10830,'Chapman','Chapman, Alabama',13765,1);
INSERT INTO "django_geo_db_city" VALUES(10831,'Clayton','Clayton, Alabama',13766,1);
INSERT INTO "django_geo_db_city" VALUES(10832,'Clio','Clio, Alabama',13767,1);
INSERT INTO "django_geo_db_city" VALUES(10833,'Coosada','Coosada, Alabama',13768,1);
INSERT INTO "django_geo_db_city" VALUES(10834,'Deatsville','Deatsville, Alabama',13769,1);
INSERT INTO "django_geo_db_city" VALUES(10835,'East Tallassee','East Tallassee, Alabama',13770,1);
INSERT INTO "django_geo_db_city" VALUES(10836,'Eclectic','Eclectic, Alabama',13771,1);
INSERT INTO "django_geo_db_city" VALUES(10837,'Elmore','Elmore, Alabama',13772,1);
INSERT INTO "django_geo_db_city" VALUES(10838,'Equality','Equality, Alabama',13773,1);
INSERT INTO "django_geo_db_city" VALUES(10839,'Eufaula','Eufaula, Alabama',13774,1);
INSERT INTO "django_geo_db_city" VALUES(10840,'Dozier','Dozier, Alabama',13775,1);
INSERT INTO "django_geo_db_city" VALUES(10841,'Fitzpatrick','Fitzpatrick, Alabama',13776,1);
INSERT INTO "django_geo_db_city" VALUES(10842,'Forest Home','Forest Home, Alabama',13777,1);
INSERT INTO "django_geo_db_city" VALUES(10843,'Fort Davis','Fort Davis, Alabama',13778,1);
INSERT INTO "django_geo_db_city" VALUES(10844,'Fort Deposit','Fort Deposit, Alabama',13779,1);
INSERT INTO "django_geo_db_city" VALUES(10845,'Georgiana','Georgiana, Alabama',13780,1);
INSERT INTO "django_geo_db_city" VALUES(10846,'Glenwood','Glenwood, Alabama',13781,1);
INSERT INTO "django_geo_db_city" VALUES(10847,'Goshen','Goshen, Alabama',13782,1);
INSERT INTO "django_geo_db_city" VALUES(10848,'Grady','Grady, Alabama',13783,1);
INSERT INTO "django_geo_db_city" VALUES(10849,'Greenville','Greenville, Alabama',13784,1);
INSERT INTO "django_geo_db_city" VALUES(10850,'Gantt','Gantt, Alabama',13785,1);
INSERT INTO "django_geo_db_city" VALUES(10851,'Hardaway','Hardaway, Alabama',13786,1);
INSERT INTO "django_geo_db_city" VALUES(10852,'Hayneville','Hayneville, Alabama',13787,1);
INSERT INTO "django_geo_db_city" VALUES(10853,'Highland Home','Highland Home, Alabama',13788,1);
INSERT INTO "django_geo_db_city" VALUES(10854,'Honoraville','Honoraville, Alabama',13789,1);
INSERT INTO "django_geo_db_city" VALUES(10855,'Hope Hull','Hope Hull, Alabama',13790,1);
INSERT INTO "django_geo_db_city" VALUES(10856,'Kent','Kent, Alabama',13791,1);
INSERT INTO "django_geo_db_city" VALUES(10857,'Lapine','Lapine, Alabama',13792,1);
INSERT INTO "django_geo_db_city" VALUES(10858,'Letohatchee','Letohatchee, Alabama',13793,1);
INSERT INTO "django_geo_db_city" VALUES(10859,'Louisville','Louisville, Alabama',13794,1);
INSERT INTO "django_geo_db_city" VALUES(10860,'Luverne','Luverne, Alabama',13795,1);
INSERT INTO "django_geo_db_city" VALUES(10861,'Marbury','Marbury, Alabama',13796,1);
INSERT INTO "django_geo_db_city" VALUES(10862,'Mathews','Mathews, Alabama',13797,1);
INSERT INTO "django_geo_db_city" VALUES(10863,'Midway','Midway, Alabama',13798,1);
INSERT INTO "django_geo_db_city" VALUES(10864,'Millbrook','Millbrook, Alabama',13799,1);
INSERT INTO "django_geo_db_city" VALUES(10865,'Mount Meigs','Mount Meigs, Alabama',13800,1);
INSERT INTO "django_geo_db_city" VALUES(10866,'Perote','Perote, Alabama',13801,1);
INSERT INTO "django_geo_db_city" VALUES(10867,'Petrey','Petrey, Alabama',13802,1);
INSERT INTO "django_geo_db_city" VALUES(10868,'Pike Road','Pike Road, Alabama',13803,1);
INSERT INTO "django_geo_db_city" VALUES(10869,'Pine Level','Pine Level, Alabama',13804,1);
INSERT INTO "django_geo_db_city" VALUES(10870,'Prattville','Prattville, Alabama',13805,1);
INSERT INTO "django_geo_db_city" VALUES(10871,'Ramer','Ramer, Alabama',13808,1);
INSERT INTO "django_geo_db_city" VALUES(10872,'Rutledge','Rutledge, Alabama',13809,1);
INSERT INTO "django_geo_db_city" VALUES(10873,'Shorter','Shorter, Alabama',13811,1);
INSERT INTO "django_geo_db_city" VALUES(10874,'Tallassee','Tallassee, Alabama',13812,1);
INSERT INTO "django_geo_db_city" VALUES(10875,'Troy','Troy, Alabama',13813,1);
INSERT INTO "django_geo_db_city" VALUES(10876,'Titus','Titus, Alabama',13814,1);
INSERT INTO "django_geo_db_city" VALUES(10877,'Tuskegee','Tuskegee, Alabama',13817,1);
INSERT INTO "django_geo_db_city" VALUES(10878,'Tuskegee Institute','Tuskegee Institute, Alabama',13818,1);
INSERT INTO "django_geo_db_city" VALUES(10879,'Union Springs','Union Springs, Alabama',13820,1);
INSERT INTO "django_geo_db_city" VALUES(10880,'Verbena','Verbena, Alabama',13821,1);
INSERT INTO "django_geo_db_city" VALUES(10881,'Wetumpka','Wetumpka, Alabama',13822,1);
INSERT INTO "django_geo_db_city" VALUES(10882,'Montgomery','Montgomery, Alabama',13824,1);
INSERT INTO "django_geo_db_city" VALUES(10883,'Anniston','Anniston, Alabama',13840,1);
INSERT INTO "django_geo_db_city" VALUES(10884,'Alexandria','Alexandria, Alabama',13846,1);
INSERT INTO "django_geo_db_city" VALUES(10885,'Ashland','Ashland, Alabama',13847,1);
INSERT INTO "django_geo_db_city" VALUES(10886,'Bynum','Bynum, Alabama',13841,1);
INSERT INTO "django_geo_db_city" VALUES(10887,'Choccolocco','Choccolocco, Alabama',13848,1);
INSERT INTO "django_geo_db_city" VALUES(10888,'Cragford','Cragford, Alabama',13849,1);
INSERT INTO "django_geo_db_city" VALUES(10889,'Daviston','Daviston, Alabama',13850,1);
INSERT INTO "django_geo_db_city" VALUES(10890,'De Armanville','De Armanville, Alabama',13841,1);
INSERT INTO "django_geo_db_city" VALUES(10891,'Delta','Delta, Alabama',13851,1);
INSERT INTO "django_geo_db_city" VALUES(10892,'Eastaboga','Eastaboga, Alabama',13852,1);
INSERT INTO "django_geo_db_city" VALUES(10893,'Edwardsville','Edwardsville, Alabama',13853,1);
INSERT INTO "django_geo_db_city" VALUES(10894,'Fruithurst','Fruithurst, Alabama',13854,1);
INSERT INTO "django_geo_db_city" VALUES(10895,'Graham','Graham, Alabama',13855,1);
INSERT INTO "django_geo_db_city" VALUES(10896,'Heflin','Heflin, Alabama',13856,1);
INSERT INTO "django_geo_db_city" VALUES(10897,'Jacksonville','Jacksonville, Alabama',13857,1);
INSERT INTO "django_geo_db_city" VALUES(10898,'Lineville','Lineville, Alabama',13858,1);
INSERT INTO "django_geo_db_city" VALUES(10899,'Millerville','Millerville, Alabama',13859,1);
INSERT INTO "django_geo_db_city" VALUES(10900,'Munford','Munford, Alabama',13860,1);
INSERT INTO "django_geo_db_city" VALUES(10901,'Muscadine','Muscadine, Alabama',13861,1);
INSERT INTO "django_geo_db_city" VALUES(10902,'Newell','Newell, Alabama',13862,1);
INSERT INTO "django_geo_db_city" VALUES(10903,'Ohatchee','Ohatchee, Alabama',13863,1);
INSERT INTO "django_geo_db_city" VALUES(10904,'Piedmont','Piedmont, Alabama',13864,1);
INSERT INTO "django_geo_db_city" VALUES(10905,'Ranburne','Ranburne, Alabama',13865,1);
INSERT INTO "django_geo_db_city" VALUES(10906,'Roanoke','Roanoke, Alabama',13866,1);
INSERT INTO "django_geo_db_city" VALUES(10907,'Spring Garden','Spring Garden, Alabama',13867,1);
INSERT INTO "django_geo_db_city" VALUES(10908,'Wadley','Wadley, Alabama',13868,1);
INSERT INTO "django_geo_db_city" VALUES(10909,'Weaver','Weaver, Alabama',13869,1);
INSERT INTO "django_geo_db_city" VALUES(10910,'Wedowee','Wedowee, Alabama',13870,1);
INSERT INTO "django_geo_db_city" VALUES(10911,'Wellington','Wellington, Alabama',13871,1);
INSERT INTO "django_geo_db_city" VALUES(10912,'Woodland','Woodland, Alabama',13872,1);
INSERT INTO "django_geo_db_city" VALUES(10913,'Dothan','Dothan, Alabama',13873,1);
INSERT INTO "django_geo_db_city" VALUES(10914,'Abbeville','Abbeville, Alabama',13877,1);
INSERT INTO "django_geo_db_city" VALUES(10915,'Ariton','Ariton, Alabama',13878,1);
INSERT INTO "django_geo_db_city" VALUES(10916,'Ashford','Ashford, Alabama',13879,1);
INSERT INTO "django_geo_db_city" VALUES(10917,'Bellwood','Bellwood, Alabama',13880,1);
INSERT INTO "django_geo_db_city" VALUES(10918,'Black','Black, Alabama',13881,1);
INSERT INTO "django_geo_db_city" VALUES(10919,'Chancellor','Chancellor, Alabama',13882,1);
INSERT INTO "django_geo_db_city" VALUES(10920,'Clopton','Clopton, Alabama',13883,1);
INSERT INTO "django_geo_db_city" VALUES(10921,'Coffee Springs','Coffee Springs, Alabama',13884,1);
INSERT INTO "django_geo_db_city" VALUES(10922,'Columbia','Columbia, Alabama',13885,1);
INSERT INTO "django_geo_db_city" VALUES(10923,'Cottonwood','Cottonwood, Alabama',13886,1);
INSERT INTO "django_geo_db_city" VALUES(10924,'Cowarts','Cowarts, Alabama',13887,1);
INSERT INTO "django_geo_db_city" VALUES(10925,'Daleville','Daleville, Alabama',13888,1);
INSERT INTO "django_geo_db_city" VALUES(10926,'Elba','Elba, Alabama',13889,1);
INSERT INTO "django_geo_db_city" VALUES(10927,'Enterprise','Enterprise, Alabama',13890,1);
INSERT INTO "django_geo_db_city" VALUES(10928,'Geneva','Geneva, Alabama',13892,1);
INSERT INTO "django_geo_db_city" VALUES(10929,'Gordon','Gordon, Alabama',13893,1);
INSERT INTO "django_geo_db_city" VALUES(10930,'Hartford','Hartford, Alabama',13894,1);
INSERT INTO "django_geo_db_city" VALUES(10931,'Headland','Headland, Alabama',13895,1);
INSERT INTO "django_geo_db_city" VALUES(10932,'Jack','Jack, Alabama',13896,1);
INSERT INTO "django_geo_db_city" VALUES(10933,'Malvern','Malvern, Alabama',13897,1);
INSERT INTO "django_geo_db_city" VALUES(10934,'Midland City','Midland City, Alabama',13898,1);
INSERT INTO "django_geo_db_city" VALUES(10935,'New Brockton','New Brockton, Alabama',13899,1);
INSERT INTO "django_geo_db_city" VALUES(10936,'Newton','Newton, Alabama',13900,1);
INSERT INTO "django_geo_db_city" VALUES(10937,'Newville','Newville, Alabama',13901,1);
INSERT INTO "django_geo_db_city" VALUES(10938,'Ozark','Ozark, Alabama',13902,1);
INSERT INTO "django_geo_db_city" VALUES(10939,'Fort Rucker','Fort Rucker, Alabama',13904,1);
INSERT INTO "django_geo_db_city" VALUES(10940,'Pansey','Pansey, Alabama',13905,1);
INSERT INTO "django_geo_db_city" VALUES(10941,'Pinckard','Pinckard, Alabama',13906,1);
INSERT INTO "django_geo_db_city" VALUES(10942,'Shorterville','Shorterville, Alabama',13907,1);
INSERT INTO "django_geo_db_city" VALUES(10943,'Skipperville','Skipperville, Alabama',13908,1);
INSERT INTO "django_geo_db_city" VALUES(10944,'Slocomb','Slocomb, Alabama',13909,1);
INSERT INTO "django_geo_db_city" VALUES(10945,'Webb','Webb, Alabama',13910,1);
INSERT INTO "django_geo_db_city" VALUES(10946,'Lanett','Lanett, Alabama',13911,1);
INSERT INTO "django_geo_db_city" VALUES(10947,'Evergreen','Evergreen, Alabama',13913,1);
INSERT INTO "django_geo_db_city" VALUES(10948,'Andalusia','Andalusia, Alabama',13914,1);
INSERT INTO "django_geo_db_city" VALUES(10949,'Lockhart','Lockhart, Alabama',13915,1);
INSERT INTO "django_geo_db_city" VALUES(10950,'Beatrice','Beatrice, Alabama',13916,1);
INSERT INTO "django_geo_db_city" VALUES(10951,'Brewton','Brewton, Alabama',13917,1);
INSERT INTO "django_geo_db_city" VALUES(10952,'Brooklyn','Brooklyn, Alabama',13919,1);
INSERT INTO "django_geo_db_city" VALUES(10953,'Burnt Corn','Burnt Corn, Alabama',13920,1);
INSERT INTO "django_geo_db_city" VALUES(10954,'Castleberry','Castleberry, Alabama',13921,1);
INSERT INTO "django_geo_db_city" VALUES(10955,'Coy','Coy, Alabama',13922,1);
INSERT INTO "django_geo_db_city" VALUES(10956,'Dickinson','Dickinson, Alabama',13923,1);
INSERT INTO "django_geo_db_city" VALUES(10957,'Excel','Excel, Alabama',13924,1);
INSERT INTO "django_geo_db_city" VALUES(10958,'Flomaton','Flomaton, Alabama',13925,1);
INSERT INTO "django_geo_db_city" VALUES(10959,'Florala','Florala, Alabama',13926,1);
INSERT INTO "django_geo_db_city" VALUES(10960,'Franklin','Franklin, Alabama',13927,1);
INSERT INTO "django_geo_db_city" VALUES(10961,'Frisco City','Frisco City, Alabama',13928,1);
INSERT INTO "django_geo_db_city" VALUES(10962,'Fulton','Fulton, Alabama',13929,1);
INSERT INTO "django_geo_db_city" VALUES(10963,'Goodway','Goodway, Alabama',13920,1);
INSERT INTO "django_geo_db_city" VALUES(10964,'Grove Hill','Grove Hill, Alabama',13930,1);
INSERT INTO "django_geo_db_city" VALUES(10965,'Kinston','Kinston, Alabama',13931,1);
INSERT INTO "django_geo_db_city" VALUES(10966,'Lenox','Lenox, Alabama',13919,1);
INSERT INTO "django_geo_db_city" VALUES(10967,'McKenzie','McKenzie, Alabama',13933,1);
INSERT INTO "django_geo_db_city" VALUES(10968,'Megargel','Megargel, Alabama',13934,1);
INSERT INTO "django_geo_db_city" VALUES(10969,'Mexia','Mexia, Alabama',13935,1);
INSERT INTO "django_geo_db_city" VALUES(10970,'Monroeville','Monroeville, Alabama',13936,1);
INSERT INTO "django_geo_db_city" VALUES(10971,'Opp','Opp, Alabama',13938,1);
INSERT INTO "django_geo_db_city" VALUES(10972,'Perdue Hill','Perdue Hill, Alabama',13939,1);
INSERT INTO "django_geo_db_city" VALUES(10973,'Peterman','Peterman, Alabama',13940,1);
INSERT INTO "django_geo_db_city" VALUES(10974,'Range','Range, Alabama',13941,1);
INSERT INTO "django_geo_db_city" VALUES(10975,'Red Level','Red Level, Alabama',13942,1);
INSERT INTO "django_geo_db_city" VALUES(10976,'Repton','Repton, Alabama',13943,1);
INSERT INTO "django_geo_db_city" VALUES(10977,'River Falls','River Falls, Alabama',13944,1);
INSERT INTO "django_geo_db_city" VALUES(10978,'Samson','Samson, Alabama',13945,1);
INSERT INTO "django_geo_db_city" VALUES(10979,'Uriah','Uriah, Alabama',13946,1);
INSERT INTO "django_geo_db_city" VALUES(10980,'Vredenburgh','Vredenburgh, Alabama',13947,1);
INSERT INTO "django_geo_db_city" VALUES(10981,'Whatley','Whatley, Alabama',13948,1);
INSERT INTO "django_geo_db_city" VALUES(10982,'Wing','Wing, Alabama',13949,1);
INSERT INTO "django_geo_db_city" VALUES(10983,'Alma','Alma, Alabama',13950,1);
INSERT INTO "django_geo_db_city" VALUES(10984,'Atmore','Atmore, Alabama',13951,1);
INSERT INTO "django_geo_db_city" VALUES(10985,'Axis','Axis, Alabama',13954,1);
INSERT INTO "django_geo_db_city" VALUES(10986,'Bay Minette','Bay Minette, Alabama',13955,1);
INSERT INTO "django_geo_db_city" VALUES(10987,'Dauphin Island','Dauphin Island, Alabama',13956,1);
INSERT INTO "django_geo_db_city" VALUES(10988,'Bayou La Batre','Bayou La Batre, Alabama',13957,1);
INSERT INTO "django_geo_db_city" VALUES(10989,'Bon Secour','Bon Secour, Alabama',13958,1);
INSERT INTO "django_geo_db_city" VALUES(10990,'Bucks','Bucks, Alabama',13959,1);
INSERT INTO "django_geo_db_city" VALUES(10991,'Calvert','Calvert, Alabama',13960,1);
INSERT INTO "django_geo_db_city" VALUES(10992,'Carlton','Carlton, Alabama',13961,1);
INSERT INTO "django_geo_db_city" VALUES(10993,'Chatom','Chatom, Alabama',13962,1);
INSERT INTO "django_geo_db_city" VALUES(10994,'Chunchula','Chunchula, Alabama',13963,1);
INSERT INTO "django_geo_db_city" VALUES(10995,'Citronelle','Citronelle, Alabama',13964,1);
INSERT INTO "django_geo_db_city" VALUES(10996,'Coden','Coden, Alabama',13965,1);
INSERT INTO "django_geo_db_city" VALUES(10997,'Coffeeville','Coffeeville, Alabama',13966,1);
INSERT INTO "django_geo_db_city" VALUES(10998,'Creola','Creola, Alabama',13967,1);
INSERT INTO "django_geo_db_city" VALUES(10999,'Daphne','Daphne, Alabama',13968,1);
INSERT INTO "django_geo_db_city" VALUES(11000,'Spanish Fort','Spanish Fort, Alabama',13969,1);
INSERT INTO "django_geo_db_city" VALUES(11001,'Deer Park','Deer Park, Alabama',13971,1);
INSERT INTO "django_geo_db_city" VALUES(11002,'Elberta','Elberta, Alabama',13972,1);
INSERT INTO "django_geo_db_city" VALUES(11003,'Loxley','Loxley, Alabama',13973,1);
INSERT INTO "django_geo_db_city" VALUES(11004,'Fairhope','Fairhope, Alabama',13974,1);
INSERT INTO "django_geo_db_city" VALUES(11005,'Foley','Foley, Alabama',13976,1);
INSERT INTO "django_geo_db_city" VALUES(11006,'Frankville','Frankville, Alabama',13978,1);
INSERT INTO "django_geo_db_city" VALUES(11007,'Fruitdale','Fruitdale, Alabama',13979,1);
INSERT INTO "django_geo_db_city" VALUES(11008,'Gainestown','Gainestown, Alabama',13980,1);
INSERT INTO "django_geo_db_city" VALUES(11009,'Grand Bay','Grand Bay, Alabama',13981,1);
INSERT INTO "django_geo_db_city" VALUES(11010,'Gulf Shores','Gulf Shores, Alabama',13982,1);
INSERT INTO "django_geo_db_city" VALUES(11011,'Huxford','Huxford, Alabama',13983,1);
INSERT INTO "django_geo_db_city" VALUES(11012,'Irvington','Irvington, Alabama',13984,1);
INSERT INTO "django_geo_db_city" VALUES(11013,'Jackson','Jackson, Alabama',13985,1);
INSERT INTO "django_geo_db_city" VALUES(11014,'Leroy','Leroy, Alabama',13987,1);
INSERT INTO "django_geo_db_city" VALUES(11015,'Lillian','Lillian, Alabama',13988,1);
INSERT INTO "django_geo_db_city" VALUES(11016,'Little River','Little River, Alabama',13989,1);
INSERT INTO "django_geo_db_city" VALUES(11017,'McIntosh','McIntosh, Alabama',13991,1);
INSERT INTO "django_geo_db_city" VALUES(11018,'Magnolia Springs','Magnolia Springs, Alabama',13992,1);
INSERT INTO "django_geo_db_city" VALUES(11019,'Malcolm','Malcolm, Alabama',13993,1);
INSERT INTO "django_geo_db_city" VALUES(11020,'Millry','Millry, Alabama',13994,1);
INSERT INTO "django_geo_db_city" VALUES(11021,'Montrose','Montrose, Alabama',13995,1);
INSERT INTO "django_geo_db_city" VALUES(11022,'Mount Vernon','Mount Vernon, Alabama',13996,1);
INSERT INTO "django_geo_db_city" VALUES(11023,'Orange Beach','Orange Beach, Alabama',13997,1);
INSERT INTO "django_geo_db_city" VALUES(11024,'Perdido','Perdido, Alabama',13998,1);
INSERT INTO "django_geo_db_city" VALUES(11025,'Point Clear','Point Clear, Alabama',13999,1);
INSERT INTO "django_geo_db_city" VALUES(11026,'Robertsdale','Robertsdale, Alabama',14000,1);
INSERT INTO "django_geo_db_city" VALUES(11027,'Saint Elmo','Saint Elmo, Alabama',14001,1);
INSERT INTO "django_geo_db_city" VALUES(11028,'Saint Stephens','Saint Stephens, Alabama',14002,1);
INSERT INTO "django_geo_db_city" VALUES(11029,'Salitpa','Salitpa, Alabama',14003,1);
INSERT INTO "django_geo_db_city" VALUES(11030,'Saraland','Saraland, Alabama',14004,1);
INSERT INTO "django_geo_db_city" VALUES(11031,'Satsuma','Satsuma, Alabama',14005,1);
INSERT INTO "django_geo_db_city" VALUES(11032,'Seminole','Seminole, Alabama',14006,1);
INSERT INTO "django_geo_db_city" VALUES(11033,'Semmes','Semmes, Alabama',14007,1);
INSERT INTO "django_geo_db_city" VALUES(11034,'Silverhill','Silverhill, Alabama',14008,1);
INSERT INTO "django_geo_db_city" VALUES(11035,'Stapleton','Stapleton, Alabama',14010,1);
INSERT INTO "django_geo_db_city" VALUES(11036,'Stockton','Stockton, Alabama',14011,1);
INSERT INTO "django_geo_db_city" VALUES(11037,'Summerdale','Summerdale, Alabama',14012,1);
INSERT INTO "django_geo_db_city" VALUES(11038,'Sunflower','Sunflower, Alabama',14013,1);
INSERT INTO "django_geo_db_city" VALUES(11039,'Theodore','Theodore, Alabama',14014,1);
INSERT INTO "django_geo_db_city" VALUES(11040,'Tibbie','Tibbie, Alabama',14015,1);
INSERT INTO "django_geo_db_city" VALUES(11041,'Vinegar Bend','Vinegar Bend, Alabama',14016,1);
INSERT INTO "django_geo_db_city" VALUES(11042,'Wagarville','Wagarville, Alabama',14017,1);
INSERT INTO "django_geo_db_city" VALUES(11043,'Walker Springs','Walker Springs, Alabama',14018,1);
INSERT INTO "django_geo_db_city" VALUES(11044,'Wilmer','Wilmer, Alabama',14019,1);
INSERT INTO "django_geo_db_city" VALUES(11045,'Mobile','Mobile, Alabama',14021,1);
INSERT INTO "django_geo_db_city" VALUES(11046,'Eight Mile','Eight Mile, Alabama',14033,1);
INSERT INTO "django_geo_db_city" VALUES(11047,'Selma','Selma, Alabama',14044,1);
INSERT INTO "django_geo_db_city" VALUES(11048,'Alberta','Alberta, Alabama',14047,1);
INSERT INTO "django_geo_db_city" VALUES(11049,'Annemanie','Annemanie, Alabama',14048,1);
INSERT INTO "django_geo_db_city" VALUES(11050,'Arlington','Arlington, Alabama',14049,1);
INSERT INTO "django_geo_db_city" VALUES(11051,'Boykin','Boykin, Alabama',14050,1);
INSERT INTO "django_geo_db_city" VALUES(11052,'Camden','Camden, Alabama',14051,1);
INSERT INTO "django_geo_db_city" VALUES(11053,'Campbell','Campbell, Alabama',14052,1);
INSERT INTO "django_geo_db_city" VALUES(11054,'Catherine','Catherine, Alabama',14053,1);
INSERT INTO "django_geo_db_city" VALUES(11055,'Demopolis','Demopolis, Alabama',14054,1);
INSERT INTO "django_geo_db_city" VALUES(11056,'Dixons Mills','Dixons Mills, Alabama',14055,1);
INSERT INTO "django_geo_db_city" VALUES(11057,'Faunsdale','Faunsdale, Alabama',14056,1);
INSERT INTO "django_geo_db_city" VALUES(11058,'Forkland','Forkland, Alabama',14057,1);
INSERT INTO "django_geo_db_city" VALUES(11059,'Furman','Furman, Alabama',14058,1);
INSERT INTO "django_geo_db_city" VALUES(11060,'Gallion','Gallion, Alabama',14059,1);
INSERT INTO "django_geo_db_city" VALUES(11061,'Greensboro','Greensboro, Alabama',14060,1);
INSERT INTO "django_geo_db_city" VALUES(11062,'Jefferson','Jefferson, Alabama',14061,1);
INSERT INTO "django_geo_db_city" VALUES(11063,'Linden','Linden, Alabama',14062,1);
INSERT INTO "django_geo_db_city" VALUES(11064,'Jones','Jones, Alabama',14063,1);
INSERT INTO "django_geo_db_city" VALUES(11065,'Maplesville','Maplesville, Alabama',14064,1);
INSERT INTO "django_geo_db_city" VALUES(11066,'Lower Peach Tree','Lower Peach Tree, Alabama',14065,1);
INSERT INTO "django_geo_db_city" VALUES(11067,'Lowndesboro','Lowndesboro, Alabama',14066,1);
INSERT INTO "django_geo_db_city" VALUES(11068,'McWilliams','McWilliams, Alabama',14048,1);
INSERT INTO "django_geo_db_city" VALUES(11069,'Magnolia','Magnolia, Alabama',14067,1);
INSERT INTO "django_geo_db_city" VALUES(11070,'Marion','Marion, Alabama',14069,1);
INSERT INTO "django_geo_db_city" VALUES(11071,'Plantersville','Plantersville, Alabama',14070,1);
INSERT INTO "django_geo_db_city" VALUES(11072,'Marion Junction','Marion Junction, Alabama',14071,1);
INSERT INTO "django_geo_db_city" VALUES(11073,'Minter','Minter, Alabama',14072,1);
INSERT INTO "django_geo_db_city" VALUES(11074,'Morvin','Morvin, Alabama',14073,1);
INSERT INTO "django_geo_db_city" VALUES(11075,'Myrtlewood','Myrtlewood, Alabama',14074,1);
INSERT INTO "django_geo_db_city" VALUES(11076,'Nanafalia','Nanafalia, Alabama',14075,1);
INSERT INTO "django_geo_db_city" VALUES(11077,'Newbern','Newbern, Alabama',14076,1);
INSERT INTO "django_geo_db_city" VALUES(11078,'Oak Hill','Oak Hill, Alabama',14077,1);
INSERT INTO "django_geo_db_city" VALUES(11079,'Orrville','Orrville, Alabama',14078,1);
INSERT INTO "django_geo_db_city" VALUES(11080,'Pine Apple','Pine Apple, Alabama',14079,1);
INSERT INTO "django_geo_db_city" VALUES(11081,'Pine Hill','Pine Hill, Alabama',14080,1);
INSERT INTO "django_geo_db_city" VALUES(11082,'Safford','Safford, Alabama',14081,1);
INSERT INTO "django_geo_db_city" VALUES(11083,'Sardis','Sardis, Alabama',14082,1);
INSERT INTO "django_geo_db_city" VALUES(11084,'Sawyerville','Sawyerville, Alabama',14083,1);
INSERT INTO "django_geo_db_city" VALUES(11085,'Snow Hill','Snow Hill, Alabama',14084,1);
INSERT INTO "django_geo_db_city" VALUES(11086,'Sprott','Sprott, Alabama',14085,1);
INSERT INTO "django_geo_db_city" VALUES(11087,'Sweet Water','Sweet Water, Alabama',14086,1);
INSERT INTO "django_geo_db_city" VALUES(11088,'Thomaston','Thomaston, Alabama',14087,1);
INSERT INTO "django_geo_db_city" VALUES(11089,'Thomasville','Thomasville, Alabama',14088,1);
INSERT INTO "django_geo_db_city" VALUES(11090,'Tyler','Tyler, Alabama',14089,1);
INSERT INTO "django_geo_db_city" VALUES(11091,'Uniontown','Uniontown, Alabama',14090,1);
INSERT INTO "django_geo_db_city" VALUES(11092,'Stanton','Stanton, Alabama',14091,1);
INSERT INTO "django_geo_db_city" VALUES(11093,'Randolph','Randolph, Alabama',14092,1);
INSERT INTO "django_geo_db_city" VALUES(11094,'Lawley','Lawley, Alabama',14093,1);
INSERT INTO "django_geo_db_city" VALUES(11095,'Opelika','Opelika, Alabama',14094,1);
INSERT INTO "django_geo_db_city" VALUES(11096,'Auburn','Auburn, Alabama',14098,1);
INSERT INTO "django_geo_db_city" VALUES(11097,'Auburn University','Auburn University, Alabama',14100,1);
INSERT INTO "django_geo_db_city" VALUES(11098,'Camp Hill','Camp Hill, Alabama',14101,1);
INSERT INTO "django_geo_db_city" VALUES(11099,'Cottonton','Cottonton, Alabama',14102,1);
INSERT INTO "django_geo_db_city" VALUES(11100,'Cusseta','Cusseta, Alabama',14103,1);
INSERT INTO "django_geo_db_city" VALUES(11101,'Dadeville','Dadeville, Alabama',14104,1);
INSERT INTO "django_geo_db_city" VALUES(11102,'Valley','Valley, Alabama',14105,1);
INSERT INTO "django_geo_db_city" VALUES(11103,'Five Points','Five Points, Alabama',14106,1);
INSERT INTO "django_geo_db_city" VALUES(11104,'Fort Mitchell','Fort Mitchell, Alabama',14107,1);
INSERT INTO "django_geo_db_city" VALUES(11105,'Hatchechubbee','Hatchechubbee, Alabama',14108,1);
INSERT INTO "django_geo_db_city" VALUES(11106,'Holy Trinity','Holy Trinity, Alabama',14109,1);
INSERT INTO "django_geo_db_city" VALUES(11107,'Hurtsboro','Hurtsboro, Alabama',14110,1);
INSERT INTO "django_geo_db_city" VALUES(11108,'Jacksons Gap','Jacksons Gap, Alabama',14111,1);
INSERT INTO "django_geo_db_city" VALUES(11109,'Lafayette','Lafayette, Alabama',14112,1);
INSERT INTO "django_geo_db_city" VALUES(11110,'Loachapoka','Loachapoka, Alabama',14095,1);
INSERT INTO "django_geo_db_city" VALUES(11111,'Notasulga','Notasulga, Alabama',14114,1);
INSERT INTO "django_geo_db_city" VALUES(11112,'Phenix City','Phenix City, Alabama',14115,1);
INSERT INTO "django_geo_db_city" VALUES(11113,'Pittsview','Pittsview, Alabama',14119,1);
INSERT INTO "django_geo_db_city" VALUES(11114,'Salem','Salem, Alabama',14120,1);
INSERT INTO "django_geo_db_city" VALUES(11115,'Seale','Seale, Alabama',14121,1);
INSERT INTO "django_geo_db_city" VALUES(11116,'Smiths','Smiths, Alabama',14123,1);
INSERT INTO "django_geo_db_city" VALUES(11117,'Waverly','Waverly, Alabama',14124,1);
INSERT INTO "django_geo_db_city" VALUES(11118,'Bellamy','Bellamy, Alabama',14125,1);
INSERT INTO "django_geo_db_city" VALUES(11119,'Butler','Butler, Alabama',14126,1);
INSERT INTO "django_geo_db_city" VALUES(11120,'Cromwell','Cromwell, Alabama',14127,1);
INSERT INTO "django_geo_db_city" VALUES(11121,'Cuba','Cuba, Alabama',14128,1);
INSERT INTO "django_geo_db_city" VALUES(11122,'Gilbertown','Gilbertown, Alabama',14129,1);
INSERT INTO "django_geo_db_city" VALUES(11123,'Jachin','Jachin, Alabama',14130,1);
INSERT INTO "django_geo_db_city" VALUES(11124,'Lisman','Lisman, Alabama',14131,1);
INSERT INTO "django_geo_db_city" VALUES(11125,'Melvin','Melvin, Alabama',14127,1);
INSERT INTO "django_geo_db_city" VALUES(11126,'Needham','Needham, Alabama',14132,1);
INSERT INTO "django_geo_db_city" VALUES(11127,'Pennington','Pennington, Alabama',14133,1);
INSERT INTO "django_geo_db_city" VALUES(11128,'Silas','Silas, Alabama',14134,1);
INSERT INTO "django_geo_db_city" VALUES(11129,'Toxey','Toxey, Alabama',14135,1);
INSERT INTO "django_geo_db_city" VALUES(11130,'Ward','Ward, Alabama',14136,1);
INSERT INTO "django_geo_db_city" VALUES(11131,'York','York, Alabama',14137,1);
INSERT INTO "django_geo_db_city" VALUES(11132,'Adams','Adams, Tennessee',14138,50);
INSERT INTO "django_geo_db_city" VALUES(11133,'Antioch','Antioch, Tennessee',14139,50);
INSERT INTO "django_geo_db_city" VALUES(11134,'Alexandria','Alexandria, Tennessee',14140,50);
INSERT INTO "django_geo_db_city" VALUES(11135,'Arrington','Arrington, Tennessee',14142,50);
INSERT INTO "django_geo_db_city" VALUES(11136,'Ashland City','Ashland City, Tennessee',14143,50);
INSERT INTO "django_geo_db_city" VALUES(11137,'Auburntown','Auburntown, Tennessee',14144,50);
INSERT INTO "django_geo_db_city" VALUES(11138,'Beechgrove','Beechgrove, Tennessee',14145,50);
INSERT INTO "django_geo_db_city" VALUES(11139,'Belfast','Belfast, Tennessee',14146,50);
INSERT INTO "django_geo_db_city" VALUES(11140,'Bell Buckle','Bell Buckle, Tennessee',14147,50);
INSERT INTO "django_geo_db_city" VALUES(11141,'Bethpage','Bethpage, Tennessee',14148,50);
INSERT INTO "django_geo_db_city" VALUES(11142,'Big Rock','Big Rock, Tennessee',14149,50);
INSERT INTO "django_geo_db_city" VALUES(11143,'Brentwood','Brentwood, Tennessee',14150,50);
INSERT INTO "django_geo_db_city" VALUES(11144,'Bon Aqua','Bon Aqua, Tennessee',14151,50);
INSERT INTO "django_geo_db_city" VALUES(11145,'Bradyville','Bradyville, Tennessee',14152,50);
INSERT INTO "django_geo_db_city" VALUES(11146,'Bumpus Mills','Bumpus Mills, Tennessee',14154,50);
INSERT INTO "django_geo_db_city" VALUES(11147,'Burns','Burns, Tennessee',14155,50);
INSERT INTO "django_geo_db_city" VALUES(11148,'Carthage','Carthage, Tennessee',14156,50);
INSERT INTO "django_geo_db_city" VALUES(11149,'Castalian Springs','Castalian Springs, Tennessee',14157,50);
INSERT INTO "django_geo_db_city" VALUES(11150,'Cedar Hill','Cedar Hill, Tennessee',14158,50);
INSERT INTO "django_geo_db_city" VALUES(11151,'Centerville','Centerville, Tennessee',14159,50);
INSERT INTO "django_geo_db_city" VALUES(11152,'Chapel Hill','Chapel Hill, Tennessee',14160,50);
INSERT INTO "django_geo_db_city" VALUES(11153,'Chapmansboro','Chapmansboro, Tennessee',14161,50);
INSERT INTO "django_geo_db_city" VALUES(11154,'Charlotte','Charlotte, Tennessee',14162,50);
INSERT INTO "django_geo_db_city" VALUES(11155,'Christiana','Christiana, Tennessee',14163,50);
INSERT INTO "django_geo_db_city" VALUES(11156,'Clarksville','Clarksville, Tennessee',14164,50);
INSERT INTO "django_geo_db_city" VALUES(11157,'College Grove','College Grove, Tennessee',14169,50);
INSERT INTO "django_geo_db_city" VALUES(11158,'Cornersville','Cornersville, Tennessee',14170,50);
INSERT INTO "django_geo_db_city" VALUES(11159,'Cottontown','Cottontown, Tennessee',14171,50);
INSERT INTO "django_geo_db_city" VALUES(11160,'Cross Plains','Cross Plains, Tennessee',14172,50);
INSERT INTO "django_geo_db_city" VALUES(11161,'Cumberland City','Cumberland City, Tennessee',14173,50);
INSERT INTO "django_geo_db_city" VALUES(11162,'Cumberland Furnace','Cumberland Furnace, Tennessee',14174,50);
INSERT INTO "django_geo_db_city" VALUES(11163,'Cunningham','Cunningham, Tennessee',14175,50);
INSERT INTO "django_geo_db_city" VALUES(11164,'Dickson','Dickson, Tennessee',14176,50);
INSERT INTO "django_geo_db_city" VALUES(11165,'Dixon Springs','Dixon Springs, Tennessee',14178,50);
INSERT INTO "django_geo_db_city" VALUES(11166,'Dover','Dover, Tennessee',14179,50);
INSERT INTO "django_geo_db_city" VALUES(11167,'Dowelltown','Dowelltown, Tennessee',14180,50);
INSERT INTO "django_geo_db_city" VALUES(11168,'Eagleville','Eagleville, Tennessee',14181,50);
INSERT INTO "django_geo_db_city" VALUES(11169,'Erin','Erin, Tennessee',14182,50);
INSERT INTO "django_geo_db_city" VALUES(11170,'Fairview','Fairview, Tennessee',14183,50);
INSERT INTO "django_geo_db_city" VALUES(11171,'Fosterville','Fosterville, Tennessee',14184,50);
INSERT INTO "django_geo_db_city" VALUES(11172,'Franklin','Franklin, Tennessee',14185,50);
INSERT INTO "django_geo_db_city" VALUES(11173,'Gallatin','Gallatin, Tennessee',14187,50);
INSERT INTO "django_geo_db_city" VALUES(11174,'Goodlettsville','Goodlettsville, Tennessee',14190,50);
INSERT INTO "django_geo_db_city" VALUES(11175,'Gladeville','Gladeville, Tennessee',14191,50);
INSERT INTO "django_geo_db_city" VALUES(11176,'Greenbrier','Greenbrier, Tennessee',14193,50);
INSERT INTO "django_geo_db_city" VALUES(11177,'Hartsville','Hartsville, Tennessee',14194,50);
INSERT INTO "django_geo_db_city" VALUES(11178,'Hendersonville','Hendersonville, Tennessee',14195,50);
INSERT INTO "django_geo_db_city" VALUES(11179,'Hermitage','Hermitage, Tennessee',14196,50);
INSERT INTO "django_geo_db_city" VALUES(11180,'Hurricane Mills','Hurricane Mills, Tennessee',14198,50);
INSERT INTO "django_geo_db_city" VALUES(11181,'Indian Mound','Indian Mound, Tennessee',14199,50);
INSERT INTO "django_geo_db_city" VALUES(11182,'Joelton','Joelton, Tennessee',14200,50);
INSERT INTO "django_geo_db_city" VALUES(11183,'Kingston Springs','Kingston Springs, Tennessee',14201,50);
INSERT INTO "django_geo_db_city" VALUES(11184,'Lafayette','Lafayette, Tennessee',14202,50);
INSERT INTO "django_geo_db_city" VALUES(11185,'Lascassas','Lascassas, Tennessee',14203,50);
INSERT INTO "django_geo_db_city" VALUES(11186,'La Vergne','La Vergne, Tennessee',14204,50);
INSERT INTO "django_geo_db_city" VALUES(11187,'Lebanon','Lebanon, Tennessee',14205,50);
INSERT INTO "django_geo_db_city" VALUES(11188,'Lewisburg','Lewisburg, Tennessee',14207,50);
INSERT INTO "django_geo_db_city" VALUES(11189,'Liberty','Liberty, Tennessee',14208,50);
INSERT INTO "django_geo_db_city" VALUES(11190,'Linden','Linden, Tennessee',14209,50);
INSERT INTO "django_geo_db_city" VALUES(11191,'Lobelville','Lobelville, Tennessee',14210,50);
INSERT INTO "django_geo_db_city" VALUES(11192,'Lyles','Lyles, Tennessee',14211,50);
INSERT INTO "django_geo_db_city" VALUES(11193,'McEwen','McEwen, Tennessee',14212,50);
INSERT INTO "django_geo_db_city" VALUES(11194,'McMinnville','McMinnville, Tennessee',14213,50);
INSERT INTO "django_geo_db_city" VALUES(11195,'Madison','Madison, Tennessee',14215,50);
INSERT INTO "django_geo_db_city" VALUES(11196,'Milton','Milton, Tennessee',14216,50);
INSERT INTO "django_geo_db_city" VALUES(11197,'Mitchellville','Mitchellville, Tennessee',14217,50);
INSERT INTO "django_geo_db_city" VALUES(11198,'Mount Juliet','Mount Juliet, Tennessee',14191,50);
INSERT INTO "django_geo_db_city" VALUES(11199,'Murfreesboro','Murfreesboro, Tennessee',14219,50);
INSERT INTO "django_geo_db_city" VALUES(11200,'New Johnsonville','New Johnsonville, Tennessee',14223,50);
INSERT INTO "django_geo_db_city" VALUES(11201,'Nolensville','Nolensville, Tennessee',14224,50);
INSERT INTO "django_geo_db_city" VALUES(11202,'Norene','Norene, Tennessee',14191,50);
INSERT INTO "django_geo_db_city" VALUES(11203,'Nunnelly','Nunnelly, Tennessee',14225,50);
INSERT INTO "django_geo_db_city" VALUES(11204,'Old Hickory','Old Hickory, Tennessee',14226,50);
INSERT INTO "django_geo_db_city" VALUES(11205,'Only','Only, Tennessee',14227,50);
INSERT INTO "django_geo_db_city" VALUES(11206,'Orlinda','Orlinda, Tennessee',14228,50);
INSERT INTO "django_geo_db_city" VALUES(11207,'Palmyra','Palmyra, Tennessee',14229,50);
INSERT INTO "django_geo_db_city" VALUES(11208,'Pegram','Pegram, Tennessee',14230,50);
INSERT INTO "django_geo_db_city" VALUES(11209,'Petersburg','Petersburg, Tennessee',14231,50);
INSERT INTO "django_geo_db_city" VALUES(11210,'Pleasant Shade','Pleasant Shade, Tennessee',14232,50);
INSERT INTO "django_geo_db_city" VALUES(11211,'Pleasant View','Pleasant View, Tennessee',14233,50);
INSERT INTO "django_geo_db_city" VALUES(11212,'Pleasantville','Pleasantville, Tennessee',14234,50);
INSERT INTO "django_geo_db_city" VALUES(11213,'Portland','Portland, Tennessee',14235,50);
INSERT INTO "django_geo_db_city" VALUES(11214,'Readyville','Readyville, Tennessee',14236,50);
INSERT INTO "django_geo_db_city" VALUES(11215,'Red Boiling Springs','Red Boiling Springs, Tennessee',14237,50);
INSERT INTO "django_geo_db_city" VALUES(11216,'Riddleton','Riddleton, Tennessee',14238,50);
INSERT INTO "django_geo_db_city" VALUES(11217,'Ridgetop','Ridgetop, Tennessee',14239,50);
INSERT INTO "django_geo_db_city" VALUES(11218,'Rockvale','Rockvale, Tennessee',14240,50);
INSERT INTO "django_geo_db_city" VALUES(11219,'Saint Bethlehem','Saint Bethlehem, Tennessee',14165,50);
INSERT INTO "django_geo_db_city" VALUES(11220,'Shelbyville','Shelbyville, Tennessee',14241,50);
INSERT INTO "django_geo_db_city" VALUES(11221,'Slayden','Slayden, Tennessee',14244,50);
INSERT INTO "django_geo_db_city" VALUES(11222,'Smithville','Smithville, Tennessee',14245,50);
INSERT INTO "django_geo_db_city" VALUES(11223,'Smyrna','Smyrna, Tennessee',14246,50);
INSERT INTO "django_geo_db_city" VALUES(11224,'Southside','Southside, Tennessee',14247,50);
INSERT INTO "django_geo_db_city" VALUES(11225,'Springfield','Springfield, Tennessee',14248,50);
INSERT INTO "django_geo_db_city" VALUES(11226,'Spring Hill','Spring Hill, Tennessee',14249,50);
INSERT INTO "django_geo_db_city" VALUES(11227,'Stewart','Stewart, Tennessee',14250,50);
INSERT INTO "django_geo_db_city" VALUES(11228,'Tennessee Ridge','Tennessee Ridge, Tennessee',14251,50);
INSERT INTO "django_geo_db_city" VALUES(11229,'Thompsons Station','Thompsons Station, Tennessee',14252,50);
INSERT INTO "django_geo_db_city" VALUES(11230,'Unionville','Unionville, Tennessee',14253,50);
INSERT INTO "django_geo_db_city" VALUES(11231,'Vanleer','Vanleer, Tennessee',14254,50);
INSERT INTO "django_geo_db_city" VALUES(11232,'Wartrace','Wartrace, Tennessee',14255,50);
INSERT INTO "django_geo_db_city" VALUES(11233,'Watertown','Watertown, Tennessee',14256,50);
INSERT INTO "django_geo_db_city" VALUES(11234,'Waverly','Waverly, Tennessee',14257,50);
INSERT INTO "django_geo_db_city" VALUES(11235,'Westmoreland','Westmoreland, Tennessee',14258,50);
INSERT INTO "django_geo_db_city" VALUES(11236,'White Bluff','White Bluff, Tennessee',14259,50);
INSERT INTO "django_geo_db_city" VALUES(11237,'Whites Creek','Whites Creek, Tennessee',14261,50);
INSERT INTO "django_geo_db_city" VALUES(11238,'Woodbury','Woodbury, Tennessee',14262,50);
INSERT INTO "django_geo_db_city" VALUES(11239,'Woodlawn','Woodlawn, Tennessee',14263,50);
INSERT INTO "django_geo_db_city" VALUES(11240,'Nashville','Nashville, Tennessee',14264,50);
INSERT INTO "django_geo_db_city" VALUES(11241,'Altamont','Altamont, Tennessee',14289,50);
INSERT INTO "django_geo_db_city" VALUES(11242,'Apison','Apison, Tennessee',14290,50);
INSERT INTO "django_geo_db_city" VALUES(11243,'Athens','Athens, Tennessee',14291,50);
INSERT INTO "django_geo_db_city" VALUES(11244,'Bakewell','Bakewell, Tennessee',14292,50);
INSERT INTO "django_geo_db_city" VALUES(11245,'Beersheba Springs','Beersheba Springs, Tennessee',14293,50);
INSERT INTO "django_geo_db_city" VALUES(11246,'Belvidere','Belvidere, Tennessee',14294,50);
INSERT INTO "django_geo_db_city" VALUES(11247,'Benton','Benton, Tennessee',14295,50);
INSERT INTO "django_geo_db_city" VALUES(11248,'Birchwood','Birchwood, Tennessee',14296,50);
INSERT INTO "django_geo_db_city" VALUES(11249,'Calhoun','Calhoun, Tennessee',14297,50);
INSERT INTO "django_geo_db_city" VALUES(11250,'Charleston','Charleston, Tennessee',14298,50);
INSERT INTO "django_geo_db_city" VALUES(11251,'Cleveland','Cleveland, Tennessee',14299,50);
INSERT INTO "django_geo_db_city" VALUES(11252,'Coalmont','Coalmont, Tennessee',14301,50);
INSERT INTO "django_geo_db_city" VALUES(11253,'Cokercreek','Cokercreek, Tennessee',14302,50);
INSERT INTO "django_geo_db_city" VALUES(11254,'Collegedale','Collegedale, Tennessee',14303,50);
INSERT INTO "django_geo_db_city" VALUES(11255,'Conasauga','Conasauga, Tennessee',14304,50);
INSERT INTO "django_geo_db_city" VALUES(11256,'Copperhill','Copperhill, Tennessee',14305,50);
INSERT INTO "django_geo_db_city" VALUES(11257,'Cowan','Cowan, Tennessee',14306,50);
INSERT INTO "django_geo_db_city" VALUES(11258,'Dayton','Dayton, Tennessee',14308,50);
INSERT INTO "django_geo_db_city" VALUES(11259,'Decatur','Decatur, Tennessee',14309,50);
INSERT INTO "django_geo_db_city" VALUES(11260,'Decherd','Decherd, Tennessee',14311,50);
INSERT INTO "django_geo_db_city" VALUES(11261,'Delano','Delano, Tennessee',14312,50);
INSERT INTO "django_geo_db_city" VALUES(11262,'Ducktown','Ducktown, Tennessee',14313,50);
INSERT INTO "django_geo_db_city" VALUES(11263,'Dunlap','Dunlap, Tennessee',14314,50);
INSERT INTO "django_geo_db_city" VALUES(11264,'Elora','Elora, Tennessee',14315,50);
INSERT INTO "django_geo_db_city" VALUES(11265,'Englewood','Englewood, Tennessee',14316,50);
INSERT INTO "django_geo_db_city" VALUES(11266,'Estill Springs','Estill Springs, Tennessee',14317,50);
INSERT INTO "django_geo_db_city" VALUES(11267,'Etowah','Etowah, Tennessee',14318,50);
INSERT INTO "django_geo_db_city" VALUES(11268,'Evensville','Evensville, Tennessee',14319,50);
INSERT INTO "django_geo_db_city" VALUES(11269,'Farner','Farner, Tennessee',14320,50);
INSERT INTO "django_geo_db_city" VALUES(11270,'Fayetteville','Fayetteville, Tennessee',14321,50);
INSERT INTO "django_geo_db_city" VALUES(11271,'Flintville','Flintville, Tennessee',14322,50);
INSERT INTO "django_geo_db_city" VALUES(11272,'Georgetown','Georgetown, Tennessee',14323,50);
INSERT INTO "django_geo_db_city" VALUES(11273,'Grandview','Grandview, Tennessee',14324,50);
INSERT INTO "django_geo_db_city" VALUES(11274,'Graysville','Graysville, Tennessee',14325,50);
INSERT INTO "django_geo_db_city" VALUES(11275,'Gruetli Laager','Gruetli Laager, Tennessee',14326,50);
INSERT INTO "django_geo_db_city" VALUES(11276,'Guild','Guild, Tennessee',14327,50);
INSERT INTO "django_geo_db_city" VALUES(11277,'Harrison','Harrison, Tennessee',14328,50);
INSERT INTO "django_geo_db_city" VALUES(11278,'Hillsboro','Hillsboro, Tennessee',14329,50);
INSERT INTO "django_geo_db_city" VALUES(11279,'Hixson','Hixson, Tennessee',14330,50);
INSERT INTO "django_geo_db_city" VALUES(11280,'Huntland','Huntland, Tennessee',14331,50);
INSERT INTO "django_geo_db_city" VALUES(11281,'Jasper','Jasper, Tennessee',14332,50);
INSERT INTO "django_geo_db_city" VALUES(11282,'Kelso','Kelso, Tennessee',14333,50);
INSERT INTO "django_geo_db_city" VALUES(11283,'Manchester','Manchester, Tennessee',14334,50);
INSERT INTO "django_geo_db_city" VALUES(11284,'Lookout Mountain','Lookout Mountain, Tennessee',14335,50);
INSERT INTO "django_geo_db_city" VALUES(11285,'Lupton City','Lupton City, Tennessee',14336,50);
INSERT INTO "django_geo_db_city" VALUES(11286,'Lynchburg','Lynchburg, Tennessee',14337,50);
INSERT INTO "django_geo_db_city" VALUES(11287,'McDonald','McDonald, Tennessee',14338,50);
INSERT INTO "django_geo_db_city" VALUES(11288,'Madisonville','Madisonville, Tennessee',14339,50);
INSERT INTO "django_geo_db_city" VALUES(11289,'Monteagle','Monteagle, Tennessee',14341,50);
INSERT INTO "django_geo_db_city" VALUES(11290,'Morrison','Morrison, Tennessee',14342,50);
INSERT INTO "django_geo_db_city" VALUES(11291,'Mulberry','Mulberry, Tennessee',14343,50);
INSERT INTO "django_geo_db_city" VALUES(11292,'Normandy','Normandy, Tennessee',14344,50);
INSERT INTO "django_geo_db_city" VALUES(11293,'Ocoee','Ocoee, Tennessee',14345,50);
INSERT INTO "django_geo_db_city" VALUES(11294,'Oldfort','Oldfort, Tennessee',14346,50);
INSERT INTO "django_geo_db_city" VALUES(11295,'Ooltewah','Ooltewah, Tennessee',14347,50);
INSERT INTO "django_geo_db_city" VALUES(11296,'Palmer','Palmer, Tennessee',14348,50);
INSERT INTO "django_geo_db_city" VALUES(11297,'Pelham','Pelham, Tennessee',14349,50);
INSERT INTO "django_geo_db_city" VALUES(11298,'Pikeville','Pikeville, Tennessee',14350,50);
INSERT INTO "django_geo_db_city" VALUES(11299,'Reliance','Reliance, Tennessee',14351,50);
INSERT INTO "django_geo_db_city" VALUES(11300,'Riceville','Riceville, Tennessee',14352,50);
INSERT INTO "django_geo_db_city" VALUES(11301,'Saint Andrews','Saint Andrews, Tennessee',14354,50);
INSERT INTO "django_geo_db_city" VALUES(11302,'Sale Creek','Sale Creek, Tennessee',14355,50);
INSERT INTO "django_geo_db_city" VALUES(11303,'Sequatchie','Sequatchie, Tennessee',14356,50);
INSERT INTO "django_geo_db_city" VALUES(11304,'Sewanee','Sewanee, Tennessee',14357,50);
INSERT INTO "django_geo_db_city" VALUES(11305,'Sherwood','Sherwood, Tennessee',14358,50);
INSERT INTO "django_geo_db_city" VALUES(11306,'Signal Mountain','Signal Mountain, Tennessee',14359,50);
INSERT INTO "django_geo_db_city" VALUES(11307,'Smartt','Smartt, Tennessee',14214,50);
INSERT INTO "django_geo_db_city" VALUES(11308,'Soddy Daisy','Soddy Daisy, Tennessee',14360,50);
INSERT INTO "django_geo_db_city" VALUES(11309,'South Pittsburg','South Pittsburg, Tennessee',14361,50);
INSERT INTO "django_geo_db_city" VALUES(11310,'Spring City','Spring City, Tennessee',14362,50);
INSERT INTO "django_geo_db_city" VALUES(11311,'Summitville','Summitville, Tennessee',14334,50);
INSERT INTO "django_geo_db_city" VALUES(11312,'Tellico Plains','Tellico Plains, Tennessee',14365,50);
INSERT INTO "django_geo_db_city" VALUES(11313,'Tracy City','Tracy City, Tennessee',14366,50);
INSERT INTO "django_geo_db_city" VALUES(11314,'Tullahoma','Tullahoma, Tennessee',14367,50);
INSERT INTO "django_geo_db_city" VALUES(11315,'Arnold AFB','Arnold AFB, Tennessee',14334,50);
INSERT INTO "django_geo_db_city" VALUES(11316,'Turtletown','Turtletown, Tennessee',14368,50);
INSERT INTO "django_geo_db_city" VALUES(11317,'Viola','Viola, Tennessee',14369,50);
INSERT INTO "django_geo_db_city" VALUES(11318,'Watts Bar Dam','Watts Bar Dam, Tennessee',14370,50);
INSERT INTO "django_geo_db_city" VALUES(11319,'Whiteside','Whiteside, Tennessee',14371,50);
INSERT INTO "django_geo_db_city" VALUES(11320,'Whitwell','Whitwell, Tennessee',14372,50);
INSERT INTO "django_geo_db_city" VALUES(11321,'Winchester','Winchester, Tennessee',14373,50);
INSERT INTO "django_geo_db_city" VALUES(11322,'Chattanooga','Chattanooga, Tennessee',14374,50);
INSERT INTO "django_geo_db_city" VALUES(11323,'Memphis','Memphis, Tennessee',14390,50);
INSERT INTO "django_geo_db_city" VALUES(11324,'Johnson City','Johnson City, Tennessee',14391,50);
INSERT INTO "django_geo_db_city" VALUES(11325,'Afton','Afton, Tennessee',14397,50);
INSERT INTO "django_geo_db_city" VALUES(11326,'Blountville','Blountville, Tennessee',14398,50);
INSERT INTO "django_geo_db_city" VALUES(11327,'Bluff City','Bluff City, Tennessee',14399,50);
INSERT INTO "django_geo_db_city" VALUES(11328,'Bristol','Bristol, Tennessee',14400,50);
INSERT INTO "django_geo_db_city" VALUES(11329,'Butler','Butler, Tennessee',14402,50);
INSERT INTO "django_geo_db_city" VALUES(11330,'Chuckey','Chuckey, Tennessee',14403,50);
INSERT INTO "django_geo_db_city" VALUES(11331,'Church Hill','Church Hill, Tennessee',14404,50);
INSERT INTO "django_geo_db_city" VALUES(11332,'Elizabethton','Elizabethton, Tennessee',14405,50);
INSERT INTO "django_geo_db_city" VALUES(11333,'Mount Carmel','Mount Carmel, Tennessee',14407,50);
INSERT INTO "django_geo_db_city" VALUES(11334,'Erwin','Erwin, Tennessee',14408,50);
INSERT INTO "django_geo_db_city" VALUES(11335,'Fall Branch','Fall Branch, Tennessee',14409,50);
INSERT INTO "django_geo_db_city" VALUES(11336,'Flag Pond','Flag Pond, Tennessee',14410,50);
INSERT INTO "django_geo_db_city" VALUES(11337,'Hampton','Hampton, Tennessee',14411,50);
INSERT INTO "django_geo_db_city" VALUES(11338,'Jonesborough','Jonesborough, Tennessee',14412,50);
INSERT INTO "django_geo_db_city" VALUES(11339,'Kingsport','Kingsport, Tennessee',14413,50);
INSERT INTO "django_geo_db_city" VALUES(11340,'Laurel Bloomery','Laurel Bloomery, Tennessee',14418,50);
INSERT INTO "django_geo_db_city" VALUES(11341,'Limestone','Limestone, Tennessee',14419,50);
INSERT INTO "django_geo_db_city" VALUES(11342,'Milligan College','Milligan College, Tennessee',14420,50);
INSERT INTO "django_geo_db_city" VALUES(11343,'Mountain City','Mountain City, Tennessee',14421,50);
INSERT INTO "django_geo_db_city" VALUES(11344,'Mountain Home','Mountain Home, Tennessee',14422,50);
INSERT INTO "django_geo_db_city" VALUES(11345,'Piney Flats','Piney Flats, Tennessee',14423,50);
INSERT INTO "django_geo_db_city" VALUES(11346,'Roan Mountain','Roan Mountain, Tennessee',14424,50);
INSERT INTO "django_geo_db_city" VALUES(11347,'Shady Valley','Shady Valley, Tennessee',14425,50);
INSERT INTO "django_geo_db_city" VALUES(11348,'Telford','Telford, Tennessee',14426,50);
INSERT INTO "django_geo_db_city" VALUES(11349,'Trade','Trade, Tennessee',14427,50);
INSERT INTO "django_geo_db_city" VALUES(11350,'Unicoi','Unicoi, Tennessee',14428,50);
INSERT INTO "django_geo_db_city" VALUES(11351,'Watauga','Watauga, Tennessee',14429,50);
INSERT INTO "django_geo_db_city" VALUES(11352,'Alcoa','Alcoa, Tennessee',14430,50);
INSERT INTO "django_geo_db_city" VALUES(11353,'Andersonville','Andersonville, Tennessee',14431,50);
INSERT INTO "django_geo_db_city" VALUES(11354,'Arthur','Arthur, Tennessee',14432,50);
INSERT INTO "django_geo_db_city" VALUES(11355,'Bean Station','Bean Station, Tennessee',14433,50);
INSERT INTO "django_geo_db_city" VALUES(11356,'Blaine','Blaine, Tennessee',14434,50);
INSERT INTO "django_geo_db_city" VALUES(11357,'Briceville','Briceville, Tennessee',14435,50);
INSERT INTO "django_geo_db_city" VALUES(11358,'Bulls Gap','Bulls Gap, Tennessee',14436,50);
INSERT INTO "django_geo_db_city" VALUES(11359,'Bybee','Bybee, Tennessee',14437,50);
INSERT INTO "django_geo_db_city" VALUES(11360,'Caryville','Caryville, Tennessee',14438,50);
INSERT INTO "django_geo_db_city" VALUES(11361,'Clairfield','Clairfield, Tennessee',14439,50);
INSERT INTO "django_geo_db_city" VALUES(11362,'Clinton','Clinton, Tennessee',14440,50);
INSERT INTO "django_geo_db_city" VALUES(11363,'Coalfield','Coalfield, Tennessee',14442,50);
INSERT INTO "django_geo_db_city" VALUES(11364,'Corryton','Corryton, Tennessee',14443,50);
INSERT INTO "django_geo_db_city" VALUES(11365,'Cosby','Cosby, Tennessee',14444,50);
INSERT INTO "django_geo_db_city" VALUES(11366,'Crab Orchard','Crab Orchard, Tennessee',14445,50);
INSERT INTO "django_geo_db_city" VALUES(11367,'Cumberland Gap','Cumberland Gap, Tennessee',14446,50);
INSERT INTO "django_geo_db_city" VALUES(11368,'Dandridge','Dandridge, Tennessee',14447,50);
INSERT INTO "django_geo_db_city" VALUES(11369,'Deer Lodge','Deer Lodge, Tennessee',14448,50);
INSERT INTO "django_geo_db_city" VALUES(11370,'Del Rio','Del Rio, Tennessee',14449,50);
INSERT INTO "django_geo_db_city" VALUES(11371,'Duff','Duff, Tennessee',14450,50);
INSERT INTO "django_geo_db_city" VALUES(11372,'Eagan','Eagan, Tennessee',14451,50);
INSERT INTO "django_geo_db_city" VALUES(11373,'Eidson','Eidson, Tennessee',14452,50);
INSERT INTO "django_geo_db_city" VALUES(11374,'Elgin','Elgin, Tennessee',14453,50);
INSERT INTO "django_geo_db_city" VALUES(11375,'Rugby','Rugby, Tennessee',14454,50);
INSERT INTO "django_geo_db_city" VALUES(11376,'Friendsville','Friendsville, Tennessee',14455,50);
INSERT INTO "django_geo_db_city" VALUES(11377,'Gatlinburg','Gatlinburg, Tennessee',14456,50);
INSERT INTO "django_geo_db_city" VALUES(11378,'Greenback','Greenback, Tennessee',14457,50);
INSERT INTO "django_geo_db_city" VALUES(11379,'Greeneville','Greeneville, Tennessee',14458,50);
INSERT INTO "django_geo_db_city" VALUES(11380,'Harriman','Harriman, Tennessee',14461,50);
INSERT INTO "django_geo_db_city" VALUES(11381,'Harrogate','Harrogate, Tennessee',14462,50);
INSERT INTO "django_geo_db_city" VALUES(11382,'Hartford','Hartford, Tennessee',14463,50);
INSERT INTO "django_geo_db_city" VALUES(11383,'Heiskell','Heiskell, Tennessee',14464,50);
INSERT INTO "django_geo_db_city" VALUES(11384,'Helenwood','Helenwood, Tennessee',14465,50);
INSERT INTO "django_geo_db_city" VALUES(11385,'Huntsville','Huntsville, Tennessee',14466,50);
INSERT INTO "django_geo_db_city" VALUES(11386,'Jacksboro','Jacksboro, Tennessee',14467,50);
INSERT INTO "django_geo_db_city" VALUES(11387,'Jefferson City','Jefferson City, Tennessee',14468,50);
INSERT INTO "django_geo_db_city" VALUES(11388,'Jellico','Jellico, Tennessee',14469,50);
INSERT INTO "django_geo_db_city" VALUES(11389,'Kingston','Kingston, Tennessee',14470,50);
INSERT INTO "django_geo_db_city" VALUES(11390,'Kodak','Kodak, Tennessee',14471,50);
INSERT INTO "django_geo_db_city" VALUES(11391,'Kyles Ford','Kyles Ford, Tennessee',14472,50);
INSERT INTO "django_geo_db_city" VALUES(11392,'La Follette','La Follette, Tennessee',14473,50);
INSERT INTO "django_geo_db_city" VALUES(11393,'Lake City','Lake City, Tennessee',14474,50);
INSERT INTO "django_geo_db_city" VALUES(11394,'Lancing','Lancing, Tennessee',14475,50);
INSERT INTO "django_geo_db_city" VALUES(11395,'Lenoir City','Lenoir City, Tennessee',14476,50);
INSERT INTO "django_geo_db_city" VALUES(11396,'Lone Mountain','Lone Mountain, Tennessee',14478,50);
INSERT INTO "django_geo_db_city" VALUES(11397,'Loudon','Loudon, Tennessee',14479,50);
INSERT INTO "django_geo_db_city" VALUES(11398,'Louisville','Louisville, Tennessee',14480,50);
INSERT INTO "django_geo_db_city" VALUES(11399,'Lowland','Lowland, Tennessee',14481,50);
INSERT INTO "django_geo_db_city" VALUES(11400,'Luttrell','Luttrell, Tennessee',14482,50);
INSERT INTO "django_geo_db_city" VALUES(11401,'Maryville','Maryville, Tennessee',14483,50);
INSERT INTO "django_geo_db_city" VALUES(11402,'Mascot','Mascot, Tennessee',14487,50);
INSERT INTO "django_geo_db_city" VALUES(11403,'Maynardville','Maynardville, Tennessee',14488,50);
INSERT INTO "django_geo_db_city" VALUES(11404,'Midway','Midway, Tennessee',14489,50);
INSERT INTO "django_geo_db_city" VALUES(11405,'Mohawk','Mohawk, Tennessee',14490,50);
INSERT INTO "django_geo_db_city" VALUES(11406,'Mooresburg','Mooresburg, Tennessee',14491,50);
INSERT INTO "django_geo_db_city" VALUES(11407,'Morristown','Morristown, Tennessee',14492,50);
INSERT INTO "django_geo_db_city" VALUES(11408,'Mosheim','Mosheim, Tennessee',14494,50);
INSERT INTO "django_geo_db_city" VALUES(11409,'Newcomb','Newcomb, Tennessee',14495,50);
INSERT INTO "django_geo_db_city" VALUES(11410,'New Market','New Market, Tennessee',14496,50);
INSERT INTO "django_geo_db_city" VALUES(11411,'Newport','Newport, Tennessee',14497,50);
INSERT INTO "django_geo_db_city" VALUES(11412,'New Tazewell','New Tazewell, Tennessee',14499,50);
INSERT INTO "django_geo_db_city" VALUES(11413,'Niota','Niota, Tennessee',14501,50);
INSERT INTO "django_geo_db_city" VALUES(11414,'Norris','Norris, Tennessee',14502,50);
INSERT INTO "django_geo_db_city" VALUES(11415,'Oakdale','Oakdale, Tennessee',14503,50);
INSERT INTO "django_geo_db_city" VALUES(11416,'Oak Ridge','Oak Ridge, Tennessee',14504,50);
INSERT INTO "django_geo_db_city" VALUES(11417,'Oliver Springs','Oliver Springs, Tennessee',14507,50);
INSERT INTO "django_geo_db_city" VALUES(11418,'Oneida','Oneida, Tennessee',14508,50);
INSERT INTO "django_geo_db_city" VALUES(11419,'Ozone','Ozone, Tennessee',14509,50);
INSERT INTO "django_geo_db_city" VALUES(11420,'Parrottsville','Parrottsville, Tennessee',14510,50);
INSERT INTO "django_geo_db_city" VALUES(11421,'Petros','Petros, Tennessee',14511,50);
INSERT INTO "django_geo_db_city" VALUES(11422,'Philadelphia','Philadelphia, Tennessee',14512,50);
INSERT INTO "django_geo_db_city" VALUES(11423,'Pioneer','Pioneer, Tennessee',14513,50);
INSERT INTO "django_geo_db_city" VALUES(11424,'Powder Springs','Powder Springs, Tennessee',14514,50);
INSERT INTO "django_geo_db_city" VALUES(11425,'Powell','Powell, Tennessee',14515,50);
INSERT INTO "django_geo_db_city" VALUES(11426,'Pruden','Pruden, Tennessee',14516,50);
INSERT INTO "django_geo_db_city" VALUES(11427,'Robbins','Robbins, Tennessee',14517,50);
INSERT INTO "django_geo_db_city" VALUES(11428,'Rockford','Rockford, Tennessee',14518,50);
INSERT INTO "django_geo_db_city" VALUES(11429,'Rockwood','Rockwood, Tennessee',14519,50);
INSERT INTO "django_geo_db_city" VALUES(11430,'Rogersville','Rogersville, Tennessee',14520,50);
INSERT INTO "django_geo_db_city" VALUES(11431,'Russellville','Russellville, Tennessee',14521,50);
INSERT INTO "django_geo_db_city" VALUES(11432,'Rutledge','Rutledge, Tennessee',14522,50);
INSERT INTO "django_geo_db_city" VALUES(11433,'Sevierville','Sevierville, Tennessee',14523,50);
INSERT INTO "django_geo_db_city" VALUES(11434,'Pigeon Forge','Pigeon Forge, Tennessee',14524,50);
INSERT INTO "django_geo_db_city" VALUES(11435,'Seymour','Seymour, Tennessee',14526,50);
INSERT INTO "django_geo_db_city" VALUES(11436,'Sharps Chapel','Sharps Chapel, Tennessee',14527,50);
INSERT INTO "django_geo_db_city" VALUES(11437,'Shawanee','Shawanee, Tennessee',14528,50);
INSERT INTO "django_geo_db_city" VALUES(11438,'Sneedville','Sneedville, Tennessee',14530,50);
INSERT INTO "django_geo_db_city" VALUES(11439,'Speedwell','Speedwell, Tennessee',14531,50);
INSERT INTO "django_geo_db_city" VALUES(11440,'Strawberry Plains','Strawberry Plains, Tennessee',14532,50);
INSERT INTO "django_geo_db_city" VALUES(11441,'Sunbright','Sunbright, Tennessee',14533,50);
INSERT INTO "django_geo_db_city" VALUES(11442,'Surgoinsville','Surgoinsville, Tennessee',14534,50);
INSERT INTO "django_geo_db_city" VALUES(11443,'Sweetwater','Sweetwater, Tennessee',14535,50);
INSERT INTO "django_geo_db_city" VALUES(11444,'Talbott','Talbott, Tennessee',14537,50);
INSERT INTO "django_geo_db_city" VALUES(11445,'Tallassee','Tallassee, Tennessee',14538,50);
INSERT INTO "django_geo_db_city" VALUES(11446,'Tazewell','Tazewell, Tennessee',14539,50);
INSERT INTO "django_geo_db_city" VALUES(11447,'Ten Mile','Ten Mile, Tennessee',14540,50);
INSERT INTO "django_geo_db_city" VALUES(11448,'Thorn Hill','Thorn Hill, Tennessee',14541,50);
INSERT INTO "django_geo_db_city" VALUES(11449,'Townsend','Townsend, Tennessee',14542,50);
INSERT INTO "django_geo_db_city" VALUES(11450,'Vonore','Vonore, Tennessee',14543,50);
INSERT INTO "django_geo_db_city" VALUES(11451,'Walland','Walland, Tennessee',14544,50);
INSERT INTO "django_geo_db_city" VALUES(11452,'Wartburg','Wartburg, Tennessee',14545,50);
INSERT INTO "django_geo_db_city" VALUES(11453,'Washburn','Washburn, Tennessee',14546,50);
INSERT INTO "django_geo_db_city" VALUES(11454,'White Pine','White Pine, Tennessee',14547,50);
INSERT INTO "django_geo_db_city" VALUES(11455,'Whitesburg','Whitesburg, Tennessee',14548,50);
INSERT INTO "django_geo_db_city" VALUES(11456,'Winfield','Winfield, Tennessee',14549,50);
INSERT INTO "django_geo_db_city" VALUES(11457,'Winona','Winona, Tennessee',14550,50);
INSERT INTO "django_geo_db_city" VALUES(11458,'Knoxville','Knoxville, Tennessee',14551,50);
INSERT INTO "django_geo_db_city" VALUES(11459,'Powells Crossroads','Powells Crossroads, Tennessee',14572,50);
INSERT INTO "django_geo_db_city" VALUES(11460,'Alamo','Alamo, Tennessee',14576,50);
INSERT INTO "django_geo_db_city" VALUES(11461,'Arlington','Arlington, Tennessee',14577,50);
INSERT INTO "django_geo_db_city" VALUES(11462,'Atoka','Atoka, Tennessee',14578,50);
INSERT INTO "django_geo_db_city" VALUES(11463,'Bells','Bells, Tennessee',14579,50);
INSERT INTO "django_geo_db_city" VALUES(11464,'Bogota','Bogota, Tennessee',14580,50);
INSERT INTO "django_geo_db_city" VALUES(11465,'Bolivar','Bolivar, Tennessee',14581,50);
INSERT INTO "django_geo_db_city" VALUES(11466,'Braden','Braden, Tennessee',14582,50);
INSERT INTO "django_geo_db_city" VALUES(11467,'Brighton','Brighton, Tennessee',14583,50);
INSERT INTO "django_geo_db_city" VALUES(11468,'Brownsville','Brownsville, Tennessee',14584,50);
INSERT INTO "django_geo_db_city" VALUES(11469,'Brunswick','Brunswick, Tennessee',14585,50);
INSERT INTO "django_geo_db_city" VALUES(11470,'Burlison','Burlison, Tennessee',14586,50);
INSERT INTO "django_geo_db_city" VALUES(11471,'Collierville','Collierville, Tennessee',14588,50);
INSERT INTO "django_geo_db_city" VALUES(11472,'Cordova','Cordova, Tennessee',14589,50);
INSERT INTO "django_geo_db_city" VALUES(11473,'Covington','Covington, Tennessee',14590,50);
INSERT INTO "django_geo_db_city" VALUES(11474,'Crockett Mills','Crockett Mills, Tennessee',14591,50);
INSERT INTO "django_geo_db_city" VALUES(11475,'Drummonds','Drummonds, Tennessee',14592,50);
INSERT INTO "django_geo_db_city" VALUES(11476,'Dyersburg','Dyersburg, Tennessee',14593,50);
INSERT INTO "django_geo_db_city" VALUES(11477,'Eads','Eads, Tennessee',14596,50);
INSERT INTO "django_geo_db_city" VALUES(11478,'Ellendale','Ellendale, Tennessee',14585,50);
INSERT INTO "django_geo_db_city" VALUES(11479,'Finley','Finley, Tennessee',14597,50);
INSERT INTO "django_geo_db_city" VALUES(11480,'Friendship','Friendship, Tennessee',14598,50);
INSERT INTO "django_geo_db_city" VALUES(11481,'Gallaway','Gallaway, Tennessee',14599,50);
INSERT INTO "django_geo_db_city" VALUES(11482,'Gates','Gates, Tennessee',14600,50);
INSERT INTO "django_geo_db_city" VALUES(11483,'Grand Junction','Grand Junction, Tennessee',14601,50);
INSERT INTO "django_geo_db_city" VALUES(11484,'Halls','Halls, Tennessee',14602,50);
INSERT INTO "django_geo_db_city" VALUES(11485,'Henning','Henning, Arkansas',14603,4);
INSERT INTO "django_geo_db_city" VALUES(11486,'Hickory Valley','Hickory Valley, Tennessee',14604,50);
INSERT INTO "django_geo_db_city" VALUES(11487,'Hickory Withe','Hickory Withe, Tennessee',14605,50);
INSERT INTO "django_geo_db_city" VALUES(11488,'Hornsby','Hornsby, Tennessee',14606,50);
INSERT INTO "django_geo_db_city" VALUES(11489,'Laconia','Laconia, Tennessee',14607,50);
INSERT INTO "django_geo_db_city" VALUES(11490,'La Grange','La Grange, Tennessee',14608,50);
INSERT INTO "django_geo_db_city" VALUES(11491,'Lenox','Lenox, Tennessee',14609,50);
INSERT INTO "django_geo_db_city" VALUES(11492,'Macon','Macon, Tennessee',14610,50);
INSERT INTO "django_geo_db_city" VALUES(11493,'Mason','Mason, Tennessee',14611,50);
INSERT INTO "django_geo_db_city" VALUES(11494,'Maury City','Maury City, Tennessee',14612,50);
INSERT INTO "django_geo_db_city" VALUES(11495,'Middleton','Middleton, Tennessee',14613,50);
INSERT INTO "django_geo_db_city" VALUES(11496,'Millington','Millington, Tennessee',14614,50);
INSERT INTO "django_geo_db_city" VALUES(11497,'Miston','Miston, Tennessee',14594,50);
INSERT INTO "django_geo_db_city" VALUES(11498,'Moscow','Moscow, Tennessee',14616,50);
INSERT INTO "django_geo_db_city" VALUES(11499,'Munford','Munford, Tennessee',14617,50);
INSERT INTO "django_geo_db_city" VALUES(11500,'Newbern','Newbern, Tennessee',14618,50);
INSERT INTO "django_geo_db_city" VALUES(11501,'Oakland','Oakland, Tennessee',14619,50);
INSERT INTO "django_geo_db_city" VALUES(11502,'Pocahontas','Pocahontas, Tennessee',14620,50);
INSERT INTO "django_geo_db_city" VALUES(11503,'Ripley','Ripley, Arkansas',14621,4);
INSERT INTO "django_geo_db_city" VALUES(11504,'Rossville','Rossville, Tennessee',14622,50);
INSERT INTO "django_geo_db_city" VALUES(11505,'Saulsbury','Saulsbury, Tennessee',14623,50);
INSERT INTO "django_geo_db_city" VALUES(11506,'Somerville','Somerville, Tennessee',14624,50);
INSERT INTO "django_geo_db_city" VALUES(11507,'Stanton','Stanton, Tennessee',14625,50);
INSERT INTO "django_geo_db_city" VALUES(11508,'Tigrett','Tigrett, Tennessee',14626,50);
INSERT INTO "django_geo_db_city" VALUES(11509,'Tipton','Tipton, Tennessee',14627,50);
INSERT INTO "django_geo_db_city" VALUES(11510,'Whiteville','Whiteville, Tennessee',14630,50);
INSERT INTO "django_geo_db_city" VALUES(11511,'Williston','Williston, Tennessee',14631,50);
INSERT INTO "django_geo_db_city" VALUES(11512,'Wynnburg','Wynnburg, Tennessee',14632,50);
INSERT INTO "django_geo_db_city" VALUES(11513,'Tiptonville','Tiptonville, Kentucky',14633,21);
INSERT INTO "django_geo_db_city" VALUES(11514,'Ridgely','Ridgely, Tennessee',14634,50);
INSERT INTO "django_geo_db_city" VALUES(11515,'Germantown','Germantown, Tennessee',14663,50);
INSERT INTO "django_geo_db_city" VALUES(11516,'Metcalfe','Metcalfe, Mississippi',14667,42);
INSERT INTO "django_geo_db_city" VALUES(11517,'McKenzie','McKenzie, Tennessee',14668,50);
INSERT INTO "django_geo_db_city" VALUES(11518,'Atwood','Atwood, Tennessee',14669,50);
INSERT INTO "django_geo_db_city" VALUES(11519,'Big Sandy','Big Sandy, Tennessee',14670,50);
INSERT INTO "django_geo_db_city" VALUES(11520,'Buchanan','Buchanan, Tennessee',14671,50);
INSERT INTO "django_geo_db_city" VALUES(11521,'Como','Como, Tennessee',14672,50);
INSERT INTO "django_geo_db_city" VALUES(11522,'Cottage Grove','Cottage Grove, Tennessee',14673,50);
INSERT INTO "django_geo_db_city" VALUES(11523,'Dresden','Dresden, Tennessee',14674,50);
INSERT INTO "django_geo_db_city" VALUES(11524,'Dukedom','Dukedom, Tennessee',14675,50);
INSERT INTO "django_geo_db_city" VALUES(11525,'Gleason','Gleason, Tennessee',14676,50);
INSERT INTO "django_geo_db_city" VALUES(11526,'Greenfield','Greenfield, Tennessee',14677,50);
INSERT INTO "django_geo_db_city" VALUES(11527,'Henry','Henry, Tennessee',14678,50);
INSERT INTO "django_geo_db_city" VALUES(11528,'Hornbeak','Hornbeak, Tennessee',14679,50);
INSERT INTO "django_geo_db_city" VALUES(11529,'Kenton','Kenton, Tennessee',14680,50);
INSERT INTO "django_geo_db_city" VALUES(11530,'McLemoresville','McLemoresville, Tennessee',14681,50);
INSERT INTO "django_geo_db_city" VALUES(11531,'Mansfield','Mansfield, Tennessee',14682,50);
INSERT INTO "django_geo_db_city" VALUES(11532,'Martin','Martin, Tennessee',14683,50);
INSERT INTO "django_geo_db_city" VALUES(11533,'Obion','Obion, Tennessee',14685,50);
INSERT INTO "django_geo_db_city" VALUES(11534,'Palmersville','Palmersville, Tennessee',14686,50);
INSERT INTO "django_geo_db_city" VALUES(11535,'Paris','Paris, Tennessee',14687,50);
INSERT INTO "django_geo_db_city" VALUES(11536,'Puryear','Puryear, Tennessee',14688,50);
INSERT INTO "django_geo_db_city" VALUES(11537,'Rives','Rives, Tennessee',14689,50);
INSERT INTO "django_geo_db_city" VALUES(11538,'Samburg','Samburg, Tennessee',14690,50);
INSERT INTO "django_geo_db_city" VALUES(11539,'Sharon','Sharon, Tennessee',14691,50);
INSERT INTO "django_geo_db_city" VALUES(11540,'Springville','Springville, Tennessee',14692,50);
INSERT INTO "django_geo_db_city" VALUES(11541,'South Fulton','South Fulton, Tennessee',14693,50);
INSERT INTO "django_geo_db_city" VALUES(11542,'Trezevant','Trezevant, Tennessee',14694,50);
INSERT INTO "django_geo_db_city" VALUES(11543,'Trimble','Trimble, Tennessee',14695,50);
INSERT INTO "django_geo_db_city" VALUES(11544,'Troy','Troy, Tennessee',14696,50);
INSERT INTO "django_geo_db_city" VALUES(11545,'Union City','Union City, Tennessee',14697,50);
INSERT INTO "django_geo_db_city" VALUES(11546,'Woodland Mills','Woodland Mills, Tennessee',14698,50);
INSERT INTO "django_geo_db_city" VALUES(11547,'Jackson','Jackson, Tennessee',14700,50);
INSERT INTO "django_geo_db_city" VALUES(11548,'Adamsville','Adamsville, Tennessee',14703,50);
INSERT INTO "django_geo_db_city" VALUES(11549,'Bath Springs','Bath Springs, Tennessee',14704,50);
INSERT INTO "django_geo_db_city" VALUES(11550,'Beech Bluff','Beech Bluff, Tennessee',14705,50);
INSERT INTO "django_geo_db_city" VALUES(11551,'Bethel Springs','Bethel Springs, Tennessee',14706,50);
INSERT INTO "django_geo_db_city" VALUES(11552,'Bradford','Bradford, Tennessee',14707,50);
INSERT INTO "django_geo_db_city" VALUES(11553,'Bruceton','Bruceton, Tennessee',14708,50);
INSERT INTO "django_geo_db_city" VALUES(11554,'Buena Vista','Buena Vista, Tennessee',14709,50);
INSERT INTO "django_geo_db_city" VALUES(11555,'Camden','Camden, Tennessee',14710,50);
INSERT INTO "django_geo_db_city" VALUES(11556,'Cedar Grove','Cedar Grove, Tennessee',14711,50);
INSERT INTO "django_geo_db_city" VALUES(11557,'Clarksburg','Clarksburg, Tennessee',14712,50);
INSERT INTO "django_geo_db_city" VALUES(11558,'Counce','Counce, Tennessee',14713,50);
INSERT INTO "django_geo_db_city" VALUES(11559,'Crump','Crump, Tennessee',14714,50);
INSERT INTO "django_geo_db_city" VALUES(11560,'Darden','Darden, Tennessee',14715,50);
INSERT INTO "django_geo_db_city" VALUES(11561,'Decaturville','Decaturville, Tennessee',14716,50);
INSERT INTO "django_geo_db_city" VALUES(11562,'Dyer','Dyer, Tennessee',14717,50);
INSERT INTO "django_geo_db_city" VALUES(11563,'Eaton','Eaton, Tennessee',14718,50);
INSERT INTO "django_geo_db_city" VALUES(11564,'Enville','Enville, Tennessee',14719,50);
INSERT INTO "django_geo_db_city" VALUES(11565,'Eva','Eva, Tennessee',14720,50);
INSERT INTO "django_geo_db_city" VALUES(11566,'Finger','Finger, Tennessee',14721,50);
INSERT INTO "django_geo_db_city" VALUES(11567,'Fruitvale','Fruitvale, Tennessee',14722,50);
INSERT INTO "django_geo_db_city" VALUES(11568,'Gadsden','Gadsden, Tennessee',14723,50);
INSERT INTO "django_geo_db_city" VALUES(11569,'Gibson','Gibson, Tennessee',14724,50);
INSERT INTO "django_geo_db_city" VALUES(11570,'Guys','Guys, Tennessee',14725,50);
INSERT INTO "django_geo_db_city" VALUES(11571,'Henderson','Henderson, Tennessee',14726,50);
INSERT INTO "django_geo_db_city" VALUES(11572,'Holladay','Holladay, Tennessee',14727,50);
INSERT INTO "django_geo_db_city" VALUES(11573,'Hollow Rock','Hollow Rock, Tennessee',14728,50);
INSERT INTO "django_geo_db_city" VALUES(11574,'Humboldt','Humboldt, Tennessee',14729,50);
INSERT INTO "django_geo_db_city" VALUES(11575,'Huntingdon','Huntingdon, Tennessee',14730,50);
INSERT INTO "django_geo_db_city" VALUES(11576,'Huron','Huron, Tennessee',14731,50);
INSERT INTO "django_geo_db_city" VALUES(11577,'Idlewild','Idlewild, Tennessee',14732,50);
INSERT INTO "django_geo_db_city" VALUES(11578,'Jacks Creek','Jacks Creek, Tennessee',14733,50);
INSERT INTO "django_geo_db_city" VALUES(11579,'Lavinia','Lavinia, Tennessee',14734,50);
INSERT INTO "django_geo_db_city" VALUES(11580,'Collinwood','Collinwood, Tennessee',14735,50);
INSERT INTO "django_geo_db_city" VALUES(11581,'Lexington','Lexington, Tennessee',14736,50);
INSERT INTO "django_geo_db_city" VALUES(11582,'Luray','Luray, Tennessee',14737,50);
INSERT INTO "django_geo_db_city" VALUES(11583,'Medina','Medina, Tennessee',14738,50);
INSERT INTO "django_geo_db_city" VALUES(11584,'Medon','Medon, Tennessee',14739,50);
INSERT INTO "django_geo_db_city" VALUES(11585,'Michie','Michie, Tennessee',14740,50);
INSERT INTO "django_geo_db_city" VALUES(11586,'Milan','Milan, Tennessee',14741,50);
INSERT INTO "django_geo_db_city" VALUES(11587,'Milledgeville','Milledgeville, Tennessee',14742,50);
INSERT INTO "django_geo_db_city" VALUES(11588,'Morris Chapel','Morris Chapel, Tennessee',14743,50);
INSERT INTO "django_geo_db_city" VALUES(11589,'Oakfield','Oakfield, Tennessee',14744,50);
INSERT INTO "django_geo_db_city" VALUES(11590,'Parsons','Parsons, Tennessee',14745,50);
INSERT INTO "django_geo_db_city" VALUES(11591,'Pickwick Dam','Pickwick Dam, Tennessee',14746,50);
INSERT INTO "django_geo_db_city" VALUES(11592,'Pinson','Pinson, Tennessee',14747,50);
INSERT INTO "django_geo_db_city" VALUES(11593,'Ramer','Ramer, Tennessee',14748,50);
INSERT INTO "django_geo_db_city" VALUES(11594,'Reagan','Reagan, Tennessee',14749,50);
INSERT INTO "django_geo_db_city" VALUES(11595,'Rutherford','Rutherford, Tennessee',14750,50);
INSERT INTO "django_geo_db_city" VALUES(11596,'Saltillo','Saltillo, Tennessee',14751,50);
INSERT INTO "django_geo_db_city" VALUES(11597,'Sardis','Sardis, Tennessee',14752,50);
INSERT INTO "django_geo_db_city" VALUES(11598,'Savannah','Savannah, Tennessee',14753,50);
INSERT INTO "django_geo_db_city" VALUES(11599,'Scotts Hill','Scotts Hill, Tennessee',14754,50);
INSERT INTO "django_geo_db_city" VALUES(11600,'Selmer','Selmer, Tennessee',14755,50);
INSERT INTO "django_geo_db_city" VALUES(11601,'Shiloh','Shiloh, Tennessee',14756,50);
INSERT INTO "django_geo_db_city" VALUES(11602,'Silerton','Silerton, Tennessee',14757,50);
INSERT INTO "django_geo_db_city" VALUES(11603,'Spring Creek','Spring Creek, Tennessee',14758,50);
INSERT INTO "django_geo_db_city" VALUES(11604,'Stantonville','Stantonville, Tennessee',14759,50);
INSERT INTO "django_geo_db_city" VALUES(11605,'Sugar Tree','Sugar Tree, Tennessee',14760,50);
INSERT INTO "django_geo_db_city" VALUES(11606,'Toone','Toone, Tennessee',14761,50);
INSERT INTO "django_geo_db_city" VALUES(11607,'Trenton','Trenton, Tennessee',14762,50);
INSERT INTO "django_geo_db_city" VALUES(11608,'Westport','Westport, Tennessee',14764,50);
INSERT INTO "django_geo_db_city" VALUES(11609,'Wildersville','Wildersville, Tennessee',14765,50);
INSERT INTO "django_geo_db_city" VALUES(11610,'Yorkville','Yorkville, Tennessee',14766,50);
INSERT INTO "django_geo_db_city" VALUES(11611,'Yuma','Yuma, Tennessee',14767,50);
INSERT INTO "django_geo_db_city" VALUES(11612,'Denmark','Denmark, Tennessee',14768,50);
INSERT INTO "django_geo_db_city" VALUES(11613,'Mercer','Mercer, Tennessee',14769,50);
INSERT INTO "django_geo_db_city" VALUES(11614,'Chewalla','Chewalla, Tennessee',14770,50);
INSERT INTO "django_geo_db_city" VALUES(11615,'Columbia','Columbia, Tennessee',14771,50);
INSERT INTO "django_geo_db_city" VALUES(11616,'Clifton','Clifton, Tennessee',14773,50);
INSERT INTO "django_geo_db_city" VALUES(11617,'Ardmore','Ardmore, Tennessee',14774,50);
INSERT INTO "django_geo_db_city" VALUES(11618,'Culleoka','Culleoka, Tennessee',14776,50);
INSERT INTO "django_geo_db_city" VALUES(11619,'Cypress Inn','Cypress Inn, Tennessee',14777,50);
INSERT INTO "django_geo_db_city" VALUES(11620,'Dellrose','Dellrose, Tennessee',14778,50);
INSERT INTO "django_geo_db_city" VALUES(11621,'Duck River','Duck River, Tennessee',14779,50);
INSERT INTO "django_geo_db_city" VALUES(11622,'Elkton','Elkton, Tennessee',14780,50);
INSERT INTO "django_geo_db_city" VALUES(11623,'Ethridge','Ethridge, Tennessee',14781,50);
INSERT INTO "django_geo_db_city" VALUES(11624,'Five Points','Five Points, Tennessee',14782,50);
INSERT INTO "django_geo_db_city" VALUES(11625,'Frankewing','Frankewing, Tennessee',14783,50);
INSERT INTO "django_geo_db_city" VALUES(11626,'Goodspring','Goodspring, Tennessee',14784,50);
INSERT INTO "django_geo_db_city" VALUES(11627,'Hampshire','Hampshire, Tennessee',14785,50);
INSERT INTO "django_geo_db_city" VALUES(11628,'Hohenwald','Hohenwald, Tennessee',14786,50);
INSERT INTO "django_geo_db_city" VALUES(11629,'Iron City','Iron City, Tennessee',14787,50);
INSERT INTO "django_geo_db_city" VALUES(11630,'Lawrenceburg','Lawrenceburg, Tennessee',14788,50);
INSERT INTO "django_geo_db_city" VALUES(11631,'Leoma','Leoma, Tennessee',14789,50);
INSERT INTO "django_geo_db_city" VALUES(11632,'Loretto','Loretto, Tennessee',14790,50);
INSERT INTO "django_geo_db_city" VALUES(11633,'Lutts','Lutts, Tennessee',14791,50);
INSERT INTO "django_geo_db_city" VALUES(11634,'Lynnville','Lynnville, Tennessee',14792,50);
INSERT INTO "django_geo_db_city" VALUES(11635,'Minor Hill','Minor Hill, Tennessee',14793,50);
INSERT INTO "django_geo_db_city" VALUES(11636,'Mount Pleasant','Mount Pleasant, Tennessee',14794,50);
INSERT INTO "django_geo_db_city" VALUES(11637,'Olivehill','Olivehill, Tennessee',14795,50);
INSERT INTO "django_geo_db_city" VALUES(11638,'Primm Springs','Primm Springs, Tennessee',14796,50);
INSERT INTO "django_geo_db_city" VALUES(11639,'Prospect','Prospect, Tennessee',14797,50);
INSERT INTO "django_geo_db_city" VALUES(11640,'Pulaski','Pulaski, Tennessee',14798,50);
INSERT INTO "django_geo_db_city" VALUES(11641,'Saint Joseph','Saint Joseph, Tennessee',14799,50);
INSERT INTO "django_geo_db_city" VALUES(11642,'Santa Fe','Santa Fe, Tennessee',14800,50);
INSERT INTO "django_geo_db_city" VALUES(11643,'Summertown','Summertown, Tennessee',14801,50);
INSERT INTO "django_geo_db_city" VALUES(11644,'Waynesboro','Waynesboro, Tennessee',14802,50);
INSERT INTO "django_geo_db_city" VALUES(11645,'Westpoint','Westpoint, Tennessee',14803,50);
INSERT INTO "django_geo_db_city" VALUES(11646,'Williamsport','Williamsport, Tennessee',14804,50);
INSERT INTO "django_geo_db_city" VALUES(11647,'Taft','Taft, Tennessee',14805,50);
INSERT INTO "django_geo_db_city" VALUES(11648,'Cookeville','Cookeville, Tennessee',14806,50);
INSERT INTO "django_geo_db_city" VALUES(11649,'Allardt','Allardt, Tennessee',14808,50);
INSERT INTO "django_geo_db_city" VALUES(11650,'Clarksdale','Clarksdale, Mississippi',14810,42);
INSERT INTO "django_geo_db_city" VALUES(11651,'Allons','Allons, Tennessee',14812,50);
INSERT INTO "django_geo_db_city" VALUES(11652,'Allred','Allred, Tennessee',14813,50);
INSERT INTO "django_geo_db_city" VALUES(11653,'Alpine','Alpine, Tennessee',14814,50);
INSERT INTO "django_geo_db_city" VALUES(11654,'Baxter','Baxter, Tennessee',14815,50);
INSERT INTO "django_geo_db_city" VALUES(11655,'Bloomington Springs','Bloomington Springs, Tennessee',14816,50);
INSERT INTO "django_geo_db_city" VALUES(11656,'Brush Creek','Brush Creek, Tennessee',14817,50);
INSERT INTO "django_geo_db_city" VALUES(11657,'Buffalo Valley','Buffalo Valley, Tennessee',14818,50);
INSERT INTO "django_geo_db_city" VALUES(11658,'Byrdstown','Byrdstown, Tennessee',14819,50);
INSERT INTO "django_geo_db_city" VALUES(11659,'Campaign','Campaign, Tennessee',14820,50);
INSERT INTO "django_geo_db_city" VALUES(11660,'Celina','Celina, Tennessee',14821,50);
INSERT INTO "django_geo_db_city" VALUES(11661,'Chestnut Mound','Chestnut Mound, Tennessee',14822,50);
INSERT INTO "django_geo_db_city" VALUES(11662,'Clarkrange','Clarkrange, Tennessee',14823,50);
INSERT INTO "django_geo_db_city" VALUES(11663,'Crawford','Crawford, Tennessee',14824,50);
INSERT INTO "django_geo_db_city" VALUES(11664,'Crossville','Crossville, Tennessee',14825,50);
INSERT INTO "django_geo_db_city" VALUES(11665,'Jamestown','Jamestown, Tennessee',14826,50);
INSERT INTO "django_geo_db_city" VALUES(11666,'Doyle','Doyle, Tennessee',14829,50);
INSERT INTO "django_geo_db_city" VALUES(11667,'Elmwood','Elmwood, Tennessee',14830,50);
INSERT INTO "django_geo_db_city" VALUES(11668,'Gainesboro','Gainesboro, Tennessee',14831,50);
INSERT INTO "django_geo_db_city" VALUES(11669,'Gordonsville','Gordonsville, Tennessee',14832,50);
INSERT INTO "django_geo_db_city" VALUES(11670,'Granville','Granville, Tennessee',14833,50);
INSERT INTO "django_geo_db_city" VALUES(11671,'Grimsley','Grimsley, Tennessee',14834,50);
INSERT INTO "django_geo_db_city" VALUES(11672,'Hickman','Hickman, Tennessee',14835,50);
INSERT INTO "django_geo_db_city" VALUES(11673,'Hilham','Hilham, Tennessee',14836,50);
INSERT INTO "django_geo_db_city" VALUES(11674,'Lancaster','Lancaster, Tennessee',14837,50);
INSERT INTO "django_geo_db_city" VALUES(11675,'Livingston','Livingston, Tennessee',14838,50);
INSERT INTO "django_geo_db_city" VALUES(11676,'Pleasant Hill','Pleasant Hill, Tennessee',14840,50);
INSERT INTO "django_geo_db_city" VALUES(11677,'Monroe','Monroe, Tennessee',14841,50);
INSERT INTO "django_geo_db_city" VALUES(11678,'Monterey','Monterey, Tennessee',14842,50);
INSERT INTO "django_geo_db_city" VALUES(11679,'Moss','Moss, Tennessee',14843,50);
INSERT INTO "django_geo_db_city" VALUES(11680,'Pall Mall','Pall Mall, Tennessee',14844,50);
INSERT INTO "django_geo_db_city" VALUES(11681,'Quebeck','Quebeck, Tennessee',14846,50);
INSERT INTO "django_geo_db_city" VALUES(11682,'Rickman','Rickman, Tennessee',14847,50);
INSERT INTO "django_geo_db_city" VALUES(11683,'Rock Island','Rock Island, Tennessee',14848,50);
INSERT INTO "django_geo_db_city" VALUES(11684,'Silver Point','Silver Point, Tennessee',14849,50);
INSERT INTO "django_geo_db_city" VALUES(11685,'Sparta','Sparta, Tennessee',14850,50);
INSERT INTO "django_geo_db_city" VALUES(11686,'Spencer','Spencer, Tennessee',14851,50);
INSERT INTO "django_geo_db_city" VALUES(11687,'Walling','Walling, Tennessee',14852,50);
INSERT INTO "django_geo_db_city" VALUES(11688,'Whitleyville','Whitleyville, Tennessee',14853,50);
INSERT INTO "django_geo_db_city" VALUES(11689,'Wilder','Wilder, Tennessee',14854,50);
INSERT INTO "django_geo_db_city" VALUES(11690,'Sumner','Sumner, Mississippi',14855,42);
INSERT INTO "django_geo_db_city" VALUES(11691,'Abbeville','Abbeville, Mississippi',14856,42);
INSERT INTO "django_geo_db_city" VALUES(11692,'Arkabutla','Arkabutla, Mississippi',14857,42);
INSERT INTO "django_geo_db_city" VALUES(11693,'Ashland','Ashland, Mississippi',14858,42);
INSERT INTO "django_geo_db_city" VALUES(11694,'Batesville','Batesville, Mississippi',14859,42);
INSERT INTO "django_geo_db_city" VALUES(11695,'Belen','Belen, Mississippi',14860,42);
INSERT INTO "django_geo_db_city" VALUES(11696,'Blue Mountain','Blue Mountain, Mississippi',14861,42);
INSERT INTO "django_geo_db_city" VALUES(11697,'Byhalia','Byhalia, Mississippi',14862,42);
INSERT INTO "django_geo_db_city" VALUES(11698,'Coahoma','Coahoma, Mississippi',14864,42);
INSERT INTO "django_geo_db_city" VALUES(11699,'Coldwater','Coldwater, Mississippi',14865,42);
INSERT INTO "django_geo_db_city" VALUES(11700,'Como','Como, Mississippi',14866,42);
INSERT INTO "django_geo_db_city" VALUES(11701,'Courtland','Courtland, Mississippi',14867,42);
INSERT INTO "django_geo_db_city" VALUES(11702,'Crenshaw','Crenshaw, Mississippi',14868,42);
INSERT INTO "django_geo_db_city" VALUES(11703,'Crowder','Crowder, Mississippi',14869,42);
INSERT INTO "django_geo_db_city" VALUES(11704,'Darling','Darling, Mississippi',14870,42);
INSERT INTO "django_geo_db_city" VALUES(11705,'Dumas','Dumas, Mississippi',14871,42);
INSERT INTO "django_geo_db_city" VALUES(11706,'Dundee','Dundee, Mississippi',14872,42);
INSERT INTO "django_geo_db_city" VALUES(11707,'Etta','Etta, Mississippi',14873,42);
INSERT INTO "django_geo_db_city" VALUES(11708,'Falcon','Falcon, Mississippi',14874,42);
INSERT INTO "django_geo_db_city" VALUES(11709,'Falkner','Falkner, Mississippi',14875,42);
INSERT INTO "django_geo_db_city" VALUES(11710,'Farrell','Farrell, Mississippi',14876,42);
INSERT INTO "django_geo_db_city" VALUES(11711,'Friars Point','Friars Point, Mississippi',14877,42);
INSERT INTO "django_geo_db_city" VALUES(11712,'Hernando','Hernando, Mississippi',14878,42);
INSERT INTO "django_geo_db_city" VALUES(11713,'Hickory Flat','Hickory Flat, Mississippi',14879,42);
INSERT INTO "django_geo_db_city" VALUES(11714,'Holly Springs','Holly Springs, Mississippi',14880,42);
INSERT INTO "django_geo_db_city" VALUES(11715,'Horn Lake','Horn Lake, Mississippi',14882,42);
INSERT INTO "django_geo_db_city" VALUES(11716,'Independence','Independence, Mississippi',14883,42);
INSERT INTO "django_geo_db_city" VALUES(11717,'Jonestown','Jonestown, Mississippi',14884,42);
INSERT INTO "django_geo_db_city" VALUES(11718,'Lake Cormorant','Lake Cormorant, Mississippi',14885,42);
INSERT INTO "django_geo_db_city" VALUES(11719,'Lamar','Lamar, Mississippi',14886,42);
INSERT INTO "django_geo_db_city" VALUES(11720,'Lambert','Lambert, Mississippi',14887,42);
INSERT INTO "django_geo_db_city" VALUES(11721,'Lula','Lula, Mississippi',14888,42);
INSERT INTO "django_geo_db_city" VALUES(11722,'Lyon','Lyon, Mississippi',14889,42);
INSERT INTO "django_geo_db_city" VALUES(11723,'Marks','Marks, Mississippi',14890,42);
INSERT INTO "django_geo_db_city" VALUES(11724,'Michigan City','Michigan City, Mississippi',14891,42);
INSERT INTO "django_geo_db_city" VALUES(11725,'Mount Pleasant','Mount Pleasant, Mississippi',14892,42);
INSERT INTO "django_geo_db_city" VALUES(11726,'Myrtle','Myrtle, Mississippi',14893,42);
INSERT INTO "django_geo_db_city" VALUES(11727,'Nesbit','Nesbit, Mississippi',14894,42);
INSERT INTO "django_geo_db_city" VALUES(11728,'New Albany','New Albany, Mississippi',14895,42);
INSERT INTO "django_geo_db_city" VALUES(11729,'Olive Branch','Olive Branch, Mississippi',14896,42);
INSERT INTO "django_geo_db_city" VALUES(11730,'Oxford','Oxford, Mississippi',14897,42);
INSERT INTO "django_geo_db_city" VALUES(11731,'Pope','Pope, Mississippi',14898,42);
INSERT INTO "django_geo_db_city" VALUES(11732,'Potts Camp','Potts Camp, Mississippi',14899,42);
INSERT INTO "django_geo_db_city" VALUES(11733,'Red Banks','Red Banks, Mississippi',14900,42);
INSERT INTO "django_geo_db_city" VALUES(11734,'Ripley','Ripley, Mississippi',14901,42);
INSERT INTO "django_geo_db_city" VALUES(11735,'Robinsonville','Robinsonville, Mississippi',14902,42);
INSERT INTO "django_geo_db_city" VALUES(11736,'Sarah','Sarah, Mississippi',14903,42);
INSERT INTO "django_geo_db_city" VALUES(11737,'Sardis','Sardis, Mississippi',14904,42);
INSERT INTO "django_geo_db_city" VALUES(11738,'Senatobia','Senatobia, Mississippi',14905,42);
INSERT INTO "django_geo_db_city" VALUES(11739,'Sherard','Sherard, Mississippi',14906,42);
INSERT INTO "django_geo_db_city" VALUES(11740,'Sledge','Sledge, Mississippi',14907,42);
INSERT INTO "django_geo_db_city" VALUES(11741,'Southaven','Southaven, Mississippi',14908,42);
INSERT INTO "django_geo_db_city" VALUES(11742,'Taylor','Taylor, Mississippi',14910,42);
INSERT INTO "django_geo_db_city" VALUES(11743,'Tiplersville','Tiplersville, Mississippi',14911,42);
INSERT INTO "django_geo_db_city" VALUES(11744,'Tula','Tula, Mississippi',14912,42);
INSERT INTO "django_geo_db_city" VALUES(11745,'Tunica','Tunica, Mississippi',14913,42);
INSERT INTO "django_geo_db_city" VALUES(11746,'University','University, Mississippi',14914,42);
INSERT INTO "django_geo_db_city" VALUES(11747,'Victoria','Victoria, Mississippi',14915,42);
INSERT INTO "django_geo_db_city" VALUES(11748,'Walls','Walls, Mississippi',14916,42);
INSERT INTO "django_geo_db_city" VALUES(11749,'Walnut','Walnut, Mississippi',14917,42);
INSERT INTO "django_geo_db_city" VALUES(11750,'Waterford','Waterford, Mississippi',14918,42);
INSERT INTO "django_geo_db_city" VALUES(11751,'Water Valley','Water Valley, Mississippi',14920,42);
INSERT INTO "django_geo_db_city" VALUES(11752,'Greenville','Greenville, Mississippi',14921,42);
INSERT INTO "django_geo_db_city" VALUES(11753,'Alligator','Alligator, Mississippi',14925,42);
INSERT INTO "django_geo_db_city" VALUES(11754,'Anguilla','Anguilla, Mississippi',14926,42);
INSERT INTO "django_geo_db_city" VALUES(11755,'Arcola','Arcola, Mississippi',14927,42);
INSERT INTO "django_geo_db_city" VALUES(11756,'Avon','Avon, Mississippi',14928,42);
INSERT INTO "django_geo_db_city" VALUES(11757,'Benoit','Benoit, Mississippi',14929,42);
INSERT INTO "django_geo_db_city" VALUES(11758,'Beulah','Beulah, Mississippi',14930,42);
INSERT INTO "django_geo_db_city" VALUES(11759,'Boyle','Boyle, Mississippi',14931,42);
INSERT INTO "django_geo_db_city" VALUES(11760,'Chatham','Chatham, Mississippi',14932,42);
INSERT INTO "django_geo_db_city" VALUES(11761,'Cleveland','Cleveland, Mississippi',14933,42);
INSERT INTO "django_geo_db_city" VALUES(11762,'Doddsville','Doddsville, Mississippi',14935,42);
INSERT INTO "django_geo_db_city" VALUES(11763,'Drew','Drew, Mississippi',14936,42);
INSERT INTO "django_geo_db_city" VALUES(11764,'Parchman','Parchman, Mississippi',14937,42);
INSERT INTO "django_geo_db_city" VALUES(11765,'Dublin','Dublin, Mississippi',14938,42);
INSERT INTO "django_geo_db_city" VALUES(11766,'Duncan','Duncan, Mississippi',14939,42);
INSERT INTO "django_geo_db_city" VALUES(11767,'Glen Allan','Glen Allan, Mississippi',14940,42);
INSERT INTO "django_geo_db_city" VALUES(11768,'Grace','Grace, Mississippi',14941,42);
INSERT INTO "django_geo_db_city" VALUES(11769,'Gunnison','Gunnison, Mississippi',14942,42);
INSERT INTO "django_geo_db_city" VALUES(11770,'Hollandale','Hollandale, Mississippi',14943,42);
INSERT INTO "django_geo_db_city" VALUES(11771,'Holly Ridge','Holly Ridge, Mississippi',14944,42);
INSERT INTO "django_geo_db_city" VALUES(11772,'Indianola','Indianola, Mississippi',14945,42);
INSERT INTO "django_geo_db_city" VALUES(11773,'Inverness','Inverness, Mississippi',14946,42);
INSERT INTO "django_geo_db_city" VALUES(11774,'Isola','Isola, Mississippi',14947,42);
INSERT INTO "django_geo_db_city" VALUES(11775,'Leland','Leland, Mississippi',14948,42);
INSERT INTO "django_geo_db_city" VALUES(11776,'Mattson','Mattson, Mississippi',14949,42);
INSERT INTO "django_geo_db_city" VALUES(11777,'Merigold','Merigold, Mississippi',14950,42);
INSERT INTO "django_geo_db_city" VALUES(11778,'Moorhead','Moorhead, Mississippi',14952,42);
INSERT INTO "django_geo_db_city" VALUES(11779,'Mound Bayou','Mound Bayou, Mississippi',14953,42);
INSERT INTO "django_geo_db_city" VALUES(11780,'Nitta Yuma','Nitta Yuma, Mississippi',14954,42);
INSERT INTO "django_geo_db_city" VALUES(11781,'Pace','Pace, Mississippi',14955,42);
INSERT INTO "django_geo_db_city" VALUES(11782,'Panther Burn','Panther Burn, Mississippi',14956,42);
INSERT INTO "django_geo_db_city" VALUES(11783,'Rena Lara','Rena Lara, Mississippi',14957,42);
INSERT INTO "django_geo_db_city" VALUES(11784,'Rome','Rome, Mississippi',14958,42);
INSERT INTO "django_geo_db_city" VALUES(11785,'Rosedale','Rosedale, Mississippi',14959,42);
INSERT INTO "django_geo_db_city" VALUES(11786,'Ruleville','Ruleville, Mississippi',14960,42);
INSERT INTO "django_geo_db_city" VALUES(11787,'Scott','Scott, Mississippi',14961,42);
INSERT INTO "django_geo_db_city" VALUES(11788,'Shaw','Shaw, Mississippi',14962,42);
INSERT INTO "django_geo_db_city" VALUES(11789,'Shelby','Shelby, Mississippi',14963,42);
INSERT INTO "django_geo_db_city" VALUES(11790,'Stoneville','Stoneville, Mississippi',14964,42);
INSERT INTO "django_geo_db_city" VALUES(11791,'Sunflower','Sunflower, Mississippi',14965,42);
INSERT INTO "django_geo_db_city" VALUES(11792,'Wayside','Wayside, Mississippi',14966,42);
INSERT INTO "django_geo_db_city" VALUES(11793,'Winstonville','Winstonville, Mississippi',14967,42);
INSERT INTO "django_geo_db_city" VALUES(11794,'Winterville','Winterville, Mississippi',14968,42);
INSERT INTO "django_geo_db_city" VALUES(11795,'Tupelo','Tupelo, Mississippi',14969,42);
INSERT INTO "django_geo_db_city" VALUES(11796,'Algoma','Algoma, Mississippi',14973,42);
INSERT INTO "django_geo_db_city" VALUES(11797,'Amory','Amory, Mississippi',14974,42);
INSERT INTO "django_geo_db_city" VALUES(11798,'Baldwyn','Baldwyn, Mississippi',14975,42);
INSERT INTO "django_geo_db_city" VALUES(11799,'Becker','Becker, Mississippi',14976,42);
INSERT INTO "django_geo_db_city" VALUES(11800,'Belden','Belden, Mississippi',14977,42);
INSERT INTO "django_geo_db_city" VALUES(11801,'Belmont','Belmont, Mississippi',14978,42);
INSERT INTO "django_geo_db_city" VALUES(11802,'Blue Springs','Blue Springs, Mississippi',14979,42);
INSERT INTO "django_geo_db_city" VALUES(11803,'Booneville','Booneville, Mississippi',14980,42);
INSERT INTO "django_geo_db_city" VALUES(11804,'Burnsville','Burnsville, Mississippi',14981,42);
INSERT INTO "django_geo_db_city" VALUES(11805,'Corinth','Corinth, Mississippi',14982,42);
INSERT INTO "django_geo_db_city" VALUES(11806,'Dennis','Dennis, Mississippi',14984,42);
INSERT INTO "django_geo_db_city" VALUES(11807,'Derma','Derma, Mississippi',14985,42);
INSERT INTO "django_geo_db_city" VALUES(11808,'Ecru','Ecru, Mississippi',14986,42);
INSERT INTO "django_geo_db_city" VALUES(11809,'Fulton','Fulton, Mississippi',14987,42);
INSERT INTO "django_geo_db_city" VALUES(11810,'Gattman','Gattman, Mississippi',14988,42);
INSERT INTO "django_geo_db_city" VALUES(11811,'Glen','Glen, Mississippi',14989,42);
INSERT INTO "django_geo_db_city" VALUES(11812,'Golden','Golden, Mississippi',14990,42);
INSERT INTO "django_geo_db_city" VALUES(11813,'Greenwood Springs','Greenwood Springs, Mississippi',14991,42);
INSERT INTO "django_geo_db_city" VALUES(11814,'Guntown','Guntown, Mississippi',14992,42);
INSERT INTO "django_geo_db_city" VALUES(11815,'Houlka','Houlka, Mississippi',14993,42);
INSERT INTO "django_geo_db_city" VALUES(11816,'Houston','Houston, Mississippi',14994,42);
INSERT INTO "django_geo_db_city" VALUES(11817,'Iuka','Iuka, Alabama',14995,1);
INSERT INTO "django_geo_db_city" VALUES(11818,'McCondy','McCondy, Mississippi',14996,42);
INSERT INTO "django_geo_db_city" VALUES(11819,'Mantachie','Mantachie, Mississippi',14997,42);
INSERT INTO "django_geo_db_city" VALUES(11820,'Marietta','Marietta, Mississippi',14998,42);
INSERT INTO "django_geo_db_city" VALUES(11821,'Mooreville','Mooreville, Mississippi',14999,42);
INSERT INTO "django_geo_db_city" VALUES(11822,'Nettleton','Nettleton, Mississippi',15000,42);
INSERT INTO "django_geo_db_city" VALUES(11823,'New Site','New Site, Mississippi',15001,42);
INSERT INTO "django_geo_db_city" VALUES(11824,'Okolona','Okolona, Mississippi',15002,42);
INSERT INTO "django_geo_db_city" VALUES(11825,'Plantersville','Plantersville, Mississippi',15003,42);
INSERT INTO "django_geo_db_city" VALUES(11826,'Pontotoc','Pontotoc, Mississippi',15004,42);
INSERT INTO "django_geo_db_city" VALUES(11827,'Randolph','Randolph, Mississippi',15005,42);
INSERT INTO "django_geo_db_city" VALUES(11828,'Rienzi','Rienzi, Mississippi',15006,42);
INSERT INTO "django_geo_db_city" VALUES(11829,'Saltillo','Saltillo, Mississippi',15007,42);
INSERT INTO "django_geo_db_city" VALUES(11830,'Shannon','Shannon, Mississippi',15008,42);
INSERT INTO "django_geo_db_city" VALUES(11831,'Sherman','Sherman, Mississippi',15009,42);
INSERT INTO "django_geo_db_city" VALUES(11832,'Smithville','Smithville, Mississippi',15010,42);
INSERT INTO "django_geo_db_city" VALUES(11833,'Thaxton','Thaxton, Mississippi',15011,42);
INSERT INTO "django_geo_db_city" VALUES(11834,'Tishomingo','Tishomingo, Mississippi',15012,42);
INSERT INTO "django_geo_db_city" VALUES(11835,'Toccopola','Toccopola, Mississippi',15013,42);
INSERT INTO "django_geo_db_city" VALUES(11836,'Trebloc','Trebloc, Mississippi',14996,42);
INSERT INTO "django_geo_db_city" VALUES(11837,'Tremont','Tremont, Mississippi',15014,42);
INSERT INTO "django_geo_db_city" VALUES(11838,'Van Vleet','Van Vleet, Mississippi',15015,42);
INSERT INTO "django_geo_db_city" VALUES(11839,'Vardaman','Vardaman, Mississippi',15016,42);
INSERT INTO "django_geo_db_city" VALUES(11840,'Verona','Verona, Mississippi',15017,42);
INSERT INTO "django_geo_db_city" VALUES(11841,'Wheeler','Wheeler, Mississippi',15018,42);
INSERT INTO "django_geo_db_city" VALUES(11842,'Grenada','Grenada, Mississippi',15019,42);
INSERT INTO "django_geo_db_city" VALUES(11843,'Avalon','Avalon, Mississippi',15021,42);
INSERT INTO "django_geo_db_city" VALUES(11844,'Banner','Banner, Mississippi',15022,42);
INSERT INTO "django_geo_db_city" VALUES(11845,'Big Creek','Big Creek, Mississippi',15023,42);
INSERT INTO "django_geo_db_city" VALUES(11846,'Bruce','Bruce, Mississippi',15024,42);
INSERT INTO "django_geo_db_city" VALUES(11847,'Calhoun City','Calhoun City, Mississippi',15025,42);
INSERT INTO "django_geo_db_city" VALUES(11848,'Carrollton','Carrollton, Mississippi',15026,42);
INSERT INTO "django_geo_db_city" VALUES(11849,'Cascilla','Cascilla, Mississippi',15027,42);
INSERT INTO "django_geo_db_city" VALUES(11850,'Charleston','Charleston, Mississippi',15028,42);
INSERT INTO "django_geo_db_city" VALUES(11851,'Coffeeville','Coffeeville, Mississippi',15029,42);
INSERT INTO "django_geo_db_city" VALUES(11852,'Coila','Coila, Mississippi',15030,42);
INSERT INTO "django_geo_db_city" VALUES(11853,'Cruger','Cruger, Mississippi',15031,42);
INSERT INTO "django_geo_db_city" VALUES(11854,'Duck Hill','Duck Hill, Mississippi',15032,42);
INSERT INTO "django_geo_db_city" VALUES(11855,'Elliott','Elliott, Mississippi',15033,42);
INSERT INTO "django_geo_db_city" VALUES(11856,'Enid','Enid, Mississippi',15034,42);
INSERT INTO "django_geo_db_city" VALUES(11857,'Glendora','Glendora, Mississippi',15035,42);
INSERT INTO "django_geo_db_city" VALUES(11858,'Gore Springs','Gore Springs, Mississippi',15036,42);
INSERT INTO "django_geo_db_city" VALUES(11859,'Greenwood','Greenwood, Mississippi',15037,42);
INSERT INTO "django_geo_db_city" VALUES(11860,'Holcomb','Holcomb, Mississippi',15039,42);
INSERT INTO "django_geo_db_city" VALUES(11861,'Itta Bena','Itta Bena, Mississippi',15040,42);
INSERT INTO "django_geo_db_city" VALUES(11862,'McCarley','McCarley, Mississippi',15041,42);
INSERT INTO "django_geo_db_city" VALUES(11863,'Minter City','Minter City, Mississippi',15042,42);
INSERT INTO "django_geo_db_city" VALUES(11864,'Money','Money, Mississippi',15043,42);
INSERT INTO "django_geo_db_city" VALUES(11865,'Morgan City','Morgan City, Mississippi',15044,42);
INSERT INTO "django_geo_db_city" VALUES(11866,'North Carrollton','North Carrollton, Mississippi',15045,42);
INSERT INTO "django_geo_db_city" VALUES(11867,'Oakland','Oakland, Mississippi',15046,42);
INSERT INTO "django_geo_db_city" VALUES(11868,'Paris','Paris, Mississippi',15047,42);
INSERT INTO "django_geo_db_city" VALUES(11869,'Philipp','Philipp, Mississippi',15048,42);
INSERT INTO "django_geo_db_city" VALUES(11870,'Pittsboro','Pittsboro, Mississippi',15049,42);
INSERT INTO "django_geo_db_city" VALUES(11871,'Schlater','Schlater, Mississippi',15050,42);
INSERT INTO "django_geo_db_city" VALUES(11872,'Scobey','Scobey, Mississippi',15051,42);
INSERT INTO "django_geo_db_city" VALUES(11873,'Sidon','Sidon, Mississippi',15052,42);
INSERT INTO "django_geo_db_city" VALUES(11874,'Slate Spring','Slate Spring, Mississippi',15053,42);
INSERT INTO "django_geo_db_city" VALUES(11875,'Swan Lake','Swan Lake, Mississippi',15055,42);
INSERT INTO "django_geo_db_city" VALUES(11876,'Swiftown','Swiftown, Mississippi',15056,42);
INSERT INTO "django_geo_db_city" VALUES(11877,'Tie Plant','Tie Plant, Mississippi',15057,42);
INSERT INTO "django_geo_db_city" VALUES(11878,'Tillatoba','Tillatoba, Mississippi',15058,42);
INSERT INTO "django_geo_db_city" VALUES(11879,'Tippo','Tippo, Mississippi',15059,42);
INSERT INTO "django_geo_db_city" VALUES(11880,'Tutwiler','Tutwiler, Mississippi',15060,42);
INSERT INTO "django_geo_db_city" VALUES(11881,'Vance','Vance, Mississippi',15061,42);
INSERT INTO "django_geo_db_city" VALUES(11882,'Webb','Webb, Mississippi',15063,42);
INSERT INTO "django_geo_db_city" VALUES(11883,'Winona','Winona, Mississippi',15064,42);
INSERT INTO "django_geo_db_city" VALUES(11884,'Belzoni','Belzoni, Mississippi',15065,42);
INSERT INTO "django_geo_db_city" VALUES(11885,'Benton','Benton, Mississippi',15066,42);
INSERT INTO "django_geo_db_city" VALUES(11886,'Bentonia','Bentonia, Mississippi',15067,42);
INSERT INTO "django_geo_db_city" VALUES(11887,'Bolton','Bolton, Mississippi',15068,42);
INSERT INTO "django_geo_db_city" VALUES(11888,'Brandon','Brandon, Mississippi',15069,42);
INSERT INTO "django_geo_db_city" VALUES(11889,'Braxton','Braxton, Mississippi',15071,42);
INSERT INTO "django_geo_db_city" VALUES(11890,'Camden','Camden, Mississippi',15072,42);
INSERT INTO "django_geo_db_city" VALUES(11891,'Canton','Canton, Mississippi',15073,42);
INSERT INTO "django_geo_db_city" VALUES(11892,'Carthage','Carthage, Mississippi',15076,42);
INSERT INTO "django_geo_db_city" VALUES(11893,'Cary','Cary, Mississippi',15077,42);
INSERT INTO "django_geo_db_city" VALUES(11894,'Clinton','Clinton, Mississippi',15078,42);
INSERT INTO "django_geo_db_city" VALUES(11895,'Conehatta','Conehatta, Mississippi',15079,42);
INSERT INTO "django_geo_db_city" VALUES(11896,'Crystal Springs','Crystal Springs, Mississippi',15081,42);
INSERT INTO "django_geo_db_city" VALUES(11897,'Delta City','Delta City, Mississippi',15083,42);
INSERT INTO "django_geo_db_city" VALUES(11898,'D Lo','D Lo, Mississippi',15084,42);
INSERT INTO "django_geo_db_city" VALUES(11899,'Durant','Durant, Mississippi',15085,42);
INSERT INTO "django_geo_db_city" VALUES(11900,'Edwards','Edwards, Mississippi',15086,42);
INSERT INTO "django_geo_db_city" VALUES(11901,'Ethel','Ethel, Mississippi',15087,42);
INSERT INTO "django_geo_db_city" VALUES(11902,'Fayette','Fayette, Mississippi',15088,42);
INSERT INTO "django_geo_db_city" VALUES(11903,'Flora','Flora, Mississippi',15089,42);
INSERT INTO "django_geo_db_city" VALUES(11904,'Pocahontas','Pocahontas, Mississippi',15080,42);
INSERT INTO "django_geo_db_city" VALUES(11905,'Florence','Florence, Mississippi',15090,42);
INSERT INTO "django_geo_db_city" VALUES(11906,'Forest','Forest, Mississippi',15091,42);
INSERT INTO "django_geo_db_city" VALUES(11907,'Gallman','Gallman, Mississippi',15092,42);
INSERT INTO "django_geo_db_city" VALUES(11908,'Georgetown','Georgetown, Mississippi',15093,42);
INSERT INTO "django_geo_db_city" VALUES(11909,'Goodman','Goodman, Mississippi',15094,42);
INSERT INTO "django_geo_db_city" VALUES(11910,'Harperville','Harperville, Mississippi',15095,42);
INSERT INTO "django_geo_db_city" VALUES(11911,'Harriston','Harriston, Mississippi',15096,42);
INSERT INTO "django_geo_db_city" VALUES(11912,'Harrisville','Harrisville, Mississippi',15097,42);
INSERT INTO "django_geo_db_city" VALUES(11913,'Hazlehurst','Hazlehurst, Mississippi',15098,42);
INSERT INTO "django_geo_db_city" VALUES(11914,'Hermanville','Hermanville, Mississippi',15099,42);
INSERT INTO "django_geo_db_city" VALUES(11915,'Hillsboro','Hillsboro, Mississippi',15100,42);
INSERT INTO "django_geo_db_city" VALUES(11916,'Holly Bluff','Holly Bluff, Mississippi',15101,42);
INSERT INTO "django_geo_db_city" VALUES(11917,'Kosciusko','Kosciusko, Mississippi',15102,42);
INSERT INTO "django_geo_db_city" VALUES(11918,'Lake','Lake, Mississippi',15103,42);
INSERT INTO "django_geo_db_city" VALUES(11919,'Lena','Lena, Mississippi',15104,42);
INSERT INTO "django_geo_db_city" VALUES(11920,'Lexington','Lexington, Mississippi',15105,42);
INSERT INTO "django_geo_db_city" VALUES(11921,'Lorman','Lorman, Mississippi',15106,42);
INSERT INTO "django_geo_db_city" VALUES(11922,'Louise','Louise, Mississippi',15107,42);
INSERT INTO "django_geo_db_city" VALUES(11923,'Ludlow','Ludlow, Mississippi',15108,42);
INSERT INTO "django_geo_db_city" VALUES(11924,'McAdams','McAdams, Mississippi',15109,42);
INSERT INTO "django_geo_db_city" VALUES(11925,'McCool','McCool, Mississippi',15110,42);
INSERT INTO "django_geo_db_city" VALUES(11926,'Madden','Madden, Mississippi',15111,42);
INSERT INTO "django_geo_db_city" VALUES(11927,'Madison','Madison, Mississippi',15112,42);
INSERT INTO "django_geo_db_city" VALUES(11928,'Magee','Magee, Mississippi',15113,42);
INSERT INTO "django_geo_db_city" VALUES(11929,'Sanatorium','Sanatorium, Mississippi',15114,42);
INSERT INTO "django_geo_db_city" VALUES(11930,'Mayersville','Mayersville, Mississippi',15115,42);
INSERT INTO "django_geo_db_city" VALUES(11931,'Mendenhall','Mendenhall, Mississippi',15116,42);
INSERT INTO "django_geo_db_city" VALUES(11932,'Midnight','Midnight, Mississippi',15117,42);
INSERT INTO "django_geo_db_city" VALUES(11933,'Mize','Mize, Mississippi',15118,42);
INSERT INTO "django_geo_db_city" VALUES(11934,'Morton','Morton, Mississippi',15119,42);
INSERT INTO "django_geo_db_city" VALUES(11935,'Mount Olive','Mount Olive, Mississippi',15120,42);
INSERT INTO "django_geo_db_city" VALUES(11936,'Natchez','Natchez, Mississippi',15121,42);
INSERT INTO "django_geo_db_city" VALUES(11937,'Newhebron','Newhebron, Mississippi',15124,42);
INSERT INTO "django_geo_db_city" VALUES(11938,'Pattison','Pattison, Mississippi',15125,42);
INSERT INTO "django_geo_db_city" VALUES(11939,'Pelahatchie','Pelahatchie, Mississippi',15126,42);
INSERT INTO "django_geo_db_city" VALUES(11940,'Pickens','Pickens, Mississippi',15127,42);
INSERT INTO "django_geo_db_city" VALUES(11941,'Piney Woods','Piney Woods, Mississippi',15128,42);
INSERT INTO "django_geo_db_city" VALUES(11942,'Pinola','Pinola, Mississippi',15129,42);
INSERT INTO "django_geo_db_city" VALUES(11943,'Port Gibson','Port Gibson, Mississippi',15130,42);
INSERT INTO "django_geo_db_city" VALUES(11944,'Puckett','Puckett, Mississippi',15131,42);
INSERT INTO "django_geo_db_city" VALUES(11945,'Pulaski','Pulaski, Mississippi',15132,42);
INSERT INTO "django_geo_db_city" VALUES(11946,'Raleigh','Raleigh, Mississippi',15133,42);
INSERT INTO "django_geo_db_city" VALUES(11947,'Raymond','Raymond, Mississippi',15134,42);
INSERT INTO "django_geo_db_city" VALUES(11948,'Redwood','Redwood, Mississippi',15135,42);
INSERT INTO "django_geo_db_city" VALUES(11949,'Ridgeland','Ridgeland, Mississippi',15136,42);
INSERT INTO "django_geo_db_city" VALUES(11950,'Rolling Fork','Rolling Fork, Mississippi',15137,42);
INSERT INTO "django_geo_db_city" VALUES(11951,'Sallis','Sallis, Mississippi',15138,42);
INSERT INTO "django_geo_db_city" VALUES(11952,'Sandhill','Sandhill, Mississippi',15139,42);
INSERT INTO "django_geo_db_city" VALUES(11953,'Satartia','Satartia, Mississippi',15140,42);
INSERT INTO "django_geo_db_city" VALUES(11954,'Sharon','Sharon, Mississippi',15123,42);
INSERT INTO "django_geo_db_city" VALUES(11955,'Sibley','Sibley, Mississippi',15122,42);
INSERT INTO "django_geo_db_city" VALUES(11956,'Silver City','Silver City, Mississippi',15141,42);
INSERT INTO "django_geo_db_city" VALUES(11957,'Star','Star, Mississippi',15142,42);
INSERT INTO "django_geo_db_city" VALUES(11958,'Taylorsville','Taylorsville, Mississippi',15143,42);
INSERT INTO "django_geo_db_city" VALUES(11959,'Tchula','Tchula, Mississippi',15144,42);
INSERT INTO "django_geo_db_city" VALUES(11960,'Terry','Terry, Mississippi',15145,42);
INSERT INTO "django_geo_db_city" VALUES(11961,'Thomastown','Thomastown, Mississippi',15146,42);
INSERT INTO "django_geo_db_city" VALUES(11962,'Tinsley','Tinsley, Mississippi',15147,42);
INSERT INTO "django_geo_db_city" VALUES(11963,'Tougaloo','Tougaloo, Mississippi',15148,42);
INSERT INTO "django_geo_db_city" VALUES(11964,'Utica','Utica, Mississippi',15149,42);
INSERT INTO "django_geo_db_city" VALUES(11965,'Vaiden','Vaiden, Mississippi',15150,42);
INSERT INTO "django_geo_db_city" VALUES(11966,'Valley Park','Valley Park, Mississippi',15151,42);
INSERT INTO "django_geo_db_city" VALUES(11967,'Vaughan','Vaughan, Mississippi',15152,42);
INSERT INTO "django_geo_db_city" VALUES(11968,'Vicksburg','Vicksburg, Mississippi',15153,42);
INSERT INTO "django_geo_db_city" VALUES(11969,'Walnut Grove','Walnut Grove, Mississippi',15156,42);
INSERT INTO "django_geo_db_city" VALUES(11970,'Washington','Washington, Mississippi',15122,42);
INSERT INTO "django_geo_db_city" VALUES(11971,'Wesson','Wesson, Mississippi',15157,42);
INSERT INTO "django_geo_db_city" VALUES(11972,'West','West, Mississippi',15158,42);
INSERT INTO "django_geo_db_city" VALUES(11973,'Whitfield','Whitfield, Mississippi',15159,42);
INSERT INTO "django_geo_db_city" VALUES(11974,'Yazoo City','Yazoo City, Mississippi',15160,42);
INSERT INTO "django_geo_db_city" VALUES(11975,'Jackson','Jackson, Mississippi',15161,42);
INSERT INTO "django_geo_db_city" VALUES(11976,'Meridian','Meridian, Mississippi',15179,42);
INSERT INTO "django_geo_db_city" VALUES(11977,'Bailey','Bailey, Mississippi',15186,42);
INSERT INTO "django_geo_db_city" VALUES(11978,'Buckatunna','Buckatunna, Mississippi',15187,42);
INSERT INTO "django_geo_db_city" VALUES(11979,'Chunky','Chunky, Mississippi',15188,42);
INSERT INTO "django_geo_db_city" VALUES(11980,'Clara','Clara, Mississippi',15189,42);
INSERT INTO "django_geo_db_city" VALUES(11981,'Collinsville','Collinsville, Mississippi',15190,42);
INSERT INTO "django_geo_db_city" VALUES(11982,'Daleville','Daleville, Mississippi',15191,42);
INSERT INTO "django_geo_db_city" VALUES(11983,'Decatur','Decatur, Mississippi',15192,42);
INSERT INTO "django_geo_db_city" VALUES(11984,'De Kalb','De Kalb, Mississippi',15193,42);
INSERT INTO "django_geo_db_city" VALUES(11985,'Enterprise','Enterprise, Mississippi',15194,42);
INSERT INTO "django_geo_db_city" VALUES(11986,'Hickory','Hickory, Mississippi',15195,42);
INSERT INTO "django_geo_db_city" VALUES(11987,'Lauderdale','Lauderdale, Mississippi',15196,42);
INSERT INTO "django_geo_db_city" VALUES(11988,'Lawrence','Lawrence, Mississippi',15197,42);
INSERT INTO "django_geo_db_city" VALUES(11989,'Little Rock','Little Rock, Mississippi',15198,42);
INSERT INTO "django_geo_db_city" VALUES(11990,'Louin','Louin, Mississippi',15199,42);
INSERT INTO "django_geo_db_city" VALUES(11991,'Louisville','Louisville, Mississippi',15200,42);
INSERT INTO "django_geo_db_city" VALUES(11992,'Macon','Macon, Mississippi',15201,42);
INSERT INTO "django_geo_db_city" VALUES(11993,'Marion','Marion, Mississippi',15202,42);
INSERT INTO "django_geo_db_city" VALUES(11994,'Newton','Newton, Mississippi',15203,42);
INSERT INTO "django_geo_db_city" VALUES(11995,'Noxapater','Noxapater, Mississippi',15204,42);
INSERT INTO "django_geo_db_city" VALUES(11996,'Pachuta','Pachuta, Mississippi',15205,42);
INSERT INTO "django_geo_db_city" VALUES(11997,'Paulding','Paulding, Mississippi',15206,42);
INSERT INTO "django_geo_db_city" VALUES(11998,'Philadelphia','Philadelphia, Mississippi',15207,42);
INSERT INTO "django_geo_db_city" VALUES(11999,'Porterville','Porterville, Mississippi',15208,42);
INSERT INTO "django_geo_db_city" VALUES(12000,'Preston','Preston, Mississippi',15209,42);
INSERT INTO "django_geo_db_city" VALUES(12001,'Quitman','Quitman, Mississippi',15210,42);
INSERT INTO "django_geo_db_city" VALUES(12002,'Rose Hill','Rose Hill, Mississippi',15211,42);
INSERT INTO "django_geo_db_city" VALUES(12003,'Scooba','Scooba, Mississippi',15213,42);
INSERT INTO "django_geo_db_city" VALUES(12004,'Sebastopol','Sebastopol, Mississippi',15214,42);
INSERT INTO "django_geo_db_city" VALUES(12005,'Shubuta','Shubuta, Mississippi',15215,42);
INSERT INTO "django_geo_db_city" VALUES(12006,'Shuqualak','Shuqualak, Mississippi',15216,42);
INSERT INTO "django_geo_db_city" VALUES(12007,'State Line','State Line, Mississippi',15217,42);
INSERT INTO "django_geo_db_city" VALUES(12008,'Stonewall','Stonewall, Mississippi',15218,42);
INSERT INTO "django_geo_db_city" VALUES(12009,'Toomsuba','Toomsuba, Mississippi',15219,42);
INSERT INTO "django_geo_db_city" VALUES(12010,'Union','Union, Mississippi',15220,42);
INSERT INTO "django_geo_db_city" VALUES(12011,'Vossburg','Vossburg, Mississippi',15221,42);
INSERT INTO "django_geo_db_city" VALUES(12012,'Waynesboro','Waynesboro, Mississippi',15222,42);
INSERT INTO "django_geo_db_city" VALUES(12013,'Hattiesburg','Hattiesburg, Mississippi',15223,42);
INSERT INTO "django_geo_db_city" VALUES(12014,'Bassfield','Bassfield, Mississippi',15227,42);
INSERT INTO "django_geo_db_city" VALUES(12015,'Bay Springs','Bay Springs, Mississippi',15228,42);
INSERT INTO "django_geo_db_city" VALUES(12016,'Beaumont','Beaumont, Mississippi',15229,42);
INSERT INTO "django_geo_db_city" VALUES(12017,'Brooklyn','Brooklyn, Mississippi',15230,42);
INSERT INTO "django_geo_db_city" VALUES(12018,'Carriere','Carriere, Mississippi',15231,42);
INSERT INTO "django_geo_db_city" VALUES(12019,'Carson','Carson, Mississippi',15232,42);
INSERT INTO "django_geo_db_city" VALUES(12020,'Collins','Collins, Mississippi',15233,42);
INSERT INTO "django_geo_db_city" VALUES(12021,'Columbia','Columbia, Mississippi',15234,42);
INSERT INTO "django_geo_db_city" VALUES(12022,'Eastabuchie','Eastabuchie, Mississippi',15235,42);
INSERT INTO "django_geo_db_city" VALUES(12023,'Ellisville','Ellisville, Mississippi',15236,42);
INSERT INTO "django_geo_db_city" VALUES(12024,'Heidelberg','Heidelberg, Mississippi',15237,42);
INSERT INTO "django_geo_db_city" VALUES(12025,'Laurel','Laurel, Mississippi',15238,42);
INSERT INTO "django_geo_db_city" VALUES(12026,'Leakesville','Leakesville, Mississippi',15242,42);
INSERT INTO "django_geo_db_city" VALUES(12027,'Lucedale','Lucedale, Mississippi',15243,42);
INSERT INTO "django_geo_db_city" VALUES(12028,'Lumberton','Lumberton, Mississippi',15244,42);
INSERT INTO "django_geo_db_city" VALUES(12029,'McLain','McLain, Mississippi',15245,42);
INSERT INTO "django_geo_db_city" VALUES(12030,'McNeill','McNeill, Mississippi',15246,42);
INSERT INTO "django_geo_db_city" VALUES(12031,'Moselle','Moselle, Mississippi',15247,42);
INSERT INTO "django_geo_db_city" VALUES(12032,'Moss','Moss, Mississippi',15248,42);
INSERT INTO "django_geo_db_city" VALUES(12033,'Neely','Neely, Mississippi',15249,42);
INSERT INTO "django_geo_db_city" VALUES(12034,'New Augusta','New Augusta, Mississippi',15250,42);
INSERT INTO "django_geo_db_city" VALUES(12035,'Nicholson','Nicholson, Mississippi',15251,42);
INSERT INTO "django_geo_db_city" VALUES(12036,'Ovett','Ovett, Mississippi',15252,42);
INSERT INTO "django_geo_db_city" VALUES(12037,'Petal','Petal, Mississippi',15253,42);
INSERT INTO "django_geo_db_city" VALUES(12038,'Picayune','Picayune, Mississippi',15254,42);
INSERT INTO "django_geo_db_city" VALUES(12039,'Poplarville','Poplarville, Mississippi',15255,42);
INSERT INTO "django_geo_db_city" VALUES(12040,'Prentiss','Prentiss, Mississippi',15256,42);
INSERT INTO "django_geo_db_city" VALUES(12041,'Purvis','Purvis, Mississippi',15257,42);
INSERT INTO "django_geo_db_city" VALUES(12042,'Richton','Richton, Mississippi',15258,42);
INSERT INTO "django_geo_db_city" VALUES(12043,'Sandersville','Sandersville, Mississippi',15259,42);
INSERT INTO "django_geo_db_city" VALUES(12044,'Sandy Hook','Sandy Hook, Mississippi',15260,42);
INSERT INTO "django_geo_db_city" VALUES(12045,'Seminary','Seminary, Mississippi',15261,42);
INSERT INTO "django_geo_db_city" VALUES(12046,'Soso','Soso, Mississippi',15262,42);
INSERT INTO "django_geo_db_city" VALUES(12047,'Stringer','Stringer, Mississippi',15263,42);
INSERT INTO "django_geo_db_city" VALUES(12048,'Sumrall','Sumrall, Mississippi',15264,42);
INSERT INTO "django_geo_db_city" VALUES(12049,'Foxworth','Foxworth, Mississippi',15265,42);
INSERT INTO "django_geo_db_city" VALUES(12050,'Gulfport','Gulfport, Mississippi',15266,42);
INSERT INTO "django_geo_db_city" VALUES(12051,'Bay Saint Louis','Bay Saint Louis, Mississippi',15270,42);
INSERT INTO "django_geo_db_city" VALUES(12052,'Stennis Space Center','Stennis Space Center, Mississippi',15271,42);
INSERT INTO "django_geo_db_city" VALUES(12053,'Diamondhead','Diamondhead, Mississippi',15272,42);
INSERT INTO "django_geo_db_city" VALUES(12054,'Biloxi','Biloxi, Mississippi',15273,42);
INSERT INTO "django_geo_db_city" VALUES(12055,'D''Iberville','D''Iberville, Mississippi',15276,42);
INSERT INTO "django_geo_db_city" VALUES(12056,'Escatawpa','Escatawpa, Mississippi',15277,42);
INSERT INTO "django_geo_db_city" VALUES(12057,'Gautier','Gautier, Mississippi',15278,42);
INSERT INTO "django_geo_db_city" VALUES(12058,'Hurley','Hurley, Mississippi',15279,42);
INSERT INTO "django_geo_db_city" VALUES(12059,'Kiln','Kiln, Mississippi',15280,42);
INSERT INTO "django_geo_db_city" VALUES(12060,'Lakeshore','Lakeshore, Mississippi',15281,42);
INSERT INTO "django_geo_db_city" VALUES(12061,'Long Beach','Long Beach, Mississippi',15282,42);
INSERT INTO "django_geo_db_city" VALUES(12062,'McHenry','McHenry, Mississippi',15283,42);
INSERT INTO "django_geo_db_city" VALUES(12063,'Moss Point','Moss Point, Mississippi',15284,42);
INSERT INTO "django_geo_db_city" VALUES(12064,'Ocean Springs','Ocean Springs, Mississippi',15286,42);
INSERT INTO "django_geo_db_city" VALUES(12065,'Pascagoula','Pascagoula, Mississippi',15288,42);
INSERT INTO "django_geo_db_city" VALUES(12066,'Pass Christian','Pass Christian, Mississippi',15289,42);
INSERT INTO "django_geo_db_city" VALUES(12067,'Pearlington','Pearlington, Mississippi',15290,42);
INSERT INTO "django_geo_db_city" VALUES(12068,'Perkinston','Perkinston, Mississippi',15291,42);
INSERT INTO "django_geo_db_city" VALUES(12069,'Saucier','Saucier, Mississippi',15292,42);
INSERT INTO "django_geo_db_city" VALUES(12070,'Waveland','Waveland, Mississippi',15293,42);
INSERT INTO "django_geo_db_city" VALUES(12071,'Wiggins','Wiggins, Mississippi',15294,42);
INSERT INTO "django_geo_db_city" VALUES(12072,'Brookhaven','Brookhaven, Mississippi',15297,42);
INSERT INTO "django_geo_db_city" VALUES(12073,'Bogue Chitto','Bogue Chitto, Mississippi',15300,42);
INSERT INTO "django_geo_db_city" VALUES(12074,'Bude','Bude, Mississippi',15301,42);
INSERT INTO "django_geo_db_city" VALUES(12075,'Centreville','Centreville, Mississippi',15302,42);
INSERT INTO "django_geo_db_city" VALUES(12076,'Chatawa','Chatawa, Mississippi',15303,42);
INSERT INTO "django_geo_db_city" VALUES(12077,'Crosby','Crosby, Mississippi',15304,42);
INSERT INTO "django_geo_db_city" VALUES(12078,'Fernwood','Fernwood, Mississippi',15305,42);
INSERT INTO "django_geo_db_city" VALUES(12079,'Gloster','Gloster, Mississippi',15306,42);
INSERT INTO "django_geo_db_city" VALUES(12080,'Jayess','Jayess, Mississippi',15307,42);
INSERT INTO "django_geo_db_city" VALUES(12081,'Kokomo','Kokomo, Mississippi',15308,42);
INSERT INTO "django_geo_db_city" VALUES(12082,'Liberty','Liberty, Mississippi',15309,42);
INSERT INTO "django_geo_db_city" VALUES(12083,'McCall Creek','McCall Creek, Mississippi',15310,42);
INSERT INTO "django_geo_db_city" VALUES(12084,'Mccomb','Mccomb, Mississippi',15311,42);
INSERT INTO "django_geo_db_city" VALUES(12085,'Magnolia','Magnolia, Mississippi',15313,42);
INSERT INTO "django_geo_db_city" VALUES(12086,'Meadville','Meadville, Mississippi',15314,42);
INSERT INTO "django_geo_db_city" VALUES(12087,'Monticello','Monticello, Mississippi',15315,42);
INSERT INTO "django_geo_db_city" VALUES(12088,'Oak Vale','Oak Vale, Mississippi',15316,42);
INSERT INTO "django_geo_db_city" VALUES(12089,'Osyka','Osyka, Mississippi',15317,42);
INSERT INTO "django_geo_db_city" VALUES(12090,'McComb','McComb, Mississippi',15318,42);
INSERT INTO "django_geo_db_city" VALUES(12091,'Roxie','Roxie, Mississippi',15319,42);
INSERT INTO "django_geo_db_city" VALUES(12092,'Ruth','Ruth, Mississippi',15320,42);
INSERT INTO "django_geo_db_city" VALUES(12093,'Silver Creek','Silver Creek, Mississippi',15321,42);
INSERT INTO "django_geo_db_city" VALUES(12094,'Smithdale','Smithdale, Mississippi',15322,42);
INSERT INTO "django_geo_db_city" VALUES(12095,'Sontag','Sontag, Mississippi',15323,42);
INSERT INTO "django_geo_db_city" VALUES(12096,'Summit','Summit, Mississippi',15324,42);
INSERT INTO "django_geo_db_city" VALUES(12097,'Tylertown','Tylertown, Mississippi',15325,42);
INSERT INTO "django_geo_db_city" VALUES(12098,'Union Church','Union Church, Mississippi',15326,42);
INSERT INTO "django_geo_db_city" VALUES(12099,'Woodville','Woodville, Mississippi',15327,42);
INSERT INTO "django_geo_db_city" VALUES(12100,'Columbus','Columbus, Mississippi',15328,42);
INSERT INTO "django_geo_db_city" VALUES(12101,'Aberdeen','Aberdeen, Mississippi',15334,42);
INSERT INTO "django_geo_db_city" VALUES(12102,'Brooksville','Brooksville, Mississippi',15335,42);
INSERT INTO "django_geo_db_city" VALUES(12103,'Ackerman','Ackerman, Mississippi',15336,42);
INSERT INTO "django_geo_db_city" VALUES(12104,'Artesia','Artesia, Mississippi',15337,42);
INSERT INTO "django_geo_db_city" VALUES(12105,'Bellefontaine','Bellefontaine, Mississippi',15338,42);
INSERT INTO "django_geo_db_city" VALUES(12106,'Caledonia','Caledonia, Mississippi',15340,42);
INSERT INTO "django_geo_db_city" VALUES(12107,'Cedarbluff','Cedarbluff, Mississippi',15341,42);
INSERT INTO "django_geo_db_city" VALUES(12108,'Crawford','Crawford, Mississippi',15342,42);
INSERT INTO "django_geo_db_city" VALUES(12109,'Eupora','Eupora, Mississippi',15343,42);
INSERT INTO "django_geo_db_city" VALUES(12110,'French Camp','French Camp, Mississippi',15344,42);
INSERT INTO "django_geo_db_city" VALUES(12111,'Hamilton','Hamilton, Mississippi',15345,42);
INSERT INTO "django_geo_db_city" VALUES(12112,'Kilmichael','Kilmichael, Mississippi',15346,42);
INSERT INTO "django_geo_db_city" VALUES(12113,'Maben','Maben, Mississippi',15347,42);
INSERT INTO "django_geo_db_city" VALUES(12114,'Mantee','Mantee, Mississippi',15348,42);
INSERT INTO "django_geo_db_city" VALUES(12115,'Mathiston','Mathiston, Mississippi',15349,42);
INSERT INTO "django_geo_db_city" VALUES(12116,'Mayhew','Mayhew, Mississippi',15350,42);
INSERT INTO "django_geo_db_city" VALUES(12117,'Montpelier','Montpelier, Mississippi',15351,42);
INSERT INTO "django_geo_db_city" VALUES(12118,'Pheba','Pheba, Mississippi',15352,42);
INSERT INTO "django_geo_db_city" VALUES(12119,'Prairie','Prairie, Mississippi',15353,42);
INSERT INTO "django_geo_db_city" VALUES(12120,'Sturgis','Sturgis, Mississippi',15354,42);
INSERT INTO "django_geo_db_city" VALUES(12121,'Starkville','Starkville, Mississippi',15355,42);
INSERT INTO "django_geo_db_city" VALUES(12122,'Mississippi State','Mississippi State, Mississippi',15357,42);
INSERT INTO "django_geo_db_city" VALUES(12123,'Steens','Steens, Mississippi',15358,42);
INSERT INTO "django_geo_db_city" VALUES(12124,'Stewart','Stewart, Mississippi',15359,42);
INSERT INTO "django_geo_db_city" VALUES(12125,'Walthall','Walthall, Mississippi',15361,42);
INSERT INTO "django_geo_db_city" VALUES(12126,'Weir','Weir, Mississippi',15362,42);
INSERT INTO "django_geo_db_city" VALUES(12127,'West Point','West Point, Mississippi',15363,42);
INSERT INTO "django_geo_db_city" VALUES(12128,'Woodland','Woodland, Mississippi',15364,42);
INSERT INTO "django_geo_db_city" VALUES(12129,'Bagdad','Bagdad, Kentucky',15368,21);
INSERT INTO "django_geo_db_city" VALUES(12130,'Bardstown','Bardstown, Kentucky',15369,21);
INSERT INTO "django_geo_db_city" VALUES(12131,'Bedford','Bedford, Kentucky',15370,21);
INSERT INTO "django_geo_db_city" VALUES(12132,'Bethlehem','Bethlehem, Kentucky',15371,21);
INSERT INTO "django_geo_db_city" VALUES(12133,'Bloomfield','Bloomfield, Kentucky',15372,21);
INSERT INTO "django_geo_db_city" VALUES(12134,'Bradfordsville','Bradfordsville, Kentucky',15373,21);
INSERT INTO "django_geo_db_city" VALUES(12135,'Buckner','Buckner, Kentucky',15374,21);
INSERT INTO "django_geo_db_city" VALUES(12136,'Campbellsburg','Campbellsburg, Kentucky',15375,21);
INSERT INTO "django_geo_db_city" VALUES(12137,'Chaplin','Chaplin, Kentucky',15376,21);
INSERT INTO "django_geo_db_city" VALUES(12138,'Coxs Creek','Coxs Creek, Kentucky',15377,21);
INSERT INTO "django_geo_db_city" VALUES(12139,'Crestwood','Crestwood, Kentucky',15378,21);
INSERT INTO "django_geo_db_city" VALUES(12140,'Eastwood','Eastwood, Kentucky',15379,21);
INSERT INTO "django_geo_db_city" VALUES(12141,'Eminence','Eminence, Kentucky',15380,21);
INSERT INTO "django_geo_db_city" VALUES(12142,'Fairfield','Fairfield, Kentucky',15381,21);
INSERT INTO "django_geo_db_city" VALUES(12143,'Finchville','Finchville, Kentucky',15382,21);
INSERT INTO "django_geo_db_city" VALUES(12144,'Fisherville','Fisherville, Kentucky',15383,21);
INSERT INTO "django_geo_db_city" VALUES(12145,'Glenview','Glenview, Kentucky',15384,21);
INSERT INTO "django_geo_db_city" VALUES(12146,'Goshen','Goshen, Kentucky',15385,21);
INSERT INTO "django_geo_db_city" VALUES(12147,'Harrods Creek','Harrods Creek, Kentucky',15386,21);
INSERT INTO "django_geo_db_city" VALUES(12148,'La Grange','La Grange, Kentucky',15387,21);
INSERT INTO "django_geo_db_city" VALUES(12149,'Lebanon','Lebanon, Kentucky',15389,21);
INSERT INTO "django_geo_db_city" VALUES(12150,'Lockport','Lockport, Kentucky',15390,21);
INSERT INTO "django_geo_db_city" VALUES(12151,'Loretto','Loretto, Kentucky',15391,21);
INSERT INTO "django_geo_db_city" VALUES(12152,'Mackville','Mackville, Kentucky',15392,21);
INSERT INTO "django_geo_db_city" VALUES(12153,'Masonic Home','Masonic Home, Kentucky',15393,21);
INSERT INTO "django_geo_db_city" VALUES(12154,'Milton','Milton, Kentucky',15394,21);
INSERT INTO "django_geo_db_city" VALUES(12155,'Mount Eden','Mount Eden, Kentucky',15395,21);
INSERT INTO "django_geo_db_city" VALUES(12156,'Mount Washington','Mount Washington, Kentucky',15396,21);
INSERT INTO "django_geo_db_city" VALUES(12157,'Nazareth','Nazareth, Kentucky',15397,21);
INSERT INTO "django_geo_db_city" VALUES(12158,'Nerinx','Nerinx, Kentucky',15398,21);
INSERT INTO "django_geo_db_city" VALUES(12159,'New Castle','New Castle, Kentucky',15399,21);
INSERT INTO "django_geo_db_city" VALUES(12160,'New Haven','New Haven, Kentucky',15400,21);
INSERT INTO "django_geo_db_city" VALUES(12161,'New Hope','New Hope, Kentucky',15401,21);
INSERT INTO "django_geo_db_city" VALUES(12162,'Pewee Valley','Pewee Valley, Kentucky',15402,21);
INSERT INTO "django_geo_db_city" VALUES(12163,'Pendleton','Pendleton, Kentucky',15403,21);
INSERT INTO "django_geo_db_city" VALUES(12164,'Pleasureville','Pleasureville, Kentucky',15405,21);
INSERT INTO "django_geo_db_city" VALUES(12165,'Port Royal','Port Royal, Kentucky',15406,21);
INSERT INTO "django_geo_db_city" VALUES(12166,'Prospect','Prospect, Kentucky',15407,21);
INSERT INTO "django_geo_db_city" VALUES(12167,'Raywick','Raywick, Kentucky',15408,21);
INSERT INTO "django_geo_db_city" VALUES(12168,'Saint Catharine','Saint Catharine, Kentucky',15409,21);
INSERT INTO "django_geo_db_city" VALUES(12169,'Saint Francis','Saint Francis, Kentucky',15410,21);
INSERT INTO "django_geo_db_city" VALUES(12170,'Saint Mary','Saint Mary, Kentucky',15411,21);
INSERT INTO "django_geo_db_city" VALUES(12171,'Shelbyville','Shelbyville, Kentucky',15412,21);
INSERT INTO "django_geo_db_city" VALUES(12172,'Simpsonville','Simpsonville, Kentucky',15414,21);
INSERT INTO "django_geo_db_city" VALUES(12173,'Smithfield','Smithfield, Kentucky',15415,21);
INSERT INTO "django_geo_db_city" VALUES(12174,'Springfield','Springfield, Kentucky',15416,21);
INSERT INTO "django_geo_db_city" VALUES(12175,'Sulphur','Sulphur, Kentucky',15417,21);
INSERT INTO "django_geo_db_city" VALUES(12176,'Taylorsville','Taylorsville, Kentucky',15418,21);
INSERT INTO "django_geo_db_city" VALUES(12177,'Turners Station','Turners Station, Kentucky',15419,21);
INSERT INTO "django_geo_db_city" VALUES(12178,'Waddy','Waddy, Kentucky',15420,21);
INSERT INTO "django_geo_db_city" VALUES(12179,'Westport','Westport, Kentucky',15421,21);
INSERT INTO "django_geo_db_city" VALUES(12180,'Willisburg','Willisburg, Kentucky',15422,21);
INSERT INTO "django_geo_db_city" VALUES(12181,'Battletown','Battletown, Kentucky',15425,21);
INSERT INTO "django_geo_db_city" VALUES(12182,'Big Spring','Big Spring, Kentucky',15426,21);
INSERT INTO "django_geo_db_city" VALUES(12183,'Boston','Boston, Kentucky',15427,21);
INSERT INTO "django_geo_db_city" VALUES(12184,'Brandenburg','Brandenburg, Kentucky',15428,21);
INSERT INTO "django_geo_db_city" VALUES(12185,'Brooks','Brooks, Kentucky',15429,21);
INSERT INTO "django_geo_db_city" VALUES(12186,'Clermont','Clermont, Kentucky',15430,21);
INSERT INTO "django_geo_db_city" VALUES(12187,'Cloverport','Cloverport, Kentucky',15431,21);
INSERT INTO "django_geo_db_city" VALUES(12188,'Custer','Custer, Kentucky',15432,21);
INSERT INTO "django_geo_db_city" VALUES(12189,'Ekron','Ekron, Kentucky',15433,21);
INSERT INTO "django_geo_db_city" VALUES(12190,'Fairdale','Fairdale, Kentucky',15434,21);
INSERT INTO "django_geo_db_city" VALUES(12191,'Falls Of Rough','Falls Of Rough, Kentucky',15435,21);
INSERT INTO "django_geo_db_city" VALUES(12192,'Fort Knox','Fort Knox, Kentucky',15436,21);
INSERT INTO "django_geo_db_city" VALUES(12193,'Garfield','Garfield, Kentucky',15437,21);
INSERT INTO "django_geo_db_city" VALUES(12194,'Guston','Guston, Kentucky',15438,21);
INSERT INTO "django_geo_db_city" VALUES(12195,'Hardinsburg','Hardinsburg, Kentucky',15439,21);
INSERT INTO "django_geo_db_city" VALUES(12196,'Harned','Harned, Kentucky',15440,21);
INSERT INTO "django_geo_db_city" VALUES(12197,'Hudson','Hudson, Kentucky',15441,21);
INSERT INTO "django_geo_db_city" VALUES(12198,'Irvington','Irvington, Kentucky',15442,21);
INSERT INTO "django_geo_db_city" VALUES(12199,'Lebanon Junction','Lebanon Junction, Kentucky',15443,21);
INSERT INTO "django_geo_db_city" VALUES(12200,'McDaniels','McDaniels, Kentucky',15444,21);
INSERT INTO "django_geo_db_city" VALUES(12201,'McQuady','McQuady, Kentucky',15445,21);
INSERT INTO "django_geo_db_city" VALUES(12202,'Muldraugh','Muldraugh, Kentucky',15446,21);
INSERT INTO "django_geo_db_city" VALUES(12203,'Payneville','Payneville, Kentucky',15447,21);
INSERT INTO "django_geo_db_city" VALUES(12204,'Radcliff','Radcliff, Kentucky',15448,21);
INSERT INTO "django_geo_db_city" VALUES(12205,'Rhodelia','Rhodelia, Kentucky',15450,21);
INSERT INTO "django_geo_db_city" VALUES(12206,'Rineyville','Rineyville, Kentucky',15451,21);
INSERT INTO "django_geo_db_city" VALUES(12207,'Se Ree','Se Ree, Kentucky',15452,21);
INSERT INTO "django_geo_db_city" VALUES(12208,'Shepherdsville','Shepherdsville, Kentucky',15453,21);
INSERT INTO "django_geo_db_city" VALUES(12209,'Stephensport','Stephensport, Kentucky',15454,21);
INSERT INTO "django_geo_db_city" VALUES(12210,'Union Star','Union Star, Kentucky',15455,21);
INSERT INTO "django_geo_db_city" VALUES(12211,'Vine Grove','Vine Grove, Kentucky',15456,21);
INSERT INTO "django_geo_db_city" VALUES(12212,'Webster','Webster, Kentucky',15457,21);
INSERT INTO "django_geo_db_city" VALUES(12213,'West Point','West Point, Kentucky',15458,21);
INSERT INTO "django_geo_db_city" VALUES(12214,'Westview','Westview, Kentucky',15459,21);
INSERT INTO "django_geo_db_city" VALUES(12215,'Louisville','Louisville, Kentucky',15461,21);
INSERT INTO "django_geo_db_city" VALUES(12216,'Burgin','Burgin, Kentucky',15494,21);
INSERT INTO "django_geo_db_city" VALUES(12217,'Carlisle','Carlisle, Kentucky',15495,21);
INSERT INTO "django_geo_db_city" VALUES(12218,'Clay City','Clay City, Kentucky',15496,21);
INSERT INTO "django_geo_db_city" VALUES(12219,'Clearfield','Clearfield, Kentucky',15497,21);
INSERT INTO "django_geo_db_city" VALUES(12220,'Denniston','Denniston, Kentucky',15498,21);
INSERT INTO "django_geo_db_city" VALUES(12221,'Elliottville','Elliottville, Kentucky',15499,21);
INSERT INTO "django_geo_db_city" VALUES(12222,'Farmers','Farmers, Kentucky',15500,21);
INSERT INTO "django_geo_db_city" VALUES(12223,'Ford','Ford, Kentucky',15501,21);
INSERT INTO "django_geo_db_city" VALUES(12224,'Frenchburg','Frenchburg, Kentucky',15502,21);
INSERT INTO "django_geo_db_city" VALUES(12225,'Georgetown','Georgetown, Kentucky',15503,21);
INSERT INTO "django_geo_db_city" VALUES(12226,'Gravel Switch','Gravel Switch, Kentucky',15504,21);
INSERT INTO "django_geo_db_city" VALUES(12227,'Haldeman','Haldeman, Kentucky',15505,21);
INSERT INTO "django_geo_db_city" VALUES(12228,'Harrodsburg','Harrodsburg, Kentucky',15506,21);
INSERT INTO "django_geo_db_city" VALUES(12229,'Hope','Hope, Kentucky',15507,21);
INSERT INTO "django_geo_db_city" VALUES(12230,'Irvine','Irvine, Kentucky',15508,21);
INSERT INTO "django_geo_db_city" VALUES(12231,'Jeffersonville','Jeffersonville, Kentucky',15509,21);
INSERT INTO "django_geo_db_city" VALUES(12232,'Keene','Keene, Kentucky',15510,21);
INSERT INTO "django_geo_db_city" VALUES(12233,'Nicholasville','Nicholasville, Kentucky',15511,21);
INSERT INTO "django_geo_db_city" VALUES(12234,'Lawrenceburg','Lawrenceburg, Kentucky',15512,21);
INSERT INTO "django_geo_db_city" VALUES(12235,'Means','Means, Kentucky',15513,21);
INSERT INTO "django_geo_db_city" VALUES(12236,'Midway','Midway, Kentucky',15514,21);
INSERT INTO "django_geo_db_city" VALUES(12237,'Millersburg','Millersburg, Kentucky',15515,21);
INSERT INTO "django_geo_db_city" VALUES(12238,'Moorefield','Moorefield, Kentucky',15516,21);
INSERT INTO "django_geo_db_city" VALUES(12239,'Morehead','Morehead, Kentucky',15517,21);
INSERT INTO "django_geo_db_city" VALUES(12240,'Mount Sterling','Mount Sterling, Kentucky',15518,21);
INSERT INTO "django_geo_db_city" VALUES(12241,'New Liberty','New Liberty, Kentucky',15519,21);
INSERT INTO "django_geo_db_city" VALUES(12242,'North Middletown','North Middletown, Kentucky',15521,21);
INSERT INTO "django_geo_db_city" VALUES(12243,'Olympia','Olympia, Kentucky',15522,21);
INSERT INTO "django_geo_db_city" VALUES(12244,'Owenton','Owenton, Kentucky',15523,21);
INSERT INTO "django_geo_db_city" VALUES(12245,'Owingsville','Owingsville, Kentucky',15524,21);
INSERT INTO "django_geo_db_city" VALUES(12246,'Paris','Paris, Kentucky',15525,21);
INSERT INTO "django_geo_db_city" VALUES(12247,'Perry Park','Perry Park, Kentucky',15527,21);
INSERT INTO "django_geo_db_city" VALUES(12248,'Preston','Preston, Kentucky',15528,21);
INSERT INTO "django_geo_db_city" VALUES(12249,'Sadieville','Sadieville, Kentucky',15529,21);
INSERT INTO "django_geo_db_city" VALUES(12250,'Salt Lick','Salt Lick, Kentucky',15530,21);
INSERT INTO "django_geo_db_city" VALUES(12251,'Salvisa','Salvisa, Kentucky',15531,21);
INSERT INTO "django_geo_db_city" VALUES(12252,'Sharpsburg','Sharpsburg, Kentucky',15532,21);
INSERT INTO "django_geo_db_city" VALUES(12253,'Slade','Slade, Kentucky',15533,21);
INSERT INTO "django_geo_db_city" VALUES(12254,'Stamping Ground','Stamping Ground, Kentucky',15534,21);
INSERT INTO "django_geo_db_city" VALUES(12255,'Stanton','Stanton, Kentucky',15535,21);
INSERT INTO "django_geo_db_city" VALUES(12256,'Versailles','Versailles, Kentucky',15536,21);
INSERT INTO "django_geo_db_city" VALUES(12257,'Waco','Waco, Kentucky',15538,21);
INSERT INTO "django_geo_db_city" VALUES(12258,'Wellington','Wellington, Kentucky',15539,21);
INSERT INTO "django_geo_db_city" VALUES(12259,'Wilmore','Wilmore, Kentucky',15540,21);
INSERT INTO "django_geo_db_city" VALUES(12260,'Winchester','Winchester, Kentucky',15541,21);
INSERT INTO "django_geo_db_city" VALUES(12261,'Annville','Annville, Kentucky',15542,21);
INSERT INTO "django_geo_db_city" VALUES(12262,'Berea','Berea, Kentucky',15543,21);
INSERT INTO "django_geo_db_city" VALUES(12263,'Bighill','Bighill, Kentucky',15544,21);
INSERT INTO "django_geo_db_city" VALUES(12264,'Brodhead','Brodhead, Kentucky',15545,21);
INSERT INTO "django_geo_db_city" VALUES(12265,'Bryantsville','Bryantsville, Kentucky',15546,21);
INSERT INTO "django_geo_db_city" VALUES(12266,'Crab Orchard','Crab Orchard, Kentucky',15547,21);
INSERT INTO "django_geo_db_city" VALUES(12267,'Dabolt','Dabolt, Kentucky',15548,21);
INSERT INTO "django_geo_db_city" VALUES(12268,'Danville','Danville, Kentucky',15549,21);
INSERT INTO "django_geo_db_city" VALUES(12269,'Gray Hawk','Gray Hawk, Kentucky',15551,21);
INSERT INTO "django_geo_db_city" VALUES(12270,'Hustonville','Hustonville, Kentucky',15552,21);
INSERT INTO "django_geo_db_city" VALUES(12271,'Junction City','Junction City, Kentucky',15553,21);
INSERT INTO "django_geo_db_city" VALUES(12272,'Kings Mountain','Kings Mountain, Kentucky',15554,21);
INSERT INTO "django_geo_db_city" VALUES(12273,'Lancaster','Lancaster, Kentucky',15555,21);
INSERT INTO "django_geo_db_city" VALUES(12274,'Livingston','Livingston, Kentucky',15556,21);
INSERT INTO "django_geo_db_city" VALUES(12275,'McKee','McKee, Kentucky',15557,21);
INSERT INTO "django_geo_db_city" VALUES(12276,'McKinney','McKinney, Kentucky',15558,21);
INSERT INTO "django_geo_db_city" VALUES(12277,'Mitchellsburg','Mitchellsburg, Kentucky',15559,21);
INSERT INTO "django_geo_db_city" VALUES(12278,'Mount Vernon','Mount Vernon, Kentucky',15560,21);
INSERT INTO "django_geo_db_city" VALUES(12279,'Orlando','Orlando, Kentucky',15561,21);
INSERT INTO "django_geo_db_city" VALUES(12280,'Paint Lick','Paint Lick, Kentucky',15562,21);
INSERT INTO "django_geo_db_city" VALUES(12281,'Parksville','Parksville, Kentucky',15563,21);
INSERT INTO "django_geo_db_city" VALUES(12282,'Peoples','Peoples, Kentucky',15548,21);
INSERT INTO "django_geo_db_city" VALUES(12283,'Perryville','Perryville, Kentucky',15564,21);
INSERT INTO "django_geo_db_city" VALUES(12284,'Ravenna','Ravenna, Kentucky',15566,21);
INSERT INTO "django_geo_db_city" VALUES(12285,'Renfro Valley','Renfro Valley, Kentucky',15567,21);
INSERT INTO "django_geo_db_city" VALUES(12286,'Richmond','Richmond, Kentucky',15568,21);
INSERT INTO "django_geo_db_city" VALUES(12287,'Sandgap','Sandgap, Kentucky',15569,21);
INSERT INTO "django_geo_db_city" VALUES(12288,'Stanford','Stanford, Kentucky',15570,21);
INSERT INTO "django_geo_db_city" VALUES(12289,'Tyner','Tyner, Kentucky',15571,21);
INSERT INTO "django_geo_db_city" VALUES(12290,'Waneta','Waneta, Kentucky',15572,21);
INSERT INTO "django_geo_db_city" VALUES(12291,'Waynesburg','Waynesburg, Kentucky',15573,21);
INSERT INTO "django_geo_db_city" VALUES(12292,'Wildie','Wildie, Kentucky',15567,21);
INSERT INTO "django_geo_db_city" VALUES(12293,'Winston','Winston, Kentucky',15574,21);
INSERT INTO "django_geo_db_city" VALUES(12294,'Lexington','Lexington, Kentucky',15575,21);
INSERT INTO "django_geo_db_city" VALUES(12295,'Frankfort','Frankfort, Kentucky',15593,21);
INSERT INTO "django_geo_db_city" VALUES(12296,'Middlesborough','Middlesborough, Kentucky',15595,21);
INSERT INTO "django_geo_db_city" VALUES(12297,'Corbin','Corbin, Kentucky',15596,21);
INSERT INTO "django_geo_db_city" VALUES(12298,'Bush','Bush, Kentucky',15598,21);
INSERT INTO "django_geo_db_city" VALUES(12299,'East Bernstadt','East Bernstadt, Kentucky',15599,21);
INSERT INTO "django_geo_db_city" VALUES(12300,'Emlyn','Emlyn, Kentucky',15600,21);
INSERT INTO "django_geo_db_city" VALUES(12301,'Gray','Gray, Kentucky',15601,21);
INSERT INTO "django_geo_db_city" VALUES(12302,'Keavy','Keavy, Kentucky',15602,21);
INSERT INTO "django_geo_db_city" VALUES(12303,'Lily','Lily, Kentucky',15603,21);
INSERT INTO "django_geo_db_city" VALUES(12304,'London','London, Kentucky',15604,21);
INSERT INTO "django_geo_db_city" VALUES(12305,'Marydell','Marydell, Kentucky',15605,21);
INSERT INTO "django_geo_db_city" VALUES(12306,'Nevisdale','Nevisdale, Kentucky',15608,21);
INSERT INTO "django_geo_db_city" VALUES(12307,'Pittsburg','Pittsburg, Kentucky',15609,21);
INSERT INTO "django_geo_db_city" VALUES(12308,'Rockholds','Rockholds, Kentucky',15610,21);
INSERT INTO "django_geo_db_city" VALUES(12309,'Siler','Siler, Kentucky',15611,21);
INSERT INTO "django_geo_db_city" VALUES(12310,'Williamsburg','Williamsburg, Kentucky',15612,21);
INSERT INTO "django_geo_db_city" VALUES(12311,'Woodbine','Woodbine, Kentucky',15613,21);
INSERT INTO "django_geo_db_city" VALUES(12312,'Ages Brookside','Ages Brookside, Kentucky',15614,21);
INSERT INTO "django_geo_db_city" VALUES(12313,'Asher','Asher, Kentucky',15615,21);
INSERT INTO "django_geo_db_city" VALUES(12314,'Baxter','Baxter, Kentucky',15616,21);
INSERT INTO "django_geo_db_city" VALUES(12315,'Benham','Benham, Kentucky',15617,21);
INSERT INTO "django_geo_db_city" VALUES(12316,'Big Laurel','Big Laurel, Kentucky',15618,21);
INSERT INTO "django_geo_db_city" VALUES(12317,'Bledsoe','Bledsoe, Kentucky',15619,21);
INSERT INTO "django_geo_db_city" VALUES(12318,'Calvin','Calvin, Kentucky',15620,21);
INSERT INTO "django_geo_db_city" VALUES(12319,'Cawood','Cawood, Kentucky',15621,21);
INSERT INTO "django_geo_db_city" VALUES(12320,'Chappell','Chappell, Kentucky',15622,21);
INSERT INTO "django_geo_db_city" VALUES(12321,'Coalgood','Coalgood, Kentucky',15623,21);
INSERT INTO "django_geo_db_city" VALUES(12322,'Coldiron','Coldiron, Kentucky',15624,21);
INSERT INTO "django_geo_db_city" VALUES(12323,'Cranks','Cranks, Kentucky',15625,21);
INSERT INTO "django_geo_db_city" VALUES(12324,'Cumberland','Cumberland, Kentucky',15626,21);
INSERT INTO "django_geo_db_city" VALUES(12325,'Dayhoit','Dayhoit, Kentucky',15627,21);
INSERT INTO "django_geo_db_city" VALUES(12326,'Eolia','Eolia, Kentucky',15628,21);
INSERT INTO "django_geo_db_city" VALUES(12327,'Essie','Essie, Kentucky',15629,21);
INSERT INTO "django_geo_db_city" VALUES(12328,'Evarts','Evarts, Kentucky',15630,21);
INSERT INTO "django_geo_db_city" VALUES(12329,'Grays Knob','Grays Knob, Kentucky',15631,21);
INSERT INTO "django_geo_db_city" VALUES(12330,'Gulston','Gulston, Kentucky',15632,21);
INSERT INTO "django_geo_db_city" VALUES(12331,'Harlan','Harlan, Kentucky',15633,21);
INSERT INTO "django_geo_db_city" VALUES(12332,'Helton','Helton, Kentucky',15634,21);
INSERT INTO "django_geo_db_city" VALUES(12333,'Holmes Mill','Holmes Mill, Kentucky',15635,21);
INSERT INTO "django_geo_db_city" VALUES(12334,'Hoskinston','Hoskinston, Kentucky',15636,21);
INSERT INTO "django_geo_db_city" VALUES(12335,'Hulen','Hulen, Kentucky',15637,21);
INSERT INTO "django_geo_db_city" VALUES(12336,'Kenvir','Kenvir, Kentucky',15638,21);
INSERT INTO "django_geo_db_city" VALUES(12337,'Lejunior','Lejunior, Kentucky',15639,21);
INSERT INTO "django_geo_db_city" VALUES(12338,'Loyall','Loyall, Kentucky',15640,21);
INSERT INTO "django_geo_db_city" VALUES(12339,'Lynch','Lynch, Kentucky',15641,21);
INSERT INTO "django_geo_db_city" VALUES(12340,'Miracle','Miracle, Kentucky',15642,21);
INSERT INTO "django_geo_db_city" VALUES(12341,'Mozelle','Mozelle, Kentucky',15643,21);
INSERT INTO "django_geo_db_city" VALUES(12342,'Partridge','Partridge, Kentucky',15644,21);
INSERT INTO "django_geo_db_city" VALUES(12343,'Pathfork','Pathfork, Kentucky',15645,21);
INSERT INTO "django_geo_db_city" VALUES(12344,'Putney','Putney, Kentucky',15646,21);
INSERT INTO "django_geo_db_city" VALUES(12345,'Smith','Smith, Kentucky',15647,21);
INSERT INTO "django_geo_db_city" VALUES(12346,'Stinnett','Stinnett, Kentucky',15648,21);
INSERT INTO "django_geo_db_city" VALUES(12347,'Totz','Totz, Kentucky',15649,21);
INSERT INTO "django_geo_db_city" VALUES(12348,'Wallins Creek','Wallins Creek, Kentucky',15650,21);
INSERT INTO "django_geo_db_city" VALUES(12349,'Warbranch','Warbranch, Kentucky',15651,21);
INSERT INTO "django_geo_db_city" VALUES(12350,'Arjay','Arjay, Kentucky',15652,21);
INSERT INTO "django_geo_db_city" VALUES(12351,'Artemus','Artemus, Kentucky',15653,21);
INSERT INTO "django_geo_db_city" VALUES(12352,'Barbourville','Barbourville, Kentucky',15654,21);
INSERT INTO "django_geo_db_city" VALUES(12353,'Beverly','Beverly, Kentucky',15655,21);
INSERT INTO "django_geo_db_city" VALUES(12354,'Big Creek','Big Creek, Kentucky',15656,21);
INSERT INTO "django_geo_db_city" VALUES(12355,'Bimble','Bimble, Kentucky',15657,21);
INSERT INTO "django_geo_db_city" VALUES(12356,'Bryants Store','Bryants Store, Kentucky',15658,21);
INSERT INTO "django_geo_db_city" VALUES(12357,'Cannon','Cannon, Kentucky',15659,21);
INSERT INTO "django_geo_db_city" VALUES(12358,'Closplint','Closplint, Kentucky',15660,21);
INSERT INTO "django_geo_db_city" VALUES(12359,'Dewitt','Dewitt, Kentucky',15661,21);
INSERT INTO "django_geo_db_city" VALUES(12360,'Eriline','Eriline, Kentucky',15662,21);
INSERT INTO "django_geo_db_city" VALUES(12361,'Fall Rock','Fall Rock, Kentucky',15662,21);
INSERT INTO "django_geo_db_city" VALUES(12362,'Flat Lick','Flat Lick, Kentucky',15663,21);
INSERT INTO "django_geo_db_city" VALUES(12363,'Fourmile','Fourmile, Kentucky',15664,21);
INSERT INTO "django_geo_db_city" VALUES(12364,'Frakes','Frakes, Kentucky',15665,21);
INSERT INTO "django_geo_db_city" VALUES(12365,'Garrard','Garrard, Kentucky',15666,21);
INSERT INTO "django_geo_db_city" VALUES(12366,'Girdler','Girdler, Kentucky',15667,21);
INSERT INTO "django_geo_db_city" VALUES(12367,'Goose Rock','Goose Rock, Kentucky',15662,21);
INSERT INTO "django_geo_db_city" VALUES(12368,'Green Road','Green Road, Kentucky',15668,21);
INSERT INTO "django_geo_db_city" VALUES(12369,'Heidrick','Heidrick, Kentucky',15669,21);
INSERT INTO "django_geo_db_city" VALUES(12370,'Hima','Hima, Kentucky',15662,21);
INSERT INTO "django_geo_db_city" VALUES(12371,'Hinkle','Hinkle, Kentucky',15670,21);
INSERT INTO "django_geo_db_city" VALUES(12372,'Ingram','Ingram, Kentucky',15671,21);
INSERT INTO "django_geo_db_city" VALUES(12373,'Kettle Island','Kettle Island, Kentucky',15672,21);
INSERT INTO "django_geo_db_city" VALUES(12374,'Manchester','Manchester, Kentucky',15673,21);
INSERT INTO "django_geo_db_city" VALUES(12375,'Mary Alice','Mary Alice, Kentucky',15674,21);
INSERT INTO "django_geo_db_city" VALUES(12376,'Middlesboro','Middlesboro, Kentucky',15675,21);
INSERT INTO "django_geo_db_city" VALUES(12377,'Oneida','Oneida, Kentucky',15676,21);
INSERT INTO "django_geo_db_city" VALUES(12378,'Pineville','Pineville, Kentucky',15677,21);
INSERT INTO "django_geo_db_city" VALUES(12379,'Roark','Roark, Kentucky',15678,21);
INSERT INTO "django_geo_db_city" VALUES(12380,'Saul','Saul, Kentucky',15679,21);
INSERT INTO "django_geo_db_city" VALUES(12381,'Scalf','Scalf, Kentucky',15680,21);
INSERT INTO "django_geo_db_city" VALUES(12382,'Sextons Creek','Sextons Creek, Kentucky',15681,21);
INSERT INTO "django_geo_db_city" VALUES(12383,'Stoney Fork','Stoney Fork, Kentucky',15682,21);
INSERT INTO "django_geo_db_city" VALUES(12384,'Trosper','Trosper, Kentucky',15683,21);
INSERT INTO "django_geo_db_city" VALUES(12385,'Walker','Walker, Kentucky',15684,21);
INSERT INTO "django_geo_db_city" VALUES(12386,'Woollum','Woollum, Kentucky',15685,21);
INSERT INTO "django_geo_db_city" VALUES(12387,'Fort Mitchell','Fort Mitchell, Kentucky',15686,21);
INSERT INTO "django_geo_db_city" VALUES(12388,'Alexandria','Alexandria, Kentucky',15687,21);
INSERT INTO "django_geo_db_city" VALUES(12389,'Augusta','Augusta, Kentucky',15688,21);
INSERT INTO "django_geo_db_city" VALUES(12390,'Berry','Berry, Kentucky',15689,21);
INSERT INTO "django_geo_db_city" VALUES(12391,'Brooksville','Brooksville, Kentucky',15690,21);
INSERT INTO "django_geo_db_city" VALUES(12392,'Burlington','Burlington, Kentucky',15691,21);
INSERT INTO "django_geo_db_city" VALUES(12393,'Butler','Butler, Kentucky',15692,21);
INSERT INTO "django_geo_db_city" VALUES(12394,'California','California, Kentucky',15693,21);
INSERT INTO "django_geo_db_city" VALUES(12395,'Carrollton','Carrollton, Kentucky',15694,21);
INSERT INTO "django_geo_db_city" VALUES(12396,'Corinth','Corinth, Kentucky',15695,21);
INSERT INTO "django_geo_db_city" VALUES(12397,'Covington','Covington, Kentucky',15696,21);
INSERT INTO "django_geo_db_city" VALUES(12398,'Latonia','Latonia, Kentucky',15699,21);
INSERT INTO "django_geo_db_city" VALUES(12399,'Ft Mitchell','Ft Mitchell, Kentucky',15701,21);
INSERT INTO "django_geo_db_city" VALUES(12400,'Erlanger','Erlanger, Kentucky',15702,21);
INSERT INTO "django_geo_db_city" VALUES(12401,'Florence','Florence, Kentucky',15703,21);
INSERT INTO "django_geo_db_city" VALUES(12402,'Crittenden','Crittenden, Kentucky',15704,21);
INSERT INTO "django_geo_db_city" VALUES(12403,'Cynthiana','Cynthiana, Kentucky',15705,21);
INSERT INTO "django_geo_db_city" VALUES(12404,'De Mossville','De Mossville, Kentucky',15706,21);
INSERT INTO "django_geo_db_city" VALUES(12405,'Dover','Dover, Kentucky',15707,21);
INSERT INTO "django_geo_db_city" VALUES(12406,'Dry Ridge','Dry Ridge, Kentucky',15708,21);
INSERT INTO "django_geo_db_city" VALUES(12407,'Elizaville','Elizaville, Kentucky',15709,21);
INSERT INTO "django_geo_db_city" VALUES(12408,'Ewing','Ewing, Kentucky',15710,21);
INSERT INTO "django_geo_db_city" VALUES(12409,'Falmouth','Falmouth, Kentucky',15711,21);
INSERT INTO "django_geo_db_city" VALUES(12410,'Flemingsburg','Flemingsburg, Kentucky',15712,21);
INSERT INTO "django_geo_db_city" VALUES(12411,'Foster','Foster, Kentucky',15714,21);
INSERT INTO "django_geo_db_city" VALUES(12412,'Germantown','Germantown, Kentucky',15715,21);
INSERT INTO "django_geo_db_city" VALUES(12413,'Ghent','Ghent, Kentucky',15716,21);
INSERT INTO "django_geo_db_city" VALUES(12414,'Glencoe','Glencoe, Kentucky',15717,21);
INSERT INTO "django_geo_db_city" VALUES(12415,'Hebron','Hebron, Kentucky',15718,21);
INSERT INTO "django_geo_db_city" VALUES(12416,'Hillsboro','Hillsboro, Kentucky',15719,21);
INSERT INTO "django_geo_db_city" VALUES(12417,'Independence','Independence, Kentucky',15720,21);
INSERT INTO "django_geo_db_city" VALUES(12418,'Jonesville','Jonesville, Kentucky',15721,21);
INSERT INTO "django_geo_db_city" VALUES(12419,'Kenton','Kenton, Kentucky',15697,21);
INSERT INTO "django_geo_db_city" VALUES(12420,'Mason','Mason, Kentucky',15722,21);
INSERT INTO "django_geo_db_city" VALUES(12421,'Mayslick','Mayslick, Kentucky',15723,21);
INSERT INTO "django_geo_db_city" VALUES(12422,'Maysville','Maysville, Kentucky',15724,21);
INSERT INTO "django_geo_db_city" VALUES(12423,'Melbourne','Melbourne, Kentucky',15725,21);
INSERT INTO "django_geo_db_city" VALUES(12424,'Milford','Milford, Kentucky',15726,21);
INSERT INTO "django_geo_db_city" VALUES(12425,'Minerva','Minerva, Kentucky',15727,21);
INSERT INTO "django_geo_db_city" VALUES(12426,'Morning View','Morning View, Kentucky',15728,21);
INSERT INTO "django_geo_db_city" VALUES(12427,'Mount Olivet','Mount Olivet, Kentucky',15729,21);
INSERT INTO "django_geo_db_city" VALUES(12428,'Muses Mills','Muses Mills, Kentucky',15709,21);
INSERT INTO "django_geo_db_city" VALUES(12429,'Newport','Newport, Kentucky',15730,21);
INSERT INTO "django_geo_db_city" VALUES(12430,'Bellevue','Bellevue, Kentucky',15732,21);
INSERT INTO "django_geo_db_city" VALUES(12431,'Dayton','Dayton, Kentucky',15733,21);
INSERT INTO "django_geo_db_city" VALUES(12432,'Fort Thomas','Fort Thomas, Kentucky',15734,21);
INSERT INTO "django_geo_db_city" VALUES(12433,'Petersburg','Petersburg, Kentucky',15736,21);
INSERT INTO "django_geo_db_city" VALUES(12434,'Plummers Landing','Plummers Landing, Kentucky',15709,21);
INSERT INTO "django_geo_db_city" VALUES(12435,'Sanders','Sanders, Kentucky',15737,21);
INSERT INTO "django_geo_db_city" VALUES(12436,'Silver Grove','Silver Grove, Kentucky',15738,21);
INSERT INTO "django_geo_db_city" VALUES(12437,'Sparta','Sparta, Kentucky',15739,21);
INSERT INTO "django_geo_db_city" VALUES(12438,'Union','Union, Kentucky',15740,21);
INSERT INTO "django_geo_db_city" VALUES(12439,'Verona','Verona, Kentucky',15741,21);
INSERT INTO "django_geo_db_city" VALUES(12440,'Wallingford','Wallingford, Kentucky',15742,21);
INSERT INTO "django_geo_db_city" VALUES(12441,'Walton','Walton, Kentucky',15743,21);
INSERT INTO "django_geo_db_city" VALUES(12442,'Warsaw','Warsaw, Kentucky',15744,21);
INSERT INTO "django_geo_db_city" VALUES(12443,'Washington','Washington, Kentucky',15745,21);
INSERT INTO "django_geo_db_city" VALUES(12444,'Williamstown','Williamstown, Kentucky',15746,21);
INSERT INTO "django_geo_db_city" VALUES(12445,'Worthville','Worthville, Kentucky',15747,21);
INSERT INTO "django_geo_db_city" VALUES(12446,'Ashland','Ashland, Kentucky',15748,21);
INSERT INTO "django_geo_db_city" VALUES(12447,'Argillite','Argillite, Kentucky',15751,21);
INSERT INTO "django_geo_db_city" VALUES(12448,'Blaine','Blaine, Kentucky',15752,21);
INSERT INTO "django_geo_db_city" VALUES(12449,'Camp Dix','Camp Dix, Kentucky',15753,21);
INSERT INTO "django_geo_db_city" VALUES(12450,'Carter','Carter, Kentucky',15754,21);
INSERT INTO "django_geo_db_city" VALUES(12451,'Catlettsburg','Catlettsburg, Kentucky',15755,21);
INSERT INTO "django_geo_db_city" VALUES(12452,'Denton','Denton, Kentucky',15756,21);
INSERT INTO "django_geo_db_city" VALUES(12453,'Emerson','Emerson, Kentucky',15757,21);
INSERT INTO "django_geo_db_city" VALUES(12454,'Firebrick','Firebrick, Kentucky',15758,21);
INSERT INTO "django_geo_db_city" VALUES(12455,'Flatwoods','Flatwoods, Kentucky',15759,21);
INSERT INTO "django_geo_db_city" VALUES(12456,'Garrison','Garrison, Kentucky',15760,21);
INSERT INTO "django_geo_db_city" VALUES(12457,'Grahn','Grahn, Kentucky',15761,21);
INSERT INTO "django_geo_db_city" VALUES(12458,'Grayson','Grayson, Kentucky',15762,21);
INSERT INTO "django_geo_db_city" VALUES(12459,'Greenup','Greenup, Kentucky',15763,21);
INSERT INTO "django_geo_db_city" VALUES(12460,'Hitchins','Hitchins, Kentucky',15764,21);
INSERT INTO "django_geo_db_city" VALUES(12461,'Isonville','Isonville, Kentucky',15765,21);
INSERT INTO "django_geo_db_city" VALUES(12462,'Jacobs','Jacobs, Kentucky',15766,21);
INSERT INTO "django_geo_db_city" VALUES(12463,'Lloyd','Lloyd, Kentucky',15767,21);
INSERT INTO "django_geo_db_city" VALUES(12464,'Martha','Martha, Kentucky',15768,21);
INSERT INTO "django_geo_db_city" VALUES(12465,'Mazie','Mazie, Kentucky',15769,21);
INSERT INTO "django_geo_db_city" VALUES(12466,'Olive Hill','Olive Hill, Kentucky',15771,21);
INSERT INTO "django_geo_db_city" VALUES(12467,'Quincy','Quincy, Kentucky',15772,21);
INSERT INTO "django_geo_db_city" VALUES(12468,'Rush','Rush, Kentucky',15773,21);
INSERT INTO "django_geo_db_city" VALUES(12469,'Russell','Russell, Kentucky',15774,21);
INSERT INTO "django_geo_db_city" VALUES(12470,'Saint Paul','Saint Paul, Kentucky',15775,21);
INSERT INTO "django_geo_db_city" VALUES(12471,'Sandy Hook','Sandy Hook, Kentucky',15776,21);
INSERT INTO "django_geo_db_city" VALUES(12472,'Soldier','Soldier, Kentucky',15777,21);
INSERT INTO "django_geo_db_city" VALUES(12473,'South Portsmouth','South Portsmouth, Kentucky',15778,21);
INSERT INTO "django_geo_db_city" VALUES(12474,'South Shore','South Shore, Kentucky',15779,21);
INSERT INTO "django_geo_db_city" VALUES(12475,'Vanceburg','Vanceburg, Kentucky',15780,21);
INSERT INTO "django_geo_db_city" VALUES(12476,'Webbville','Webbville, Kentucky',15781,21);
INSERT INTO "django_geo_db_city" VALUES(12477,'Willard','Willard, Kentucky',15782,21);
INSERT INTO "django_geo_db_city" VALUES(12478,'Worthington','Worthington, Kentucky',15783,21);
INSERT INTO "django_geo_db_city" VALUES(12479,'Tollesboro','Tollesboro, Kentucky',15784,21);
INSERT INTO "django_geo_db_city" VALUES(12480,'Adams','Adams, Kentucky',15785,21);
INSERT INTO "django_geo_db_city" VALUES(12481,'Beauty','Beauty, Kentucky',15786,21);
INSERT INTO "django_geo_db_city" VALUES(12482,'Boons Camp','Boons Camp, Kentucky',15787,21);
INSERT INTO "django_geo_db_city" VALUES(12483,'Debord','Debord, Kentucky',15788,21);
INSERT INTO "django_geo_db_city" VALUES(12484,'Denver','Denver, Kentucky',15789,21);
INSERT INTO "django_geo_db_city" VALUES(12485,'East Point','East Point, Kentucky',15790,21);
INSERT INTO "django_geo_db_city" VALUES(12486,'Flatgap','Flatgap, Kentucky',15791,21);
INSERT INTO "django_geo_db_city" VALUES(12487,'Hagerhill','Hagerhill, Kentucky',15792,21);
INSERT INTO "django_geo_db_city" VALUES(12488,'Inez','Inez, Kentucky',15793,21);
INSERT INTO "django_geo_db_city" VALUES(12489,'Keaton','Keaton, Kentucky',15794,21);
INSERT INTO "django_geo_db_city" VALUES(12490,'Leander','Leander, Kentucky',15795,21);
INSERT INTO "django_geo_db_city" VALUES(12491,'Louisa','Louisa, Kentucky',15796,21);
INSERT INTO "django_geo_db_city" VALUES(12492,'Lovely','Lovely, Kentucky',15797,21);
INSERT INTO "django_geo_db_city" VALUES(12493,'Lowmansville','Lowmansville, Kentucky',15798,21);
INSERT INTO "django_geo_db_city" VALUES(12494,'Meally','Meally, Kentucky',15799,21);
INSERT INTO "django_geo_db_city" VALUES(12495,'Oil Springs','Oil Springs, Kentucky',15800,21);
INSERT INTO "django_geo_db_city" VALUES(12496,'Paintsville','Paintsville, Kentucky',15801,21);
INSERT INTO "django_geo_db_city" VALUES(12497,'Pilgrim','Pilgrim, Kentucky',15802,21);
INSERT INTO "django_geo_db_city" VALUES(12498,'River','River, Kentucky',15803,21);
INSERT INTO "django_geo_db_city" VALUES(12499,'Sitka','Sitka, Kentucky',15804,21);
INSERT INTO "django_geo_db_city" VALUES(12500,'Staffordsville','Staffordsville, Kentucky',15805,21);
INSERT INTO "django_geo_db_city" VALUES(12501,'Stambaugh','Stambaugh, Kentucky',15806,21);
INSERT INTO "django_geo_db_city" VALUES(12502,'Thelma','Thelma, Kentucky',15807,21);
INSERT INTO "django_geo_db_city" VALUES(12503,'Tomahawk','Tomahawk, Kentucky',15808,21);
INSERT INTO "django_geo_db_city" VALUES(12504,'Tutor Key','Tutor Key, Kentucky',15809,21);
INSERT INTO "django_geo_db_city" VALUES(12505,'Ulysses','Ulysses, Kentucky',15810,21);
INSERT INTO "django_geo_db_city" VALUES(12506,'Van Lear','Van Lear, Kentucky',15811,21);
INSERT INTO "django_geo_db_city" VALUES(12507,'Warfield','Warfield, Kentucky',15812,21);
INSERT INTO "django_geo_db_city" VALUES(12508,'West Van Lear','West Van Lear, Kentucky',15813,21);
INSERT INTO "django_geo_db_city" VALUES(12509,'Williamsport','Williamsport, Kentucky',15814,21);
INSERT INTO "django_geo_db_city" VALUES(12510,'Wittensville','Wittensville, Kentucky',15815,21);
INSERT INTO "django_geo_db_city" VALUES(12511,'Campton','Campton, Kentucky',15816,21);
INSERT INTO "django_geo_db_city" VALUES(12512,'Athol','Athol, Kentucky',15817,21);
INSERT INTO "django_geo_db_city" VALUES(12513,'Bays','Bays, Kentucky',15818,21);
INSERT INTO "django_geo_db_city" VALUES(12514,'Beattyville','Beattyville, Kentucky',15819,21);
INSERT INTO "django_geo_db_city" VALUES(12515,'Bethany','Bethany, Kentucky',15820,21);
INSERT INTO "django_geo_db_city" VALUES(12516,'Booneville','Booneville, Kentucky',15821,21);
INSERT INTO "django_geo_db_city" VALUES(12517,'Clayhole','Clayhole, Kentucky',15822,21);
INSERT INTO "django_geo_db_city" VALUES(12518,'Hazel Green','Hazel Green, Kentucky',15823,21);
INSERT INTO "django_geo_db_city" VALUES(12519,'Heidelberg','Heidelberg, Kentucky',15824,21);
INSERT INTO "django_geo_db_city" VALUES(12520,'Island City','Island City, Kentucky',15825,21);
INSERT INTO "django_geo_db_city" VALUES(12521,'Jackson','Jackson, Kentucky',15826,21);
INSERT INTO "django_geo_db_city" VALUES(12522,'Lee City','Lee City, Kentucky',15820,21);
INSERT INTO "django_geo_db_city" VALUES(12523,'Lerose','Lerose, Kentucky',15827,21);
INSERT INTO "django_geo_db_city" VALUES(12524,'Lone','Lone, Kentucky',15828,21);
INSERT INTO "django_geo_db_city" VALUES(12525,'Lost Creek','Lost Creek, Kentucky',15829,21);
INSERT INTO "django_geo_db_city" VALUES(12526,'Mistletoe','Mistletoe, Kentucky',15825,21);
INSERT INTO "django_geo_db_city" VALUES(12527,'Mize','Mize, Kentucky',15830,21);
INSERT INTO "django_geo_db_city" VALUES(12528,'Pine Ridge','Pine Ridge, Kentucky',15831,21);
INSERT INTO "django_geo_db_city" VALUES(12529,'Primrose','Primrose, Kentucky',15832,21);
INSERT INTO "django_geo_db_city" VALUES(12530,'Ricetown','Ricetown, Kentucky',15833,21);
INSERT INTO "django_geo_db_city" VALUES(12531,'Rogers','Rogers, Kentucky',15834,21);
INSERT INTO "django_geo_db_city" VALUES(12532,'Rousseau','Rousseau, Kentucky',15835,21);
INSERT INTO "django_geo_db_city" VALUES(12533,'Rowdy','Rowdy, Kentucky',15836,21);
INSERT INTO "django_geo_db_city" VALUES(12534,'Saint Helens','Saint Helens, Kentucky',15837,21);
INSERT INTO "django_geo_db_city" VALUES(12535,'Talbert','Talbert, Kentucky',15838,21);
INSERT INTO "django_geo_db_city" VALUES(12536,'Vancleve','Vancleve, Kentucky',15839,21);
INSERT INTO "django_geo_db_city" VALUES(12537,'Vincent','Vincent, Kentucky',15840,21);
INSERT INTO "django_geo_db_city" VALUES(12538,'Whick','Whick, Kentucky',15841,21);
INSERT INTO "django_geo_db_city" VALUES(12539,'Zoe','Zoe, Kentucky',15842,21);
INSERT INTO "django_geo_db_city" VALUES(12540,'Cannel City','Cannel City, Kentucky',15843,21);
INSERT INTO "django_geo_db_city" VALUES(12541,'Cisco','Cisco, Kentucky',15844,21);
INSERT INTO "django_geo_db_city" VALUES(12542,'Crockett','Crockett, Kentucky',15845,21);
INSERT INTO "django_geo_db_city" VALUES(12543,'Edna','Edna, Kentucky',15844,21);
INSERT INTO "django_geo_db_city" VALUES(12544,'Elkfork','Elkfork, Kentucky',15846,21);
INSERT INTO "django_geo_db_city" VALUES(12545,'Elsie','Elsie, Kentucky',15844,21);
INSERT INTO "django_geo_db_city" VALUES(12546,'Ezel','Ezel, Kentucky',15847,21);
INSERT INTO "django_geo_db_city" VALUES(12547,'Falcon','Falcon, Kentucky',15848,21);
INSERT INTO "django_geo_db_city" VALUES(12548,'Gapville','Gapville, Kentucky',15844,21);
INSERT INTO "django_geo_db_city" VALUES(12549,'Ivyton','Ivyton, Kentucky',15844,21);
INSERT INTO "django_geo_db_city" VALUES(12550,'Malone','Malone, Kentucky',15830,21);
INSERT INTO "django_geo_db_city" VALUES(12551,'Ophir','Ophir, Kentucky',15830,21);
INSERT INTO "django_geo_db_city" VALUES(12552,'Salyersville','Salyersville, Kentucky',15849,21);
INSERT INTO "django_geo_db_city" VALUES(12553,'Royalton','Royalton, Kentucky',15850,21);
INSERT INTO "django_geo_db_city" VALUES(12554,'West Liberty','West Liberty, Kentucky',15852,21);
INSERT INTO "django_geo_db_city" VALUES(12555,'Wrigley','Wrigley, Kentucky',15830,21);
INSERT INTO "django_geo_db_city" VALUES(12556,'Pikeville','Pikeville, Kentucky',15853,21);
INSERT INTO "django_geo_db_city" VALUES(12557,'South Williamson','South Williamson, Kentucky',15855,21);
INSERT INTO "django_geo_db_city" VALUES(12558,'Ashcamp','Ashcamp, Kentucky',15856,21);
INSERT INTO "django_geo_db_city" VALUES(12559,'Belcher','Belcher, Kentucky',15857,21);
INSERT INTO "django_geo_db_city" VALUES(12560,'Belfry','Belfry, Kentucky',15858,21);
INSERT INTO "django_geo_db_city" VALUES(12561,'Burdine','Burdine, Kentucky',15859,21);
INSERT INTO "django_geo_db_city" VALUES(12562,'Canada','Canada, Kentucky',15860,21);
INSERT INTO "django_geo_db_city" VALUES(12563,'Dorton','Dorton, Kentucky',15861,21);
INSERT INTO "django_geo_db_city" VALUES(12564,'Elkhorn City','Elkhorn City, Kentucky',15862,21);
INSERT INTO "django_geo_db_city" VALUES(12565,'Fedscreek','Fedscreek, Kentucky',15863,21);
INSERT INTO "django_geo_db_city" VALUES(12566,'Fords Branch','Fords Branch, Kentucky',15864,21);
INSERT INTO "django_geo_db_city" VALUES(12567,'Forest Hills','Forest Hills, Kentucky',15865,21);
INSERT INTO "django_geo_db_city" VALUES(12568,'Freeburn','Freeburn, Kentucky',15866,21);
INSERT INTO "django_geo_db_city" VALUES(12569,'Hardy','Hardy, Kentucky',15867,21);
INSERT INTO "django_geo_db_city" VALUES(12570,'Hellier','Hellier, Kentucky',15868,21);
INSERT INTO "django_geo_db_city" VALUES(12571,'Huddy','Huddy, Kentucky',15869,21);
INSERT INTO "django_geo_db_city" VALUES(12572,'Jenkins','Jenkins, Kentucky',15870,21);
INSERT INTO "django_geo_db_city" VALUES(12573,'Jonancy','Jonancy, Kentucky',15871,21);
INSERT INTO "django_geo_db_city" VALUES(12574,'Kimper','Kimper, Kentucky',15872,21);
INSERT INTO "django_geo_db_city" VALUES(12575,'Lick Creek','Lick Creek, Kentucky',15873,21);
INSERT INTO "django_geo_db_city" VALUES(12576,'Lookout','Lookout, Kentucky',15874,21);
INSERT INTO "django_geo_db_city" VALUES(12577,'McAndrews','McAndrews, Kentucky',15875,21);
INSERT INTO "django_geo_db_city" VALUES(12578,'McCarr','McCarr, Kentucky',15876,21);
INSERT INTO "django_geo_db_city" VALUES(12579,'McVeigh','McVeigh, Kentucky',15877,21);
INSERT INTO "django_geo_db_city" VALUES(12580,'Majestic','Majestic, Kentucky',15878,21);
INSERT INTO "django_geo_db_city" VALUES(12581,'Mouthcard','Mouthcard, Kentucky',15879,21);
INSERT INTO "django_geo_db_city" VALUES(12582,'Myra','Myra, Kentucky',15880,21);
INSERT INTO "django_geo_db_city" VALUES(12583,'Phelps','Phelps, Kentucky',15881,21);
INSERT INTO "django_geo_db_city" VALUES(12584,'Phyllis','Phyllis, Kentucky',15882,21);
INSERT INTO "django_geo_db_city" VALUES(12585,'Pinsonfork','Pinsonfork, Kentucky',15883,21);
INSERT INTO "django_geo_db_city" VALUES(12586,'Raccoon','Raccoon, Kentucky',15884,21);
INSERT INTO "django_geo_db_city" VALUES(12587,'Ransom','Ransom, Kentucky',15885,21);
INSERT INTO "django_geo_db_city" VALUES(12588,'Regina','Regina, Kentucky',15886,21);
INSERT INTO "django_geo_db_city" VALUES(12589,'Robinson Creek','Robinson Creek, Kentucky',15887,21);
INSERT INTO "django_geo_db_city" VALUES(12590,'Rockhouse','Rockhouse, Kentucky',15888,21);
INSERT INTO "django_geo_db_city" VALUES(12591,'Shelbiana','Shelbiana, Kentucky',15889,21);
INSERT INTO "django_geo_db_city" VALUES(12592,'Shelby Gap','Shelby Gap, Kentucky',15890,21);
INSERT INTO "django_geo_db_city" VALUES(12593,'Sidney','Sidney, Kentucky',15891,21);
INSERT INTO "django_geo_db_city" VALUES(12594,'Steele','Steele, Kentucky',15892,21);
INSERT INTO "django_geo_db_city" VALUES(12595,'Stone','Stone, Kentucky',15893,21);
INSERT INTO "django_geo_db_city" VALUES(12596,'Stopover','Stopover, Kentucky',15894,21);
INSERT INTO "django_geo_db_city" VALUES(12597,'Toler','Toler, Kentucky',15895,21);
INSERT INTO "django_geo_db_city" VALUES(12598,'Varney','Varney, Kentucky',15896,21);
INSERT INTO "django_geo_db_city" VALUES(12599,'Virgie','Virgie, Kentucky',15897,21);
INSERT INTO "django_geo_db_city" VALUES(12600,'Allen','Allen, Kentucky',15898,21);
INSERT INTO "django_geo_db_city" VALUES(12601,'Auxier','Auxier, Kentucky',15899,21);
INSERT INTO "django_geo_db_city" VALUES(12602,'Banner','Banner, Kentucky',15900,21);
INSERT INTO "django_geo_db_city" VALUES(12603,'Beaver','Beaver, Kentucky',15901,21);
INSERT INTO "django_geo_db_city" VALUES(12604,'Betsy Layne','Betsy Layne, Kentucky',15902,21);
INSERT INTO "django_geo_db_city" VALUES(12605,'Bevinsville','Bevinsville, Kentucky',15903,21);
INSERT INTO "django_geo_db_city" VALUES(12606,'Blue River','Blue River, Kentucky',15904,21);
INSERT INTO "django_geo_db_city" VALUES(12607,'Bypro','Bypro, Kentucky',15905,21);
INSERT INTO "django_geo_db_city" VALUES(12608,'Dana','Dana, Kentucky',15906,21);
INSERT INTO "django_geo_db_city" VALUES(12609,'David','David, Kentucky',15907,21);
INSERT INTO "django_geo_db_city" VALUES(12610,'Drift','Drift, Kentucky',15908,21);
INSERT INTO "django_geo_db_city" VALUES(12611,'Dwale','Dwale, Kentucky',15909,21);
INSERT INTO "django_geo_db_city" VALUES(12612,'Eastern','Eastern, Kentucky',15910,21);
INSERT INTO "django_geo_db_city" VALUES(12613,'Garrett','Garrett, Kentucky',15911,21);
INSERT INTO "django_geo_db_city" VALUES(12614,'Grethel','Grethel, Kentucky',15912,21);
INSERT INTO "django_geo_db_city" VALUES(12615,'Gunlock','Gunlock, Kentucky',15913,21);
INSERT INTO "django_geo_db_city" VALUES(12616,'Harold','Harold, Kentucky',15914,21);
INSERT INTO "django_geo_db_city" VALUES(12617,'Hi Hat','Hi Hat, Kentucky',15915,21);
INSERT INTO "django_geo_db_city" VALUES(12618,'Hueysville','Hueysville, Kentucky',15916,21);
INSERT INTO "django_geo_db_city" VALUES(12619,'Ivel','Ivel, Kentucky',15917,21);
INSERT INTO "django_geo_db_city" VALUES(12620,'Lackey','Lackey, Kentucky',15918,21);
INSERT INTO "django_geo_db_city" VALUES(12621,'Langley','Langley, Kentucky',15919,21);
INSERT INTO "django_geo_db_city" VALUES(12622,'McDowell','McDowell, Kentucky',15920,21);
INSERT INTO "django_geo_db_city" VALUES(12623,'Martin','Martin, Kentucky',15921,21);
INSERT INTO "django_geo_db_city" VALUES(12624,'Melvin','Melvin, Kentucky',15922,21);
INSERT INTO "django_geo_db_city" VALUES(12625,'Minnie','Minnie, Kentucky',15923,21);
INSERT INTO "django_geo_db_city" VALUES(12626,'Prestonsburg','Prestonsburg, Kentucky',15924,21);
INSERT INTO "django_geo_db_city" VALUES(12627,'Printer','Printer, Kentucky',15925,21);
INSERT INTO "django_geo_db_city" VALUES(12628,'Stanville','Stanville, Kentucky',15926,21);
INSERT INTO "django_geo_db_city" VALUES(12629,'Teaberry','Teaberry, Kentucky',15927,21);
INSERT INTO "django_geo_db_city" VALUES(12630,'Tram','Tram, Kentucky',15928,21);
INSERT INTO "django_geo_db_city" VALUES(12631,'Wayland','Wayland, Kentucky',15929,21);
INSERT INTO "django_geo_db_city" VALUES(12632,'Weeksbury','Weeksbury, Kentucky',15930,21);
INSERT INTO "django_geo_db_city" VALUES(12633,'West Prestonsburg','West Prestonsburg, Kentucky',15931,21);
INSERT INTO "django_geo_db_city" VALUES(12634,'Wheelwright','Wheelwright, Kentucky',15932,21);
INSERT INTO "django_geo_db_city" VALUES(12635,'Hazard','Hazard, Kentucky',15933,21);
INSERT INTO "django_geo_db_city" VALUES(12636,'Ary','Ary, Kentucky',15936,21);
INSERT INTO "django_geo_db_city" VALUES(12637,'Avawam','Avawam, Kentucky',15937,21);
INSERT INTO "django_geo_db_city" VALUES(12638,'Bear Branch','Bear Branch, Kentucky',15938,21);
INSERT INTO "django_geo_db_city" VALUES(12639,'Bonnyman','Bonnyman, Kentucky',15939,21);
INSERT INTO "django_geo_db_city" VALUES(12640,'Buckhorn','Buckhorn, Kentucky',15940,21);
INSERT INTO "django_geo_db_city" VALUES(12641,'Bulan','Bulan, Kentucky',15941,21);
INSERT INTO "django_geo_db_city" VALUES(12642,'Busy','Busy, Kentucky',15942,21);
INSERT INTO "django_geo_db_city" VALUES(12643,'Carrie','Carrie, Kentucky',15943,21);
INSERT INTO "django_geo_db_city" VALUES(12644,'Chavies','Chavies, Kentucky',15944,21);
INSERT INTO "django_geo_db_city" VALUES(12645,'Combs','Combs, Kentucky',15945,21);
INSERT INTO "django_geo_db_city" VALUES(12646,'Confluence','Confluence, Kentucky',15946,21);
INSERT INTO "django_geo_db_city" VALUES(12647,'Cornettsville','Cornettsville, Kentucky',15947,21);
INSERT INTO "django_geo_db_city" VALUES(12648,'Delphia','Delphia, Kentucky',15948,21);
INSERT INTO "django_geo_db_city" VALUES(12649,'Dice','Dice, Kentucky',15949,21);
INSERT INTO "django_geo_db_city" VALUES(12650,'Dwarf','Dwarf, Kentucky',15950,21);
INSERT INTO "django_geo_db_city" VALUES(12651,'Emmalena','Emmalena, Kentucky',15951,21);
INSERT INTO "django_geo_db_city" VALUES(12652,'Fisty','Fisty, Kentucky',15952,21);
INSERT INTO "django_geo_db_city" VALUES(12653,'Gays Creek','Gays Creek, Kentucky',15953,21);
INSERT INTO "django_geo_db_city" VALUES(12654,'Happy','Happy, Kentucky',15954,21);
INSERT INTO "django_geo_db_city" VALUES(12655,'Hardburly','Hardburly, Kentucky',15955,21);
INSERT INTO "django_geo_db_city" VALUES(12656,'Hyden','Hyden, Kentucky',15956,21);
INSERT INTO "django_geo_db_city" VALUES(12657,'Jeff','Jeff, Kentucky',15957,21);
INSERT INTO "django_geo_db_city" VALUES(12658,'Krypton','Krypton, Kentucky',15958,21);
INSERT INTO "django_geo_db_city" VALUES(12659,'Sassafras','Sassafras, Kentucky',15959,21);
INSERT INTO "django_geo_db_city" VALUES(12660,'Scuddy','Scuddy, Kentucky',15960,21);
INSERT INTO "django_geo_db_city" VALUES(12661,'Sizerock','Sizerock, Kentucky',15961,21);
INSERT INTO "django_geo_db_city" VALUES(12662,'Slemp','Slemp, Kentucky',15962,21);
INSERT INTO "django_geo_db_city" VALUES(12663,'Smilax','Smilax, Kentucky',15963,21);
INSERT INTO "django_geo_db_city" VALUES(12664,'Thousandsticks','Thousandsticks, Kentucky',15964,21);
INSERT INTO "django_geo_db_city" VALUES(12665,'Vest','Vest, Kentucky',15965,21);
INSERT INTO "django_geo_db_city" VALUES(12666,'Vicco','Vicco, Kentucky',15966,21);
INSERT INTO "django_geo_db_city" VALUES(12667,'Viper','Viper, Kentucky',15967,21);
INSERT INTO "django_geo_db_city" VALUES(12668,'Wendover','Wendover, Kentucky',15968,21);
INSERT INTO "django_geo_db_city" VALUES(12669,'Wooton','Wooton, Kentucky',15969,21);
INSERT INTO "django_geo_db_city" VALUES(12670,'Yeaddiss','Yeaddiss, Kentucky',15970,21);
INSERT INTO "django_geo_db_city" VALUES(12671,'Yerkes','Yerkes, Kentucky',15971,21);
INSERT INTO "django_geo_db_city" VALUES(12672,'Blackey','Blackey, Kentucky',15972,21);
INSERT INTO "django_geo_db_city" VALUES(12673,'Cromona','Cromona, Kentucky',15973,21);
INSERT INTO "django_geo_db_city" VALUES(12674,'Deane','Deane, Kentucky',15974,21);
INSERT INTO "django_geo_db_city" VALUES(12675,'Ermine','Ermine, Kentucky',15975,21);
INSERT INTO "django_geo_db_city" VALUES(12676,'Garner','Garner, Kentucky',15976,21);
INSERT INTO "django_geo_db_city" VALUES(12677,'Gordon','Gordon, Kentucky',15977,21);
INSERT INTO "django_geo_db_city" VALUES(12678,'Hallie','Hallie, Kentucky',15978,21);
INSERT INTO "django_geo_db_city" VALUES(12679,'Hindman','Hindman, Kentucky',15979,21);
INSERT INTO "django_geo_db_city" VALUES(12680,'Isom','Isom, Kentucky',15980,21);
INSERT INTO "django_geo_db_city" VALUES(12681,'Jackhorn','Jackhorn, Kentucky',15981,21);
INSERT INTO "django_geo_db_city" VALUES(12682,'Jeremiah','Jeremiah, Kentucky',15982,21);
INSERT INTO "django_geo_db_city" VALUES(12683,'Kite','Kite, Kentucky',15983,21);
INSERT INTO "django_geo_db_city" VALUES(12684,'Leburn','Leburn, Kentucky',15984,21);
INSERT INTO "django_geo_db_city" VALUES(12685,'Letcher','Letcher, Kentucky',15985,21);
INSERT INTO "django_geo_db_city" VALUES(12686,'Linefork','Linefork, Kentucky',15986,21);
INSERT INTO "django_geo_db_city" VALUES(12687,'Littcarr','Littcarr, Kentucky',15987,21);
INSERT INTO "django_geo_db_city" VALUES(12688,'McRoberts','McRoberts, Kentucky',15988,21);
INSERT INTO "django_geo_db_city" VALUES(12689,'Mallie','Mallie, Kentucky',15989,21);
INSERT INTO "django_geo_db_city" VALUES(12690,'Mayking','Mayking, Kentucky',15990,21);
INSERT INTO "django_geo_db_city" VALUES(12691,'Millstone','Millstone, Kentucky',15991,21);
INSERT INTO "django_geo_db_city" VALUES(12692,'Mousie','Mousie, Kentucky',15992,21);
INSERT INTO "django_geo_db_city" VALUES(12693,'Neon','Neon, Kentucky',15993,21);
INSERT INTO "django_geo_db_city" VALUES(12694,'Pine Top','Pine Top, Kentucky',15994,21);
INSERT INTO "django_geo_db_city" VALUES(12695,'Pippa Passes','Pippa Passes, Kentucky',15995,21);
INSERT INTO "django_geo_db_city" VALUES(12696,'Premium','Premium, Kentucky',15996,21);
INSERT INTO "django_geo_db_city" VALUES(12697,'Redfox','Redfox, Kentucky',15997,21);
INSERT INTO "django_geo_db_city" VALUES(12698,'Roxana','Roxana, Kentucky',15998,21);
INSERT INTO "django_geo_db_city" VALUES(12699,'Seco','Seco, Kentucky',15999,21);
INSERT INTO "django_geo_db_city" VALUES(12700,'Thornton','Thornton, Kentucky',16000,21);
INSERT INTO "django_geo_db_city" VALUES(12701,'Whitesburg','Whitesburg, Kentucky',16001,21);
INSERT INTO "django_geo_db_city" VALUES(12702,'Dema','Dema, Kentucky',16002,21);
INSERT INTO "django_geo_db_city" VALUES(12703,'Raven','Raven, Kentucky',16003,21);
INSERT INTO "django_geo_db_city" VALUES(12704,'Topmost','Topmost, Kentucky',16004,21);
INSERT INTO "django_geo_db_city" VALUES(12705,'Paducah','Paducah, Kentucky',16005,21);
INSERT INTO "django_geo_db_city" VALUES(12706,'Fredonia','Fredonia, Kentucky',16008,21);
INSERT INTO "django_geo_db_city" VALUES(12707,'Almo','Almo, Kentucky',16009,21);
INSERT INTO "django_geo_db_city" VALUES(12708,'Arlington','Arlington, Kentucky',16010,21);
INSERT INTO "django_geo_db_city" VALUES(12709,'Bandana','Bandana, Kentucky',16011,21);
INSERT INTO "django_geo_db_city" VALUES(12710,'Bardwell','Bardwell, Kentucky',16012,21);
INSERT INTO "django_geo_db_city" VALUES(12711,'Barlow','Barlow, Kentucky',16013,21);
INSERT INTO "django_geo_db_city" VALUES(12712,'Benton','Benton, Kentucky',16014,21);
INSERT INTO "django_geo_db_city" VALUES(12713,'Boaz','Boaz, Kentucky',16015,21);
INSERT INTO "django_geo_db_city" VALUES(12714,'Burna','Burna, Kentucky',16016,21);
INSERT INTO "django_geo_db_city" VALUES(12715,'Calvert City','Calvert City, Kentucky',16017,21);
INSERT INTO "django_geo_db_city" VALUES(12716,'Clinton','Clinton, Kentucky',16018,21);
INSERT INTO "django_geo_db_city" VALUES(12717,'Columbus','Columbus, Kentucky',16019,21);
INSERT INTO "django_geo_db_city" VALUES(12718,'Crayne','Crayne, Kentucky',16020,21);
INSERT INTO "django_geo_db_city" VALUES(12719,'Cunningham','Cunningham, Kentucky',16021,21);
INSERT INTO "django_geo_db_city" VALUES(12720,'Dexter','Dexter, Kentucky',16022,21);
INSERT INTO "django_geo_db_city" VALUES(12721,'Dycusburg','Dycusburg, Kentucky',16023,21);
INSERT INTO "django_geo_db_city" VALUES(12722,'Eddyville','Eddyville, Kentucky',16024,21);
INSERT INTO "django_geo_db_city" VALUES(12723,'Fancy Farm','Fancy Farm, Kentucky',16025,21);
INSERT INTO "django_geo_db_city" VALUES(12724,'Farmington','Farmington, Kentucky',16026,21);
INSERT INTO "django_geo_db_city" VALUES(12725,'Fulton','Fulton, Kentucky',16027,21);
INSERT INTO "django_geo_db_city" VALUES(12726,'Gilbertsville','Gilbertsville, Kentucky',16028,21);
INSERT INTO "django_geo_db_city" VALUES(12727,'Grand Rivers','Grand Rivers, Kentucky',16029,21);
INSERT INTO "django_geo_db_city" VALUES(12728,'Hamlin','Hamlin, Kentucky',16030,21);
INSERT INTO "django_geo_db_city" VALUES(12729,'Hampton','Hampton, Kentucky',16031,21);
INSERT INTO "django_geo_db_city" VALUES(12730,'Hardin','Hardin, Kentucky',16032,21);
INSERT INTO "django_geo_db_city" VALUES(12731,'Hazel','Hazel, Kentucky',16033,21);
INSERT INTO "django_geo_db_city" VALUES(12732,'Hickman','Hickman, Kentucky',16034,21);
INSERT INTO "django_geo_db_city" VALUES(12733,'Hickory','Hickory, Kentucky',16035,21);
INSERT INTO "django_geo_db_city" VALUES(12734,'Kevil','Kevil, Kentucky',16036,21);
INSERT INTO "django_geo_db_city" VALUES(12735,'Kirksey','Kirksey, Kentucky',16037,21);
INSERT INTO "django_geo_db_city" VALUES(12736,'Kuttawa','Kuttawa, Kentucky',16038,21);
INSERT INTO "django_geo_db_city" VALUES(12737,'La Center','La Center, Kentucky',16039,21);
INSERT INTO "django_geo_db_city" VALUES(12738,'Ledbetter','Ledbetter, Kentucky',16040,21);
INSERT INTO "django_geo_db_city" VALUES(12739,'Lovelaceville','Lovelaceville, Kentucky',16041,21);
INSERT INTO "django_geo_db_city" VALUES(12740,'Lowes','Lowes, Kentucky',16042,21);
INSERT INTO "django_geo_db_city" VALUES(12741,'Lynnville','Lynnville, Kentucky',16043,21);
INSERT INTO "django_geo_db_city" VALUES(12742,'Marion','Marion, Kentucky',16044,21);
INSERT INTO "django_geo_db_city" VALUES(12743,'Mayfield','Mayfield, Kentucky',16045,21);
INSERT INTO "django_geo_db_city" VALUES(12744,'Melber','Melber, Kentucky',16046,21);
INSERT INTO "django_geo_db_city" VALUES(12745,'Milburn','Milburn, Kentucky',16047,21);
INSERT INTO "django_geo_db_city" VALUES(12746,'Murray','Murray, Kentucky',16048,21);
INSERT INTO "django_geo_db_city" VALUES(12747,'New Concord','New Concord, Kentucky',16049,21);
INSERT INTO "django_geo_db_city" VALUES(12748,'Salem','Salem, Kentucky',16050,21);
INSERT INTO "django_geo_db_city" VALUES(12749,'Sedalia','Sedalia, Kentucky',16051,21);
INSERT INTO "django_geo_db_city" VALUES(12750,'Smithland','Smithland, Kentucky',16052,21);
INSERT INTO "django_geo_db_city" VALUES(12751,'Symsonia','Symsonia, Kentucky',16053,21);
INSERT INTO "django_geo_db_city" VALUES(12752,'Tiline','Tiline, Kentucky',16054,21);
INSERT INTO "django_geo_db_city" VALUES(12753,'Tolu','Tolu, Kentucky',16055,21);
INSERT INTO "django_geo_db_city" VALUES(12754,'Water Valley','Water Valley, Kentucky',16056,21);
INSERT INTO "django_geo_db_city" VALUES(12755,'West Paducah','West Paducah, Kentucky',16057,21);
INSERT INTO "django_geo_db_city" VALUES(12756,'Wickliffe','Wickliffe, Kentucky',16058,21);
INSERT INTO "django_geo_db_city" VALUES(12757,'Wingo','Wingo, Kentucky',16059,21);
INSERT INTO "django_geo_db_city" VALUES(12758,'Bowling Green','Bowling Green, Kentucky',16060,21);
INSERT INTO "django_geo_db_city" VALUES(12759,'Adolphus','Adolphus, Kentucky',16065,21);
INSERT INTO "django_geo_db_city" VALUES(12760,'Alvaton','Alvaton, Kentucky',16066,21);
INSERT INTO "django_geo_db_city" VALUES(12761,'Austin','Austin, Kentucky',16067,21);
INSERT INTO "django_geo_db_city" VALUES(12762,'Beaumont','Beaumont, Kentucky',16068,21);
INSERT INTO "django_geo_db_city" VALUES(12763,'Cave City','Cave City, Kentucky',16069,21);
INSERT INTO "django_geo_db_city" VALUES(12764,'Drake','Drake, Kentucky',16070,21);
INSERT INTO "django_geo_db_city" VALUES(12765,'Edmonton','Edmonton, Kentucky',16071,21);
INSERT INTO "django_geo_db_city" VALUES(12766,'Eighty Eight','Eighty Eight, Kentucky',16072,21);
INSERT INTO "django_geo_db_city" VALUES(12767,'Etoile','Etoile, Kentucky',16073,21);
INSERT INTO "django_geo_db_city" VALUES(12768,'Fountain Run','Fountain Run, Kentucky',16074,21);
INSERT INTO "django_geo_db_city" VALUES(12769,'Franklin','Franklin, Kentucky',16075,21);
INSERT INTO "django_geo_db_city" VALUES(12770,'Gamaliel','Gamaliel, Kentucky',16077,21);
INSERT INTO "django_geo_db_city" VALUES(12771,'Glasgow','Glasgow, Kentucky',16078,21);
INSERT INTO "django_geo_db_city" VALUES(12772,'Halfway','Halfway, Kentucky',16080,21);
INSERT INTO "django_geo_db_city" VALUES(12773,'Hestand','Hestand, Kentucky',16081,21);
INSERT INTO "django_geo_db_city" VALUES(12774,'Hiseville','Hiseville, Kentucky',16082,21);
INSERT INTO "django_geo_db_city" VALUES(12775,'Holland','Holland, Kentucky',16083,21);
INSERT INTO "django_geo_db_city" VALUES(12776,'Knob Lick','Knob Lick, Kentucky',16084,21);
INSERT INTO "django_geo_db_city" VALUES(12777,'Lucas','Lucas, Kentucky',16085,21);
INSERT INTO "django_geo_db_city" VALUES(12778,'Mount Hermon','Mount Hermon, Kentucky',16086,21);
INSERT INTO "django_geo_db_city" VALUES(12779,'Oakland','Oakland, Kentucky',16087,21);
INSERT INTO "django_geo_db_city" VALUES(12780,'Park City','Park City, Kentucky',16088,21);
INSERT INTO "django_geo_db_city" VALUES(12781,'Rocky Hill','Rocky Hill, Kentucky',16089,21);
INSERT INTO "django_geo_db_city" VALUES(12782,'Scottsville','Scottsville, Kentucky',16090,21);
INSERT INTO "django_geo_db_city" VALUES(12783,'Summer Shade','Summer Shade, Kentucky',16091,21);
INSERT INTO "django_geo_db_city" VALUES(12784,'Tompkinsville','Tompkinsville, Kentucky',16092,21);
INSERT INTO "django_geo_db_city" VALUES(12785,'Woodburn','Woodburn, Kentucky',16093,21);
INSERT INTO "django_geo_db_city" VALUES(12786,'Smiths Grove','Smiths Grove, Kentucky',16094,21);
INSERT INTO "django_geo_db_city" VALUES(12787,'Aberdeen','Aberdeen, Kentucky',16095,21);
INSERT INTO "django_geo_db_city" VALUES(12788,'Adairville','Adairville, Kentucky',16096,21);
INSERT INTO "django_geo_db_city" VALUES(12789,'Allegre','Allegre, Kentucky',16097,21);
INSERT INTO "django_geo_db_city" VALUES(12790,'Allensville','Allensville, Kentucky',16098,21);
INSERT INTO "django_geo_db_city" VALUES(12791,'Auburn','Auburn, Kentucky',16099,21);
INSERT INTO "django_geo_db_city" VALUES(12792,'Bee Spring','Bee Spring, Kentucky',16100,21);
INSERT INTO "django_geo_db_city" VALUES(12793,'Brooklyn','Brooklyn, Kentucky',16101,21);
INSERT INTO "django_geo_db_city" VALUES(12794,'Brownsville','Brownsville, Kentucky',16102,21);
INSERT INTO "django_geo_db_city" VALUES(12795,'Cadiz','Cadiz, Kentucky',16103,21);
INSERT INTO "django_geo_db_city" VALUES(12796,'Center','Center, Kentucky',16104,21);
INSERT INTO "django_geo_db_city" VALUES(12797,'Cerulean','Cerulean, Kentucky',16105,21);
INSERT INTO "django_geo_db_city" VALUES(12798,'Clifty','Clifty, Kentucky',16106,21);
INSERT INTO "django_geo_db_city" VALUES(12799,'Crofton','Crofton, Kentucky',16107,21);
INSERT INTO "django_geo_db_city" VALUES(12800,'Dunbar','Dunbar, Kentucky',16108,21);
INSERT INTO "django_geo_db_city" VALUES(12801,'Elkton','Elkton, Kentucky',16109,21);
INSERT INTO "django_geo_db_city" VALUES(12802,'Fairview','Fairview, Kentucky',16110,21);
INSERT INTO "django_geo_db_city" VALUES(12803,'Fort Campbell','Fort Campbell, Kentucky',16111,21);
INSERT INTO "django_geo_db_city" VALUES(12804,'Gracey','Gracey, Kentucky',16112,21);
INSERT INTO "django_geo_db_city" VALUES(12805,'Guthrie','Guthrie, Kentucky',16113,21);
INSERT INTO "django_geo_db_city" VALUES(12806,'Hadley','Hadley, Kentucky',16070,21);
INSERT INTO "django_geo_db_city" VALUES(12807,'Herndon','Herndon, Kentucky',16114,21);
INSERT INTO "django_geo_db_city" VALUES(12808,'Hopkinsville','Hopkinsville, Kentucky',16115,21);
INSERT INTO "django_geo_db_city" VALUES(12809,'Huntsville','Huntsville, Kentucky',16116,21);
INSERT INTO "django_geo_db_city" VALUES(12810,'Jetson','Jetson, Kentucky',16117,21);
INSERT INTO "django_geo_db_city" VALUES(12811,'Science Hill','Science Hill, Kentucky',16118,21);
INSERT INTO "django_geo_db_city" VALUES(12812,'La Fayette','La Fayette, Kentucky',16119,21);
INSERT INTO "django_geo_db_city" VALUES(12813,'Lewisburg','Lewisburg, Kentucky',16120,21);
INSERT INTO "django_geo_db_city" VALUES(12814,'Lindseyville','Lindseyville, Kentucky',16121,21);
INSERT INTO "django_geo_db_city" VALUES(12815,'Mammoth Cave','Mammoth Cave, Kentucky',16122,21);
INSERT INTO "django_geo_db_city" VALUES(12816,'Morgantown','Morgantown, Kentucky',16123,21);
INSERT INTO "django_geo_db_city" VALUES(12817,'Oak Grove','Oak Grove, Kentucky',16124,21);
INSERT INTO "django_geo_db_city" VALUES(12818,'Olmstead','Olmstead, Kentucky',16125,21);
INSERT INTO "django_geo_db_city" VALUES(12819,'Pembroke','Pembroke, Kentucky',16126,21);
INSERT INTO "django_geo_db_city" VALUES(12820,'Provo','Provo, Kentucky',16127,21);
INSERT INTO "django_geo_db_city" VALUES(12821,'Richardsville','Richardsville, Kentucky',16070,21);
INSERT INTO "django_geo_db_city" VALUES(12822,'Rochester','Rochester, Kentucky',16128,21);
INSERT INTO "django_geo_db_city" VALUES(12823,'Rockfield','Rockfield, Kentucky',16129,21);
INSERT INTO "django_geo_db_city" VALUES(12824,'Roundhill','Roundhill, Kentucky',16130,21);
INSERT INTO "django_geo_db_city" VALUES(12825,'Russellville','Russellville, Kentucky',16131,21);
INSERT INTO "django_geo_db_city" VALUES(12826,'Sharon Grove','Sharon Grove, Kentucky',16132,21);
INSERT INTO "django_geo_db_city" VALUES(12827,'South Union','South Union, Kentucky',16133,21);
INSERT INTO "django_geo_db_city" VALUES(12828,'Sweeden','Sweeden, Kentucky',16134,21);
INSERT INTO "django_geo_db_city" VALUES(12829,'Trenton','Trenton, Kentucky',16135,21);
INSERT INTO "django_geo_db_city" VALUES(12830,'Welchs Creek','Welchs Creek, Kentucky',16136,21);
INSERT INTO "django_geo_db_city" VALUES(12831,'Woodbury','Woodbury, Kentucky',16101,21);
INSERT INTO "django_geo_db_city" VALUES(12832,'Owensboro','Owensboro, Kentucky',16137,21);
INSERT INTO "django_geo_db_city" VALUES(12833,'Beaver Dam','Beaver Dam, Kentucky',16140,21);
INSERT INTO "django_geo_db_city" VALUES(12834,'Beech Creek','Beech Creek, Kentucky',16141,21);
INSERT INTO "django_geo_db_city" VALUES(12835,'Beech Grove','Beech Grove, Kentucky',16142,21);
INSERT INTO "django_geo_db_city" VALUES(12836,'Beechmont','Beechmont, Kentucky',16143,21);
INSERT INTO "django_geo_db_city" VALUES(12837,'Belton','Belton, Kentucky',16144,21);
INSERT INTO "django_geo_db_city" VALUES(12838,'Bremen','Bremen, Kentucky',16145,21);
INSERT INTO "django_geo_db_city" VALUES(12839,'Browder','Browder, Kentucky',16146,21);
INSERT INTO "django_geo_db_city" VALUES(12840,'Calhoun','Calhoun, Kentucky',16147,21);
INSERT INTO "django_geo_db_city" VALUES(12841,'Centertown','Centertown, Kentucky',16148,21);
INSERT INTO "django_geo_db_city" VALUES(12842,'Central City','Central City, Kentucky',16149,21);
INSERT INTO "django_geo_db_city" VALUES(12843,'Cleaton','Cleaton, Kentucky',16150,21);
INSERT INTO "django_geo_db_city" VALUES(12844,'Cromwell','Cromwell, Kentucky',16151,21);
INSERT INTO "django_geo_db_city" VALUES(12845,'Curdsville','Curdsville, Kentucky',16138,21);
INSERT INTO "django_geo_db_city" VALUES(12846,'Drakesboro','Drakesboro, Kentucky',16152,21);
INSERT INTO "django_geo_db_city" VALUES(12847,'Dundee','Dundee, Kentucky',16153,21);
INSERT INTO "django_geo_db_city" VALUES(12848,'Dunmor','Dunmor, Kentucky',16154,21);
INSERT INTO "django_geo_db_city" VALUES(12849,'Fordsville','Fordsville, Kentucky',16155,21);
INSERT INTO "django_geo_db_city" VALUES(12850,'Graham','Graham, Kentucky',16156,21);
INSERT INTO "django_geo_db_city" VALUES(12851,'Greenville','Greenville, Kentucky',16157,21);
INSERT INTO "django_geo_db_city" VALUES(12852,'Hartford','Hartford, Kentucky',16158,21);
INSERT INTO "django_geo_db_city" VALUES(12853,'Hawesville','Hawesville, Kentucky',16159,21);
INSERT INTO "django_geo_db_city" VALUES(12854,'Horse Branch','Horse Branch, Kentucky',16160,21);
INSERT INTO "django_geo_db_city" VALUES(12855,'Island','Island, Kentucky',16161,21);
INSERT INTO "django_geo_db_city" VALUES(12856,'Lewisport','Lewisport, Kentucky',16162,21);
INSERT INTO "django_geo_db_city" VALUES(12857,'Livermore','Livermore, Kentucky',16163,21);
INSERT INTO "django_geo_db_city" VALUES(12858,'McHenry','McHenry, Kentucky',16164,21);
INSERT INTO "django_geo_db_city" VALUES(12859,'Maceo','Maceo, Kentucky',16165,21);
INSERT INTO "django_geo_db_city" VALUES(12860,'Maple Mount','Maple Mount, Kentucky',16166,21);
INSERT INTO "django_geo_db_city" VALUES(12861,'Olaton','Olaton, Kentucky',16167,21);
INSERT INTO "django_geo_db_city" VALUES(12862,'Pellville','Pellville, Kentucky',16168,21);
INSERT INTO "django_geo_db_city" VALUES(12863,'Penrod','Penrod, Kentucky',16169,21);
INSERT INTO "django_geo_db_city" VALUES(12864,'Philpot','Philpot, Kentucky',16170,21);
INSERT INTO "django_geo_db_city" VALUES(12865,'Powderly','Powderly, Kentucky',16171,21);
INSERT INTO "django_geo_db_city" VALUES(12866,'Reynolds Station','Reynolds Station, Kentucky',16172,21);
INSERT INTO "django_geo_db_city" VALUES(12867,'Rockport','Rockport, Kentucky',16173,21);
INSERT INTO "django_geo_db_city" VALUES(12868,'Rosine','Rosine, Kentucky',16174,21);
INSERT INTO "django_geo_db_city" VALUES(12869,'Rumsey','Rumsey, Kentucky',16175,21);
INSERT INTO "django_geo_db_city" VALUES(12870,'Sacramento','Sacramento, Kentucky',16176,21);
INSERT INTO "django_geo_db_city" VALUES(12871,'South Carrollton','South Carrollton, Kentucky',16177,21);
INSERT INTO "django_geo_db_city" VALUES(12872,'Stanley','Stanley, Kentucky',16138,21);
INSERT INTO "django_geo_db_city" VALUES(12873,'Utica','Utica, Kentucky',16178,21);
INSERT INTO "django_geo_db_city" VALUES(12874,'West Louisville','West Louisville, Kentucky',16138,21);
INSERT INTO "django_geo_db_city" VALUES(12875,'Whitesville','Whitesville, Kentucky',16179,21);
INSERT INTO "django_geo_db_city" VALUES(12876,'Morganfield','Morganfield, Kentucky',16180,21);
INSERT INTO "django_geo_db_city" VALUES(12877,'Baskett','Baskett, Kentucky',16181,21);
INSERT INTO "django_geo_db_city" VALUES(12878,'Blackford','Blackford, Kentucky',16182,21);
INSERT INTO "django_geo_db_city" VALUES(12879,'Clay','Clay, Kentucky',16183,21);
INSERT INTO "django_geo_db_city" VALUES(12880,'Corydon','Corydon, Kentucky',16184,21);
INSERT INTO "django_geo_db_city" VALUES(12881,'Dawson Springs','Dawson Springs, Kentucky',16185,21);
INSERT INTO "django_geo_db_city" VALUES(12882,'Dixon','Dixon, Kentucky',16186,21);
INSERT INTO "django_geo_db_city" VALUES(12883,'Earlington','Earlington, Kentucky',16187,21);
INSERT INTO "django_geo_db_city" VALUES(12884,'Hanson','Hanson, Kentucky',16189,21);
INSERT INTO "django_geo_db_city" VALUES(12885,'Henderson','Henderson, Kentucky',16190,21);
INSERT INTO "django_geo_db_city" VALUES(12886,'Madisonville','Madisonville, Kentucky',16192,21);
INSERT INTO "django_geo_db_city" VALUES(12887,'Manitou','Manitou, Kentucky',16193,21);
INSERT INTO "django_geo_db_city" VALUES(12888,'Mortons Gap','Mortons Gap, Kentucky',16195,21);
INSERT INTO "django_geo_db_city" VALUES(12889,'Nebo','Nebo, Kentucky',16196,21);
INSERT INTO "django_geo_db_city" VALUES(12890,'Nortonville','Nortonville, Kentucky',16197,21);
INSERT INTO "django_geo_db_city" VALUES(12891,'Poole','Poole, Kentucky',16198,21);
INSERT INTO "django_geo_db_city" VALUES(12892,'Princeton','Princeton, Kentucky',16199,21);
INSERT INTO "django_geo_db_city" VALUES(12893,'Providence','Providence, Kentucky',16200,21);
INSERT INTO "django_geo_db_city" VALUES(12894,'Reed','Reed, Kentucky',16201,21);
INSERT INTO "django_geo_db_city" VALUES(12895,'Robards','Robards, Kentucky',16202,21);
INSERT INTO "django_geo_db_city" VALUES(12896,'Saint Charles','Saint Charles, Kentucky',16203,21);
INSERT INTO "django_geo_db_city" VALUES(12897,'Sebree','Sebree, Kentucky',16204,21);
INSERT INTO "django_geo_db_city" VALUES(12898,'Slaughters','Slaughters, Kentucky',16205,21);
INSERT INTO "django_geo_db_city" VALUES(12899,'Smith Mills','Smith Mills, Kentucky',16206,21);
INSERT INTO "django_geo_db_city" VALUES(12900,'Spottsville','Spottsville, Kentucky',16207,21);
INSERT INTO "django_geo_db_city" VALUES(12901,'Sturgis','Sturgis, Kentucky',16208,21);
INSERT INTO "django_geo_db_city" VALUES(12902,'Sullivan','Sullivan, Kentucky',16209,21);
INSERT INTO "django_geo_db_city" VALUES(12903,'Uniontown','Uniontown, Kentucky',16210,21);
INSERT INTO "django_geo_db_city" VALUES(12904,'Waverly','Waverly, Kentucky',16211,21);
INSERT INTO "django_geo_db_city" VALUES(12905,'Wheatcroft','Wheatcroft, Kentucky',16212,21);
INSERT INTO "django_geo_db_city" VALUES(12906,'White Plains','White Plains, Kentucky',16213,21);
INSERT INTO "django_geo_db_city" VALUES(12907,'Somerset','Somerset, Kentucky',16214,21);
INSERT INTO "django_geo_db_city" VALUES(12908,'Bethelridge','Bethelridge, Kentucky',16217,21);
INSERT INTO "django_geo_db_city" VALUES(12909,'Bronston','Bronston, Kentucky',16218,21);
INSERT INTO "django_geo_db_city" VALUES(12910,'Burnside','Burnside, Kentucky',16219,21);
INSERT INTO "django_geo_db_city" VALUES(12911,'Dunnville','Dunnville, Kentucky',16220,21);
INSERT INTO "django_geo_db_city" VALUES(12912,'Ferguson','Ferguson, Kentucky',16221,21);
INSERT INTO "django_geo_db_city" VALUES(12913,'Liberty','Liberty, Kentucky',16222,21);
INSERT INTO "django_geo_db_city" VALUES(12914,'Middleburg','Middleburg, Kentucky',16223,21);
INSERT INTO "django_geo_db_city" VALUES(12915,'Nancy','Nancy, Kentucky',16224,21);
INSERT INTO "django_geo_db_city" VALUES(12916,'Tateville','Tateville, Kentucky',16226,21);
INSERT INTO "django_geo_db_city" VALUES(12917,'West Somerset','West Somerset, Kentucky',16227,21);
INSERT INTO "django_geo_db_city" VALUES(12918,'Windsor','Windsor, Kentucky',16228,21);
INSERT INTO "django_geo_db_city" VALUES(12919,'Yosemite','Yosemite, Kentucky',16229,21);
INSERT INTO "django_geo_db_city" VALUES(12920,'Eubank','Eubank, Kentucky',16230,21);
INSERT INTO "django_geo_db_city" VALUES(12921,'Albany','Albany, Kentucky',16231,21);
INSERT INTO "django_geo_db_city" VALUES(12922,'Alpha','Alpha, Kentucky',16232,21);
INSERT INTO "django_geo_db_city" VALUES(12923,'Jamestown','Jamestown, Kentucky',16233,21);
INSERT INTO "django_geo_db_city" VALUES(12924,'Marshes Siding','Marshes Siding, Kentucky',16234,21);
INSERT INTO "django_geo_db_city" VALUES(12925,'Mill Springs','Mill Springs, Kentucky',16235,21);
INSERT INTO "django_geo_db_city" VALUES(12926,'Monticello','Monticello, Kentucky',16236,21);
INSERT INTO "django_geo_db_city" VALUES(12927,'Parkers Lake','Parkers Lake, Kentucky',16237,21);
INSERT INTO "django_geo_db_city" VALUES(12928,'Pine Knot','Pine Knot, Kentucky',16238,21);
INSERT INTO "django_geo_db_city" VALUES(12929,'Revelo','Revelo, Kentucky',16240,21);
INSERT INTO "django_geo_db_city" VALUES(12930,'Russell Springs','Russell Springs, Kentucky',16241,21);
INSERT INTO "django_geo_db_city" VALUES(12931,'Stearns','Stearns, Kentucky',16242,21);
INSERT INTO "django_geo_db_city" VALUES(12932,'Strunk','Strunk, Kentucky',16243,21);
INSERT INTO "django_geo_db_city" VALUES(12933,'Whitley City','Whitley City, Kentucky',16244,21);
INSERT INTO "django_geo_db_city" VALUES(12934,'Elizabethtown','Elizabethtown, Kentucky',16245,21);
INSERT INTO "django_geo_db_city" VALUES(12935,'Bakerton','Bakerton, Kentucky',16246,21);
INSERT INTO "django_geo_db_city" VALUES(12936,'Big Clifty','Big Clifty, Kentucky',16247,21);
INSERT INTO "django_geo_db_city" VALUES(12937,'Bonnieville','Bonnieville, Kentucky',16248,21);
INSERT INTO "django_geo_db_city" VALUES(12938,'Breeding','Breeding, Kentucky',16249,21);
INSERT INTO "django_geo_db_city" VALUES(12939,'Buffalo','Buffalo, Kentucky',16250,21);
INSERT INTO "django_geo_db_city" VALUES(12940,'Burkesville','Burkesville, Kentucky',16251,21);
INSERT INTO "django_geo_db_city" VALUES(12941,'Campbellsville','Campbellsville, Kentucky',16252,21);
INSERT INTO "django_geo_db_city" VALUES(12942,'Cane Valley','Cane Valley, Kentucky',16254,21);
INSERT INTO "django_geo_db_city" VALUES(12943,'Caneyville','Caneyville, Kentucky',16255,21);
INSERT INTO "django_geo_db_city" VALUES(12944,'Canmer','Canmer, Kentucky',16256,21);
INSERT INTO "django_geo_db_city" VALUES(12945,'Cecilia','Cecilia, Kentucky',16257,21);
INSERT INTO "django_geo_db_city" VALUES(12946,'Clarkson','Clarkson, Kentucky',16258,21);
INSERT INTO "django_geo_db_city" VALUES(12947,'Columbia','Columbia, Kentucky',16259,21);
INSERT INTO "django_geo_db_city" VALUES(12948,'Cub Run','Cub Run, Kentucky',16260,21);
INSERT INTO "django_geo_db_city" VALUES(12949,'Dubre','Dubre, Kentucky',16261,21);
INSERT INTO "django_geo_db_city" VALUES(12950,'Eastview','Eastview, Kentucky',16262,21);
INSERT INTO "django_geo_db_city" VALUES(12951,'Elk Horn','Elk Horn, Kentucky',16263,21);
INSERT INTO "django_geo_db_city" VALUES(12952,'Fairplay','Fairplay, Kentucky',16264,21);
INSERT INTO "django_geo_db_city" VALUES(12953,'Glendale','Glendale, Kentucky',16265,21);
INSERT INTO "django_geo_db_city" VALUES(12954,'Glens Fork','Glens Fork, Kentucky',16266,21);
INSERT INTO "django_geo_db_city" VALUES(12955,'Gradyville','Gradyville, Kentucky',16267,21);
INSERT INTO "django_geo_db_city" VALUES(12956,'Greensburg','Greensburg, Kentucky',16268,21);
INSERT INTO "django_geo_db_city" VALUES(12957,'Hardyville','Hardyville, Kentucky',16269,21);
INSERT INTO "django_geo_db_city" VALUES(12958,'Hodgenville','Hodgenville, Kentucky',16270,21);
INSERT INTO "django_geo_db_city" VALUES(12959,'Horse Cave','Horse Cave, Kentucky',16271,21);
INSERT INTO "django_geo_db_city" VALUES(12960,'Knifley','Knifley, Kentucky',16272,21);
INSERT INTO "django_geo_db_city" VALUES(12961,'Leitchfield','Leitchfield, Kentucky',16273,21);
INSERT INTO "django_geo_db_city" VALUES(12962,'Magnolia','Magnolia, Kentucky',16275,21);
INSERT INTO "django_geo_db_city" VALUES(12963,'Mannsville','Mannsville, Kentucky',16276,21);
INSERT INTO "django_geo_db_city" VALUES(12964,'Marrowbone','Marrowbone, Kentucky',16277,21);
INSERT INTO "django_geo_db_city" VALUES(12965,'Milltown','Milltown, Kentucky',16278,21);
INSERT INTO "django_geo_db_city" VALUES(12966,'Millwood','Millwood, Kentucky',16279,21);
INSERT INTO "django_geo_db_city" VALUES(12967,'Mount Sherman','Mount Sherman, Kentucky',16280,21);
INSERT INTO "django_geo_db_city" VALUES(12968,'Munfordville','Munfordville, Kentucky',16281,21);
INSERT INTO "django_geo_db_city" VALUES(12969,'Sonora','Sonora, Kentucky',16282,21);
INSERT INTO "django_geo_db_city" VALUES(12970,'Summersville','Summersville, Kentucky',16283,21);
INSERT INTO "django_geo_db_city" VALUES(12971,'Summit','Summit, Kentucky',16284,21);
INSERT INTO "django_geo_db_city" VALUES(12972,'Upton','Upton, Kentucky',16285,21);
INSERT INTO "django_geo_db_city" VALUES(12973,'Waterview','Waterview, Kentucky',16286,21);
INSERT INTO "django_geo_db_city" VALUES(12974,'White Mills','White Mills, Kentucky',16287,21);
INSERT INTO "django_geo_db_city" VALUES(12975,'Alexandria','Alexandria, Ohio',16288,35);
INSERT INTO "django_geo_db_city" VALUES(12976,'Amlin','Amlin, Ohio',16289,35);
INSERT INTO "django_geo_db_city" VALUES(12977,'Ashley','Ashley, Ohio',16290,35);
INSERT INTO "django_geo_db_city" VALUES(12978,'Blacklick','Blacklick, Ohio',16291,35);
INSERT INTO "django_geo_db_city" VALUES(12979,'Bladensburg','Bladensburg, Ohio',16292,35);
INSERT INTO "django_geo_db_city" VALUES(12980,'Brinkhaven','Brinkhaven, Ohio',16293,35);
INSERT INTO "django_geo_db_city" VALUES(12981,'Broadway','Broadway, Ohio',16294,35);
INSERT INTO "django_geo_db_city" VALUES(12982,'Buckeye Lake','Buckeye Lake, Ohio',16295,35);
INSERT INTO "django_geo_db_city" VALUES(12983,'Cable','Cable, Ohio',16296,35);
INSERT INTO "django_geo_db_city" VALUES(12984,'Catawba','Catawba, Ohio',16297,35);
INSERT INTO "django_geo_db_city" VALUES(12985,'Centerburg','Centerburg, Ohio',16298,35);
INSERT INTO "django_geo_db_city" VALUES(12986,'Croton','Croton, Ohio',16299,35);
INSERT INTO "django_geo_db_city" VALUES(12987,'Danville','Danville, Ohio',16300,35);
INSERT INTO "django_geo_db_city" VALUES(12988,'Delaware','Delaware, Ohio',16301,35);
INSERT INTO "django_geo_db_city" VALUES(12989,'Dublin','Dublin, Ohio',16302,35);
INSERT INTO "django_geo_db_city" VALUES(12990,'Etna','Etna, Ohio',16304,35);
INSERT INTO "django_geo_db_city" VALUES(12991,'Fredericktown','Fredericktown, Ohio',16305,35);
INSERT INTO "django_geo_db_city" VALUES(12992,'Galena','Galena, Ohio',16306,35);
INSERT INTO "django_geo_db_city" VALUES(12993,'Gambier','Gambier, Ohio',16307,35);
INSERT INTO "django_geo_db_city" VALUES(12994,'Granville','Granville, Ohio',16308,35);
INSERT INTO "django_geo_db_city" VALUES(12995,'Hebron','Hebron, Ohio',16309,35);
INSERT INTO "django_geo_db_city" VALUES(12996,'Hilliard','Hilliard, Ohio',16310,35);
INSERT INTO "django_geo_db_city" VALUES(12997,'Homer','Homer, Ohio',16311,35);
INSERT INTO "django_geo_db_city" VALUES(12998,'Howard','Howard, Ohio',16312,35);
INSERT INTO "django_geo_db_city" VALUES(12999,'Irwin','Irwin, Ohio',16313,35);
INSERT INTO "django_geo_db_city" VALUES(13000,'Jacksontown','Jacksontown, Ohio',16314,35);
INSERT INTO "django_geo_db_city" VALUES(13001,'Johnstown','Johnstown, Ohio',16315,35);
INSERT INTO "django_geo_db_city" VALUES(13002,'Kilbourne','Kilbourne, Ohio',16316,35);
INSERT INTO "django_geo_db_city" VALUES(13003,'Kirkersville','Kirkersville, Ohio',16317,35);
INSERT INTO "django_geo_db_city" VALUES(13004,'Lewis Center','Lewis Center, Ohio',16318,35);
INSERT INTO "django_geo_db_city" VALUES(13005,'Magnetic Springs','Magnetic Springs, Ohio',16319,35);
INSERT INTO "django_geo_db_city" VALUES(13006,'Martinsburg','Martinsburg, Ohio',16320,35);
INSERT INTO "django_geo_db_city" VALUES(13007,'Marysville','Marysville, Ohio',16321,35);
INSERT INTO "django_geo_db_city" VALUES(13008,'Mechanicsburg','Mechanicsburg, Ohio',16323,35);
INSERT INTO "django_geo_db_city" VALUES(13009,'Milford Center','Milford Center, Ohio',16324,35);
INSERT INTO "django_geo_db_city" VALUES(13010,'Millersport','Millersport, Ohio',16325,35);
INSERT INTO "django_geo_db_city" VALUES(13011,'Mingo','Mingo, Ohio',16326,35);
INSERT INTO "django_geo_db_city" VALUES(13012,'Mount Liberty','Mount Liberty, Ohio',16327,35);
INSERT INTO "django_geo_db_city" VALUES(13013,'Mount Vernon','Mount Vernon, Ohio',16328,35);
INSERT INTO "django_geo_db_city" VALUES(13014,'New Albany','New Albany, Ohio',16329,35);
INSERT INTO "django_geo_db_city" VALUES(13015,'Newark','Newark, Ohio',16330,35);
INSERT INTO "django_geo_db_city" VALUES(13016,'Heath','Heath, Ohio',16331,35);
INSERT INTO "django_geo_db_city" VALUES(13017,'North Lewisburg','North Lewisburg, Ohio',16333,35);
INSERT INTO "django_geo_db_city" VALUES(13018,'Ostrander','Ostrander, Ohio',16334,35);
INSERT INTO "django_geo_db_city" VALUES(13019,'Pataskala','Pataskala, Ohio',16335,35);
INSERT INTO "django_geo_db_city" VALUES(13020,'Plain City','Plain City, Ohio',16336,35);
INSERT INTO "django_geo_db_city" VALUES(13021,'Powell','Powell, Ohio',16337,35);
INSERT INTO "django_geo_db_city" VALUES(13022,'Radnor','Radnor, Ohio',16338,35);
INSERT INTO "django_geo_db_city" VALUES(13023,'Raymond','Raymond, Ohio',16339,35);
INSERT INTO "django_geo_db_city" VALUES(13024,'Reynoldsburg','Reynoldsburg, Ohio',16340,35);
INSERT INTO "django_geo_db_city" VALUES(13025,'Rosewood','Rosewood, Ohio',16341,35);
INSERT INTO "django_geo_db_city" VALUES(13026,'Saint Louisville','Saint Louisville, Ohio',16342,35);
INSERT INTO "django_geo_db_city" VALUES(13027,'Saint Paris','Saint Paris, Ohio',16343,35);
INSERT INTO "django_geo_db_city" VALUES(13028,'Summit Station','Summit Station, Ohio',16344,35);
INSERT INTO "django_geo_db_city" VALUES(13029,'Sunbury','Sunbury, Ohio',16345,35);
INSERT INTO "django_geo_db_city" VALUES(13030,'Thornville','Thornville, Ohio',16346,35);
INSERT INTO "django_geo_db_city" VALUES(13031,'Unionville Center','Unionville Center, Ohio',16347,35);
INSERT INTO "django_geo_db_city" VALUES(13032,'Urbana','Urbana, Ohio',16348,35);
INSERT INTO "django_geo_db_city" VALUES(13033,'Utica','Utica, Ohio',16349,35);
INSERT INTO "django_geo_db_city" VALUES(13034,'Westerville','Westerville, Ohio',16350,35);
INSERT INTO "django_geo_db_city" VALUES(13035,'Westville','Westville, Ohio',16352,35);
INSERT INTO "django_geo_db_city" VALUES(13036,'Woodstock','Woodstock, Ohio',16353,35);
INSERT INTO "django_geo_db_city" VALUES(13037,'Columbus','Columbus, Ohio',16354,35);
INSERT INTO "django_geo_db_city" VALUES(13038,'Adelphi','Adelphi, Ohio',16356,35);
INSERT INTO "django_geo_db_city" VALUES(13039,'Amanda','Amanda, Ohio',16357,35);
INSERT INTO "django_geo_db_city" VALUES(13040,'Ashville','Ashville, Ohio',16358,35);
INSERT INTO "django_geo_db_city" VALUES(13041,'Baltimore','Baltimore, Ohio',16359,35);
INSERT INTO "django_geo_db_city" VALUES(13042,'Bloomingburg','Bloomingburg, Ohio',16360,35);
INSERT INTO "django_geo_db_city" VALUES(13043,'Bremen','Bremen, Ohio',16361,35);
INSERT INTO "django_geo_db_city" VALUES(13044,'Brice','Brice, Ohio',16362,35);
INSERT INTO "django_geo_db_city" VALUES(13045,'Canal Winchester','Canal Winchester, Ohio',16363,35);
INSERT INTO "django_geo_db_city" VALUES(13046,'Carbon Hill','Carbon Hill, Ohio',16364,35);
INSERT INTO "django_geo_db_city" VALUES(13047,'Carroll','Carroll, Ohio',16365,35);
INSERT INTO "django_geo_db_city" VALUES(13048,'Circleville','Circleville, Ohio',16366,35);
INSERT INTO "django_geo_db_city" VALUES(13049,'Clarksburg','Clarksburg, Ohio',16367,35);
INSERT INTO "django_geo_db_city" VALUES(13050,'Commercial Point','Commercial Point, Ohio',16368,35);
INSERT INTO "django_geo_db_city" VALUES(13051,'Derby','Derby, Ohio',16369,35);
INSERT INTO "django_geo_db_city" VALUES(13052,'Galloway','Galloway, Ohio',16370,35);
INSERT INTO "django_geo_db_city" VALUES(13053,'Grove City','Grove City, Ohio',16371,35);
INSERT INTO "django_geo_db_city" VALUES(13054,'Groveport','Groveport, Ohio',16372,35);
INSERT INTO "django_geo_db_city" VALUES(13055,'Harrisburg','Harrisburg, Ohio',16373,35);
INSERT INTO "django_geo_db_city" VALUES(13056,'Haydenville','Haydenville, Ohio',16374,35);
INSERT INTO "django_geo_db_city" VALUES(13057,'Jeffersonville','Jeffersonville, Ohio',16375,35);
INSERT INTO "django_geo_db_city" VALUES(13058,'Lancaster','Lancaster, Ohio',16376,35);
INSERT INTO "django_geo_db_city" VALUES(13059,'Laurelville','Laurelville, Ohio',16377,35);
INSERT INTO "django_geo_db_city" VALUES(13060,'Lithopolis','Lithopolis, Ohio',16378,35);
INSERT INTO "django_geo_db_city" VALUES(13061,'Lockbourne','Lockbourne, Ohio',16379,35);
INSERT INTO "django_geo_db_city" VALUES(13062,'Logan','Logan, Ohio',16380,35);
INSERT INTO "django_geo_db_city" VALUES(13063,'London','London, Ohio',16381,35);
INSERT INTO "django_geo_db_city" VALUES(13064,'Milledgeville','Milledgeville, Ohio',16382,35);
INSERT INTO "django_geo_db_city" VALUES(13065,'Mount Sterling','Mount Sterling, Ohio',16383,35);
INSERT INTO "django_geo_db_city" VALUES(13066,'Murray City','Murray City, Ohio',16384,35);
INSERT INTO "django_geo_db_city" VALUES(13067,'New Holland','New Holland, Ohio',16385,35);
INSERT INTO "django_geo_db_city" VALUES(13068,'Orient','Orient, Ohio',16386,35);
INSERT INTO "django_geo_db_city" VALUES(13069,'Pickerington','Pickerington, Ohio',16387,35);
INSERT INTO "django_geo_db_city" VALUES(13070,'Pleasantville','Pleasantville, Ohio',16388,35);
INSERT INTO "django_geo_db_city" VALUES(13071,'Rockbridge','Rockbridge, Ohio',16389,35);
INSERT INTO "django_geo_db_city" VALUES(13072,'Rushville','Rushville, Ohio',16390,35);
INSERT INTO "django_geo_db_city" VALUES(13073,'Sedalia','Sedalia, Ohio',16391,35);
INSERT INTO "django_geo_db_city" VALUES(13074,'South Bloomingville','South Bloomingville, Ohio',16392,35);
INSERT INTO "django_geo_db_city" VALUES(13075,'South Solon','South Solon, Ohio',16393,35);
INSERT INTO "django_geo_db_city" VALUES(13076,'Stoutsville','Stoutsville, Ohio',16394,35);
INSERT INTO "django_geo_db_city" VALUES(13077,'Sugar Grove','Sugar Grove, Ohio',16395,35);
INSERT INTO "django_geo_db_city" VALUES(13078,'Tarlton','Tarlton, Ohio',16396,35);
INSERT INTO "django_geo_db_city" VALUES(13079,'Thurston','Thurston, Ohio',16397,35);
INSERT INTO "django_geo_db_city" VALUES(13080,'Union Furnace','Union Furnace, Ohio',16398,35);
INSERT INTO "django_geo_db_city" VALUES(13081,'Washington Court House','Washington Court House, Ohio',16399,35);
INSERT INTO "django_geo_db_city" VALUES(13082,'West Jefferson','West Jefferson, Ohio',16400,35);
INSERT INTO "django_geo_db_city" VALUES(13083,'West Rushville','West Rushville, Ohio',16401,35);
INSERT INTO "django_geo_db_city" VALUES(13084,'Williamsport','Williamsport, Ohio',16402,35);
INSERT INTO "django_geo_db_city" VALUES(13085,'Marion','Marion, Ohio',16434,35);
INSERT INTO "django_geo_db_city" VALUES(13086,'Belle Center','Belle Center, Ohio',16437,35);
INSERT INTO "django_geo_db_city" VALUES(13087,'Bellefontaine','Bellefontaine, Ohio',16438,35);
INSERT INTO "django_geo_db_city" VALUES(13088,'Caledonia','Caledonia, Ohio',16439,35);
INSERT INTO "django_geo_db_city" VALUES(13089,'Cardington','Cardington, Ohio',16440,35);
INSERT INTO "django_geo_db_city" VALUES(13090,'Carey','Carey, Ohio',16441,35);
INSERT INTO "django_geo_db_city" VALUES(13091,'Chesterville','Chesterville, Ohio',16442,35);
INSERT INTO "django_geo_db_city" VALUES(13092,'De Graff','De Graff, Ohio',16443,35);
INSERT INTO "django_geo_db_city" VALUES(13093,'East Liberty','East Liberty, Ohio',16444,35);
INSERT INTO "django_geo_db_city" VALUES(13094,'Edison','Edison, Ohio',16445,35);
INSERT INTO "django_geo_db_city" VALUES(13095,'Fulton','Fulton, Ohio',16446,35);
INSERT INTO "django_geo_db_city" VALUES(13096,'Green Camp','Green Camp, Ohio',16447,35);
INSERT INTO "django_geo_db_city" VALUES(13097,'Harpster','Harpster, Ohio',16448,35);
INSERT INTO "django_geo_db_city" VALUES(13098,'Huntsville','Huntsville, Ohio',16449,35);
INSERT INTO "django_geo_db_city" VALUES(13099,'Iberia','Iberia, Ohio',16450,35);
INSERT INTO "django_geo_db_city" VALUES(13100,'Kenton','Kenton, Ohio',16451,35);
INSERT INTO "django_geo_db_city" VALUES(13101,'Kirby','Kirby, Ohio',16452,35);
INSERT INTO "django_geo_db_city" VALUES(13102,'Lakeview','Lakeview, Ohio',16453,35);
INSERT INTO "django_geo_db_city" VALUES(13103,'La Rue','La Rue, Ohio',16454,35);
INSERT INTO "django_geo_db_city" VALUES(13104,'Lewistown','Lewistown, Ohio',16455,35);
INSERT INTO "django_geo_db_city" VALUES(13105,'Marengo','Marengo, Ohio',16456,35);
INSERT INTO "django_geo_db_city" VALUES(13106,'Martel','Martel, Ohio',16457,35);
INSERT INTO "django_geo_db_city" VALUES(13107,'Middleburg','Middleburg, Ohio',16458,35);
INSERT INTO "django_geo_db_city" VALUES(13108,'Morral','Morral, Ohio',16459,35);
INSERT INTO "django_geo_db_city" VALUES(13109,'Mount Gilead','Mount Gilead, Ohio',16460,35);
INSERT INTO "django_geo_db_city" VALUES(13110,'Mount Victory','Mount Victory, Ohio',16461,35);
INSERT INTO "django_geo_db_city" VALUES(13111,'New Bloomington','New Bloomington, Ohio',16462,35);
INSERT INTO "django_geo_db_city" VALUES(13112,'Prospect','Prospect, Ohio',16463,35);
INSERT INTO "django_geo_db_city" VALUES(13113,'Quincy','Quincy, Ohio',16464,35);
INSERT INTO "django_geo_db_city" VALUES(13114,'Richwood','Richwood, Ohio',16465,35);
INSERT INTO "django_geo_db_city" VALUES(13115,'Ridgeway','Ridgeway, Ohio',16466,35);
INSERT INTO "django_geo_db_city" VALUES(13116,'Roundhead','Roundhead, Ohio',16467,35);
INSERT INTO "django_geo_db_city" VALUES(13117,'Rushsylvania','Rushsylvania, Ohio',16468,35);
INSERT INTO "django_geo_db_city" VALUES(13118,'Russells Point','Russells Point, Ohio',16469,35);
INSERT INTO "django_geo_db_city" VALUES(13119,'Shauck','Shauck, Ohio',16470,35);
INSERT INTO "django_geo_db_city" VALUES(13120,'Sparta','Sparta, Ohio',16471,35);
INSERT INTO "django_geo_db_city" VALUES(13121,'Upper Sandusky','Upper Sandusky, Ohio',16472,35);
INSERT INTO "django_geo_db_city" VALUES(13122,'Ridgeville','Ridgeville, Ohio',16473,35);
INSERT INTO "django_geo_db_city" VALUES(13123,'Waldo','Waldo, Ohio',16474,35);
INSERT INTO "django_geo_db_city" VALUES(13124,'West Liberty','West Liberty, Ohio',16475,35);
INSERT INTO "django_geo_db_city" VALUES(13125,'West Mansfield','West Mansfield, Ohio',16476,35);
INSERT INTO "django_geo_db_city" VALUES(13126,'Wharton','Wharton, Ohio',16477,35);
INSERT INTO "django_geo_db_city" VALUES(13127,'Zanesfield','Zanesfield, Ohio',16478,35);
INSERT INTO "django_geo_db_city" VALUES(13128,'Stokes','Stokes, Ohio',16479,35);
INSERT INTO "django_geo_db_city" VALUES(13129,'Danbury','Danbury, Ohio',16480,35);
INSERT INTO "django_geo_db_city" VALUES(13130,'Bowling Green','Bowling Green, Ohio',16481,35);
INSERT INTO "django_geo_db_city" VALUES(13131,'Bradner','Bradner, Ohio',16483,35);
INSERT INTO "django_geo_db_city" VALUES(13132,'Burgoon','Burgoon, Ohio',16484,35);
INSERT INTO "django_geo_db_city" VALUES(13133,'Clay Center','Clay Center, Ohio',16485,35);
INSERT INTO "django_geo_db_city" VALUES(13134,'Clyde','Clyde, Ohio',16486,35);
INSERT INTO "django_geo_db_city" VALUES(13135,'Curtice','Curtice, Ohio',16487,35);
INSERT INTO "django_geo_db_city" VALUES(13136,'Cygnet','Cygnet, Ohio',16488,35);
INSERT INTO "django_geo_db_city" VALUES(13137,'Dunbridge','Dunbridge, Ohio',16482,35);
INSERT INTO "django_geo_db_city" VALUES(13138,'Elmore','Elmore, Ohio',16489,35);
INSERT INTO "django_geo_db_city" VALUES(13139,'Fremont','Fremont, Ohio',16490,35);
INSERT INTO "django_geo_db_city" VALUES(13140,'Genoa','Genoa, Ohio',16491,35);
INSERT INTO "django_geo_db_city" VALUES(13141,'Gibsonburg','Gibsonburg, Ohio',16492,35);
INSERT INTO "django_geo_db_city" VALUES(13142,'Graytown','Graytown, Ohio',16493,35);
INSERT INTO "django_geo_db_city" VALUES(13143,'Gypsum','Gypsum, Ohio',16494,35);
INSERT INTO "django_geo_db_city" VALUES(13144,'Harbor View','Harbor View, Ohio',16495,35);
INSERT INTO "django_geo_db_city" VALUES(13145,'Helena','Helena, Ohio',16496,35);
INSERT INTO "django_geo_db_city" VALUES(13146,'Isle Saint George','Isle Saint George, Ohio',16497,35);
INSERT INTO "django_geo_db_city" VALUES(13147,'Jerry City','Jerry City, Ohio',16498,35);
INSERT INTO "django_geo_db_city" VALUES(13148,'Kelleys Island','Kelleys Island, Ohio',16499,35);
INSERT INTO "django_geo_db_city" VALUES(13149,'Lacarne','Lacarne, Ohio',16500,35);
INSERT INTO "django_geo_db_city" VALUES(13150,'Lakeside Marblehead','Lakeside Marblehead, Ohio',16501,35);
INSERT INTO "django_geo_db_city" VALUES(13151,'Lemoyne','Lemoyne, Ohio',16502,35);
INSERT INTO "django_geo_db_city" VALUES(13152,'Lindsey','Lindsey, Ohio',16503,35);
INSERT INTO "django_geo_db_city" VALUES(13153,'Luckey','Luckey, Ohio',16504,35);
INSERT INTO "django_geo_db_city" VALUES(13154,'Martin','Martin, Ohio',16505,35);
INSERT INTO "django_geo_db_city" VALUES(13155,'Middle Bass','Middle Bass, Ohio',16506,35);
INSERT INTO "django_geo_db_city" VALUES(13156,'Millbury','Millbury, Ohio',16507,35);
INSERT INTO "django_geo_db_city" VALUES(13157,'Oak Harbor','Oak Harbor, Ohio',16508,35);
INSERT INTO "django_geo_db_city" VALUES(13158,'Pemberville','Pemberville, Ohio',16509,35);
INSERT INTO "django_geo_db_city" VALUES(13159,'Portage','Portage, Ohio',16510,35);
INSERT INTO "django_geo_db_city" VALUES(13160,'Port Clinton','Port Clinton, Ohio',16511,35);
INSERT INTO "django_geo_db_city" VALUES(13161,'Put In Bay','Put In Bay, Ohio',16512,35);
INSERT INTO "django_geo_db_city" VALUES(13162,'Risingsun','Risingsun, Ohio',16513,35);
INSERT INTO "django_geo_db_city" VALUES(13163,'Rocky Ridge','Rocky Ridge, Ohio',16514,35);
INSERT INTO "django_geo_db_city" VALUES(13164,'Rossford','Rossford, Ohio',16515,35);
INSERT INTO "django_geo_db_city" VALUES(13165,'Rudolph','Rudolph, Ohio',16516,35);
INSERT INTO "django_geo_db_city" VALUES(13166,'Stony Ridge','Stony Ridge, Ohio',16517,35);
INSERT INTO "django_geo_db_city" VALUES(13167,'Vickery','Vickery, Ohio',16518,35);
INSERT INTO "django_geo_db_city" VALUES(13168,'Walbridge','Walbridge, Ohio',16519,35);
INSERT INTO "django_geo_db_city" VALUES(13169,'Wayne','Wayne, Ohio',16520,35);
INSERT INTO "django_geo_db_city" VALUES(13170,'West Millgrove','West Millgrove, Ohio',16521,35);
INSERT INTO "django_geo_db_city" VALUES(13171,'Williston','Williston, Ohio',16522,35);
INSERT INTO "django_geo_db_city" VALUES(13172,'Woodville','Woodville, Ohio',16523,35);
INSERT INTO "django_geo_db_city" VALUES(13173,'Alvordton','Alvordton, Ohio',16524,35);
INSERT INTO "django_geo_db_city" VALUES(13174,'Archbold','Archbold, Ohio',16525,35);
INSERT INTO "django_geo_db_city" VALUES(13175,'Berkey','Berkey, Ohio',16526,35);
INSERT INTO "django_geo_db_city" VALUES(13176,'Blakeslee','Blakeslee, Ohio',16527,35);
INSERT INTO "django_geo_db_city" VALUES(13177,'Bryan','Bryan, Ohio',16528,35);
INSERT INTO "django_geo_db_city" VALUES(13178,'Colton','Colton, Ohio',16529,35);
INSERT INTO "django_geo_db_city" VALUES(13179,'Custar','Custar, Ohio',16530,35);
INSERT INTO "django_geo_db_city" VALUES(13180,'Defiance','Defiance, Ohio',16531,35);
INSERT INTO "django_geo_db_city" VALUES(13181,'Delta','Delta, Ohio',16532,35);
INSERT INTO "django_geo_db_city" VALUES(13182,'Deshler','Deshler, Ohio',16533,35);
INSERT INTO "django_geo_db_city" VALUES(13183,'Edgerton','Edgerton, Ohio',16534,35);
INSERT INTO "django_geo_db_city" VALUES(13184,'Edon','Edon, Ohio',16535,35);
INSERT INTO "django_geo_db_city" VALUES(13185,'Evansport','Evansport, Ohio',16536,35);
INSERT INTO "django_geo_db_city" VALUES(13186,'Farmer','Farmer, Ohio',16537,35);
INSERT INTO "django_geo_db_city" VALUES(13187,'Fayette','Fayette, Ohio',16538,35);
INSERT INTO "django_geo_db_city" VALUES(13188,'Grand Rapids','Grand Rapids, Ohio',16539,35);
INSERT INTO "django_geo_db_city" VALUES(13189,'Grelton','Grelton, Ohio',16540,35);
INSERT INTO "django_geo_db_city" VALUES(13190,'Hamler','Hamler, Ohio',16541,35);
INSERT INTO "django_geo_db_city" VALUES(13191,'Haskins','Haskins, Ohio',16542,35);
INSERT INTO "django_geo_db_city" VALUES(13192,'Hicksville','Hicksville, Ohio',16543,35);
INSERT INTO "django_geo_db_city" VALUES(13193,'Holgate','Holgate, Ohio',16544,35);
INSERT INTO "django_geo_db_city" VALUES(13194,'Holland','Holland, Ohio',16545,35);
INSERT INTO "django_geo_db_city" VALUES(13195,'Hoytville','Hoytville, Ohio',16546,35);
INSERT INTO "django_geo_db_city" VALUES(13196,'Jewell','Jewell, Ohio',16547,35);
INSERT INTO "django_geo_db_city" VALUES(13197,'Kunkle','Kunkle, Ohio',16548,35);
INSERT INTO "django_geo_db_city" VALUES(13198,'Liberty Center','Liberty Center, Ohio',16549,35);
INSERT INTO "django_geo_db_city" VALUES(13199,'Lyons','Lyons, Ohio',16550,35);
INSERT INTO "django_geo_db_city" VALUES(13200,'McClure','McClure, Ohio',16551,35);
INSERT INTO "django_geo_db_city" VALUES(13201,'Malinta','Malinta, Ohio',16552,35);
INSERT INTO "django_geo_db_city" VALUES(13202,'Mark Center','Mark Center, Ohio',16553,35);
INSERT INTO "django_geo_db_city" VALUES(13203,'Maumee','Maumee, Ohio',16554,35);
INSERT INTO "django_geo_db_city" VALUES(13204,'Monclova','Monclova, Ohio',16555,35);
INSERT INTO "django_geo_db_city" VALUES(13205,'Metamora','Metamora, Ohio',16556,35);
INSERT INTO "django_geo_db_city" VALUES(13206,'Milton Center','Milton Center, Ohio',16557,35);
INSERT INTO "django_geo_db_city" VALUES(13207,'Montpelier','Montpelier, Ohio',16559,35);
INSERT INTO "django_geo_db_city" VALUES(13208,'Napoleon','Napoleon, Ohio',16560,35);
INSERT INTO "django_geo_db_city" VALUES(13209,'Neapolis','Neapolis, Ohio',16561,35);
INSERT INTO "django_geo_db_city" VALUES(13210,'New Bavaria','New Bavaria, Ohio',16562,35);
INSERT INTO "django_geo_db_city" VALUES(13211,'Ney','Ney, Ohio',16563,35);
INSERT INTO "django_geo_db_city" VALUES(13212,'Okolona','Okolona, Ohio',16564,35);
INSERT INTO "django_geo_db_city" VALUES(13213,'Perrysburg','Perrysburg, Ohio',16565,35);
INSERT INTO "django_geo_db_city" VALUES(13214,'Pettisville','Pettisville, Ohio',16566,35);
INSERT INTO "django_geo_db_city" VALUES(13215,'Pioneer','Pioneer, Ohio',16567,35);
INSERT INTO "django_geo_db_city" VALUES(13216,'Ridgeville Corners','Ridgeville Corners, Ohio',16568,35);
INSERT INTO "django_geo_db_city" VALUES(13217,'Sherwood','Sherwood, Ohio',16569,35);
INSERT INTO "django_geo_db_city" VALUES(13218,'Stryker','Stryker, Ohio',16570,35);
INSERT INTO "django_geo_db_city" VALUES(13219,'Swanton','Swanton, Ohio',16571,35);
INSERT INTO "django_geo_db_city" VALUES(13220,'Sylvania','Sylvania, Ohio',16572,35);
INSERT INTO "django_geo_db_city" VALUES(13221,'Tontogany','Tontogany, Ohio',16573,35);
INSERT INTO "django_geo_db_city" VALUES(13222,'Waterville','Waterville, Ohio',16574,35);
INSERT INTO "django_geo_db_city" VALUES(13223,'Wauseon','Wauseon, Ohio',16575,35);
INSERT INTO "django_geo_db_city" VALUES(13224,'Weston','Weston, Ohio',16576,35);
INSERT INTO "django_geo_db_city" VALUES(13225,'West Unity','West Unity, Ohio',16577,35);
INSERT INTO "django_geo_db_city" VALUES(13226,'Whitehouse','Whitehouse, Ohio',16578,35);
INSERT INTO "django_geo_db_city" VALUES(13227,'Tiffin','Tiffin, Ohio',16579,35);
INSERT INTO "django_geo_db_city" VALUES(13228,'Toledo','Toledo, Ohio',16580,35);
INSERT INTO "django_geo_db_city" VALUES(13229,'Oregon','Oregon, Ohio',16595,35);
INSERT INTO "django_geo_db_city" VALUES(13230,'Northwood','Northwood, Ohio',16598,35);
INSERT INTO "django_geo_db_city" VALUES(13231,'Zanesville','Zanesville, Ohio',16606,35);
INSERT INTO "django_geo_db_city" VALUES(13232,'Ava','Ava, Ohio',16610,35);
INSERT INTO "django_geo_db_city" VALUES(13233,'Barnesville','Barnesville, Ohio',16611,35);
INSERT INTO "django_geo_db_city" VALUES(13234,'Beallsville','Beallsville, Ohio',16612,35);
INSERT INTO "django_geo_db_city" VALUES(13235,'Belle Valley','Belle Valley, Ohio',16613,35);
INSERT INTO "django_geo_db_city" VALUES(13236,'Belmont','Belmont, Ohio',16614,35);
INSERT INTO "django_geo_db_city" VALUES(13237,'Bethesda','Bethesda, Ohio',16615,35);
INSERT INTO "django_geo_db_city" VALUES(13238,'Blue Rock','Blue Rock, Ohio',16616,35);
INSERT INTO "django_geo_db_city" VALUES(13239,'Brownsville','Brownsville, Ohio',16617,35);
INSERT INTO "django_geo_db_city" VALUES(13240,'Buffalo','Buffalo, Ohio',16618,35);
INSERT INTO "django_geo_db_city" VALUES(13241,'Byesville','Byesville, Ohio',16619,35);
INSERT INTO "django_geo_db_city" VALUES(13242,'Caldwell','Caldwell, Ohio',16620,35);
INSERT INTO "django_geo_db_city" VALUES(13243,'Cambridge','Cambridge, Ohio',16621,35);
INSERT INTO "django_geo_db_city" VALUES(13244,'Chandlersville','Chandlersville, Ohio',16622,35);
INSERT INTO "django_geo_db_city" VALUES(13245,'Chesterhill','Chesterhill, Ohio',16623,35);
INSERT INTO "django_geo_db_city" VALUES(13246,'Corning','Corning, Ohio',16624,35);
INSERT INTO "django_geo_db_city" VALUES(13247,'Crooksville','Crooksville, Ohio',16625,35);
INSERT INTO "django_geo_db_city" VALUES(13248,'Cumberland','Cumberland, Ohio',16626,35);
INSERT INTO "django_geo_db_city" VALUES(13249,'Derwent','Derwent, Ohio',16627,35);
INSERT INTO "django_geo_db_city" VALUES(13250,'Duncan Falls','Duncan Falls, Ohio',16628,35);
INSERT INTO "django_geo_db_city" VALUES(13251,'East Fultonham','East Fultonham, Ohio',16629,35);
INSERT INTO "django_geo_db_city" VALUES(13252,'Fairview','Fairview, Ohio',16630,35);
INSERT INTO "django_geo_db_city" VALUES(13253,'Fultonham','Fultonham, Ohio',16631,35);
INSERT INTO "django_geo_db_city" VALUES(13254,'Glenford','Glenford, Ohio',16632,35);
INSERT INTO "django_geo_db_city" VALUES(13255,'Gratiot','Gratiot, Ohio',16633,35);
INSERT INTO "django_geo_db_city" VALUES(13256,'Hopewell','Hopewell, Ohio',16635,35);
INSERT INTO "django_geo_db_city" VALUES(13257,'Jerusalem','Jerusalem, Ohio',16636,35);
INSERT INTO "django_geo_db_city" VALUES(13258,'Junction City','Junction City, Ohio',16637,35);
INSERT INTO "django_geo_db_city" VALUES(13259,'Kimbolton','Kimbolton, Ohio',16638,35);
INSERT INTO "django_geo_db_city" VALUES(13260,'Kipling','Kipling, Ohio',16639,35);
INSERT INTO "django_geo_db_city" VALUES(13261,'Laings','Laings, Ohio',16640,35);
INSERT INTO "django_geo_db_city" VALUES(13262,'Lewisville','Lewisville, Ohio',16641,35);
INSERT INTO "django_geo_db_city" VALUES(13263,'Lore City','Lore City, Ohio',16642,35);
INSERT INTO "django_geo_db_city" VALUES(13264,'McConnelsville','McConnelsville, Ohio',16643,35);
INSERT INTO "django_geo_db_city" VALUES(13265,'Malaga','Malaga, Ohio',16644,35);
INSERT INTO "django_geo_db_city" VALUES(13266,'Malta','Malta, Ohio',16645,35);
INSERT INTO "django_geo_db_city" VALUES(13267,'Morristown','Morristown, Ohio',16646,35);
INSERT INTO "django_geo_db_city" VALUES(13268,'Mount Perry','Mount Perry, Ohio',16647,35);
INSERT INTO "django_geo_db_city" VALUES(13269,'Moxahala','Moxahala, Ohio',16648,35);
INSERT INTO "django_geo_db_city" VALUES(13270,'New Concord','New Concord, Ohio',16649,35);
INSERT INTO "django_geo_db_city" VALUES(13271,'New Lexington','New Lexington, Ohio',16650,35);
INSERT INTO "django_geo_db_city" VALUES(13272,'New Straitsville','New Straitsville, Ohio',16651,35);
INSERT INTO "django_geo_db_city" VALUES(13273,'Norwich','Norwich, Ohio',16652,35);
INSERT INTO "django_geo_db_city" VALUES(13274,'Old Washington','Old Washington, Ohio',16653,35);
INSERT INTO "django_geo_db_city" VALUES(13275,'Philo','Philo, Ohio',16654,35);
INSERT INTO "django_geo_db_city" VALUES(13276,'Pleasant City','Pleasant City, Ohio',16655,35);
INSERT INTO "django_geo_db_city" VALUES(13277,'Quaker City','Quaker City, Ohio',16656,35);
INSERT INTO "django_geo_db_city" VALUES(13278,'Roseville','Roseville, Ohio',16657,35);
INSERT INTO "django_geo_db_city" VALUES(13279,'Salesville','Salesville, Ohio',16658,35);
INSERT INTO "django_geo_db_city" VALUES(13280,'Sarahsville','Sarahsville, Ohio',16659,35);
INSERT INTO "django_geo_db_city" VALUES(13281,'Senecaville','Senecaville, Ohio',16660,35);
INSERT INTO "django_geo_db_city" VALUES(13282,'Shawnee','Shawnee, Ohio',16661,35);
INSERT INTO "django_geo_db_city" VALUES(13283,'Somerset','Somerset, Ohio',16662,35);
INSERT INTO "django_geo_db_city" VALUES(13284,'Stafford','Stafford, Ohio',16663,35);
INSERT INTO "django_geo_db_city" VALUES(13285,'Stockport','Stockport, Ohio',16664,35);
INSERT INTO "django_geo_db_city" VALUES(13286,'Summerfield','Summerfield, Ohio',16665,35);
INSERT INTO "django_geo_db_city" VALUES(13287,'Sycamore Valley','Sycamore Valley, Ohio',16666,35);
INSERT INTO "django_geo_db_city" VALUES(13288,'White Cottage','White Cottage, Ohio',16667,35);
INSERT INTO "django_geo_db_city" VALUES(13289,'Woodsfield','Woodsfield, Ohio',16668,35);
INSERT INTO "django_geo_db_city" VALUES(13290,'Center','Center, Ohio',16669,35);
INSERT INTO "django_geo_db_city" VALUES(13291,'Adamsville','Adamsville, Ohio',16670,35);
INSERT INTO "django_geo_db_city" VALUES(13292,'Bakersville','Bakersville, Ohio',16671,35);
INSERT INTO "django_geo_db_city" VALUES(13293,'Baltic','Baltic, Ohio',16672,35);
INSERT INTO "django_geo_db_city" VALUES(13294,'Blissfield','Blissfield, Ohio',16673,35);
INSERT INTO "django_geo_db_city" VALUES(13295,'Conesville','Conesville, Ohio',16674,35);
INSERT INTO "django_geo_db_city" VALUES(13296,'Coshocton','Coshocton, Ohio',16675,35);
INSERT INTO "django_geo_db_city" VALUES(13297,'Dresden','Dresden, Ohio',16676,35);
INSERT INTO "django_geo_db_city" VALUES(13298,'Frazeysburg','Frazeysburg, Ohio',16677,35);
INSERT INTO "django_geo_db_city" VALUES(13299,'Fresno','Fresno, Ohio',16678,35);
INSERT INTO "django_geo_db_city" VALUES(13300,'Keene','Keene, Ohio',16679,35);
INSERT INTO "django_geo_db_city" VALUES(13301,'Nashport','Nashport, Ohio',16680,35);
INSERT INTO "django_geo_db_city" VALUES(13302,'Newcomerstown','Newcomerstown, Ohio',16681,35);
INSERT INTO "django_geo_db_city" VALUES(13303,'Plainfield','Plainfield, Ohio',16682,35);
INSERT INTO "django_geo_db_city" VALUES(13304,'Port Washington','Port Washington, Ohio',16683,35);
INSERT INTO "django_geo_db_city" VALUES(13305,'Stone Creek','Stone Creek, Ohio',16684,35);
INSERT INTO "django_geo_db_city" VALUES(13306,'Trinway','Trinway, Ohio',16685,35);
INSERT INTO "django_geo_db_city" VALUES(13307,'Walhonding','Walhonding, Ohio',16686,35);
INSERT INTO "django_geo_db_city" VALUES(13308,'Warsaw','Warsaw, Ohio',16687,35);
INSERT INTO "django_geo_db_city" VALUES(13309,'West Lafayette','West Lafayette, Ohio',16688,35);
INSERT INTO "django_geo_db_city" VALUES(13310,'Adena','Adena, Ohio',16689,35);
INSERT INTO "django_geo_db_city" VALUES(13311,'Alledonia','Alledonia, Ohio',16690,35);
INSERT INTO "django_geo_db_city" VALUES(13312,'Amsterdam','Amsterdam, Ohio',16691,35);
INSERT INTO "django_geo_db_city" VALUES(13313,'Barton','Barton, Ohio',16692,35);
INSERT INTO "django_geo_db_city" VALUES(13314,'Bellaire','Bellaire, Ohio',16693,35);
INSERT INTO "django_geo_db_city" VALUES(13315,'Cadiz','Cadiz, Ohio',16694,35);
INSERT INTO "django_geo_db_city" VALUES(13316,'Bergholz','Bergholz, Ohio',16695,35);
INSERT INTO "django_geo_db_city" VALUES(13317,'Blaine','Blaine, Ohio',16696,35);
INSERT INTO "django_geo_db_city" VALUES(13318,'Bloomingdale','Bloomingdale, Ohio',16697,35);
INSERT INTO "django_geo_db_city" VALUES(13319,'Bridgeport','Bridgeport, Ohio',16698,35);
INSERT INTO "django_geo_db_city" VALUES(13320,'Brilliant','Brilliant, Ohio',16699,35);
INSERT INTO "django_geo_db_city" VALUES(13321,'Cameron','Cameron, Ohio',16700,35);
INSERT INTO "django_geo_db_city" VALUES(13322,'Clarington','Clarington, Ohio',16701,35);
INSERT INTO "django_geo_db_city" VALUES(13323,'Colerain','Colerain, Ohio',16702,35);
INSERT INTO "django_geo_db_city" VALUES(13324,'Dillonvale','Dillonvale, Ohio',16703,35);
INSERT INTO "django_geo_db_city" VALUES(13325,'East Liverpool','East Liverpool, Ohio',16704,35);
INSERT INTO "django_geo_db_city" VALUES(13326,'Noble','Noble, Ohio',16705,35);
INSERT INTO "django_geo_db_city" VALUES(13327,'East Springfield','East Springfield, Ohio',16706,35);
INSERT INTO "django_geo_db_city" VALUES(13328,'Empire','Empire, Ohio',16707,35);
INSERT INTO "django_geo_db_city" VALUES(13329,'Fairpoint','Fairpoint, Ohio',16708,35);
INSERT INTO "django_geo_db_city" VALUES(13330,'Glencoe','Glencoe, Ohio',16709,35);
INSERT INTO "django_geo_db_city" VALUES(13331,'Hammondsville','Hammondsville, Ohio',16710,35);
INSERT INTO "django_geo_db_city" VALUES(13332,'Hannibal','Hannibal, Ohio',16711,35);
INSERT INTO "django_geo_db_city" VALUES(13333,'Irondale','Irondale, Ohio',16712,35);
INSERT INTO "django_geo_db_city" VALUES(13334,'Jacobsburg','Jacobsburg, Ohio',16713,35);
INSERT INTO "django_geo_db_city" VALUES(13335,'Lansing','Lansing, Ohio',16714,35);
INSERT INTO "django_geo_db_city" VALUES(13336,'Martins Ferry','Martins Ferry, Ohio',16715,35);
INSERT INTO "django_geo_db_city" VALUES(13337,'Maynard','Maynard, Ohio',16716,35);
INSERT INTO "django_geo_db_city" VALUES(13338,'Mingo Junction','Mingo Junction, Ohio',16717,35);
INSERT INTO "django_geo_db_city" VALUES(13339,'Mount Pleasant','Mount Pleasant, Ohio',16718,35);
INSERT INTO "django_geo_db_city" VALUES(13340,'Neffs','Neffs, Ohio',16719,35);
INSERT INTO "django_geo_db_city" VALUES(13341,'Piney Fork','Piney Fork, Ohio',16720,35);
INSERT INTO "django_geo_db_city" VALUES(13342,'Powhatan Point','Powhatan Point, Ohio',16721,35);
INSERT INTO "django_geo_db_city" VALUES(13343,'Rayland','Rayland, Ohio',16722,35);
INSERT INTO "django_geo_db_city" VALUES(13344,'Richmond','Richmond, Ohio',16723,35);
INSERT INTO "django_geo_db_city" VALUES(13345,'Salineville','Salineville, Ohio',16724,35);
INSERT INTO "django_geo_db_city" VALUES(13346,'Sardis','Sardis, Ohio',16725,35);
INSERT INTO "django_geo_db_city" VALUES(13347,'Shadyside','Shadyside, Ohio',16726,35);
INSERT INTO "django_geo_db_city" VALUES(13348,'Smithfield','Smithfield, Ohio',16727,35);
INSERT INTO "django_geo_db_city" VALUES(13349,'Saint Clairsville','Saint Clairsville, Ohio',16728,35);
INSERT INTO "django_geo_db_city" VALUES(13350,'Lafferty','Lafferty, Ohio',16729,35);
INSERT INTO "django_geo_db_city" VALUES(13351,'Steubenville','Steubenville, Ohio',16730,35);
INSERT INTO "django_geo_db_city" VALUES(13352,'Richland','Richland, Ohio',16732,35);
INSERT INTO "django_geo_db_city" VALUES(13353,'Stratton','Stratton, Ohio',16733,35);
INSERT INTO "django_geo_db_city" VALUES(13354,'Summitville','Summitville, Ohio',16734,35);
INSERT INTO "django_geo_db_city" VALUES(13355,'Tiltonsville','Tiltonsville, Ohio',16735,35);
INSERT INTO "django_geo_db_city" VALUES(13356,'Toronto','Toronto, Ohio',16736,35);
INSERT INTO "django_geo_db_city" VALUES(13357,'Unionport','Unionport, Ohio',16737,35);
INSERT INTO "django_geo_db_city" VALUES(13358,'Warnock','Warnock, Ohio',16738,35);
INSERT INTO "django_geo_db_city" VALUES(13359,'Wellsville','Wellsville, Ohio',16739,35);
INSERT INTO "django_geo_db_city" VALUES(13360,'Wolf Run','Wolf Run, Ohio',16740,35);
INSERT INTO "django_geo_db_city" VALUES(13361,'Yorkville','Yorkville, Ohio',16741,35);
INSERT INTO "django_geo_db_city" VALUES(13362,'Bannock','Bannock, Ohio',16742,35);
INSERT INTO "django_geo_db_city" VALUES(13363,'Freeport','Freeport, Ohio',16743,35);
INSERT INTO "django_geo_db_city" VALUES(13364,'Harrisville','Harrisville, Ohio',16744,35);
INSERT INTO "django_geo_db_city" VALUES(13365,'Hopedale','Hopedale, Ohio',16745,35);
INSERT INTO "django_geo_db_city" VALUES(13366,'Flushing','Flushing, Ohio',16746,35);
INSERT INTO "django_geo_db_city" VALUES(13367,'New Athens','New Athens, Ohio',16747,35);
INSERT INTO "django_geo_db_city" VALUES(13368,'Piedmont','Piedmont, Ohio',16748,35);
INSERT INTO "django_geo_db_city" VALUES(13369,'New Rumley','New Rumley, Ohio',16749,35);
INSERT INTO "django_geo_db_city" VALUES(13370,'Holloway','Holloway, Ohio',16646,35);
INSERT INTO "django_geo_db_city" VALUES(13371,'Jewett','Jewett, Ohio',16750,35);
INSERT INTO "django_geo_db_city" VALUES(13372,'Scio','Scio, Ohio',16751,35);
INSERT INTO "django_geo_db_city" VALUES(13373,'Short Creek','Short Creek, Ohio',16749,35);
INSERT INTO "django_geo_db_city" VALUES(13374,'Amherst','Amherst, Ohio',16752,35);
INSERT INTO "django_geo_db_city" VALUES(13375,'Andover','Andover, Ohio',16753,35);
INSERT INTO "django_geo_db_city" VALUES(13376,'Ashtabula','Ashtabula, Ohio',16754,35);
INSERT INTO "django_geo_db_city" VALUES(13377,'Austinburg','Austinburg, Ohio',16756,35);
INSERT INTO "django_geo_db_city" VALUES(13378,'Avon','Avon, Ohio',16757,35);
INSERT INTO "django_geo_db_city" VALUES(13379,'Avon Lake','Avon Lake, Ohio',16758,35);
INSERT INTO "django_geo_db_city" VALUES(13380,'Berea','Berea, Ohio',16759,35);
INSERT INTO "django_geo_db_city" VALUES(13381,'Burton','Burton, Ohio',16760,35);
INSERT INTO "django_geo_db_city" VALUES(13382,'Chagrin Falls','Chagrin Falls, Ohio',16761,35);
INSERT INTO "django_geo_db_city" VALUES(13383,'Chardon','Chardon, Ohio',16763,35);
INSERT INTO "django_geo_db_city" VALUES(13384,'Chesterland','Chesterland, Ohio',16764,35);
INSERT INTO "django_geo_db_city" VALUES(13385,'Columbia Station','Columbia Station, Ohio',16765,35);
INSERT INTO "django_geo_db_city" VALUES(13386,'Conneaut','Conneaut, Ohio',16766,35);
INSERT INTO "django_geo_db_city" VALUES(13387,'Dorset','Dorset, Ohio',16767,35);
INSERT INTO "django_geo_db_city" VALUES(13388,'East Claridon','East Claridon, Ohio',16768,35);
INSERT INTO "django_geo_db_city" VALUES(13389,'Elyria','Elyria, Ohio',16769,35);
INSERT INTO "django_geo_db_city" VALUES(13390,'North Ridgeville','North Ridgeville, Ohio',16771,35);
INSERT INTO "django_geo_db_city" VALUES(13391,'Gates Mills','Gates Mills, Ohio',16772,35);
INSERT INTO "django_geo_db_city" VALUES(13392,'Geneva','Geneva, Ohio',16773,35);
INSERT INTO "django_geo_db_city" VALUES(13393,'Grafton','Grafton, Ohio',16774,35);
INSERT INTO "django_geo_db_city" VALUES(13394,'Grand River','Grand River, Ohio',16775,35);
INSERT INTO "django_geo_db_city" VALUES(13395,'Huntsburg','Huntsburg, Ohio',16776,35);
INSERT INTO "django_geo_db_city" VALUES(13396,'Jefferson','Jefferson, Ohio',16777,35);
INSERT INTO "django_geo_db_city" VALUES(13397,'Kingsville','Kingsville, Ohio',16778,35);
INSERT INTO "django_geo_db_city" VALUES(13398,'Kipton','Kipton, Ohio',16779,35);
INSERT INTO "django_geo_db_city" VALUES(13399,'Lagrange','Lagrange, Ohio',16780,35);
INSERT INTO "django_geo_db_city" VALUES(13400,'Lorain','Lorain, Ohio',16781,35);
INSERT INTO "django_geo_db_city" VALUES(13401,'Sheffield Lake','Sheffield Lake, Ohio',16783,35);
INSERT INTO "django_geo_db_city" VALUES(13402,'Macedonia','Macedonia, Ohio',16785,35);
INSERT INTO "django_geo_db_city" VALUES(13403,'Madison','Madison, Ohio',16786,35);
INSERT INTO "django_geo_db_city" VALUES(13404,'Mentor','Mentor, Ohio',16787,35);
INSERT INTO "django_geo_db_city" VALUES(13405,'Middlefield','Middlefield, Ohio',16789,35);
INSERT INTO "django_geo_db_city" VALUES(13406,'Montville','Montville, Ohio',16790,35);
INSERT INTO "django_geo_db_city" VALUES(13407,'Newbury','Newbury, Ohio',16791,35);
INSERT INTO "django_geo_db_city" VALUES(13408,'Northfield','Northfield, Ohio',16792,35);
INSERT INTO "django_geo_db_city" VALUES(13409,'North Kingsville','North Kingsville, Ohio',16793,35);
INSERT INTO "django_geo_db_city" VALUES(13410,'North Olmsted','North Olmsted, Ohio',16794,35);
INSERT INTO "django_geo_db_city" VALUES(13411,'Novelty','Novelty, Ohio',16795,35);
INSERT INTO "django_geo_db_city" VALUES(13412,'Oberlin','Oberlin, Ohio',16797,35);
INSERT INTO "django_geo_db_city" VALUES(13413,'Orwell','Orwell, Ohio',16798,35);
INSERT INTO "django_geo_db_city" VALUES(13414,'Painesville','Painesville, Ohio',16799,35);
INSERT INTO "django_geo_db_city" VALUES(13415,'Parkman','Parkman, Ohio',16800,35);
INSERT INTO "django_geo_db_city" VALUES(13416,'Perry','Perry, Ohio',16801,35);
INSERT INTO "django_geo_db_city" VALUES(13417,'Pierpont','Pierpont, Ohio',16802,35);
INSERT INTO "django_geo_db_city" VALUES(13418,'Rock Creek','Rock Creek, Ohio',16803,35);
INSERT INTO "django_geo_db_city" VALUES(13419,'Rome','Rome, Ohio',16804,35);
INSERT INTO "django_geo_db_city" VALUES(13420,'Thompson','Thompson, Ohio',16805,35);
INSERT INTO "django_geo_db_city" VALUES(13421,'Twinsburg','Twinsburg, Ohio',16806,35);
INSERT INTO "django_geo_db_city" VALUES(13422,'Unionville','Unionville, Ohio',16807,35);
INSERT INTO "django_geo_db_city" VALUES(13423,'Vermilion','Vermilion, Ohio',16808,35);
INSERT INTO "django_geo_db_city" VALUES(13424,'Wellington','Wellington, Ohio',16809,35);
INSERT INTO "django_geo_db_city" VALUES(13425,'Wickliffe','Wickliffe, Ohio',16810,35);
INSERT INTO "django_geo_db_city" VALUES(13426,'Williamsfield','Williamsfield, Ohio',16811,35);
INSERT INTO "django_geo_db_city" VALUES(13427,'Willoughby','Willoughby, Ohio',16812,35);
INSERT INTO "django_geo_db_city" VALUES(13428,'Eastlake','Eastlake, Ohio',16813,35);
INSERT INTO "django_geo_db_city" VALUES(13429,'Windsor','Windsor, Ohio',16814,35);
INSERT INTO "django_geo_db_city" VALUES(13430,'Cleveland','Cleveland, Ohio',16815,35);
INSERT INTO "django_geo_db_city" VALUES(13431,'Lakewood','Lakewood, Ohio',16821,35);
INSERT INTO "django_geo_db_city" VALUES(13432,'Rocky River','Rocky River, Ohio',16830,35);
INSERT INTO "django_geo_db_city" VALUES(13433,'Euclid','Euclid, Ohio',16831,35);
INSERT INTO "django_geo_db_city" VALUES(13434,'Beachwood','Beachwood, Ohio',16836,35);
INSERT INTO "django_geo_db_city" VALUES(13435,'Independence','Independence, Ohio',16845,35);
INSERT INTO "django_geo_db_city" VALUES(13436,'North Royalton','North Royalton, Ohio',16847,35);
INSERT INTO "django_geo_db_city" VALUES(13437,'Strongsville','Strongsville, Ohio',16850,35);
INSERT INTO "django_geo_db_city" VALUES(13438,'Maple Heights','Maple Heights, Ohio',16851,35);
INSERT INTO "django_geo_db_city" VALUES(13439,'Olmsted Falls','Olmsted Falls, Ohio',16852,35);
INSERT INTO "django_geo_db_city" VALUES(13440,'Solon','Solon, Ohio',16853,35);
INSERT INTO "django_geo_db_city" VALUES(13441,'Bay Village','Bay Village, Ohio',16854,35);
INSERT INTO "django_geo_db_city" VALUES(13442,'Brecksville','Brecksville, Ohio',16855,35);
INSERT INTO "django_geo_db_city" VALUES(13443,'Brookpark','Brookpark, Ohio',16856,35);
INSERT INTO "django_geo_db_city" VALUES(13444,'Westlake','Westlake, Ohio',16859,35);
INSERT INTO "django_geo_db_city" VALUES(13445,'Bedford','Bedford, Ohio',16860,35);
INSERT INTO "django_geo_db_city" VALUES(13446,'Broadview Heights','Broadview Heights, Ohio',16861,35);
INSERT INTO "django_geo_db_city" VALUES(13447,'Brunswick','Brunswick, Ohio',16862,35);
INSERT INTO "django_geo_db_city" VALUES(13448,'Dalton','Dalton, Ohio',16863,35);
INSERT INTO "django_geo_db_city" VALUES(13449,'Atwater','Atwater, Ohio',16865,35);
INSERT INTO "django_geo_db_city" VALUES(13450,'Aurora','Aurora, Ohio',16866,35);
INSERT INTO "django_geo_db_city" VALUES(13451,'Barberton','Barberton, Ohio',16867,35);
INSERT INTO "django_geo_db_city" VALUES(13452,'Bath','Bath, Ohio',16868,35);
INSERT INTO "django_geo_db_city" VALUES(13453,'Brady Lake','Brady Lake, Ohio',16869,35);
INSERT INTO "django_geo_db_city" VALUES(13454,'Burbank','Burbank, Ohio',16871,35);
INSERT INTO "django_geo_db_city" VALUES(13455,'Chippewa Lake','Chippewa Lake, Ohio',16872,35);
INSERT INTO "django_geo_db_city" VALUES(13456,'Clinton','Clinton, Ohio',16873,35);
INSERT INTO "django_geo_db_city" VALUES(13457,'Creston','Creston, Ohio',16874,35);
INSERT INTO "django_geo_db_city" VALUES(13458,'Cuyahoga Falls','Cuyahoga Falls, Ohio',16875,35);
INSERT INTO "django_geo_db_city" VALUES(13459,'Stow','Stow, Ohio',16877,35);
INSERT INTO "django_geo_db_city" VALUES(13460,'Doylestown','Doylestown, Ohio',16878,35);
INSERT INTO "django_geo_db_city" VALUES(13461,'Garrettsville','Garrettsville, Ohio',16879,35);
INSERT INTO "django_geo_db_city" VALUES(13462,'Green','Green, Ohio',16880,35);
INSERT INTO "django_geo_db_city" VALUES(13463,'Hinckley','Hinckley, Ohio',16881,35);
INSERT INTO "django_geo_db_city" VALUES(13464,'Hiram','Hiram, Ohio',16882,35);
INSERT INTO "django_geo_db_city" VALUES(13465,'Homerville','Homerville, Ohio',16883,35);
INSERT INTO "django_geo_db_city" VALUES(13466,'Hudson','Hudson, Ohio',16884,35);
INSERT INTO "django_geo_db_city" VALUES(13467,'Kent','Kent, Ohio',16885,35);
INSERT INTO "django_geo_db_city" VALUES(13468,'Streetsboro','Streetsboro, Ohio',16886,35);
INSERT INTO "django_geo_db_city" VALUES(13469,'Lakemore','Lakemore, Ohio',16889,35);
INSERT INTO "django_geo_db_city" VALUES(13470,'Westfield Center','Westfield Center, Ohio',16890,35);
INSERT INTO "django_geo_db_city" VALUES(13471,'Litchfield','Litchfield, Ohio',16891,35);
INSERT INTO "django_geo_db_city" VALUES(13472,'Lodi','Lodi, Ohio',16892,35);
INSERT INTO "django_geo_db_city" VALUES(13473,'Mantua','Mantua, Ohio',16893,35);
INSERT INTO "django_geo_db_city" VALUES(13474,'Medina','Medina, Ohio',16894,35);
INSERT INTO "django_geo_db_city" VALUES(13475,'Mogadore','Mogadore, Ohio',16896,35);
INSERT INTO "django_geo_db_city" VALUES(13476,'Munroe Falls','Munroe Falls, Ohio',16897,35);
INSERT INTO "django_geo_db_city" VALUES(13477,'Peninsula','Peninsula, Ohio',16898,35);
INSERT INTO "django_geo_db_city" VALUES(13478,'Randolph','Randolph, Ohio',16899,35);
INSERT INTO "django_geo_db_city" VALUES(13479,'Ravenna','Ravenna, Ohio',16900,35);
INSERT INTO "django_geo_db_city" VALUES(13480,'Rittman','Rittman, Ohio',16901,35);
INSERT INTO "django_geo_db_city" VALUES(13481,'Rootstown','Rootstown, Ohio',16902,35);
INSERT INTO "django_geo_db_city" VALUES(13482,'Seville','Seville, Ohio',16903,35);
INSERT INTO "django_geo_db_city" VALUES(13483,'Sharon Center','Sharon Center, Ohio',16904,35);
INSERT INTO "django_geo_db_city" VALUES(13484,'Spencer','Spencer, Ohio',16905,35);
INSERT INTO "django_geo_db_city" VALUES(13485,'Sterling','Sterling, Ohio',16906,35);
INSERT INTO "django_geo_db_city" VALUES(13486,'Tallmadge','Tallmadge, Ohio',16907,35);
INSERT INTO "django_geo_db_city" VALUES(13487,'Valley City','Valley City, Ohio',16908,35);
INSERT INTO "django_geo_db_city" VALUES(13488,'Wadsworth','Wadsworth, Ohio',16909,35);
INSERT INTO "django_geo_db_city" VALUES(13489,'Wayland','Wayland, Ohio',16911,35);
INSERT INTO "django_geo_db_city" VALUES(13490,'Richfield','Richfield, Ohio',16912,35);
INSERT INTO "django_geo_db_city" VALUES(13491,'West Salem','West Salem, Ohio',16913,35);
INSERT INTO "django_geo_db_city" VALUES(13492,'Windham','Windham, Ohio',16914,35);
INSERT INTO "django_geo_db_city" VALUES(13493,'Akron','Akron, Ohio',16915,35);
INSERT INTO "django_geo_db_city" VALUES(13494,'Paint','Paint, Ohio',16939,35);
INSERT INTO "django_geo_db_city" VALUES(13495,'Berlin Center','Berlin Center, Ohio',16942,35);
INSERT INTO "django_geo_db_city" VALUES(13496,'Bristolville','Bristolville, Ohio',16943,35);
INSERT INTO "django_geo_db_city" VALUES(13497,'Brookfield','Brookfield, Ohio',16944,35);
INSERT INTO "django_geo_db_city" VALUES(13498,'Burghill','Burghill, Ohio',16945,35);
INSERT INTO "django_geo_db_city" VALUES(13499,'Campbell','Campbell, Ohio',16946,35);
INSERT INTO "django_geo_db_city" VALUES(13500,'Canfield','Canfield, Ohio',16947,35);
INSERT INTO "django_geo_db_city" VALUES(13501,'Columbiana','Columbiana, Ohio',16948,35);
INSERT INTO "django_geo_db_city" VALUES(13502,'Cortland','Cortland, Ohio',16949,35);
INSERT INTO "django_geo_db_city" VALUES(13503,'Deerfield','Deerfield, Ohio',16950,35);
INSERT INTO "django_geo_db_city" VALUES(13504,'Diamond','Diamond, Ohio',16951,35);
INSERT INTO "django_geo_db_city" VALUES(13505,'East Palestine','East Palestine, Ohio',16952,35);
INSERT INTO "django_geo_db_city" VALUES(13506,'Elkton','Elkton, Ohio',16953,35);
INSERT INTO "django_geo_db_city" VALUES(13507,'Ellsworth','Ellsworth, Ohio',16954,35);
INSERT INTO "django_geo_db_city" VALUES(13508,'Farmdale','Farmdale, Ohio',16955,35);
INSERT INTO "django_geo_db_city" VALUES(13509,'Fowler','Fowler, Ohio',16956,35);
INSERT INTO "django_geo_db_city" VALUES(13510,'Girard','Girard, Ohio',16957,35);
INSERT INTO "django_geo_db_city" VALUES(13511,'Greenford','Greenford, Ohio',16954,35);
INSERT INTO "django_geo_db_city" VALUES(13512,'Hanoverton','Hanoverton, Ohio',16958,35);
INSERT INTO "django_geo_db_city" VALUES(13513,'Hartford','Hartford, Ohio',16959,35);
INSERT INTO "django_geo_db_city" VALUES(13514,'Hubbard','Hubbard, Ohio',16960,35);
INSERT INTO "django_geo_db_city" VALUES(13515,'Kensington','Kensington, Ohio',16961,35);
INSERT INTO "django_geo_db_city" VALUES(13516,'Kinsman','Kinsman, Ohio',16962,35);
INSERT INTO "django_geo_db_city" VALUES(13517,'Lake Milton','Lake Milton, Ohio',16963,35);
INSERT INTO "django_geo_db_city" VALUES(13518,'Leavittsburg','Leavittsburg, Ohio',16964,35);
INSERT INTO "django_geo_db_city" VALUES(13519,'Leetonia','Leetonia, Ohio',16965,35);
INSERT INTO "django_geo_db_city" VALUES(13520,'Lisbon','Lisbon, Ohio',16966,35);
INSERT INTO "django_geo_db_city" VALUES(13521,'Lowellville','Lowellville, Ohio',16967,35);
INSERT INTO "django_geo_db_city" VALUES(13522,'McDonald','McDonald, Ohio',16968,35);
INSERT INTO "django_geo_db_city" VALUES(13523,'Masury','Masury, Ohio',16969,35);
INSERT INTO "django_geo_db_city" VALUES(13524,'Mesopotamia','Mesopotamia, Ohio',16970,35);
INSERT INTO "django_geo_db_city" VALUES(13525,'Mineral Ridge','Mineral Ridge, Ohio',16971,35);
INSERT INTO "django_geo_db_city" VALUES(13526,'Negley','Negley, Ohio',16972,35);
INSERT INTO "django_geo_db_city" VALUES(13527,'New Middletown','New Middletown, Ohio',16973,35);
INSERT INTO "django_geo_db_city" VALUES(13528,'New Springfield','New Springfield, Ohio',16974,35);
INSERT INTO "django_geo_db_city" VALUES(13529,'Newton Falls','Newton Falls, Ohio',16975,35);
INSERT INTO "django_geo_db_city" VALUES(13530,'New Waterford','New Waterford, Ohio',16976,35);
INSERT INTO "django_geo_db_city" VALUES(13531,'Niles','Niles, Ohio',16977,35);
INSERT INTO "django_geo_db_city" VALUES(13532,'North Benton','North Benton, Ohio',16978,35);
INSERT INTO "django_geo_db_city" VALUES(13533,'North Bloomfield','North Bloomfield, Ohio',16979,35);
INSERT INTO "django_geo_db_city" VALUES(13534,'North Jackson','North Jackson, Ohio',16980,35);
INSERT INTO "django_geo_db_city" VALUES(13535,'North Lima','North Lima, Ohio',16981,35);
INSERT INTO "django_geo_db_city" VALUES(13536,'Orangeville','Orangeville, Ohio',16982,35);
INSERT INTO "django_geo_db_city" VALUES(13537,'Petersburg','Petersburg, Ohio',16983,35);
INSERT INTO "django_geo_db_city" VALUES(13538,'Rogers','Rogers, Ohio',16984,35);
INSERT INTO "django_geo_db_city" VALUES(13539,'Salem','Salem, Ohio',16985,35);
INSERT INTO "django_geo_db_city" VALUES(13540,'Southington','Southington, Ohio',16986,35);
INSERT INTO "django_geo_db_city" VALUES(13541,'Struthers','Struthers, Ohio',16987,35);
INSERT INTO "django_geo_db_city" VALUES(13542,'Vienna','Vienna, Ohio',16988,35);
INSERT INTO "django_geo_db_city" VALUES(13543,'Warren','Warren, Ohio',16989,35);
INSERT INTO "django_geo_db_city" VALUES(13544,'Washingtonville','Washingtonville, Ohio',16994,35);
INSERT INTO "django_geo_db_city" VALUES(13545,'West Farmington','West Farmington, Ohio',16995,35);
INSERT INTO "django_geo_db_city" VALUES(13546,'West Point','West Point, Ohio',16996,35);
INSERT INTO "django_geo_db_city" VALUES(13547,'Winona','Winona, Ohio',16997,35);
INSERT INTO "django_geo_db_city" VALUES(13548,'Youngstown','Youngstown, Ohio',16954,35);
INSERT INTO "django_geo_db_city" VALUES(13549,'Alliance','Alliance, Ohio',17011,35);
INSERT INTO "django_geo_db_city" VALUES(13550,'Apple Creek','Apple Creek, Ohio',17012,35);
INSERT INTO "django_geo_db_city" VALUES(13551,'Augusta','Augusta, Ohio',17013,35);
INSERT INTO "django_geo_db_city" VALUES(13552,'Beach City','Beach City, Ohio',17014,35);
INSERT INTO "django_geo_db_city" VALUES(13553,'Beloit','Beloit, Ohio',17015,35);
INSERT INTO "django_geo_db_city" VALUES(13554,'Berlin','Berlin, Ohio',17016,35);
INSERT INTO "django_geo_db_city" VALUES(13555,'Big Prairie','Big Prairie, Ohio',17017,35);
INSERT INTO "django_geo_db_city" VALUES(13556,'Bolivar','Bolivar, Ohio',17018,35);
INSERT INTO "django_geo_db_city" VALUES(13557,'Brewster','Brewster, Ohio',17019,35);
INSERT INTO "django_geo_db_city" VALUES(13558,'Canal Fulton','Canal Fulton, Ohio',17020,35);
INSERT INTO "django_geo_db_city" VALUES(13559,'Carrollton','Carrollton, Ohio',17021,35);
INSERT INTO "django_geo_db_city" VALUES(13560,'Charm','Charm, Ohio',17022,35);
INSERT INTO "django_geo_db_city" VALUES(13561,'Damascus','Damascus, Ohio',17024,35);
INSERT INTO "django_geo_db_city" VALUES(13562,'Dellroy','Dellroy, Ohio',17025,35);
INSERT INTO "django_geo_db_city" VALUES(13563,'Dennison','Dennison, Ohio',17026,35);
INSERT INTO "django_geo_db_city" VALUES(13564,'Dover','Dover, Ohio',17027,35);
INSERT INTO "django_geo_db_city" VALUES(13565,'Dundee','Dundee, Ohio',17028,35);
INSERT INTO "django_geo_db_city" VALUES(13566,'East Rochester','East Rochester, Ohio',17029,35);
INSERT INTO "django_geo_db_city" VALUES(13567,'East Sparta','East Sparta, Ohio',17030,35);
INSERT INTO "django_geo_db_city" VALUES(13568,'Fredericksburg','Fredericksburg, Ohio',17031,35);
INSERT INTO "django_geo_db_city" VALUES(13569,'Glenmont','Glenmont, Ohio',17032,35);
INSERT INTO "django_geo_db_city" VALUES(13570,'Gnadenhutten','Gnadenhutten, Ohio',17033,35);
INSERT INTO "django_geo_db_city" VALUES(13571,'Greentown','Greentown, Ohio',17034,35);
INSERT INTO "django_geo_db_city" VALUES(13572,'Harlem Springs','Harlem Springs, Ohio',17035,35);
INSERT INTO "django_geo_db_city" VALUES(13573,'Hartville','Hartville, Ohio',17036,35);
INSERT INTO "django_geo_db_city" VALUES(13574,'Holmesville','Holmesville, Ohio',17037,35);
INSERT INTO "django_geo_db_city" VALUES(13575,'Homeworth','Homeworth, Ohio',17038,35);
INSERT INTO "django_geo_db_city" VALUES(13576,'Kidron','Kidron, Ohio',17039,35);
INSERT INTO "django_geo_db_city" VALUES(13577,'Killbuck','Killbuck, Ohio',17040,35);
INSERT INTO "django_geo_db_city" VALUES(13578,'Lakeville','Lakeville, Ohio',17041,35);
INSERT INTO "django_geo_db_city" VALUES(13579,'Leesville','Leesville, Ohio',17042,35);
INSERT INTO "django_geo_db_city" VALUES(13580,'Limaville','Limaville, Ohio',17043,35);
INSERT INTO "django_geo_db_city" VALUES(13581,'Louisville','Louisville, Ohio',17044,35);
INSERT INTO "django_geo_db_city" VALUES(13582,'Magnolia','Magnolia, Ohio',17045,35);
INSERT INTO "django_geo_db_city" VALUES(13583,'Malvern','Malvern, Ohio',17046,35);
INSERT INTO "django_geo_db_city" VALUES(13584,'Marshallville','Marshallville, Ohio',17047,35);
INSERT INTO "django_geo_db_city" VALUES(13585,'Massillon','Massillon, Ohio',17048,35);
INSERT INTO "django_geo_db_city" VALUES(13586,'Maximo','Maximo, Ohio',17051,35);
INSERT INTO "django_geo_db_city" VALUES(13587,'Mechanicstown','Mechanicstown, Ohio',17052,35);
INSERT INTO "django_geo_db_city" VALUES(13588,'Middlebranch','Middlebranch, Ohio',17053,35);
INSERT INTO "django_geo_db_city" VALUES(13589,'Midvale','Midvale, Ohio',17054,35);
INSERT INTO "django_geo_db_city" VALUES(13590,'Millersburg','Millersburg, Ohio',17055,35);
INSERT INTO "django_geo_db_city" VALUES(13591,'Mineral City','Mineral City, Ohio',17056,35);
INSERT INTO "django_geo_db_city" VALUES(13592,'Minerva','Minerva, Ohio',17057,35);
INSERT INTO "django_geo_db_city" VALUES(13593,'Mount Eaton','Mount Eaton, Ohio',17058,35);
INSERT INTO "django_geo_db_city" VALUES(13594,'Mount Hope','Mount Hope, Ohio',17059,35);
INSERT INTO "django_geo_db_city" VALUES(13595,'Nashville','Nashville, Ohio',17060,35);
INSERT INTO "django_geo_db_city" VALUES(13596,'Navarre','Navarre, Ohio',17061,35);
INSERT INTO "django_geo_db_city" VALUES(13597,'New Philadelphia','New Philadelphia, Ohio',17062,35);
INSERT INTO "django_geo_db_city" VALUES(13598,'North Georgetown','North Georgetown, Ohio',17063,35);
INSERT INTO "django_geo_db_city" VALUES(13599,'North Lawrence','North Lawrence, Ohio',17064,35);
INSERT INTO "django_geo_db_city" VALUES(13600,'Orrville','Orrville, Ohio',17065,35);
INSERT INTO "django_geo_db_city" VALUES(13601,'Paris','Paris, Ohio',17066,35);
INSERT INTO "django_geo_db_city" VALUES(13602,'Robertsville','Robertsville, Ohio',17067,35);
INSERT INTO "django_geo_db_city" VALUES(13603,'Sandyville','Sandyville, Ohio',17068,35);
INSERT INTO "django_geo_db_city" VALUES(13604,'Sebring','Sebring, Ohio',17069,35);
INSERT INTO "django_geo_db_city" VALUES(13605,'Sherrodsville','Sherrodsville, Ohio',17070,35);
INSERT INTO "django_geo_db_city" VALUES(13606,'Shreve','Shreve, Ohio',17071,35);
INSERT INTO "django_geo_db_city" VALUES(13607,'Smithville','Smithville, Ohio',17072,35);
INSERT INTO "django_geo_db_city" VALUES(13608,'Somerdale','Somerdale, Ohio',17073,35);
INSERT INTO "django_geo_db_city" VALUES(13609,'Stillwater','Stillwater, Ohio',17074,35);
INSERT INTO "django_geo_db_city" VALUES(13610,'Strasburg','Strasburg, Ohio',17075,35);
INSERT INTO "django_geo_db_city" VALUES(13611,'Sugarcreek','Sugarcreek, Ohio',17076,35);
INSERT INTO "django_geo_db_city" VALUES(13612,'Tuscarawas','Tuscarawas, Ohio',17077,35);
INSERT INTO "django_geo_db_city" VALUES(13613,'Uhrichsville','Uhrichsville, Ohio',17078,35);
INSERT INTO "django_geo_db_city" VALUES(13614,'Walnut Creek','Walnut Creek, Ohio',17079,35);
INSERT INTO "django_geo_db_city" VALUES(13615,'Uniontown','Uniontown, Ohio',17080,35);
INSERT INTO "django_geo_db_city" VALUES(13616,'Waynesburg','Waynesburg, Ohio',17082,35);
INSERT INTO "django_geo_db_city" VALUES(13617,'Wilmot','Wilmot, Ohio',17083,35);
INSERT INTO "django_geo_db_city" VALUES(13618,'Winesburg','Winesburg, Ohio',17084,35);
INSERT INTO "django_geo_db_city" VALUES(13619,'Wooster','Wooster, Ohio',17085,35);
INSERT INTO "django_geo_db_city" VALUES(13620,'Deersville','Deersville, Ohio',17087,35);
INSERT INTO "django_geo_db_city" VALUES(13621,'Bowerston','Bowerston, Ohio',17088,35);
INSERT INTO "django_geo_db_city" VALUES(13622,'Zoar','Zoar, Ohio',17089,35);
INSERT INTO "django_geo_db_city" VALUES(13623,'Tippecanoe','Tippecanoe, Ohio',17090,35);
INSERT INTO "django_geo_db_city" VALUES(13624,'Canton','Canton, Ohio',17091,35);
INSERT INTO "django_geo_db_city" VALUES(13625,'Adrian','Adrian, Ohio',17109,35);
INSERT INTO "django_geo_db_city" VALUES(13626,'Alvada','Alvada, Ohio',17110,35);
INSERT INTO "django_geo_db_city" VALUES(13627,'Amsden','Amsden, Ohio',17111,35);
INSERT INTO "django_geo_db_city" VALUES(13628,'Arcadia','Arcadia, Ohio',17112,35);
INSERT INTO "django_geo_db_city" VALUES(13629,'Ashland','Ashland, Ohio',17113,35);
INSERT INTO "django_geo_db_city" VALUES(13630,'Attica','Attica, Ohio',17114,35);
INSERT INTO "django_geo_db_city" VALUES(13631,'Bascom','Bascom, Ohio',17115,35);
INSERT INTO "django_geo_db_city" VALUES(13632,'Bellevue','Bellevue, Ohio',17116,35);
INSERT INTO "django_geo_db_city" VALUES(13633,'Bellville','Bellville, Ohio',17117,35);
INSERT INTO "django_geo_db_city" VALUES(13634,'Berlin Heights','Berlin Heights, Ohio',17118,35);
INSERT INTO "django_geo_db_city" VALUES(13635,'Bettsville','Bettsville, Ohio',17119,35);
INSERT INTO "django_geo_db_city" VALUES(13636,'Birmingham','Birmingham, Ohio',17120,35);
INSERT INTO "django_geo_db_city" VALUES(13637,'Bloomdale','Bloomdale, Ohio',17121,35);
INSERT INTO "django_geo_db_city" VALUES(13638,'Bloomville','Bloomville, Ohio',17122,35);
INSERT INTO "django_geo_db_city" VALUES(13639,'Bucyrus','Bucyrus, Ohio',17123,35);
INSERT INTO "django_geo_db_city" VALUES(13640,'Butler','Butler, Ohio',17124,35);
INSERT INTO "django_geo_db_city" VALUES(13641,'Castalia','Castalia, Ohio',17125,35);
INSERT INTO "django_geo_db_city" VALUES(13642,'Chatfield','Chatfield, Ohio',17126,35);
INSERT INTO "django_geo_db_city" VALUES(13643,'Collins','Collins, Ohio',17127,35);
INSERT INTO "django_geo_db_city" VALUES(13644,'Crestline','Crestline, Ohio',17128,35);
INSERT INTO "django_geo_db_city" VALUES(13645,'Flat Rock','Flat Rock, Ohio',17129,35);
INSERT INTO "django_geo_db_city" VALUES(13646,'Fostoria','Fostoria, Ohio',17130,35);
INSERT INTO "django_geo_db_city" VALUES(13647,'Galion','Galion, Ohio',17131,35);
INSERT INTO "django_geo_db_city" VALUES(13648,'Green Springs','Green Springs, Ohio',17132,35);
INSERT INTO "django_geo_db_city" VALUES(13649,'Greenwich','Greenwich, Ohio',17133,35);
INSERT INTO "django_geo_db_city" VALUES(13650,'Hayesville','Hayesville, Ohio',17134,35);
INSERT INTO "django_geo_db_city" VALUES(13651,'Huron','Huron, Ohio',17135,35);
INSERT INTO "django_geo_db_city" VALUES(13652,'Jeromesville','Jeromesville, Ohio',17136,35);
INSERT INTO "django_geo_db_city" VALUES(13653,'Kansas','Kansas, Ohio',17137,35);
INSERT INTO "django_geo_db_city" VALUES(13654,'Loudonville','Loudonville, Ohio',17138,35);
INSERT INTO "django_geo_db_city" VALUES(13655,'Lucas','Lucas, Ohio',17139,35);
INSERT INTO "django_geo_db_city" VALUES(13656,'McCutchenville','McCutchenville, Ohio',17140,35);
INSERT INTO "django_geo_db_city" VALUES(13657,'Melmore','Melmore, Ohio',17141,35);
INSERT INTO "django_geo_db_city" VALUES(13658,'Milan','Milan, Ohio',17142,35);
INSERT INTO "django_geo_db_city" VALUES(13659,'Monroeville','Monroeville, Ohio',17143,35);
INSERT INTO "django_geo_db_city" VALUES(13660,'Nankin','Nankin, Ohio',17144,35);
INSERT INTO "django_geo_db_city" VALUES(13661,'Nevada','Nevada, Ohio',17145,35);
INSERT INTO "django_geo_db_city" VALUES(13662,'New Haven','New Haven, Ohio',17146,35);
INSERT INTO "django_geo_db_city" VALUES(13663,'New London','New London, Ohio',17147,35);
INSERT INTO "django_geo_db_city" VALUES(13664,'New Riegel','New Riegel, Ohio',17148,35);
INSERT INTO "django_geo_db_city" VALUES(13665,'New Washington','New Washington, Ohio',17149,35);
INSERT INTO "django_geo_db_city" VALUES(13666,'North Fairfield','North Fairfield, Ohio',17150,35);
INSERT INTO "django_geo_db_city" VALUES(13667,'North Robinson','North Robinson, Ohio',17151,35);
INSERT INTO "django_geo_db_city" VALUES(13668,'Norwalk','Norwalk, Ohio',17152,35);
INSERT INTO "django_geo_db_city" VALUES(13669,'Nova','Nova, Ohio',17154,35);
INSERT INTO "django_geo_db_city" VALUES(13670,'Oceola','Oceola, Ohio',17155,35);
INSERT INTO "django_geo_db_city" VALUES(13671,'Old Fort','Old Fort, Ohio',17156,35);
INSERT INTO "django_geo_db_city" VALUES(13672,'Ontario','Ontario, Ohio',17157,35);
INSERT INTO "django_geo_db_city" VALUES(13673,'Perrysville','Perrysville, Ohio',17158,35);
INSERT INTO "django_geo_db_city" VALUES(13674,'Plymouth','Plymouth, Ohio',17159,35);
INSERT INTO "django_geo_db_city" VALUES(13675,'Polk','Polk, Ohio',17160,35);
INSERT INTO "django_geo_db_city" VALUES(13676,'Republic','Republic, Ohio',17161,35);
INSERT INTO "django_geo_db_city" VALUES(13677,'Sandusky','Sandusky, Ohio',17162,35);
INSERT INTO "django_geo_db_city" VALUES(13678,'Savannah','Savannah, Ohio',17164,35);
INSERT INTO "django_geo_db_city" VALUES(13679,'Shelby','Shelby, Ohio',17165,35);
INSERT INTO "django_geo_db_city" VALUES(13680,'Shiloh','Shiloh, Ohio',17166,35);
INSERT INTO "django_geo_db_city" VALUES(13681,'Sullivan','Sullivan, Ohio',17167,35);
INSERT INTO "django_geo_db_city" VALUES(13682,'Sulphur Springs','Sulphur Springs, Ohio',17168,35);
INSERT INTO "django_geo_db_city" VALUES(13683,'Sycamore','Sycamore, Ohio',17169,35);
INSERT INTO "django_geo_db_city" VALUES(13684,'Tiro','Tiro, Ohio',17171,35);
INSERT INTO "django_geo_db_city" VALUES(13685,'Willard','Willard, Ohio',17172,35);
INSERT INTO "django_geo_db_city" VALUES(13686,'Wakeman','Wakeman, Ohio',17173,35);
INSERT INTO "django_geo_db_city" VALUES(13687,'Mansfield','Mansfield, Ohio',17175,35);
INSERT INTO "django_geo_db_city" VALUES(13688,'North Bend','North Bend, Ohio',17182,35);
INSERT INTO "django_geo_db_city" VALUES(13689,'Addyston','Addyston, Ohio',17183,35);
INSERT INTO "django_geo_db_city" VALUES(13690,'Cleves','Cleves, Ohio',17184,35);
INSERT INTO "django_geo_db_city" VALUES(13691,'College Corner','College Corner, Ohio',17185,35);
INSERT INTO "django_geo_db_city" VALUES(13692,'Collinsville','Collinsville, Ohio',17186,35);
INSERT INTO "django_geo_db_city" VALUES(13693,'Franklin','Franklin, Ohio',17187,35);
INSERT INTO "django_geo_db_city" VALUES(13694,'Hamilton','Hamilton, Ohio',17189,35);
INSERT INTO "django_geo_db_city" VALUES(13695,'Fairfield','Fairfield, Ohio',17191,35);
INSERT INTO "django_geo_db_city" VALUES(13696,'Harrison','Harrison, Ohio',17193,35);
INSERT INTO "django_geo_db_city" VALUES(13697,'Harveysburg','Harveysburg, Ohio',17194,35);
INSERT INTO "django_geo_db_city" VALUES(13698,'Hooven','Hooven, Ohio',17195,35);
INSERT INTO "django_geo_db_city" VALUES(13699,'Kings Mills','Kings Mills, Ohio',17196,35);
INSERT INTO "django_geo_db_city" VALUES(13700,'Lebanon','Lebanon, Ohio',17197,35);
INSERT INTO "django_geo_db_city" VALUES(13701,'Maineville','Maineville, Ohio',17198,35);
INSERT INTO "django_geo_db_city" VALUES(13702,'Mason','Mason, Ohio',17199,35);
INSERT INTO "django_geo_db_city" VALUES(13703,'Miamitown','Miamitown, Ohio',17200,35);
INSERT INTO "django_geo_db_city" VALUES(13704,'Middletown','Middletown, Ohio',17201,35);
INSERT INTO "django_geo_db_city" VALUES(13705,'Monroe','Monroe, Ohio',17203,35);
INSERT INTO "django_geo_db_city" VALUES(13706,'Mount Saint Joseph','Mount Saint Joseph, Ohio',17204,35);
INSERT INTO "django_geo_db_city" VALUES(13707,'Okeana','Okeana, Ohio',17206,35);
INSERT INTO "django_geo_db_city" VALUES(13708,'Oregonia','Oregonia, Ohio',17207,35);
INSERT INTO "django_geo_db_city" VALUES(13709,'Overpeck','Overpeck, Ohio',17208,35);
INSERT INTO "django_geo_db_city" VALUES(13710,'Oxford','Oxford, Ohio',17209,35);
INSERT INTO "django_geo_db_city" VALUES(13711,'Ross','Ross, Ohio',17210,35);
INSERT INTO "django_geo_db_city" VALUES(13712,'Seven Mile','Seven Mile, Ohio',17211,35);
INSERT INTO "django_geo_db_city" VALUES(13713,'Shandon','Shandon, Ohio',17212,35);
INSERT INTO "django_geo_db_city" VALUES(13714,'Somerville','Somerville, Ohio',17213,35);
INSERT INTO "django_geo_db_city" VALUES(13715,'South Lebanon','South Lebanon, Ohio',17214,35);
INSERT INTO "django_geo_db_city" VALUES(13716,'Springboro','Springboro, Ohio',17215,35);
INSERT INTO "django_geo_db_city" VALUES(13717,'Trenton','Trenton, Ohio',17216,35);
INSERT INTO "django_geo_db_city" VALUES(13718,'Waynesville','Waynesville, Ohio',17217,35);
INSERT INTO "django_geo_db_city" VALUES(13719,'West Chester','West Chester, Ohio',17218,35);
INSERT INTO "django_geo_db_city" VALUES(13720,'West Elkton','West Elkton, Ohio',17219,35);
INSERT INTO "django_geo_db_city" VALUES(13721,'Aberdeen','Aberdeen, Ohio',17220,35);
INSERT INTO "django_geo_db_city" VALUES(13722,'Amelia','Amelia, Ohio',17221,35);
INSERT INTO "django_geo_db_city" VALUES(13723,'Batavia','Batavia, Ohio',17222,35);
INSERT INTO "django_geo_db_city" VALUES(13724,'Bentonville','Bentonville, Ohio',17223,35);
INSERT INTO "django_geo_db_city" VALUES(13725,'Bethel','Bethel, Ohio',17224,35);
INSERT INTO "django_geo_db_city" VALUES(13726,'Blanchester','Blanchester, Ohio',17225,35);
INSERT INTO "django_geo_db_city" VALUES(13727,'Buford','Buford, Ohio',17226,35);
INSERT INTO "django_geo_db_city" VALUES(13728,'Camp Dennison','Camp Dennison, Ohio',17227,35);
INSERT INTO "django_geo_db_city" VALUES(13729,'Chilo','Chilo, Ohio',17228,35);
INSERT INTO "django_geo_db_city" VALUES(13730,'Clarksville','Clarksville, Ohio',17229,35);
INSERT INTO "django_geo_db_city" VALUES(13731,'Cuba','Cuba, Ohio',17230,35);
INSERT INTO "django_geo_db_city" VALUES(13732,'Decatur','Decatur, Ohio',17231,35);
INSERT INTO "django_geo_db_city" VALUES(13733,'Fayetteville','Fayetteville, Ohio',17232,35);
INSERT INTO "django_geo_db_city" VALUES(13734,'Feesburg','Feesburg, Ohio',17233,35);
INSERT INTO "django_geo_db_city" VALUES(13735,'Felicity','Felicity, Ohio',17234,35);
INSERT INTO "django_geo_db_city" VALUES(13736,'Georgetown','Georgetown, Ohio',17235,35);
INSERT INTO "django_geo_db_city" VALUES(13737,'Goshen','Goshen, Ohio',17236,35);
INSERT INTO "django_geo_db_city" VALUES(13738,'Greenfield','Greenfield, Ohio',17237,35);
INSERT INTO "django_geo_db_city" VALUES(13739,'Union','Union, Ohio',17238,35);
INSERT INTO "django_geo_db_city" VALUES(13740,'Columbia','Columbia, Ohio',17239,35);
INSERT INTO "django_geo_db_city" VALUES(13741,'Hamersville','Hamersville, Ohio',17240,35);
INSERT INTO "django_geo_db_city" VALUES(13742,'Higginsport','Higginsport, Ohio',17241,35);
INSERT INTO "django_geo_db_city" VALUES(13743,'Highland','Highland, Ohio',17242,35);
INSERT INTO "django_geo_db_city" VALUES(13744,'Hillsboro','Hillsboro, Ohio',17243,35);
INSERT INTO "django_geo_db_city" VALUES(13745,'Leesburg','Leesburg, Ohio',17244,35);
INSERT INTO "django_geo_db_city" VALUES(13746,'Lees Creek','Lees Creek, Ohio',17245,35);
INSERT INTO "django_geo_db_city" VALUES(13747,'Loveland','Loveland, Ohio',17246,35);
INSERT INTO "django_geo_db_city" VALUES(13748,'Lynchburg','Lynchburg, Ohio',17247,35);
INSERT INTO "django_geo_db_city" VALUES(13749,'Manchester','Manchester, Ohio',17248,35);
INSERT INTO "django_geo_db_city" VALUES(13750,'Marathon','Marathon, Ohio',17249,35);
INSERT INTO "django_geo_db_city" VALUES(13751,'Martinsville','Martinsville, Ohio',17250,35);
INSERT INTO "django_geo_db_city" VALUES(13752,'Miamiville','Miamiville, Ohio',17251,35);
INSERT INTO "django_geo_db_city" VALUES(13753,'Midland','Midland, Ohio',17252,35);
INSERT INTO "django_geo_db_city" VALUES(13754,'Milford','Milford, Ohio',17253,35);
INSERT INTO "django_geo_db_city" VALUES(13755,'Morrow','Morrow, Ohio',17254,35);
INSERT INTO "django_geo_db_city" VALUES(13756,'Moscow','Moscow, Ohio',17255,35);
INSERT INTO "django_geo_db_city" VALUES(13757,'Mount Orab','Mount Orab, Ohio',17256,35);
INSERT INTO "django_geo_db_city" VALUES(13758,'Mowrystown','Mowrystown, Ohio',17257,35);
INSERT INTO "django_geo_db_city" VALUES(13759,'Neville','Neville, Ohio',17258,35);
INSERT INTO "django_geo_db_city" VALUES(13760,'New Richmond','New Richmond, Ohio',17259,35);
INSERT INTO "django_geo_db_city" VALUES(13761,'Newtonsville','Newtonsville, Ohio',17260,35);
INSERT INTO "django_geo_db_city" VALUES(13762,'New Vienna','New Vienna, Ohio',17261,35);
INSERT INTO "django_geo_db_city" VALUES(13763,'Owensville','Owensville, Ohio',17262,35);
INSERT INTO "django_geo_db_city" VALUES(13764,'Pleasant Plain','Pleasant Plain, Ohio',17263,35);
INSERT INTO "django_geo_db_city" VALUES(13765,'Port William','Port William, Ohio',17264,35);
INSERT INTO "django_geo_db_city" VALUES(13766,'Reesville','Reesville, Ohio',17266,35);
INSERT INTO "django_geo_db_city" VALUES(13767,'Ripley','Ripley, Ohio',17267,35);
INSERT INTO "django_geo_db_city" VALUES(13768,'Russellville','Russellville, Ohio',17268,35);
INSERT INTO "django_geo_db_city" VALUES(13769,'Sabina','Sabina, Ohio',17269,35);
INSERT INTO "django_geo_db_city" VALUES(13770,'Sardinia','Sardinia, Ohio',17270,35);
INSERT INTO "django_geo_db_city" VALUES(13771,'Sinking Spring','Sinking Spring, Ohio',17271,35);
INSERT INTO "django_geo_db_city" VALUES(13772,'Terrace Park','Terrace Park, Ohio',17272,35);
INSERT INTO "django_geo_db_city" VALUES(13773,'Williamsburg','Williamsburg, Ohio',17273,35);
INSERT INTO "django_geo_db_city" VALUES(13774,'Wilmington','Wilmington, Ohio',17274,35);
INSERT INTO "django_geo_db_city" VALUES(13775,'Cincinnati','Cincinnati, Ohio',17275,35);
INSERT INTO "django_geo_db_city" VALUES(13776,'Alpha','Alpha, Ohio',17325,35);
INSERT INTO "django_geo_db_city" VALUES(13777,'Anna','Anna, Ohio',17326,35);
INSERT INTO "django_geo_db_city" VALUES(13778,'Ansonia','Ansonia, Ohio',17327,35);
INSERT INTO "django_geo_db_city" VALUES(13779,'Arcanum','Arcanum, Ohio',17328,35);
INSERT INTO "django_geo_db_city" VALUES(13780,'Bellbrook','Bellbrook, Ohio',17329,35);
INSERT INTO "django_geo_db_city" VALUES(13781,'Botkins','Botkins, Ohio',17330,35);
INSERT INTO "django_geo_db_city" VALUES(13782,'Bowersville','Bowersville, Ohio',17331,35);
INSERT INTO "django_geo_db_city" VALUES(13783,'Bradford','Bradford, Ohio',17332,35);
INSERT INTO "django_geo_db_city" VALUES(13784,'Brookville','Brookville, Ohio',17333,35);
INSERT INTO "django_geo_db_city" VALUES(13785,'Burkettsville','Burkettsville, Ohio',17334,35);
INSERT INTO "django_geo_db_city" VALUES(13786,'Camden','Camden, Ohio',17335,35);
INSERT INTO "django_geo_db_city" VALUES(13787,'Casstown','Casstown, Ohio',17336,35);
INSERT INTO "django_geo_db_city" VALUES(13788,'Cedarville','Cedarville, Ohio',17337,35);
INSERT INTO "django_geo_db_city" VALUES(13789,'Clayton','Clayton, Ohio',17338,35);
INSERT INTO "django_geo_db_city" VALUES(13790,'Clifton','Clifton, Ohio',17339,35);
INSERT INTO "django_geo_db_city" VALUES(13791,'Conover','Conover, Ohio',17340,35);
INSERT INTO "django_geo_db_city" VALUES(13792,'Covington','Covington, Ohio',17341,35);
INSERT INTO "django_geo_db_city" VALUES(13793,'Donnelsville','Donnelsville, Ohio',17342,35);
INSERT INTO "django_geo_db_city" VALUES(13794,'Eaton','Eaton, Ohio',17343,35);
INSERT INTO "django_geo_db_city" VALUES(13795,'Eldorado','Eldorado, Ohio',17344,35);
INSERT INTO "django_geo_db_city" VALUES(13796,'Englewood','Englewood, Ohio',17345,35);
INSERT INTO "django_geo_db_city" VALUES(13797,'Enon','Enon, Ohio',17346,35);
INSERT INTO "django_geo_db_city" VALUES(13798,'Fairborn','Fairborn, Ohio',17347,35);
INSERT INTO "django_geo_db_city" VALUES(13799,'Farmersville','Farmersville, Ohio',17348,35);
INSERT INTO "django_geo_db_city" VALUES(13800,'Fletcher','Fletcher, Ohio',17349,35);
INSERT INTO "django_geo_db_city" VALUES(13801,'Germantown','Germantown, Ohio',17350,35);
INSERT INTO "django_geo_db_city" VALUES(13802,'Gettysburg','Gettysburg, Ohio',17351,35);
INSERT INTO "django_geo_db_city" VALUES(13803,'Gordon','Gordon, Ohio',17352,35);
INSERT INTO "django_geo_db_city" VALUES(13804,'Gratis','Gratis, Ohio',17353,35);
INSERT INTO "django_geo_db_city" VALUES(13805,'Greenville','Greenville, Ohio',17354,35);
INSERT INTO "django_geo_db_city" VALUES(13806,'Hollansburg','Hollansburg, Ohio',17355,35);
INSERT INTO "django_geo_db_city" VALUES(13807,'Houston','Houston, Ohio',17356,35);
INSERT INTO "django_geo_db_city" VALUES(13808,'Jackson Center','Jackson Center, Ohio',17357,35);
INSERT INTO "django_geo_db_city" VALUES(13809,'Jamestown','Jamestown, Ohio',17358,35);
INSERT INTO "django_geo_db_city" VALUES(13810,'Kettlersville','Kettlersville, Ohio',17359,35);
INSERT INTO "django_geo_db_city" VALUES(13811,'Laura','Laura, Ohio',17360,35);
INSERT INTO "django_geo_db_city" VALUES(13812,'Lewisburg','Lewisburg, Ohio',17361,35);
INSERT INTO "django_geo_db_city" VALUES(13813,'Ludlow Falls','Ludlow Falls, Ohio',17362,35);
INSERT INTO "django_geo_db_city" VALUES(13814,'Maplewood','Maplewood, Ohio',17363,35);
INSERT INTO "django_geo_db_city" VALUES(13815,'Medway','Medway, Ohio',17364,35);
INSERT INTO "django_geo_db_city" VALUES(13816,'Miamisburg','Miamisburg, Ohio',17365,35);
INSERT INTO "django_geo_db_city" VALUES(13817,'New Carlisle','New Carlisle, Ohio',17367,35);
INSERT INTO "django_geo_db_city" VALUES(13818,'New Lebanon','New Lebanon, Ohio',17368,35);
INSERT INTO "django_geo_db_city" VALUES(13819,'New Madison','New Madison, Ohio',17369,35);
INSERT INTO "django_geo_db_city" VALUES(13820,'New Paris','New Paris, Ohio',17370,35);
INSERT INTO "django_geo_db_city" VALUES(13821,'New Weston','New Weston, Ohio',17371,35);
INSERT INTO "django_geo_db_city" VALUES(13822,'North Hampton','North Hampton, Ohio',17372,35);
INSERT INTO "django_geo_db_city" VALUES(13823,'North Star','North Star, Ohio',17352,35);
INSERT INTO "django_geo_db_city" VALUES(13824,'Osgood','Osgood, Ohio',17373,35);
INSERT INTO "django_geo_db_city" VALUES(13825,'Palestine','Palestine, Ohio',17374,35);
INSERT INTO "django_geo_db_city" VALUES(13826,'Pemberton','Pemberton, Ohio',17375,35);
INSERT INTO "django_geo_db_city" VALUES(13827,'Phillipsburg','Phillipsburg, Ohio',17376,35);
INSERT INTO "django_geo_db_city" VALUES(13828,'Piqua','Piqua, Ohio',17377,35);
INSERT INTO "django_geo_db_city" VALUES(13829,'Pitsburg','Pitsburg, Ohio',17378,35);
INSERT INTO "django_geo_db_city" VALUES(13830,'Pleasant Hill','Pleasant Hill, Ohio',17379,35);
INSERT INTO "django_geo_db_city" VALUES(13831,'Port Jefferson','Port Jefferson, Ohio',17380,35);
INSERT INTO "django_geo_db_city" VALUES(13832,'Potsdam','Potsdam, Ohio',17381,35);
INSERT INTO "django_geo_db_city" VALUES(13833,'Rossburg','Rossburg, Ohio',17382,35);
INSERT INTO "django_geo_db_city" VALUES(13834,'Russia','Russia, Ohio',17383,35);
INSERT INTO "django_geo_db_city" VALUES(13835,'Sidney','Sidney, Ohio',17384,35);
INSERT INTO "django_geo_db_city" VALUES(13836,'South Charleston','South Charleston, Ohio',17386,35);
INSERT INTO "django_geo_db_city" VALUES(13837,'South Vienna','South Vienna, Ohio',17387,35);
INSERT INTO "django_geo_db_city" VALUES(13838,'Spring Valley','Spring Valley, Ohio',17388,35);
INSERT INTO "django_geo_db_city" VALUES(13839,'Tipp City','Tipp City, Ohio',17389,35);
INSERT INTO "django_geo_db_city" VALUES(13840,'Tremont City','Tremont City, Ohio',17390,35);
INSERT INTO "django_geo_db_city" VALUES(13841,'Troy','Troy, Ohio',17391,35);
INSERT INTO "django_geo_db_city" VALUES(13842,'Vandalia','Vandalia, Ohio',17393,35);
INSERT INTO "django_geo_db_city" VALUES(13843,'Verona','Verona, Ohio',17394,35);
INSERT INTO "django_geo_db_city" VALUES(13844,'Versailles','Versailles, Ohio',17395,35);
INSERT INTO "django_geo_db_city" VALUES(13845,'West Alexandria','West Alexandria, Ohio',17396,35);
INSERT INTO "django_geo_db_city" VALUES(13846,'West Manchester','West Manchester, Ohio',17397,35);
INSERT INTO "django_geo_db_city" VALUES(13847,'West Milton','West Milton, Ohio',17398,35);
INSERT INTO "django_geo_db_city" VALUES(13848,'Wilberforce','Wilberforce, Ohio',17399,35);
INSERT INTO "django_geo_db_city" VALUES(13849,'Xenia','Xenia, Ohio',17400,35);
INSERT INTO "django_geo_db_city" VALUES(13850,'Yellow Springs','Yellow Springs, Ohio',17401,35);
INSERT INTO "django_geo_db_city" VALUES(13851,'Yorkshire','Yorkshire, Ohio',17402,35);
INSERT INTO "django_geo_db_city" VALUES(13852,'Christiansburg','Christiansburg, Ohio',17403,35);
INSERT INTO "django_geo_db_city" VALUES(13853,'Union City','Union City, Ohio',17404,35);
INSERT INTO "django_geo_db_city" VALUES(13854,'Dayton','Dayton, Ohio',17366,35);
INSERT INTO "django_geo_db_city" VALUES(13855,'Springfield','Springfield, Ohio',17439,35);
INSERT INTO "django_geo_db_city" VALUES(13856,'West Union','West Union, Ohio',17445,35);
INSERT INTO "django_geo_db_city" VALUES(13857,'Chillicothe','Chillicothe, Ohio',17446,35);
INSERT INTO "django_geo_db_city" VALUES(13858,'Bainbridge','Bainbridge, Ohio',17447,35);
INSERT INTO "django_geo_db_city" VALUES(13859,'Beaver','Beaver, Ohio',17448,35);
INSERT INTO "django_geo_db_city" VALUES(13860,'Bidwell','Bidwell, Ohio',17449,35);
INSERT INTO "django_geo_db_city" VALUES(13861,'Blue Creek','Blue Creek, Ohio',17450,35);
INSERT INTO "django_geo_db_city" VALUES(13862,'Bourneville','Bourneville, Ohio',17451,35);
INSERT INTO "django_geo_db_city" VALUES(13863,'Cherry Fork','Cherry Fork, Ohio',17452,35);
INSERT INTO "django_geo_db_city" VALUES(13864,'Chesapeake','Chesapeake, Ohio',17453,35);
INSERT INTO "django_geo_db_city" VALUES(13865,'Cheshire','Cheshire, Ohio',17454,35);
INSERT INTO "django_geo_db_city" VALUES(13866,'Coalton','Coalton, Ohio',17455,35);
INSERT INTO "django_geo_db_city" VALUES(13867,'Creola','Creola, Ohio',17456,35);
INSERT INTO "django_geo_db_city" VALUES(13868,'Crown City','Crown City, Ohio',17457,35);
INSERT INTO "django_geo_db_city" VALUES(13869,'Cynthiana','Cynthiana, Ohio',17458,35);
INSERT INTO "django_geo_db_city" VALUES(13870,'Frankfort','Frankfort, Ohio',17459,35);
INSERT INTO "django_geo_db_city" VALUES(13871,'Franklin Furnace','Franklin Furnace, Ohio',17460,35);
INSERT INTO "django_geo_db_city" VALUES(13872,'Friendship','Friendship, Ohio',17461,35);
INSERT INTO "django_geo_db_city" VALUES(13873,'Gallipolis','Gallipolis, Ohio',17462,35);
INSERT INTO "django_geo_db_city" VALUES(13874,'Hallsville','Hallsville, Ohio',17463,35);
INSERT INTO "django_geo_db_city" VALUES(13875,'Hamden','Hamden, Ohio',17464,35);
INSERT INTO "django_geo_db_city" VALUES(13876,'Haverhill','Haverhill, Ohio',17465,35);
INSERT INTO "django_geo_db_city" VALUES(13877,'Ironton','Ironton, Ohio',17466,35);
INSERT INTO "django_geo_db_city" VALUES(13878,'Jackson','Jackson, Ohio',17467,35);
INSERT INTO "django_geo_db_city" VALUES(13879,'Morgan','Morgan, Ohio',17468,35);
INSERT INTO "django_geo_db_city" VALUES(13880,'Jasper','Jasper, Ohio',17469,35);
INSERT INTO "django_geo_db_city" VALUES(13881,'Kerr','Kerr, Ohio',17470,35);
INSERT INTO "django_geo_db_city" VALUES(13882,'Kingston','Kingston, Ohio',17471,35);
INSERT INTO "django_geo_db_city" VALUES(13883,'Kitts Hill','Kitts Hill, Ohio',17472,35);
INSERT INTO "django_geo_db_city" VALUES(13884,'Latham','Latham, Ohio',17473,35);
INSERT INTO "django_geo_db_city" VALUES(13885,'Londonderry','Londonderry, Ohio',17474,35);
INSERT INTO "django_geo_db_city" VALUES(13886,'Lucasville','Lucasville, Ohio',17475,35);
INSERT INTO "django_geo_db_city" VALUES(13887,'Lynx','Lynx, Ohio',17476,35);
INSERT INTO "django_geo_db_city" VALUES(13888,'McArthur','McArthur, Ohio',17477,35);
INSERT INTO "django_geo_db_city" VALUES(13889,'McDermott','McDermott, Ohio',17478,35);
INSERT INTO "django_geo_db_city" VALUES(13890,'Minford','Minford, Ohio',17479,35);
INSERT INTO "django_geo_db_city" VALUES(13891,'New Plymouth','New Plymouth, Ohio',17480,35);
INSERT INTO "django_geo_db_city" VALUES(13892,'Oak Hill','Oak Hill, Ohio',17481,35);
INSERT INTO "django_geo_db_city" VALUES(13893,'Otway','Otway, Ohio',17482,35);
INSERT INTO "django_geo_db_city" VALUES(13894,'Patriot','Patriot, Ohio',17483,35);
INSERT INTO "django_geo_db_city" VALUES(13895,'Pedro','Pedro, Ohio',17484,35);
INSERT INTO "django_geo_db_city" VALUES(13896,'Peebles','Peebles, Ohio',17485,35);
INSERT INTO "django_geo_db_city" VALUES(13897,'Piketon','Piketon, Ohio',17486,35);
INSERT INTO "django_geo_db_city" VALUES(13898,'Portsmouth','Portsmouth, Ohio',17487,35);
INSERT INTO "django_geo_db_city" VALUES(13899,'West Portsmouth','West Portsmouth, Ohio',17488,35);
INSERT INTO "django_geo_db_city" VALUES(13900,'Proctorville','Proctorville, Ohio',17489,35);
INSERT INTO "django_geo_db_city" VALUES(13901,'Wilkesville','Wilkesville, Ohio',17490,35);
INSERT INTO "django_geo_db_city" VALUES(13902,'Rarden','Rarden, Ohio',17491,35);
INSERT INTO "django_geo_db_city" VALUES(13903,'Ray','Ray, Ohio',17492,35);
INSERT INTO "django_geo_db_city" VALUES(13904,'Richmond Dale','Richmond Dale, Ohio',17493,35);
INSERT INTO "django_geo_db_city" VALUES(13905,'Rio Grande','Rio Grande, Ohio',17494,35);
INSERT INTO "django_geo_db_city" VALUES(13906,'Rock Camp','Rock Camp, Ohio',17495,35);
INSERT INTO "django_geo_db_city" VALUES(13907,'Scioto Furnace','Scioto Furnace, Ohio',17496,35);
INSERT INTO "django_geo_db_city" VALUES(13908,'Scottown','Scottown, Ohio',17497,35);
INSERT INTO "django_geo_db_city" VALUES(13909,'Seaman','Seaman, Ohio',17498,35);
INSERT INTO "django_geo_db_city" VALUES(13910,'South Point','South Point, Ohio',17499,35);
INSERT INTO "django_geo_db_city" VALUES(13911,'South Salem','South Salem, Ohio',17500,35);
INSERT INTO "django_geo_db_city" VALUES(13912,'South Webster','South Webster, Ohio',17501,35);
INSERT INTO "django_geo_db_city" VALUES(13913,'Stockdale','Stockdale, Ohio',17502,35);
INSERT INTO "django_geo_db_city" VALUES(13914,'Stout','Stout, Ohio',17503,35);
INSERT INTO "django_geo_db_city" VALUES(13915,'Thurman','Thurman, Ohio',17504,35);
INSERT INTO "django_geo_db_city" VALUES(13916,'Vinton','Vinton, Ohio',17505,35);
INSERT INTO "django_geo_db_city" VALUES(13917,'Wakefield','Wakefield, Ohio',17506,35);
INSERT INTO "django_geo_db_city" VALUES(13918,'Waterloo','Waterloo, Ohio',17507,35);
INSERT INTO "django_geo_db_city" VALUES(13919,'Waverly','Waverly, Ohio',17508,35);
INSERT INTO "django_geo_db_city" VALUES(13920,'Wellston','Wellston, Ohio',17509,35);
INSERT INTO "django_geo_db_city" VALUES(13921,'Wheelersburg','Wheelersburg, Ohio',17511,35);
INSERT INTO "django_geo_db_city" VALUES(13922,'Willow Wood','Willow Wood, Ohio',17513,35);
INSERT INTO "django_geo_db_city" VALUES(13923,'Winchester','Winchester, Ohio',17514,35);
INSERT INTO "django_geo_db_city" VALUES(13924,'Zaleski','Zaleski, Ohio',17515,35);
INSERT INTO "django_geo_db_city" VALUES(13925,'Athens','Athens, Ohio',17516,35);
INSERT INTO "django_geo_db_city" VALUES(13926,'Albany','Albany, Ohio',17517,35);
INSERT INTO "django_geo_db_city" VALUES(13927,'Amesville','Amesville, Ohio',17518,35);
INSERT INTO "django_geo_db_city" VALUES(13928,'Barlow','Barlow, Ohio',17519,35);
INSERT INTO "django_geo_db_city" VALUES(13929,'Bartlett','Bartlett, Ohio',17520,35);
INSERT INTO "django_geo_db_city" VALUES(13930,'Belpre','Belpre, Ohio',17521,35);
INSERT INTO "django_geo_db_city" VALUES(13931,'Beverly','Beverly, Ohio',17522,35);
INSERT INTO "django_geo_db_city" VALUES(13932,'Buchtel','Buchtel, Ohio',17523,35);
INSERT INTO "django_geo_db_city" VALUES(13933,'Carbondale','Carbondale, Ohio',17524,35);
INSERT INTO "django_geo_db_city" VALUES(13934,'Chauncey','Chauncey, Ohio',17525,35);
INSERT INTO "django_geo_db_city" VALUES(13935,'Chester','Chester, Ohio',17526,35);
INSERT INTO "django_geo_db_city" VALUES(13936,'Coal Run','Coal Run, Ohio',17527,35);
INSERT INTO "django_geo_db_city" VALUES(13937,'Coolville','Coolville, Ohio',17528,35);
INSERT INTO "django_geo_db_city" VALUES(13938,'Cutler','Cutler, Ohio',17529,35);
INSERT INTO "django_geo_db_city" VALUES(13939,'Dexter City','Dexter City, Ohio',17530,35);
INSERT INTO "django_geo_db_city" VALUES(13940,'Fleming','Fleming, Ohio',17531,35);
INSERT INTO "django_geo_db_city" VALUES(13941,'Glouster','Glouster, Ohio',17532,35);
INSERT INTO "django_geo_db_city" VALUES(13942,'Graysville','Graysville, Ohio',17533,35);
INSERT INTO "django_geo_db_city" VALUES(13943,'Guysville','Guysville, Ohio',17534,35);
INSERT INTO "django_geo_db_city" VALUES(13944,'Hockingport','Hockingport, Ohio',17535,35);
INSERT INTO "django_geo_db_city" VALUES(13945,'Jacksonville','Jacksonville, Ohio',17536,35);
INSERT INTO "django_geo_db_city" VALUES(13946,'Langsville','Langsville, Ohio',17537,35);
INSERT INTO "django_geo_db_city" VALUES(13947,'Little Hocking','Little Hocking, Ohio',17538,35);
INSERT INTO "django_geo_db_city" VALUES(13948,'Long Bottom','Long Bottom, Ohio',17539,35);
INSERT INTO "django_geo_db_city" VALUES(13949,'Lowell','Lowell, Ohio',17540,35);
INSERT INTO "django_geo_db_city" VALUES(13950,'Lower Salem','Lower Salem, Ohio',17541,35);
INSERT INTO "django_geo_db_city" VALUES(13951,'Macksburg','Macksburg, Ohio',17542,35);
INSERT INTO "django_geo_db_city" VALUES(13952,'Marietta','Marietta, Ohio',17543,35);
INSERT INTO "django_geo_db_city" VALUES(13953,'Middleport','Middleport, Ohio',17545,35);
INSERT INTO "django_geo_db_city" VALUES(13954,'Millfield','Millfield, Ohio',17546,35);
INSERT INTO "django_geo_db_city" VALUES(13955,'Nelsonville','Nelsonville, Ohio',17547,35);
INSERT INTO "django_geo_db_city" VALUES(13956,'New Marshfield','New Marshfield, Ohio',17548,35);
INSERT INTO "django_geo_db_city" VALUES(13957,'New Matamoras','New Matamoras, Ohio',17549,35);
INSERT INTO "django_geo_db_city" VALUES(13958,'Newport','Newport, Ohio',17550,35);
INSERT INTO "django_geo_db_city" VALUES(13959,'Pomeroy','Pomeroy, Ohio',17551,35);
INSERT INTO "django_geo_db_city" VALUES(13960,'Portland','Portland, Ohio',17552,35);
INSERT INTO "django_geo_db_city" VALUES(13961,'Racine','Racine, Ohio',17553,35);
INSERT INTO "django_geo_db_city" VALUES(13962,'Reedsville','Reedsville, Ohio',17554,35);
INSERT INTO "django_geo_db_city" VALUES(13963,'Reno','Reno, Ohio',17555,35);
INSERT INTO "django_geo_db_city" VALUES(13964,'Rutland','Rutland, Ohio',17556,35);
INSERT INTO "django_geo_db_city" VALUES(13965,'Shade','Shade, Ohio',17557,35);
INSERT INTO "django_geo_db_city" VALUES(13966,'Sharpsburg','Sharpsburg, Ohio',17524,35);
INSERT INTO "django_geo_db_city" VALUES(13967,'Stewart','Stewart, Ohio',17558,35);
INSERT INTO "django_geo_db_city" VALUES(13968,'Syracuse','Syracuse, Ohio',17559,35);
INSERT INTO "django_geo_db_city" VALUES(13969,'The Plains','The Plains, Ohio',17560,35);
INSERT INTO "django_geo_db_city" VALUES(13970,'Torch','Torch, Ohio',17524,35);
INSERT INTO "django_geo_db_city" VALUES(13971,'Trimble','Trimble, Ohio',17561,35);
INSERT INTO "django_geo_db_city" VALUES(13972,'Tuppers Plains','Tuppers Plains, Ohio',17562,35);
INSERT INTO "django_geo_db_city" VALUES(13973,'Vincent','Vincent, Ohio',17563,35);
INSERT INTO "django_geo_db_city" VALUES(13974,'Waterford','Waterford, Ohio',17564,35);
INSERT INTO "django_geo_db_city" VALUES(13975,'Watertown','Watertown, Ohio',17527,35);
INSERT INTO "django_geo_db_city" VALUES(13976,'Whipple','Whipple, Ohio',17565,35);
INSERT INTO "django_geo_db_city" VALUES(13977,'Wingett Run','Wingett Run, Ohio',17566,35);
INSERT INTO "django_geo_db_city" VALUES(13978,'Lima','Lima, Ohio',17567,35);
INSERT INTO "django_geo_db_city" VALUES(13979,'Beaverdam','Beaverdam, Ohio',17573,35);
INSERT INTO "django_geo_db_city" VALUES(13980,'Gomer','Gomer, Ohio',17574,35);
INSERT INTO "django_geo_db_city" VALUES(13981,'Ada','Ada, Ohio',17575,35);
INSERT INTO "django_geo_db_city" VALUES(13982,'Alger','Alger, Ohio',17576,35);
INSERT INTO "django_geo_db_city" VALUES(13983,'Antwerp','Antwerp, Ohio',17577,35);
INSERT INTO "django_geo_db_city" VALUES(13984,'Arlington','Arlington, Ohio',17578,35);
INSERT INTO "django_geo_db_city" VALUES(13985,'Belmore','Belmore, Ohio',17579,35);
INSERT INTO "django_geo_db_city" VALUES(13986,'Benton Ridge','Benton Ridge, Ohio',17580,35);
INSERT INTO "django_geo_db_city" VALUES(13987,'Bluffton','Bluffton, Ohio',17581,35);
INSERT INTO "django_geo_db_city" VALUES(13988,'Buckland','Buckland, Ohio',17582,35);
INSERT INTO "django_geo_db_city" VALUES(13989,'Cairo','Cairo, Ohio',17583,35);
INSERT INTO "django_geo_db_city" VALUES(13990,'Cecil','Cecil, Ohio',17584,35);
INSERT INTO "django_geo_db_city" VALUES(13991,'Celina','Celina, Ohio',17585,35);
INSERT INTO "django_geo_db_city" VALUES(13992,'Chickasaw','Chickasaw, Ohio',17586,35);
INSERT INTO "django_geo_db_city" VALUES(13993,'Cloverdale','Cloverdale, Ohio',17587,35);
INSERT INTO "django_geo_db_city" VALUES(13994,'Coldwater','Coldwater, Ohio',17588,35);
INSERT INTO "django_geo_db_city" VALUES(13995,'Crane','Crane, Ohio',17589,35);
INSERT INTO "django_geo_db_city" VALUES(13996,'Columbus Grove','Columbus Grove, Ohio',17590,35);
INSERT INTO "django_geo_db_city" VALUES(13997,'Continental','Continental, Ohio',17591,35);
INSERT INTO "django_geo_db_city" VALUES(13998,'Convoy','Convoy, Ohio',17592,35);
INSERT INTO "django_geo_db_city" VALUES(13999,'Delphos','Delphos, Ohio',17593,35);
INSERT INTO "django_geo_db_city" VALUES(14000,'Dola','Dola, Ohio',17594,35);
INSERT INTO "django_geo_db_city" VALUES(14001,'Dunkirk','Dunkirk, Ohio',17595,35);
INSERT INTO "django_geo_db_city" VALUES(14002,'Dupont','Dupont, Ohio',17596,35);
INSERT INTO "django_geo_db_city" VALUES(14003,'Elgin','Elgin, Ohio',17597,35);
INSERT INTO "django_geo_db_city" VALUES(14004,'Findlay','Findlay, Ohio',17598,35);
INSERT INTO "django_geo_db_city" VALUES(14005,'Jenera','Jenera, Ohio',17600,35);
INSERT INTO "django_geo_db_city" VALUES(14006,'Forest','Forest, Ohio',17601,35);
INSERT INTO "django_geo_db_city" VALUES(14007,'Fort Jennings','Fort Jennings, Ohio',17602,35);
INSERT INTO "django_geo_db_city" VALUES(14008,'Fort Loramie','Fort Loramie, Ohio',17603,35);
INSERT INTO "django_geo_db_city" VALUES(14009,'Fort Recovery','Fort Recovery, Ohio',17604,35);
INSERT INTO "django_geo_db_city" VALUES(14010,'Glandorf','Glandorf, Ohio',17605,35);
INSERT INTO "django_geo_db_city" VALUES(14011,'Grover Hill','Grover Hill, Ohio',17606,35);
INSERT INTO "django_geo_db_city" VALUES(14012,'Harrod','Harrod, Ohio',17607,35);
INSERT INTO "django_geo_db_city" VALUES(14013,'Haviland','Haviland, Ohio',17608,35);
INSERT INTO "django_geo_db_city" VALUES(14014,'Kalida','Kalida, Ohio',17609,35);
INSERT INTO "django_geo_db_city" VALUES(14015,'Lafayette','Lafayette, Ohio',17610,35);
INSERT INTO "django_geo_db_city" VALUES(14016,'Latty','Latty, Ohio',17611,35);
INSERT INTO "django_geo_db_city" VALUES(14017,'Leipsic','Leipsic, Ohio',17612,35);
INSERT INTO "django_geo_db_city" VALUES(14018,'McComb','McComb, Ohio',17613,35);
INSERT INTO "django_geo_db_city" VALUES(14019,'McGuffey','McGuffey, Ohio',17614,35);
INSERT INTO "django_geo_db_city" VALUES(14020,'Maria Stein','Maria Stein, Ohio',17615,35);
INSERT INTO "django_geo_db_city" VALUES(14021,'Melrose','Melrose, Ohio',17616,35);
INSERT INTO "django_geo_db_city" VALUES(14022,'Mendon','Mendon, Ohio',17617,35);
INSERT INTO "django_geo_db_city" VALUES(14023,'Middle Point','Middle Point, Ohio',17618,35);
INSERT INTO "django_geo_db_city" VALUES(14024,'Miller City','Miller City, Ohio',17619,35);
INSERT INTO "django_geo_db_city" VALUES(14025,'Minster','Minster, Ohio',17620,35);
INSERT INTO "django_geo_db_city" VALUES(14026,'Montezuma','Montezuma, Ohio',17621,35);
INSERT INTO "django_geo_db_city" VALUES(14027,'Mount Blanchard','Mount Blanchard, Ohio',17622,35);
INSERT INTO "django_geo_db_city" VALUES(14028,'Mount Cory','Mount Cory, Ohio',17623,35);
INSERT INTO "django_geo_db_city" VALUES(14029,'New Bremen','New Bremen, Ohio',17624,35);
INSERT INTO "django_geo_db_city" VALUES(14030,'New Hampshire','New Hampshire, Ohio',17625,35);
INSERT INTO "django_geo_db_city" VALUES(14031,'New Knoxville','New Knoxville, Ohio',17626,35);
INSERT INTO "django_geo_db_city" VALUES(14032,'North Baltimore','North Baltimore, Ohio',17627,35);
INSERT INTO "django_geo_db_city" VALUES(14033,'Oakwood','Oakwood, Ohio',17628,35);
INSERT INTO "django_geo_db_city" VALUES(14034,'Ohio City','Ohio City, Ohio',17629,35);
INSERT INTO "django_geo_db_city" VALUES(14035,'Ottawa','Ottawa, Ohio',17630,35);
INSERT INTO "django_geo_db_city" VALUES(14036,'Ottoville','Ottoville, Ohio',17631,35);
INSERT INTO "django_geo_db_city" VALUES(14037,'Pandora','Pandora, Ohio',17632,35);
INSERT INTO "django_geo_db_city" VALUES(14038,'Paulding','Paulding, Ohio',17633,35);
INSERT INTO "django_geo_db_city" VALUES(14039,'Payne','Payne, Ohio',17634,35);
INSERT INTO "django_geo_db_city" VALUES(14040,'Rawson','Rawson, Ohio',17635,35);
INSERT INTO "django_geo_db_city" VALUES(14041,'Rockford','Rockford, Ohio',17636,35);
INSERT INTO "django_geo_db_city" VALUES(14042,'Saint Henry','Saint Henry, Ohio',17637,35);
INSERT INTO "django_geo_db_city" VALUES(14043,'Saint Johns','Saint Johns, Ohio',17638,35);
INSERT INTO "django_geo_db_city" VALUES(14044,'Saint Marys','Saint Marys, Ohio',17639,35);
INSERT INTO "django_geo_db_city" VALUES(14045,'Scott','Scott, Ohio',17640,35);
INSERT INTO "django_geo_db_city" VALUES(14046,'Spencerville','Spencerville, Ohio',17641,35);
INSERT INTO "django_geo_db_city" VALUES(14047,'Uniopolis','Uniopolis, Ohio',17642,35);
INSERT INTO "django_geo_db_city" VALUES(14048,'Van Buren','Van Buren, Ohio',17643,35);
INSERT INTO "django_geo_db_city" VALUES(14049,'Vanlue','Vanlue, Ohio',17644,35);
INSERT INTO "django_geo_db_city" VALUES(14050,'Van Wert','Van Wert, Ohio',17645,35);
INSERT INTO "django_geo_db_city" VALUES(14051,'Vaughnsville','Vaughnsville, Ohio',17646,35);
INSERT INTO "django_geo_db_city" VALUES(14052,'Venedocia','Venedocia, Ohio',17647,35);
INSERT INTO "django_geo_db_city" VALUES(14053,'Wapakoneta','Wapakoneta, Ohio',17648,35);
INSERT INTO "django_geo_db_city" VALUES(14054,'Waynesfield','Waynesfield, Ohio',17649,35);
INSERT INTO "django_geo_db_city" VALUES(14055,'Williamstown','Williamstown, Ohio',17650,35);
INSERT INTO "django_geo_db_city" VALUES(14056,'Willshire','Willshire, Ohio',17651,35);
INSERT INTO "django_geo_db_city" VALUES(14057,'Wren','Wren, Ohio',17652,35);
INSERT INTO "django_geo_db_city" VALUES(14058,'Alexandria','Alexandria, Indiana',17653,18);
INSERT INTO "django_geo_db_city" VALUES(14059,'Anderson','Anderson, Indiana',17654,18);
INSERT INTO "django_geo_db_city" VALUES(14060,'Arcadia','Arcadia, Indiana',17661,18);
INSERT INTO "django_geo_db_city" VALUES(14061,'Atlanta','Atlanta, Indiana',17662,18);
INSERT INTO "django_geo_db_city" VALUES(14062,'Carmel','Carmel, Indiana',17663,18);
INSERT INTO "django_geo_db_city" VALUES(14063,'Cicero','Cicero, Indiana',17665,18);
INSERT INTO "django_geo_db_city" VALUES(14064,'Colfax','Colfax, Indiana',17666,18);
INSERT INTO "django_geo_db_city" VALUES(14065,'Elwood','Elwood, Indiana',17667,18);
INSERT INTO "django_geo_db_city" VALUES(14066,'Fishers','Fishers, Indiana',17668,18);
INSERT INTO "django_geo_db_city" VALUES(14067,'Forest','Forest, Indiana',17669,18);
INSERT INTO "django_geo_db_city" VALUES(14068,'Fortville','Fortville, Indiana',17670,18);
INSERT INTO "django_geo_db_city" VALUES(14069,'Frankfort','Frankfort, Indiana',17671,18);
INSERT INTO "django_geo_db_city" VALUES(14070,'Frankton','Frankton, Indiana',17672,18);
INSERT INTO "django_geo_db_city" VALUES(14071,'Goldsmith','Goldsmith, Indiana',17673,18);
INSERT INTO "django_geo_db_city" VALUES(14072,'Hillisburg','Hillisburg, Indiana',17674,18);
INSERT INTO "django_geo_db_city" VALUES(14073,'Hobbs','Hobbs, Indiana',17675,18);
INSERT INTO "django_geo_db_city" VALUES(14074,'Ingalls','Ingalls, Indiana',17676,18);
INSERT INTO "django_geo_db_city" VALUES(14075,'Kempton','Kempton, Indiana',17677,18);
INSERT INTO "django_geo_db_city" VALUES(14076,'Kirklin','Kirklin, Indiana',17678,18);
INSERT INTO "django_geo_db_city" VALUES(14077,'Lapel','Lapel, Indiana',17679,18);
INSERT INTO "django_geo_db_city" VALUES(14078,'Lebanon','Lebanon, Indiana',17680,18);
INSERT INTO "django_geo_db_city" VALUES(14079,'McCordsville','McCordsville, Indiana',17681,18);
INSERT INTO "django_geo_db_city" VALUES(14080,'Markleville','Markleville, Indiana',17682,18);
INSERT INTO "django_geo_db_city" VALUES(14081,'Michigantown','Michigantown, Indiana',17683,18);
INSERT INTO "django_geo_db_city" VALUES(14082,'Mulberry','Mulberry, Indiana',17684,18);
INSERT INTO "django_geo_db_city" VALUES(14083,'Noblesville','Noblesville, Indiana',17685,18);
INSERT INTO "django_geo_db_city" VALUES(14084,'Orestes','Orestes, Indiana',17687,18);
INSERT INTO "django_geo_db_city" VALUES(14085,'Pendleton','Pendleton, Indiana',17688,18);
INSERT INTO "django_geo_db_city" VALUES(14086,'Rossville','Rossville, Indiana',17689,18);
INSERT INTO "django_geo_db_city" VALUES(14087,'Sedalia','Sedalia, Indiana',17674,18);
INSERT INTO "django_geo_db_city" VALUES(14088,'Sharpsville','Sharpsville, Indiana',17690,18);
INSERT INTO "django_geo_db_city" VALUES(14089,'Sheridan','Sheridan, Indiana',17691,18);
INSERT INTO "django_geo_db_city" VALUES(14090,'Summitville','Summitville, Indiana',17692,18);
INSERT INTO "django_geo_db_city" VALUES(14091,'Thorntown','Thorntown, Indiana',17693,18);
INSERT INTO "django_geo_db_city" VALUES(14092,'Tipton','Tipton, Indiana',17694,18);
INSERT INTO "django_geo_db_city" VALUES(14093,'Westfield','Westfield, Indiana',17695,18);
INSERT INTO "django_geo_db_city" VALUES(14094,'Whitestown','Whitestown, Indiana',17696,18);
INSERT INTO "django_geo_db_city" VALUES(14095,'Windfall','Windfall, Indiana',17697,18);
INSERT INTO "django_geo_db_city" VALUES(14096,'Zionsville','Zionsville, Indiana',17698,18);
INSERT INTO "django_geo_db_city" VALUES(14097,'Advance','Advance, Indiana',17699,18);
INSERT INTO "django_geo_db_city" VALUES(14098,'Amo','Amo, Indiana',17700,18);
INSERT INTO "django_geo_db_city" VALUES(14099,'Arlington','Arlington, Indiana',17701,18);
INSERT INTO "django_geo_db_city" VALUES(14100,'Bainbridge','Bainbridge, Indiana',17702,18);
INSERT INTO "django_geo_db_city" VALUES(14101,'Bargersville','Bargersville, Indiana',17703,18);
INSERT INTO "django_geo_db_city" VALUES(14102,'Beech Grove','Beech Grove, Indiana',17704,18);
INSERT INTO "django_geo_db_city" VALUES(14103,'Boggstown','Boggstown, Indiana',17705,18);
INSERT INTO "django_geo_db_city" VALUES(14104,'Brooklyn','Brooklyn, Indiana',17706,18);
INSERT INTO "django_geo_db_city" VALUES(14105,'Brownsburg','Brownsburg, Indiana',17707,18);
INSERT INTO "django_geo_db_city" VALUES(14106,'Camby','Camby, Indiana',17708,18);
INSERT INTO "django_geo_db_city" VALUES(14107,'Cartersburg','Cartersburg, Indiana',17709,18);
INSERT INTO "django_geo_db_city" VALUES(14108,'Carthage','Carthage, Indiana',17710,18);
INSERT INTO "django_geo_db_city" VALUES(14109,'Charlottesville','Charlottesville, Indiana',17711,18);
INSERT INTO "django_geo_db_city" VALUES(14110,'Clayton','Clayton, Indiana',17712,18);
INSERT INTO "django_geo_db_city" VALUES(14111,'Cloverdale','Cloverdale, Indiana',17713,18);
INSERT INTO "django_geo_db_city" VALUES(14112,'Coatesville','Coatesville, Indiana',17714,18);
INSERT INTO "django_geo_db_city" VALUES(14113,'Danville','Danville, Indiana',17715,18);
INSERT INTO "django_geo_db_city" VALUES(14114,'Avon','Avon, Indiana',17716,18);
INSERT INTO "django_geo_db_city" VALUES(14115,'Edinburgh','Edinburgh, Indiana',17717,18);
INSERT INTO "django_geo_db_city" VALUES(14116,'Eminence','Eminence, Indiana',17718,18);
INSERT INTO "django_geo_db_city" VALUES(14117,'Fairland','Fairland, Indiana',17719,18);
INSERT INTO "django_geo_db_city" VALUES(14118,'Falmouth','Falmouth, Indiana',17720,18);
INSERT INTO "django_geo_db_city" VALUES(14119,'Fillmore','Fillmore, Indiana',17721,18);
INSERT INTO "django_geo_db_city" VALUES(14120,'Finly','Finly, Indiana',17722,18);
INSERT INTO "django_geo_db_city" VALUES(14121,'Fountaintown','Fountaintown, Indiana',17723,18);
INSERT INTO "django_geo_db_city" VALUES(14122,'Franklin','Franklin, Indiana',17724,18);
INSERT INTO "django_geo_db_city" VALUES(14123,'Glenwood','Glenwood, Indiana',17725,18);
INSERT INTO "django_geo_db_city" VALUES(14124,'Greencastle','Greencastle, Indiana',17726,18);
INSERT INTO "django_geo_db_city" VALUES(14125,'Greenfield','Greenfield, Indiana',17727,18);
INSERT INTO "django_geo_db_city" VALUES(14126,'Greenwood','Greenwood, Indiana',17728,18);
INSERT INTO "django_geo_db_city" VALUES(14127,'Gwynneville','Gwynneville, Indiana',17730,18);
INSERT INTO "django_geo_db_city" VALUES(14128,'Homer','Homer, Indiana',17732,18);
INSERT INTO "django_geo_db_city" VALUES(14129,'Jamestown','Jamestown, Indiana',17733,18);
INSERT INTO "django_geo_db_city" VALUES(14130,'Knightstown','Knightstown, Indiana',17734,18);
INSERT INTO "django_geo_db_city" VALUES(14131,'Lizton','Lizton, Indiana',17735,18);
INSERT INTO "django_geo_db_city" VALUES(14132,'Manilla','Manilla, Indiana',17736,18);
INSERT INTO "django_geo_db_city" VALUES(14133,'Martinsville','Martinsville, Indiana',17737,18);
INSERT INTO "django_geo_db_city" VALUES(14134,'Maxwell','Maxwell, Indiana',17738,18);
INSERT INTO "django_geo_db_city" VALUES(14135,'Mays','Mays, Indiana',17739,18);
INSERT INTO "django_geo_db_city" VALUES(14136,'Milroy','Milroy, Indiana',17740,18);
INSERT INTO "django_geo_db_city" VALUES(14137,'Monrovia','Monrovia, Indiana',17741,18);
INSERT INTO "django_geo_db_city" VALUES(14138,'Mooresville','Mooresville, Indiana',17742,18);
INSERT INTO "django_geo_db_city" VALUES(14139,'Morgantown','Morgantown, Indiana',17743,18);
INSERT INTO "django_geo_db_city" VALUES(14140,'Morristown','Morristown, Indiana',17744,18);
INSERT INTO "django_geo_db_city" VALUES(14141,'Needham','Needham, Indiana',17745,18);
INSERT INTO "django_geo_db_city" VALUES(14142,'New Palestine','New Palestine, Indiana',17746,18);
INSERT INTO "django_geo_db_city" VALUES(14143,'Nineveh','Nineveh, Indiana',17747,18);
INSERT INTO "django_geo_db_city" VALUES(14144,'North Salem','North Salem, Indiana',17748,18);
INSERT INTO "django_geo_db_city" VALUES(14145,'Paragon','Paragon, Indiana',17749,18);
INSERT INTO "django_geo_db_city" VALUES(14146,'Pittsboro','Pittsboro, Indiana',17750,18);
INSERT INTO "django_geo_db_city" VALUES(14147,'Plainfield','Plainfield, Indiana',17751,18);
INSERT INTO "django_geo_db_city" VALUES(14148,'Putnamville','Putnamville, Indiana',17752,18);
INSERT INTO "django_geo_db_city" VALUES(14149,'Reelsville','Reelsville, Indiana',17753,18);
INSERT INTO "django_geo_db_city" VALUES(14150,'Roachdale','Roachdale, Indiana',17754,18);
INSERT INTO "django_geo_db_city" VALUES(14151,'Rushville','Rushville, Indiana',17755,18);
INSERT INTO "django_geo_db_city" VALUES(14152,'Russellville','Russellville, Indiana',17756,18);
INSERT INTO "django_geo_db_city" VALUES(14153,'Shelbyville','Shelbyville, Indiana',17757,18);
INSERT INTO "django_geo_db_city" VALUES(14154,'Stilesville','Stilesville, Indiana',17758,18);
INSERT INTO "django_geo_db_city" VALUES(14155,'Trafalgar','Trafalgar, Indiana',17759,18);
INSERT INTO "django_geo_db_city" VALUES(14156,'Waldron','Waldron, Indiana',17760,18);
INSERT INTO "django_geo_db_city" VALUES(14157,'West Newton','West Newton, Indiana',17761,18);
INSERT INTO "django_geo_db_city" VALUES(14158,'Whiteland','Whiteland, Indiana',17762,18);
INSERT INTO "django_geo_db_city" VALUES(14159,'Wilkinson','Wilkinson, Indiana',17763,18);
INSERT INTO "django_geo_db_city" VALUES(14160,'Indianapolis','Indianapolis, Indiana',17764,18);
INSERT INTO "django_geo_db_city" VALUES(14161,'Washington','Washington, Indiana',17795,18);
INSERT INTO "django_geo_db_city" VALUES(14162,'Beverly Shores','Beverly Shores, Indiana',17806,18);
INSERT INTO "django_geo_db_city" VALUES(14163,'Boone Grove','Boone Grove, Indiana',17807,18);
INSERT INTO "django_geo_db_city" VALUES(14164,'Cedar Lake','Cedar Lake, Indiana',17808,18);
INSERT INTO "django_geo_db_city" VALUES(14165,'Chesterton','Chesterton, Indiana',17809,18);
INSERT INTO "django_geo_db_city" VALUES(14166,'Granger','Granger, Indiana',17810,18);
INSERT INTO "django_geo_db_city" VALUES(14167,'Crown Point','Crown Point, Indiana',17811,18);
INSERT INTO "django_geo_db_city" VALUES(14168,'Demotte','Demotte, Indiana',17813,18);
INSERT INTO "django_geo_db_city" VALUES(14169,'Dyer','Dyer, Indiana',17814,18);
INSERT INTO "django_geo_db_city" VALUES(14170,'East Chicago','East Chicago, Indiana',17815,18);
INSERT INTO "django_geo_db_city" VALUES(14171,'Griffith','Griffith, Indiana',17816,18);
INSERT INTO "django_geo_db_city" VALUES(14172,'Hammond','Hammond, Indiana',17817,18);
INSERT INTO "django_geo_db_city" VALUES(14173,'Munster','Munster, Indiana',17818,18);
INSERT INTO "django_geo_db_city" VALUES(14174,'Highland','Highland, Indiana',17819,18);
INSERT INTO "django_geo_db_city" VALUES(14175,'Hanna','Hanna, Indiana',17824,18);
INSERT INTO "django_geo_db_city" VALUES(14176,'Hebron','Hebron, Indiana',17825,18);
INSERT INTO "django_geo_db_city" VALUES(14177,'Hobart','Hobart, Indiana',17826,18);
INSERT INTO "django_geo_db_city" VALUES(14178,'Kingsbury','Kingsbury, Indiana',17827,18);
INSERT INTO "django_geo_db_city" VALUES(14179,'Kingsford Heights','Kingsford Heights, Indiana',17828,18);
INSERT INTO "django_geo_db_city" VALUES(14180,'Kouts','Kouts, Indiana',17829,18);
INSERT INTO "django_geo_db_city" VALUES(14181,'La Crosse','La Crosse, Indiana',17830,18);
INSERT INTO "django_geo_db_city" VALUES(14182,'Lake Village','Lake Village, Indiana',17831,18);
INSERT INTO "django_geo_db_city" VALUES(14183,'La Porte','La Porte, Indiana',17832,18);
INSERT INTO "django_geo_db_city" VALUES(14184,'Leroy','Leroy, Indiana',17834,18);
INSERT INTO "django_geo_db_city" VALUES(14185,'Lowell','Lowell, Indiana',17835,18);
INSERT INTO "django_geo_db_city" VALUES(14186,'Michigan City','Michigan City, Indiana',17836,18);
INSERT INTO "django_geo_db_city" VALUES(14187,'Mill Creek','Mill Creek, Indiana',17838,18);
INSERT INTO "django_geo_db_city" VALUES(14188,'North Judson','North Judson, Indiana',17839,18);
INSERT INTO "django_geo_db_city" VALUES(14189,'Portage','Portage, Indiana',17840,18);
INSERT INTO "django_geo_db_city" VALUES(14190,'Russiaville','Russiaville, Indiana',17841,18);
INSERT INTO "django_geo_db_city" VALUES(14191,'Rolling Prairie','Rolling Prairie, Indiana',17842,18);
INSERT INTO "django_geo_db_city" VALUES(14192,'Roselawn','Roselawn, Indiana',17843,18);
INSERT INTO "django_geo_db_city" VALUES(14193,'Saint John','Saint John, Indiana',17844,18);
INSERT INTO "django_geo_db_city" VALUES(14194,'San Pierre','San Pierre, Indiana',17845,18);
INSERT INTO "django_geo_db_city" VALUES(14195,'Schererville','Schererville, Indiana',17846,18);
INSERT INTO "django_geo_db_city" VALUES(14196,'Schneider','Schneider, Indiana',17847,18);
INSERT INTO "django_geo_db_city" VALUES(14197,'Shelby','Shelby, Indiana',17848,18);
INSERT INTO "django_geo_db_city" VALUES(14198,'Sumava Resorts','Sumava Resorts, Indiana',17849,18);
INSERT INTO "django_geo_db_city" VALUES(14199,'Tefft','Tefft, Indiana',17850,18);
INSERT INTO "django_geo_db_city" VALUES(14200,'Thayer','Thayer, Indiana',17851,18);
INSERT INTO "django_geo_db_city" VALUES(14201,'Union Mills','Union Mills, Indiana',17852,18);
INSERT INTO "django_geo_db_city" VALUES(14202,'Valparaiso','Valparaiso, Indiana',17853,18);
INSERT INTO "django_geo_db_city" VALUES(14203,'Porter','Porter, Indiana',17856,18);
INSERT INTO "django_geo_db_city" VALUES(14204,'Wanatah','Wanatah, Indiana',17857,18);
INSERT INTO "django_geo_db_city" VALUES(14205,'Westville','Westville, Indiana',17858,18);
INSERT INTO "django_geo_db_city" VALUES(14206,'Wheatfield','Wheatfield, Indiana',17859,18);
INSERT INTO "django_geo_db_city" VALUES(14207,'Wheeler','Wheeler, Indiana',17860,18);
INSERT INTO "django_geo_db_city" VALUES(14208,'Whiting','Whiting, Indiana',17861,18);
INSERT INTO "django_geo_db_city" VALUES(14209,'Gary','Gary, Indiana',17862,18);
INSERT INTO "django_geo_db_city" VALUES(14210,'Lake Station','Lake Station, Indiana',17866,18);
INSERT INTO "django_geo_db_city" VALUES(14211,'Merrillville','Merrillville, Indiana',17871,18);
INSERT INTO "django_geo_db_city" VALUES(14212,'Burlington','Burlington, Indiana',17872,18);
INSERT INTO "django_geo_db_city" VALUES(14213,'Argos','Argos, Indiana',17873,18);
INSERT INTO "django_geo_db_city" VALUES(14214,'Atwood','Atwood, Indiana',17874,18);
INSERT INTO "django_geo_db_city" VALUES(14215,'Bourbon','Bourbon, Indiana',17875,18);
INSERT INTO "django_geo_db_city" VALUES(14216,'Bremen','Bremen, Indiana',17876,18);
INSERT INTO "django_geo_db_city" VALUES(14217,'Bristol','Bristol, Indiana',17877,18);
INSERT INTO "django_geo_db_city" VALUES(14218,'Burket','Burket, Indiana',17878,18);
INSERT INTO "django_geo_db_city" VALUES(14219,'Claypool','Claypool, Indiana',17879,18);
INSERT INTO "django_geo_db_city" VALUES(14220,'Culver','Culver, Indiana',17880,18);
INSERT INTO "django_geo_db_city" VALUES(14221,'Donaldson','Donaldson, Indiana',17881,18);
INSERT INTO "django_geo_db_city" VALUES(14222,'Elkhart','Elkhart, Indiana',17882,18);
INSERT INTO "django_geo_db_city" VALUES(14223,'Madison','Madison, Indiana',17886,18);
INSERT INTO "django_geo_db_city" VALUES(14224,'Etna Green','Etna Green, Indiana',17887,18);
INSERT INTO "django_geo_db_city" VALUES(14225,'Goshen','Goshen, Indiana',17888,18);
INSERT INTO "django_geo_db_city" VALUES(14226,'Grovertown','Grovertown, Indiana',17892,18);
INSERT INTO "django_geo_db_city" VALUES(14227,'Hamlet','Hamlet, Indiana',17893,18);
INSERT INTO "django_geo_db_city" VALUES(14228,'Knox','Knox, Indiana',17894,18);
INSERT INTO "django_geo_db_city" VALUES(14229,'Lakeville','Lakeville, Indiana',17896,18);
INSERT INTO "django_geo_db_city" VALUES(14230,'Lapaz','Lapaz, Indiana',17897,18);
INSERT INTO "django_geo_db_city" VALUES(14231,'Leesburg','Leesburg, Indiana',17898,18);
INSERT INTO "django_geo_db_city" VALUES(14232,'Mentone','Mentone, Indiana',17899,18);
INSERT INTO "django_geo_db_city" VALUES(14233,'Middlebury','Middlebury, Indiana',17900,18);
INSERT INTO "django_geo_db_city" VALUES(14234,'Milford','Milford, Indiana',17901,18);
INSERT INTO "django_geo_db_city" VALUES(14235,'Millersburg','Millersburg, Indiana',17902,18);
INSERT INTO "django_geo_db_city" VALUES(14236,'Mishawaka','Mishawaka, Indiana',17903,18);
INSERT INTO "django_geo_db_city" VALUES(14237,'Nappanee','Nappanee, Indiana',17906,18);
INSERT INTO "django_geo_db_city" VALUES(14238,'New Carlisle','New Carlisle, Indiana',17907,18);
INSERT INTO "django_geo_db_city" VALUES(14239,'New Paris','New Paris, Indiana',17908,18);
INSERT INTO "django_geo_db_city" VALUES(14240,'North Liberty','North Liberty, Indiana',17909,18);
INSERT INTO "django_geo_db_city" VALUES(14241,'North Webster','North Webster, Indiana',17910,18);
INSERT INTO "django_geo_db_city" VALUES(14242,'Notre Dame','Notre Dame, Indiana',17911,18);
INSERT INTO "django_geo_db_city" VALUES(14243,'Osceola','Osceola, Indiana',17912,18);
INSERT INTO "django_geo_db_city" VALUES(14244,'Pierceton','Pierceton, Indiana',17913,18);
INSERT INTO "django_geo_db_city" VALUES(14245,'Plymouth','Plymouth, Indiana',17914,18);
INSERT INTO "django_geo_db_city" VALUES(14246,'Shipshewana','Shipshewana, Indiana',17915,18);
INSERT INTO "django_geo_db_city" VALUES(14247,'Sidney','Sidney, Indiana',17916,18);
INSERT INTO "django_geo_db_city" VALUES(14248,'Syracuse','Syracuse, Indiana',17917,18);
INSERT INTO "django_geo_db_city" VALUES(14249,'Tippecanoe','Tippecanoe, Indiana',17918,18);
INSERT INTO "django_geo_db_city" VALUES(14250,'Topeka','Topeka, Indiana',17919,18);
INSERT INTO "django_geo_db_city" VALUES(14251,'Tyner','Tyner, Indiana',17920,18);
INSERT INTO "django_geo_db_city" VALUES(14252,'Wakarusa','Wakarusa, Indiana',17921,18);
INSERT INTO "django_geo_db_city" VALUES(14253,'Walkerton','Walkerton, Indiana',17922,18);
INSERT INTO "django_geo_db_city" VALUES(14254,'Warsaw','Warsaw, Indiana',17923,18);
INSERT INTO "django_geo_db_city" VALUES(14255,'Winona Lake','Winona Lake, Indiana',17926,18);
INSERT INTO "django_geo_db_city" VALUES(14256,'Wyatt','Wyatt, Indiana',17927,18);
INSERT INTO "django_geo_db_city" VALUES(14257,'South Bend','South Bend, Indiana',17928,18);
INSERT INTO "django_geo_db_city" VALUES(14258,'Noble','Noble, Indiana',17945,18);
INSERT INTO "django_geo_db_city" VALUES(14259,'Albion','Albion, Indiana',17947,18);
INSERT INTO "django_geo_db_city" VALUES(14260,'Andrews','Andrews, Indiana',17948,18);
INSERT INTO "django_geo_db_city" VALUES(14261,'Angola','Angola, Indiana',17949,18);
INSERT INTO "django_geo_db_city" VALUES(14262,'Arcola','Arcola, Indiana',17950,18);
INSERT INTO "django_geo_db_city" VALUES(14263,'Ashley','Ashley, Indiana',17951,18);
INSERT INTO "django_geo_db_city" VALUES(14264,'Auburn','Auburn, Indiana',17952,18);
INSERT INTO "django_geo_db_city" VALUES(14265,'Avilla','Avilla, Indiana',17953,18);
INSERT INTO "django_geo_db_city" VALUES(14266,'Berne','Berne, Indiana',17954,18);
INSERT INTO "django_geo_db_city" VALUES(14267,'Bippus','Bippus, Indiana',17955,18);
INSERT INTO "django_geo_db_city" VALUES(14268,'Bluffton','Bluffton, Indiana',17956,18);
INSERT INTO "django_geo_db_city" VALUES(14269,'Brimfield','Brimfield, Indiana',17957,18);
INSERT INTO "django_geo_db_city" VALUES(14270,'Butler','Butler, Indiana',17958,18);
INSERT INTO "django_geo_db_city" VALUES(14271,'Churubusco','Churubusco, Indiana',17959,18);
INSERT INTO "django_geo_db_city" VALUES(14272,'Columbia City','Columbia City, Indiana',17960,18);
INSERT INTO "django_geo_db_city" VALUES(14273,'Corunna','Corunna, Indiana',17961,18);
INSERT INTO "django_geo_db_city" VALUES(14274,'Craigville','Craigville, Indiana',17962,18);
INSERT INTO "django_geo_db_city" VALUES(14275,'Cromwell','Cromwell, Indiana',17963,18);
INSERT INTO "django_geo_db_city" VALUES(14276,'Decatur','Decatur, Indiana',17964,18);
INSERT INTO "django_geo_db_city" VALUES(14277,'Fremont','Fremont, Indiana',17965,18);
INSERT INTO "django_geo_db_city" VALUES(14278,'Garrett','Garrett, Indiana',17966,18);
INSERT INTO "django_geo_db_city" VALUES(14279,'Geneva','Geneva, Indiana',17967,18);
INSERT INTO "django_geo_db_city" VALUES(14280,'Grabill','Grabill, Indiana',17968,18);
INSERT INTO "django_geo_db_city" VALUES(14281,'Hamilton','Hamilton, Indiana',17969,18);
INSERT INTO "django_geo_db_city" VALUES(14282,'Harlan','Harlan, Indiana',17970,18);
INSERT INTO "django_geo_db_city" VALUES(14283,'Hoagland','Hoagland, Indiana',17971,18);
INSERT INTO "django_geo_db_city" VALUES(14284,'Howe','Howe, Indiana',17972,18);
INSERT INTO "django_geo_db_city" VALUES(14285,'Hudson','Hudson, Indiana',17973,18);
INSERT INTO "django_geo_db_city" VALUES(14286,'Huntertown','Huntertown, Indiana',17974,18);
INSERT INTO "django_geo_db_city" VALUES(14287,'Huntington','Huntington, Indiana',17975,18);
INSERT INTO "django_geo_db_city" VALUES(14288,'Kendallville','Kendallville, Indiana',17976,18);
INSERT INTO "django_geo_db_city" VALUES(14289,'Keystone','Keystone, Indiana',17977,18);
INSERT INTO "django_geo_db_city" VALUES(14290,'Kimmell','Kimmell, Indiana',17978,18);
INSERT INTO "django_geo_db_city" VALUES(14291,'Lagrange','Lagrange, Indiana',17979,18);
INSERT INTO "django_geo_db_city" VALUES(14292,'Laotto','Laotto, Indiana',17980,18);
INSERT INTO "django_geo_db_city" VALUES(14293,'Larwill','Larwill, Indiana',17981,18);
INSERT INTO "django_geo_db_city" VALUES(14294,'Leo','Leo, Indiana',17982,18);
INSERT INTO "django_geo_db_city" VALUES(14295,'Liberty Center','Liberty Center, Indiana',17983,18);
INSERT INTO "django_geo_db_city" VALUES(14296,'Ligonier','Ligonier, Indiana',17984,18);
INSERT INTO "django_geo_db_city" VALUES(14297,'Linn Grove','Linn Grove, Indiana',17986,18);
INSERT INTO "django_geo_db_city" VALUES(14298,'Markle','Markle, Indiana',17987,18);
INSERT INTO "django_geo_db_city" VALUES(14299,'Mongo','Mongo, Indiana',17988,18);
INSERT INTO "django_geo_db_city" VALUES(14300,'Monroe','Monroe, Indiana',17989,18);
INSERT INTO "django_geo_db_city" VALUES(14301,'Monroeville','Monroeville, Indiana',17990,18);
INSERT INTO "django_geo_db_city" VALUES(14302,'New Haven','New Haven, Indiana',17991,18);
INSERT INTO "django_geo_db_city" VALUES(14303,'Orland','Orland, Indiana',17992,18);
INSERT INTO "django_geo_db_city" VALUES(14304,'Ossian','Ossian, Indiana',17993,18);
INSERT INTO "django_geo_db_city" VALUES(14305,'Petroleum','Petroleum, Indiana',17994,18);
INSERT INTO "django_geo_db_city" VALUES(14306,'Pleasant Lake','Pleasant Lake, Indiana',17995,18);
INSERT INTO "django_geo_db_city" VALUES(14307,'Pleasant Mills','Pleasant Mills, Indiana',17986,18);
INSERT INTO "django_geo_db_city" VALUES(14308,'Poneto','Poneto, Indiana',17996,18);
INSERT INTO "django_geo_db_city" VALUES(14309,'Preble','Preble, Indiana',17997,18);
INSERT INTO "django_geo_db_city" VALUES(14310,'Roanoke','Roanoke, Indiana',17998,18);
INSERT INTO "django_geo_db_city" VALUES(14311,'Rome City','Rome City, Indiana',17999,18);
INSERT INTO "django_geo_db_city" VALUES(14312,'Saint Joe','Saint Joe, Indiana',18000,18);
INSERT INTO "django_geo_db_city" VALUES(14313,'South Milford','South Milford, Indiana',18001,18);
INSERT INTO "django_geo_db_city" VALUES(14314,'South Whitley','South Whitley, Indiana',18002,18);
INSERT INTO "django_geo_db_city" VALUES(14315,'Spencerville','Spencerville, Indiana',18003,18);
INSERT INTO "django_geo_db_city" VALUES(14316,'Stroh','Stroh, Indiana',18004,18);
INSERT INTO "django_geo_db_city" VALUES(14317,'Uniondale','Uniondale, Indiana',18005,18);
INSERT INTO "django_geo_db_city" VALUES(14318,'Warren','Warren, Indiana',18006,18);
INSERT INTO "django_geo_db_city" VALUES(14319,'Waterloo','Waterloo, Indiana',18007,18);
INSERT INTO "django_geo_db_city" VALUES(14320,'Wawaka','Wawaka, Indiana',18008,18);
INSERT INTO "django_geo_db_city" VALUES(14321,'Wolcottville','Wolcottville, Indiana',18009,18);
INSERT INTO "django_geo_db_city" VALUES(14322,'Wolflake','Wolflake, Indiana',18010,18);
INSERT INTO "django_geo_db_city" VALUES(14323,'Woodburn','Woodburn, Indiana',18011,18);
INSERT INTO "django_geo_db_city" VALUES(14324,'Yoder','Yoder, Indiana',18012,18);
INSERT INTO "django_geo_db_city" VALUES(14325,'Zanesville','Zanesville, Indiana',18013,18);
INSERT INTO "django_geo_db_city" VALUES(14326,'Fort Wayne','Fort Wayne, Indiana',18014,18);
INSERT INTO "django_geo_db_city" VALUES(14327,'Kokomo','Kokomo, Indiana',18034,18);
INSERT INTO "django_geo_db_city" VALUES(14328,'Akron','Akron, Indiana',18037,18);
INSERT INTO "django_geo_db_city" VALUES(14329,'Amboy','Amboy, Indiana',18038,18);
INSERT INTO "django_geo_db_city" VALUES(14330,'Athens','Athens, Indiana',18039,18);
INSERT INTO "django_geo_db_city" VALUES(14331,'Bringhurst','Bringhurst, Indiana',18040,18);
INSERT INTO "django_geo_db_city" VALUES(14332,'Bunker Hill','Bunker Hill, Indiana',18041,18);
INSERT INTO "django_geo_db_city" VALUES(14333,'Burrows','Burrows, Indiana',18043,18);
INSERT INTO "django_geo_db_city" VALUES(14334,'Camden','Camden, Indiana',18044,18);
INSERT INTO "django_geo_db_city" VALUES(14335,'Converse','Converse, Indiana',18045,18);
INSERT INTO "django_geo_db_city" VALUES(14336,'Cutler','Cutler, Indiana',18046,18);
INSERT INTO "django_geo_db_city" VALUES(14337,'Deedsville','Deedsville, Indiana',18047,18);
INSERT INTO "django_geo_db_city" VALUES(14338,'Delong','Delong, Indiana',18039,18);
INSERT INTO "django_geo_db_city" VALUES(14339,'Delphi','Delphi, Indiana',18048,18);
INSERT INTO "django_geo_db_city" VALUES(14340,'Denver','Denver, Indiana',18049,18);
INSERT INTO "django_geo_db_city" VALUES(14341,'Fairmount','Fairmount, Indiana',18050,18);
INSERT INTO "django_geo_db_city" VALUES(14342,'Flora','Flora, Indiana',18051,18);
INSERT INTO "django_geo_db_city" VALUES(14343,'Fowlerton','Fowlerton, Indiana',18052,18);
INSERT INTO "django_geo_db_city" VALUES(14344,'Fulton','Fulton, Indiana',18053,18);
INSERT INTO "django_geo_db_city" VALUES(14345,'Galveston','Galveston, Indiana',18054,18);
INSERT INTO "django_geo_db_city" VALUES(14346,'Gas City','Gas City, Indiana',18055,18);
INSERT INTO "django_geo_db_city" VALUES(14347,'Grass Creek','Grass Creek, Indiana',18039,18);
INSERT INTO "django_geo_db_city" VALUES(14348,'Greentown','Greentown, Indiana',18056,18);
INSERT INTO "django_geo_db_city" VALUES(14349,'Hemlock','Hemlock, Indiana',18057,18);
INSERT INTO "django_geo_db_city" VALUES(14350,'Jonesboro','Jonesboro, Indiana',18058,18);
INSERT INTO "django_geo_db_city" VALUES(14351,'Kewanna','Kewanna, Indiana',18059,18);
INSERT INTO "django_geo_db_city" VALUES(14352,'La Fontaine','La Fontaine, Indiana',18060,18);
INSERT INTO "django_geo_db_city" VALUES(14353,'Lagro','Lagro, Indiana',18061,18);
INSERT INTO "django_geo_db_city" VALUES(14354,'Lake Cicott','Lake Cicott, Indiana',18062,18);
INSERT INTO "django_geo_db_city" VALUES(14355,'Laketon','Laketon, Indiana',18063,18);
INSERT INTO "django_geo_db_city" VALUES(14356,'Leiters Ford','Leiters Ford, Indiana',18039,18);
INSERT INTO "django_geo_db_city" VALUES(14357,'Liberty Mills','Liberty Mills, Indiana',18064,18);
INSERT INTO "django_geo_db_city" VALUES(14358,'Logansport','Logansport, Indiana',18065,18);
INSERT INTO "django_geo_db_city" VALUES(14359,'Lucerne','Lucerne, Indiana',18066,18);
INSERT INTO "django_geo_db_city" VALUES(14360,'Macy','Macy, Indiana',18067,18);
INSERT INTO "django_geo_db_city" VALUES(14361,'Marion','Marion, Indiana',18068,18);
INSERT INTO "django_geo_db_city" VALUES(14362,'Matthews','Matthews, Indiana',18070,18);
INSERT INTO "django_geo_db_city" VALUES(14363,'Mexico','Mexico, Indiana',18071,18);
INSERT INTO "django_geo_db_city" VALUES(14364,'Miami','Miami, Indiana',18072,18);
INSERT INTO "django_geo_db_city" VALUES(14365,'Monterey','Monterey, Indiana',18073,18);
INSERT INTO "django_geo_db_city" VALUES(14366,'New Waverly','New Waverly, Indiana',18074,18);
INSERT INTO "django_geo_db_city" VALUES(14367,'North Manchester','North Manchester, Indiana',18075,18);
INSERT INTO "django_geo_db_city" VALUES(14368,'Oakford','Oakford, Indiana',18076,18);
INSERT INTO "django_geo_db_city" VALUES(14369,'Harrison','Harrison, Indiana',18077,18);
INSERT INTO "django_geo_db_city" VALUES(14370,'Onward','Onward, Indiana',18078,18);
INSERT INTO "django_geo_db_city" VALUES(14371,'Ora','Ora, Indiana',18079,18);
INSERT INTO "django_geo_db_city" VALUES(14372,'Peru','Peru, Indiana',18080,18);
INSERT INTO "django_geo_db_city" VALUES(14373,'Grissom AFB','Grissom AFB, Indiana',18081,18);
INSERT INTO "django_geo_db_city" VALUES(14374,'Roann','Roann, Indiana',18082,18);
INSERT INTO "django_geo_db_city" VALUES(14375,'Rochester','Rochester, Indiana',18083,18);
INSERT INTO "django_geo_db_city" VALUES(14376,'Rockfield','Rockfield, Indiana',18043,18);
INSERT INTO "django_geo_db_city" VALUES(14377,'Royal Center','Royal Center, Indiana',18084,18);
INSERT INTO "django_geo_db_city" VALUES(14378,'Servia','Servia, Indiana',18086,18);
INSERT INTO "django_geo_db_city" VALUES(14379,'Silver Lake','Silver Lake, Indiana',18087,18);
INSERT INTO "django_geo_db_city" VALUES(14380,'Somerset','Somerset, Indiana',18088,18);
INSERT INTO "django_geo_db_city" VALUES(14381,'Star City','Star City, Indiana',18089,18);
INSERT INTO "django_geo_db_city" VALUES(14382,'Swayzee','Swayzee, Indiana',18090,18);
INSERT INTO "django_geo_db_city" VALUES(14383,'Sweetser','Sweetser, Indiana',18091,18);
INSERT INTO "django_geo_db_city" VALUES(14384,'Twelve Mile','Twelve Mile, Indiana',18092,18);
INSERT INTO "django_geo_db_city" VALUES(14385,'Upland','Upland, Indiana',18093,18);
INSERT INTO "django_geo_db_city" VALUES(14386,'Urbana','Urbana, Indiana',18094,18);
INSERT INTO "django_geo_db_city" VALUES(14387,'Van Buren','Van Buren, Indiana',18095,18);
INSERT INTO "django_geo_db_city" VALUES(14388,'Wabash','Wabash, Indiana',18096,18);
INSERT INTO "django_geo_db_city" VALUES(14389,'Walton','Walton, Indiana',18097,18);
INSERT INTO "django_geo_db_city" VALUES(14390,'West Middleton','West Middleton, Indiana',18098,18);
INSERT INTO "django_geo_db_city" VALUES(14391,'Winamac','Winamac, Indiana',18099,18);
INSERT INTO "django_geo_db_city" VALUES(14392,'Young America','Young America, Indiana',18100,18);
INSERT INTO "django_geo_db_city" VALUES(14393,'Aurora','Aurora, Indiana',18101,18);
INSERT INTO "django_geo_db_city" VALUES(14394,'West College Corner','West College Corner, Indiana',18102,18);
INSERT INTO "django_geo_db_city" VALUES(14395,'Batesville','Batesville, Indiana',18103,18);
INSERT INTO "django_geo_db_city" VALUES(14396,'Bath','Bath, Indiana',18104,18);
INSERT INTO "django_geo_db_city" VALUES(14397,'Bennington','Bennington, Indiana',18105,18);
INSERT INTO "django_geo_db_city" VALUES(14398,'Brookville','Brookville, Indiana',18106,18);
INSERT INTO "django_geo_db_city" VALUES(14399,'Cedar Grove','Cedar Grove, Indiana',18107,18);
INSERT INTO "django_geo_db_city" VALUES(14400,'Cross Plains','Cross Plains, Indiana',18108,18);
INSERT INTO "django_geo_db_city" VALUES(14401,'Dillsboro','Dillsboro, Indiana',18109,18);
INSERT INTO "django_geo_db_city" VALUES(14402,'East Enterprise','East Enterprise, Indiana',18110,18);
INSERT INTO "django_geo_db_city" VALUES(14403,'Florence','Florence, Indiana',18111,18);
INSERT INTO "django_geo_db_city" VALUES(14404,'Friendship','Friendship, Indiana',18112,18);
INSERT INTO "django_geo_db_city" VALUES(14405,'Guilford','Guilford, Indiana',18113,18);
INSERT INTO "django_geo_db_city" VALUES(14406,'Holton','Holton, Indiana',18114,18);
INSERT INTO "django_geo_db_city" VALUES(14407,'Laurel','Laurel, Indiana',18115,18);
INSERT INTO "django_geo_db_city" VALUES(14408,'Lawrenceburg','Lawrenceburg, Indiana',18116,18);
INSERT INTO "django_geo_db_city" VALUES(14409,'Metamora','Metamora, Indiana',18117,18);
INSERT INTO "django_geo_db_city" VALUES(14410,'Milan','Milan, Indiana',18118,18);
INSERT INTO "django_geo_db_city" VALUES(14411,'Moores Hill','Moores Hill, Indiana',18119,18);
INSERT INTO "django_geo_db_city" VALUES(14412,'Morris','Morris, Indiana',18120,18);
INSERT INTO "django_geo_db_city" VALUES(14413,'Napoleon','Napoleon, Indiana',18121,18);
INSERT INTO "django_geo_db_city" VALUES(14414,'New Trenton','New Trenton, Indiana',18122,18);
INSERT INTO "django_geo_db_city" VALUES(14415,'Oldenburg','Oldenburg, Indiana',18123,18);
INSERT INTO "django_geo_db_city" VALUES(14416,'Osgood','Osgood, Indiana',18124,18);
INSERT INTO "django_geo_db_city" VALUES(14417,'Patriot','Patriot, Indiana',18125,18);
INSERT INTO "django_geo_db_city" VALUES(14418,'Pierceville','Pierceville, Indiana',18126,18);
INSERT INTO "django_geo_db_city" VALUES(14419,'Rising Sun','Rising Sun, Indiana',18127,18);
INSERT INTO "django_geo_db_city" VALUES(14420,'Sunman','Sunman, Indiana',18128,18);
INSERT INTO "django_geo_db_city" VALUES(14421,'Versailles','Versailles, Indiana',18129,18);
INSERT INTO "django_geo_db_city" VALUES(14422,'Vevay','Vevay, Indiana',18130,18);
INSERT INTO "django_geo_db_city" VALUES(14423,'Jefferson','Jefferson, Indiana',18131,18);
INSERT INTO "django_geo_db_city" VALUES(14424,'Bloomington','Bloomington, Indiana',18132,18);
INSERT INTO "django_geo_db_city" VALUES(14425,'West Harrison','West Harrison, Indiana',18133,18);
INSERT INTO "django_geo_db_city" VALUES(14426,'Lovett','Lovett, Indiana',18134,18);
INSERT INTO "django_geo_db_city" VALUES(14427,'Austin','Austin, Indiana',18136,18);
INSERT INTO "django_geo_db_city" VALUES(14428,'Bethlehem','Bethlehem, Indiana',18137,18);
INSERT INTO "django_geo_db_city" VALUES(14429,'Borden','Borden, Indiana',18138,18);
INSERT INTO "django_geo_db_city" VALUES(14430,'Bradford','Bradford, Indiana',18139,18);
INSERT INTO "django_geo_db_city" VALUES(14431,'Campbellsburg','Campbellsburg, Indiana',18140,18);
INSERT INTO "django_geo_db_city" VALUES(14432,'Central','Central, Indiana',18141,18);
INSERT INTO "django_geo_db_city" VALUES(14433,'Charlestown','Charlestown, Indiana',18142,18);
INSERT INTO "django_geo_db_city" VALUES(14434,'Corydon','Corydon, Indiana',18143,18);
INSERT INTO "django_geo_db_city" VALUES(14435,'Crandall','Crandall, Indiana',18144,18);
INSERT INTO "django_geo_db_city" VALUES(14436,'Depauw','Depauw, Indiana',18145,18);
INSERT INTO "django_geo_db_city" VALUES(14437,'Eckerty','Eckerty, Indiana',18146,18);
INSERT INTO "django_geo_db_city" VALUES(14438,'Elizabeth','Elizabeth, Indiana',18147,18);
INSERT INTO "django_geo_db_city" VALUES(14439,'English','English, Indiana',18148,18);
INSERT INTO "django_geo_db_city" VALUES(14440,'Floyds Knobs','Floyds Knobs, Indiana',18149,18);
INSERT INTO "django_geo_db_city" VALUES(14441,'Fredericksburg','Fredericksburg, Indiana',18150,18);
INSERT INTO "django_geo_db_city" VALUES(14442,'Georgetown','Georgetown, Indiana',18151,18);
INSERT INTO "django_geo_db_city" VALUES(14443,'Grantsburg','Grantsburg, Indiana',18152,18);
INSERT INTO "django_geo_db_city" VALUES(14444,'Greenville','Greenville, Indiana',18153,18);
INSERT INTO "django_geo_db_city" VALUES(14445,'Hardinsburg','Hardinsburg, Indiana',18154,18);
INSERT INTO "django_geo_db_city" VALUES(14446,'Henryville','Henryville, Indiana',18155,18);
INSERT INTO "django_geo_db_city" VALUES(14447,'Clarksville','Clarksville, Indiana',18157,18);
INSERT INTO "django_geo_db_city" VALUES(14448,'Jeffersonville','Jeffersonville, Indiana',18158,18);
INSERT INTO "django_geo_db_city" VALUES(14449,'Laconia','Laconia, Indiana',18161,18);
INSERT INTO "django_geo_db_city" VALUES(14450,'Lanesville','Lanesville, Indiana',18162,18);
INSERT INTO "django_geo_db_city" VALUES(14451,'Leavenworth','Leavenworth, Indiana',18163,18);
INSERT INTO "django_geo_db_city" VALUES(14452,'Lexington','Lexington, Indiana',18164,18);
INSERT INTO "django_geo_db_city" VALUES(14453,'Little York','Little York, Indiana',18165,18);
INSERT INTO "django_geo_db_city" VALUES(14454,'Marengo','Marengo, Indiana',18166,18);
INSERT INTO "django_geo_db_city" VALUES(14455,'Marysville','Marysville, Indiana',18167,18);
INSERT INTO "django_geo_db_city" VALUES(14456,'Mauckport','Mauckport, Indiana',18168,18);
INSERT INTO "django_geo_db_city" VALUES(14457,'Memphis','Memphis, Indiana',18169,18);
INSERT INTO "django_geo_db_city" VALUES(14458,'Milltown','Milltown, Indiana',18170,18);
INSERT INTO "django_geo_db_city" VALUES(14459,'Mount Saint Francis','Mount Saint Francis, Indiana',18171,18);
INSERT INTO "django_geo_db_city" VALUES(14460,'Nabb','Nabb, Indiana',18172,18);
INSERT INTO "django_geo_db_city" VALUES(14461,'New Albany','New Albany, Indiana',18173,18);
INSERT INTO "django_geo_db_city" VALUES(14462,'New Middletown','New Middletown, Indiana',18174,18);
INSERT INTO "django_geo_db_city" VALUES(14463,'New Salisbury','New Salisbury, Indiana',18175,18);
INSERT INTO "django_geo_db_city" VALUES(14464,'New Washington','New Washington, Indiana',18176,18);
INSERT INTO "django_geo_db_city" VALUES(14465,'Otisco','Otisco, Indiana',18177,18);
INSERT INTO "django_geo_db_city" VALUES(14466,'Palmyra','Palmyra, Indiana',18178,18);
INSERT INTO "django_geo_db_city" VALUES(14467,'Pekin','Pekin, Indiana',18179,18);
INSERT INTO "django_geo_db_city" VALUES(14468,'Ramsey','Ramsey, Indiana',18180,18);
INSERT INTO "django_geo_db_city" VALUES(14469,'Salem','Salem, Indiana',18181,18);
INSERT INTO "django_geo_db_city" VALUES(14470,'Scottsburg','Scottsburg, Indiana',18183,18);
INSERT INTO "django_geo_db_city" VALUES(14471,'Sellersburg','Sellersburg, Indiana',18184,18);
INSERT INTO "django_geo_db_city" VALUES(14472,'Sulphur','Sulphur, Indiana',18185,18);
INSERT INTO "django_geo_db_city" VALUES(14473,'Taswell','Taswell, Indiana',18186,18);
INSERT INTO "django_geo_db_city" VALUES(14474,'Underwood','Underwood, Indiana',18187,18);
INSERT INTO "django_geo_db_city" VALUES(14475,'Columbus','Columbus, Indiana',18188,18);
INSERT INTO "django_geo_db_city" VALUES(14476,'Brownstown','Brownstown, Indiana',18191,18);
INSERT INTO "django_geo_db_city" VALUES(14477,'Butlerville','Butlerville, Indiana',18192,18);
INSERT INTO "django_geo_db_city" VALUES(14478,'Canaan','Canaan, Indiana',18193,18);
INSERT INTO "django_geo_db_city" VALUES(14479,'Clarksburg','Clarksburg, Indiana',18194,18);
INSERT INTO "django_geo_db_city" VALUES(14480,'Clifford','Clifford, Indiana',18195,18);
INSERT INTO "django_geo_db_city" VALUES(14481,'Commiskey','Commiskey, Indiana',18196,18);
INSERT INTO "django_geo_db_city" VALUES(14482,'Cortland','Cortland, Indiana',18197,18);
INSERT INTO "django_geo_db_city" VALUES(14483,'Crothersville','Crothersville, Indiana',18198,18);
INSERT INTO "django_geo_db_city" VALUES(14484,'Deputy','Deputy, Indiana',18199,18);
INSERT INTO "django_geo_db_city" VALUES(14485,'Dupont','Dupont, Indiana',18200,18);
INSERT INTO "django_geo_db_city" VALUES(14486,'Elizabethtown','Elizabethtown, Indiana',18201,18);
INSERT INTO "django_geo_db_city" VALUES(14487,'Flat Rock','Flat Rock, Indiana',18202,18);
INSERT INTO "django_geo_db_city" VALUES(14488,'Freetown','Freetown, Indiana',18203,18);
INSERT INTO "django_geo_db_city" VALUES(14489,'Grammer','Grammer, Indiana',18204,18);
INSERT INTO "django_geo_db_city" VALUES(14490,'Greensburg','Greensburg, Indiana',18205,18);
INSERT INTO "django_geo_db_city" VALUES(14491,'Bedford','Bedford, Indiana',18206,18);
INSERT INTO "django_geo_db_city" VALUES(14492,'Hanover','Hanover, Indiana',18207,18);
INSERT INTO "django_geo_db_city" VALUES(14493,'Hartsville','Hartsville, Indiana',18208,18);
INSERT INTO "django_geo_db_city" VALUES(14494,'Hayden','Hayden, Indiana',18209,18);
INSERT INTO "django_geo_db_city" VALUES(14495,'Hope','Hope, Indiana',18210,18);
INSERT INTO "django_geo_db_city" VALUES(14496,'Jonesville','Jonesville, Indiana',18211,18);
INSERT INTO "django_geo_db_city" VALUES(14497,'Kurtz','Kurtz, Indiana',18212,18);
INSERT INTO "django_geo_db_city" VALUES(14498,'North Vernon','North Vernon, Indiana',18214,18);
INSERT INTO "django_geo_db_city" VALUES(14499,'Medora','Medora, Indiana',18216,18);
INSERT INTO "django_geo_db_city" VALUES(14500,'Millhousen','Millhousen, Indiana',18217,18);
INSERT INTO "django_geo_db_city" VALUES(14501,'Nebraska','Nebraska, Indiana',18209,18);
INSERT INTO "django_geo_db_city" VALUES(14502,'New Point','New Point, Indiana',18218,18);
INSERT INTO "django_geo_db_city" VALUES(14503,'Norman','Norman, Indiana',18219,18);
INSERT INTO "django_geo_db_city" VALUES(14504,'Paris Crossing','Paris Crossing, Indiana',18221,18);
INSERT INTO "django_geo_db_city" VALUES(14505,'Saint Paul','Saint Paul, Indiana',18222,18);
INSERT INTO "django_geo_db_city" VALUES(14506,'Scipio','Scipio, Indiana',18223,18);
INSERT INTO "django_geo_db_city" VALUES(14507,'Seymour','Seymour, Indiana',18224,18);
INSERT INTO "django_geo_db_city" VALUES(14508,'Taylorsville','Taylorsville, Indiana',18225,18);
INSERT INTO "django_geo_db_city" VALUES(14509,'Vallonia','Vallonia, Indiana',18226,18);
INSERT INTO "django_geo_db_city" VALUES(14510,'Vernon','Vernon, Indiana',18227,18);
INSERT INTO "django_geo_db_city" VALUES(14511,'Westport','Westport, Indiana',18228,18);
INSERT INTO "django_geo_db_city" VALUES(14512,'Cayuga','Cayuga, Indiana',18229,18);
INSERT INTO "django_geo_db_city" VALUES(14513,'Muncie','Muncie, Indiana',18230,18);
INSERT INTO "django_geo_db_city" VALUES(14514,'Kennard','Kennard, Indiana',18237,18);
INSERT INTO "django_geo_db_city" VALUES(14515,'Albany','Albany, Indiana',18238,18);
INSERT INTO "django_geo_db_city" VALUES(14516,'Bentonville','Bentonville, Indiana',18239,18);
INSERT INTO "django_geo_db_city" VALUES(14517,'Boston','Boston, Indiana',18240,18);
INSERT INTO "django_geo_db_city" VALUES(14518,'Brownsville','Brownsville, Indiana',18241,18);
INSERT INTO "django_geo_db_city" VALUES(14519,'Bryant','Bryant, Indiana',18242,18);
INSERT INTO "django_geo_db_city" VALUES(14520,'Cambridge City','Cambridge City, Indiana',18243,18);
INSERT INTO "django_geo_db_city" VALUES(14521,'Centerville','Centerville, Indiana',18244,18);
INSERT INTO "django_geo_db_city" VALUES(14522,'Connersville','Connersville, Indiana',18245,18);
INSERT INTO "django_geo_db_city" VALUES(14523,'Daleville','Daleville, Indiana',18246,18);
INSERT INTO "django_geo_db_city" VALUES(14524,'Dublin','Dublin, Indiana',18247,18);
INSERT INTO "django_geo_db_city" VALUES(14525,'Dunkirk','Dunkirk, Indiana',18248,18);
INSERT INTO "django_geo_db_city" VALUES(14526,'Dunreith','Dunreith, Indiana',18249,18);
INSERT INTO "django_geo_db_city" VALUES(14527,'Eaton','Eaton, Indiana',18250,18);
INSERT INTO "django_geo_db_city" VALUES(14528,'Economy','Economy, Indiana',18251,18);
INSERT INTO "django_geo_db_city" VALUES(14529,'Farmland','Farmland, Indiana',18252,18);
INSERT INTO "django_geo_db_city" VALUES(14530,'Fountain City','Fountain City, Indiana',18253,18);
INSERT INTO "django_geo_db_city" VALUES(14531,'Gaston','Gaston, Indiana',18254,18);
INSERT INTO "django_geo_db_city" VALUES(14532,'Greensboro','Greensboro, Indiana',18255,18);
INSERT INTO "django_geo_db_city" VALUES(14533,'Greens Fork','Greens Fork, Indiana',18256,18);
INSERT INTO "django_geo_db_city" VALUES(14534,'Hagerstown','Hagerstown, Indiana',18257,18);
INSERT INTO "django_geo_db_city" VALUES(14535,'Hartford City','Hartford City, Indiana',18258,18);
INSERT INTO "django_geo_db_city" VALUES(14536,'Lewisville','Lewisville, Indiana',18260,18);
INSERT INTO "django_geo_db_city" VALUES(14537,'Liberty','Liberty, Indiana',18261,18);
INSERT INTO "django_geo_db_city" VALUES(14538,'Losantville','Losantville, Indiana',18262,18);
INSERT INTO "django_geo_db_city" VALUES(14539,'Lynn','Lynn, Indiana',18263,18);
INSERT INTO "django_geo_db_city" VALUES(14540,'Middletown','Middletown, Indiana',18264,18);
INSERT INTO "django_geo_db_city" VALUES(14541,'Milton','Milton, Indiana',18265,18);
INSERT INTO "django_geo_db_city" VALUES(14542,'Modoc','Modoc, Indiana',18266,18);
INSERT INTO "django_geo_db_city" VALUES(14543,'Montpelier','Montpelier, Indiana',18267,18);
INSERT INTO "django_geo_db_city" VALUES(14544,'Mooreland','Mooreland, Indiana',18268,18);
INSERT INTO "django_geo_db_city" VALUES(14545,'Mount Summit','Mount Summit, Indiana',18269,18);
INSERT INTO "django_geo_db_city" VALUES(14546,'New Castle','New Castle, Indiana',18270,18);
INSERT INTO "django_geo_db_city" VALUES(14547,'New Lisbon','New Lisbon, Indiana',18271,18);
INSERT INTO "django_geo_db_city" VALUES(14548,'Oakville','Oakville, Indiana',18272,18);
INSERT INTO "django_geo_db_city" VALUES(14549,'Parker City','Parker City, Indiana',18273,18);
INSERT INTO "django_geo_db_city" VALUES(14550,'Pennville','Pennville, Indiana',18274,18);
INSERT INTO "django_geo_db_city" VALUES(14551,'Pershing','Pershing, Indiana',18275,18);
INSERT INTO "django_geo_db_city" VALUES(14552,'Portland','Portland, Indiana',18276,18);
INSERT INTO "django_geo_db_city" VALUES(14553,'Redkey','Redkey, Indiana',18277,18);
INSERT INTO "django_geo_db_city" VALUES(14554,'Richmond','Richmond, Indiana',18278,18);
INSERT INTO "django_geo_db_city" VALUES(14555,'Ridgeville','Ridgeville, Indiana',18280,18);
INSERT INTO "django_geo_db_city" VALUES(14556,'Salamonia','Salamonia, Indiana',18281,18);
INSERT INTO "django_geo_db_city" VALUES(14557,'Saratoga','Saratoga, Indiana',18282,18);
INSERT INTO "django_geo_db_city" VALUES(14558,'Selma','Selma, Indiana',18283,18);
INSERT INTO "django_geo_db_city" VALUES(14559,'Shirley','Shirley, Indiana',18284,18);
INSERT INTO "django_geo_db_city" VALUES(14560,'Spiceland','Spiceland, Indiana',18285,18);
INSERT INTO "django_geo_db_city" VALUES(14561,'Springport','Springport, Indiana',18286,18);
INSERT INTO "django_geo_db_city" VALUES(14562,'Straughn','Straughn, Indiana',18287,18);
INSERT INTO "django_geo_db_city" VALUES(14563,'Sulphur Springs','Sulphur Springs, Indiana',18288,18);
INSERT INTO "django_geo_db_city" VALUES(14564,'Union City','Union City, Indiana',18289,18);
INSERT INTO "django_geo_db_city" VALUES(14565,'Webster','Webster, Indiana',18290,18);
INSERT INTO "django_geo_db_city" VALUES(14566,'Williamsburg','Williamsburg, Indiana',18291,18);
INSERT INTO "django_geo_db_city" VALUES(14567,'Winchester','Winchester, Indiana',18292,18);
INSERT INTO "django_geo_db_city" VALUES(14568,'Yorktown','Yorktown, Indiana',18294,18);
INSERT INTO "django_geo_db_city" VALUES(14569,'Evansville','Evansville, Indiana',18303,18);
INSERT INTO "django_geo_db_city" VALUES(14570,'Avoca','Avoca, Indiana',18304,18);
INSERT INTO "django_geo_db_city" VALUES(14571,'Bloomfield','Bloomfield, Indiana',18306,18);
INSERT INTO "django_geo_db_city" VALUES(14572,'Clear Creek','Clear Creek, Indiana',18297,18);
INSERT INTO "django_geo_db_city" VALUES(14573,'Coal City','Coal City, Indiana',18307,18);
INSERT INTO "django_geo_db_city" VALUES(14574,'Ellettsville','Ellettsville, Indiana',18308,18);
INSERT INTO "django_geo_db_city" VALUES(14575,'Fort Ritner','Fort Ritner, Indiana',18309,18);
INSERT INTO "django_geo_db_city" VALUES(14576,'Freedom','Freedom, Indiana',18310,18);
INSERT INTO "django_geo_db_city" VALUES(14577,'French Lick','French Lick, Indiana',18311,18);
INSERT INTO "django_geo_db_city" VALUES(14578,'Gosport','Gosport, Indiana',18312,18);
INSERT INTO "django_geo_db_city" VALUES(14579,'Harrodsburg','Harrodsburg, Indiana',18313,18);
INSERT INTO "django_geo_db_city" VALUES(14580,'Helmsburg','Helmsburg, Indiana',18314,18);
INSERT INTO "django_geo_db_city" VALUES(14581,'Heltonville','Heltonville, Indiana',18315,18);
INSERT INTO "django_geo_db_city" VALUES(14582,'Huron','Huron, Indiana',18316,18);
INSERT INTO "django_geo_db_city" VALUES(14583,'Jasonville','Jasonville, Indiana',18317,18);
INSERT INTO "django_geo_db_city" VALUES(14584,'Koleen','Koleen, Indiana',18318,18);
INSERT INTO "django_geo_db_city" VALUES(14585,'Linton','Linton, Indiana',18319,18);
INSERT INTO "django_geo_db_city" VALUES(14586,'Lyons','Lyons, Indiana',18320,18);
INSERT INTO "django_geo_db_city" VALUES(14587,'Midland','Midland, Indiana',18321,18);
INSERT INTO "django_geo_db_city" VALUES(14588,'Mitchell','Mitchell, Indiana',18322,18);
INSERT INTO "django_geo_db_city" VALUES(14589,'Nashville','Nashville, Indiana',18323,18);
INSERT INTO "django_geo_db_city" VALUES(14590,'Newberry','Newberry, Indiana',18324,18);
INSERT INTO "django_geo_db_city" VALUES(14591,'Oolitic','Oolitic, Indiana',18325,18);
INSERT INTO "django_geo_db_city" VALUES(14592,'Orleans','Orleans, Indiana',18326,18);
INSERT INTO "django_geo_db_city" VALUES(14593,'Owensburg','Owensburg, Indiana',18327,18);
INSERT INTO "django_geo_db_city" VALUES(14594,'Paoli','Paoli, Indiana',18328,18);
INSERT INTO "django_geo_db_city" VALUES(14595,'Patricksburg','Patricksburg, Indiana',18329,18);
INSERT INTO "django_geo_db_city" VALUES(14596,'Quincy','Quincy, Indiana',18330,18);
INSERT INTO "django_geo_db_city" VALUES(14597,'Scotland','Scotland, Indiana',18318,18);
INSERT INTO "django_geo_db_city" VALUES(14598,'Smithville','Smithville, Indiana',18297,18);
INSERT INTO "django_geo_db_city" VALUES(14599,'Solsberry','Solsberry, Indiana',18331,18);
INSERT INTO "django_geo_db_city" VALUES(14600,'Spencer','Spencer, Indiana',18332,18);
INSERT INTO "django_geo_db_city" VALUES(14601,'Springville','Springville, Indiana',18333,18);
INSERT INTO "django_geo_db_city" VALUES(14602,'Stanford','Stanford, Indiana',18334,18);
INSERT INTO "django_geo_db_city" VALUES(14603,'Stinesville','Stinesville, Indiana',18335,18);
INSERT INTO "django_geo_db_city" VALUES(14604,'Switz City','Switz City, Indiana',18336,18);
INSERT INTO "django_geo_db_city" VALUES(14605,'Tunnelton','Tunnelton, Indiana',18337,18);
INSERT INTO "django_geo_db_city" VALUES(14606,'Unionville','Unionville, Indiana',18338,18);
INSERT INTO "django_geo_db_city" VALUES(14607,'West Baden Springs','West Baden Springs, Indiana',18339,18);
INSERT INTO "django_geo_db_city" VALUES(14608,'Williams','Williams, Indiana',18340,18);
INSERT INTO "django_geo_db_city" VALUES(14609,'Worthington','Worthington, Indiana',18341,18);
INSERT INTO "django_geo_db_city" VALUES(14610,'Lewis','Lewis, Indiana',18342,18);
INSERT INTO "django_geo_db_city" VALUES(14611,'Hamblen','Hamblen, Indiana',18343,18);
INSERT INTO "django_geo_db_city" VALUES(14612,'Bicknell','Bicknell, Indiana',18345,18);
INSERT INTO "django_geo_db_city" VALUES(14613,'Birdseye','Birdseye, Indiana',18346,18);
INSERT INTO "django_geo_db_city" VALUES(14614,'Branchville','Branchville, Indiana',18347,18);
INSERT INTO "django_geo_db_city" VALUES(14615,'Bristow','Bristow, Indiana',18348,18);
INSERT INTO "django_geo_db_city" VALUES(14616,'Bruceville','Bruceville, Indiana',18349,18);
INSERT INTO "django_geo_db_city" VALUES(14617,'Cannelburg','Cannelburg, Indiana',18350,18);
INSERT INTO "django_geo_db_city" VALUES(14618,'Cannelton','Cannelton, Indiana',18351,18);
INSERT INTO "django_geo_db_city" VALUES(14619,'Celestine','Celestine, Indiana',18352,18);
INSERT INTO "django_geo_db_city" VALUES(14620,'Crane','Crane, Indiana',18353,18);
INSERT INTO "django_geo_db_city" VALUES(14621,'Dale','Dale, Indiana',18354,18);
INSERT INTO "django_geo_db_city" VALUES(14622,'Decker','Decker, Indiana',18355,18);
INSERT INTO "django_geo_db_city" VALUES(14623,'Derby','Derby, Indiana',18356,18);
INSERT INTO "django_geo_db_city" VALUES(14624,'Dubois','Dubois, Indiana',18357,18);
INSERT INTO "django_geo_db_city" VALUES(14625,'Edwardsport','Edwardsport, Indiana',18358,18);
INSERT INTO "django_geo_db_city" VALUES(14626,'Elnora','Elnora, Indiana',18359,18);
INSERT INTO "django_geo_db_city" VALUES(14627,'Evanston','Evanston, Indiana',18360,18);
INSERT INTO "django_geo_db_city" VALUES(14628,'Ferdinand','Ferdinand, Indiana',18361,18);
INSERT INTO "django_geo_db_city" VALUES(14629,'Freelandville','Freelandville, Indiana',18362,18);
INSERT INTO "django_geo_db_city" VALUES(14630,'Fulda','Fulda, Indiana',18363,18);
INSERT INTO "django_geo_db_city" VALUES(14631,'Gentryville','Gentryville, Indiana',18364,18);
INSERT INTO "django_geo_db_city" VALUES(14632,'Holland','Holland, Indiana',18365,18);
INSERT INTO "django_geo_db_city" VALUES(14633,'Huntingburg','Huntingburg, Indiana',18366,18);
INSERT INTO "django_geo_db_city" VALUES(14634,'Ireland','Ireland, Indiana',18367,18);
INSERT INTO "django_geo_db_city" VALUES(14635,'Jasper','Jasper, Indiana',18368,18);
INSERT INTO "django_geo_db_city" VALUES(14636,'Lamar','Lamar, Indiana',18370,18);
INSERT INTO "django_geo_db_city" VALUES(14637,'Leopold','Leopold, Indiana',18371,18);
INSERT INTO "django_geo_db_city" VALUES(14638,'Lincoln City','Lincoln City, Indiana',18372,18);
INSERT INTO "django_geo_db_city" VALUES(14639,'Loogootee','Loogootee, Indiana',18373,18);
INSERT INTO "django_geo_db_city" VALUES(14640,'Mariah Hill','Mariah Hill, Indiana',18374,18);
INSERT INTO "django_geo_db_city" VALUES(14641,'Monroe City','Monroe City, Indiana',18375,18);
INSERT INTO "django_geo_db_city" VALUES(14642,'Montgomery','Montgomery, Indiana',18376,18);
INSERT INTO "django_geo_db_city" VALUES(14643,'Oaktown','Oaktown, Indiana',18377,18);
INSERT INTO "django_geo_db_city" VALUES(14644,'Odon','Odon, Indiana',18378,18);
INSERT INTO "django_geo_db_city" VALUES(14645,'Otwell','Otwell, Indiana',18379,18);
INSERT INTO "django_geo_db_city" VALUES(14646,'Petersburg','Petersburg, Indiana',18380,18);
INSERT INTO "django_geo_db_city" VALUES(14647,'Plainville','Plainville, Indiana',18381,18);
INSERT INTO "django_geo_db_city" VALUES(14648,'Ragsdale','Ragsdale, Indiana',18382,18);
INSERT INTO "django_geo_db_city" VALUES(14649,'Rome','Rome, Indiana',18383,18);
INSERT INTO "django_geo_db_city" VALUES(14650,'Saint Anthony','Saint Anthony, Indiana',18384,18);
INSERT INTO "django_geo_db_city" VALUES(14651,'Saint Croix','Saint Croix, Indiana',18385,18);
INSERT INTO "django_geo_db_city" VALUES(14652,'Saint Meinrad','Saint Meinrad, Indiana',18386,18);
INSERT INTO "django_geo_db_city" VALUES(14653,'Sandborn','Sandborn, Indiana',18387,18);
INSERT INTO "django_geo_db_city" VALUES(14654,'Santa Claus','Santa Claus, Indiana',18388,18);
INSERT INTO "django_geo_db_city" VALUES(14655,'Schnellville','Schnellville, Indiana',18389,18);
INSERT INTO "django_geo_db_city" VALUES(14656,'Shoals','Shoals, Indiana',18390,18);
INSERT INTO "django_geo_db_city" VALUES(14657,'Spurgeon','Spurgeon, Indiana',18391,18);
INSERT INTO "django_geo_db_city" VALUES(14658,'Stendal','Stendal, Indiana',18392,18);
INSERT INTO "django_geo_db_city" VALUES(14659,'Tell City','Tell City, Indiana',18393,18);
INSERT INTO "django_geo_db_city" VALUES(14660,'Troy','Troy, Indiana',18394,18);
INSERT INTO "django_geo_db_city" VALUES(14661,'Velpen','Velpen, Indiana',18395,18);
INSERT INTO "django_geo_db_city" VALUES(14662,'Vincennes','Vincennes, Indiana',18396,18);
INSERT INTO "django_geo_db_city" VALUES(14663,'Westphalia','Westphalia, Indiana',18397,18);
INSERT INTO "django_geo_db_city" VALUES(14664,'Wheatland','Wheatland, Indiana',18398,18);
INSERT INTO "django_geo_db_city" VALUES(14665,'Winslow','Winslow, Indiana',18399,18);
INSERT INTO "django_geo_db_city" VALUES(14666,'Boonville','Boonville, Indiana',18400,18);
INSERT INTO "django_geo_db_city" VALUES(14667,'Chandler','Chandler, Indiana',18401,18);
INSERT INTO "django_geo_db_city" VALUES(14668,'Chrisney','Chrisney, Indiana',18402,18);
INSERT INTO "django_geo_db_city" VALUES(14669,'Cynthiana','Cynthiana, Indiana',18403,18);
INSERT INTO "django_geo_db_city" VALUES(14670,'Elberfeld','Elberfeld, Indiana',18404,18);
INSERT INTO "django_geo_db_city" VALUES(14671,'Folsomville','Folsomville, Indiana',18405,18);
INSERT INTO "django_geo_db_city" VALUES(14672,'Grandview','Grandview, Indiana',18406,18);
INSERT INTO "django_geo_db_city" VALUES(14673,'Griffin','Griffin, Indiana',18407,18);
INSERT INTO "django_geo_db_city" VALUES(14674,'Hatfield','Hatfield, Indiana',18408,18);
INSERT INTO "django_geo_db_city" VALUES(14675,'Inglefield','Inglefield, Indiana',18409,18);
INSERT INTO "django_geo_db_city" VALUES(14676,'Lynnville','Lynnville, Indiana',18410,18);
INSERT INTO "django_geo_db_city" VALUES(14677,'Mount Vernon','Mount Vernon, Indiana',18411,18);
INSERT INTO "django_geo_db_city" VALUES(14678,'Newburgh','Newburgh, Indiana',18413,18);
INSERT INTO "django_geo_db_city" VALUES(14679,'New Harmony','New Harmony, Indiana',18415,18);
INSERT INTO "django_geo_db_city" VALUES(14680,'Poseyville','Poseyville, Indiana',18416,18);
INSERT INTO "django_geo_db_city" VALUES(14681,'Richland','Richland, Indiana',18417,18);
INSERT INTO "django_geo_db_city" VALUES(14682,'Rockport','Rockport, Indiana',18418,18);
INSERT INTO "django_geo_db_city" VALUES(14683,'Tennyson','Tennyson, Indiana',18419,18);
INSERT INTO "django_geo_db_city" VALUES(14684,'Wadesville','Wadesville, Indiana',18420,18);
INSERT INTO "django_geo_db_city" VALUES(14685,'Haubstadt','Haubstadt, Indiana',18421,18);
INSERT INTO "django_geo_db_city" VALUES(14686,'Hazleton','Hazleton, Indiana',18422,18);
INSERT INTO "django_geo_db_city" VALUES(14687,'Buckskin','Buckskin, Indiana',18423,18);
INSERT INTO "django_geo_db_city" VALUES(14688,'Fort Branch','Fort Branch, Indiana',18424,18);
INSERT INTO "django_geo_db_city" VALUES(14689,'Francisco','Francisco, Indiana',18425,18);
INSERT INTO "django_geo_db_city" VALUES(14690,'Mackey','Mackey, Indiana',18426,18);
INSERT INTO "django_geo_db_city" VALUES(14691,'Oakland City','Oakland City, Indiana',18427,18);
INSERT INTO "django_geo_db_city" VALUES(14692,'Owensville','Owensville, Indiana',18428,18);
INSERT INTO "django_geo_db_city" VALUES(14693,'Patoka','Patoka, Indiana',18429,18);
INSERT INTO "django_geo_db_city" VALUES(14694,'Princeton','Princeton, Indiana',18431,18);
INSERT INTO "django_geo_db_city" VALUES(14695,'Oxford','Oxford, Indiana',18432,18);
INSERT INTO "django_geo_db_city" VALUES(14696,'Somerville','Somerville, Indiana',18434,18);
INSERT INTO "django_geo_db_city" VALUES(14697,'Jackson','Jackson, Indiana',18442,18);
INSERT INTO "django_geo_db_city" VALUES(14698,'Scott','Scott, Indiana',18448,18);
INSERT INTO "django_geo_db_city" VALUES(14699,'New Market','New Market, Indiana',18451,18);
INSERT INTO "django_geo_db_city" VALUES(14700,'Terre Haute','Terre Haute, Indiana',18452,18);
INSERT INTO "django_geo_db_city" VALUES(14701,'Bellmore','Bellmore, Indiana',18459,18);
INSERT INTO "django_geo_db_city" VALUES(14702,'Blanford','Blanford, Indiana',18460,18);
INSERT INTO "django_geo_db_city" VALUES(14703,'Bloomingdale','Bloomingdale, Indiana',18461,18);
INSERT INTO "django_geo_db_city" VALUES(14704,'Bowling Green','Bowling Green, Indiana',18462,18);
INSERT INTO "django_geo_db_city" VALUES(14705,'Brazil','Brazil, Indiana',18463,18);
INSERT INTO "django_geo_db_city" VALUES(14706,'Bridgeton','Bridgeton, Indiana',18464,18);
INSERT INTO "django_geo_db_city" VALUES(14707,'Carbon','Carbon, Indiana',18465,18);
INSERT INTO "django_geo_db_city" VALUES(14708,'Carlisle','Carlisle, Indiana',18466,18);
INSERT INTO "django_geo_db_city" VALUES(14709,'Centerpoint','Centerpoint, Indiana',18467,18);
INSERT INTO "django_geo_db_city" VALUES(14710,'Clay City','Clay City, Indiana',18468,18);
INSERT INTO "django_geo_db_city" VALUES(14711,'Clinton','Clinton, Indiana',18469,18);
INSERT INTO "django_geo_db_city" VALUES(14712,'Coalmont','Coalmont, Indiana',18470,18);
INSERT INTO "django_geo_db_city" VALUES(14713,'Cory','Cory, Indiana',18471,18);
INSERT INTO "django_geo_db_city" VALUES(14714,'Dana','Dana, Indiana',18472,18);
INSERT INTO "django_geo_db_city" VALUES(14715,'Dugger','Dugger, Indiana',18473,18);
INSERT INTO "django_geo_db_city" VALUES(14716,'Fairbanks','Fairbanks, Indiana',18474,18);
INSERT INTO "django_geo_db_city" VALUES(14717,'Farmersburg','Farmersburg, Indiana',18475,18);
INSERT INTO "django_geo_db_city" VALUES(14718,'Fontanet','Fontanet, Indiana',18476,18);
INSERT INTO "django_geo_db_city" VALUES(14719,'Graysville','Graysville, Indiana',18477,18);
INSERT INTO "django_geo_db_city" VALUES(14720,'Harmony','Harmony, Indiana',18478,18);
INSERT INTO "django_geo_db_city" VALUES(14721,'Hillsdale','Hillsdale, Indiana',18479,18);
INSERT INTO "django_geo_db_city" VALUES(14722,'Hymera','Hymera, Indiana',18480,18);
INSERT INTO "django_geo_db_city" VALUES(14723,'Judson','Judson, Indiana',18481,18);
INSERT INTO "django_geo_db_city" VALUES(14724,'Knightsville','Knightsville, Indiana',18482,18);
INSERT INTO "django_geo_db_city" VALUES(14725,'Marshall','Marshall, Indiana',18484,18);
INSERT INTO "django_geo_db_city" VALUES(14726,'Mecca','Mecca, Indiana',18485,18);
INSERT INTO "django_geo_db_city" VALUES(14727,'Merom','Merom, Indiana',18486,18);
INSERT INTO "django_geo_db_city" VALUES(14728,'Montezuma','Montezuma, Indiana',18487,18);
INSERT INTO "django_geo_db_city" VALUES(14729,'New Goshen','New Goshen, Indiana',18488,18);
INSERT INTO "django_geo_db_city" VALUES(14730,'New Lebanon','New Lebanon, Indiana',18489,18);
INSERT INTO "django_geo_db_city" VALUES(14731,'Paxton','Paxton, Indiana',18490,18);
INSERT INTO "django_geo_db_city" VALUES(14732,'Pimento','Pimento, Indiana',18491,18);
INSERT INTO "django_geo_db_city" VALUES(14733,'Poland','Poland, Indiana',18492,18);
INSERT INTO "django_geo_db_city" VALUES(14734,'Prairie Creek','Prairie Creek, Indiana',18452,18);
INSERT INTO "django_geo_db_city" VALUES(14735,'Prairieton','Prairieton, Indiana',18493,18);
INSERT INTO "django_geo_db_city" VALUES(14736,'Riley','Riley, Indiana',18494,18);
INSERT INTO "django_geo_db_city" VALUES(14737,'Rockville','Rockville, Indiana',18495,18);
INSERT INTO "django_geo_db_city" VALUES(14738,'Rosedale','Rosedale, Indiana',18496,18);
INSERT INTO "django_geo_db_city" VALUES(14739,'Saint Bernice','Saint Bernice, Indiana',18460,18);
INSERT INTO "django_geo_db_city" VALUES(14740,'Saint Mary Of The Woods','Saint Mary Of The Woods, Indiana',18497,18);
INSERT INTO "django_geo_db_city" VALUES(14741,'Seelyville','Seelyville, Indiana',18498,18);
INSERT INTO "django_geo_db_city" VALUES(14742,'Shelburn','Shelburn, Indiana',18499,18);
INSERT INTO "django_geo_db_city" VALUES(14743,'Shepardsville','Shepardsville, Indiana',18500,18);
INSERT INTO "django_geo_db_city" VALUES(14744,'Staunton','Staunton, Indiana',18501,18);
INSERT INTO "django_geo_db_city" VALUES(14745,'Sullivan','Sullivan, Indiana',18502,18);
INSERT INTO "django_geo_db_city" VALUES(14746,'Universal','Universal, Indiana',18503,18);
INSERT INTO "django_geo_db_city" VALUES(14747,'West Terre Haute','West Terre Haute, Indiana',18504,18);
INSERT INTO "django_geo_db_city" VALUES(14748,'Helt','Helt, Indiana',18505,18);
INSERT INTO "django_geo_db_city" VALUES(14749,'Lafayette','Lafayette, Indiana',18506,18);
INSERT INTO "django_geo_db_city" VALUES(14750,'West Lafayette','West Lafayette, Indiana',18511,18);
INSERT INTO "django_geo_db_city" VALUES(14751,'Alamo','Alamo, Indiana',18514,18);
INSERT INTO "django_geo_db_city" VALUES(14752,'Ambia','Ambia, Indiana',18515,18);
INSERT INTO "django_geo_db_city" VALUES(14753,'Attica','Attica, Indiana',18516,18);
INSERT INTO "django_geo_db_city" VALUES(14754,'Battle Ground','Battle Ground, Indiana',18517,18);
INSERT INTO "django_geo_db_city" VALUES(14755,'Boswell','Boswell, Indiana',18518,18);
INSERT INTO "django_geo_db_city" VALUES(14756,'Brook','Brook, Indiana',18519,18);
INSERT INTO "django_geo_db_city" VALUES(14757,'Brookston','Brookston, Indiana',18520,18);
INSERT INTO "django_geo_db_city" VALUES(14758,'Buck Creek','Buck Creek, Indiana',18521,18);
INSERT INTO "django_geo_db_city" VALUES(14759,'Buffalo','Buffalo, Indiana',18522,18);
INSERT INTO "django_geo_db_city" VALUES(14760,'Burnettsville','Burnettsville, Indiana',18523,18);
INSERT INTO "django_geo_db_city" VALUES(14761,'Chalmers','Chalmers, Indiana',18525,18);
INSERT INTO "django_geo_db_city" VALUES(14762,'Clarks Hill','Clarks Hill, Indiana',18526,18);
INSERT INTO "django_geo_db_city" VALUES(14763,'Covington','Covington, Indiana',18527,18);
INSERT INTO "django_geo_db_city" VALUES(14764,'Crawfordsville','Crawfordsville, Indiana',18528,18);
INSERT INTO "django_geo_db_city" VALUES(14765,'Darlington','Darlington, Indiana',18530,18);
INSERT INTO "django_geo_db_city" VALUES(14766,'Dayton','Dayton, Indiana',18531,18);
INSERT INTO "django_geo_db_city" VALUES(14767,'Earl Park','Earl Park, Indiana',18532,18);
INSERT INTO "django_geo_db_city" VALUES(14768,'Fair Oaks','Fair Oaks, Indiana',18533,18);
INSERT INTO "django_geo_db_city" VALUES(14769,'Fowler','Fowler, Indiana',18534,18);
INSERT INTO "django_geo_db_city" VALUES(14770,'Francesville','Francesville, Indiana',18535,18);
INSERT INTO "django_geo_db_city" VALUES(14771,'Goodland','Goodland, Indiana',18536,18);
INSERT INTO "django_geo_db_city" VALUES(14772,'Hillsboro','Hillsboro, Indiana',18537,18);
INSERT INTO "django_geo_db_city" VALUES(14773,'Idaville','Idaville, Indiana',18538,18);
INSERT INTO "django_geo_db_city" VALUES(14774,'Kentland','Kentland, Indiana',18539,18);
INSERT INTO "django_geo_db_city" VALUES(14775,'Kingman','Kingman, Indiana',18540,18);
INSERT INTO "django_geo_db_city" VALUES(14776,'Ladoga','Ladoga, Indiana',18541,18);
INSERT INTO "django_geo_db_city" VALUES(14777,'Linden','Linden, Indiana',18542,18);
INSERT INTO "django_geo_db_city" VALUES(14778,'Medaryville','Medaryville, Indiana',18543,18);
INSERT INTO "django_geo_db_city" VALUES(14779,'Mellott','Mellott, Indiana',18544,18);
INSERT INTO "django_geo_db_city" VALUES(14780,'Monon','Monon, Indiana',18545,18);
INSERT INTO "django_geo_db_city" VALUES(14781,'Monticello','Monticello, Indiana',18546,18);
INSERT INTO "django_geo_db_city" VALUES(14782,'Montmorenci','Montmorenci, Indiana',18547,18);
INSERT INTO "django_geo_db_city" VALUES(14783,'Morocco','Morocco, Indiana',18548,18);
INSERT INTO "django_geo_db_city" VALUES(14784,'Mount Ayr','Mount Ayr, Indiana',18549,18);
INSERT INTO "django_geo_db_city" VALUES(14785,'Newport','Newport, Indiana',18551,18);
INSERT INTO "django_geo_db_city" VALUES(14786,'New Richmond','New Richmond, Indiana',18552,18);
INSERT INTO "django_geo_db_city" VALUES(14787,'New Ross','New Ross, Indiana',18553,18);
INSERT INTO "django_geo_db_city" VALUES(14788,'Newtown','Newtown, Indiana',18554,18);
INSERT INTO "django_geo_db_city" VALUES(14789,'Otterbein','Otterbein, Indiana',18555,18);
INSERT INTO "django_geo_db_city" VALUES(14790,'Perrysville','Perrysville, Indiana',18557,18);
INSERT INTO "django_geo_db_city" VALUES(14791,'Pine Village','Pine Village, Indiana',18558,18);
INSERT INTO "django_geo_db_city" VALUES(14792,'Remington','Remington, Indiana',18560,18);
INSERT INTO "django_geo_db_city" VALUES(14793,'Rensselaer','Rensselaer, Indiana',18561,18);
INSERT INTO "django_geo_db_city" VALUES(14794,'Reynolds','Reynolds, Indiana',18562,18);
INSERT INTO "django_geo_db_city" VALUES(14795,'Romney','Romney, Indiana',18563,18);
INSERT INTO "django_geo_db_city" VALUES(14796,'State Line','State Line, Indiana',18564,18);
INSERT INTO "django_geo_db_city" VALUES(14797,'Stockwell','Stockwell, Indiana',18565,18);
INSERT INTO "django_geo_db_city" VALUES(14798,'Talbot','Talbot, Indiana',18559,18);
INSERT INTO "django_geo_db_city" VALUES(14799,'Templeton','Templeton, Indiana',18566,18);
INSERT INTO "django_geo_db_city" VALUES(14800,'Veedersburg','Veedersburg, Indiana',18567,18);
INSERT INTO "django_geo_db_city" VALUES(14801,'Wallace','Wallace, Indiana',18568,18);
INSERT INTO "django_geo_db_city" VALUES(14802,'Waveland','Waveland, Indiana',18569,18);
INSERT INTO "django_geo_db_city" VALUES(14803,'Waynetown','Waynetown, Indiana',18570,18);
INSERT INTO "django_geo_db_city" VALUES(14804,'West Lebanon','West Lebanon, Indiana',18571,18);
INSERT INTO "django_geo_db_city" VALUES(14805,'Westpoint','Westpoint, Indiana',18572,18);
INSERT INTO "django_geo_db_city" VALUES(14806,'Williamsport','Williamsport, Indiana',18573,18);
INSERT INTO "django_geo_db_city" VALUES(14807,'Wingate','Wingate, Indiana',18574,18);
INSERT INTO "django_geo_db_city" VALUES(14808,'Wolcott','Wolcott, Indiana',18575,18);
INSERT INTO "django_geo_db_city" VALUES(14809,'Yeoman','Yeoman, Indiana',18576,18);
INSERT INTO "django_geo_db_city" VALUES(14810,'Algonac','Algonac, Michigan',18577,40);
INSERT INTO "django_geo_db_city" VALUES(14811,'Allenton','Allenton, Michigan',18578,40);
INSERT INTO "django_geo_db_city" VALUES(14812,'Almont','Almont, Michigan',18579,40);
INSERT INTO "django_geo_db_city" VALUES(14813,'Anchorville','Anchorville, Michigan',18580,40);
INSERT INTO "django_geo_db_city" VALUES(14814,'Armada','Armada, Michigan',18581,40);
INSERT INTO "django_geo_db_city" VALUES(14815,'Avoca','Avoca, Michigan',18582,40);
INSERT INTO "django_geo_db_city" VALUES(14816,'Troy','Troy, Michigan',18583,40);
INSERT INTO "django_geo_db_city" VALUES(14817,'Birmingham','Birmingham, Michigan',18584,40);
INSERT INTO "django_geo_db_city" VALUES(14818,'Capac','Capac, Michigan',18586,40);
INSERT INTO "django_geo_db_city" VALUES(14819,'Center Line','Center Line, Michigan',18587,40);
INSERT INTO "django_geo_db_city" VALUES(14820,'Clawson','Clawson, Michigan',18588,40);
INSERT INTO "django_geo_db_city" VALUES(14821,'Rose','Rose, Michigan',18589,40);
INSERT INTO "django_geo_db_city" VALUES(14822,'Eastpointe','Eastpointe, Michigan',18590,40);
INSERT INTO "django_geo_db_city" VALUES(14823,'Emmett','Emmett, Michigan',18591,40);
INSERT INTO "django_geo_db_city" VALUES(14824,'Fair Haven','Fair Haven, Michigan',18592,40);
INSERT INTO "django_geo_db_city" VALUES(14825,'Franklin','Franklin, Michigan',18593,40);
INSERT INTO "django_geo_db_city" VALUES(14826,'Fraser','Fraser, Michigan',18594,40);
INSERT INTO "django_geo_db_city" VALUES(14827,'Goodells','Goodells, Michigan',18595,40);
INSERT INTO "django_geo_db_city" VALUES(14828,'Harsens Island','Harsens Island, Michigan',18596,40);
INSERT INTO "django_geo_db_city" VALUES(14829,'Hazel Park','Hazel Park, Michigan',18597,40);
INSERT INTO "django_geo_db_city" VALUES(14830,'Jeddo','Jeddo, Michigan',18598,40);
INSERT INTO "django_geo_db_city" VALUES(14831,'Southfield','Southfield, Michigan',18599,40);
INSERT INTO "django_geo_db_city" VALUES(14832,'Clinton Township','Clinton Township, Michigan',18600,40);
INSERT INTO "django_geo_db_city" VALUES(14833,'Marine City','Marine City, Michigan',18604,40);
INSERT INTO "django_geo_db_city" VALUES(14834,'Marysville','Marysville, Michigan',18605,40);
INSERT INTO "django_geo_db_city" VALUES(14835,'Memphis','Memphis, Michigan',18606,40);
INSERT INTO "django_geo_db_city" VALUES(14836,'Macomb','Macomb, Michigan',18607,40);
INSERT INTO "django_geo_db_city" VALUES(14837,'Mount Clemens','Mount Clemens, Michigan',18608,40);
INSERT INTO "django_geo_db_city" VALUES(14838,'Harrison Township','Harrison Township, Michigan',18610,40);
INSERT INTO "django_geo_db_city" VALUES(14839,'New Baltimore','New Baltimore, Michigan',18612,40);
INSERT INTO "django_geo_db_city" VALUES(14840,'New Haven','New Haven, Michigan',18613,40);
INSERT INTO "django_geo_db_city" VALUES(14841,'North Street','North Street, Michigan',18614,40);
INSERT INTO "django_geo_db_city" VALUES(14842,'East China','East China, Michigan',18617,40);
INSERT INTO "django_geo_db_city" VALUES(14843,'Fort Gratiot','Fort Gratiot, Michigan',18618,40);
INSERT INTO "django_geo_db_city" VALUES(14844,'Port Huron','Port Huron, Michigan',18619,40);
INSERT INTO "django_geo_db_city" VALUES(14845,'Richmond','Richmond, Michigan',18620,40);
INSERT INTO "django_geo_db_city" VALUES(14846,'Columbus','Columbus, Michigan',18621,40);
INSERT INTO "django_geo_db_city" VALUES(14847,'Casco','Casco, Michigan',18622,40);
INSERT INTO "django_geo_db_city" VALUES(14848,'Romeo','Romeo, Michigan',18623,40);
INSERT INTO "django_geo_db_city" VALUES(14849,'Roseville','Roseville, Michigan',18624,40);
INSERT INTO "django_geo_db_city" VALUES(14850,'Royal Oak','Royal Oak, Michigan',18625,40);
INSERT INTO "django_geo_db_city" VALUES(14851,'Pleasant Ridge','Pleasant Ridge, Michigan',18627,40);
INSERT INTO "django_geo_db_city" VALUES(14852,'Huntington Woods','Huntington Woods, Michigan',18628,40);
INSERT INTO "django_geo_db_city" VALUES(14853,'Madison Heights','Madison Heights, Michigan',18629,40);
INSERT INTO "django_geo_db_city" VALUES(14854,'Berkley','Berkley, Michigan',18630,40);
INSERT INTO "django_geo_db_city" VALUES(14855,'Smiths Creek','Smiths Creek, Michigan',18632,40);
INSERT INTO "django_geo_db_city" VALUES(14856,'Saint Clair','Saint Clair, Michigan',18635,40);
INSERT INTO "django_geo_db_city" VALUES(14857,'Saint Clair Shores','Saint Clair Shores, Michigan',18636,40);
INSERT INTO "django_geo_db_city" VALUES(14858,'Warren','Warren, Michigan',18642,40);
INSERT INTO "django_geo_db_city" VALUES(14859,'Washington','Washington, Michigan',18647,40);
INSERT INTO "django_geo_db_city" VALUES(14860,'Ray','Ray, Michigan',18649,40);
INSERT INTO "django_geo_db_city" VALUES(14861,'Yale','Yale, Michigan',18650,40);
INSERT INTO "django_geo_db_city" VALUES(14862,'Allen Park','Allen Park, Michigan',18653,40);
INSERT INTO "django_geo_db_city" VALUES(14863,'Ann Arbor','Ann Arbor, Michigan',18654,40);
INSERT INTO "django_geo_db_city" VALUES(14864,'Azalia','Azalia, Michigan',18660,40);
INSERT INTO "django_geo_db_city" VALUES(14865,'Belleville','Belleville, Michigan',18661,40);
INSERT INTO "django_geo_db_city" VALUES(14866,'Brighton','Brighton, Michigan',18663,40);
INSERT INTO "django_geo_db_city" VALUES(14867,'Bridgewater','Bridgewater, Michigan',18664,40);
INSERT INTO "django_geo_db_city" VALUES(14868,'Carleton','Carleton, Michigan',18666,40);
INSERT INTO "django_geo_db_city" VALUES(14869,'Chelsea','Chelsea, Michigan',18667,40);
INSERT INTO "django_geo_db_city" VALUES(14870,'Dearborn','Dearborn, Michigan',18668,40);
INSERT INTO "django_geo_db_city" VALUES(14871,'Melvindale','Melvindale, Michigan',18669,40);
INSERT INTO "django_geo_db_city" VALUES(14872,'Dearborn Heights','Dearborn Heights, Michigan',18671,40);
INSERT INTO "django_geo_db_city" VALUES(14873,'Dexter','Dexter, Michigan',18675,40);
INSERT INTO "django_geo_db_city" VALUES(14874,'Dundee','Dundee, Michigan',18676,40);
INSERT INTO "django_geo_db_city" VALUES(14875,'Erie','Erie, Michigan',18677,40);
INSERT INTO "django_geo_db_city" VALUES(14876,'Flat Rock','Flat Rock, Michigan',18678,40);
INSERT INTO "django_geo_db_city" VALUES(14877,'Garden City','Garden City, Michigan',18679,40);
INSERT INTO "django_geo_db_city" VALUES(14878,'Gregory','Gregory, Michigan',18680,40);
INSERT INTO "django_geo_db_city" VALUES(14879,'Grosse Ile','Grosse Ile, Michigan',18681,40);
INSERT INTO "django_geo_db_city" VALUES(14880,'Hamburg','Hamburg, Michigan',18682,40);
INSERT INTO "django_geo_db_city" VALUES(14881,'Ida','Ida, Michigan',18683,40);
INSERT INTO "django_geo_db_city" VALUES(14882,'Inkster','Inkster, Michigan',18684,40);
INSERT INTO "django_geo_db_city" VALUES(14883,'Lakeland','Lakeland, Michigan',18685,40);
INSERT INTO "django_geo_db_city" VALUES(14884,'Lambertville','Lambertville, Michigan',18686,40);
INSERT INTO "django_geo_db_city" VALUES(14885,'La Salle','La Salle, Michigan',18687,40);
INSERT INTO "django_geo_db_city" VALUES(14886,'Lincoln Park','Lincoln Park, Michigan',18688,40);
INSERT INTO "django_geo_db_city" VALUES(14887,'Livonia','Livonia, Michigan',18689,40);
INSERT INTO "django_geo_db_city" VALUES(14888,'Luna Pier','Luna Pier, Michigan',18692,40);
INSERT INTO "django_geo_db_city" VALUES(14889,'Manchester','Manchester, Michigan',18693,40);
INSERT INTO "django_geo_db_city" VALUES(14890,'Maybee','Maybee, Michigan',18694,40);
INSERT INTO "django_geo_db_city" VALUES(14891,'Milan','Milan, Michigan',18695,40);
INSERT INTO "django_geo_db_city" VALUES(14892,'Monroe','Monroe, Michigan',18696,40);
INSERT INTO "django_geo_db_city" VALUES(14893,'New Boston','New Boston, Michigan',18698,40);
INSERT INTO "django_geo_db_city" VALUES(14894,'New Hudson','New Hudson, Michigan',18699,40);
INSERT INTO "django_geo_db_city" VALUES(14895,'Newport','Newport, Michigan',18700,40);
INSERT INTO "django_geo_db_city" VALUES(14896,'Northville','Northville, Michigan',18701,40);
INSERT INTO "django_geo_db_city" VALUES(14897,'South Monroe','South Monroe, Michigan',18702,40);
INSERT INTO "django_geo_db_city" VALUES(14898,'Pinckney','Pinckney, Michigan',18703,40);
INSERT INTO "django_geo_db_city" VALUES(14899,'Plymouth','Plymouth, Michigan',18704,40);
INSERT INTO "django_geo_db_city" VALUES(14900,'Rockwood','Rockwood, Michigan',18705,40);
INSERT INTO "django_geo_db_city" VALUES(14901,'Romulus','Romulus, Michigan',18706,40);
INSERT INTO "django_geo_db_city" VALUES(14902,'Salem','Salem, Michigan',18707,40);
INSERT INTO "django_geo_db_city" VALUES(14903,'Saline','Saline, Michigan',18708,40);
INSERT INTO "django_geo_db_city" VALUES(14904,'Samaria','Samaria, Michigan',18709,40);
INSERT INTO "django_geo_db_city" VALUES(14905,'South Lyon','South Lyon, Michigan',18710,40);
INSERT INTO "django_geo_db_city" VALUES(14906,'South Rockwood','South Rockwood, Michigan',18711,40);
INSERT INTO "django_geo_db_city" VALUES(14907,'Taylor','Taylor, Michigan',18712,40);
INSERT INTO "django_geo_db_city" VALUES(14908,'Temperance','Temperance, Michigan',18713,40);
INSERT INTO "django_geo_db_city" VALUES(14909,'Trenton','Trenton, Michigan',18714,40);
INSERT INTO "django_geo_db_city" VALUES(14910,'Wayne','Wayne, Michigan',18715,40);
INSERT INTO "django_geo_db_city" VALUES(14911,'Westland','Westland, Michigan',18716,40);
INSERT INTO "django_geo_db_city" VALUES(14912,'Canton','Canton, Michigan',18718,40);
INSERT INTO "django_geo_db_city" VALUES(14913,'Whitmore Lake','Whitmore Lake, Michigan',18720,40);
INSERT INTO "django_geo_db_city" VALUES(14914,'Whittaker','Whittaker, Michigan',18721,40);
INSERT INTO "django_geo_db_city" VALUES(14915,'Willis','Willis, Michigan',18722,40);
INSERT INTO "django_geo_db_city" VALUES(14916,'Wyandotte','Wyandotte, Michigan',18723,40);
INSERT INTO "django_geo_db_city" VALUES(14917,'Southgate','Southgate, Michigan',18724,40);
INSERT INTO "django_geo_db_city" VALUES(14918,'Ypsilanti','Ypsilanti, Michigan',18725,40);
INSERT INTO "django_geo_db_city" VALUES(14919,'Detroit','Detroit, Michigan',18727,40);
INSERT INTO "django_geo_db_city" VALUES(14920,'Highland Park','Highland Park, Michigan',18729,40);
INSERT INTO "django_geo_db_city" VALUES(14921,'Hamtramck','Hamtramck, Michigan',18738,40);
INSERT INTO "django_geo_db_city" VALUES(14922,'River Rouge','River Rouge, Michigan',18744,40);
INSERT INTO "django_geo_db_city" VALUES(14923,'Ferndale','Ferndale, Michigan',18746,40);
INSERT INTO "django_geo_db_city" VALUES(14924,'Harper Woods','Harper Woods, Michigan',18750,40);
INSERT INTO "django_geo_db_city" VALUES(14925,'Ecorse','Ecorse, Michigan',18754,40);
INSERT INTO "django_geo_db_city" VALUES(14926,'Grosse Pointe','Grosse Pointe, Michigan',18755,40);
INSERT INTO "django_geo_db_city" VALUES(14927,'Oak Park','Oak Park, Michigan',18759,40);
INSERT INTO "django_geo_db_city" VALUES(14928,'Redford','Redford, Michigan',18761,40);
INSERT INTO "django_geo_db_city" VALUES(14929,'Independence','Independence, Michigan',18764,40);
INSERT INTO "django_geo_db_city" VALUES(14930,'Bloomfield Hills','Bloomfield Hills, Michigan',18765,40);
INSERT INTO "django_geo_db_city" VALUES(14931,'Clinton','Clinton, Michigan',18768,40);
INSERT INTO "django_geo_db_city" VALUES(14932,'Rochester','Rochester, Michigan',18769,40);
INSERT INTO "django_geo_db_city" VALUES(14933,'Sterling Heights','Sterling Heights, Michigan',18773,40);
INSERT INTO "django_geo_db_city" VALUES(14934,'Utica','Utica, Michigan',18777,40);
INSERT INTO "django_geo_db_city" VALUES(14935,'Keego Harbor','Keego Harbor, Michigan',18780,40);
INSERT INTO "django_geo_db_city" VALUES(14936,'Auburn Hills','Auburn Hills, Michigan',18626,40);
INSERT INTO "django_geo_db_city" VALUES(14937,'West Bloomfield','West Bloomfield, Michigan',18781,40);
INSERT INTO "django_geo_db_city" VALUES(14938,'Waterford','Waterford, Michigan',18785,40);
INSERT INTO "django_geo_db_city" VALUES(14939,'Drayton Plains','Drayton Plains, Michigan',18788,40);
INSERT INTO "django_geo_db_city" VALUES(14940,'Farmington','Farmington, Michigan',18789,40);
INSERT INTO "django_geo_db_city" VALUES(14941,'Pontiac','Pontiac, Michigan',18793,40);
INSERT INTO "django_geo_db_city" VALUES(14942,'Clarkston','Clarkston, Michigan',18796,40);
INSERT INTO "django_geo_db_city" VALUES(14943,'Davisburg','Davisburg, Michigan',18798,40);
INSERT INTO "django_geo_db_city" VALUES(14944,'Hartland','Hartland, Michigan',18799,40);
INSERT INTO "django_geo_db_city" VALUES(14945,'Highland','Highland, Michigan',18800,40);
INSERT INTO "django_geo_db_city" VALUES(14946,'Lake Orion','Lake Orion, Michigan',18802,40);
INSERT INTO "django_geo_db_city" VALUES(14947,'Oakland','Oakland, Michigan',18805,40);
INSERT INTO "django_geo_db_city" VALUES(14948,'Lakeville','Lakeville, Michigan',18806,40);
INSERT INTO "django_geo_db_city" VALUES(14949,'Leonard','Leonard, Michigan',18807,40);
INSERT INTO "django_geo_db_city" VALUES(14950,'Oxford','Oxford, Michigan',18808,40);
INSERT INTO "django_geo_db_city" VALUES(14951,'Novi','Novi, Michigan',18810,40);
INSERT INTO "django_geo_db_city" VALUES(14952,'Milford','Milford, Michigan',18814,40);
INSERT INTO "django_geo_db_city" VALUES(14953,'Commerce Township','Commerce Township, Michigan',18816,40);
INSERT INTO "django_geo_db_city" VALUES(14954,'White Lake','White Lake, Michigan',18817,40);
INSERT INTO "django_geo_db_city" VALUES(14955,'Union Lake','Union Lake, Michigan',18819,40);
INSERT INTO "django_geo_db_city" VALUES(14956,'Walled Lake','Walled Lake, Michigan',18820,40);
INSERT INTO "django_geo_db_city" VALUES(14957,'Wixom','Wixom, Michigan',18821,40);
INSERT INTO "django_geo_db_city" VALUES(14958,'Applegate','Applegate, Michigan',18824,40);
INSERT INTO "django_geo_db_city" VALUES(14959,'Argyle','Argyle, Michigan',18825,40);
INSERT INTO "django_geo_db_city" VALUES(14960,'Atlas','Atlas, Michigan',18826,40);
INSERT INTO "django_geo_db_city" VALUES(14961,'Attica','Attica, Michigan',18827,40);
INSERT INTO "django_geo_db_city" VALUES(14962,'Bad Axe','Bad Axe, Michigan',18828,40);
INSERT INTO "django_geo_db_city" VALUES(14963,'Bancroft','Bancroft, Michigan',18829,40);
INSERT INTO "django_geo_db_city" VALUES(14964,'Birch Run','Birch Run, Michigan',18830,40);
INSERT INTO "django_geo_db_city" VALUES(14965,'Brown City','Brown City, Michigan',18831,40);
INSERT INTO "django_geo_db_city" VALUES(14966,'Burt','Burt, Michigan',18832,40);
INSERT INTO "django_geo_db_city" VALUES(14967,'Byron','Byron, Michigan',18833,40);
INSERT INTO "django_geo_db_city" VALUES(14968,'Carsonville','Carsonville, Michigan',18834,40);
INSERT INTO "django_geo_db_city" VALUES(14969,'Clio','Clio, Michigan',18835,40);
INSERT INTO "django_geo_db_city" VALUES(14970,'Columbiaville','Columbiaville, Michigan',18836,40);
INSERT INTO "django_geo_db_city" VALUES(14971,'Croswell','Croswell, Michigan',18837,40);
INSERT INTO "django_geo_db_city" VALUES(14972,'Davison','Davison, Michigan',18838,40);
INSERT INTO "django_geo_db_city" VALUES(14973,'Decker','Decker, Michigan',18839,40);
INSERT INTO "django_geo_db_city" VALUES(14974,'Deckerville','Deckerville, Michigan',18840,40);
INSERT INTO "django_geo_db_city" VALUES(14975,'Dryden','Dryden, Michigan',18841,40);
INSERT INTO "django_geo_db_city" VALUES(14976,'Durand','Durand, Michigan',18842,40);
INSERT INTO "django_geo_db_city" VALUES(14977,'Fenton','Fenton, Michigan',18843,40);
INSERT INTO "django_geo_db_city" VALUES(14978,'Filion','Filion, Michigan',18844,40);
INSERT INTO "django_geo_db_city" VALUES(14979,'Flushing','Flushing, Michigan',18845,40);
INSERT INTO "django_geo_db_city" VALUES(14980,'Forestville','Forestville, Michigan',18846,40);
INSERT INTO "django_geo_db_city" VALUES(14981,'Fostoria','Fostoria, Michigan',18847,40);
INSERT INTO "django_geo_db_city" VALUES(14982,'Gaines','Gaines, Michigan',18848,40);
INSERT INTO "django_geo_db_city" VALUES(14983,'Genesee','Genesee, Michigan',18849,40);
INSERT INTO "django_geo_db_city" VALUES(14984,'Goodrich','Goodrich, Michigan',18850,40);
INSERT INTO "django_geo_db_city" VALUES(14985,'Grand Blanc','Grand Blanc, Michigan',18851,40);
INSERT INTO "django_geo_db_city" VALUES(14986,'Hadley','Hadley, Michigan',18852,40);
INSERT INTO "django_geo_db_city" VALUES(14987,'Harbor Beach','Harbor Beach, Michigan',18853,40);
INSERT INTO "django_geo_db_city" VALUES(14988,'Holly','Holly, Michigan',18854,40);
INSERT INTO "django_geo_db_city" VALUES(14989,'Imlay City','Imlay City, Michigan',18855,40);
INSERT INTO "django_geo_db_city" VALUES(14990,'Kinde','Kinde, Michigan',18856,40);
INSERT INTO "django_geo_db_city" VALUES(14991,'Lapeer','Lapeer, Michigan',18857,40);
INSERT INTO "django_geo_db_city" VALUES(14992,'Sciota','Sciota, Michigan',18858,40);
INSERT INTO "django_geo_db_city" VALUES(14993,'Lennon','Lennon, Michigan',18859,40);
INSERT INTO "django_geo_db_city" VALUES(14994,'Lexington','Lexington, Michigan',18860,40);
INSERT INTO "django_geo_db_city" VALUES(14995,'Linden','Linden, Michigan',18861,40);
INSERT INTO "django_geo_db_city" VALUES(14996,'Marlette','Marlette, Michigan',18862,40);
INSERT INTO "django_geo_db_city" VALUES(14997,'Melvin','Melvin, Michigan',18863,40);
INSERT INTO "django_geo_db_city" VALUES(14998,'Metamora','Metamora, Michigan',18864,40);
INSERT INTO "django_geo_db_city" VALUES(14999,'Minden City','Minden City, Michigan',18865,40);
INSERT INTO "django_geo_db_city" VALUES(15000,'Montrose','Montrose, Michigan',18866,40);
INSERT INTO "django_geo_db_city" VALUES(15001,'Mount Morris','Mount Morris, Michigan',18867,40);
INSERT INTO "django_geo_db_city" VALUES(15002,'New Lothrop','New Lothrop, Michigan',18868,40);
INSERT INTO "django_geo_db_city" VALUES(15003,'North Branch','North Branch, Michigan',18869,40);
INSERT INTO "django_geo_db_city" VALUES(15004,'Ortonville','Ortonville, Michigan',18870,40);
INSERT INTO "django_geo_db_city" VALUES(15005,'Otisville','Otisville, Michigan',18871,40);
INSERT INTO "django_geo_db_city" VALUES(15006,'Otter Lake','Otter Lake, Michigan',18872,40);
INSERT INTO "django_geo_db_city" VALUES(15007,'Palms','Palms, Michigan',18873,40);
INSERT INTO "django_geo_db_city" VALUES(15008,'Peck','Peck, Michigan',18874,40);
INSERT INTO "django_geo_db_city" VALUES(15009,'Port Austin','Port Austin, Michigan',18875,40);
INSERT INTO "django_geo_db_city" VALUES(15010,'Port Hope','Port Hope, Michigan',18876,40);
INSERT INTO "django_geo_db_city" VALUES(15011,'Port Sanilac','Port Sanilac, Michigan',18877,40);
INSERT INTO "django_geo_db_city" VALUES(15012,'Ruth','Ruth, Michigan',18878,40);
INSERT INTO "django_geo_db_city" VALUES(15013,'Sandusky','Sandusky, Michigan',18879,40);
INSERT INTO "django_geo_db_city" VALUES(15014,'Snover','Snover, Michigan',18880,40);
INSERT INTO "django_geo_db_city" VALUES(15015,'Swartz Creek','Swartz Creek, Michigan',18881,40);
INSERT INTO "django_geo_db_city" VALUES(15016,'Ubly','Ubly, Michigan',18882,40);
INSERT INTO "django_geo_db_city" VALUES(15017,'Vernon','Vernon, Michigan',18883,40);
INSERT INTO "django_geo_db_city" VALUES(15018,'Flint','Flint, Michigan',18884,40);
INSERT INTO "django_geo_db_city" VALUES(15019,'Burton','Burton, Michigan',18891,40);
INSERT INTO "django_geo_db_city" VALUES(15020,'Markey','Markey, Michigan',18904,40);
INSERT INTO "django_geo_db_city" VALUES(15021,'Saginaw','Saginaw, Michigan',18906,40);
INSERT INTO "django_geo_db_city" VALUES(15022,'Alger','Alger, Michigan',18914,40);
INSERT INTO "django_geo_db_city" VALUES(15023,'Auburn','Auburn, Michigan',18915,40);
INSERT INTO "django_geo_db_city" VALUES(15024,'Beaverton','Beaverton, Michigan',18916,40);
INSERT INTO "django_geo_db_city" VALUES(15025,'Bentley','Bentley, Michigan',18917,40);
INSERT INTO "django_geo_db_city" VALUES(15026,'Brant','Brant, Michigan',18918,40);
INSERT INTO "django_geo_db_city" VALUES(15027,'Breckenridge','Breckenridge, Michigan',18919,40);
INSERT INTO "django_geo_db_city" VALUES(15028,'Chesaning','Chesaning, Michigan',18920,40);
INSERT INTO "django_geo_db_city" VALUES(15029,'Clare','Clare, Michigan',18921,40);
INSERT INTO "django_geo_db_city" VALUES(15030,'Coleman','Coleman, Michigan',18922,40);
INSERT INTO "django_geo_db_city" VALUES(15031,'Comins','Comins, Michigan',18923,40);
INSERT INTO "django_geo_db_city" VALUES(15032,'Edenville','Edenville, Michigan',18924,40);
INSERT INTO "django_geo_db_city" VALUES(15033,'Fairview','Fairview, Michigan',18925,40);
INSERT INTO "django_geo_db_city" VALUES(15034,'Farwell','Farwell, Michigan',18926,40);
INSERT INTO "django_geo_db_city" VALUES(15035,'Freeland','Freeland, Michigan',18927,40);
INSERT INTO "django_geo_db_city" VALUES(15036,'Gladwin','Gladwin, Michigan',18928,40);
INSERT INTO "django_geo_db_city" VALUES(15037,'Harrison','Harrison, Michigan',18929,40);
INSERT INTO "django_geo_db_city" VALUES(15038,'Hemlock','Hemlock, Michigan',18930,40);
INSERT INTO "django_geo_db_city" VALUES(15039,'Higgins Lake','Higgins Lake, Michigan',18931,40);
INSERT INTO "django_geo_db_city" VALUES(15040,'Hope','Hope, Michigan',18932,40);
INSERT INTO "django_geo_db_city" VALUES(15041,'Houghton Lake','Houghton Lake, Michigan',18933,40);
INSERT INTO "django_geo_db_city" VALUES(15042,'Houghton Lake Heights','Houghton Lake Heights, Michigan',18934,40);
INSERT INTO "django_geo_db_city" VALUES(15043,'Kawkawlin','Kawkawlin, Michigan',18935,40);
INSERT INTO "django_geo_db_city" VALUES(15044,'Lake','Lake, Michigan',18936,40);
INSERT INTO "django_geo_db_city" VALUES(15045,'Lake George','Lake George, Michigan',18937,40);
INSERT INTO "django_geo_db_city" VALUES(15046,'Linwood','Linwood, Michigan',18938,40);
INSERT INTO "django_geo_db_city" VALUES(15047,'Lupton','Lupton, Michigan',18939,40);
INSERT INTO "django_geo_db_city" VALUES(15048,'Luzerne','Luzerne, Michigan',18940,40);
INSERT INTO "django_geo_db_city" VALUES(15049,'Merrill','Merrill, Michigan',18941,40);
INSERT INTO "django_geo_db_city" VALUES(15050,'Midland','Midland, Michigan',18942,40);
INSERT INTO "django_geo_db_city" VALUES(15051,'Mio','Mio, Michigan',18945,40);
INSERT INTO "django_geo_db_city" VALUES(15052,'Oakley','Oakley, Michigan',18946,40);
INSERT INTO "django_geo_db_city" VALUES(15053,'Pinconning','Pinconning, Michigan',18947,40);
INSERT INTO "django_geo_db_city" VALUES(15054,'Prudenville','Prudenville, Michigan',18948,40);
INSERT INTO "django_geo_db_city" VALUES(15055,'Rhodes','Rhodes, Michigan',18949,40);
INSERT INTO "django_geo_db_city" VALUES(15056,'Roscommon','Roscommon, Michigan',18950,40);
INSERT INTO "django_geo_db_city" VALUES(15057,'Rose City','Rose City, Michigan',18951,40);
INSERT INTO "django_geo_db_city" VALUES(15058,'Saint Charles','Saint Charles, Michigan',18952,40);
INSERT INTO "django_geo_db_city" VALUES(15059,'Saint Helen','Saint Helen, Michigan',18953,40);
INSERT INTO "django_geo_db_city" VALUES(15060,'Sanford','Sanford, Michigan',18954,40);
INSERT INTO "django_geo_db_city" VALUES(15061,'Standish','Standish, Michigan',18955,40);
INSERT INTO "django_geo_db_city" VALUES(15062,'Sterling','Sterling, Michigan',18956,40);
INSERT INTO "django_geo_db_city" VALUES(15063,'West Branch','West Branch, Michigan',18957,40);
INSERT INTO "django_geo_db_city" VALUES(15064,'Wheeler','Wheeler, Michigan',18958,40);
INSERT INTO "django_geo_db_city" VALUES(15065,'Akron','Akron, Michigan',18963,40);
INSERT INTO "django_geo_db_city" VALUES(15066,'Au Gres','Au Gres, Michigan',18964,40);
INSERT INTO "django_geo_db_city" VALUES(15067,'Barton City','Barton City, Michigan',18965,40);
INSERT INTO "django_geo_db_city" VALUES(15068,'Bay City','Bay City, Michigan',18966,40);
INSERT INTO "django_geo_db_city" VALUES(15069,'University Center','University Center, Michigan',18969,40);
INSERT INTO "django_geo_db_city" VALUES(15070,'Bay Port','Bay Port, Michigan',18970,40);
INSERT INTO "django_geo_db_city" VALUES(15071,'Black River','Black River, Michigan',18971,40);
INSERT INTO "django_geo_db_city" VALUES(15072,'Bridgeport','Bridgeport, Michigan',18972,40);
INSERT INTO "django_geo_db_city" VALUES(15073,'Caro','Caro, Michigan',18973,40);
INSERT INTO "django_geo_db_city" VALUES(15074,'Carrollton','Carrollton, Michigan',18974,40);
INSERT INTO "django_geo_db_city" VALUES(15075,'Caseville','Caseville, Michigan',18975,40);
INSERT INTO "django_geo_db_city" VALUES(15076,'Cass City','Cass City, Michigan',18976,40);
INSERT INTO "django_geo_db_city" VALUES(15077,'Clifford','Clifford, Michigan',18977,40);
INSERT INTO "django_geo_db_city" VALUES(15078,'Curran','Curran, Michigan',18978,40);
INSERT INTO "django_geo_db_city" VALUES(15079,'Deford','Deford, Michigan',18979,40);
INSERT INTO "django_geo_db_city" VALUES(15080,'East Tawas','East Tawas, Michigan',18980,40);
INSERT INTO "django_geo_db_city" VALUES(15081,'Elkton','Elkton, Michigan',18981,40);
INSERT INTO "django_geo_db_city" VALUES(15082,'Essexville','Essexville, Michigan',18982,40);
INSERT INTO "django_geo_db_city" VALUES(15083,'Fairgrove','Fairgrove, Michigan',18983,40);
INSERT INTO "django_geo_db_city" VALUES(15084,'Frankenmuth','Frankenmuth, Michigan',18984,40);
INSERT INTO "django_geo_db_city" VALUES(15085,'Gagetown','Gagetown, Michigan',18985,40);
INSERT INTO "django_geo_db_city" VALUES(15086,'Gilford','Gilford, Michigan',18986,40);
INSERT INTO "django_geo_db_city" VALUES(15087,'Glennie','Glennie, Michigan',18987,40);
INSERT INTO "django_geo_db_city" VALUES(15088,'Greenbush','Greenbush, Michigan',18988,40);
INSERT INTO "django_geo_db_city" VALUES(15089,'Hale','Hale, Michigan',18989,40);
INSERT INTO "django_geo_db_city" VALUES(15090,'Harrisville','Harrisville, Michigan',18990,40);
INSERT INTO "django_geo_db_city" VALUES(15091,'Kingston','Kingston, Michigan',18991,40);
INSERT INTO "django_geo_db_city" VALUES(15092,'Lincoln','Lincoln, Michigan',18992,40);
INSERT INTO "django_geo_db_city" VALUES(15093,'Long Lake','Long Lake, Michigan',18993,40);
INSERT INTO "django_geo_db_city" VALUES(15094,'Mayville','Mayville, Michigan',18994,40);
INSERT INTO "django_geo_db_city" VALUES(15095,'Mikado','Mikado, Michigan',18995,40);
INSERT INTO "django_geo_db_city" VALUES(15096,'Millington','Millington, Michigan',18996,40);
INSERT INTO "django_geo_db_city" VALUES(15097,'Munger','Munger, Michigan',18997,40);
INSERT INTO "django_geo_db_city" VALUES(15098,'National City','National City, Michigan',18998,40);
INSERT INTO "django_geo_db_city" VALUES(15099,'Omer','Omer, Michigan',18999,40);
INSERT INTO "django_geo_db_city" VALUES(15100,'Oscoda','Oscoda, Michigan',19000,40);
INSERT INTO "django_geo_db_city" VALUES(15101,'Owendale','Owendale, Michigan',19001,40);
INSERT INTO "django_geo_db_city" VALUES(15102,'Pigeon','Pigeon, Michigan',19002,40);
INSERT INTO "django_geo_db_city" VALUES(15103,'Prescott','Prescott, Michigan',19003,40);
INSERT INTO "django_geo_db_city" VALUES(15104,'Reese','Reese, Michigan',19004,40);
INSERT INTO "django_geo_db_city" VALUES(15105,'Richville','Richville, Michigan',19005,40);
INSERT INTO "django_geo_db_city" VALUES(15106,'Sebewaing','Sebewaing, Michigan',19006,40);
INSERT INTO "django_geo_db_city" VALUES(15107,'Silverwood','Silverwood, Michigan',19007,40);
INSERT INTO "django_geo_db_city" VALUES(15108,'South Branch','South Branch, Michigan',19008,40);
INSERT INTO "django_geo_db_city" VALUES(15109,'Spruce','Spruce, Michigan',19009,40);
INSERT INTO "django_geo_db_city" VALUES(15110,'Tawas City','Tawas City, Michigan',19010,40);
INSERT INTO "django_geo_db_city" VALUES(15111,'Turner','Turner, Michigan',19012,40);
INSERT INTO "django_geo_db_city" VALUES(15112,'Twining','Twining, Michigan',19013,40);
INSERT INTO "django_geo_db_city" VALUES(15113,'Unionville','Unionville, Michigan',19014,40);
INSERT INTO "django_geo_db_city" VALUES(15114,'Vassar','Vassar, Michigan',19015,40);
INSERT INTO "django_geo_db_city" VALUES(15115,'Tuscola','Tuscola, Michigan',19016,40);
INSERT INTO "django_geo_db_city" VALUES(15116,'Whittemore','Whittemore, Michigan',19017,40);
INSERT INTO "django_geo_db_city" VALUES(15117,'Alma','Alma, Michigan',19019,40);
INSERT INTO "django_geo_db_city" VALUES(15118,'Mount Pleasant','Mount Pleasant, Michigan',19022,40);
INSERT INTO "django_geo_db_city" VALUES(15119,'Okemos','Okemos, Michigan',19023,40);
INSERT INTO "django_geo_db_city" VALUES(15120,'Ashley','Ashley, Michigan',19024,40);
INSERT INTO "django_geo_db_city" VALUES(15121,'Bannister','Bannister, Michigan',19025,40);
INSERT INTO "django_geo_db_city" VALUES(15122,'Bath','Bath, Michigan',19026,40);
INSERT INTO "django_geo_db_city" VALUES(15123,'Belding','Belding, Michigan',19027,40);
INSERT INTO "django_geo_db_city" VALUES(15124,'Carson City','Carson City, Michigan',19028,40);
INSERT INTO "django_geo_db_city" VALUES(15125,'Cedar Lake','Cedar Lake, Michigan',19029,40);
INSERT INTO "django_geo_db_city" VALUES(15126,'Charlotte','Charlotte, Michigan',19030,40);
INSERT INTO "django_geo_db_city" VALUES(15127,'Clarksville','Clarksville, Michigan',19031,40);
INSERT INTO "django_geo_db_city" VALUES(15128,'Cohoctah','Cohoctah, Michigan',19032,40);
INSERT INTO "django_geo_db_city" VALUES(15129,'Corunna','Corunna, Michigan',19033,40);
INSERT INTO "django_geo_db_city" VALUES(15130,'Crystal','Crystal, Michigan',19034,40);
INSERT INTO "django_geo_db_city" VALUES(15131,'Dansville','Dansville, Michigan',19035,40);
INSERT INTO "django_geo_db_city" VALUES(15132,'Dewitt','Dewitt, Michigan',19036,40);
INSERT INTO "django_geo_db_city" VALUES(15133,'Dimondale','Dimondale, Michigan',19037,40);
INSERT INTO "django_geo_db_city" VALUES(15134,'Eagle','Eagle, Michigan',19038,40);
INSERT INTO "django_geo_db_city" VALUES(15135,'East Lansing','East Lansing, Michigan',19039,40);
INSERT INTO "django_geo_db_city" VALUES(15136,'Eaton Rapids','Eaton Rapids, Michigan',19042,40);
INSERT INTO "django_geo_db_city" VALUES(15137,'Edmore','Edmore, Michigan',19043,40);
INSERT INTO "django_geo_db_city" VALUES(15138,'Elm Hall','Elm Hall, Michigan',19044,40);
INSERT INTO "django_geo_db_city" VALUES(15139,'Elsie','Elsie, Michigan',19045,40);
INSERT INTO "django_geo_db_city" VALUES(15140,'Elwell','Elwell, Michigan',19046,40);
INSERT INTO "django_geo_db_city" VALUES(15141,'Eureka','Eureka, Michigan',19047,40);
INSERT INTO "django_geo_db_city" VALUES(15142,'Fenwick','Fenwick, Michigan',19048,40);
INSERT INTO "django_geo_db_city" VALUES(15143,'Fowler','Fowler, Michigan',19049,40);
INSERT INTO "django_geo_db_city" VALUES(15144,'Fowlerville','Fowlerville, Michigan',19050,40);
INSERT INTO "django_geo_db_city" VALUES(15145,'Grand Ledge','Grand Ledge, Michigan',19051,40);
INSERT INTO "django_geo_db_city" VALUES(15146,'Greenville','Greenville, Michigan',19052,40);
INSERT INTO "django_geo_db_city" VALUES(15147,'Haslett','Haslett, Michigan',19053,40);
INSERT INTO "django_geo_db_city" VALUES(15148,'Henderson','Henderson, Michigan',19054,40);
INSERT INTO "django_geo_db_city" VALUES(15149,'Holt','Holt, Michigan',19055,40);
INSERT INTO "django_geo_db_city" VALUES(15150,'Howell','Howell, Michigan',19056,40);
INSERT INTO "django_geo_db_city" VALUES(15151,'Hubbardston','Hubbardston, Michigan',19058,40);
INSERT INTO "django_geo_db_city" VALUES(15152,'Ionia','Ionia, Michigan',19059,40);
INSERT INTO "django_geo_db_city" VALUES(15153,'Ithaca','Ithaca, Michigan',19060,40);
INSERT INTO "django_geo_db_city" VALUES(15154,'Laingsburg','Laingsburg, Michigan',19061,40);
INSERT INTO "django_geo_db_city" VALUES(15155,'Lake Odessa','Lake Odessa, Michigan',19062,40);
INSERT INTO "django_geo_db_city" VALUES(15156,'Lakeview','Lakeview, Michigan',19063,40);
INSERT INTO "django_geo_db_city" VALUES(15157,'Lyons','Lyons, Michigan',19064,40);
INSERT INTO "django_geo_db_city" VALUES(15158,'Mcbrides','Mcbrides, Michigan',19065,40);
INSERT INTO "django_geo_db_city" VALUES(15159,'Maple Rapids','Maple Rapids, Michigan',19066,40);
INSERT INTO "django_geo_db_city" VALUES(15160,'Mason','Mason, Michigan',19067,40);
INSERT INTO "django_geo_db_city" VALUES(15161,'Middleton','Middleton, Michigan',19069,40);
INSERT INTO "django_geo_db_city" VALUES(15162,'Morrice','Morrice, Michigan',19070,40);
INSERT INTO "django_geo_db_city" VALUES(15163,'Muir','Muir, Michigan',19073,40);
INSERT INTO "django_geo_db_city" VALUES(15164,'Mulliken','Mulliken, Michigan',19074,40);
INSERT INTO "django_geo_db_city" VALUES(15165,'North Star','North Star, Michigan',19075,40);
INSERT INTO "django_geo_db_city" VALUES(15166,'Oak Grove','Oak Grove, Michigan',19057,40);
INSERT INTO "django_geo_db_city" VALUES(15167,'Orleans','Orleans, Michigan',19077,40);
INSERT INTO "django_geo_db_city" VALUES(15168,'Ovid','Ovid, Michigan',19078,40);
INSERT INTO "django_geo_db_city" VALUES(15169,'Owosso','Owosso, Michigan',19079,40);
INSERT INTO "django_geo_db_city" VALUES(15170,'Palo','Palo, Michigan',19080,40);
INSERT INTO "django_geo_db_city" VALUES(15171,'Perrinton','Perrinton, Michigan',19081,40);
INSERT INTO "django_geo_db_city" VALUES(15172,'Perry','Perry, Michigan',19082,40);
INSERT INTO "django_geo_db_city" VALUES(15173,'Pewamo','Pewamo, Michigan',19083,40);
INSERT INTO "django_geo_db_city" VALUES(15174,'Pompeii','Pompeii, Michigan',19084,40);
INSERT INTO "django_geo_db_city" VALUES(15175,'Portland','Portland, Michigan',19085,40);
INSERT INTO "django_geo_db_city" VALUES(15176,'Potterville','Potterville, Michigan',19086,40);
INSERT INTO "django_geo_db_city" VALUES(15177,'Riverdale','Riverdale, Michigan',19087,40);
INSERT INTO "django_geo_db_city" VALUES(15178,'Rosebush','Rosebush, Michigan',19088,40);
INSERT INTO "django_geo_db_city" VALUES(15179,'Saint Johns','Saint Johns, Michigan',19089,40);
INSERT INTO "django_geo_db_city" VALUES(15180,'Saint Louis','Saint Louis, Michigan',19090,40);
INSERT INTO "django_geo_db_city" VALUES(15181,'Saranac','Saranac, Michigan',19091,40);
INSERT INTO "django_geo_db_city" VALUES(15182,'Shaftsburg','Shaftsburg, Michigan',19092,40);
INSERT INTO "django_geo_db_city" VALUES(15183,'Shepherd','Shepherd, Michigan',19093,40);
INSERT INTO "django_geo_db_city" VALUES(15184,'Sheridan','Sheridan, Michigan',19094,40);
INSERT INTO "django_geo_db_city" VALUES(15185,'Sidney','Sidney, Michigan',19095,40);
INSERT INTO "django_geo_db_city" VALUES(15186,'Six Lakes','Six Lakes, Michigan',19096,40);
INSERT INTO "django_geo_db_city" VALUES(15187,'Smyrna','Smyrna, Michigan',19097,40);
INSERT INTO "django_geo_db_city" VALUES(15188,'Stanton','Stanton, Michigan',19098,40);
INSERT INTO "django_geo_db_city" VALUES(15189,'Sumner','Sumner, Michigan',19099,40);
INSERT INTO "django_geo_db_city" VALUES(15190,'Sunfield','Sunfield, Michigan',19100,40);
INSERT INTO "django_geo_db_city" VALUES(15191,'Vestaburg','Vestaburg, Michigan',19101,40);
INSERT INTO "django_geo_db_city" VALUES(15192,'Webberville','Webberville, Michigan',19102,40);
INSERT INTO "django_geo_db_city" VALUES(15193,'Weidman','Weidman, Michigan',19103,40);
INSERT INTO "django_geo_db_city" VALUES(15194,'Westphalia','Westphalia, Michigan',19104,40);
INSERT INTO "django_geo_db_city" VALUES(15195,'Williamston','Williamston, Michigan',19105,40);
INSERT INTO "django_geo_db_city" VALUES(15196,'Winn','Winn, Michigan',19106,40);
INSERT INTO "django_geo_db_city" VALUES(15197,'Woodland','Woodland, Michigan',19107,40);
INSERT INTO "django_geo_db_city" VALUES(15198,'Lansing','Lansing, Michigan',19023,40);
INSERT INTO "django_geo_db_city" VALUES(15199,'Kalamazoo','Kalamazoo, Michigan',19120,40);
INSERT INTO "django_geo_db_city" VALUES(15200,'Portage','Portage, Michigan',19121,40);
INSERT INTO "django_geo_db_city" VALUES(15201,'Allegan','Allegan, Michigan',19129,40);
INSERT INTO "django_geo_db_city" VALUES(15202,'Athens','Athens, Michigan',19130,40);
INSERT INTO "django_geo_db_city" VALUES(15203,'Augusta','Augusta, Michigan',19131,40);
INSERT INTO "django_geo_db_city" VALUES(15204,'Bangor','Bangor, Michigan',19132,40);
INSERT INTO "django_geo_db_city" VALUES(15205,'Battle Creek','Battle Creek, Michigan',19133,40);
INSERT INTO "django_geo_db_city" VALUES(15206,'Bedford','Bedford, Michigan',19137,40);
INSERT INTO "django_geo_db_city" VALUES(15207,'Bellevue','Bellevue, Michigan',19138,40);
INSERT INTO "django_geo_db_city" VALUES(15208,'Benton Harbor','Benton Harbor, Michigan',19139,40);
INSERT INTO "django_geo_db_city" VALUES(15209,'Bloomingdale','Bloomingdale, Michigan',19142,40);
INSERT INTO "django_geo_db_city" VALUES(15210,'Breedsville','Breedsville, Michigan',19143,40);
INSERT INTO "django_geo_db_city" VALUES(15211,'Bronson','Bronson, Michigan',19144,40);
INSERT INTO "django_geo_db_city" VALUES(15212,'Burlington','Burlington, Michigan',19145,40);
INSERT INTO "django_geo_db_city" VALUES(15213,'Burr Oak','Burr Oak, Michigan',19146,40);
INSERT INTO "django_geo_db_city" VALUES(15214,'Cassopolis','Cassopolis, Michigan',19147,40);
INSERT INTO "django_geo_db_city" VALUES(15215,'Centreville','Centreville, Michigan',19148,40);
INSERT INTO "django_geo_db_city" VALUES(15216,'Ceresco','Ceresco, Michigan',19149,40);
INSERT INTO "django_geo_db_city" VALUES(15217,'Climax','Climax, Michigan',19150,40);
INSERT INTO "django_geo_db_city" VALUES(15218,'Cloverdale','Cloverdale, Michigan',19151,40);
INSERT INTO "django_geo_db_city" VALUES(15219,'Coldwater','Coldwater, Michigan',19152,40);
INSERT INTO "django_geo_db_city" VALUES(15220,'Coloma','Coloma, Michigan',19153,40);
INSERT INTO "django_geo_db_city" VALUES(15221,'Hagar Shores','Hagar Shores, Michigan',19154,40);
INSERT INTO "django_geo_db_city" VALUES(15222,'Colon','Colon, Michigan',19155,40);
INSERT INTO "django_geo_db_city" VALUES(15223,'Comstock','Comstock, Michigan',19122,40);
INSERT INTO "django_geo_db_city" VALUES(15224,'Constantine','Constantine, Michigan',19156,40);
INSERT INTO "django_geo_db_city" VALUES(15225,'Covert','Covert, Michigan',19157,40);
INSERT INTO "django_geo_db_city" VALUES(15226,'Decatur','Decatur, Michigan',19158,40);
INSERT INTO "django_geo_db_city" VALUES(15227,'Delton','Delton, Michigan',19159,40);
INSERT INTO "django_geo_db_city" VALUES(15228,'Dowagiac','Dowagiac, Michigan',19160,40);
INSERT INTO "django_geo_db_city" VALUES(15229,'Dowling','Dowling, Michigan',19162,40);
INSERT INTO "django_geo_db_city" VALUES(15230,'East Leroy','East Leroy, Michigan',19163,40);
INSERT INTO "django_geo_db_city" VALUES(15231,'Fulton','Fulton, Michigan',19164,40);
INSERT INTO "django_geo_db_city" VALUES(15232,'Galesburg','Galesburg, Michigan',19165,40);
INSERT INTO "django_geo_db_city" VALUES(15233,'Gobles','Gobles, Michigan',19166,40);
INSERT INTO "django_geo_db_city" VALUES(15234,'Grand Junction','Grand Junction, Michigan',19167,40);
INSERT INTO "django_geo_db_city" VALUES(15235,'Hartford','Hartford, Michigan',19168,40);
INSERT INTO "django_geo_db_city" VALUES(15236,'Hastings','Hastings, Michigan',19169,40);
INSERT INTO "django_geo_db_city" VALUES(15237,'Hickory Corners','Hickory Corners, Michigan',19170,40);
INSERT INTO "django_geo_db_city" VALUES(15238,'Jones','Jones, Michigan',19171,40);
INSERT INTO "django_geo_db_city" VALUES(15239,'Kendall','Kendall, Michigan',19172,40);
INSERT INTO "django_geo_db_city" VALUES(15240,'Lacota','Lacota, Michigan',19173,40);
INSERT INTO "django_geo_db_city" VALUES(15241,'Lawrence','Lawrence, Michigan',19174,40);
INSERT INTO "django_geo_db_city" VALUES(15242,'Lawton','Lawton, Michigan',19175,40);
INSERT INTO "django_geo_db_city" VALUES(15243,'Leonidas','Leonidas, Michigan',19176,40);
INSERT INTO "django_geo_db_city" VALUES(15244,'Marcellus','Marcellus, Michigan',19177,40);
INSERT INTO "django_geo_db_city" VALUES(15245,'Marshall','Marshall, Michigan',19178,40);
INSERT INTO "django_geo_db_city" VALUES(15246,'Martin','Martin, Michigan',19180,40);
INSERT INTO "django_geo_db_city" VALUES(15247,'Mattawan','Mattawan, Michigan',19181,40);
INSERT INTO "django_geo_db_city" VALUES(15248,'Mendon','Mendon, Michigan',19182,40);
INSERT INTO "django_geo_db_city" VALUES(15249,'Nashville','Nashville, Michigan',19183,40);
INSERT INTO "django_geo_db_city" VALUES(15250,'Nazareth','Nazareth, Michigan',19122,40);
INSERT INTO "django_geo_db_city" VALUES(15251,'Nottawa','Nottawa, Michigan',19184,40);
INSERT INTO "django_geo_db_city" VALUES(15252,'Olivet','Olivet, Michigan',19185,40);
INSERT INTO "django_geo_db_city" VALUES(15253,'Oshtemo','Oshtemo, Michigan',19122,40);
INSERT INTO "django_geo_db_city" VALUES(15254,'Otsego','Otsego, Michigan',19186,40);
INSERT INTO "django_geo_db_city" VALUES(15255,'Paw Paw','Paw Paw, Michigan',19187,40);
INSERT INTO "django_geo_db_city" VALUES(15256,'Plainwell','Plainwell, Michigan',19188,40);
INSERT INTO "django_geo_db_city" VALUES(15257,'Quincy','Quincy, Michigan',19190,40);
INSERT INTO "django_geo_db_city" VALUES(15258,'Richland','Richland, Michigan',19191,40);
INSERT INTO "django_geo_db_city" VALUES(15259,'Riverside','Riverside, Michigan',19192,40);
INSERT INTO "django_geo_db_city" VALUES(15260,'Saint Joseph','Saint Joseph, Michigan',19193,40);
INSERT INTO "django_geo_db_city" VALUES(15261,'Schoolcraft','Schoolcraft, Michigan',19194,40);
INSERT INTO "django_geo_db_city" VALUES(15262,'Scotts','Scotts, Michigan',19195,40);
INSERT INTO "django_geo_db_city" VALUES(15263,'Sherwood','Sherwood, Michigan',19196,40);
INSERT INTO "django_geo_db_city" VALUES(15264,'South Haven','South Haven, Michigan',19197,40);
INSERT INTO "django_geo_db_city" VALUES(15265,'Sturgis','Sturgis, Michigan',19198,40);
INSERT INTO "django_geo_db_city" VALUES(15266,'Tekonsha','Tekonsha, Michigan',19199,40);
INSERT INTO "django_geo_db_city" VALUES(15267,'Three Rivers','Three Rivers, Michigan',19200,40);
INSERT INTO "django_geo_db_city" VALUES(15268,'Union City','Union City, Michigan',19201,40);
INSERT INTO "django_geo_db_city" VALUES(15269,'Vandalia','Vandalia, Michigan',19202,40);
INSERT INTO "django_geo_db_city" VALUES(15270,'Vermontville','Vermontville, Michigan',19203,40);
INSERT INTO "django_geo_db_city" VALUES(15271,'Vicksburg','Vicksburg, Michigan',19204,40);
INSERT INTO "django_geo_db_city" VALUES(15272,'Watervliet','Watervliet, Michigan',19205,40);
INSERT INTO "django_geo_db_city" VALUES(15273,'White Pigeon','White Pigeon, Michigan',19206,40);
INSERT INTO "django_geo_db_city" VALUES(15274,'Baroda','Baroda, Michigan',19207,40);
INSERT INTO "django_geo_db_city" VALUES(15275,'Berrien Center','Berrien Center, Michigan',19208,40);
INSERT INTO "django_geo_db_city" VALUES(15276,'Berrien Springs','Berrien Springs, Michigan',19209,40);
INSERT INTO "django_geo_db_city" VALUES(15277,'Bridgman','Bridgman, Michigan',19210,40);
INSERT INTO "django_geo_db_city" VALUES(15278,'Buchanan','Buchanan, Michigan',19211,40);
INSERT INTO "django_geo_db_city" VALUES(15279,'Eau Claire','Eau Claire, Michigan',19212,40);
INSERT INTO "django_geo_db_city" VALUES(15280,'Edwardsburg','Edwardsburg, Michigan',19213,40);
INSERT INTO "django_geo_db_city" VALUES(15281,'Galien','Galien, Michigan',19214,40);
INSERT INTO "django_geo_db_city" VALUES(15282,'Harbert','Harbert, Michigan',19215,40);
INSERT INTO "django_geo_db_city" VALUES(15283,'Lakeside','Lakeside, Michigan',19216,40);
INSERT INTO "django_geo_db_city" VALUES(15284,'New Buffalo','New Buffalo, Michigan',19217,40);
INSERT INTO "django_geo_db_city" VALUES(15285,'New Troy','New Troy, Michigan',19218,40);
INSERT INTO "django_geo_db_city" VALUES(15286,'Niles','Niles, Michigan',19219,40);
INSERT INTO "django_geo_db_city" VALUES(15287,'Sawyer','Sawyer, Michigan',19220,40);
INSERT INTO "django_geo_db_city" VALUES(15288,'Sodus','Sodus, Michigan',19221,40);
INSERT INTO "django_geo_db_city" VALUES(15289,'Stevensville','Stevensville, Michigan',19222,40);
INSERT INTO "django_geo_db_city" VALUES(15290,'Three Oaks','Three Oaks, Michigan',19223,40);
INSERT INTO "django_geo_db_city" VALUES(15291,'Union Pier','Union Pier, Michigan',19224,40);
INSERT INTO "django_geo_db_city" VALUES(15292,'Union','Union, Michigan',19225,40);
INSERT INTO "django_geo_db_city" VALUES(15293,'Lyndon','Lyndon, Michigan',19226,40);
INSERT INTO "django_geo_db_city" VALUES(15294,'Dickson','Dickson, Michigan',19228,40);
INSERT INTO "django_geo_db_city" VALUES(15295,'Jackson','Jackson, Michigan',19229,40);
INSERT INTO "django_geo_db_city" VALUES(15296,'Addison','Addison, Michigan',19233,40);
INSERT INTO "django_geo_db_city" VALUES(15297,'Adrian','Adrian, Michigan',19234,40);
INSERT INTO "django_geo_db_city" VALUES(15298,'Albion','Albion, Michigan',19235,40);
INSERT INTO "django_geo_db_city" VALUES(15299,'Allen','Allen, Michigan',19237,40);
INSERT INTO "django_geo_db_city" VALUES(15300,'Blissfield','Blissfield, Michigan',19238,40);
INSERT INTO "django_geo_db_city" VALUES(15301,'Britton','Britton, Michigan',19239,40);
INSERT INTO "django_geo_db_city" VALUES(15302,'Brooklyn','Brooklyn, Michigan',19240,40);
INSERT INTO "django_geo_db_city" VALUES(15303,'Camden','Camden, Michigan',19241,40);
INSERT INTO "django_geo_db_city" VALUES(15304,'Cement City','Cement City, Michigan',19242,40);
INSERT INTO "django_geo_db_city" VALUES(15305,'Clarklake','Clarklake, Michigan',19243,40);
INSERT INTO "django_geo_db_city" VALUES(15306,'Clayton','Clayton, Michigan',19244,40);
INSERT INTO "django_geo_db_city" VALUES(15307,'Concord','Concord, Michigan',19246,40);
INSERT INTO "django_geo_db_city" VALUES(15308,'Deerfield','Deerfield, Michigan',19247,40);
INSERT INTO "django_geo_db_city" VALUES(15309,'Frontier','Frontier, Michigan',19248,40);
INSERT INTO "django_geo_db_city" VALUES(15310,'Grass Lake','Grass Lake, Michigan',19249,40);
INSERT INTO "django_geo_db_city" VALUES(15311,'Hanover','Hanover, Michigan',19250,40);
INSERT INTO "django_geo_db_city" VALUES(15312,'Hillsdale','Hillsdale, Michigan',19251,40);
INSERT INTO "django_geo_db_city" VALUES(15313,'Homer','Homer, Michigan',19252,40);
INSERT INTO "django_geo_db_city" VALUES(15314,'Horton','Horton, Michigan',19253,40);
INSERT INTO "django_geo_db_city" VALUES(15315,'Hudson','Hudson, Michigan',19254,40);
INSERT INTO "django_geo_db_city" VALUES(15316,'Jasper','Jasper, Michigan',19255,40);
INSERT INTO "django_geo_db_city" VALUES(15317,'Jerome','Jerome, Michigan',19256,40);
INSERT INTO "django_geo_db_city" VALUES(15318,'Jonesville','Jonesville, Michigan',19257,40);
INSERT INTO "django_geo_db_city" VALUES(15319,'Leslie','Leslie, Michigan',19258,40);
INSERT INTO "django_geo_db_city" VALUES(15320,'Litchfield','Litchfield, Michigan',19259,40);
INSERT INTO "django_geo_db_city" VALUES(15321,'Manitou Beach','Manitou Beach, Michigan',19260,40);
INSERT INTO "django_geo_db_city" VALUES(15322,'Michigan Center','Michigan Center, Michigan',19261,40);
INSERT INTO "django_geo_db_city" VALUES(15323,'Montgomery','Montgomery, Michigan',19262,40);
INSERT INTO "django_geo_db_city" VALUES(15324,'Morenci','Morenci, Michigan',19263,40);
INSERT INTO "django_geo_db_city" VALUES(15325,'Moscow','Moscow, Michigan',19264,40);
INSERT INTO "django_geo_db_city" VALUES(15326,'Mosherville','Mosherville, Michigan',19265,40);
INSERT INTO "django_geo_db_city" VALUES(15327,'Munith','Munith, Michigan',19266,40);
INSERT INTO "django_geo_db_city" VALUES(15328,'Napoleon','Napoleon, Michigan',19267,40);
INSERT INTO "django_geo_db_city" VALUES(15329,'North Adams','North Adams, Michigan',19268,40);
INSERT INTO "django_geo_db_city" VALUES(15330,'Norvell','Norvell, Michigan',19269,40);
INSERT INTO "django_geo_db_city" VALUES(15331,'Onondaga','Onondaga, Michigan',19270,40);
INSERT INTO "django_geo_db_city" VALUES(15332,'Onsted','Onsted, Michigan',19271,40);
INSERT INTO "django_geo_db_city" VALUES(15333,'Osseo','Osseo, Michigan',19272,40);
INSERT INTO "django_geo_db_city" VALUES(15334,'Ottawa Lake','Ottawa Lake, Michigan',19273,40);
INSERT INTO "django_geo_db_city" VALUES(15335,'Palmyra','Palmyra, Michigan',19274,40);
INSERT INTO "django_geo_db_city" VALUES(15336,'Parma','Parma, Michigan',19275,40);
INSERT INTO "django_geo_db_city" VALUES(15337,'Petersburg','Petersburg, Michigan',19276,40);
INSERT INTO "django_geo_db_city" VALUES(15338,'Pittsford','Pittsford, Michigan',19277,40);
INSERT INTO "django_geo_db_city" VALUES(15339,'Pleasant Lake','Pleasant Lake, Michigan',19278,40);
INSERT INTO "django_geo_db_city" VALUES(15340,'Reading','Reading, Michigan',19279,40);
INSERT INTO "django_geo_db_city" VALUES(15341,'Ridgeway','Ridgeway, Michigan',19280,40);
INSERT INTO "django_geo_db_city" VALUES(15342,'Riga','Riga, Michigan',19281,40);
INSERT INTO "django_geo_db_city" VALUES(15343,'Rives Junction','Rives Junction, Michigan',19282,40);
INSERT INTO "django_geo_db_city" VALUES(15344,'Rollin','Rollin, Michigan',19283,40);
INSERT INTO "django_geo_db_city" VALUES(15345,'Sand Creek','Sand Creek, Michigan',19284,40);
INSERT INTO "django_geo_db_city" VALUES(15346,'Seneca','Seneca, Michigan',19285,40);
INSERT INTO "django_geo_db_city" VALUES(15347,'Somerset','Somerset, Michigan',19286,40);
INSERT INTO "django_geo_db_city" VALUES(15348,'Somerset Center','Somerset Center, Michigan',19287,40);
INSERT INTO "django_geo_db_city" VALUES(15349,'Spring Arbor','Spring Arbor, Michigan',19288,40);
INSERT INTO "django_geo_db_city" VALUES(15350,'Springport','Springport, Michigan',19289,40);
INSERT INTO "django_geo_db_city" VALUES(15351,'Stockbridge','Stockbridge, Michigan',19290,40);
INSERT INTO "django_geo_db_city" VALUES(15352,'Tecumseh','Tecumseh, Michigan',19291,40);
INSERT INTO "django_geo_db_city" VALUES(15353,'Tipton','Tipton, Michigan',19292,40);
INSERT INTO "django_geo_db_city" VALUES(15354,'Waldron','Waldron, Michigan',19293,40);
INSERT INTO "django_geo_db_city" VALUES(15355,'Weston','Weston, Michigan',19294,40);
INSERT INTO "django_geo_db_city" VALUES(15356,'Ada','Ada, Michigan',19295,40);
INSERT INTO "django_geo_db_city" VALUES(15357,'Alto','Alto, Michigan',19296,40);
INSERT INTO "django_geo_db_city" VALUES(15358,'Bailey','Bailey, Michigan',19297,40);
INSERT INTO "django_geo_db_city" VALUES(15359,'Baldwin','Baldwin, Michigan',19298,40);
INSERT INTO "django_geo_db_city" VALUES(15360,'Barryton','Barryton, Michigan',19299,40);
INSERT INTO "django_geo_db_city" VALUES(15361,'Belmont','Belmont, Michigan',19300,40);
INSERT INTO "django_geo_db_city" VALUES(15362,'Big Rapids','Big Rapids, Michigan',19301,40);
INSERT INTO "django_geo_db_city" VALUES(15363,'Bitely','Bitely, Michigan',19302,40);
INSERT INTO "django_geo_db_city" VALUES(15364,'Blanchard','Blanchard, Michigan',19303,40);
INSERT INTO "django_geo_db_city" VALUES(15365,'Bradley','Bradley, Michigan',19304,40);
INSERT INTO "django_geo_db_city" VALUES(15366,'Brohman','Brohman, Michigan',19305,40);
INSERT INTO "django_geo_db_city" VALUES(15367,'Burnips','Burnips, Michigan',19306,40);
INSERT INTO "django_geo_db_city" VALUES(15368,'Byron Center','Byron Center, Michigan',19307,40);
INSERT INTO "django_geo_db_city" VALUES(15369,'Caledonia','Caledonia, Michigan',19308,40);
INSERT INTO "django_geo_db_city" VALUES(15370,'Cannonsburg','Cannonsburg, Michigan',19309,40);
INSERT INTO "django_geo_db_city" VALUES(15371,'Casnovia','Casnovia, Michigan',19310,40);
INSERT INTO "django_geo_db_city" VALUES(15372,'Cedar Springs','Cedar Springs, Michigan',19311,40);
INSERT INTO "django_geo_db_city" VALUES(15373,'Chippewa Lake','Chippewa Lake, Michigan',19312,40);
INSERT INTO "django_geo_db_city" VALUES(15374,'Comstock Park','Comstock Park, Michigan',19313,40);
INSERT INTO "django_geo_db_city" VALUES(15375,'Coral','Coral, Michigan',19314,40);
INSERT INTO "django_geo_db_city" VALUES(15376,'Dorr','Dorr, Michigan',19315,40);
INSERT INTO "django_geo_db_city" VALUES(15377,'Freeport','Freeport, Michigan',19316,40);
INSERT INTO "django_geo_db_city" VALUES(15378,'Gowen','Gowen, Michigan',19317,40);
INSERT INTO "django_geo_db_city" VALUES(15379,'Grant','Grant, Michigan',19318,40);
INSERT INTO "django_geo_db_city" VALUES(15380,'Hopkins','Hopkins, Michigan',19319,40);
INSERT INTO "django_geo_db_city" VALUES(15381,'Howard City','Howard City, Michigan',19320,40);
INSERT INTO "django_geo_db_city" VALUES(15382,'Kent City','Kent City, Michigan',19321,40);
INSERT INTO "django_geo_db_city" VALUES(15383,'Lowell','Lowell, Michigan',19322,40);
INSERT INTO "django_geo_db_city" VALUES(15384,'Mecosta','Mecosta, Michigan',19323,40);
INSERT INTO "django_geo_db_city" VALUES(15385,'Middleville','Middleville, Michigan',19324,40);
INSERT INTO "django_geo_db_city" VALUES(15386,'Moline','Moline, Michigan',19325,40);
INSERT INTO "django_geo_db_city" VALUES(15387,'Morley','Morley, Michigan',19326,40);
INSERT INTO "django_geo_db_city" VALUES(15388,'Newaygo','Newaygo, Michigan',19327,40);
INSERT INTO "django_geo_db_city" VALUES(15389,'Paris','Paris, Michigan',19328,40);
INSERT INTO "django_geo_db_city" VALUES(15390,'Pierson','Pierson, Michigan',19329,40);
INSERT INTO "django_geo_db_city" VALUES(15391,'Remus','Remus, Michigan',19330,40);
INSERT INTO "django_geo_db_city" VALUES(15392,'Rockford','Rockford, Michigan',19331,40);
INSERT INTO "django_geo_db_city" VALUES(15393,'Rodney','Rodney, Michigan',19332,40);
INSERT INTO "django_geo_db_city" VALUES(15394,'Sand Lake','Sand Lake, Michigan',19333,40);
INSERT INTO "django_geo_db_city" VALUES(15395,'Shelbyville','Shelbyville, Michigan',19334,40);
INSERT INTO "django_geo_db_city" VALUES(15396,'Sparta','Sparta, Michigan',19335,40);
INSERT INTO "django_geo_db_city" VALUES(15397,'Stanwood','Stanwood, Michigan',19336,40);
INSERT INTO "django_geo_db_city" VALUES(15398,'Trufant','Trufant, Michigan',19337,40);
INSERT INTO "django_geo_db_city" VALUES(15399,'Wayland','Wayland, Michigan',19338,40);
INSERT INTO "django_geo_db_city" VALUES(15400,'White Cloud','White Cloud, Michigan',19339,40);
INSERT INTO "django_geo_db_city" VALUES(15401,'Slagle','Slagle, Michigan',19341,40);
INSERT INTO "django_geo_db_city" VALUES(15402,'Allendale','Allendale, Michigan',19343,40);
INSERT INTO "django_geo_db_city" VALUES(15403,'Branch','Branch, Michigan',19344,40);
INSERT INTO "django_geo_db_city" VALUES(15404,'Conklin','Conklin, Michigan',19345,40);
INSERT INTO "django_geo_db_city" VALUES(15405,'Coopersville','Coopersville, Michigan',19346,40);
INSERT INTO "django_geo_db_city" VALUES(15406,'Custer','Custer, Michigan',19347,40);
INSERT INTO "django_geo_db_city" VALUES(15407,'Douglas','Douglas, Michigan',19348,40);
INSERT INTO "django_geo_db_city" VALUES(15408,'Fennville','Fennville, Michigan',19349,40);
INSERT INTO "django_geo_db_city" VALUES(15409,'Ferrysburg','Ferrysburg, Michigan',19350,40);
INSERT INTO "django_geo_db_city" VALUES(15410,'Fountain','Fountain, Michigan',19351,40);
INSERT INTO "django_geo_db_city" VALUES(15411,'Free Soil','Free Soil, Michigan',19352,40);
INSERT INTO "django_geo_db_city" VALUES(15412,'Fremont','Fremont, Michigan',19353,40);
INSERT INTO "django_geo_db_city" VALUES(15413,'Fruitport','Fruitport, Michigan',19355,40);
INSERT INTO "django_geo_db_city" VALUES(15414,'Glenn','Glenn, Michigan',19356,40);
INSERT INTO "django_geo_db_city" VALUES(15415,'Grand Haven','Grand Haven, Michigan',19357,40);
INSERT INTO "django_geo_db_city" VALUES(15416,'Grandville','Grandville, Michigan',19358,40);
INSERT INTO "django_geo_db_city" VALUES(15417,'Hamilton','Hamilton, Michigan',19359,40);
INSERT INTO "django_geo_db_city" VALUES(15418,'Hart','Hart, Michigan',19360,40);
INSERT INTO "django_geo_db_city" VALUES(15419,'Hesperia','Hesperia, Michigan',19361,40);
INSERT INTO "django_geo_db_city" VALUES(15420,'Holland','Holland, Michigan',19362,40);
INSERT INTO "django_geo_db_city" VALUES(15421,'Holton','Holton, Michigan',19365,40);
INSERT INTO "django_geo_db_city" VALUES(15422,'Hudsonville','Hudsonville, Michigan',19366,40);
INSERT INTO "django_geo_db_city" VALUES(15423,'Jamestown','Jamestown, Michigan',19367,40);
INSERT INTO "django_geo_db_city" VALUES(15424,'Jenison','Jenison, Michigan',19368,40);
INSERT INTO "django_geo_db_city" VALUES(15425,'Lamont','Lamont, Michigan',19369,40);
INSERT INTO "django_geo_db_city" VALUES(15426,'Ludington','Ludington, Michigan',19370,40);
INSERT INTO "django_geo_db_city" VALUES(15427,'Macatawa','Macatawa, Michigan',19371,40);
INSERT INTO "django_geo_db_city" VALUES(15428,'Marne','Marne, Michigan',19372,40);
INSERT INTO "django_geo_db_city" VALUES(15429,'Mears','Mears, Michigan',19373,40);
INSERT INTO "django_geo_db_city" VALUES(15430,'Montague','Montague, Michigan',19374,40);
INSERT INTO "django_geo_db_city" VALUES(15431,'Muskegon','Muskegon, Michigan',19375,40);
INSERT INTO "django_geo_db_city" VALUES(15432,'New Era','New Era, Michigan',19381,40);
INSERT INTO "django_geo_db_city" VALUES(15433,'Nunica','Nunica, Michigan',19382,40);
INSERT INTO "django_geo_db_city" VALUES(15434,'Pentwater','Pentwater, Michigan',19383,40);
INSERT INTO "django_geo_db_city" VALUES(15435,'Pullman','Pullman, Michigan',19384,40);
INSERT INTO "django_geo_db_city" VALUES(15436,'Ravenna','Ravenna, Michigan',19385,40);
INSERT INTO "django_geo_db_city" VALUES(15437,'Rothbury','Rothbury, Michigan',19386,40);
INSERT INTO "django_geo_db_city" VALUES(15438,'Saugatuck','Saugatuck, Michigan',19387,40);
INSERT INTO "django_geo_db_city" VALUES(15439,'Scottville','Scottville, Michigan',19388,40);
INSERT INTO "django_geo_db_city" VALUES(15440,'Shelby','Shelby, Michigan',19389,40);
INSERT INTO "django_geo_db_city" VALUES(15441,'Spring Lake','Spring Lake, Michigan',19390,40);
INSERT INTO "django_geo_db_city" VALUES(15442,'Twin Lake','Twin Lake, Michigan',19391,40);
INSERT INTO "django_geo_db_city" VALUES(15443,'Walhalla','Walhalla, Michigan',19392,40);
INSERT INTO "django_geo_db_city" VALUES(15444,'Walkerville','Walkerville, Michigan',19393,40);
INSERT INTO "django_geo_db_city" VALUES(15445,'West Olive','West Olive, Michigan',19394,40);
INSERT INTO "django_geo_db_city" VALUES(15446,'Whitehall','Whitehall, Michigan',19395,40);
INSERT INTO "django_geo_db_city" VALUES(15447,'Wabaningo','Wabaningo, Michigan',19378,40);
INSERT INTO "django_geo_db_city" VALUES(15448,'Zeeland','Zeeland, Michigan',19396,40);
INSERT INTO "django_geo_db_city" VALUES(15449,'Grand Rapids','Grand Rapids, Michigan',19397,40);
INSERT INTO "django_geo_db_city" VALUES(15450,'Glen Arbor','Glen Arbor, Michigan',19410,40);
INSERT INTO "django_geo_db_city" VALUES(15451,'Newkirk','Newkirk, Michigan',19411,40);
INSERT INTO "django_geo_db_city" VALUES(15452,'Colfax','Colfax, Michigan',19412,40);
INSERT INTO "django_geo_db_city" VALUES(15453,'Whitewater','Whitewater, Michigan',19413,40);
INSERT INTO "django_geo_db_city" VALUES(15454,'Cadillac','Cadillac, Michigan',19414,40);
INSERT INTO "django_geo_db_city" VALUES(15455,'Acme','Acme, Michigan',19415,40);
INSERT INTO "django_geo_db_city" VALUES(15456,'Alba','Alba, Michigan',19416,40);
INSERT INTO "django_geo_db_city" VALUES(15457,'Alden','Alden, Michigan',19417,40);
INSERT INTO "django_geo_db_city" VALUES(15458,'Arcadia','Arcadia, Michigan',19418,40);
INSERT INTO "django_geo_db_city" VALUES(15459,'Bear Lake','Bear Lake, Michigan',19419,40);
INSERT INTO "django_geo_db_city" VALUES(15460,'Bellaire','Bellaire, Michigan',19420,40);
INSERT INTO "django_geo_db_city" VALUES(15461,'Benzonia','Benzonia, Michigan',19421,40);
INSERT INTO "django_geo_db_city" VALUES(15462,'Beulah','Beulah, Michigan',19422,40);
INSERT INTO "django_geo_db_city" VALUES(15463,'Boon','Boon, Michigan',19423,40);
INSERT INTO "django_geo_db_city" VALUES(15464,'Brethren','Brethren, Michigan',19424,40);
INSERT INTO "django_geo_db_city" VALUES(15465,'Buckley','Buckley, Michigan',19425,40);
INSERT INTO "django_geo_db_city" VALUES(15466,'Cedar','Cedar, Michigan',19426,40);
INSERT INTO "django_geo_db_city" VALUES(15467,'Central Lake','Central Lake, Michigan',19427,40);
INSERT INTO "django_geo_db_city" VALUES(15468,'Chase','Chase, Michigan',19428,40);
INSERT INTO "django_geo_db_city" VALUES(15469,'Copemish','Copemish, Michigan',19429,40);
INSERT INTO "django_geo_db_city" VALUES(15470,'Eastlake','Eastlake, Michigan',19430,40);
INSERT INTO "django_geo_db_city" VALUES(15471,'Eastport','Eastport, Michigan',19431,40);
INSERT INTO "django_geo_db_city" VALUES(15472,'Elberta','Elberta, Michigan',19432,40);
INSERT INTO "django_geo_db_city" VALUES(15473,'Elk Rapids','Elk Rapids, Michigan',19433,40);
INSERT INTO "django_geo_db_city" VALUES(15474,'Empire','Empire, Michigan',19434,40);
INSERT INTO "django_geo_db_city" VALUES(15475,'Evart','Evart, Michigan',19435,40);
INSERT INTO "django_geo_db_city" VALUES(15476,'Falmouth','Falmouth, Michigan',19436,40);
INSERT INTO "django_geo_db_city" VALUES(15477,'Fife Lake','Fife Lake, Michigan',19437,40);
INSERT INTO "django_geo_db_city" VALUES(15478,'Filer City','Filer City, Michigan',19438,40);
INSERT INTO "django_geo_db_city" VALUES(15479,'Frankfort','Frankfort, Michigan',19439,40);
INSERT INTO "django_geo_db_city" VALUES(15480,'Grawn','Grawn, Michigan',19441,40);
INSERT INTO "django_geo_db_city" VALUES(15481,'Harrietta','Harrietta, Michigan',19442,40);
INSERT INTO "django_geo_db_city" VALUES(15482,'Hersey','Hersey, Michigan',19443,40);
INSERT INTO "django_geo_db_city" VALUES(15483,'Honor','Honor, Michigan',19444,40);
INSERT INTO "django_geo_db_city" VALUES(15484,'Idlewild','Idlewild, Michigan',19445,40);
INSERT INTO "django_geo_db_city" VALUES(15485,'Interlochen','Interlochen, Michigan',19446,40);
INSERT INTO "django_geo_db_city" VALUES(15486,'Irons','Irons, Michigan',19447,40);
INSERT INTO "django_geo_db_city" VALUES(15487,'Kaleva','Kaleva, Michigan',19448,40);
INSERT INTO "django_geo_db_city" VALUES(15488,'Kalkaska','Kalkaska, Michigan',19449,40);
INSERT INTO "django_geo_db_city" VALUES(15489,'Paradise','Paradise, Michigan',19450,40);
INSERT INTO "django_geo_db_city" VALUES(15490,'Kewadin','Kewadin, Michigan',19451,40);
INSERT INTO "django_geo_db_city" VALUES(15491,'Kingsley','Kingsley, Michigan',19452,40);
INSERT INTO "django_geo_db_city" VALUES(15492,'Lake Ann','Lake Ann, Michigan',19453,40);
INSERT INTO "django_geo_db_city" VALUES(15493,'Lake City','Lake City, Michigan',19454,40);
INSERT INTO "django_geo_db_city" VALUES(15494,'Yates','Yates, Michigan',19455,40);
INSERT INTO "django_geo_db_city" VALUES(15495,'Lake Leelanau','Lake Leelanau, Michigan',19456,40);
INSERT INTO "django_geo_db_city" VALUES(15496,'Leland','Leland, Michigan',19457,40);
INSERT INTO "django_geo_db_city" VALUES(15497,'Leroy','Leroy, Michigan',19458,40);
INSERT INTO "django_geo_db_city" VALUES(15498,'Luther','Luther, Michigan',19459,40);
INSERT INTO "django_geo_db_city" VALUES(15499,'McBain','McBain, Michigan',19460,40);
INSERT INTO "django_geo_db_city" VALUES(15500,'Mancelona','Mancelona, Michigan',19461,40);
INSERT INTO "django_geo_db_city" VALUES(15501,'Manistee','Manistee, Michigan',19462,40);
INSERT INTO "django_geo_db_city" VALUES(15502,'Manton','Manton, Michigan',19463,40);
INSERT INTO "django_geo_db_city" VALUES(15503,'Maple City','Maple City, Michigan',19464,40);
INSERT INTO "django_geo_db_city" VALUES(15504,'Marion','Marion, Michigan',19465,40);
INSERT INTO "django_geo_db_city" VALUES(15505,'Mayfield','Mayfield, Michigan',19466,40);
INSERT INTO "django_geo_db_city" VALUES(15506,'Merritt','Merritt, Michigan',19467,40);
INSERT INTO "django_geo_db_city" VALUES(15507,'Mesick','Mesick, Michigan',19468,40);
INSERT INTO "django_geo_db_city" VALUES(15508,'Northport','Northport, Michigan',19469,40);
INSERT INTO "django_geo_db_city" VALUES(15509,'Old Mission','Old Mission, Michigan',19470,40);
INSERT INTO "django_geo_db_city" VALUES(15510,'Omena','Omena, Michigan',19471,40);
INSERT INTO "django_geo_db_city" VALUES(15511,'Onekama','Onekama, Michigan',19472,40);
INSERT INTO "django_geo_db_city" VALUES(15512,'Rapid City','Rapid City, Michigan',19473,40);
INSERT INTO "django_geo_db_city" VALUES(15513,'Reed City','Reed City, Michigan',19474,40);
INSERT INTO "django_geo_db_city" VALUES(15514,'Sears','Sears, Michigan',19475,40);
INSERT INTO "django_geo_db_city" VALUES(15515,'South Boardman','South Boardman, Michigan',19476,40);
INSERT INTO "django_geo_db_city" VALUES(15516,'Suttons Bay','Suttons Bay, Michigan',19477,40);
INSERT INTO "django_geo_db_city" VALUES(15517,'Thompsonville','Thompsonville, Michigan',19478,40);
INSERT INTO "django_geo_db_city" VALUES(15518,'Traverse City','Traverse City, Michigan',19479,40);
INSERT INTO "django_geo_db_city" VALUES(15519,'Tustin','Tustin, Michigan',19482,40);
INSERT INTO "django_geo_db_city" VALUES(15520,'Wellston','Wellston, Michigan',19483,40);
INSERT INTO "django_geo_db_city" VALUES(15521,'Williamsburg','Williamsburg, Michigan',19484,40);
INSERT INTO "django_geo_db_city" VALUES(15522,'Mackinaw City','Mackinaw City, Michigan',19486,40);
INSERT INTO "django_geo_db_city" VALUES(15523,'Afton','Afton, Michigan',19487,40);
INSERT INTO "django_geo_db_city" VALUES(15524,'Alanson','Alanson, Michigan',19488,40);
INSERT INTO "django_geo_db_city" VALUES(15525,'Alpena','Alpena, Michigan',19489,40);
INSERT INTO "django_geo_db_city" VALUES(15526,'Atlanta','Atlanta, Michigan',19490,40);
INSERT INTO "django_geo_db_city" VALUES(15527,'Barbeau','Barbeau, Michigan',19491,40);
INSERT INTO "django_geo_db_city" VALUES(15528,'Bay Shore','Bay Shore, Michigan',19492,40);
INSERT INTO "django_geo_db_city" VALUES(15529,'Boyne City','Boyne City, Michigan',19493,40);
INSERT INTO "django_geo_db_city" VALUES(15530,'Boyne Falls','Boyne Falls, Michigan',19494,40);
INSERT INTO "django_geo_db_city" VALUES(15531,'Brimley','Brimley, Michigan',19495,40);
INSERT INTO "django_geo_db_city" VALUES(15532,'Brutus','Brutus, Michigan',19496,40);
INSERT INTO "django_geo_db_city" VALUES(15533,'Burt Lake','Burt Lake, Michigan',19497,40);
INSERT INTO "django_geo_db_city" VALUES(15534,'Carp Lake','Carp Lake, Michigan',19498,40);
INSERT INTO "django_geo_db_city" VALUES(15535,'Cedarville','Cedarville, Michigan',19499,40);
INSERT INTO "django_geo_db_city" VALUES(15536,'Charlevoix','Charlevoix, Michigan',19500,40);
INSERT INTO "django_geo_db_city" VALUES(15537,'Cheboygan','Cheboygan, Michigan',19501,40);
INSERT INTO "django_geo_db_city" VALUES(15538,'Conway','Conway, Michigan',19502,40);
INSERT INTO "django_geo_db_city" VALUES(15539,'Cross Village','Cross Village, Michigan',19503,40);
INSERT INTO "django_geo_db_city" VALUES(15540,'Dafter','Dafter, Michigan',19504,40);
INSERT INTO "django_geo_db_city" VALUES(15541,'De Tour Village','De Tour Village, Michigan',19505,40);
INSERT INTO "django_geo_db_city" VALUES(15542,'Drummond Island','Drummond Island, Michigan',19506,40);
INSERT INTO "django_geo_db_city" VALUES(15543,'East Jordan','East Jordan, Michigan',19507,40);
INSERT INTO "django_geo_db_city" VALUES(15544,'Eckerman','Eckerman, Michigan',19508,40);
INSERT INTO "django_geo_db_city" VALUES(15545,'Ellsworth','Ellsworth, Michigan',19509,40);
INSERT INTO "django_geo_db_city" VALUES(15546,'Elmira','Elmira, Michigan',19510,40);
INSERT INTO "django_geo_db_city" VALUES(15547,'Forest','Forest, Michigan',19511,40);
INSERT INTO "django_geo_db_city" VALUES(15548,'Frederic','Frederic, Michigan',19512,40);
INSERT INTO "django_geo_db_city" VALUES(15549,'Gaylord','Gaylord, Michigan',19513,40);
INSERT INTO "django_geo_db_city" VALUES(15550,'Goetzville','Goetzville, Michigan',19515,40);
INSERT INTO "django_geo_db_city" VALUES(15551,'Good Hart','Good Hart, Michigan',19516,40);
INSERT INTO "django_geo_db_city" VALUES(15552,'Grayling','Grayling, Michigan',19517,40);
INSERT INTO "django_geo_db_city" VALUES(15553,'Harbor Springs','Harbor Springs, Michigan',19519,40);
INSERT INTO "django_geo_db_city" VALUES(15554,'Hawks','Hawks, Michigan',19520,40);
INSERT INTO "django_geo_db_city" VALUES(15555,'Herron','Herron, Michigan',19521,40);
INSERT INTO "django_geo_db_city" VALUES(15556,'Hessel','Hessel, Michigan',19522,40);
INSERT INTO "django_geo_db_city" VALUES(15557,'Hillman','Hillman, Michigan',19523,40);
INSERT INTO "django_geo_db_city" VALUES(15558,'Hubbard Lake','Hubbard Lake, Michigan',19524,40);
INSERT INTO "django_geo_db_city" VALUES(15559,'Hulbert','Hulbert, Michigan',19525,40);
INSERT INTO "django_geo_db_city" VALUES(15560,'Indian River','Indian River, Michigan',19526,40);
INSERT INTO "django_geo_db_city" VALUES(15561,'Lewiston','Lewiston, Michigan',19527,40);
INSERT INTO "django_geo_db_city" VALUES(15562,'Johannesburg','Johannesburg, Michigan',19528,40);
INSERT INTO "django_geo_db_city" VALUES(15563,'Kinross','Kinross, Michigan',19529,40);
INSERT INTO "django_geo_db_city" VALUES(15564,'Lachine','Lachine, Michigan',19530,40);
INSERT INTO "django_geo_db_city" VALUES(15565,'Levering','Levering, Michigan',19531,40);
INSERT INTO "django_geo_db_city" VALUES(15566,'Mackinac Island','Mackinac Island, Michigan',19533,40);
INSERT INTO "django_geo_db_city" VALUES(15567,'Greenwood','Greenwood, Michigan',19534,40);
INSERT INTO "django_geo_db_city" VALUES(15568,'Millersburg','Millersburg, Michigan',19535,40);
INSERT INTO "django_geo_db_city" VALUES(15569,'Moran','Moran, Michigan',19536,40);
INSERT INTO "django_geo_db_city" VALUES(15570,'Mullett Lake','Mullett Lake, Michigan',19537,40);
INSERT INTO "django_geo_db_city" VALUES(15571,'Naubinway','Naubinway, Michigan',19538,40);
INSERT INTO "django_geo_db_city" VALUES(15572,'Oden','Oden, Michigan',19539,40);
INSERT INTO "django_geo_db_city" VALUES(15573,'Onaway','Onaway, Michigan',19540,40);
INSERT INTO "django_geo_db_city" VALUES(15574,'Ossineke','Ossineke, Michigan',19541,40);
INSERT INTO "django_geo_db_city" VALUES(15575,'Pellston','Pellston, Michigan',19543,40);
INSERT INTO "django_geo_db_city" VALUES(15576,'Petoskey','Petoskey, Michigan',19544,40);
INSERT INTO "django_geo_db_city" VALUES(15577,'Pickford','Pickford, Michigan',19545,40);
INSERT INTO "django_geo_db_city" VALUES(15578,'Pointe Aux Pins','Pointe Aux Pins, Michigan',19546,40);
INSERT INTO "django_geo_db_city" VALUES(15579,'Posen','Posen, Michigan',19547,40);
INSERT INTO "django_geo_db_city" VALUES(15580,'Presque Isle','Presque Isle, Michigan',19548,40);
INSERT INTO "django_geo_db_city" VALUES(15581,'Rogers City','Rogers City, Michigan',19550,40);
INSERT INTO "django_geo_db_city" VALUES(15582,'Rudyard','Rudyard, Michigan',19551,40);
INSERT INTO "django_geo_db_city" VALUES(15583,'Saint Ignace','Saint Ignace, Michigan',19552,40);
INSERT INTO "django_geo_db_city" VALUES(15584,'Beaver Island','Beaver Island, Michigan',19553,40);
INSERT INTO "django_geo_db_city" VALUES(15585,'Sault Sainte Marie','Sault Sainte Marie, Michigan',19554,40);
INSERT INTO "django_geo_db_city" VALUES(15586,'Kincheloe','Kincheloe, Michigan',19549,40);
INSERT INTO "django_geo_db_city" VALUES(15587,'Strongs','Strongs, Michigan',19557,40);
INSERT INTO "django_geo_db_city" VALUES(15588,'Topinabee','Topinabee, Michigan',19558,40);
INSERT INTO "django_geo_db_city" VALUES(15589,'Tower','Tower, Michigan',19559,40);
INSERT INTO "django_geo_db_city" VALUES(15590,'Trout Lake','Trout Lake, Michigan',19560,40);
INSERT INTO "django_geo_db_city" VALUES(15591,'Vanderbilt','Vanderbilt, Michigan',19561,40);
INSERT INTO "django_geo_db_city" VALUES(15592,'Walloon Lake','Walloon Lake, Michigan',19562,40);
INSERT INTO "django_geo_db_city" VALUES(15593,'Waters','Waters, Michigan',19563,40);
INSERT INTO "django_geo_db_city" VALUES(15594,'Wolverine','Wolverine, Michigan',19564,40);
INSERT INTO "django_geo_db_city" VALUES(15595,'Iron Mountain','Iron Mountain, Michigan',19565,40);
INSERT INTO "django_geo_db_city" VALUES(15596,'Kingsford','Kingsford, Michigan',19566,40);
INSERT INTO "django_geo_db_city" VALUES(15597,'Allouez','Allouez, Michigan',19567,40);
INSERT INTO "django_geo_db_city" VALUES(15598,'Au Train','Au Train, Michigan',19568,40);
INSERT INTO "django_geo_db_city" VALUES(15599,'Bark River','Bark River, Michigan',19569,40);
INSERT INTO "django_geo_db_city" VALUES(15600,'Big Bay','Big Bay, Michigan',19570,40);
INSERT INTO "django_geo_db_city" VALUES(15601,'Carney','Carney, Michigan',19571,40);
INSERT INTO "django_geo_db_city" VALUES(15602,'Cedar River','Cedar River, Michigan',19572,40);
INSERT INTO "django_geo_db_city" VALUES(15603,'Champion','Champion, Michigan',19573,40);
INSERT INTO "django_geo_db_city" VALUES(15604,'Channing','Channing, Michigan',19574,40);
INSERT INTO "django_geo_db_city" VALUES(15605,'Chatham','Chatham, Michigan',19575,40);
INSERT INTO "django_geo_db_city" VALUES(15606,'Cooks','Cooks, Michigan',19576,40);
INSERT INTO "django_geo_db_city" VALUES(15607,'Cornell','Cornell, Michigan',19577,40);
INSERT INTO "django_geo_db_city" VALUES(15608,'Arnold','Arnold, Michigan',19578,40);
INSERT INTO "django_geo_db_city" VALUES(15609,'Curtis','Curtis, Michigan',19579,40);
INSERT INTO "django_geo_db_city" VALUES(15610,'Daggett','Daggett, Michigan',19580,40);
INSERT INTO "django_geo_db_city" VALUES(15611,'Deerton','Deerton, Michigan',19581,40);
INSERT INTO "django_geo_db_city" VALUES(15612,'Eben Junction','Eben Junction, Michigan',19582,40);
INSERT INTO "django_geo_db_city" VALUES(15613,'Rumely','Rumely, Michigan',19583,40);
INSERT INTO "django_geo_db_city" VALUES(15614,'Engadine','Engadine, Michigan',19584,40);
INSERT INTO "django_geo_db_city" VALUES(15615,'Escanaba','Escanaba, Michigan',19585,40);
INSERT INTO "django_geo_db_city" VALUES(15616,'Felch','Felch, Michigan',19586,40);
INSERT INTO "django_geo_db_city" VALUES(15617,'Little Lake','Little Lake, Michigan',19587,40);
INSERT INTO "django_geo_db_city" VALUES(15618,'Foster City','Foster City, Michigan',19588,40);
INSERT INTO "django_geo_db_city" VALUES(15619,'Garden','Garden, Michigan',19589,40);
INSERT INTO "django_geo_db_city" VALUES(15620,'Germfask','Germfask, Michigan',19590,40);
INSERT INTO "django_geo_db_city" VALUES(15621,'Gladstone','Gladstone, Michigan',19591,40);
INSERT INTO "django_geo_db_city" VALUES(15622,'Gould City','Gould City, Michigan',19592,40);
INSERT INTO "django_geo_db_city" VALUES(15623,'Grand Marais','Grand Marais, Michigan',19593,40);
INSERT INTO "django_geo_db_city" VALUES(15624,'Gulliver','Gulliver, Michigan',19594,40);
INSERT INTO "django_geo_db_city" VALUES(15625,'Gwinn','Gwinn, Michigan',19595,40);
INSERT INTO "django_geo_db_city" VALUES(15626,'Harris','Harris, Michigan',19596,40);
INSERT INTO "django_geo_db_city" VALUES(15627,'Hermansville','Hermansville, Michigan',19597,40);
INSERT INTO "django_geo_db_city" VALUES(15628,'Ingalls','Ingalls, Michigan',19598,40);
INSERT INTO "django_geo_db_city" VALUES(15629,'Ishpeming','Ishpeming, Michigan',19599,40);
INSERT INTO "django_geo_db_city" VALUES(15630,'Loretto','Loretto, Michigan',19600,40);
INSERT INTO "django_geo_db_city" VALUES(15631,'McMillan','McMillan, Michigan',19601,40);
INSERT INTO "django_geo_db_city" VALUES(15632,'Manistique','Manistique, Michigan',19602,40);
INSERT INTO "django_geo_db_city" VALUES(15633,'Marquette','Marquette, Michigan',19603,40);
INSERT INTO "django_geo_db_city" VALUES(15634,'Menominee','Menominee, Michigan',19604,40);
INSERT INTO "django_geo_db_city" VALUES(15635,'Michigamme','Michigamme, Michigan',19605,40);
INSERT INTO "django_geo_db_city" VALUES(15636,'Munising','Munising, Michigan',19606,40);
INSERT INTO "django_geo_db_city" VALUES(15637,'Nadeau','Nadeau, Michigan',19607,40);
INSERT INTO "django_geo_db_city" VALUES(15638,'Nahma','Nahma, Michigan',19608,40);
INSERT INTO "django_geo_db_city" VALUES(15639,'National Mine','National Mine, Michigan',19578,40);
INSERT INTO "django_geo_db_city" VALUES(15640,'Negaunee','Negaunee, Michigan',19609,40);
INSERT INTO "django_geo_db_city" VALUES(15641,'Newberry','Newberry, Michigan',19610,40);
INSERT INTO "django_geo_db_city" VALUES(15642,'Wells','Wells, Michigan',19611,40);
INSERT INTO "django_geo_db_city" VALUES(15643,'Norway','Norway, Michigan',19612,40);
INSERT INTO "django_geo_db_city" VALUES(15644,'Palmer','Palmer, Michigan',19613,40);
INSERT INTO "django_geo_db_city" VALUES(15645,'Perkins','Perkins, Michigan',19614,40);
INSERT INTO "django_geo_db_city" VALUES(15646,'Perronville','Perronville, Michigan',19615,40);
INSERT INTO "django_geo_db_city" VALUES(15647,'Powers','Powers, Michigan',19616,40);
INSERT INTO "django_geo_db_city" VALUES(15648,'Quinnesec','Quinnesec, Michigan',19617,40);
INSERT INTO "django_geo_db_city" VALUES(15649,'Ralph','Ralph, Michigan',19618,40);
INSERT INTO "django_geo_db_city" VALUES(15650,'Rapid River','Rapid River, Michigan',19619,40);
INSERT INTO "django_geo_db_city" VALUES(15651,'Republic','Republic, Michigan',19620,40);
INSERT INTO "django_geo_db_city" VALUES(15652,'Rock','Rock, Michigan',19621,40);
INSERT INTO "django_geo_db_city" VALUES(15653,'Sagola','Sagola, Michigan',19622,40);
INSERT INTO "django_geo_db_city" VALUES(15654,'Seney','Seney, Michigan',19623,40);
INSERT INTO "django_geo_db_city" VALUES(15655,'Shingleton','Shingleton, Michigan',19624,40);
INSERT INTO "django_geo_db_city" VALUES(15656,'Skandia','Skandia, Michigan',19625,40);
INSERT INTO "django_geo_db_city" VALUES(15657,'Spalding','Spalding, Michigan',19626,40);
INSERT INTO "django_geo_db_city" VALUES(15658,'Stephenson','Stephenson, Michigan',19627,40);
INSERT INTO "django_geo_db_city" VALUES(15659,'Trenary','Trenary, Michigan',19628,40);
INSERT INTO "django_geo_db_city" VALUES(15660,'Vulcan','Vulcan, Michigan',19629,40);
INSERT INTO "django_geo_db_city" VALUES(15661,'Wallace','Wallace, Michigan',19630,40);
INSERT INTO "django_geo_db_city" VALUES(15662,'Wetmore','Wetmore, Michigan',19632,40);
INSERT INTO "django_geo_db_city" VALUES(15663,'Wilson','Wilson, Michigan',19633,40);
INSERT INTO "django_geo_db_city" VALUES(15664,'Ahmeek','Ahmeek, Michigan',19634,40);
INSERT INTO "django_geo_db_city" VALUES(15665,'Alpha','Alpha, Michigan',19635,40);
INSERT INTO "django_geo_db_city" VALUES(15666,'Amasa','Amasa, Michigan',19636,40);
INSERT INTO "django_geo_db_city" VALUES(15667,'Atlantic Mine','Atlantic Mine, Michigan',19637,40);
INSERT INTO "django_geo_db_city" VALUES(15668,'Baraga','Baraga, Michigan',19638,40);
INSERT INTO "django_geo_db_city" VALUES(15669,'Bergland','Bergland, Michigan',19639,40);
INSERT INTO "django_geo_db_city" VALUES(15670,'Bessemer','Bessemer, Michigan',19640,40);
INSERT INTO "django_geo_db_city" VALUES(15671,'Bruce Crossing','Bruce Crossing, Michigan',19641,40);
INSERT INTO "django_geo_db_city" VALUES(15672,'Calumet','Calumet, Michigan',19642,40);
INSERT INTO "django_geo_db_city" VALUES(15673,'Caspian','Caspian, Michigan',19643,40);
INSERT INTO "django_geo_db_city" VALUES(15674,'Chassell','Chassell, Michigan',19644,40);
INSERT INTO "django_geo_db_city" VALUES(15675,'Copper City','Copper City, Michigan',19645,40);
INSERT INTO "django_geo_db_city" VALUES(15676,'Copper Harbor','Copper Harbor, Michigan',19646,40);
INSERT INTO "django_geo_db_city" VALUES(15677,'Covington','Covington, Michigan',19647,40);
INSERT INTO "django_geo_db_city" VALUES(15678,'Crystal Falls','Crystal Falls, Michigan',19648,40);
INSERT INTO "django_geo_db_city" VALUES(15679,'Dodgeville','Dodgeville, Michigan',19649,40);
INSERT INTO "django_geo_db_city" VALUES(15680,'Dollar Bay','Dollar Bay, Michigan',19650,40);
INSERT INTO "django_geo_db_city" VALUES(15681,'Houghton','Houghton, Michigan',19651,40);
INSERT INTO "django_geo_db_city" VALUES(15682,'Ewen','Ewen, Michigan',19652,40);
INSERT INTO "django_geo_db_city" VALUES(15683,'Gaastra','Gaastra, Michigan',19653,40);
INSERT INTO "django_geo_db_city" VALUES(15684,'Greenland','Greenland, Michigan',19654,40);
INSERT INTO "django_geo_db_city" VALUES(15685,'Hancock','Hancock, Michigan',19655,40);
INSERT INTO "django_geo_db_city" VALUES(15686,'Hubbell','Hubbell, Michigan',19657,40);
INSERT INTO "django_geo_db_city" VALUES(15687,'Iron River','Iron River, Michigan',19658,40);
INSERT INTO "django_geo_db_city" VALUES(15688,'Ironwood','Ironwood, Michigan',19659,40);
INSERT INTO "django_geo_db_city" VALUES(15689,'Kearsarge','Kearsarge, Michigan',19660,40);
INSERT INTO "django_geo_db_city" VALUES(15690,'Lake Linden','Lake Linden, Michigan',19662,40);
INSERT INTO "django_geo_db_city" VALUES(15691,'Lanse','Lanse, Michigan',19663,40);
INSERT INTO "django_geo_db_city" VALUES(15692,'Marenisco','Marenisco, Michigan',19664,40);
INSERT INTO "django_geo_db_city" VALUES(15693,'Mass City','Mass City, Michigan',19665,40);
INSERT INTO "django_geo_db_city" VALUES(15694,'Mohawk','Mohawk, Michigan',19666,40);
INSERT INTO "django_geo_db_city" VALUES(15695,'Nisula','Nisula, Michigan',19667,40);
INSERT INTO "django_geo_db_city" VALUES(15696,'Ontonagon','Ontonagon, Michigan',19668,40);
INSERT INTO "django_geo_db_city" VALUES(15697,'Painesdale','Painesdale, Michigan',19669,40);
INSERT INTO "django_geo_db_city" VALUES(15698,'Pelkie','Pelkie, Michigan',19670,40);
INSERT INTO "django_geo_db_city" VALUES(15699,'Ramsay','Ramsay, Michigan',19671,40);
INSERT INTO "django_geo_db_city" VALUES(15700,'Rockland','Rockland, Michigan',19672,40);
INSERT INTO "django_geo_db_city" VALUES(15701,'Sidnaw','Sidnaw, Michigan',19673,40);
INSERT INTO "django_geo_db_city" VALUES(15702,'Skanee','Skanee, Michigan',19674,40);
INSERT INTO "django_geo_db_city" VALUES(15703,'South Range','South Range, Michigan',19675,40);
INSERT INTO "django_geo_db_city" VALUES(15704,'Stambaugh','Stambaugh, Michigan',19676,40);
INSERT INTO "django_geo_db_city" VALUES(15705,'Toivola','Toivola, Michigan',19677,40);
INSERT INTO "django_geo_db_city" VALUES(15706,'Trout Creek','Trout Creek, Michigan',19678,40);
INSERT INTO "django_geo_db_city" VALUES(15707,'Wakefield','Wakefield, Michigan',19679,40);
INSERT INTO "django_geo_db_city" VALUES(15708,'Watersmeet','Watersmeet, Michigan',19680,40);
INSERT INTO "django_geo_db_city" VALUES(15709,'Watton','Watton, Michigan',19681,40);
INSERT INTO "django_geo_db_city" VALUES(15710,'White Pine','White Pine, Michigan',19682,40);
INSERT INTO "django_geo_db_city" VALUES(15711,'Ackworth','Ackworth, Iowa',19685,19);
INSERT INTO "django_geo_db_city" VALUES(15712,'Adair','Adair, Iowa',19686,19);
INSERT INTO "django_geo_db_city" VALUES(15713,'Adel','Adel, Iowa',19687,19);
INSERT INTO "django_geo_db_city" VALUES(15714,'Albion','Albion, Iowa',19688,19);
INSERT INTO "django_geo_db_city" VALUES(15715,'Alden','Alden, Iowa',19689,19);
INSERT INTO "django_geo_db_city" VALUES(15716,'Alleman','Alleman, Iowa',19690,19);
INSERT INTO "django_geo_db_city" VALUES(15717,'Allerton','Allerton, Iowa',19691,19);
INSERT INTO "django_geo_db_city" VALUES(15718,'Altoona','Altoona, Iowa',19692,19);
INSERT INTO "django_geo_db_city" VALUES(15719,'Ames','Ames, Iowa',19693,19);
INSERT INTO "django_geo_db_city" VALUES(15720,'Ankeny','Ankeny, Iowa',19698,19);
INSERT INTO "django_geo_db_city" VALUES(15721,'Anita','Anita, Iowa',19699,19);
INSERT INTO "django_geo_db_city" VALUES(15722,'Atlantic','Atlantic, Iowa',19701,19);
INSERT INTO "django_geo_db_city" VALUES(15723,'Audubon','Audubon, Iowa',19702,19);
INSERT INTO "django_geo_db_city" VALUES(15724,'Bagley','Bagley, Iowa',19703,19);
INSERT INTO "django_geo_db_city" VALUES(15725,'Barnes City','Barnes City, Iowa',19704,19);
INSERT INTO "django_geo_db_city" VALUES(15726,'Baxter','Baxter, Iowa',19705,19);
INSERT INTO "django_geo_db_city" VALUES(15727,'Bayard','Bayard, Iowa',19706,19);
INSERT INTO "django_geo_db_city" VALUES(15728,'Beaver','Beaver, Iowa',19707,19);
INSERT INTO "django_geo_db_city" VALUES(15729,'Berwick','Berwick, Iowa',19708,19);
INSERT INTO "django_geo_db_city" VALUES(15730,'Bevington','Bevington, Iowa',19709,19);
INSERT INTO "django_geo_db_city" VALUES(15731,'Blairsburg','Blairsburg, Iowa',19710,19);
INSERT INTO "django_geo_db_city" VALUES(15732,'Bondurant','Bondurant, Iowa',19711,19);
INSERT INTO "django_geo_db_city" VALUES(15733,'Boone','Boone, Iowa',19712,19);
INSERT INTO "django_geo_db_city" VALUES(15734,'Booneville','Booneville, Iowa',19714,19);
INSERT INTO "django_geo_db_city" VALUES(15735,'Bouton','Bouton, Iowa',19715,19);
INSERT INTO "django_geo_db_city" VALUES(15736,'Boxholm','Boxholm, Iowa',19716,19);
INSERT INTO "django_geo_db_city" VALUES(15737,'Bradford','Bradford, Iowa',19717,19);
INSERT INTO "django_geo_db_city" VALUES(15738,'Brayton','Brayton, Iowa',19718,19);
INSERT INTO "django_geo_db_city" VALUES(15739,'Buckeye','Buckeye, Iowa',19719,19);
INSERT INTO "django_geo_db_city" VALUES(15740,'Bussey','Bussey, Iowa',19720,19);
INSERT INTO "django_geo_db_city" VALUES(15741,'Cambridge','Cambridge, Iowa',19721,19);
INSERT INTO "django_geo_db_city" VALUES(15742,'Carlisle','Carlisle, Iowa',19722,19);
INSERT INTO "django_geo_db_city" VALUES(15743,'Casey','Casey, Iowa',19723,19);
INSERT INTO "django_geo_db_city" VALUES(15744,'Chariton','Chariton, Iowa',19724,19);
INSERT INTO "django_geo_db_city" VALUES(15745,'Churdan','Churdan, Iowa',19725,19);
INSERT INTO "django_geo_db_city" VALUES(15746,'Clemons','Clemons, Iowa',19726,19);
INSERT INTO "django_geo_db_city" VALUES(15747,'Clio','Clio, Iowa',19727,19);
INSERT INTO "django_geo_db_city" VALUES(15748,'Colfax','Colfax, Iowa',19728,19);
INSERT INTO "django_geo_db_city" VALUES(15749,'Collins','Collins, Iowa',19729,19);
INSERT INTO "django_geo_db_city" VALUES(15750,'Colo','Colo, Iowa',19730,19);
INSERT INTO "django_geo_db_city" VALUES(15751,'Columbia','Columbia, Iowa',19731,19);
INSERT INTO "django_geo_db_city" VALUES(15752,'Coon Rapids','Coon Rapids, Iowa',19732,19);
INSERT INTO "django_geo_db_city" VALUES(15753,'Cooper','Cooper, Iowa',19733,19);
INSERT INTO "django_geo_db_city" VALUES(15754,'Corydon','Corydon, Iowa',19734,19);
INSERT INTO "django_geo_db_city" VALUES(15755,'Cumming','Cumming, Iowa',19735,19);
INSERT INTO "django_geo_db_city" VALUES(15756,'Dallas','Dallas, Iowa',19736,19);
INSERT INTO "django_geo_db_city" VALUES(15757,'Dallas Center','Dallas Center, Iowa',19737,19);
INSERT INTO "django_geo_db_city" VALUES(15758,'Dana','Dana, Iowa',19738,19);
INSERT INTO "django_geo_db_city" VALUES(15759,'Davis City','Davis City, Iowa',19739,19);
INSERT INTO "django_geo_db_city" VALUES(15760,'Dawson','Dawson, Iowa',19740,19);
INSERT INTO "django_geo_db_city" VALUES(15761,'Decatur','Decatur, Iowa',19741,19);
INSERT INTO "django_geo_db_city" VALUES(15762,'Derby','Derby, Iowa',19742,19);
INSERT INTO "django_geo_db_city" VALUES(15763,'De Soto','De Soto, Iowa',19743,19);
INSERT INTO "django_geo_db_city" VALUES(15764,'Dexter','Dexter, Iowa',19744,19);
INSERT INTO "django_geo_db_city" VALUES(15765,'Dows','Dows, Iowa',19745,19);
INSERT INTO "django_geo_db_city" VALUES(15766,'Earlham','Earlham, Iowa',19746,19);
INSERT INTO "django_geo_db_city" VALUES(15767,'Elkhart','Elkhart, Iowa',19747,19);
INSERT INTO "django_geo_db_city" VALUES(15768,'Ellston','Ellston, Iowa',19748,19);
INSERT INTO "django_geo_db_city" VALUES(15769,'Ellsworth','Ellsworth, Iowa',19749,19);
INSERT INTO "django_geo_db_city" VALUES(15770,'Exira','Exira, Iowa',19750,19);
INSERT INTO "django_geo_db_city" VALUES(15771,'Ferguson','Ferguson, Iowa',19751,19);
INSERT INTO "django_geo_db_city" VALUES(15772,'Galt','Galt, Iowa',19752,19);
INSERT INTO "django_geo_db_city" VALUES(15773,'Garden City','Garden City, Iowa',19753,19);
INSERT INTO "django_geo_db_city" VALUES(15774,'Garden Grove','Garden Grove, Iowa',19754,19);
INSERT INTO "django_geo_db_city" VALUES(15775,'Gibson','Gibson, Iowa',19755,19);
INSERT INTO "django_geo_db_city" VALUES(15776,'Gilbert','Gilbert, Iowa',19756,19);
INSERT INTO "django_geo_db_city" VALUES(15777,'Gilman','Gilman, Iowa',19757,19);
INSERT INTO "django_geo_db_city" VALUES(15778,'Grand Junction','Grand Junction, Iowa',19758,19);
INSERT INTO "django_geo_db_city" VALUES(15779,'Grand River','Grand River, Iowa',19759,19);
INSERT INTO "django_geo_db_city" VALUES(15780,'Granger','Granger, Iowa',19760,19);
INSERT INTO "django_geo_db_city" VALUES(15781,'Gray','Gray, Iowa',19761,19);
INSERT INTO "django_geo_db_city" VALUES(15782,'Grimes','Grimes, Iowa',19762,19);
INSERT INTO "django_geo_db_city" VALUES(15783,'Grinnell','Grinnell, Iowa',19763,19);
INSERT INTO "django_geo_db_city" VALUES(15784,'Guthrie Center','Guthrie Center, Iowa',19764,19);
INSERT INTO "django_geo_db_city" VALUES(15785,'Hamilton','Hamilton, Iowa',19765,19);
INSERT INTO "django_geo_db_city" VALUES(15786,'Hamlin','Hamlin, Iowa',19766,19);
INSERT INTO "django_geo_db_city" VALUES(15787,'Hartford','Hartford, Iowa',19767,19);
INSERT INTO "django_geo_db_city" VALUES(15788,'Harvey','Harvey, Iowa',19768,19);
INSERT INTO "django_geo_db_city" VALUES(15789,'Haverhill','Haverhill, Iowa',19769,19);
INSERT INTO "django_geo_db_city" VALUES(15790,'Hubbard','Hubbard, Iowa',19770,19);
INSERT INTO "django_geo_db_city" VALUES(15791,'Humeston','Humeston, Iowa',19771,19);
INSERT INTO "django_geo_db_city" VALUES(15792,'Huxley','Huxley, Iowa',19772,19);
INSERT INTO "django_geo_db_city" VALUES(15793,'Indianola','Indianola, Iowa',19773,19);
INSERT INTO "django_geo_db_city" VALUES(15794,'Iowa Falls','Iowa Falls, Iowa',19774,19);
INSERT INTO "django_geo_db_city" VALUES(15795,'Ira','Ira, Iowa',19775,19);
INSERT INTO "django_geo_db_city" VALUES(15796,'Jamaica','Jamaica, Iowa',19776,19);
INSERT INTO "django_geo_db_city" VALUES(15797,'Jefferson','Jefferson, Iowa',19777,19);
INSERT INTO "django_geo_db_city" VALUES(15798,'Jewell','Jewell, Iowa',19778,19);
INSERT INTO "django_geo_db_city" VALUES(15799,'Johnston','Johnston, Iowa',19779,19);
INSERT INTO "django_geo_db_city" VALUES(15800,'Kamrar','Kamrar, Iowa',19780,19);
INSERT INTO "django_geo_db_city" VALUES(15801,'Kellerton','Kellerton, Iowa',19781,19);
INSERT INTO "django_geo_db_city" VALUES(15802,'Kelley','Kelley, Iowa',19782,19);
INSERT INTO "django_geo_db_city" VALUES(15803,'Kellogg','Kellogg, Iowa',19783,19);
INSERT INTO "django_geo_db_city" VALUES(15804,'Keswick','Keswick, Iowa',19784,19);
INSERT INTO "django_geo_db_city" VALUES(15805,'Killduff','Killduff, Iowa',19785,19);
INSERT INTO "django_geo_db_city" VALUES(15806,'Knoxville','Knoxville, Iowa',19786,19);
INSERT INTO "django_geo_db_city" VALUES(15807,'Lacona','Lacona, Iowa',19787,19);
INSERT INTO "django_geo_db_city" VALUES(15808,'Lamoni','Lamoni, Iowa',19788,19);
INSERT INTO "django_geo_db_city" VALUES(15809,'Laurel','Laurel, Iowa',19789,19);
INSERT INTO "django_geo_db_city" VALUES(15810,'Le Grand','Le Grand, Iowa',19790,19);
INSERT INTO "django_geo_db_city" VALUES(15811,'Leighton','Leighton, Iowa',19791,19);
INSERT INTO "django_geo_db_city" VALUES(15812,'Leon','Leon, Iowa',19792,19);
INSERT INTO "django_geo_db_city" VALUES(15813,'Liberty Center','Liberty Center, Iowa',19793,19);
INSERT INTO "django_geo_db_city" VALUES(15814,'Linden','Linden, Iowa',19794,19);
INSERT INTO "django_geo_db_city" VALUES(15815,'Lineville','Lineville, Iowa',19795,19);
INSERT INTO "django_geo_db_city" VALUES(15816,'Liscomb','Liscomb, Iowa',19796,19);
INSERT INTO "django_geo_db_city" VALUES(15817,'Lorimor','Lorimor, Iowa',19797,19);
INSERT INTO "django_geo_db_city" VALUES(15818,'Lovilia','Lovilia, Iowa',19798,19);
INSERT INTO "django_geo_db_city" VALUES(15819,'Lucas','Lucas, Iowa',19799,19);
INSERT INTO "django_geo_db_city" VALUES(15820,'Luther','Luther, Iowa',19800,19);
INSERT INTO "django_geo_db_city" VALUES(15821,'Lynnville','Lynnville, Iowa',19801,19);
INSERT INTO "django_geo_db_city" VALUES(15822,'McCallsburg','McCallsburg, Iowa',19802,19);
INSERT INTO "django_geo_db_city" VALUES(15823,'Macksburg','Macksburg, Iowa',19803,19);
INSERT INTO "django_geo_db_city" VALUES(15824,'Madrid','Madrid, Iowa',19804,19);
INSERT INTO "django_geo_db_city" VALUES(15825,'Malcom','Malcom, Iowa',19805,19);
INSERT INTO "django_geo_db_city" VALUES(15826,'Marshalltown','Marshalltown, Iowa',19806,19);
INSERT INTO "django_geo_db_city" VALUES(15827,'Martensdale','Martensdale, Iowa',19807,19);
INSERT INTO "django_geo_db_city" VALUES(15828,'Maxwell','Maxwell, Iowa',19808,19);
INSERT INTO "django_geo_db_city" VALUES(15829,'Melbourne','Melbourne, Iowa',19809,19);
INSERT INTO "django_geo_db_city" VALUES(15830,'Melcher','Melcher, Iowa',19810,19);
INSERT INTO "django_geo_db_city" VALUES(15831,'Menlo','Menlo, Iowa',19811,19);
INSERT INTO "django_geo_db_city" VALUES(15832,'Millerton','Millerton, Iowa',19812,19);
INSERT INTO "django_geo_db_city" VALUES(15833,'Milo','Milo, Iowa',19813,19);
INSERT INTO "django_geo_db_city" VALUES(15834,'Minburn','Minburn, Iowa',19814,19);
INSERT INTO "django_geo_db_city" VALUES(15835,'Mingo','Mingo, Iowa',19815,19);
INSERT INTO "django_geo_db_city" VALUES(15836,'Mitchellville','Mitchellville, Iowa',19816,19);
INSERT INTO "django_geo_db_city" VALUES(15837,'Monroe','Monroe, Iowa',19817,19);
INSERT INTO "django_geo_db_city" VALUES(15838,'Montezuma','Montezuma, Iowa',19818,19);
INSERT INTO "django_geo_db_city" VALUES(15839,'Montour','Montour, Iowa',19819,19);
INSERT INTO "django_geo_db_city" VALUES(15840,'Murray','Murray, Iowa',19820,19);
INSERT INTO "django_geo_db_city" VALUES(15841,'Nevada','Nevada, Iowa',19823,19);
INSERT INTO "django_geo_db_city" VALUES(15842,'New Providence','New Providence, Iowa',19824,19);
INSERT INTO "django_geo_db_city" VALUES(15843,'New Sharon','New Sharon, Iowa',19825,19);
INSERT INTO "django_geo_db_city" VALUES(15844,'Newton','Newton, Iowa',19826,19);
INSERT INTO "django_geo_db_city" VALUES(15845,'New Virginia','New Virginia, Iowa',19827,19);
INSERT INTO "django_geo_db_city" VALUES(15846,'Norwalk','Norwalk, Iowa',19828,19);
INSERT INTO "django_geo_db_city" VALUES(15847,'Ogden','Ogden, Iowa',19829,19);
INSERT INTO "django_geo_db_city" VALUES(15848,'Osceola','Osceola, Iowa',19830,19);
INSERT INTO "django_geo_db_city" VALUES(15849,'Otley','Otley, Iowa',19831,19);
INSERT INTO "django_geo_db_city" VALUES(15850,'Panora','Panora, Iowa',19832,19);
INSERT INTO "django_geo_db_city" VALUES(15851,'Paton','Paton, Iowa',19833,19);
INSERT INTO "django_geo_db_city" VALUES(15852,'Patterson','Patterson, Iowa',19834,19);
INSERT INTO "django_geo_db_city" VALUES(15853,'Pella','Pella, Iowa',19835,19);
INSERT INTO "django_geo_db_city" VALUES(15854,'Perry','Perry, Iowa',19836,19);
INSERT INTO "django_geo_db_city" VALUES(15855,'Peru','Peru, Iowa',19837,19);
INSERT INTO "django_geo_db_city" VALUES(15856,'Pilot Mound','Pilot Mound, Iowa',19838,19);
INSERT INTO "django_geo_db_city" VALUES(15857,'Pleasantville','Pleasantville, Iowa',19839,19);
INSERT INTO "django_geo_db_city" VALUES(15858,'Polk City','Polk City, Iowa',19840,19);
INSERT INTO "django_geo_db_city" VALUES(15859,'Popejoy','Popejoy, Iowa',19841,19);
INSERT INTO "django_geo_db_city" VALUES(15860,'Prairie City','Prairie City, Iowa',19842,19);
INSERT INTO "django_geo_db_city" VALUES(15861,'Prole','Prole, Iowa',19843,19);
INSERT INTO "django_geo_db_city" VALUES(15862,'Radcliffe','Radcliffe, Iowa',19844,19);
INSERT INTO "django_geo_db_city" VALUES(15863,'Randall','Randall, Iowa',19845,19);
INSERT INTO "django_geo_db_city" VALUES(15864,'Reasnor','Reasnor, Iowa',19846,19);
INSERT INTO "django_geo_db_city" VALUES(15865,'Redfield','Redfield, Iowa',19847,19);
INSERT INTO "django_geo_db_city" VALUES(15866,'Rhodes','Rhodes, Iowa',19848,19);
INSERT INTO "django_geo_db_city" VALUES(15867,'Rippey','Rippey, Iowa',19849,19);
INSERT INTO "django_geo_db_city" VALUES(15868,'Roland','Roland, Iowa',19850,19);
INSERT INTO "django_geo_db_city" VALUES(15869,'Runnells','Runnells, Iowa',19851,19);
INSERT INTO "django_geo_db_city" VALUES(15870,'Russell','Russell, Iowa',19852,19);
INSERT INTO "django_geo_db_city" VALUES(15871,'Saint Anthony','Saint Anthony, Iowa',19853,19);
INSERT INTO "django_geo_db_city" VALUES(15872,'Saint Charles','Saint Charles, Iowa',19854,19);
INSERT INTO "django_geo_db_city" VALUES(15873,'Saint Marys','Saint Marys, Iowa',19855,19);
INSERT INTO "django_geo_db_city" VALUES(15874,'Searsboro','Searsboro, Iowa',19856,19);
INSERT INTO "django_geo_db_city" VALUES(15875,'Sheldahl','Sheldahl, Iowa',19857,19);
INSERT INTO "django_geo_db_city" VALUES(15876,'Slater','Slater, Iowa',19858,19);
INSERT INTO "django_geo_db_city" VALUES(15877,'Stanhope','Stanhope, Iowa',19859,19);
INSERT INTO "django_geo_db_city" VALUES(15878,'State Center','State Center, Iowa',19860,19);
INSERT INTO "django_geo_db_city" VALUES(15879,'Story City','Story City, Iowa',19861,19);
INSERT INTO "django_geo_db_city" VALUES(15880,'Stratford','Stratford, Iowa',19862,19);
INSERT INTO "django_geo_db_city" VALUES(15881,'Stuart','Stuart, Iowa',19863,19);
INSERT INTO "django_geo_db_city" VALUES(15882,'Sully','Sully, Iowa',19864,19);
INSERT INTO "django_geo_db_city" VALUES(15883,'Swan','Swan, Iowa',19865,19);
INSERT INTO "django_geo_db_city" VALUES(15884,'Thayer','Thayer, Iowa',19866,19);
INSERT INTO "django_geo_db_city" VALUES(15885,'Thornburg','Thornburg, Iowa',19867,19);
INSERT INTO "django_geo_db_city" VALUES(15886,'Tracy','Tracy, Iowa',19868,19);
INSERT INTO "django_geo_db_city" VALUES(15887,'Truro','Truro, Iowa',19869,19);
INSERT INTO "django_geo_db_city" VALUES(15888,'Union','Union, Iowa',19870,19);
INSERT INTO "django_geo_db_city" VALUES(15889,'Gifford','Gifford, Iowa',19871,19);
INSERT INTO "django_geo_db_city" VALUES(15890,'Van Meter','Van Meter, Iowa',19872,19);
INSERT INTO "django_geo_db_city" VALUES(15891,'Van Wert','Van Wert, Iowa',19873,19);
INSERT INTO "django_geo_db_city" VALUES(15892,'Waukee','Waukee, Iowa',19874,19);
INSERT INTO "django_geo_db_city" VALUES(15893,'Weldon','Weldon, Iowa',19875,19);
INSERT INTO "django_geo_db_city" VALUES(15894,'West Des Moines','West Des Moines, Iowa',19876,19);
INSERT INTO "django_geo_db_city" VALUES(15895,'What Cheer','What Cheer, Iowa',19878,19);
INSERT INTO "django_geo_db_city" VALUES(15896,'Whitten','Whitten, Iowa',19879,19);
INSERT INTO "django_geo_db_city" VALUES(15897,'Williams','Williams, Iowa',19880,19);
INSERT INTO "django_geo_db_city" VALUES(15898,'Williamson','Williamson, Iowa',19881,19);
INSERT INTO "django_geo_db_city" VALUES(15899,'Winterset','Winterset, Iowa',19882,19);
INSERT INTO "django_geo_db_city" VALUES(15900,'Wiota','Wiota, Iowa',19883,19);
INSERT INTO "django_geo_db_city" VALUES(15901,'Woodburn','Woodburn, Iowa',19884,19);
INSERT INTO "django_geo_db_city" VALUES(15902,'Woodward','Woodward, Iowa',19885,19);
INSERT INTO "django_geo_db_city" VALUES(15903,'Yale','Yale, Iowa',19886,19);
INSERT INTO "django_geo_db_city" VALUES(15904,'Zearing','Zearing, Iowa',19887,19);
INSERT INTO "django_geo_db_city" VALUES(15905,'Des Moines','Des Moines, Iowa',19698,19);
INSERT INTO "django_geo_db_city" VALUES(15906,'Urbandale','Urbandale, Iowa',19901,19);
INSERT INTO "django_geo_db_city" VALUES(15907,'Clive','Clive, Iowa',19903,19);
INSERT INTO "django_geo_db_city" VALUES(15908,'Pleasant Hill','Pleasant Hill, Iowa',19904,19);
INSERT INTO "django_geo_db_city" VALUES(15909,'Mason City','Mason City, Iowa',19907,19);
INSERT INTO "django_geo_db_city" VALUES(15910,'Lake Mills','Lake Mills, Iowa',19909,19);
INSERT INTO "django_geo_db_city" VALUES(15911,'Alexander','Alexander, Iowa',19910,19);
INSERT INTO "django_geo_db_city" VALUES(15912,'Belmond','Belmond, Iowa',19911,19);
INSERT INTO "django_geo_db_city" VALUES(15913,'Britt','Britt, Iowa',19912,19);
INSERT INTO "django_geo_db_city" VALUES(15914,'Buffalo Center','Buffalo Center, Iowa',19913,19);
INSERT INTO "django_geo_db_city" VALUES(15915,'Carpenter','Carpenter, Iowa',19914,19);
INSERT INTO "django_geo_db_city" VALUES(15916,'Chapin','Chapin, Iowa',19915,19);
INSERT INTO "django_geo_db_city" VALUES(15917,'Clear Lake','Clear Lake, Iowa',19916,19);
INSERT INTO "django_geo_db_city" VALUES(15918,'Corwith','Corwith, Iowa',19917,19);
INSERT INTO "django_geo_db_city" VALUES(15919,'Coulter','Coulter, Iowa',19918,19);
INSERT INTO "django_geo_db_city" VALUES(15920,'Crystal Lake','Crystal Lake, Iowa',19919,19);
INSERT INTO "django_geo_db_city" VALUES(15921,'Dougherty','Dougherty, Iowa',19920,19);
INSERT INTO "django_geo_db_city" VALUES(15922,'Fertile','Fertile, Iowa',19921,19);
INSERT INTO "django_geo_db_city" VALUES(15923,'Floyd','Floyd, Iowa',19922,19);
INSERT INTO "django_geo_db_city" VALUES(15924,'Forest City','Forest City, Iowa',19923,19);
INSERT INTO "django_geo_db_city" VALUES(15925,'Garner','Garner, Iowa',19924,19);
INSERT INTO "django_geo_db_city" VALUES(15926,'Goodell','Goodell, Iowa',19925,19);
INSERT INTO "django_geo_db_city" VALUES(15927,'Grafton','Grafton, Iowa',19926,19);
INSERT INTO "django_geo_db_city" VALUES(15928,'Hampton','Hampton, Iowa',19927,19);
INSERT INTO "django_geo_db_city" VALUES(15929,'Hanlontown','Hanlontown, Iowa',19928,19);
INSERT INTO "django_geo_db_city" VALUES(15930,'Joice','Joice, Iowa',19929,19);
INSERT INTO "django_geo_db_city" VALUES(15931,'Kanawha','Kanawha, Iowa',19930,19);
INSERT INTO "django_geo_db_city" VALUES(15932,'Kensett','Kensett, Iowa',19931,19);
INSERT INTO "django_geo_db_city" VALUES(15933,'Klemme','Klemme, Iowa',19932,19);
INSERT INTO "django_geo_db_city" VALUES(15934,'Lakota','Lakota, Iowa',19934,19);
INSERT INTO "django_geo_db_city" VALUES(15935,'Latimer','Latimer, Iowa',19935,19);
INSERT INTO "django_geo_db_city" VALUES(15936,'Leland','Leland, Iowa',19936,19);
INSERT INTO "django_geo_db_city" VALUES(15937,'Little Cedar','Little Cedar, Iowa',19937,19);
INSERT INTO "django_geo_db_city" VALUES(15938,'McIntire','McIntire, Iowa',19938,19);
INSERT INTO "django_geo_db_city" VALUES(15939,'Manly','Manly, Iowa',19939,19);
INSERT INTO "django_geo_db_city" VALUES(15940,'Meservey','Meservey, Iowa',19940,19);
INSERT INTO "django_geo_db_city" VALUES(15941,'Nora Springs','Nora Springs, Iowa',19941,19);
INSERT INTO "django_geo_db_city" VALUES(15942,'Northwood','Northwood, Iowa',19942,19);
INSERT INTO "django_geo_db_city" VALUES(15943,'Orchard','Orchard, Iowa',19943,19);
INSERT INTO "django_geo_db_city" VALUES(15944,'Osage','Osage, Iowa',19944,19);
INSERT INTO "django_geo_db_city" VALUES(15945,'Plymouth','Plymouth, Iowa',19945,19);
INSERT INTO "django_geo_db_city" VALUES(15946,'Rake','Rake, Iowa',19946,19);
INSERT INTO "django_geo_db_city" VALUES(15947,'Riceville','Riceville, Iowa',19947,19);
INSERT INTO "django_geo_db_city" VALUES(15948,'Rock Falls','Rock Falls, Iowa',19948,19);
INSERT INTO "django_geo_db_city" VALUES(15949,'Rockford','Rockford, Iowa',19949,19);
INSERT INTO "django_geo_db_city" VALUES(15950,'Rockwell','Rockwell, Iowa',19950,19);
INSERT INTO "django_geo_db_city" VALUES(15951,'Rowan','Rowan, Iowa',19951,19);
INSERT INTO "django_geo_db_city" VALUES(15952,'Rudd','Rudd, Iowa',19952,19);
INSERT INTO "django_geo_db_city" VALUES(15953,'Saint Ansgar','Saint Ansgar, Iowa',19953,19);
INSERT INTO "django_geo_db_city" VALUES(15954,'Scarville','Scarville, Iowa',19954,19);
INSERT INTO "django_geo_db_city" VALUES(15955,'Sheffield','Sheffield, Iowa',19955,19);
INSERT INTO "django_geo_db_city" VALUES(15956,'Stacyville','Stacyville, Iowa',19956,19);
INSERT INTO "django_geo_db_city" VALUES(15957,'Swaledale','Swaledale, Iowa',19957,19);
INSERT INTO "django_geo_db_city" VALUES(15958,'Thompson','Thompson, Iowa',19958,19);
INSERT INTO "django_geo_db_city" VALUES(15959,'Thornton','Thornton, Iowa',19959,19);
INSERT INTO "django_geo_db_city" VALUES(15960,'Titonka','Titonka, Iowa',19960,19);
INSERT INTO "django_geo_db_city" VALUES(15961,'Toeterville','Toeterville, Iowa',19961,19);
INSERT INTO "django_geo_db_city" VALUES(15962,'Ventura','Ventura, Iowa',19962,19);
INSERT INTO "django_geo_db_city" VALUES(15963,'Wesley','Wesley, Iowa',19963,19);
INSERT INTO "django_geo_db_city" VALUES(15964,'Woden','Woden, Iowa',19964,19);
INSERT INTO "django_geo_db_city" VALUES(15965,'Fort Dodge','Fort Dodge, Iowa',19965,19);
INSERT INTO "django_geo_db_city" VALUES(15966,'Albert City','Albert City, Iowa',19966,19);
INSERT INTO "django_geo_db_city" VALUES(15967,'Algona','Algona, Iowa',19967,19);
INSERT INTO "django_geo_db_city" VALUES(15968,'Armstrong','Armstrong, Iowa',19968,19);
INSERT INTO "django_geo_db_city" VALUES(15969,'Ayrshire','Ayrshire, Iowa',19969,19);
INSERT INTO "django_geo_db_city" VALUES(15970,'Badger','Badger, Iowa',19970,19);
INSERT INTO "django_geo_db_city" VALUES(15971,'Bancroft','Bancroft, Iowa',19971,19);
INSERT INTO "django_geo_db_city" VALUES(15972,'Barnum','Barnum, Iowa',19972,19);
INSERT INTO "django_geo_db_city" VALUES(15973,'Bode','Bode, Iowa',19973,19);
INSERT INTO "django_geo_db_city" VALUES(15974,'Bradgate','Bradgate, Iowa',19974,19);
INSERT INTO "django_geo_db_city" VALUES(15975,'Burnside','Burnside, Iowa',19975,19);
INSERT INTO "django_geo_db_city" VALUES(15976,'Burt','Burt, Iowa',19976,19);
INSERT INTO "django_geo_db_city" VALUES(15977,'Callender','Callender, Iowa',19977,19);
INSERT INTO "django_geo_db_city" VALUES(15978,'Clare','Clare, Iowa',19978,19);
INSERT INTO "django_geo_db_city" VALUES(15979,'Clarion','Clarion, Iowa',19979,19);
INSERT INTO "django_geo_db_city" VALUES(15980,'Curlew','Curlew, Iowa',19981,19);
INSERT INTO "django_geo_db_city" VALUES(15981,'Cylinder','Cylinder, Iowa',19982,19);
INSERT INTO "django_geo_db_city" VALUES(15982,'Dakota City','Dakota City, Iowa',19983,19);
INSERT INTO "django_geo_db_city" VALUES(15983,'Dayton','Dayton, Iowa',19984,19);
INSERT INTO "django_geo_db_city" VALUES(15984,'Dolliver','Dolliver, Iowa',19985,19);
INSERT INTO "django_geo_db_city" VALUES(15985,'Duncombe','Duncombe, Iowa',19986,19);
INSERT INTO "django_geo_db_city" VALUES(15986,'Eagle Grove','Eagle Grove, Iowa',19987,19);
INSERT INTO "django_geo_db_city" VALUES(15987,'Early','Early, Iowa',19988,19);
INSERT INTO "django_geo_db_city" VALUES(15988,'Emmetsburg','Emmetsburg, Iowa',19989,19);
INSERT INTO "django_geo_db_city" VALUES(15989,'Farnhamville','Farnhamville, Iowa',19990,19);
INSERT INTO "django_geo_db_city" VALUES(15990,'Fenton','Fenton, Iowa',19991,19);
INSERT INTO "django_geo_db_city" VALUES(15991,'Fonda','Fonda, Iowa',19992,19);
INSERT INTO "django_geo_db_city" VALUES(15992,'Gilmore City','Gilmore City, Iowa',19993,19);
INSERT INTO "django_geo_db_city" VALUES(15993,'Goldfield','Goldfield, Iowa',19994,19);
INSERT INTO "django_geo_db_city" VALUES(15994,'Gowrie','Gowrie, Iowa',19995,19);
INSERT INTO "django_geo_db_city" VALUES(15995,'Harcourt','Harcourt, Iowa',19996,19);
INSERT INTO "django_geo_db_city" VALUES(15996,'Hardy','Hardy, Iowa',19997,19);
INSERT INTO "django_geo_db_city" VALUES(15997,'Havelock','Havelock, Iowa',19998,19);
INSERT INTO "django_geo_db_city" VALUES(15998,'Humboldt','Humboldt, Iowa',19999,19);
INSERT INTO "django_geo_db_city" VALUES(15999,'Jolley','Jolley, Iowa',20000,19);
INSERT INTO "django_geo_db_city" VALUES(16000,'Knierim','Knierim, Iowa',20001,19);
INSERT INTO "django_geo_db_city" VALUES(16001,'Laurens','Laurens, Iowa',20002,19);
INSERT INTO "django_geo_db_city" VALUES(16002,'Ledyard','Ledyard, Iowa',20003,19);
INSERT INTO "django_geo_db_city" VALUES(16003,'Lehigh','Lehigh, Iowa',20004,19);
INSERT INTO "django_geo_db_city" VALUES(16004,'Livermore','Livermore, Iowa',20005,19);
INSERT INTO "django_geo_db_city" VALUES(16005,'Lone Rock','Lone Rock, Iowa',20006,19);
INSERT INTO "django_geo_db_city" VALUES(16006,'Lu Verne','Lu Verne, Iowa',20007,19);
INSERT INTO "django_geo_db_city" VALUES(16007,'Lytton','Lytton, Iowa',20008,19);
INSERT INTO "django_geo_db_city" VALUES(16008,'Mallard','Mallard, Iowa',20009,19);
INSERT INTO "django_geo_db_city" VALUES(16009,'Manson','Manson, Iowa',20010,19);
INSERT INTO "django_geo_db_city" VALUES(16010,'Marathon','Marathon, Iowa',20011,19);
INSERT INTO "django_geo_db_city" VALUES(16011,'Moorland','Moorland, Iowa',20012,19);
INSERT INTO "django_geo_db_city" VALUES(16012,'Nemaha','Nemaha, Iowa',20013,19);
INSERT INTO "django_geo_db_city" VALUES(16013,'Newell','Newell, Iowa',20014,19);
INSERT INTO "django_geo_db_city" VALUES(16014,'Otho','Otho, Iowa',20015,19);
INSERT INTO "django_geo_db_city" VALUES(16015,'Ottosen','Ottosen, Iowa',20016,19);
INSERT INTO "django_geo_db_city" VALUES(16016,'Palmer','Palmer, Iowa',20017,19);
INSERT INTO "django_geo_db_city" VALUES(16017,'Plover','Plover, Iowa',20018,19);
INSERT INTO "django_geo_db_city" VALUES(16018,'Pocahontas','Pocahontas, Iowa',20019,19);
INSERT INTO "django_geo_db_city" VALUES(16019,'Pomeroy','Pomeroy, Iowa',20020,19);
INSERT INTO "django_geo_db_city" VALUES(16020,'Rembrandt','Rembrandt, Iowa',20021,19);
INSERT INTO "django_geo_db_city" VALUES(16021,'Renwick','Renwick, Iowa',20022,19);
INSERT INTO "django_geo_db_city" VALUES(16022,'Ringsted','Ringsted, Iowa',20023,19);
INSERT INTO "django_geo_db_city" VALUES(16023,'Rockwell City','Rockwell City, Iowa',20024,19);
INSERT INTO "django_geo_db_city" VALUES(16024,'Rolfe','Rolfe, Iowa',20025,19);
INSERT INTO "django_geo_db_city" VALUES(16025,'Rutland','Rutland, Iowa',20026,19);
INSERT INTO "django_geo_db_city" VALUES(16026,'Sac City','Sac City, Iowa',20027,19);
INSERT INTO "django_geo_db_city" VALUES(16027,'Sioux Rapids','Sioux Rapids, Iowa',20028,19);
INSERT INTO "django_geo_db_city" VALUES(16028,'Somers','Somers, Iowa',20029,19);
INSERT INTO "django_geo_db_city" VALUES(16029,'Rinard','Rinard, Iowa',20030,19);
INSERT INTO "django_geo_db_city" VALUES(16030,'Storm Lake','Storm Lake, Iowa',20031,19);
INSERT INTO "django_geo_db_city" VALUES(16031,'Swea City','Swea City, Iowa',20032,19);
INSERT INTO "django_geo_db_city" VALUES(16032,'Thor','Thor, Iowa',20033,19);
INSERT INTO "django_geo_db_city" VALUES(16033,'Truesdale','Truesdale, Iowa',20034,19);
INSERT INTO "django_geo_db_city" VALUES(16034,'Varina','Varina, Iowa',20035,19);
INSERT INTO "django_geo_db_city" VALUES(16035,'Vincent','Vincent, Iowa',20036,19);
INSERT INTO "django_geo_db_city" VALUES(16036,'Webster City','Webster City, Iowa',20037,19);
INSERT INTO "django_geo_db_city" VALUES(16037,'West Bend','West Bend, Iowa',20038,19);
INSERT INTO "django_geo_db_city" VALUES(16038,'Whittemore','Whittemore, Iowa',20039,19);
INSERT INTO "django_geo_db_city" VALUES(16039,'Woolstock','Woolstock, Iowa',20040,19);
INSERT INTO "django_geo_db_city" VALUES(16040,'Ackley','Ackley, Iowa',20041,19);
INSERT INTO "django_geo_db_city" VALUES(16041,'Allison','Allison, Iowa',20042,19);
INSERT INTO "django_geo_db_city" VALUES(16042,'Alta Vista','Alta Vista, Iowa',20043,19);
INSERT INTO "django_geo_db_city" VALUES(16043,'Aplington','Aplington, Iowa',20044,19);
INSERT INTO "django_geo_db_city" VALUES(16044,'Aredale','Aredale, Iowa',20045,19);
INSERT INTO "django_geo_db_city" VALUES(16045,'Arlington','Arlington, Iowa',20046,19);
INSERT INTO "django_geo_db_city" VALUES(16046,'Aurora','Aurora, Iowa',20047,19);
INSERT INTO "django_geo_db_city" VALUES(16047,'Austinville','Austinville, Iowa',20048,19);
INSERT INTO "django_geo_db_city" VALUES(16048,'Beaman','Beaman, Iowa',20049,19);
INSERT INTO "django_geo_db_city" VALUES(16049,'Bristow','Bristow, Iowa',20050,19);
INSERT INTO "django_geo_db_city" VALUES(16050,'Buckingham','Buckingham, Iowa',20051,19);
INSERT INTO "django_geo_db_city" VALUES(16051,'Cedar Falls','Cedar Falls, Iowa',20052,19);
INSERT INTO "django_geo_db_city" VALUES(16052,'Charles City','Charles City, Iowa',20054,19);
INSERT INTO "django_geo_db_city" VALUES(16053,'Clarksville','Clarksville, Iowa',20055,19);
INSERT INTO "django_geo_db_city" VALUES(16054,'Colwell','Colwell, Iowa',20056,19);
INSERT INTO "django_geo_db_city" VALUES(16055,'Conrad','Conrad, Iowa',20057,19);
INSERT INTO "django_geo_db_city" VALUES(16056,'Denver','Denver, Iowa',20058,19);
INSERT INTO "django_geo_db_city" VALUES(16057,'Dewar','Dewar, Iowa',20059,19);
INSERT INTO "django_geo_db_city" VALUES(16058,'Dike','Dike, Iowa',20060,19);
INSERT INTO "django_geo_db_city" VALUES(16059,'Dumont','Dumont, Iowa',20061,19);
INSERT INTO "django_geo_db_city" VALUES(16060,'Dunkerton','Dunkerton, Iowa',20062,19);
INSERT INTO "django_geo_db_city" VALUES(16061,'Eldora','Eldora, Iowa',20063,19);
INSERT INTO "django_geo_db_city" VALUES(16062,'Elma','Elma, Iowa',20064,19);
INSERT INTO "django_geo_db_city" VALUES(16063,'Fairbank','Fairbank, Iowa',20065,19);
INSERT INTO "django_geo_db_city" VALUES(16064,'Fredericksburg','Fredericksburg, Iowa',20066,19);
INSERT INTO "django_geo_db_city" VALUES(16065,'Frederika','Frederika, Iowa',20067,19);
INSERT INTO "django_geo_db_city" VALUES(16066,'Garwin','Garwin, Iowa',20068,19);
INSERT INTO "django_geo_db_city" VALUES(16067,'Geneva','Geneva, Iowa',20069,19);
INSERT INTO "django_geo_db_city" VALUES(16068,'Gilbertville','Gilbertville, Iowa',20070,19);
INSERT INTO "django_geo_db_city" VALUES(16069,'Gladbrook','Gladbrook, Iowa',20071,19);
INSERT INTO "django_geo_db_city" VALUES(16070,'Greene','Greene, Iowa',20072,19);
INSERT INTO "django_geo_db_city" VALUES(16071,'Grundy Center','Grundy Center, Iowa',20073,19);
INSERT INTO "django_geo_db_city" VALUES(16072,'Hazleton','Hazleton, Iowa',20074,19);
INSERT INTO "django_geo_db_city" VALUES(16073,'Holland','Holland, Iowa',20075,19);
INSERT INTO "django_geo_db_city" VALUES(16074,'Hudson','Hudson, Iowa',20076,19);
INSERT INTO "django_geo_db_city" VALUES(16075,'Independence','Independence, Iowa',20077,19);
INSERT INTO "django_geo_db_city" VALUES(16076,'Ionia','Ionia, Iowa',20078,19);
INSERT INTO "django_geo_db_city" VALUES(16077,'Janesville','Janesville, Iowa',20079,19);
INSERT INTO "django_geo_db_city" VALUES(16078,'Jesup','Jesup, Iowa',20080,19);
INSERT INTO "django_geo_db_city" VALUES(16079,'Kesley','Kesley, Iowa',20081,19);
INSERT INTO "django_geo_db_city" VALUES(16080,'Lamont','Lamont, Iowa',20082,19);
INSERT INTO "django_geo_db_city" VALUES(16081,'La Porte City','La Porte City, Iowa',20083,19);
INSERT INTO "django_geo_db_city" VALUES(16082,'Lincoln','Lincoln, Iowa',20084,19);
INSERT INTO "django_geo_db_city" VALUES(16083,'Marble Rock','Marble Rock, Iowa',20085,19);
INSERT INTO "django_geo_db_city" VALUES(16084,'Masonville','Masonville, Iowa',20086,19);
INSERT INTO "django_geo_db_city" VALUES(16085,'Maynard','Maynard, Iowa',20087,19);
INSERT INTO "django_geo_db_city" VALUES(16086,'Morrison','Morrison, Iowa',20088,19);
INSERT INTO "django_geo_db_city" VALUES(16087,'Nashua','Nashua, Iowa',20089,19);
INSERT INTO "django_geo_db_city" VALUES(16088,'New Hampton','New Hampton, Iowa',20090,19);
INSERT INTO "django_geo_db_city" VALUES(16089,'New Hartford','New Hartford, Iowa',20091,19);
INSERT INTO "django_geo_db_city" VALUES(16090,'North Washington','North Washington, Iowa',20092,19);
INSERT INTO "django_geo_db_city" VALUES(16091,'Oelwein','Oelwein, Iowa',20093,19);
INSERT INTO "django_geo_db_city" VALUES(16092,'Oran','Oran, Iowa',20094,19);
INSERT INTO "django_geo_db_city" VALUES(16093,'Parkersburg','Parkersburg, Iowa',20095,19);
INSERT INTO "django_geo_db_city" VALUES(16094,'Plainfield','Plainfield, Iowa',20096,19);
INSERT INTO "django_geo_db_city" VALUES(16095,'Raymond','Raymond, Iowa',20097,19);
INSERT INTO "django_geo_db_city" VALUES(16096,'Readlyn','Readlyn, Iowa',20098,19);
INSERT INTO "django_geo_db_city" VALUES(16097,'Reinbeck','Reinbeck, Iowa',20099,19);
INSERT INTO "django_geo_db_city" VALUES(16098,'Shell Rock','Shell Rock, Iowa',20100,19);
INSERT INTO "django_geo_db_city" VALUES(16099,'Stanley','Stanley, Iowa',20101,19);
INSERT INTO "django_geo_db_city" VALUES(16100,'Steamboat Rock','Steamboat Rock, Iowa',20102,19);
INSERT INTO "django_geo_db_city" VALUES(16101,'Stout','Stout, Iowa',20103,19);
INSERT INTO "django_geo_db_city" VALUES(16102,'Sumner','Sumner, Iowa',20104,19);
INSERT INTO "django_geo_db_city" VALUES(16103,'Traer','Traer, Iowa',20105,19);
INSERT INTO "django_geo_db_city" VALUES(16104,'Tripoli','Tripoli, Iowa',20106,19);
INSERT INTO "django_geo_db_city" VALUES(16105,'Waverly','Waverly, Iowa',20107,19);
INSERT INTO "django_geo_db_city" VALUES(16106,'Wellsburg','Wellsburg, Iowa',20108,19);
INSERT INTO "django_geo_db_city" VALUES(16107,'Westgate','Westgate, Iowa',20109,19);
INSERT INTO "django_geo_db_city" VALUES(16108,'Winthrop','Winthrop, Iowa',20110,19);
INSERT INTO "django_geo_db_city" VALUES(16109,'Waterloo','Waterloo, Iowa',20111,19);
INSERT INTO "django_geo_db_city" VALUES(16110,'Evansdale','Evansdale, Iowa',20115,19);
INSERT INTO "django_geo_db_city" VALUES(16111,'Creston','Creston, Iowa',20116,19);
INSERT INTO "django_geo_db_city" VALUES(16112,'Afton','Afton, Iowa',20117,19);
INSERT INTO "django_geo_db_city" VALUES(16113,'Arispe','Arispe, Iowa',20118,19);
INSERT INTO "django_geo_db_city" VALUES(16114,'Bedford','Bedford, Iowa',20119,19);
INSERT INTO "django_geo_db_city" VALUES(16115,'Benton','Benton, Iowa',20120,19);
INSERT INTO "django_geo_db_city" VALUES(16116,'Blockton','Blockton, Iowa',20121,19);
INSERT INTO "django_geo_db_city" VALUES(16117,'Bridgewater','Bridgewater, Iowa',20122,19);
INSERT INTO "django_geo_db_city" VALUES(16118,'Carbon','Carbon, Iowa',20123,19);
INSERT INTO "django_geo_db_city" VALUES(16119,'Clearfield','Clearfield, Iowa',20124,19);
INSERT INTO "django_geo_db_city" VALUES(16120,'Corning','Corning, Iowa',20125,19);
INSERT INTO "django_geo_db_city" VALUES(16121,'Cromwell','Cromwell, Iowa',20126,19);
INSERT INTO "django_geo_db_city" VALUES(16122,'Cumberland','Cumberland, Iowa',20127,19);
INSERT INTO "django_geo_db_city" VALUES(16123,'Diagonal','Diagonal, Iowa',20128,19);
INSERT INTO "django_geo_db_city" VALUES(16124,'Fontanelle','Fontanelle, Iowa',20129,19);
INSERT INTO "django_geo_db_city" VALUES(16125,'Grant','Grant, Iowa',20130,19);
INSERT INTO "django_geo_db_city" VALUES(16126,'Gravity','Gravity, Iowa',20131,19);
INSERT INTO "django_geo_db_city" VALUES(16127,'Greenfield','Greenfield, Iowa',20132,19);
INSERT INTO "django_geo_db_city" VALUES(16128,'Lenox','Lenox, Iowa',20133,19);
INSERT INTO "django_geo_db_city" VALUES(16129,'Massena','Massena, Iowa',20134,19);
INSERT INTO "django_geo_db_city" VALUES(16130,'Mount Ayr','Mount Ayr, Iowa',20135,19);
INSERT INTO "django_geo_db_city" VALUES(16131,'Nodaway','Nodaway, Iowa',20136,19);
INSERT INTO "django_geo_db_city" VALUES(16132,'Orient','Orient, Iowa',20137,19);
INSERT INTO "django_geo_db_city" VALUES(16133,'Prescott','Prescott, Iowa',20138,19);
INSERT INTO "django_geo_db_city" VALUES(16134,'Redding','Redding, Iowa',20139,19);
INSERT INTO "django_geo_db_city" VALUES(16135,'Shannon City','Shannon City, Iowa',20140,19);
INSERT INTO "django_geo_db_city" VALUES(16136,'Sharpsburg','Sharpsburg, Iowa',20141,19);
INSERT INTO "django_geo_db_city" VALUES(16137,'Tingley','Tingley, Iowa',20142,19);
INSERT INTO "django_geo_db_city" VALUES(16138,'Villisca','Villisca, Iowa',20143,19);
INSERT INTO "django_geo_db_city" VALUES(16139,'Akron','Akron, Iowa',20144,19);
INSERT INTO "django_geo_db_city" VALUES(16140,'Alta','Alta, Iowa',20145,19);
INSERT INTO "django_geo_db_city" VALUES(16141,'Alton','Alton, Iowa',20146,19);
INSERT INTO "django_geo_db_city" VALUES(16142,'Anthon','Anthon, Iowa',20147,19);
INSERT INTO "django_geo_db_city" VALUES(16143,'Aurelia','Aurelia, Iowa',20148,19);
INSERT INTO "django_geo_db_city" VALUES(16144,'Battle Creek','Battle Creek, Iowa',20149,19);
INSERT INTO "django_geo_db_city" VALUES(16145,'Bronson','Bronson, Iowa',20150,19);
INSERT INTO "django_geo_db_city" VALUES(16146,'Brunsville','Brunsville, Iowa',20151,19);
INSERT INTO "django_geo_db_city" VALUES(16147,'Calumet','Calumet, Iowa',20152,19);
INSERT INTO "django_geo_db_city" VALUES(16148,'Castana','Castana, Iowa',20153,19);
INSERT INTO "django_geo_db_city" VALUES(16149,'Chatsworth','Chatsworth, Iowa',20154,19);
INSERT INTO "django_geo_db_city" VALUES(16150,'Cherokee','Cherokee, Iowa',20155,19);
INSERT INTO "django_geo_db_city" VALUES(16151,'Cleghorn','Cleghorn, Iowa',20156,19);
INSERT INTO "django_geo_db_city" VALUES(16152,'Climbing Hill','Climbing Hill, Iowa',20157,19);
INSERT INTO "django_geo_db_city" VALUES(16153,'Correctionville','Correctionville, Iowa',20158,19);
INSERT INTO "django_geo_db_city" VALUES(16154,'Craig','Craig, Iowa',20159,19);
INSERT INTO "django_geo_db_city" VALUES(16155,'Cushing','Cushing, Iowa',20160,19);
INSERT INTO "django_geo_db_city" VALUES(16156,'Danbury','Danbury, Iowa',20161,19);
INSERT INTO "django_geo_db_city" VALUES(16157,'Galva','Galva, Iowa',20162,19);
INSERT INTO "django_geo_db_city" VALUES(16158,'Granville','Granville, Iowa',20163,19);
INSERT INTO "django_geo_db_city" VALUES(16159,'Hawarden','Hawarden, Iowa',20164,19);
INSERT INTO "django_geo_db_city" VALUES(16160,'Hinton','Hinton, Iowa',20165,19);
INSERT INTO "django_geo_db_city" VALUES(16161,'Holstein','Holstein, Iowa',20166,19);
INSERT INTO "django_geo_db_city" VALUES(16162,'Hornick','Hornick, Iowa',20167,19);
INSERT INTO "django_geo_db_city" VALUES(16163,'Ireton','Ireton, Iowa',20168,19);
INSERT INTO "django_geo_db_city" VALUES(16164,'Kingsley','Kingsley, Iowa',20169,19);
INSERT INTO "django_geo_db_city" VALUES(16165,'Larrabee','Larrabee, Iowa',20170,19);
INSERT INTO "django_geo_db_city" VALUES(16166,'Lawton','Lawton, Iowa',20171,19);
INSERT INTO "django_geo_db_city" VALUES(16167,'Le Mars','Le Mars, Iowa',20172,19);
INSERT INTO "django_geo_db_city" VALUES(16168,'Linn Grove','Linn Grove, Iowa',20173,19);
INSERT INTO "django_geo_db_city" VALUES(16169,'Mapleton','Mapleton, Iowa',20174,19);
INSERT INTO "django_geo_db_city" VALUES(16170,'Marcus','Marcus, Iowa',20175,19);
INSERT INTO "django_geo_db_city" VALUES(16171,'Maurice','Maurice, Iowa',20176,19);
INSERT INTO "django_geo_db_city" VALUES(16172,'Meriden','Meriden, Iowa',20177,19);
INSERT INTO "django_geo_db_city" VALUES(16173,'Merrill','Merrill, Iowa',20178,19);
INSERT INTO "django_geo_db_city" VALUES(16174,'Moville','Moville, Iowa',20179,19);
INSERT INTO "django_geo_db_city" VALUES(16175,'Onawa','Onawa, Iowa',20180,19);
INSERT INTO "django_geo_db_city" VALUES(16176,'Orange City','Orange City, Iowa',20181,19);
INSERT INTO "django_geo_db_city" VALUES(16177,'Oto','Oto, Iowa',20182,19);
INSERT INTO "django_geo_db_city" VALUES(16178,'Oyens','Oyens, Iowa',20183,19);
INSERT INTO "django_geo_db_city" VALUES(16179,'Paullina','Paullina, Iowa',20184,19);
INSERT INTO "django_geo_db_city" VALUES(16180,'Peterson','Peterson, Iowa',20185,19);
INSERT INTO "django_geo_db_city" VALUES(16181,'Pierson','Pierson, Iowa',20186,19);
INSERT INTO "django_geo_db_city" VALUES(16182,'Quimby','Quimby, Iowa',20187,19);
INSERT INTO "django_geo_db_city" VALUES(16183,'Remsen','Remsen, Iowa',20188,19);
INSERT INTO "django_geo_db_city" VALUES(16184,'Rodney','Rodney, Iowa',20189,19);
INSERT INTO "django_geo_db_city" VALUES(16185,'Salix','Salix, Iowa',20190,19);
INSERT INTO "django_geo_db_city" VALUES(16186,'Schaller','Schaller, Iowa',20191,19);
INSERT INTO "django_geo_db_city" VALUES(16187,'Sergeant Bluff','Sergeant Bluff, Iowa',20192,19);
INSERT INTO "django_geo_db_city" VALUES(16188,'Sloan','Sloan, Iowa',20193,19);
INSERT INTO "django_geo_db_city" VALUES(16189,'Smithland','Smithland, Iowa',20194,19);
INSERT INTO "django_geo_db_city" VALUES(16190,'Struble','Struble, Iowa',20195,19);
INSERT INTO "django_geo_db_city" VALUES(16191,'Sutherland','Sutherland, Iowa',20196,19);
INSERT INTO "django_geo_db_city" VALUES(16192,'Turin','Turin, Iowa',20197,19);
INSERT INTO "django_geo_db_city" VALUES(16193,'Ute','Ute, Iowa',20198,19);
INSERT INTO "django_geo_db_city" VALUES(16194,'Washta','Washta, Iowa',20199,19);
INSERT INTO "django_geo_db_city" VALUES(16195,'Westfield','Westfield, Iowa',20200,19);
INSERT INTO "django_geo_db_city" VALUES(16196,'Whiting','Whiting, Iowa',20201,19);
INSERT INTO "django_geo_db_city" VALUES(16197,'Sioux City','Sioux City, Iowa',20202,19);
INSERT INTO "django_geo_db_city" VALUES(16198,'Sheldon','Sheldon, Iowa',20212,19);
INSERT INTO "django_geo_db_city" VALUES(16199,'Alvord','Alvord, Iowa',20213,19);
INSERT INTO "django_geo_db_city" VALUES(16200,'Archer','Archer, Iowa',20214,19);
INSERT INTO "django_geo_db_city" VALUES(16201,'Ashton','Ashton, Iowa',20215,19);
INSERT INTO "django_geo_db_city" VALUES(16202,'Boyden','Boyden, Iowa',20216,19);
INSERT INTO "django_geo_db_city" VALUES(16203,'Doon','Doon, Iowa',20217,19);
INSERT INTO "django_geo_db_city" VALUES(16204,'George','George, Iowa',20218,19);
INSERT INTO "django_geo_db_city" VALUES(16205,'Hospers','Hospers, Iowa',20219,19);
INSERT INTO "django_geo_db_city" VALUES(16206,'Hull','Hull, Iowa',20220,19);
INSERT INTO "django_geo_db_city" VALUES(16207,'Inwood','Inwood, Iowa',20221,19);
INSERT INTO "django_geo_db_city" VALUES(16208,'Larchwood','Larchwood, Iowa',20222,19);
INSERT INTO "django_geo_db_city" VALUES(16209,'Lester','Lester, Iowa',20223,19);
INSERT INTO "django_geo_db_city" VALUES(16210,'Little Rock','Little Rock, Iowa',20224,19);
INSERT INTO "django_geo_db_city" VALUES(16211,'Matlock','Matlock, Iowa',20225,19);
INSERT INTO "django_geo_db_city" VALUES(16212,'Primghar','Primghar, Iowa',20226,19);
INSERT INTO "django_geo_db_city" VALUES(16213,'Rock Rapids','Rock Rapids, Iowa',20227,19);
INSERT INTO "django_geo_db_city" VALUES(16214,'Rock Valley','Rock Valley, Iowa',20228,19);
INSERT INTO "django_geo_db_city" VALUES(16215,'Sanborn','Sanborn, Iowa',20229,19);
INSERT INTO "django_geo_db_city" VALUES(16216,'Sibley','Sibley, Iowa',20230,19);
INSERT INTO "django_geo_db_city" VALUES(16217,'Sioux Center','Sioux Center, Iowa',20231,19);
INSERT INTO "django_geo_db_city" VALUES(16218,'Spencer','Spencer, Iowa',20232,19);
INSERT INTO "django_geo_db_city" VALUES(16219,'Allendorf','Allendorf, Iowa',20233,19);
INSERT INTO "django_geo_db_city" VALUES(16220,'Arnolds Park','Arnolds Park, Iowa',20234,19);
INSERT INTO "django_geo_db_city" VALUES(16221,'Dickens','Dickens, Iowa',20235,19);
INSERT INTO "django_geo_db_city" VALUES(16222,'Estherville','Estherville, Iowa',20236,19);
INSERT INTO "django_geo_db_city" VALUES(16223,'Everly','Everly, Iowa',20237,19);
INSERT INTO "django_geo_db_city" VALUES(16224,'Fostoria','Fostoria, Iowa',20238,19);
INSERT INTO "django_geo_db_city" VALUES(16225,'Gillett Grove','Gillett Grove, Iowa',20239,19);
INSERT INTO "django_geo_db_city" VALUES(16226,'Graettinger','Graettinger, Iowa',20240,19);
INSERT INTO "django_geo_db_city" VALUES(16227,'Greenville','Greenville, Iowa',20241,19);
INSERT INTO "django_geo_db_city" VALUES(16228,'Gruver','Gruver, Iowa',20242,19);
INSERT INTO "django_geo_db_city" VALUES(16229,'Harris','Harris, Iowa',20243,19);
INSERT INTO "django_geo_db_city" VALUES(16230,'Hartley','Hartley, Iowa',20244,19);
INSERT INTO "django_geo_db_city" VALUES(16231,'Lake Park','Lake Park, Iowa',20245,19);
INSERT INTO "django_geo_db_city" VALUES(16232,'May City','May City, Iowa',20246,19);
INSERT INTO "django_geo_db_city" VALUES(16233,'Melvin','Melvin, Iowa',20247,19);
INSERT INTO "django_geo_db_city" VALUES(16234,'Milford','Milford, Iowa',20248,19);
INSERT INTO "django_geo_db_city" VALUES(16235,'Ocheyedan','Ocheyedan, Iowa',20249,19);
INSERT INTO "django_geo_db_city" VALUES(16236,'Okoboji','Okoboji, Iowa',20250,19);
INSERT INTO "django_geo_db_city" VALUES(16237,'Royal','Royal, Iowa',20251,19);
INSERT INTO "django_geo_db_city" VALUES(16238,'Ruthven','Ruthven, Iowa',20252,19);
INSERT INTO "django_geo_db_city" VALUES(16239,'Spirit Lake','Spirit Lake, Iowa',20253,19);
INSERT INTO "django_geo_db_city" VALUES(16240,'Superior','Superior, Iowa',20254,19);
INSERT INTO "django_geo_db_city" VALUES(16241,'Terril','Terril, Iowa',20255,19);
INSERT INTO "django_geo_db_city" VALUES(16242,'Wallingford','Wallingford, Iowa',20256,19);
INSERT INTO "django_geo_db_city" VALUES(16243,'Webb','Webb, Iowa',20257,19);
INSERT INTO "django_geo_db_city" VALUES(16244,'Carroll','Carroll, Iowa',20258,19);
INSERT INTO "django_geo_db_city" VALUES(16245,'Arcadia','Arcadia, Iowa',20259,19);
INSERT INTO "django_geo_db_city" VALUES(16246,'Arthur','Arthur, Iowa',20260,19);
INSERT INTO "django_geo_db_city" VALUES(16247,'Aspinwall','Aspinwall, Iowa',20261,19);
INSERT INTO "django_geo_db_city" VALUES(16248,'Auburn','Auburn, Iowa',20262,19);
INSERT INTO "django_geo_db_city" VALUES(16249,'Breda','Breda, Iowa',20263,19);
INSERT INTO "django_geo_db_city" VALUES(16250,'Charter Oak','Charter Oak, Iowa',20264,19);
INSERT INTO "django_geo_db_city" VALUES(16251,'Dedham','Dedham, Iowa',20265,19);
INSERT INTO "django_geo_db_city" VALUES(16252,'Deloit','Deloit, Iowa',20266,19);
INSERT INTO "django_geo_db_city" VALUES(16253,'Denison','Denison, Iowa',20267,19);
INSERT INTO "django_geo_db_city" VALUES(16254,'Glidden','Glidden, Iowa',20268,19);
INSERT INTO "django_geo_db_city" VALUES(16255,'Halbur','Halbur, Iowa',20269,19);
INSERT INTO "django_geo_db_city" VALUES(16256,'Ida Grove','Ida Grove, Iowa',20270,19);
INSERT INTO "django_geo_db_city" VALUES(16257,'Irwin','Irwin, Iowa',20271,19);
INSERT INTO "django_geo_db_city" VALUES(16258,'Kirkman','Kirkman, Iowa',20272,19);
INSERT INTO "django_geo_db_city" VALUES(16259,'Kiron','Kiron, Iowa',20273,19);
INSERT INTO "django_geo_db_city" VALUES(16260,'Lake City','Lake City, Iowa',20274,19);
INSERT INTO "django_geo_db_city" VALUES(16261,'Lake View','Lake View, Iowa',20275,19);
INSERT INTO "django_geo_db_city" VALUES(16262,'Lanesboro','Lanesboro, Iowa',20276,19);
INSERT INTO "django_geo_db_city" VALUES(16263,'Lidderdale','Lidderdale, Iowa',20277,19);
INSERT INTO "django_geo_db_city" VALUES(16264,'Lohrville','Lohrville, Iowa',20278,19);
INSERT INTO "django_geo_db_city" VALUES(16265,'Manilla','Manilla, Iowa',20279,19);
INSERT INTO "django_geo_db_city" VALUES(16266,'Manning','Manning, Iowa',20280,19);
INSERT INTO "django_geo_db_city" VALUES(16267,'Odebolt','Odebolt, Iowa',20281,19);
INSERT INTO "django_geo_db_city" VALUES(16268,'Ralston','Ralston, Iowa',20282,19);
INSERT INTO "django_geo_db_city" VALUES(16269,'Ricketts','Ricketts, Iowa',20283,19);
INSERT INTO "django_geo_db_city" VALUES(16270,'Schleswig','Schleswig, Iowa',20284,19);
INSERT INTO "django_geo_db_city" VALUES(16271,'Scranton','Scranton, Iowa',20285,19);
INSERT INTO "django_geo_db_city" VALUES(16272,'Templeton','Templeton, Iowa',20286,19);
INSERT INTO "django_geo_db_city" VALUES(16273,'Vail','Vail, Iowa',20287,19);
INSERT INTO "django_geo_db_city" VALUES(16274,'Wall Lake','Wall Lake, Iowa',20288,19);
INSERT INTO "django_geo_db_city" VALUES(16275,'Westside','Westside, Iowa',20289,19);
INSERT INTO "django_geo_db_city" VALUES(16276,'Council Bluffs','Council Bluffs, Iowa',20291,19);
INSERT INTO "django_geo_db_city" VALUES(16277,'Carter Lake','Carter Lake, Iowa',20294,19);
INSERT INTO "django_geo_db_city" VALUES(16278,'Griswold','Griswold, Iowa',20295,19);
INSERT INTO "django_geo_db_city" VALUES(16279,'Arion','Arion, Iowa',20296,19);
INSERT INTO "django_geo_db_city" VALUES(16280,'Avoca','Avoca, Iowa',20297,19);
INSERT INTO "django_geo_db_city" VALUES(16281,'Blencoe','Blencoe, Iowa',20298,19);
INSERT INTO "django_geo_db_city" VALUES(16282,'Carson','Carson, Iowa',20299,19);
INSERT INTO "django_geo_db_city" VALUES(16283,'Crescent','Crescent, Iowa',20300,19);
INSERT INTO "django_geo_db_city" VALUES(16284,'Defiance','Defiance, Iowa',20301,19);
INSERT INTO "django_geo_db_city" VALUES(16285,'Dow City','Dow City, Iowa',20302,19);
INSERT INTO "django_geo_db_city" VALUES(16286,'Dunlap','Dunlap, Iowa',20303,19);
INSERT INTO "django_geo_db_city" VALUES(16287,'Earling','Earling, Iowa',20304,19);
INSERT INTO "django_geo_db_city" VALUES(16288,'Elk Horn','Elk Horn, Iowa',20305,19);
INSERT INTO "django_geo_db_city" VALUES(16289,'Elliott','Elliott, Iowa',20306,19);
INSERT INTO "django_geo_db_city" VALUES(16290,'Emerson','Emerson, Iowa',20307,19);
INSERT INTO "django_geo_db_city" VALUES(16291,'Glenwood','Glenwood, Iowa',20308,19);
INSERT INTO "django_geo_db_city" VALUES(16292,'Hancock','Hancock, Iowa',20310,19);
INSERT INTO "django_geo_db_city" VALUES(16293,'Harlan','Harlan, Iowa',20311,19);
INSERT INTO "django_geo_db_city" VALUES(16294,'Hastings','Hastings, Iowa',20312,19);
INSERT INTO "django_geo_db_city" VALUES(16295,'Henderson','Henderson, Iowa',20313,19);
INSERT INTO "django_geo_db_city" VALUES(16296,'Honey Creek','Honey Creek, Iowa',20314,19);
INSERT INTO "django_geo_db_city" VALUES(16297,'Kimballton','Kimballton, Iowa',20315,19);
INSERT INTO "django_geo_db_city" VALUES(16298,'Lewis','Lewis, Iowa',20316,19);
INSERT INTO "django_geo_db_city" VALUES(16299,'Little Sioux','Little Sioux, Iowa',20317,19);
INSERT INTO "django_geo_db_city" VALUES(16300,'Logan','Logan, Iowa',20318,19);
INSERT INTO "django_geo_db_city" VALUES(16301,'McClelland','McClelland, Iowa',20320,19);
INSERT INTO "django_geo_db_city" VALUES(16302,'Macedonia','Macedonia, Iowa',20321,19);
INSERT INTO "django_geo_db_city" VALUES(16303,'Magnolia','Magnolia, Iowa',20322,19);
INSERT INTO "django_geo_db_city" VALUES(16304,'Malvern','Malvern, Iowa',20323,19);
INSERT INTO "django_geo_db_city" VALUES(16305,'Marne','Marne, Iowa',20324,19);
INSERT INTO "django_geo_db_city" VALUES(16306,'Minden','Minden, Iowa',20325,19);
INSERT INTO "django_geo_db_city" VALUES(16307,'Mineola','Mineola, Iowa',20326,19);
INSERT INTO "django_geo_db_city" VALUES(16308,'Missouri Valley','Missouri Valley, Iowa',20327,19);
INSERT INTO "django_geo_db_city" VALUES(16309,'Modale','Modale, Iowa',20328,19);
INSERT INTO "django_geo_db_city" VALUES(16310,'Mondamin','Mondamin, Iowa',20329,19);
INSERT INTO "django_geo_db_city" VALUES(16311,'Moorhead','Moorhead, Iowa',20330,19);
INSERT INTO "django_geo_db_city" VALUES(16312,'Neola','Neola, Iowa',20331,19);
INSERT INTO "django_geo_db_city" VALUES(16313,'Oakland','Oakland, Iowa',20332,19);
INSERT INTO "django_geo_db_city" VALUES(16314,'Pacific Junction','Pacific Junction, Iowa',20333,19);
INSERT INTO "django_geo_db_city" VALUES(16315,'Panama','Panama, Iowa',20334,19);
INSERT INTO "django_geo_db_city" VALUES(16316,'Persia','Persia, Iowa',20335,19);
INSERT INTO "django_geo_db_city" VALUES(16317,'Pisgah','Pisgah, Iowa',20336,19);
INSERT INTO "django_geo_db_city" VALUES(16318,'Portsmouth','Portsmouth, Iowa',20337,19);
INSERT INTO "django_geo_db_city" VALUES(16319,'Red Oak','Red Oak, Iowa',20338,19);
INSERT INTO "django_geo_db_city" VALUES(16320,'Shelby','Shelby, Iowa',20339,19);
INSERT INTO "django_geo_db_city" VALUES(16321,'Silver City','Silver City, Iowa',20340,19);
INSERT INTO "django_geo_db_city" VALUES(16322,'Soldier','Soldier, Iowa',20341,19);
INSERT INTO "django_geo_db_city" VALUES(16323,'Stanton','Stanton, Iowa',20342,19);
INSERT INTO "django_geo_db_city" VALUES(16324,'Tennant','Tennant, Iowa',20343,19);
INSERT INTO "django_geo_db_city" VALUES(16325,'Treynor','Treynor, Iowa',20344,19);
INSERT INTO "django_geo_db_city" VALUES(16326,'Underwood','Underwood, Iowa',20345,19);
INSERT INTO "django_geo_db_city" VALUES(16327,'Walnut','Walnut, Iowa',20346,19);
INSERT INTO "django_geo_db_city" VALUES(16328,'Westphalia','Westphalia, Iowa',20347,19);
INSERT INTO "django_geo_db_city" VALUES(16329,'Woodbine','Woodbine, Iowa',20348,19);
INSERT INTO "django_geo_db_city" VALUES(16330,'Shenandoah','Shenandoah, Iowa',20351,19);
INSERT INTO "django_geo_db_city" VALUES(16331,'Blanchard','Blanchard, Iowa',20353,19);
INSERT INTO "django_geo_db_city" VALUES(16332,'Braddyville','Braddyville, Iowa',20354,19);
INSERT INTO "django_geo_db_city" VALUES(16333,'Clarinda','Clarinda, Iowa',20355,19);
INSERT INTO "django_geo_db_city" VALUES(16334,'Coin','Coin, Iowa',20356,19);
INSERT INTO "django_geo_db_city" VALUES(16335,'College Springs','College Springs, Iowa',20357,19);
INSERT INTO "django_geo_db_city" VALUES(16336,'Essex','Essex, Iowa',20358,19);
INSERT INTO "django_geo_db_city" VALUES(16337,'Farragut','Farragut, Iowa',20359,19);
INSERT INTO "django_geo_db_city" VALUES(16338,'Hamburg','Hamburg, Iowa',20360,19);
INSERT INTO "django_geo_db_city" VALUES(16339,'Imogene','Imogene, Iowa',20361,19);
INSERT INTO "django_geo_db_city" VALUES(16340,'New Market','New Market, Iowa',20362,19);
INSERT INTO "django_geo_db_city" VALUES(16341,'Northboro','Northboro, Iowa',20363,19);
INSERT INTO "django_geo_db_city" VALUES(16342,'Percival','Percival, Iowa',20364,19);
INSERT INTO "django_geo_db_city" VALUES(16343,'Randolph','Randolph, Iowa',20365,19);
INSERT INTO "django_geo_db_city" VALUES(16344,'Riverton','Riverton, Iowa',20366,19);
INSERT INTO "django_geo_db_city" VALUES(16345,'Shambaugh','Shambaugh, Iowa',20367,19);
INSERT INTO "django_geo_db_city" VALUES(16346,'Sidney','Sidney, Iowa',20368,19);
INSERT INTO "django_geo_db_city" VALUES(16347,'Tabor','Tabor, Iowa',20369,19);
INSERT INTO "django_geo_db_city" VALUES(16348,'Thurman','Thurman, Iowa',20370,19);
INSERT INTO "django_geo_db_city" VALUES(16349,'Yorktown','Yorktown, Iowa',20371,19);
INSERT INTO "django_geo_db_city" VALUES(16350,'Dubuque','Dubuque, Iowa',20372,19);
INSERT INTO "django_geo_db_city" VALUES(16351,'Andrew','Andrew, Iowa',20376,19);
INSERT INTO "django_geo_db_city" VALUES(16352,'Bellevue','Bellevue, Iowa',20377,19);
INSERT INTO "django_geo_db_city" VALUES(16353,'Bernard','Bernard, Iowa',20378,19);
INSERT INTO "django_geo_db_city" VALUES(16354,'Cascade','Cascade, Iowa',20379,19);
INSERT INTO "django_geo_db_city" VALUES(16355,'Colesburg','Colesburg, Iowa',20380,19);
INSERT INTO "django_geo_db_city" VALUES(16356,'Delaware','Delaware, Iowa',20381,19);
INSERT INTO "django_geo_db_city" VALUES(16357,'Delmar','Delmar, Iowa',20382,19);
INSERT INTO "django_geo_db_city" VALUES(16358,'Dundee','Dundee, Iowa',20383,19);
INSERT INTO "django_geo_db_city" VALUES(16359,'Durango','Durango, Iowa',20384,19);
INSERT INTO "django_geo_db_city" VALUES(16360,'Dyersville','Dyersville, Iowa',20385,19);
INSERT INTO "django_geo_db_city" VALUES(16361,'Earlville','Earlville, Iowa',20386,19);
INSERT INTO "django_geo_db_city" VALUES(16362,'Edgewood','Edgewood, Iowa',20387,19);
INSERT INTO "django_geo_db_city" VALUES(16363,'Elkader','Elkader, Iowa',20388,19);
INSERT INTO "django_geo_db_city" VALUES(16364,'Elkport','Elkport, Iowa',20389,19);
INSERT INTO "django_geo_db_city" VALUES(16365,'Epworth','Epworth, Iowa',20390,19);
INSERT INTO "django_geo_db_city" VALUES(16366,'Farley','Farley, Iowa',20391,19);
INSERT INTO "django_geo_db_city" VALUES(16367,'Farmersburg','Farmersburg, Iowa',20392,19);
INSERT INTO "django_geo_db_city" VALUES(16368,'Garber','Garber, Iowa',20393,19);
INSERT INTO "django_geo_db_city" VALUES(16369,'Garnavillo','Garnavillo, Iowa',20394,19);
INSERT INTO "django_geo_db_city" VALUES(16370,'Greeley','Greeley, Iowa',20395,19);
INSERT INTO "django_geo_db_city" VALUES(16371,'Guttenberg','Guttenberg, Iowa',20396,19);
INSERT INTO "django_geo_db_city" VALUES(16372,'Holy Cross','Holy Cross, Iowa',20397,19);
INSERT INTO "django_geo_db_city" VALUES(16373,'La Motte','La Motte, Iowa',20398,19);
INSERT INTO "django_geo_db_city" VALUES(16374,'Littleport','Littleport, Iowa',20399,19);
INSERT INTO "django_geo_db_city" VALUES(16375,'Luxemburg','Luxemburg, Iowa',20400,19);
INSERT INTO "django_geo_db_city" VALUES(16376,'Manchester','Manchester, Iowa',20401,19);
INSERT INTO "django_geo_db_city" VALUES(16377,'Maquoketa','Maquoketa, Iowa',20402,19);
INSERT INTO "django_geo_db_city" VALUES(16378,'Miles','Miles, Iowa',20403,19);
INSERT INTO "django_geo_db_city" VALUES(16379,'New Vienna','New Vienna, Iowa',20404,19);
INSERT INTO "django_geo_db_city" VALUES(16380,'North Buena Vista','North Buena Vista, Iowa',20405,19);
INSERT INTO "django_geo_db_city" VALUES(16381,'Peosta','Peosta, Iowa',20406,19);
INSERT INTO "django_geo_db_city" VALUES(16382,'Preston','Preston, Iowa',20407,19);
INSERT INTO "django_geo_db_city" VALUES(16383,'Sabula','Sabula, Iowa',20408,19);
INSERT INTO "django_geo_db_city" VALUES(16384,'Saint Donatus','Saint Donatus, Iowa',20409,19);
INSERT INTO "django_geo_db_city" VALUES(16385,'Saint Olaf','Saint Olaf, Iowa',20410,19);
INSERT INTO "django_geo_db_city" VALUES(16386,'Sherrill','Sherrill, Iowa',20411,19);
INSERT INTO "django_geo_db_city" VALUES(16387,'Spragueville','Spragueville, Iowa',20412,19);
INSERT INTO "django_geo_db_city" VALUES(16388,'Springbrook','Springbrook, Iowa',20413,19);
INSERT INTO "django_geo_db_city" VALUES(16389,'Strawberry Point','Strawberry Point, Iowa',20414,19);
INSERT INTO "django_geo_db_city" VALUES(16390,'Volga','Volga, Iowa',20415,19);
INSERT INTO "django_geo_db_city" VALUES(16391,'Worthington','Worthington, Iowa',20416,19);
INSERT INTO "django_geo_db_city" VALUES(16392,'Zwingle','Zwingle, Iowa',20417,19);
INSERT INTO "django_geo_db_city" VALUES(16393,'Decorah','Decorah, Iowa',20418,19);
INSERT INTO "django_geo_db_city" VALUES(16394,'Burr Oak','Burr Oak, Iowa',20419,19);
INSERT INTO "django_geo_db_city" VALUES(16395,'Calmar','Calmar, Iowa',20420,19);
INSERT INTO "django_geo_db_city" VALUES(16396,'Castalia','Castalia, Iowa',20421,19);
INSERT INTO "django_geo_db_city" VALUES(16397,'Chester','Chester, Iowa',20422,19);
INSERT INTO "django_geo_db_city" VALUES(16398,'Clermont','Clermont, Iowa',20423,19);
INSERT INTO "django_geo_db_city" VALUES(16399,'Cresco','Cresco, Iowa',20424,19);
INSERT INTO "django_geo_db_city" VALUES(16400,'Dorchester','Dorchester, Iowa',20425,19);
INSERT INTO "django_geo_db_city" VALUES(16401,'Elgin','Elgin, Iowa',20426,19);
INSERT INTO "django_geo_db_city" VALUES(16402,'Fayette','Fayette, Iowa',20427,19);
INSERT INTO "django_geo_db_city" VALUES(16403,'Fort Atkinson','Fort Atkinson, Iowa',20428,19);
INSERT INTO "django_geo_db_city" VALUES(16404,'Harpers Ferry','Harpers Ferry, Iowa',20429,19);
INSERT INTO "django_geo_db_city" VALUES(16405,'Hawkeye','Hawkeye, Iowa',20430,19);
INSERT INTO "django_geo_db_city" VALUES(16406,'Highlandville','Highlandville, Iowa',20431,19);
INSERT INTO "django_geo_db_city" VALUES(16407,'Lansing','Lansing, Iowa',20432,19);
INSERT INTO "django_geo_db_city" VALUES(16408,'Lawler','Lawler, Iowa',20433,19);
INSERT INTO "django_geo_db_city" VALUES(16409,'Lime Springs','Lime Springs, Iowa',20434,19);
INSERT INTO "django_geo_db_city" VALUES(16410,'Luana','Luana, Iowa',20435,19);
INSERT INTO "django_geo_db_city" VALUES(16411,'McGregor','McGregor, Iowa',20436,19);
INSERT INTO "django_geo_db_city" VALUES(16412,'Marquette','Marquette, Iowa',20437,19);
INSERT INTO "django_geo_db_city" VALUES(16413,'Monona','Monona, Iowa',20438,19);
INSERT INTO "django_geo_db_city" VALUES(16414,'New Albin','New Albin, Iowa',20439,19);
INSERT INTO "django_geo_db_city" VALUES(16415,'Ossian','Ossian, Iowa',20440,19);
INSERT INTO "django_geo_db_city" VALUES(16416,'Postville','Postville, Iowa',20441,19);
INSERT INTO "django_geo_db_city" VALUES(16417,'Protivin','Protivin, Iowa',20442,19);
INSERT INTO "django_geo_db_city" VALUES(16418,'Randalia','Randalia, Iowa',20443,19);
INSERT INTO "django_geo_db_city" VALUES(16419,'Ridgeway','Ridgeway, Iowa',20444,19);
INSERT INTO "django_geo_db_city" VALUES(16420,'Saint Lucas','Saint Lucas, Iowa',20445,19);
INSERT INTO "django_geo_db_city" VALUES(16421,'Spillville','Spillville, Iowa',20446,19);
INSERT INTO "django_geo_db_city" VALUES(16422,'Wadena','Wadena, Iowa',20447,19);
INSERT INTO "django_geo_db_city" VALUES(16423,'Waterville','Waterville, Iowa',20448,19);
INSERT INTO "django_geo_db_city" VALUES(16424,'Waucoma','Waucoma, Iowa',20449,19);
INSERT INTO "django_geo_db_city" VALUES(16425,'Waukon','Waukon, Iowa',20450,19);
INSERT INTO "django_geo_db_city" VALUES(16426,'West Union','West Union, Iowa',20451,19);
INSERT INTO "django_geo_db_city" VALUES(16427,'Ainsworth','Ainsworth, Iowa',20452,19);
INSERT INTO "django_geo_db_city" VALUES(16428,'Alburnett','Alburnett, Iowa',20453,19);
INSERT INTO "django_geo_db_city" VALUES(16429,'Amana','Amana, Iowa',20454,19);
INSERT INTO "django_geo_db_city" VALUES(16430,'Anamosa','Anamosa, Iowa',20456,19);
INSERT INTO "django_geo_db_city" VALUES(16431,'Atkins','Atkins, Iowa',20457,19);
INSERT INTO "django_geo_db_city" VALUES(16432,'Baldwin','Baldwin, Iowa',20458,19);
INSERT INTO "django_geo_db_city" VALUES(16433,'Belle Plaine','Belle Plaine, Iowa',20459,19);
INSERT INTO "django_geo_db_city" VALUES(16434,'Blairstown','Blairstown, Iowa',20460,19);
INSERT INTO "django_geo_db_city" VALUES(16435,'Brandon','Brandon, Iowa',20461,19);
INSERT INTO "django_geo_db_city" VALUES(16436,'Brooklyn','Brooklyn, Iowa',20462,19);
INSERT INTO "django_geo_db_city" VALUES(16437,'Center Junction','Center Junction, Iowa',20463,19);
INSERT INTO "django_geo_db_city" VALUES(16438,'Center Point','Center Point, Iowa',20464,19);
INSERT INTO "django_geo_db_city" VALUES(16439,'Central City','Central City, Iowa',20465,19);
INSERT INTO "django_geo_db_city" VALUES(16440,'Chelsea','Chelsea, Iowa',20466,19);
INSERT INTO "django_geo_db_city" VALUES(16441,'Clarence','Clarence, Iowa',20467,19);
INSERT INTO "django_geo_db_city" VALUES(16442,'Clutier','Clutier, Iowa',20468,19);
INSERT INTO "django_geo_db_city" VALUES(16443,'Coggon','Coggon, Iowa',20469,19);
INSERT INTO "django_geo_db_city" VALUES(16444,'Prairieburg','Prairieburg, Iowa',20470,19);
INSERT INTO "django_geo_db_city" VALUES(16445,'Conroy','Conroy, Iowa',20471,19);
INSERT INTO "django_geo_db_city" VALUES(16446,'Guernsey','Guernsey, Iowa',20472,19);
INSERT INTO "django_geo_db_city" VALUES(16447,'Deep River','Deep River, Iowa',20473,19);
INSERT INTO "django_geo_db_city" VALUES(16448,'Delhi','Delhi, Iowa',20474,19);
INSERT INTO "django_geo_db_city" VALUES(16449,'Dysart','Dysart, Iowa',20475,19);
INSERT INTO "django_geo_db_city" VALUES(16450,'Elberon','Elberon, Iowa',20476,19);
INSERT INTO "django_geo_db_city" VALUES(16451,'Elwood','Elwood, Iowa',20477,19);
INSERT INTO "django_geo_db_city" VALUES(16452,'Ely','Ely, Iowa',20478,19);
INSERT INTO "django_geo_db_city" VALUES(16453,'Fairfax','Fairfax, Iowa',20479,19);
INSERT INTO "django_geo_db_city" VALUES(16454,'Garrison','Garrison, Iowa',20480,19);
INSERT INTO "django_geo_db_city" VALUES(16455,'Harper','Harper, Iowa',20481,19);
INSERT INTO "django_geo_db_city" VALUES(16456,'Hartwick','Hartwick, Iowa',20482,19);
INSERT INTO "django_geo_db_city" VALUES(16457,'Hiawatha','Hiawatha, Iowa',20483,19);
INSERT INTO "django_geo_db_city" VALUES(16458,'Hills','Hills, Iowa',20484,19);
INSERT INTO "django_geo_db_city" VALUES(16459,'Homestead','Homestead, Iowa',20485,19);
INSERT INTO "django_geo_db_city" VALUES(16460,'Hopkinton','Hopkinton, Iowa',20486,19);
INSERT INTO "django_geo_db_city" VALUES(16461,'Tama','Tama, Iowa',20487,19);
INSERT INTO "django_geo_db_city" VALUES(16462,'Iowa City','Iowa City, Iowa',20488,19);
INSERT INTO "django_geo_db_city" VALUES(16463,'Coralville','Coralville, Iowa',20489,19);
INSERT INTO "django_geo_db_city" VALUES(16464,'Kalona','Kalona, Iowa',20495,19);
INSERT INTO "django_geo_db_city" VALUES(16465,'Keota','Keota, Iowa',20496,19);
INSERT INTO "django_geo_db_city" VALUES(16466,'Keystone','Keystone, Iowa',20497,19);
INSERT INTO "django_geo_db_city" VALUES(16467,'Ladora','Ladora, Iowa',20498,19);
INSERT INTO "django_geo_db_city" VALUES(16468,'Langworthy','Langworthy, Iowa',20499,19);
INSERT INTO "django_geo_db_city" VALUES(16469,'Lisbon','Lisbon, Iowa',20500,19);
INSERT INTO "django_geo_db_city" VALUES(16470,'Lost Nation','Lost Nation, Iowa',20501,19);
INSERT INTO "django_geo_db_city" VALUES(16471,'Lowden','Lowden, Iowa',20502,19);
INSERT INTO "django_geo_db_city" VALUES(16472,'Luzerne','Luzerne, Iowa',20503,19);
INSERT INTO "django_geo_db_city" VALUES(16473,'Marengo','Marengo, Iowa',20504,19);
INSERT INTO "django_geo_db_city" VALUES(16474,'Marion','Marion, Iowa',20505,19);
INSERT INTO "django_geo_db_city" VALUES(16475,'Martelle','Martelle, Iowa',20506,19);
INSERT INTO "django_geo_db_city" VALUES(16476,'Mechanicsville','Mechanicsville, Iowa',20507,19);
INSERT INTO "django_geo_db_city" VALUES(16477,'Middle Amana','Middle Amana, Iowa',20508,19);
INSERT INTO "django_geo_db_city" VALUES(16478,'Millersburg','Millersburg, Iowa',20509,19);
INSERT INTO "django_geo_db_city" VALUES(16479,'Monmouth','Monmouth, Iowa',20510,19);
INSERT INTO "django_geo_db_city" VALUES(16480,'Monticello','Monticello, Iowa',20511,19);
INSERT INTO "django_geo_db_city" VALUES(16481,'Morley','Morley, Iowa',20512,19);
INSERT INTO "django_geo_db_city" VALUES(16482,'Mount Auburn','Mount Auburn, Iowa',20513,19);
INSERT INTO "django_geo_db_city" VALUES(16483,'Mount Vernon','Mount Vernon, Iowa',20514,19);
INSERT INTO "django_geo_db_city" VALUES(16484,'Newhall','Newhall, Iowa',20515,19);
INSERT INTO "django_geo_db_city" VALUES(16485,'North English','North English, Iowa',20516,19);
INSERT INTO "django_geo_db_city" VALUES(16486,'North Liberty','North Liberty, Iowa',20517,19);
INSERT INTO "django_geo_db_city" VALUES(16487,'Norway','Norway, Iowa',20518,19);
INSERT INTO "django_geo_db_city" VALUES(16488,'Oakdale','Oakdale, Iowa',20491,19);
INSERT INTO "django_geo_db_city" VALUES(16489,'Olin','Olin, Iowa',20519,19);
INSERT INTO "django_geo_db_city" VALUES(16490,'Onslow','Onslow, Iowa',20520,19);
INSERT INTO "django_geo_db_city" VALUES(16491,'Oxford','Oxford, Iowa',20521,19);
INSERT INTO "django_geo_db_city" VALUES(16492,'Oxford Junction','Oxford Junction, Iowa',20522,19);
INSERT INTO "django_geo_db_city" VALUES(16493,'Palo','Palo, Iowa',20523,19);
INSERT INTO "django_geo_db_city" VALUES(16494,'Parnell','Parnell, Iowa',20524,19);
INSERT INTO "django_geo_db_city" VALUES(16495,'Quasqueton','Quasqueton, Iowa',20525,19);
INSERT INTO "django_geo_db_city" VALUES(16496,'Riverside','Riverside, Iowa',20526,19);
INSERT INTO "django_geo_db_city" VALUES(16497,'Robins','Robins, Iowa',20527,19);
INSERT INTO "django_geo_db_city" VALUES(16498,'Rowley','Rowley, Iowa',20528,19);
INSERT INTO "django_geo_db_city" VALUES(16499,'Ryan','Ryan, Iowa',20529,19);
INSERT INTO "django_geo_db_city" VALUES(16500,'Shellsburg','Shellsburg, Iowa',20530,19);
INSERT INTO "django_geo_db_city" VALUES(16501,'Solon','Solon, Iowa',20531,19);
INSERT INTO "django_geo_db_city" VALUES(16502,'South Amana','South Amana, Iowa',20532,19);
INSERT INTO "django_geo_db_city" VALUES(16503,'South English','South English, Iowa',20533,19);
INSERT INTO "django_geo_db_city" VALUES(16504,'Springville','Springville, Iowa',20534,19);
INSERT INTO "django_geo_db_city" VALUES(16505,'Stanwood','Stanwood, Iowa',20535,19);
INSERT INTO "django_geo_db_city" VALUES(16506,'Swisher','Swisher, Iowa',20536,19);
INSERT INTO "django_geo_db_city" VALUES(16507,'Tiffin','Tiffin, Iowa',20538,19);
INSERT INTO "django_geo_db_city" VALUES(16508,'Toddville','Toddville, Iowa',20539,19);
INSERT INTO "django_geo_db_city" VALUES(16509,'Toledo','Toledo, Iowa',20540,19);
INSERT INTO "django_geo_db_city" VALUES(16510,'Troy Mills','Troy Mills, Iowa',20541,19);
INSERT INTO "django_geo_db_city" VALUES(16511,'Urbana','Urbana, Iowa',20542,19);
INSERT INTO "django_geo_db_city" VALUES(16512,'Van Horne','Van Horne, Iowa',20543,19);
INSERT INTO "django_geo_db_city" VALUES(16513,'Victor','Victor, Iowa',20544,19);
INSERT INTO "django_geo_db_city" VALUES(16514,'Vining','Vining, Iowa',20545,19);
INSERT INTO "django_geo_db_city" VALUES(16515,'Vinton','Vinton, Iowa',20546,19);
INSERT INTO "django_geo_db_city" VALUES(16516,'Viola','Viola, Iowa',20547,19);
INSERT INTO "django_geo_db_city" VALUES(16517,'Walford','Walford, Iowa',20548,19);
INSERT INTO "django_geo_db_city" VALUES(16518,'Walker','Walker, Iowa',20549,19);
INSERT INTO "django_geo_db_city" VALUES(16519,'Washington','Washington, Iowa',20550,19);
INSERT INTO "django_geo_db_city" VALUES(16520,'Watkins','Watkins, Iowa',20551,19);
INSERT INTO "django_geo_db_city" VALUES(16521,'Webster','Webster, Iowa',20552,19);
INSERT INTO "django_geo_db_city" VALUES(16522,'Wellman','Wellman, Iowa',20553,19);
INSERT INTO "django_geo_db_city" VALUES(16523,'West Branch','West Branch, Iowa',20554,19);
INSERT INTO "django_geo_db_city" VALUES(16524,'West Chester','West Chester, Iowa',20555,19);
INSERT INTO "django_geo_db_city" VALUES(16525,'Williamsburg','Williamsburg, Iowa',20556,19);
INSERT INTO "django_geo_db_city" VALUES(16526,'Wyoming','Wyoming, Iowa',20557,19);
INSERT INTO "django_geo_db_city" VALUES(16527,'Cedar Rapids','Cedar Rapids, Iowa',20558,19);
INSERT INTO "django_geo_db_city" VALUES(16528,'Ottumwa','Ottumwa, Iowa',20565,19);
INSERT INTO "django_geo_db_city" VALUES(16529,'Agency','Agency, Iowa',20566,19);
INSERT INTO "django_geo_db_city" VALUES(16530,'Albia','Albia, Iowa',20567,19);
INSERT INTO "django_geo_db_city" VALUES(16531,'Batavia','Batavia, Iowa',20568,19);
INSERT INTO "django_geo_db_city" VALUES(16532,'Beacon','Beacon, Iowa',20569,19);
INSERT INTO "django_geo_db_city" VALUES(16533,'Birmingham','Birmingham, Iowa',20570,19);
INSERT INTO "django_geo_db_city" VALUES(16534,'Blakesburg','Blakesburg, Iowa',20571,19);
INSERT INTO "django_geo_db_city" VALUES(16535,'Bloomfield','Bloomfield, Iowa',20572,19);
INSERT INTO "django_geo_db_city" VALUES(16536,'West Grove','West Grove, Iowa',20573,19);
INSERT INTO "django_geo_db_city" VALUES(16537,'Brighton','Brighton, Iowa',20574,19);
INSERT INTO "django_geo_db_city" VALUES(16538,'Cantril','Cantril, Iowa',20575,19);
INSERT INTO "django_geo_db_city" VALUES(16539,'Cedar','Cedar, Iowa',20576,19);
INSERT INTO "django_geo_db_city" VALUES(16540,'Centerville','Centerville, Iowa',20577,19);
INSERT INTO "django_geo_db_city" VALUES(16541,'Chillicothe','Chillicothe, Iowa',20578,19);
INSERT INTO "django_geo_db_city" VALUES(16542,'Cincinnati','Cincinnati, Iowa',20579,19);
INSERT INTO "django_geo_db_city" VALUES(16543,'Delta','Delta, Iowa',20580,19);
INSERT INTO "django_geo_db_city" VALUES(16544,'Douds','Douds, Iowa',20581,19);
INSERT INTO "django_geo_db_city" VALUES(16545,'Drakesville','Drakesville, Iowa',20582,19);
INSERT INTO "django_geo_db_city" VALUES(16546,'Eddyville','Eddyville, Iowa',20583,19);
INSERT INTO "django_geo_db_city" VALUES(16547,'Eldon','Eldon, Iowa',20584,19);
INSERT INTO "django_geo_db_city" VALUES(16548,'Exline','Exline, Iowa',20585,19);
INSERT INTO "django_geo_db_city" VALUES(16549,'Fairfield','Fairfield, Iowa',20586,19);
INSERT INTO "django_geo_db_city" VALUES(16550,'Floris','Floris, Iowa',20588,19);
INSERT INTO "django_geo_db_city" VALUES(16551,'Fremont','Fremont, Iowa',20589,19);
INSERT INTO "django_geo_db_city" VALUES(16552,'Hayesville','Hayesville, Iowa',20590,19);
INSERT INTO "django_geo_db_city" VALUES(16553,'Hedrick','Hedrick, Iowa',20591,19);
INSERT INTO "django_geo_db_city" VALUES(16554,'Keosauqua','Keosauqua, Iowa',20592,19);
INSERT INTO "django_geo_db_city" VALUES(16555,'Kirkville','Kirkville, Iowa',20593,19);
INSERT INTO "django_geo_db_city" VALUES(16556,'Libertyville','Libertyville, Iowa',20594,19);
INSERT INTO "django_geo_db_city" VALUES(16557,'Martinsburg','Martinsburg, Iowa',20595,19);
INSERT INTO "django_geo_db_city" VALUES(16558,'Melrose','Melrose, Iowa',20596,19);
INSERT INTO "django_geo_db_city" VALUES(16559,'Milton','Milton, Iowa',20597,19);
INSERT INTO "django_geo_db_city" VALUES(16560,'Moravia','Moravia, Iowa',20598,19);
INSERT INTO "django_geo_db_city" VALUES(16561,'Moulton','Moulton, Iowa',20599,19);
INSERT INTO "django_geo_db_city" VALUES(16562,'Mount Sterling','Mount Sterling, Iowa',20600,19);
INSERT INTO "django_geo_db_city" VALUES(16563,'Mystic','Mystic, Iowa',20601,19);
INSERT INTO "django_geo_db_city" VALUES(16564,'Ollie','Ollie, Iowa',20602,19);
INSERT INTO "django_geo_db_city" VALUES(16565,'Oskaloosa','Oskaloosa, Iowa',20603,19);
INSERT INTO "django_geo_db_city" VALUES(16566,'Packwood','Packwood, Iowa',20604,19);
INSERT INTO "django_geo_db_city" VALUES(16567,'Plano','Plano, Iowa',20605,19);
INSERT INTO "django_geo_db_city" VALUES(16568,'Promise City','Promise City, Iowa',20606,19);
INSERT INTO "django_geo_db_city" VALUES(16569,'Pulaski','Pulaski, Iowa',20607,19);
INSERT INTO "django_geo_db_city" VALUES(16570,'Richland','Richland, Iowa',20608,19);
INSERT INTO "django_geo_db_city" VALUES(16571,'Rose Hill','Rose Hill, Iowa',20609,19);
INSERT INTO "django_geo_db_city" VALUES(16572,'Selma','Selma, Iowa',20610,19);
INSERT INTO "django_geo_db_city" VALUES(16573,'Seymour','Seymour, Iowa',20611,19);
INSERT INTO "django_geo_db_city" VALUES(16574,'Sigourney','Sigourney, Iowa',20612,19);
INSERT INTO "django_geo_db_city" VALUES(16575,'Udell','Udell, Iowa',20613,19);
INSERT INTO "django_geo_db_city" VALUES(16576,'Unionville','Unionville, Iowa',20614,19);
INSERT INTO "django_geo_db_city" VALUES(16577,'University Park','University Park, Iowa',20615,19);
INSERT INTO "django_geo_db_city" VALUES(16578,'Burlington','Burlington, Iowa',20616,19);
INSERT INTO "django_geo_db_city" VALUES(16579,'Argyle','Argyle, Iowa',20617,19);
INSERT INTO "django_geo_db_city" VALUES(16580,'Bonaparte','Bonaparte, Iowa',20618,19);
INSERT INTO "django_geo_db_city" VALUES(16581,'Crawfordsville','Crawfordsville, Iowa',20619,19);
INSERT INTO "django_geo_db_city" VALUES(16582,'Danville','Danville, Iowa',20620,19);
INSERT INTO "django_geo_db_city" VALUES(16583,'Denmark','Denmark, Iowa',20621,19);
INSERT INTO "django_geo_db_city" VALUES(16584,'Donnellson','Donnellson, Iowa',20622,19);
INSERT INTO "django_geo_db_city" VALUES(16585,'Farmington','Farmington, Iowa',20623,19);
INSERT INTO "django_geo_db_city" VALUES(16586,'Fort Madison','Fort Madison, Iowa',20624,19);
INSERT INTO "django_geo_db_city" VALUES(16587,'Hillsboro','Hillsboro, Iowa',20625,19);
INSERT INTO "django_geo_db_city" VALUES(16588,'Houghton','Houghton, Iowa',20626,19);
INSERT INTO "django_geo_db_city" VALUES(16589,'Keokuk','Keokuk, Iowa',20627,19);
INSERT INTO "django_geo_db_city" VALUES(16590,'Lockridge','Lockridge, Iowa',20628,19);
INSERT INTO "django_geo_db_city" VALUES(16591,'Mediapolis','Mediapolis, Iowa',20629,19);
INSERT INTO "django_geo_db_city" VALUES(16592,'Middletown','Middletown, Iowa',20630,19);
INSERT INTO "django_geo_db_city" VALUES(16593,'Montrose','Montrose, Iowa',20631,19);
INSERT INTO "django_geo_db_city" VALUES(16594,'Morning Sun','Morning Sun, Iowa',20632,19);
INSERT INTO "django_geo_db_city" VALUES(16595,'Mount Pleasant','Mount Pleasant, Iowa',20633,19);
INSERT INTO "django_geo_db_city" VALUES(16596,'Rome','Rome, Iowa',20634,19);
INSERT INTO "django_geo_db_city" VALUES(16597,'Mount Union','Mount Union, Iowa',20635,19);
INSERT INTO "django_geo_db_city" VALUES(16598,'New London','New London, Iowa',20636,19);
INSERT INTO "django_geo_db_city" VALUES(16599,'Oakville','Oakville, Iowa',20637,19);
INSERT INTO "django_geo_db_city" VALUES(16600,'Olds','Olds, Iowa',20638,19);
INSERT INTO "django_geo_db_city" VALUES(16601,'Pilot Grove','Pilot Grove, Iowa',20639,19);
INSERT INTO "django_geo_db_city" VALUES(16602,'Salem','Salem, Iowa',20640,19);
INSERT INTO "django_geo_db_city" VALUES(16603,'Sperry','Sperry, Iowa',20641,19);
INSERT INTO "django_geo_db_city" VALUES(16604,'Stockport','Stockport, Iowa',20642,19);
INSERT INTO "django_geo_db_city" VALUES(16605,'Swedesburg','Swedesburg, Iowa',20643,19);
INSERT INTO "django_geo_db_city" VALUES(16606,'Wapello','Wapello, Iowa',20644,19);
INSERT INTO "django_geo_db_city" VALUES(16607,'Wayland','Wayland, Iowa',20645,19);
INSERT INTO "django_geo_db_city" VALUES(16608,'West Burlington','West Burlington, Iowa',20646,19);
INSERT INTO "django_geo_db_city" VALUES(16609,'West Point','West Point, Iowa',20647,19);
INSERT INTO "django_geo_db_city" VALUES(16610,'Saint Paul','Saint Paul, Iowa',20648,19);
INSERT INTO "django_geo_db_city" VALUES(16611,'Wever','Wever, Iowa',20649,19);
INSERT INTO "django_geo_db_city" VALUES(16612,'Winfield','Winfield, Iowa',20650,19);
INSERT INTO "django_geo_db_city" VALUES(16613,'Yarmouth','Yarmouth, Iowa',20651,19);
INSERT INTO "django_geo_db_city" VALUES(16614,'Andover','Andover, Iowa',20652,19);
INSERT INTO "django_geo_db_city" VALUES(16615,'Blue Grass','Blue Grass, Iowa',20653,19);
INSERT INTO "django_geo_db_city" VALUES(16616,'Atalissa','Atalissa, Iowa',20654,19);
INSERT INTO "django_geo_db_city" VALUES(16617,'Bennett','Bennett, Iowa',20655,19);
INSERT INTO "django_geo_db_city" VALUES(16618,'Bettendorf','Bettendorf, Iowa',20656,19);
INSERT INTO "django_geo_db_city" VALUES(16619,'Bryant','Bryant, Iowa',20658,19);
INSERT INTO "django_geo_db_city" VALUES(16620,'Buffalo','Buffalo, Iowa',20659,19);
INSERT INTO "django_geo_db_city" VALUES(16621,'Calamus','Calamus, Iowa',20660,19);
INSERT INTO "django_geo_db_city" VALUES(16622,'Camanche','Camanche, Iowa',20661,19);
INSERT INTO "django_geo_db_city" VALUES(16623,'Charlotte','Charlotte, Iowa',20662,19);
INSERT INTO "django_geo_db_city" VALUES(16624,'Clinton','Clinton, Iowa',20663,19);
INSERT INTO "django_geo_db_city" VALUES(16625,'Columbus City','Columbus City, Iowa',20665,19);
INSERT INTO "django_geo_db_city" VALUES(16626,'Columbus Junction','Columbus Junction, Iowa',20666,19);
INSERT INTO "django_geo_db_city" VALUES(16627,'Conesville','Conesville, Iowa',20667,19);
INSERT INTO "django_geo_db_city" VALUES(16628,'De Witt','De Witt, Iowa',20668,19);
INSERT INTO "django_geo_db_city" VALUES(16629,'Dixon','Dixon, Iowa',20669,19);
INSERT INTO "django_geo_db_city" VALUES(16630,'Donahue','Donahue, Iowa',20670,19);
INSERT INTO "django_geo_db_city" VALUES(16631,'Durant','Durant, Iowa',20671,19);
INSERT INTO "django_geo_db_city" VALUES(16632,'Eldridge','Eldridge, Iowa',20672,19);
INSERT INTO "django_geo_db_city" VALUES(16633,'Fruitland','Fruitland, Iowa',20673,19);
INSERT INTO "django_geo_db_city" VALUES(16634,'Goose Lake','Goose Lake, Iowa',20674,19);
INSERT INTO "django_geo_db_city" VALUES(16635,'Grand Mound','Grand Mound, Iowa',20675,19);
INSERT INTO "django_geo_db_city" VALUES(16636,'Grandview','Grandview, Iowa',20676,19);
INSERT INTO "django_geo_db_city" VALUES(16637,'Le Claire','Le Claire, Iowa',20677,19);
INSERT INTO "django_geo_db_city" VALUES(16638,'Letts','Letts, Iowa',20678,19);
INSERT INTO "django_geo_db_city" VALUES(16639,'Lone Tree','Lone Tree, Iowa',20679,19);
INSERT INTO "django_geo_db_city" VALUES(16640,'Long Grove','Long Grove, Iowa',20680,19);
INSERT INTO "django_geo_db_city" VALUES(16641,'Low Moor','Low Moor, Iowa',20681,19);
INSERT INTO "django_geo_db_city" VALUES(16642,'McCausland','McCausland, Iowa',20682,19);
INSERT INTO "django_geo_db_city" VALUES(16643,'Montpelier','Montpelier, Iowa',20683,19);
INSERT INTO "django_geo_db_city" VALUES(16644,'Moscow','Moscow, Iowa',20684,19);
INSERT INTO "django_geo_db_city" VALUES(16645,'Muscatine','Muscatine, Illinois',20685,17);
INSERT INTO "django_geo_db_city" VALUES(16646,'New Liberty','New Liberty, Iowa',20686,19);
INSERT INTO "django_geo_db_city" VALUES(16647,'Nichols','Nichols, Iowa',20687,19);
INSERT INTO "django_geo_db_city" VALUES(16648,'Pleasant Valley','Pleasant Valley, Iowa',20688,19);
INSERT INTO "django_geo_db_city" VALUES(16649,'Princeton','Princeton, Iowa',20689,19);
INSERT INTO "django_geo_db_city" VALUES(16650,'Stockton','Stockton, Iowa',20690,19);
INSERT INTO "django_geo_db_city" VALUES(16651,'Teeds Grove','Teeds Grove, Iowa',20691,19);
INSERT INTO "django_geo_db_city" VALUES(16652,'Tipton','Tipton, Iowa',20692,19);
INSERT INTO "django_geo_db_city" VALUES(16653,'Walcott','Walcott, Iowa',20693,19);
INSERT INTO "django_geo_db_city" VALUES(16654,'Welton','Welton, Iowa',20694,19);
INSERT INTO "django_geo_db_city" VALUES(16655,'West Liberty','West Liberty, Iowa',20695,19);
INSERT INTO "django_geo_db_city" VALUES(16656,'Wheatland','Wheatland, Iowa',20696,19);
INSERT INTO "django_geo_db_city" VALUES(16657,'Wilton','Wilton, Iowa',20697,19);
INSERT INTO "django_geo_db_city" VALUES(16658,'Davenport','Davenport, Iowa',20698,19);
INSERT INTO "django_geo_db_city" VALUES(16659,'Tennyson','Tennyson, Wisconsin',20705,58);
INSERT INTO "django_geo_db_city" VALUES(16660,'Adell','Adell, Wisconsin',20706,58);
INSERT INTO "django_geo_db_city" VALUES(16661,'Allenton','Allenton, Wisconsin',20707,58);
INSERT INTO "django_geo_db_city" VALUES(16662,'Ashippun','Ashippun, Wisconsin',20708,58);
INSERT INTO "django_geo_db_city" VALUES(16663,'Belgium','Belgium, Wisconsin',20709,58);
INSERT INTO "django_geo_db_city" VALUES(16664,'Brookfield','Brookfield, Wisconsin',20710,58);
INSERT INTO "django_geo_db_city" VALUES(16665,'Brownsville','Brownsville, Wisconsin',20711,58);
INSERT INTO "django_geo_db_city" VALUES(16666,'Butler','Butler, Wisconsin',20712,58);
INSERT INTO "django_geo_db_city" VALUES(16667,'Byron','Byron, Wisconsin',20714,58);
INSERT INTO "django_geo_db_city" VALUES(16668,'Campbellsport','Campbellsport, Wisconsin',20715,58);
INSERT INTO "django_geo_db_city" VALUES(16669,'Cascade','Cascade, Wisconsin',20716,58);
INSERT INTO "django_geo_db_city" VALUES(16670,'Cedarburg','Cedarburg, Wisconsin',20717,58);
INSERT INTO "django_geo_db_city" VALUES(16671,'Cedar Grove','Cedar Grove, Wisconsin',20718,58);
INSERT INTO "django_geo_db_city" VALUES(16672,'Chilton','Chilton, Wisconsin',20719,58);
INSERT INTO "django_geo_db_city" VALUES(16673,'Cleveland','Cleveland, Wisconsin',20720,58);
INSERT INTO "django_geo_db_city" VALUES(16674,'Clyman','Clyman, Wisconsin',20721,58);
INSERT INTO "django_geo_db_city" VALUES(16675,'Colgate','Colgate, Wisconsin',20722,58);
INSERT INTO "django_geo_db_city" VALUES(16676,'Delafield','Delafield, Wisconsin',20723,58);
INSERT INTO "django_geo_db_city" VALUES(16677,'Eden','Eden, Wisconsin',20724,58);
INSERT INTO "django_geo_db_city" VALUES(16678,'Elkhart Lake','Elkhart Lake, Wisconsin',20725,58);
INSERT INTO "django_geo_db_city" VALUES(16679,'Fredonia','Fredonia, Wisconsin',20726,58);
INSERT INTO "django_geo_db_city" VALUES(16680,'Germantown','Germantown, Wisconsin',20727,58);
INSERT INTO "django_geo_db_city" VALUES(16681,'Glenbeulah','Glenbeulah, Wisconsin',20728,58);
INSERT INTO "django_geo_db_city" VALUES(16682,'Grafton','Grafton, Wisconsin',20729,58);
INSERT INTO "django_geo_db_city" VALUES(16683,'Greenbush','Greenbush, Wisconsin',20730,58);
INSERT INTO "django_geo_db_city" VALUES(16684,'Hartford','Hartford, Wisconsin',20731,58);
INSERT INTO "django_geo_db_city" VALUES(16685,'Hartland','Hartland, Wisconsin',20732,58);
INSERT INTO "django_geo_db_city" VALUES(16686,'Hingham','Hingham, Wisconsin',20733,58);
INSERT INTO "django_geo_db_city" VALUES(16687,'Horicon','Horicon, Wisconsin',20734,58);
INSERT INTO "django_geo_db_city" VALUES(16688,'Hubertus','Hubertus, Wisconsin',20735,58);
INSERT INTO "django_geo_db_city" VALUES(16689,'Hustisford','Hustisford, Wisconsin',20736,58);
INSERT INTO "django_geo_db_city" VALUES(16690,'Iron Ridge','Iron Ridge, Wisconsin',20737,58);
INSERT INTO "django_geo_db_city" VALUES(16691,'Ixonia','Ixonia, Wisconsin',20738,58);
INSERT INTO "django_geo_db_city" VALUES(16692,'Jackson','Jackson, Wisconsin',20739,58);
INSERT INTO "django_geo_db_city" VALUES(16693,'Johnson Creek','Johnson Creek, Wisconsin',20740,58);
INSERT INTO "django_geo_db_city" VALUES(16694,'Juneau','Juneau, Wisconsin',20741,58);
INSERT INTO "django_geo_db_city" VALUES(16695,'Kewaskum','Kewaskum, Wisconsin',20742,58);
INSERT INTO "django_geo_db_city" VALUES(16696,'Kiel','Kiel, Wisconsin',20743,58);
INSERT INTO "django_geo_db_city" VALUES(16697,'Kohler','Kohler, Wisconsin',20744,58);
INSERT INTO "django_geo_db_city" VALUES(16698,'Lannon','Lannon, Wisconsin',20746,58);
INSERT INTO "django_geo_db_city" VALUES(16699,'Lebanon','Lebanon, Wisconsin',20747,58);
INSERT INTO "django_geo_db_city" VALUES(16700,'Lomira','Lomira, Wisconsin',20748,58);
INSERT INTO "django_geo_db_city" VALUES(16701,'Malone','Malone, Wisconsin',20749,58);
INSERT INTO "django_geo_db_city" VALUES(16702,'Mayville','Mayville, Wisconsin',20750,58);
INSERT INTO "django_geo_db_city" VALUES(16703,'Menomonee Falls','Menomonee Falls, Wisconsin',20751,58);
INSERT INTO "django_geo_db_city" VALUES(16704,'Merton','Merton, Wisconsin',20752,58);
INSERT INTO "django_geo_db_city" VALUES(16705,'Mount Calvary','Mount Calvary, Wisconsin',20753,58);
INSERT INTO "django_geo_db_city" VALUES(16706,'Nashotah','Nashotah, Wisconsin',20754,58);
INSERT INTO "django_geo_db_city" VALUES(16707,'Neosho','Neosho, Wisconsin',20755,58);
INSERT INTO "django_geo_db_city" VALUES(16708,'Newburg','Newburg, Wisconsin',20756,58);
INSERT INTO "django_geo_db_city" VALUES(16709,'New Holstein','New Holstein, Wisconsin',20757,58);
INSERT INTO "django_geo_db_city" VALUES(16710,'Newton','Newton, Wisconsin',20759,58);
INSERT INTO "django_geo_db_city" VALUES(16711,'North Lake','North Lake, Wisconsin',20713,58);
INSERT INTO "django_geo_db_city" VALUES(16712,'Oakfield','Oakfield, Wisconsin',20760,58);
INSERT INTO "django_geo_db_city" VALUES(16713,'Oconomowoc','Oconomowoc, Wisconsin',20761,58);
INSERT INTO "django_geo_db_city" VALUES(16714,'Okauchee','Okauchee, Wisconsin',20762,58);
INSERT INTO "django_geo_db_city" VALUES(16715,'Oostburg','Oostburg, Wisconsin',20763,58);
INSERT INTO "django_geo_db_city" VALUES(16716,'Pewaukee','Pewaukee, Wisconsin',20764,58);
INSERT INTO "django_geo_db_city" VALUES(16717,'Plymouth','Plymouth, Wisconsin',20765,58);
INSERT INTO "django_geo_db_city" VALUES(16718,'Port Washington','Port Washington, Wisconsin',20766,58);
INSERT INTO "django_geo_db_city" VALUES(16719,'Random Lake','Random Lake, Wisconsin',20767,58);
INSERT INTO "django_geo_db_city" VALUES(16720,'Richfield','Richfield, Wisconsin',20768,58);
INSERT INTO "django_geo_db_city" VALUES(16721,'Rubicon','Rubicon, Wisconsin',20769,58);
INSERT INTO "django_geo_db_city" VALUES(16722,'Saint Cloud','Saint Cloud, Wisconsin',20770,58);
INSERT INTO "django_geo_db_city" VALUES(16723,'Saukville','Saukville, Wisconsin',20771,58);
INSERT INTO "django_geo_db_city" VALUES(16724,'Sheboygan','Sheboygan, Wisconsin',20772,58);
INSERT INTO "django_geo_db_city" VALUES(16725,'Sheboygan Falls','Sheboygan Falls, Wisconsin',20774,58);
INSERT INTO "django_geo_db_city" VALUES(16726,'Slinger','Slinger, Wisconsin',20775,58);
INSERT INTO "django_geo_db_city" VALUES(16727,'Stockbridge','Stockbridge, Wisconsin',20776,58);
INSERT INTO "django_geo_db_city" VALUES(16728,'Sussex','Sussex, Wisconsin',20777,58);
INSERT INTO "django_geo_db_city" VALUES(16729,'West Bend','West Bend, Wisconsin',20778,58);
INSERT INTO "django_geo_db_city" VALUES(16730,'Theresa','Theresa, Wisconsin',20779,58);
INSERT INTO "django_geo_db_city" VALUES(16731,'Thiensville','Thiensville, Wisconsin',20780,58);
INSERT INTO "django_geo_db_city" VALUES(16732,'Waldo','Waldo, Wisconsin',20781,58);
INSERT INTO "django_geo_db_city" VALUES(16733,'Watertown','Watertown, Wisconsin',20782,58);
INSERT INTO "django_geo_db_city" VALUES(16734,'Mequon','Mequon, Wisconsin',20784,58);
INSERT INTO "django_geo_db_city" VALUES(16735,'Woodland','Woodland, Wisconsin',20786,58);
INSERT INTO "django_geo_db_city" VALUES(16736,'Bassett','Bassett, Wisconsin',20787,58);
INSERT INTO "django_geo_db_city" VALUES(16737,'Benet Lake','Benet Lake, Wisconsin',20788,58);
INSERT INTO "django_geo_db_city" VALUES(16738,'Big Bend','Big Bend, Wisconsin',20789,58);
INSERT INTO "django_geo_db_city" VALUES(16739,'Bristol','Bristol, Wisconsin',20790,58);
INSERT INTO "django_geo_db_city" VALUES(16740,'Burlington','Burlington, Wisconsin',20791,58);
INSERT INTO "django_geo_db_city" VALUES(16741,'Caledonia','Caledonia, Wisconsin',20792,58);
INSERT INTO "django_geo_db_city" VALUES(16742,'Camp Lake','Camp Lake, Wisconsin',20793,58);
INSERT INTO "django_geo_db_city" VALUES(16743,'Cudahy','Cudahy, Wisconsin',20794,58);
INSERT INTO "django_geo_db_city" VALUES(16744,'Darien','Darien, Wisconsin',20795,58);
INSERT INTO "django_geo_db_city" VALUES(16745,'Delavan','Delavan, Wisconsin',20796,58);
INSERT INTO "django_geo_db_city" VALUES(16746,'Dousman','Dousman, Wisconsin',20797,58);
INSERT INTO "django_geo_db_city" VALUES(16747,'Eagle','Eagle, Wisconsin',20798,58);
INSERT INTO "django_geo_db_city" VALUES(16748,'East Troy','East Troy, Wisconsin',20799,58);
INSERT INTO "django_geo_db_city" VALUES(16749,'Elkhorn','Elkhorn, Wisconsin',20800,58);
INSERT INTO "django_geo_db_city" VALUES(16750,'Elm Grove','Elm Grove, Wisconsin',20801,58);
INSERT INTO "django_geo_db_city" VALUES(16751,'Fontana','Fontana, Wisconsin',20802,58);
INSERT INTO "django_geo_db_city" VALUES(16752,'Franksville','Franksville, Wisconsin',20803,58);
INSERT INTO "django_geo_db_city" VALUES(16753,'Genesee Depot','Genesee Depot, Wisconsin',20804,58);
INSERT INTO "django_geo_db_city" VALUES(16754,'Genoa City','Genoa City, Wisconsin',20805,58);
INSERT INTO "django_geo_db_city" VALUES(16755,'Greendale','Greendale, Wisconsin',20806,58);
INSERT INTO "django_geo_db_city" VALUES(16756,'Hales Corners','Hales Corners, Wisconsin',20807,58);
INSERT INTO "django_geo_db_city" VALUES(16757,'Franklin','Franklin, Wisconsin',20808,58);
INSERT INTO "django_geo_db_city" VALUES(16758,'Walworth','Walworth, Wisconsin',20809,58);
INSERT INTO "django_geo_db_city" VALUES(16759,'Helenville','Helenville, Wisconsin',20810,58);
INSERT INTO "django_geo_db_city" VALUES(16760,'Honey Creek','Honey Creek, Wisconsin',20811,58);
INSERT INTO "django_geo_db_city" VALUES(16761,'Kansasville','Kansasville, Wisconsin',20812,58);
INSERT INTO "django_geo_db_city" VALUES(16762,'Kenosha','Kenosha, Wisconsin',20813,58);
INSERT INTO "django_geo_db_city" VALUES(16763,'New Berlin','New Berlin, Wisconsin',20817,58);
INSERT INTO "django_geo_db_city" VALUES(16764,'Lake Geneva','Lake Geneva, Wisconsin',20818,58);
INSERT INTO "django_geo_db_city" VALUES(16765,'Lyons','Lyons, Wisconsin',20819,58);
INSERT INTO "django_geo_db_city" VALUES(16766,'Mukwonago','Mukwonago, Wisconsin',20820,58);
INSERT INTO "django_geo_db_city" VALUES(16767,'Muskego','Muskego, Wisconsin',20821,58);
INSERT INTO "django_geo_db_city" VALUES(16768,'New Munster','New Munster, Wisconsin',20823,58);
INSERT INTO "django_geo_db_city" VALUES(16769,'North Prairie','North Prairie, Wisconsin',20824,58);
INSERT INTO "django_geo_db_city" VALUES(16770,'Oak Creek','Oak Creek, Wisconsin',20825,58);
INSERT INTO "django_geo_db_city" VALUES(16771,'Palmyra','Palmyra, Wisconsin',20826,58);
INSERT INTO "django_geo_db_city" VALUES(16772,'Pell Lake','Pell Lake, Wisconsin',20827,58);
INSERT INTO "django_geo_db_city" VALUES(16773,'Pleasant Prairie','Pleasant Prairie, Wisconsin',20828,58);
INSERT INTO "django_geo_db_city" VALUES(16774,'Powers Lake','Powers Lake, Wisconsin',20829,58);
INSERT INTO "django_geo_db_city" VALUES(16775,'Rochester','Rochester, Wisconsin',20830,58);
INSERT INTO "django_geo_db_city" VALUES(16776,'Salem','Salem, Wisconsin',20831,58);
INSERT INTO "django_geo_db_city" VALUES(16777,'Silver Lake','Silver Lake, Wisconsin',20832,58);
INSERT INTO "django_geo_db_city" VALUES(16778,'Somers','Somers, Wisconsin',20833,58);
INSERT INTO "django_geo_db_city" VALUES(16779,'South Milwaukee','South Milwaukee, Wisconsin',20834,58);
INSERT INTO "django_geo_db_city" VALUES(16780,'Springfield','Springfield, Wisconsin',20835,58);
INSERT INTO "django_geo_db_city" VALUES(16781,'Sturtevant','Sturtevant, Wisconsin',20836,58);
INSERT INTO "django_geo_db_city" VALUES(16782,'Sullivan','Sullivan, Wisconsin',20837,58);
INSERT INTO "django_geo_db_city" VALUES(16783,'Trevor','Trevor, Wisconsin',20838,58);
INSERT INTO "django_geo_db_city" VALUES(16784,'Twin Lakes','Twin Lakes, Wisconsin',20839,58);
INSERT INTO "django_geo_db_city" VALUES(16785,'Union Grove','Union Grove, Wisconsin',20840,58);
INSERT INTO "django_geo_db_city" VALUES(16786,'Wales','Wales, Wisconsin',20841,58);
INSERT INTO "django_geo_db_city" VALUES(16787,'Waterford','Waterford, Wisconsin',20843,58);
INSERT INTO "django_geo_db_city" VALUES(16788,'Waukesha','Waukesha, Wisconsin',20844,58);
INSERT INTO "django_geo_db_city" VALUES(16789,'Whitewater','Whitewater, Wisconsin',20847,58);
INSERT INTO "django_geo_db_city" VALUES(16790,'Williams Bay','Williams Bay, Wisconsin',20848,58);
INSERT INTO "django_geo_db_city" VALUES(16791,'Wilmot','Wilmot, Wisconsin',20849,58);
INSERT INTO "django_geo_db_city" VALUES(16792,'Woodworth','Woodworth, Wisconsin',20787,58);
INSERT INTO "django_geo_db_city" VALUES(16793,'Zenda','Zenda, Wisconsin',20850,58);
INSERT INTO "django_geo_db_city" VALUES(16794,'Milwaukee','Milwaukee, Wisconsin',20852,58);
INSERT INTO "django_geo_db_city" VALUES(16795,'Saint Francis','Saint Francis, Wisconsin',20882,58);
INSERT INTO "django_geo_db_city" VALUES(16796,'Eaton','Eaton, Wisconsin',20883,58);
INSERT INTO "django_geo_db_city" VALUES(16797,'Racine','Racine, Wisconsin',20894,58);
INSERT INTO "django_geo_db_city" VALUES(16798,'Jefferson','Jefferson, Wisconsin',20901,58);
INSERT INTO "django_geo_db_city" VALUES(16799,'Afton','Afton, Wisconsin',20902,58);
INSERT INTO "django_geo_db_city" VALUES(16800,'Albany','Albany, Wisconsin',20903,58);
INSERT INTO "django_geo_db_city" VALUES(16801,'Arena','Arena, Wisconsin',20904,58);
INSERT INTO "django_geo_db_city" VALUES(16802,'Argyle','Argyle, Wisconsin',20905,58);
INSERT INTO "django_geo_db_city" VALUES(16803,'Avalon','Avalon, Wisconsin',20906,58);
INSERT INTO "django_geo_db_city" VALUES(16804,'Avoca','Avoca, Wisconsin',20907,58);
INSERT INTO "django_geo_db_city" VALUES(16805,'Barneveld','Barneveld, Wisconsin',20908,58);
INSERT INTO "django_geo_db_city" VALUES(16806,'Belleville','Belleville, Wisconsin',20909,58);
INSERT INTO "django_geo_db_city" VALUES(16807,'Belmont','Belmont, Wisconsin',20910,58);
INSERT INTO "django_geo_db_city" VALUES(16808,'Beloit','Beloit, Wisconsin',20911,58);
INSERT INTO "django_geo_db_city" VALUES(16809,'Black Earth','Black Earth, Wisconsin',20913,58);
INSERT INTO "django_geo_db_city" VALUES(16810,'Blanchardville','Blanchardville, Wisconsin',20914,58);
INSERT INTO "django_geo_db_city" VALUES(16811,'Blue Mounds','Blue Mounds, Wisconsin',20915,58);
INSERT INTO "django_geo_db_city" VALUES(16812,'Blue River','Blue River, Wisconsin',20916,58);
INSERT INTO "django_geo_db_city" VALUES(16813,'Brodhead','Brodhead, Wisconsin',20917,58);
INSERT INTO "django_geo_db_city" VALUES(16814,'Brooklyn','Brooklyn, Wisconsin',20918,58);
INSERT INTO "django_geo_db_city" VALUES(16815,'Browntown','Browntown, Wisconsin',20919,58);
INSERT INTO "django_geo_db_city" VALUES(16816,'Cambridge','Cambridge, Wisconsin',20920,58);
INSERT INTO "django_geo_db_city" VALUES(16817,'Clinton','Clinton, Wisconsin',20921,58);
INSERT INTO "django_geo_db_city" VALUES(16818,'Cobb','Cobb, Wisconsin',20922,58);
INSERT INTO "django_geo_db_city" VALUES(16819,'Cottage Grove','Cottage Grove, Wisconsin',20923,58);
INSERT INTO "django_geo_db_city" VALUES(16820,'Cross Plains','Cross Plains, Wisconsin',20924,58);
INSERT INTO "django_geo_db_city" VALUES(16821,'Dane','Dane, Wisconsin',20925,58);
INSERT INTO "django_geo_db_city" VALUES(16822,'Darlington','Darlington, Wisconsin',20926,58);
INSERT INTO "django_geo_db_city" VALUES(16823,'Deerfield','Deerfield, Wisconsin',20927,58);
INSERT INTO "django_geo_db_city" VALUES(16824,'De Forest','De Forest, Wisconsin',20928,58);
INSERT INTO "django_geo_db_city" VALUES(16825,'Dodgeville','Dodgeville, Wisconsin',20929,58);
INSERT INTO "django_geo_db_city" VALUES(16826,'Edgerton','Edgerton, Wisconsin',20930,58);
INSERT INTO "django_geo_db_city" VALUES(16827,'Edmund','Edmund, Wisconsin',20931,58);
INSERT INTO "django_geo_db_city" VALUES(16828,'Evansville','Evansville, Wisconsin',20932,58);
INSERT INTO "django_geo_db_city" VALUES(16829,'Footville','Footville, Wisconsin',20933,58);
INSERT INTO "django_geo_db_city" VALUES(16830,'Fort Atkinson','Fort Atkinson, Wisconsin',20934,58);
INSERT INTO "django_geo_db_city" VALUES(16831,'Gotham','Gotham, Wisconsin',20935,58);
INSERT INTO "django_geo_db_city" VALUES(16832,'Gratiot','Gratiot, Wisconsin',20936,58);
INSERT INTO "django_geo_db_city" VALUES(16833,'Hanover','Hanover, Wisconsin',20937,58);
INSERT INTO "django_geo_db_city" VALUES(16834,'Highland','Highland, Wisconsin',20938,58);
INSERT INTO "django_geo_db_city" VALUES(16835,'Hollandale','Hollandale, Wisconsin',20939,58);
INSERT INTO "django_geo_db_city" VALUES(16836,'Janesville','Janesville, Wisconsin',20940,58);
INSERT INTO "django_geo_db_city" VALUES(16837,'Juda','Juda, Wisconsin',20944,58);
INSERT INTO "django_geo_db_city" VALUES(16838,'Lake Mills','Lake Mills, Wisconsin',20945,58);
INSERT INTO "django_geo_db_city" VALUES(16839,'Linden','Linden, Wisconsin',20946,58);
INSERT INTO "django_geo_db_city" VALUES(16840,'Livingston','Livingston, Wisconsin',20947,58);
INSERT INTO "django_geo_db_city" VALUES(16841,'Lodi','Lodi, Wisconsin',20948,58);
INSERT INTO "django_geo_db_city" VALUES(16842,'Lone Rock','Lone Rock, Wisconsin',20949,58);
INSERT INTO "django_geo_db_city" VALUES(16843,'Lowell','Lowell, Wisconsin',20950,58);
INSERT INTO "django_geo_db_city" VALUES(16844,'McFarland','McFarland, Wisconsin',20951,58);
INSERT INTO "django_geo_db_city" VALUES(16845,'Marshall','Marshall, Wisconsin',20952,58);
INSERT INTO "django_geo_db_city" VALUES(16846,'Mazomanie','Mazomanie, Wisconsin',20953,58);
INSERT INTO "django_geo_db_city" VALUES(16847,'Merrimac','Merrimac, Wisconsin',20954,58);
INSERT INTO "django_geo_db_city" VALUES(16848,'Middleton','Middleton, Wisconsin',20955,58);
INSERT INTO "django_geo_db_city" VALUES(16849,'Milton','Milton, Wisconsin',20956,58);
INSERT INTO "django_geo_db_city" VALUES(16850,'Mineral Point','Mineral Point, Wisconsin',20957,58);
INSERT INTO "django_geo_db_city" VALUES(16851,'Monroe','Monroe, Wisconsin',20958,58);
INSERT INTO "django_geo_db_city" VALUES(16852,'Montfort','Montfort, Wisconsin',20959,58);
INSERT INTO "django_geo_db_city" VALUES(16853,'Monticello','Monticello, Wisconsin',20960,58);
INSERT INTO "django_geo_db_city" VALUES(16854,'Morrisonville','Morrisonville, Wisconsin',20961,58);
INSERT INTO "django_geo_db_city" VALUES(16855,'Mount Horeb','Mount Horeb, Wisconsin',20962,58);
INSERT INTO "django_geo_db_city" VALUES(16856,'Muscoda','Muscoda, Wisconsin',20963,58);
INSERT INTO "django_geo_db_city" VALUES(16857,'New Glarus','New Glarus, Wisconsin',20964,58);
INSERT INTO "django_geo_db_city" VALUES(16858,'Oregon','Oregon, Wisconsin',20965,58);
INSERT INTO "django_geo_db_city" VALUES(16859,'Orfordville','Orfordville, Wisconsin',20966,58);
INSERT INTO "django_geo_db_city" VALUES(16860,'Plain','Plain, Wisconsin',20967,58);
INSERT INTO "django_geo_db_city" VALUES(16861,'Prairie Du Sac','Prairie Du Sac, Wisconsin',20968,58);
INSERT INTO "django_geo_db_city" VALUES(16862,'Reeseville','Reeseville, Wisconsin',20969,58);
INSERT INTO "django_geo_db_city" VALUES(16863,'Rewey','Rewey, Wisconsin',20970,58);
INSERT INTO "django_geo_db_city" VALUES(16864,'Richland Center','Richland Center, Wisconsin',20971,58);
INSERT INTO "django_geo_db_city" VALUES(16865,'Ridgeway','Ridgeway, Wisconsin',20972,58);
INSERT INTO "django_geo_db_city" VALUES(16866,'Sauk City','Sauk City, Wisconsin',20973,58);
INSERT INTO "django_geo_db_city" VALUES(16867,'Sextonville','Sextonville, Wisconsin',20974,58);
INSERT INTO "django_geo_db_city" VALUES(16868,'Sharon','Sharon, Wisconsin',20975,58);
INSERT INTO "django_geo_db_city" VALUES(16869,'Shullsburg','Shullsburg, Wisconsin',20976,58);
INSERT INTO "django_geo_db_city" VALUES(16870,'South Wayne','South Wayne, Wisconsin',20977,58);
INSERT INTO "django_geo_db_city" VALUES(16871,'Spring Green','Spring Green, Wisconsin',20978,58);
INSERT INTO "django_geo_db_city" VALUES(16872,'Stoughton','Stoughton, Wisconsin',20979,58);
INSERT INTO "django_geo_db_city" VALUES(16873,'Sun Prairie','Sun Prairie, Wisconsin',20980,58);
INSERT INTO "django_geo_db_city" VALUES(16874,'Verona','Verona, Wisconsin',20982,58);
INSERT INTO "django_geo_db_city" VALUES(16875,'Waterloo','Waterloo, Wisconsin',20983,58);
INSERT INTO "django_geo_db_city" VALUES(16876,'Waunakee','Waunakee, Wisconsin',20986,58);
INSERT INTO "django_geo_db_city" VALUES(16877,'Windsor','Windsor, Wisconsin',20987,58);
INSERT INTO "django_geo_db_city" VALUES(16878,'Woodford','Woodford, Wisconsin',20988,58);
INSERT INTO "django_geo_db_city" VALUES(16879,'Union Center','Union Center, Wisconsin',20990,58);
INSERT INTO "django_geo_db_city" VALUES(16880,'Madison','Madison, Wisconsin',20981,58);
INSERT INTO "django_geo_db_city" VALUES(16881,'Bagley','Bagley, Wisconsin',21007,58);
INSERT INTO "django_geo_db_city" VALUES(16882,'Beetown','Beetown, Wisconsin',21008,58);
INSERT INTO "django_geo_db_city" VALUES(16883,'Benton','Benton, Wisconsin',21009,58);
INSERT INTO "django_geo_db_city" VALUES(16884,'Bloomington','Bloomington, Wisconsin',21010,58);
INSERT INTO "django_geo_db_city" VALUES(16885,'Boscobel','Boscobel, Wisconsin',21011,58);
INSERT INTO "django_geo_db_city" VALUES(16886,'Cassville','Cassville, Wisconsin',21012,58);
INSERT INTO "django_geo_db_city" VALUES(16887,'Cuba City','Cuba City, Wisconsin',21013,58);
INSERT INTO "django_geo_db_city" VALUES(16888,'Dickeyville','Dickeyville, Wisconsin',21014,58);
INSERT INTO "django_geo_db_city" VALUES(16889,'Fennimore','Fennimore, Wisconsin',21015,58);
INSERT INTO "django_geo_db_city" VALUES(16890,'Glen Haven','Glen Haven, Wisconsin',21016,58);
INSERT INTO "django_geo_db_city" VALUES(16891,'Hazel Green','Hazel Green, Wisconsin',21017,58);
INSERT INTO "django_geo_db_city" VALUES(16892,'Kieler','Kieler, Wisconsin',21018,58);
INSERT INTO "django_geo_db_city" VALUES(16893,'Lancaster','Lancaster, Wisconsin',21019,58);
INSERT INTO "django_geo_db_city" VALUES(16894,'Mount Hope','Mount Hope, Wisconsin',21020,58);
INSERT INTO "django_geo_db_city" VALUES(16895,'Patch Grove','Patch Grove, Wisconsin',21021,58);
INSERT INTO "django_geo_db_city" VALUES(16896,'Platteville','Platteville, Wisconsin',21022,58);
INSERT INTO "django_geo_db_city" VALUES(16897,'Potosi','Potosi, Wisconsin',21023,58);
INSERT INTO "django_geo_db_city" VALUES(16898,'Prairie Du Chien','Prairie Du Chien, Wisconsin',21024,58);
INSERT INTO "django_geo_db_city" VALUES(16899,'Sinsinawa','Sinsinawa, Wisconsin',21018,58);
INSERT INTO "django_geo_db_city" VALUES(16900,'Stitzer','Stitzer, Wisconsin',21025,58);
INSERT INTO "django_geo_db_city" VALUES(16901,'Wauzeka','Wauzeka, Wisconsin',21026,58);
INSERT INTO "django_geo_db_city" VALUES(16902,'Woodman','Woodman, Wisconsin',21027,58);
INSERT INTO "django_geo_db_city" VALUES(16903,'New Diggings','New Diggings, Wisconsin',21028,58);
INSERT INTO "django_geo_db_city" VALUES(16904,'Portage','Portage, Wisconsin',21029,58);
INSERT INTO "django_geo_db_city" VALUES(16905,'Adams','Adams, Wisconsin',21030,58);
INSERT INTO "django_geo_db_city" VALUES(16906,'Arlington','Arlington, Wisconsin',21031,58);
INSERT INTO "django_geo_db_city" VALUES(16907,'Baraboo','Baraboo, Wisconsin',21032,58);
INSERT INTO "django_geo_db_city" VALUES(16908,'Beaver Dam','Beaver Dam, Wisconsin',21033,58);
INSERT INTO "django_geo_db_city" VALUES(16909,'Brandon','Brandon, Wisconsin',21034,58);
INSERT INTO "django_geo_db_city" VALUES(16910,'Briggsville','Briggsville, Wisconsin',21035,58);
INSERT INTO "django_geo_db_city" VALUES(16911,'Burnett','Burnett, Wisconsin',21036,58);
INSERT INTO "django_geo_db_city" VALUES(16912,'Cambria','Cambria, Wisconsin',21037,58);
INSERT INTO "django_geo_db_city" VALUES(16913,'Cazenovia','Cazenovia, Wisconsin',21038,58);
INSERT INTO "django_geo_db_city" VALUES(16914,'Columbus','Columbus, Wisconsin',21039,58);
INSERT INTO "django_geo_db_city" VALUES(16915,'Dalton','Dalton, Wisconsin',21040,58);
INSERT INTO "django_geo_db_city" VALUES(16916,'Dellwood','Dellwood, Wisconsin',21041,58);
INSERT INTO "django_geo_db_city" VALUES(16917,'Doylestown','Doylestown, Wisconsin',21042,58);
INSERT INTO "django_geo_db_city" VALUES(16918,'Elroy','Elroy, Wisconsin',21043,58);
INSERT INTO "django_geo_db_city" VALUES(16919,'Endeavor','Endeavor, Wisconsin',21044,58);
INSERT INTO "django_geo_db_city" VALUES(16920,'Fairwater','Fairwater, Wisconsin',21045,58);
INSERT INTO "django_geo_db_city" VALUES(16921,'Fall River','Fall River, Wisconsin',21046,58);
INSERT INTO "django_geo_db_city" VALUES(16922,'Fox Lake','Fox Lake, Wisconsin',21047,58);
INSERT INTO "django_geo_db_city" VALUES(16923,'Friendship','Friendship, Wisconsin',21048,58);
INSERT INTO "django_geo_db_city" VALUES(16924,'Friesland','Friesland, Wisconsin',21049,58);
INSERT INTO "django_geo_db_city" VALUES(16925,'Grand Marsh','Grand Marsh, Wisconsin',21050,58);
INSERT INTO "django_geo_db_city" VALUES(16926,'Hillpoint','Hillpoint, Wisconsin',21051,58);
INSERT INTO "django_geo_db_city" VALUES(16927,'Kingston','Kingston, Wisconsin',21052,58);
INSERT INTO "django_geo_db_city" VALUES(16928,'Lake Delton','Lake Delton, Wisconsin',21053,58);
INSERT INTO "django_geo_db_city" VALUES(16929,'La Valle','La Valle, Wisconsin',21054,58);
INSERT INTO "django_geo_db_city" VALUES(16930,'Lime Ridge','Lime Ridge, Wisconsin',21055,58);
INSERT INTO "django_geo_db_city" VALUES(16931,'Loganville','Loganville, Wisconsin',21056,58);
INSERT INTO "django_geo_db_city" VALUES(16932,'Lyndon Station','Lyndon Station, Wisconsin',21057,58);
INSERT INTO "django_geo_db_city" VALUES(16933,'Markesan','Markesan, Wisconsin',21058,58);
INSERT INTO "django_geo_db_city" VALUES(16934,'Marquette','Marquette, Wisconsin',21059,58);
INSERT INTO "django_geo_db_city" VALUES(16935,'Mauston','Mauston, Wisconsin',21060,58);
INSERT INTO "django_geo_db_city" VALUES(16936,'Montello','Montello, Wisconsin',21061,58);
INSERT INTO "django_geo_db_city" VALUES(16937,'New Lisbon','New Lisbon, Wisconsin',21062,58);
INSERT INTO "django_geo_db_city" VALUES(16938,'North Freedom','North Freedom, Wisconsin',21063,58);
INSERT INTO "django_geo_db_city" VALUES(16939,'Oxford','Oxford, Wisconsin',21064,58);
INSERT INTO "django_geo_db_city" VALUES(16940,'Packwaukee','Packwaukee, Wisconsin',21065,58);
INSERT INTO "django_geo_db_city" VALUES(16941,'Pardeeville','Pardeeville, Wisconsin',21066,58);
INSERT INTO "django_geo_db_city" VALUES(16942,'Poynette','Poynette, Wisconsin',21067,58);
INSERT INTO "django_geo_db_city" VALUES(16943,'Randolph','Randolph, Wisconsin',21068,58);
INSERT INTO "django_geo_db_city" VALUES(16944,'Reedsburg','Reedsburg, Wisconsin',21070,58);
INSERT INTO "django_geo_db_city" VALUES(16945,'Rio','Rio, Wisconsin',21072,58);
INSERT INTO "django_geo_db_city" VALUES(16946,'Rock Springs','Rock Springs, Wisconsin',21073,58);
INSERT INTO "django_geo_db_city" VALUES(16947,'Waupun','Waupun, Wisconsin',21075,58);
INSERT INTO "django_geo_db_city" VALUES(16948,'Westfield','Westfield, Wisconsin',21076,58);
INSERT INTO "django_geo_db_city" VALUES(16949,'Wisconsin Dells','Wisconsin Dells, Wisconsin',21077,58);
INSERT INTO "django_geo_db_city" VALUES(16950,'Wonewoc','Wonewoc, Wisconsin',21078,58);
INSERT INTO "django_geo_db_city" VALUES(16951,'Wyocena','Wyocena, Wisconsin',21079,58);
INSERT INTO "django_geo_db_city" VALUES(16952,'Willow','Willow, Wisconsin',21080,58);
INSERT INTO "django_geo_db_city" VALUES(16953,'Amery','Amery, Wisconsin',21082,58);
INSERT INTO "django_geo_db_city" VALUES(16954,'Baldwin','Baldwin, Wisconsin',21083,58);
INSERT INTO "django_geo_db_city" VALUES(16955,'Beldenville','Beldenville, Wisconsin',21084,58);
INSERT INTO "django_geo_db_city" VALUES(16956,'Clayton','Clayton, Wisconsin',21085,58);
INSERT INTO "django_geo_db_city" VALUES(16957,'Clear Lake','Clear Lake, Wisconsin',21086,58);
INSERT INTO "django_geo_db_city" VALUES(16958,'Cushing','Cushing, Wisconsin',21087,58);
INSERT INTO "django_geo_db_city" VALUES(16959,'Deer Park','Deer Park, Wisconsin',21088,58);
INSERT INTO "django_geo_db_city" VALUES(16960,'Dresser','Dresser, Wisconsin',21089,58);
INSERT INTO "django_geo_db_city" VALUES(16961,'East Ellsworth','East Ellsworth, Wisconsin',21090,58);
INSERT INTO "django_geo_db_city" VALUES(16962,'Ellsworth','Ellsworth, Wisconsin',21091,58);
INSERT INTO "django_geo_db_city" VALUES(16963,'Emerald','Emerald, Wisconsin',21092,58);
INSERT INTO "django_geo_db_city" VALUES(16964,'Glenwood City','Glenwood City, Wisconsin',21093,58);
INSERT INTO "django_geo_db_city" VALUES(16965,'Hager City','Hager City, Wisconsin',21094,58);
INSERT INTO "django_geo_db_city" VALUES(16966,'Hammond','Hammond, Wisconsin',21095,58);
INSERT INTO "django_geo_db_city" VALUES(16967,'Hudson','Hudson, Wisconsin',21096,58);
INSERT INTO "django_geo_db_city" VALUES(16968,'New Richmond','New Richmond, Wisconsin',21097,58);
INSERT INTO "django_geo_db_city" VALUES(16969,'Osceola','Osceola, Wisconsin',21098,58);
INSERT INTO "django_geo_db_city" VALUES(16970,'Prescott','Prescott, Wisconsin',21099,58);
INSERT INTO "django_geo_db_city" VALUES(16971,'River Falls','River Falls, Wisconsin',21100,58);
INSERT INTO "django_geo_db_city" VALUES(16972,'Roberts','Roberts, Wisconsin',21101,58);
INSERT INTO "django_geo_db_city" VALUES(16973,'Saint Croix Falls','Saint Croix Falls, Wisconsin',21102,58);
INSERT INTO "django_geo_db_city" VALUES(16974,'Somerset','Somerset, Wisconsin',21103,58);
INSERT INTO "django_geo_db_city" VALUES(16975,'Star Prairie','Star Prairie, Wisconsin',21104,58);
INSERT INTO "django_geo_db_city" VALUES(16976,'Wilson','Wilson, Wisconsin',21105,58);
INSERT INTO "django_geo_db_city" VALUES(16977,'Woodville','Woodville, Wisconsin',21106,58);
INSERT INTO "django_geo_db_city" VALUES(16978,'Forest','Forest, Wisconsin',21107,58);
INSERT INTO "django_geo_db_city" VALUES(16979,'Fond du Lac','Fond du Lac, Wisconsin',21108,58);
INSERT INTO "django_geo_db_city" VALUES(16980,'Kickapoo','Kickapoo, Wisconsin',21109,58);
INSERT INTO "django_geo_db_city" VALUES(16981,'New London','New London, Wisconsin',21110,58);
INSERT INTO "django_geo_db_city" VALUES(16982,'Saint Joseph','Saint Joseph, Wisconsin',21111,58);
INSERT INTO "django_geo_db_city" VALUES(16983,'Abrams','Abrams, Wisconsin',21112,58);
INSERT INTO "django_geo_db_city" VALUES(16984,'Amberg','Amberg, Wisconsin',21113,58);
INSERT INTO "django_geo_db_city" VALUES(16985,'Armstrong Creek','Armstrong Creek, Wisconsin',21114,58);
INSERT INTO "django_geo_db_city" VALUES(16986,'Athelstane','Athelstane, Wisconsin',21115,58);
INSERT INTO "django_geo_db_city" VALUES(16987,'Black Creek','Black Creek, Wisconsin',21116,58);
INSERT INTO "django_geo_db_city" VALUES(16988,'Bonduel','Bonduel, Wisconsin',21117,58);
INSERT INTO "django_geo_db_city" VALUES(16989,'Brillion','Brillion, Wisconsin',21118,58);
INSERT INTO "django_geo_db_city" VALUES(16990,'Cecil','Cecil, Wisconsin',21119,58);
INSERT INTO "django_geo_db_city" VALUES(16991,'Coleman','Coleman, Wisconsin',21120,58);
INSERT INTO "django_geo_db_city" VALUES(16992,'Combined Locks','Combined Locks, Wisconsin',21121,58);
INSERT INTO "django_geo_db_city" VALUES(16993,'Crivitz','Crivitz, Wisconsin',21122,58);
INSERT INTO "django_geo_db_city" VALUES(16994,'De Pere','De Pere, Wisconsin',21123,58);
INSERT INTO "django_geo_db_city" VALUES(16995,'Dunbar','Dunbar, Wisconsin',21124,58);
INSERT INTO "django_geo_db_city" VALUES(16996,'Fence','Fence, Wisconsin',21125,58);
INSERT INTO "django_geo_db_city" VALUES(16997,'Florence','Florence, Wisconsin',21126,58);
INSERT INTO "django_geo_db_city" VALUES(16998,'Forest Junction','Forest Junction, Wisconsin',21127,58);
INSERT INTO "django_geo_db_city" VALUES(16999,'Gillett','Gillett, Wisconsin',21128,58);
INSERT INTO "django_geo_db_city" VALUES(17000,'Goodman','Goodman, Wisconsin',21129,58);
INSERT INTO "django_geo_db_city" VALUES(17001,'Greenleaf','Greenleaf, Wisconsin',21130,58);
INSERT INTO "django_geo_db_city" VALUES(17002,'Green Valley','Green Valley, Wisconsin',21131,58);
INSERT INTO "django_geo_db_city" VALUES(17003,'Gresham','Gresham, Wisconsin',21132,58);
INSERT INTO "django_geo_db_city" VALUES(17004,'Hilbert','Hilbert, Wisconsin',21133,58);
INSERT INTO "django_geo_db_city" VALUES(17005,'Kaukauna','Kaukauna, Wisconsin',21134,58);
INSERT INTO "django_geo_db_city" VALUES(17006,'Freedom','Freedom, Wisconsin',21135,58);
INSERT INTO "django_geo_db_city" VALUES(17007,'Keshena','Keshena, Wisconsin',21136,58);
INSERT INTO "django_geo_db_city" VALUES(17008,'Kimberly','Kimberly, Wisconsin',21137,58);
INSERT INTO "django_geo_db_city" VALUES(17009,'Krakow','Krakow, Wisconsin',21138,58);
INSERT INTO "django_geo_db_city" VALUES(17010,'Lakewood','Lakewood, Wisconsin',21139,58);
INSERT INTO "django_geo_db_city" VALUES(17011,'Lena','Lena, Wisconsin',21140,58);
INSERT INTO "django_geo_db_city" VALUES(17012,'Little Chute','Little Chute, Wisconsin',21141,58);
INSERT INTO "django_geo_db_city" VALUES(17013,'Little Suamico','Little Suamico, Wisconsin',21142,58);
INSERT INTO "django_geo_db_city" VALUES(17014,'Marinette','Marinette, Wisconsin',21143,58);
INSERT INTO "django_geo_db_city" VALUES(17015,'Mountain','Mountain, Wisconsin',21144,58);
INSERT INTO "django_geo_db_city" VALUES(17016,'Neopit','Neopit, Wisconsin',21145,58);
INSERT INTO "django_geo_db_city" VALUES(17017,'Niagara','Niagara, Wisconsin',21146,58);
INSERT INTO "django_geo_db_city" VALUES(17018,'Nichols','Nichols, Wisconsin',21147,58);
INSERT INTO "django_geo_db_city" VALUES(17019,'Oconto','Oconto, Wisconsin',21148,58);
INSERT INTO "django_geo_db_city" VALUES(17020,'Oconto Falls','Oconto Falls, Wisconsin',21149,58);
INSERT INTO "django_geo_db_city" VALUES(17021,'Oneida','Oneida, Wisconsin',21150,58);
INSERT INTO "django_geo_db_city" VALUES(17022,'Pembine','Pembine, Wisconsin',21151,58);
INSERT INTO "django_geo_db_city" VALUES(17023,'Peshtigo','Peshtigo, Wisconsin',21152,58);
INSERT INTO "django_geo_db_city" VALUES(17024,'Porterfield','Porterfield, Wisconsin',21153,58);
INSERT INTO "django_geo_db_city" VALUES(17025,'Potter','Potter, Wisconsin',21154,58);
INSERT INTO "django_geo_db_city" VALUES(17026,'Pound','Pound, Wisconsin',21155,58);
INSERT INTO "django_geo_db_city" VALUES(17027,'Pulaski','Pulaski, Wisconsin',21156,58);
INSERT INTO "django_geo_db_city" VALUES(17028,'Seymour','Seymour, Wisconsin',21157,58);
INSERT INTO "django_geo_db_city" VALUES(17029,'Shawano','Shawano, Wisconsin',21158,58);
INSERT INTO "django_geo_db_city" VALUES(17030,'Sherwood','Sherwood, Wisconsin',21159,58);
INSERT INTO "django_geo_db_city" VALUES(17031,'Shiocton','Shiocton, Wisconsin',21160,58);
INSERT INTO "django_geo_db_city" VALUES(17032,'Sobieski','Sobieski, Wisconsin',21161,58);
INSERT INTO "django_geo_db_city" VALUES(17033,'Suamico','Suamico, Wisconsin',21162,58);
INSERT INTO "django_geo_db_city" VALUES(17034,'Suring','Suring, Wisconsin',21163,58);
INSERT INTO "django_geo_db_city" VALUES(17035,'Townsend','Townsend, Wisconsin',21164,58);
INSERT INTO "django_geo_db_city" VALUES(17036,'Wausaukee','Wausaukee, Wisconsin',21165,58);
INSERT INTO "django_geo_db_city" VALUES(17037,'Wrightstown','Wrightstown, Wisconsin',21166,58);
INSERT INTO "django_geo_db_city" VALUES(17038,'Zachow','Zachow, Wisconsin',21167,58);
INSERT INTO "django_geo_db_city" VALUES(17039,'Algoma','Algoma, Wisconsin',21168,58);
INSERT INTO "django_geo_db_city" VALUES(17040,'Baileys Harbor','Baileys Harbor, Wisconsin',21169,58);
INSERT INTO "django_geo_db_city" VALUES(17041,'Branch','Branch, Wisconsin',21170,58);
INSERT INTO "django_geo_db_city" VALUES(17042,'Brussels','Brussels, Wisconsin',21171,58);
INSERT INTO "django_geo_db_city" VALUES(17043,'Casco','Casco, Wisconsin',21172,58);
INSERT INTO "django_geo_db_city" VALUES(17044,'Kossuth','Kossuth, Wisconsin',21173,58);
INSERT INTO "django_geo_db_city" VALUES(17045,'Collins','Collins, Wisconsin',21174,58);
INSERT INTO "django_geo_db_city" VALUES(17046,'Denmark','Denmark, Wisconsin',21175,58);
INSERT INTO "django_geo_db_city" VALUES(17047,'Egg Harbor','Egg Harbor, Wisconsin',21176,58);
INSERT INTO "django_geo_db_city" VALUES(17048,'Ellison Bay','Ellison Bay, Wisconsin',21177,58);
INSERT INTO "django_geo_db_city" VALUES(17049,'Ephraim','Ephraim, Wisconsin',21178,58);
INSERT INTO "django_geo_db_city" VALUES(17050,'Fish Creek','Fish Creek, Wisconsin',21179,58);
INSERT INTO "django_geo_db_city" VALUES(17051,'Forestville','Forestville, Wisconsin',21180,58);
INSERT INTO "django_geo_db_city" VALUES(17052,'Francis Creek','Francis Creek, Wisconsin',21181,58);
INSERT INTO "django_geo_db_city" VALUES(17053,'Kellnersville','Kellnersville, Wisconsin',21182,58);
INSERT INTO "django_geo_db_city" VALUES(17054,'Kewaunee','Kewaunee, Wisconsin',21183,58);
INSERT INTO "django_geo_db_city" VALUES(17055,'Luxemburg','Luxemburg, Wisconsin',21184,58);
INSERT INTO "django_geo_db_city" VALUES(17056,'Manitowoc','Manitowoc, Wisconsin',21185,58);
INSERT INTO "django_geo_db_city" VALUES(17057,'Maplewood','Maplewood, Wisconsin',21187,58);
INSERT INTO "django_geo_db_city" VALUES(17058,'Maribel','Maribel, Wisconsin',21188,58);
INSERT INTO "django_geo_db_city" VALUES(17059,'Mishicot','Mishicot, Wisconsin',21189,58);
INSERT INTO "django_geo_db_city" VALUES(17060,'New Franken','New Franken, Wisconsin',21190,58);
INSERT INTO "django_geo_db_city" VALUES(17061,'Reedsville','Reedsville, Wisconsin',21191,58);
INSERT INTO "django_geo_db_city" VALUES(17062,'Saint Nazianz','Saint Nazianz, Wisconsin',21192,58);
INSERT INTO "django_geo_db_city" VALUES(17063,'Sister Bay','Sister Bay, Wisconsin',21193,58);
INSERT INTO "django_geo_db_city" VALUES(17064,'Sturgeon Bay','Sturgeon Bay, Wisconsin',21194,58);
INSERT INTO "django_geo_db_city" VALUES(17065,'Tisch Mills','Tisch Mills, Wisconsin',21195,58);
INSERT INTO "django_geo_db_city" VALUES(17066,'Two Rivers','Two Rivers, Wisconsin',21196,58);
INSERT INTO "django_geo_db_city" VALUES(17067,'Ludington','Ludington, Wisconsin',21197,58);
INSERT INTO "django_geo_db_city" VALUES(17068,'Valders','Valders, Wisconsin',21198,58);
INSERT INTO "django_geo_db_city" VALUES(17069,'Washington Island','Washington Island, Wisconsin',21199,58);
INSERT INTO "django_geo_db_city" VALUES(17070,'Whitelaw','Whitelaw, Wisconsin',21200,58);
INSERT INTO "django_geo_db_city" VALUES(17071,'Green Bay','Green Bay, Wisconsin',21201,58);
INSERT INTO "django_geo_db_city" VALUES(17072,'Liberty Grove','Liberty Grove, Wisconsin',21207,58);
INSERT INTO "django_geo_db_city" VALUES(17073,'Bone Lake','Bone Lake, Wisconsin',21210,58);
INSERT INTO "django_geo_db_city" VALUES(17074,'Georgetown','Georgetown, Wisconsin',21212,58);
INSERT INTO "django_geo_db_city" VALUES(17075,'Wascott','Wascott, Wisconsin',21213,58);
INSERT INTO "django_geo_db_city" VALUES(17076,'Wausau','Wausau, Wisconsin',21214,58);
INSERT INTO "django_geo_db_city" VALUES(17077,'Marshfield','Marshfield, Wisconsin',21217,58);
INSERT INTO "django_geo_db_city" VALUES(17078,'Abbotsford','Abbotsford, Wisconsin',21218,58);
INSERT INTO "django_geo_db_city" VALUES(17079,'Amherst','Amherst, Wisconsin',21219,58);
INSERT INTO "django_geo_db_city" VALUES(17080,'Amherst Junction','Amherst Junction, Wisconsin',21220,58);
INSERT INTO "django_geo_db_city" VALUES(17081,'Aniwa','Aniwa, Wisconsin',21221,58);
INSERT INTO "django_geo_db_city" VALUES(17082,'Antigo','Antigo, Wisconsin',21222,58);
INSERT INTO "django_geo_db_city" VALUES(17083,'Arpin','Arpin, Wisconsin',21223,58);
INSERT INTO "django_geo_db_city" VALUES(17084,'Athens','Athens, Wisconsin',21224,58);
INSERT INTO "django_geo_db_city" VALUES(17085,'Auburndale','Auburndale, Wisconsin',21225,58);
INSERT INTO "django_geo_db_city" VALUES(17086,'Babcock','Babcock, Wisconsin',21226,58);
INSERT INTO "django_geo_db_city" VALUES(17087,'Birnamwood','Birnamwood, Wisconsin',21227,58);
INSERT INTO "django_geo_db_city" VALUES(17088,'Blenker','Blenker, Wisconsin',21228,58);
INSERT INTO "django_geo_db_city" VALUES(17089,'Bowler','Bowler, Wisconsin',21229,58);
INSERT INTO "django_geo_db_city" VALUES(17090,'Brokaw','Brokaw, Wisconsin',21230,58);
INSERT INTO "django_geo_db_city" VALUES(17091,'Bryant','Bryant, Wisconsin',21231,58);
INSERT INTO "django_geo_db_city" VALUES(17092,'Chelsea','Chelsea, Wisconsin',21232,58);
INSERT INTO "django_geo_db_city" VALUES(17093,'Chili','Chili, Wisconsin',21233,58);
INSERT INTO "django_geo_db_city" VALUES(17094,'Colby','Colby, Wisconsin',21234,58);
INSERT INTO "django_geo_db_city" VALUES(17095,'Curtiss','Curtiss, Wisconsin',21235,58);
INSERT INTO "django_geo_db_city" VALUES(17096,'Custer','Custer, Wisconsin',21236,58);
INSERT INTO "django_geo_db_city" VALUES(17097,'Deerbrook','Deerbrook, Wisconsin',21237,58);
INSERT INTO "django_geo_db_city" VALUES(17098,'Dorchester','Dorchester, Wisconsin',21238,58);
INSERT INTO "django_geo_db_city" VALUES(17099,'Edgar','Edgar, Wisconsin',21239,58);
INSERT INTO "django_geo_db_city" VALUES(17100,'Eland','Eland, Wisconsin',21240,58);
INSERT INTO "django_geo_db_city" VALUES(17101,'Elcho','Elcho, Wisconsin',21241,58);
INSERT INTO "django_geo_db_city" VALUES(17102,'Elderon','Elderon, Wisconsin',21242,58);
INSERT INTO "django_geo_db_city" VALUES(17103,'Elton','Elton, Wisconsin',21243,58);
INSERT INTO "django_geo_db_city" VALUES(17104,'Little Black','Little Black, Wisconsin',21244,58);
INSERT INTO "django_geo_db_city" VALUES(17105,'Galloway','Galloway, Wisconsin',21215,58);
INSERT INTO "django_geo_db_city" VALUES(17106,'Gilman','Gilman, Wisconsin',21245,58);
INSERT INTO "django_geo_db_city" VALUES(17107,'Jump River','Jump River, Wisconsin',21246,58);
INSERT INTO "django_geo_db_city" VALUES(17108,'Gleason','Gleason, Wisconsin',21247,58);
INSERT INTO "django_geo_db_city" VALUES(17109,'Granton','Granton, Wisconsin',21248,58);
INSERT INTO "django_geo_db_city" VALUES(17110,'Greenwood','Greenwood, Wisconsin',21249,58);
INSERT INTO "django_geo_db_city" VALUES(17111,'Hannibal','Hannibal, Wisconsin',21246,58);
INSERT INTO "django_geo_db_city" VALUES(17112,'Hatley','Hatley, Wisconsin',21250,58);
INSERT INTO "django_geo_db_city" VALUES(17113,'Hewitt','Hewitt, Wisconsin',21251,58);
INSERT INTO "django_geo_db_city" VALUES(17114,'Irma','Irma, Wisconsin',21252,58);
INSERT INTO "django_geo_db_city" VALUES(17115,'Junction City','Junction City, Wisconsin',21253,58);
INSERT INTO "django_geo_db_city" VALUES(17116,'Kempster','Kempster, Wisconsin',21254,58);
INSERT INTO "django_geo_db_city" VALUES(17117,'Loyal','Loyal, Wisconsin',21255,58);
INSERT INTO "django_geo_db_city" VALUES(17118,'Lublin','Lublin, Wisconsin',21256,58);
INSERT INTO "django_geo_db_city" VALUES(17119,'Marathon','Marathon, Wisconsin',21257,58);
INSERT INTO "django_geo_db_city" VALUES(17120,'Mattoon','Mattoon, Wisconsin',21259,58);
INSERT INTO "django_geo_db_city" VALUES(17121,'Medford','Medford, Wisconsin',21260,58);
INSERT INTO "django_geo_db_city" VALUES(17122,'Merrill','Merrill, Wisconsin',21261,58);
INSERT INTO "django_geo_db_city" VALUES(17123,'Milladore','Milladore, Wisconsin',21262,58);
INSERT INTO "django_geo_db_city" VALUES(17124,'Mosinee','Mosinee, Wisconsin',21263,58);
INSERT INTO "django_geo_db_city" VALUES(17125,'Neillsville','Neillsville, Wisconsin',21264,58);
INSERT INTO "django_geo_db_city" VALUES(17126,'Nekoosa','Nekoosa, Wisconsin',21265,58);
INSERT INTO "django_geo_db_city" VALUES(17127,'Nelsonville','Nelsonville, Wisconsin',21266,58);
INSERT INTO "django_geo_db_city" VALUES(17128,'Ogema','Ogema, Wisconsin',21267,58);
INSERT INTO "django_geo_db_city" VALUES(17129,'Owen','Owen, Wisconsin',21268,58);
INSERT INTO "django_geo_db_city" VALUES(17130,'Pearson','Pearson, Wisconsin',21269,58);
INSERT INTO "django_geo_db_city" VALUES(17131,'Pelican Lake','Pelican Lake, Wisconsin',21270,58);
INSERT INTO "django_geo_db_city" VALUES(17132,'Phlox','Phlox, Wisconsin',21254,58);
INSERT INTO "django_geo_db_city" VALUES(17133,'Pickerel','Pickerel, Wisconsin',21271,58);
INSERT INTO "django_geo_db_city" VALUES(17134,'Pittsville','Pittsville, Wisconsin',21272,58);
INSERT INTO "django_geo_db_city" VALUES(17135,'Plover','Plover, Wisconsin',21273,58);
INSERT INTO "django_geo_db_city" VALUES(17136,'Port Edwards','Port Edwards, Wisconsin',21274,58);
INSERT INTO "django_geo_db_city" VALUES(17137,'Rib Lake','Rib Lake, Wisconsin',21275,58);
INSERT INTO "django_geo_db_city" VALUES(17138,'Ringle','Ringle, Wisconsin',21276,58);
INSERT INTO "django_geo_db_city" VALUES(17139,'Rosholt','Rosholt, Wisconsin',21277,58);
INSERT INTO "django_geo_db_city" VALUES(17140,'Rothschild','Rothschild, Wisconsin',21278,58);
INSERT INTO "django_geo_db_city" VALUES(17141,'Rudolph','Rudolph, Wisconsin',21279,58);
INSERT INTO "django_geo_db_city" VALUES(17142,'Schofield','Schofield, Wisconsin',21280,58);
INSERT INTO "django_geo_db_city" VALUES(17143,'Spencer','Spencer, Wisconsin',21281,58);
INSERT INTO "django_geo_db_city" VALUES(17144,'Stetsonville','Stetsonville, Wisconsin',21282,58);
INSERT INTO "django_geo_db_city" VALUES(17145,'Stevens Point','Stevens Point, Wisconsin',21283,58);
INSERT INTO "django_geo_db_city" VALUES(17146,'Stratford','Stratford, Wisconsin',21284,58);
INSERT INTO "django_geo_db_city" VALUES(17147,'Summit Lake','Summit Lake, Wisconsin',21285,58);
INSERT INTO "django_geo_db_city" VALUES(17148,'Tigerton','Tigerton, Wisconsin',21286,58);
INSERT INTO "django_geo_db_city" VALUES(17149,'Tomahawk','Tomahawk, Wisconsin',21287,58);
INSERT INTO "django_geo_db_city" VALUES(17150,'Unity','Unity, Wisconsin',21288,58);
INSERT INTO "django_geo_db_city" VALUES(17151,'Vesper','Vesper, Wisconsin',21289,58);
INSERT INTO "django_geo_db_city" VALUES(17152,'Westboro','Westboro, Wisconsin',21290,58);
INSERT INTO "django_geo_db_city" VALUES(17153,'White Lake','White Lake, Wisconsin',21291,58);
INSERT INTO "django_geo_db_city" VALUES(17154,'Willard','Willard, Wisconsin',21293,58);
INSERT INTO "django_geo_db_city" VALUES(17155,'Wisconsin Rapids','Wisconsin Rapids, Wisconsin',21294,58);
INSERT INTO "django_geo_db_city" VALUES(17156,'Withee','Withee, Wisconsin',21296,58);
INSERT INTO "django_geo_db_city" VALUES(17157,'Wittenberg','Wittenberg, Wisconsin',21297,58);
INSERT INTO "django_geo_db_city" VALUES(17158,'Rhinelander','Rhinelander, Wisconsin',21298,58);
INSERT INTO "django_geo_db_city" VALUES(17159,'Argonne','Argonne, Wisconsin',21299,58);
INSERT INTO "django_geo_db_city" VALUES(17160,'Boulder Junction','Boulder Junction, Wisconsin',21300,58);
INSERT INTO "django_geo_db_city" VALUES(17161,'Brantwood','Brantwood, Wisconsin',21301,58);
INSERT INTO "django_geo_db_city" VALUES(17162,'Butternut','Butternut, Wisconsin',21302,58);
INSERT INTO "django_geo_db_city" VALUES(17163,'Catawba','Catawba, Wisconsin',21303,58);
INSERT INTO "django_geo_db_city" VALUES(17164,'Clam Lake','Clam Lake, Wisconsin',21304,58);
INSERT INTO "django_geo_db_city" VALUES(17165,'Conover','Conover, Wisconsin',21305,58);
INSERT INTO "django_geo_db_city" VALUES(17166,'Crandon','Crandon, Wisconsin',21306,58);
INSERT INTO "django_geo_db_city" VALUES(17167,'Eagle River','Eagle River, Wisconsin',21307,58);
INSERT INTO "django_geo_db_city" VALUES(17168,'Fifield','Fifield, Wisconsin',21308,58);
INSERT INTO "django_geo_db_city" VALUES(17169,'Gile','Gile, Wisconsin',21309,58);
INSERT INTO "django_geo_db_city" VALUES(17170,'Glen Flora','Glen Flora, Wisconsin',21310,58);
INSERT INTO "django_geo_db_city" VALUES(17171,'Glidden','Glidden, Wisconsin',21311,58);
INSERT INTO "django_geo_db_city" VALUES(17172,'Harshaw','Harshaw, Wisconsin',21312,58);
INSERT INTO "django_geo_db_city" VALUES(17173,'Hawkins','Hawkins, Wisconsin',21313,58);
INSERT INTO "django_geo_db_city" VALUES(17174,'Hazelhurst','Hazelhurst, Wisconsin',21314,58);
INSERT INTO "django_geo_db_city" VALUES(17175,'Heafford Junction','Heafford Junction, Wisconsin',21315,58);
INSERT INTO "django_geo_db_city" VALUES(17176,'Hurley','Hurley, Wisconsin',21316,58);
INSERT INTO "django_geo_db_city" VALUES(17177,'Iron Belt','Iron Belt, Wisconsin',21317,58);
INSERT INTO "django_geo_db_city" VALUES(17178,'Kennan','Kennan, Wisconsin',21318,58);
INSERT INTO "django_geo_db_city" VALUES(17179,'Lac Du Flambeau','Lac Du Flambeau, Wisconsin',21319,58);
INSERT INTO "django_geo_db_city" VALUES(17180,'Lake Tomahawk','Lake Tomahawk, Wisconsin',21320,58);
INSERT INTO "django_geo_db_city" VALUES(17181,'Land O Lakes','Land O Lakes, Wisconsin',21321,58);
INSERT INTO "django_geo_db_city" VALUES(17182,'Laona','Laona, Wisconsin',21322,58);
INSERT INTO "django_geo_db_city" VALUES(17183,'Long Lake','Long Lake, Wisconsin',21323,58);
INSERT INTO "django_geo_db_city" VALUES(17184,'McNaughton','McNaughton, Wisconsin',21324,58);
INSERT INTO "django_geo_db_city" VALUES(17185,'Manitowish Waters','Manitowish Waters, Wisconsin',21325,58);
INSERT INTO "django_geo_db_city" VALUES(17186,'Mellen','Mellen, Wisconsin',21326,58);
INSERT INTO "django_geo_db_city" VALUES(17187,'Mercer','Mercer, Wisconsin',21327,58);
INSERT INTO "django_geo_db_city" VALUES(17188,'Minocqua','Minocqua, Wisconsin',21328,58);
INSERT INTO "django_geo_db_city" VALUES(17189,'Montreal','Montreal, Wisconsin',21329,58);
INSERT INTO "django_geo_db_city" VALUES(17190,'Presque Isle','Presque Isle, Wisconsin',21330,58);
INSERT INTO "django_geo_db_city" VALUES(17191,'Park Falls','Park Falls, Wisconsin',21331,58);
INSERT INTO "django_geo_db_city" VALUES(17192,'Phelps','Phelps, Wisconsin',21332,58);
INSERT INTO "django_geo_db_city" VALUES(17193,'Phillips','Phillips, Wisconsin',21333,58);
INSERT INTO "django_geo_db_city" VALUES(17194,'Prentice','Prentice, Wisconsin',21334,58);
INSERT INTO "django_geo_db_city" VALUES(17195,'Saint Germain','Saint Germain, Wisconsin',21336,58);
INSERT INTO "django_geo_db_city" VALUES(17196,'Saxon','Saxon, Wisconsin',21337,58);
INSERT INTO "django_geo_db_city" VALUES(17197,'Sayner','Sayner, Wisconsin',21338,58);
INSERT INTO "django_geo_db_city" VALUES(17198,'Star Lake','Star Lake, Wisconsin',21339,58);
INSERT INTO "django_geo_db_city" VALUES(17199,'Three Lakes','Three Lakes, Wisconsin',21340,58);
INSERT INTO "django_geo_db_city" VALUES(17200,'Tony','Tony, Wisconsin',21341,58);
INSERT INTO "django_geo_db_city" VALUES(17201,'Tripoli','Tripoli, Wisconsin',21342,58);
INSERT INTO "django_geo_db_city" VALUES(17202,'Upson','Upson, Wisconsin',21343,58);
INSERT INTO "django_geo_db_city" VALUES(17203,'Wabeno','Wabeno, Wisconsin',21344,58);
INSERT INTO "django_geo_db_city" VALUES(17204,'Woodruff','Woodruff, Wisconsin',21345,58);
INSERT INTO "django_geo_db_city" VALUES(17205,'La Crosse','La Crosse, Wisconsin',21346,58);
INSERT INTO "django_geo_db_city" VALUES(17206,'Alma','Alma, Wisconsin',21349,58);
INSERT INTO "django_geo_db_city" VALUES(17207,'Alma Center','Alma Center, Wisconsin',21350,58);
INSERT INTO "django_geo_db_city" VALUES(17208,'Arcadia','Arcadia, Wisconsin',21351,58);
INSERT INTO "django_geo_db_city" VALUES(17209,'Arkdale','Arkdale, Wisconsin',21352,58);
INSERT INTO "django_geo_db_city" VALUES(17210,'Bangor','Bangor, Wisconsin',21353,58);
INSERT INTO "django_geo_db_city" VALUES(17211,'Black River Falls','Black River Falls, Wisconsin',21354,58);
INSERT INTO "django_geo_db_city" VALUES(17212,'Blair','Blair, Wisconsin',21355,58);
INSERT INTO "django_geo_db_city" VALUES(17213,'Camp Douglas','Camp Douglas, Wisconsin',21356,58);
INSERT INTO "django_geo_db_city" VALUES(17214,'Cashton','Cashton, Wisconsin',21357,58);
INSERT INTO "django_geo_db_city" VALUES(17215,'Cataract','Cataract, Wisconsin',21358,58);
INSERT INTO "django_geo_db_city" VALUES(17216,'Chaseburg','Chaseburg, Wisconsin',21359,58);
INSERT INTO "django_geo_db_city" VALUES(17217,'Cochrane','Cochrane, Wisconsin',21360,58);
INSERT INTO "django_geo_db_city" VALUES(17218,'Coon Valley','Coon Valley, Wisconsin',21361,58);
INSERT INTO "django_geo_db_city" VALUES(17219,'De Soto','De Soto, Wisconsin',21362,58);
INSERT INTO "django_geo_db_city" VALUES(17220,'Dodge','Dodge, Wisconsin',21363,58);
INSERT INTO "django_geo_db_city" VALUES(17221,'Eastman','Eastman, Wisconsin',21364,58);
INSERT INTO "django_geo_db_city" VALUES(17222,'Ettrick','Ettrick, Wisconsin',21365,58);
INSERT INTO "django_geo_db_city" VALUES(17223,'Ferryville','Ferryville, Wisconsin',21366,58);
INSERT INTO "django_geo_db_city" VALUES(17224,'Fountain City','Fountain City, Wisconsin',21367,58);
INSERT INTO "django_geo_db_city" VALUES(17225,'Galesville','Galesville, Wisconsin',21368,58);
INSERT INTO "django_geo_db_city" VALUES(17226,'Gays Mills','Gays Mills, Wisconsin',21369,58);
INSERT INTO "django_geo_db_city" VALUES(17227,'Genoa','Genoa, Wisconsin',21370,58);
INSERT INTO "django_geo_db_city" VALUES(17228,'Hillsboro','Hillsboro, Wisconsin',21371,58);
INSERT INTO "django_geo_db_city" VALUES(17229,'Hixton','Hixton, Wisconsin',21372,58);
INSERT INTO "django_geo_db_city" VALUES(17230,'Holmen','Holmen, Wisconsin',21373,58);
INSERT INTO "django_geo_db_city" VALUES(17231,'Hustler','Hustler, Wisconsin',21374,58);
INSERT INTO "django_geo_db_city" VALUES(17232,'Kendall','Kendall, Wisconsin',21375,58);
INSERT INTO "django_geo_db_city" VALUES(17233,'La Farge','La Farge, Wisconsin',21376,58);
INSERT INTO "django_geo_db_city" VALUES(17234,'Lynxville','Lynxville, Wisconsin',21377,58);
INSERT INTO "django_geo_db_city" VALUES(17235,'Mather','Mather, Wisconsin',21378,58);
INSERT INTO "django_geo_db_city" VALUES(17236,'Melrose','Melrose, Wisconsin',21379,58);
INSERT INTO "django_geo_db_city" VALUES(17237,'Millston','Millston, Wisconsin',21380,58);
INSERT INTO "django_geo_db_city" VALUES(17238,'Mindoro','Mindoro, Wisconsin',21381,58);
INSERT INTO "django_geo_db_city" VALUES(17239,'Mount Sterling','Mount Sterling, Wisconsin',21382,58);
INSERT INTO "django_geo_db_city" VALUES(17240,'Necedah','Necedah, Wisconsin',21383,58);
INSERT INTO "django_geo_db_city" VALUES(17241,'Norwalk','Norwalk, Wisconsin',21384,58);
INSERT INTO "django_geo_db_city" VALUES(17242,'Oakdale','Oakdale, Wisconsin',21385,58);
INSERT INTO "django_geo_db_city" VALUES(17243,'Onalaska','Onalaska, Wisconsin',21386,58);
INSERT INTO "django_geo_db_city" VALUES(17244,'Ontario','Ontario, Wisconsin',21387,58);
INSERT INTO "django_geo_db_city" VALUES(17245,'Readstown','Readstown, Wisconsin',21388,58);
INSERT INTO "django_geo_db_city" VALUES(17246,'Rockland','Rockland, Wisconsin',21389,58);
INSERT INTO "django_geo_db_city" VALUES(17247,'Seneca','Seneca, Wisconsin',21390,58);
INSERT INTO "django_geo_db_city" VALUES(17248,'Soldiers Grove','Soldiers Grove, Wisconsin',21391,58);
INSERT INTO "django_geo_db_city" VALUES(17249,'Sparta','Sparta, Wisconsin',21392,58);
INSERT INTO "django_geo_db_city" VALUES(17250,'Steuben','Steuben, Wisconsin',21393,58);
INSERT INTO "django_geo_db_city" VALUES(17251,'Stoddard','Stoddard, Wisconsin',21394,58);
INSERT INTO "django_geo_db_city" VALUES(17252,'Taylor','Taylor, Wisconsin',21395,58);
INSERT INTO "django_geo_db_city" VALUES(17253,'Tomah','Tomah, Wisconsin',21396,58);
INSERT INTO "django_geo_db_city" VALUES(17254,'Trempealeau','Trempealeau, Wisconsin',21397,58);
INSERT INTO "django_geo_db_city" VALUES(17255,'Tunnel City','Tunnel City, Wisconsin',21398,58);
INSERT INTO "django_geo_db_city" VALUES(17256,'Viola','Viola, Wisconsin',21399,58);
INSERT INTO "django_geo_db_city" VALUES(17257,'Viroqua','Viroqua, Wisconsin',21400,58);
INSERT INTO "django_geo_db_city" VALUES(17258,'Warrens','Warrens, Wisconsin',21401,58);
INSERT INTO "django_geo_db_city" VALUES(17259,'Westby','Westby, Wisconsin',21402,58);
INSERT INTO "django_geo_db_city" VALUES(17260,'West Salem','West Salem, Wisconsin',21403,58);
INSERT INTO "django_geo_db_city" VALUES(17261,'Wilton','Wilton, Wisconsin',21404,58);
INSERT INTO "django_geo_db_city" VALUES(17262,'Eau Claire','Eau Claire, Wisconsin',21406,58);
INSERT INTO "django_geo_db_city" VALUES(17263,'Altoona','Altoona, Wisconsin',21409,58);
INSERT INTO "django_geo_db_city" VALUES(17264,'Arkansaw','Arkansaw, Wisconsin',21410,58);
INSERT INTO "django_geo_db_city" VALUES(17265,'Augusta','Augusta, Wisconsin',21411,58);
INSERT INTO "django_geo_db_city" VALUES(17266,'Bay City','Bay City, Wisconsin',21412,58);
INSERT INTO "django_geo_db_city" VALUES(17267,'Bloomer','Bloomer, Wisconsin',21413,58);
INSERT INTO "django_geo_db_city" VALUES(17268,'Boyceville','Boyceville, Wisconsin',21414,58);
INSERT INTO "django_geo_db_city" VALUES(17269,'Boyd','Boyd, Wisconsin',21415,58);
INSERT INTO "django_geo_db_city" VALUES(17270,'Cadott','Cadott, Wisconsin',21416,58);
INSERT INTO "django_geo_db_city" VALUES(17271,'Chetek','Chetek, Wisconsin',21417,58);
INSERT INTO "django_geo_db_city" VALUES(17272,'Chippewa Falls','Chippewa Falls, Wisconsin',21418,58);
INSERT INTO "django_geo_db_city" VALUES(17273,'Colfax','Colfax, Wisconsin',21419,58);
INSERT INTO "django_geo_db_city" VALUES(17274,'Conrath','Conrath, Wisconsin',21420,58);
INSERT INTO "django_geo_db_city" VALUES(17275,'Cornell','Cornell, Wisconsin',21421,58);
INSERT INTO "django_geo_db_city" VALUES(17276,'Dallas','Dallas, Wisconsin',21422,58);
INSERT INTO "django_geo_db_city" VALUES(17277,'Downing','Downing, Wisconsin',21423,58);
INSERT INTO "django_geo_db_city" VALUES(17278,'Downsville','Downsville, Wisconsin',21424,58);
INSERT INTO "django_geo_db_city" VALUES(17279,'Durand','Durand, Wisconsin',21425,58);
INSERT INTO "django_geo_db_city" VALUES(17280,'Eau Galle','Eau Galle, Wisconsin',21426,58);
INSERT INTO "django_geo_db_city" VALUES(17281,'Eleva','Eleva, Wisconsin',21427,58);
INSERT INTO "django_geo_db_city" VALUES(17282,'Elk Mound','Elk Mound, Wisconsin',21428,58);
INSERT INTO "django_geo_db_city" VALUES(17283,'Elmwood','Elmwood, Wisconsin',21429,58);
INSERT INTO "django_geo_db_city" VALUES(17284,'Fairchild','Fairchild, Wisconsin',21430,58);
INSERT INTO "django_geo_db_city" VALUES(17285,'Fall Creek','Fall Creek, Wisconsin',21431,58);
INSERT INTO "django_geo_db_city" VALUES(17286,'Gilmanton','Gilmanton, Wisconsin',21432,58);
INSERT INTO "django_geo_db_city" VALUES(17287,'Hillsdale','Hillsdale, Wisconsin',21433,58);
INSERT INTO "django_geo_db_city" VALUES(17288,'Holcombe','Holcombe, Wisconsin',21434,58);
INSERT INTO "django_geo_db_city" VALUES(17289,'Humbird','Humbird, Wisconsin',21435,58);
INSERT INTO "django_geo_db_city" VALUES(17290,'Independence','Independence, Wisconsin',21436,58);
INSERT INTO "django_geo_db_city" VALUES(17291,'Jim Falls','Jim Falls, Wisconsin',21437,58);
INSERT INTO "django_geo_db_city" VALUES(17292,'Knapp','Knapp, Wisconsin',21438,58);
INSERT INTO "django_geo_db_city" VALUES(17293,'Maiden Rock','Maiden Rock, Wisconsin',21439,58);
INSERT INTO "django_geo_db_city" VALUES(17294,'Menomonie','Menomonie, Wisconsin',21440,58);
INSERT INTO "django_geo_db_city" VALUES(17295,'Merrillan','Merrillan, Wisconsin',21441,58);
INSERT INTO "django_geo_db_city" VALUES(17296,'Mondovi','Mondovi, Wisconsin',21442,58);
INSERT INTO "django_geo_db_city" VALUES(17297,'Nelson','Nelson, Wisconsin',21443,58);
INSERT INTO "django_geo_db_city" VALUES(17298,'New Auburn','New Auburn, Wisconsin',21444,58);
INSERT INTO "django_geo_db_city" VALUES(17299,'Osseo','Osseo, Wisconsin',21445,58);
INSERT INTO "django_geo_db_city" VALUES(17300,'Pepin','Pepin, Wisconsin',21446,58);
INSERT INTO "django_geo_db_city" VALUES(17301,'Pigeon Falls','Pigeon Falls, Wisconsin',21447,58);
INSERT INTO "django_geo_db_city" VALUES(17302,'Plum City','Plum City, Wisconsin',21448,58);
INSERT INTO "django_geo_db_city" VALUES(17303,'Prairie Farm','Prairie Farm, Wisconsin',21449,58);
INSERT INTO "django_geo_db_city" VALUES(17304,'Ridgeland','Ridgeland, Wisconsin',21450,58);
INSERT INTO "django_geo_db_city" VALUES(17305,'Rock Falls','Rock Falls, Wisconsin',21424,58);
INSERT INTO "django_geo_db_city" VALUES(17306,'Sand Creek','Sand Creek, Wisconsin',21451,58);
INSERT INTO "django_geo_db_city" VALUES(17307,'Sheldon','Sheldon, Wisconsin',21452,58);
INSERT INTO "django_geo_db_city" VALUES(17308,'Spring Valley','Spring Valley, Wisconsin',21453,58);
INSERT INTO "django_geo_db_city" VALUES(17309,'Stanley','Stanley, Wisconsin',21454,58);
INSERT INTO "django_geo_db_city" VALUES(17310,'Stockholm','Stockholm, Wisconsin',21455,58);
INSERT INTO "django_geo_db_city" VALUES(17311,'Strum','Strum, Wisconsin',21456,58);
INSERT INTO "django_geo_db_city" VALUES(17312,'Thorp','Thorp, Wisconsin',21457,58);
INSERT INTO "django_geo_db_city" VALUES(17313,'Wheeler','Wheeler, Wisconsin',21458,58);
INSERT INTO "django_geo_db_city" VALUES(17314,'Whitehall','Whitehall, Wisconsin',21459,58);
INSERT INTO "django_geo_db_city" VALUES(17315,'Spooner','Spooner, Wisconsin',21461,58);
INSERT INTO "django_geo_db_city" VALUES(17316,'Almena','Almena, Wisconsin',21462,58);
INSERT INTO "django_geo_db_city" VALUES(17317,'Ashland','Ashland, Wisconsin',21463,58);
INSERT INTO "django_geo_db_city" VALUES(17318,'Balsam Lake','Balsam Lake, Wisconsin',21464,58);
INSERT INTO "django_geo_db_city" VALUES(17319,'Barron','Barron, Wisconsin',21465,58);
INSERT INTO "django_geo_db_city" VALUES(17320,'Barronett','Barronett, Wisconsin',21466,58);
INSERT INTO "django_geo_db_city" VALUES(17321,'Bayfield','Bayfield, Wisconsin',21467,58);
INSERT INTO "django_geo_db_city" VALUES(17322,'Benoit','Benoit, Wisconsin',21468,58);
INSERT INTO "django_geo_db_city" VALUES(17323,'Birchwood','Birchwood, Wisconsin',21469,58);
INSERT INTO "django_geo_db_city" VALUES(17324,'Brill','Brill, Wisconsin',21470,58);
INSERT INTO "django_geo_db_city" VALUES(17325,'Bruce','Bruce, Wisconsin',21471,58);
INSERT INTO "django_geo_db_city" VALUES(17326,'Brule','Brule, Wisconsin',21472,58);
INSERT INTO "django_geo_db_city" VALUES(17327,'Cable','Cable, Wisconsin',21473,58);
INSERT INTO "django_geo_db_city" VALUES(17328,'Cameron','Cameron, Wisconsin',21474,58);
INSERT INTO "django_geo_db_city" VALUES(17329,'Centuria','Centuria, Wisconsin',21475,58);
INSERT INTO "django_geo_db_city" VALUES(17330,'Comstock','Comstock, Wisconsin',21476,58);
INSERT INTO "django_geo_db_city" VALUES(17331,'Cornucopia','Cornucopia, Wisconsin',21477,58);
INSERT INTO "django_geo_db_city" VALUES(17332,'Couderay','Couderay, Wisconsin',21478,58);
INSERT INTO "django_geo_db_city" VALUES(17333,'Cumberland','Cumberland, Wisconsin',21479,58);
INSERT INTO "django_geo_db_city" VALUES(17334,'Danbury','Danbury, Wisconsin',21480,58);
INSERT INTO "django_geo_db_city" VALUES(17335,'Drummond','Drummond, Wisconsin',21481,58);
INSERT INTO "django_geo_db_city" VALUES(17336,'Edgewater','Edgewater, Wisconsin',21482,58);
INSERT INTO "django_geo_db_city" VALUES(17337,'Exeland','Exeland, Wisconsin',21483,58);
INSERT INTO "django_geo_db_city" VALUES(17338,'Foxboro','Foxboro, Wisconsin',21484,58);
INSERT INTO "django_geo_db_city" VALUES(17339,'Frederic','Frederic, Wisconsin',21485,58);
INSERT INTO "django_geo_db_city" VALUES(17340,'Gordon','Gordon, Wisconsin',21486,58);
INSERT INTO "django_geo_db_city" VALUES(17341,'Grand View','Grand View, Wisconsin',21487,58);
INSERT INTO "django_geo_db_city" VALUES(17342,'Grantsburg','Grantsburg, Wisconsin',21488,58);
INSERT INTO "django_geo_db_city" VALUES(17343,'Haugen','Haugen, Wisconsin',21489,58);
INSERT INTO "django_geo_db_city" VALUES(17344,'Hawthorne','Hawthorne, Wisconsin',21490,58);
INSERT INTO "django_geo_db_city" VALUES(17345,'Hayward','Hayward, Wisconsin',21491,58);
INSERT INTO "django_geo_db_city" VALUES(17346,'Herbster','Herbster, Wisconsin',21492,58);
INSERT INTO "django_geo_db_city" VALUES(17347,'Hertel','Hertel, Wisconsin',21493,58);
INSERT INTO "django_geo_db_city" VALUES(17348,'High Bridge','High Bridge, Wisconsin',21494,58);
INSERT INTO "django_geo_db_city" VALUES(17349,'Iron River','Iron River, Wisconsin',21495,58);
INSERT INTO "django_geo_db_city" VALUES(17350,'Ladysmith','Ladysmith, Wisconsin',21496,58);
INSERT INTO "django_geo_db_city" VALUES(17351,'Lake Nebagamon','Lake Nebagamon, Wisconsin',21497,58);
INSERT INTO "django_geo_db_city" VALUES(17352,'La Pointe','La Pointe, Wisconsin',21498,58);
INSERT INTO "django_geo_db_city" VALUES(17353,'Lewis','Lewis, Wisconsin',21499,58);
INSERT INTO "django_geo_db_city" VALUES(17354,'Luck','Luck, Wisconsin',21500,58);
INSERT INTO "django_geo_db_city" VALUES(17355,'Maple','Maple, Wisconsin',21501,58);
INSERT INTO "django_geo_db_city" VALUES(17356,'Marengo','Marengo, Wisconsin',21502,58);
INSERT INTO "django_geo_db_city" VALUES(17357,'Mason','Mason, Wisconsin',21503,58);
INSERT INTO "django_geo_db_city" VALUES(17358,'Mikana','Mikana, Wisconsin',21504,58);
INSERT INTO "django_geo_db_city" VALUES(17359,'Milltown','Milltown, Wisconsin',21505,58);
INSERT INTO "django_geo_db_city" VALUES(17360,'Minong','Minong, Wisconsin',21506,58);
INSERT INTO "django_geo_db_city" VALUES(17361,'Odanah','Odanah, Wisconsin',21507,58);
INSERT INTO "django_geo_db_city" VALUES(17362,'Ojibwa','Ojibwa, Wisconsin',21508,58);
INSERT INTO "django_geo_db_city" VALUES(17363,'Poplar','Poplar, Wisconsin',21510,58);
INSERT INTO "django_geo_db_city" VALUES(17364,'Port Wing','Port Wing, Wisconsin',21511,58);
INSERT INTO "django_geo_db_city" VALUES(17365,'Radisson','Radisson, Wisconsin',21512,58);
INSERT INTO "django_geo_db_city" VALUES(17366,'Rice Lake','Rice Lake, Wisconsin',21513,58);
INSERT INTO "django_geo_db_city" VALUES(17367,'Sarona','Sarona, Wisconsin',21514,58);
INSERT INTO "django_geo_db_city" VALUES(17368,'Shell Lake','Shell Lake, Wisconsin',21515,58);
INSERT INTO "django_geo_db_city" VALUES(17369,'Siren','Siren, Wisconsin',21516,58);
INSERT INTO "django_geo_db_city" VALUES(17370,'Solon Springs','Solon Springs, Wisconsin',21517,58);
INSERT INTO "django_geo_db_city" VALUES(17371,'South Range','South Range, Wisconsin',21518,58);
INSERT INTO "django_geo_db_city" VALUES(17372,'Springbrook','Springbrook, Wisconsin',21519,58);
INSERT INTO "django_geo_db_city" VALUES(17373,'Stone Lake','Stone Lake, Wisconsin',21520,58);
INSERT INTO "django_geo_db_city" VALUES(17374,'Superior','Superior, Wisconsin',21521,58);
INSERT INTO "django_geo_db_city" VALUES(17375,'Winter','Winter, Wisconsin',21522,58);
INSERT INTO "django_geo_db_city" VALUES(17376,'Trego','Trego, Wisconsin',21523,58);
INSERT INTO "django_geo_db_city" VALUES(17377,'Turtle Lake','Turtle Lake, Wisconsin',21524,58);
INSERT INTO "django_geo_db_city" VALUES(17378,'Washburn','Washburn, Wisconsin',21526,58);
INSERT INTO "django_geo_db_city" VALUES(17379,'Webster','Webster, Wisconsin',21527,58);
INSERT INTO "django_geo_db_city" VALUES(17380,'Weyerhaeuser','Weyerhaeuser, Wisconsin',21528,58);
INSERT INTO "django_geo_db_city" VALUES(17381,'Oshkosh','Oshkosh, Wisconsin',21530,58);
INSERT INTO "django_geo_db_city" VALUES(17382,'Almond','Almond, Wisconsin',21534,58);
INSERT INTO "django_geo_db_city" VALUES(17383,'Appleton','Appleton, Wisconsin',21535,58);
INSERT INTO "django_geo_db_city" VALUES(17384,'Bancroft','Bancroft, Wisconsin',21539,58);
INSERT INTO "django_geo_db_city" VALUES(17385,'Bear Creek','Bear Creek, Wisconsin',21540,58);
INSERT INTO "django_geo_db_city" VALUES(17386,'Berlin','Berlin, Wisconsin',21541,58);
INSERT INTO "django_geo_db_city" VALUES(17387,'Big Falls','Big Falls, Wisconsin',21542,58);
INSERT INTO "django_geo_db_city" VALUES(17388,'Butte Des Morts','Butte Des Morts, Wisconsin',21543,58);
INSERT INTO "django_geo_db_city" VALUES(17389,'Caroline','Caroline, Wisconsin',21544,58);
INSERT INTO "django_geo_db_city" VALUES(17390,'Clintonville','Clintonville, Wisconsin',21545,58);
INSERT INTO "django_geo_db_city" VALUES(17391,'Coloma','Coloma, Wisconsin',21546,58);
INSERT INTO "django_geo_db_city" VALUES(17392,'Dale','Dale, Wisconsin',21135,58);
INSERT INTO "django_geo_db_city" VALUES(17393,'Eldorado','Eldorado, Wisconsin',21547,58);
INSERT INTO "django_geo_db_city" VALUES(17394,'Embarrass','Embarrass, Wisconsin',21548,58);
INSERT INTO "django_geo_db_city" VALUES(17395,'Eureka','Eureka, Wisconsin',21549,58);
INSERT INTO "django_geo_db_city" VALUES(17396,'Fond Du Lac','Fond Du Lac, Wisconsin',21550,58);
INSERT INTO "django_geo_db_city" VALUES(17397,'Fremont','Fremont, Wisconsin',21553,58);
INSERT INTO "django_geo_db_city" VALUES(17398,'Green Lake','Green Lake, Wisconsin',21554,58);
INSERT INTO "django_geo_db_city" VALUES(17399,'Greenville','Greenville, Wisconsin',21555,58);
INSERT INTO "django_geo_db_city" VALUES(17400,'Hancock','Hancock, Wisconsin',21556,58);
INSERT INTO "django_geo_db_city" VALUES(17401,'Hortonville','Hortonville, Wisconsin',21557,58);
INSERT INTO "django_geo_db_city" VALUES(17402,'Iola','Iola, Wisconsin',21558,58);
INSERT INTO "django_geo_db_city" VALUES(17403,'King','King, Wisconsin',21559,58);
INSERT INTO "django_geo_db_city" VALUES(17404,'Larsen','Larsen, Wisconsin',21560,58);
INSERT INTO "django_geo_db_city" VALUES(17405,'Leopolis','Leopolis, Wisconsin',21561,58);
INSERT INTO "django_geo_db_city" VALUES(17406,'Manawa','Manawa, Wisconsin',21562,58);
INSERT INTO "django_geo_db_city" VALUES(17407,'Marion','Marion, Wisconsin',21563,58);
INSERT INTO "django_geo_db_city" VALUES(17408,'Medina','Medina, Wisconsin',21135,58);
INSERT INTO "django_geo_db_city" VALUES(17409,'Menasha','Menasha, Wisconsin',21564,58);
INSERT INTO "django_geo_db_city" VALUES(17410,'Neenah','Neenah, Wisconsin',21565,58);
INSERT INTO "django_geo_db_city" VALUES(17411,'Neshkoro','Neshkoro, Wisconsin',21567,58);
INSERT INTO "django_geo_db_city" VALUES(17412,'Ogdensburg','Ogdensburg, Wisconsin',21569,58);
INSERT INTO "django_geo_db_city" VALUES(17413,'Omro','Omro, Wisconsin',21570,58);
INSERT INTO "django_geo_db_city" VALUES(17414,'Pickett','Pickett, Wisconsin',21571,58);
INSERT INTO "django_geo_db_city" VALUES(17415,'Pine River','Pine River, Wisconsin',21572,58);
INSERT INTO "django_geo_db_city" VALUES(17416,'Plainfield','Plainfield, Wisconsin',21573,58);
INSERT INTO "django_geo_db_city" VALUES(17417,'Poy Sippi','Poy Sippi, Wisconsin',21574,58);
INSERT INTO "django_geo_db_city" VALUES(17418,'Princeton','Princeton, Wisconsin',21575,58);
INSERT INTO "django_geo_db_city" VALUES(17419,'Readfield','Readfield, Wisconsin',21576,58);
INSERT INTO "django_geo_db_city" VALUES(17420,'Redgranite','Redgranite, Wisconsin',21577,58);
INSERT INTO "django_geo_db_city" VALUES(17421,'Ripon','Ripon, Wisconsin',21578,58);
INSERT INTO "django_geo_db_city" VALUES(17422,'Rosendale','Rosendale, Wisconsin',21579,58);
INSERT INTO "django_geo_db_city" VALUES(17423,'Royalton','Royalton, Wisconsin',21580,58);
INSERT INTO "django_geo_db_city" VALUES(17424,'Saxeville','Saxeville, Wisconsin',21581,58);
INSERT INTO "django_geo_db_city" VALUES(17425,'Scandinavia','Scandinavia, Wisconsin',21582,58);
INSERT INTO "django_geo_db_city" VALUES(17426,'Tilleda','Tilleda, Wisconsin',21583,58);
INSERT INTO "django_geo_db_city" VALUES(17427,'Van Dyne','Van Dyne, Wisconsin',21584,58);
INSERT INTO "django_geo_db_city" VALUES(17428,'Waukau','Waukau, Wisconsin',21585,58);
INSERT INTO "django_geo_db_city" VALUES(17429,'Waupaca','Waupaca, Wisconsin',21586,58);
INSERT INTO "django_geo_db_city" VALUES(17430,'Wautoma','Wautoma, Wisconsin',21587,58);
INSERT INTO "django_geo_db_city" VALUES(17431,'Weyauwega','Weyauwega, Wisconsin',21588,58);
INSERT INTO "django_geo_db_city" VALUES(17432,'Wild Rose','Wild Rose, Wisconsin',21589,58);
INSERT INTO "django_geo_db_city" VALUES(17433,'Winnebago','Winnebago, Wisconsin',21590,58);
INSERT INTO "django_geo_db_city" VALUES(17434,'Winneconne','Winneconne, Wisconsin',21591,58);
INSERT INTO "django_geo_db_city" VALUES(17435,'Afton','Afton, Minnesota',21592,41);
INSERT INTO "django_geo_db_city" VALUES(17436,'Almelund','Almelund, Minnesota',21593,41);
INSERT INTO "django_geo_db_city" VALUES(17437,'Bayport','Bayport, Minnesota',21594,41);
INSERT INTO "django_geo_db_city" VALUES(17438,'Bethel','Bethel, Minnesota',21595,41);
INSERT INTO "django_geo_db_city" VALUES(17439,'Braham','Braham, Minnesota',21596,41);
INSERT INTO "django_geo_db_city" VALUES(17440,'Brook Park','Brook Park, Minnesota',21597,41);
INSERT INTO "django_geo_db_city" VALUES(17441,'Cambridge','Cambridge, Minnesota',21598,41);
INSERT INTO "django_geo_db_city" VALUES(17442,'Cannon Falls','Cannon Falls, Minnesota',21599,41);
INSERT INTO "django_geo_db_city" VALUES(17443,'Castle Rock','Castle Rock, Minnesota',21600,41);
INSERT INTO "django_geo_db_city" VALUES(17444,'Cedar','Cedar, Minnesota',21601,41);
INSERT INTO "django_geo_db_city" VALUES(17445,'Center City','Center City, Minnesota',21602,41);
INSERT INTO "django_geo_db_city" VALUES(17446,'Chisago City','Chisago City, Minnesota',21603,41);
INSERT INTO "django_geo_db_city" VALUES(17447,'Circle Pines','Circle Pines, Minnesota',21604,41);
INSERT INTO "django_geo_db_city" VALUES(17448,'Cottage Grove','Cottage Grove, Minnesota',21605,41);
INSERT INTO "django_geo_db_city" VALUES(17449,'Dalbo','Dalbo, Minnesota',21606,41);
INSERT INTO "django_geo_db_city" VALUES(17450,'Dennison','Dennison, Minnesota',21607,41);
INSERT INTO "django_geo_db_city" VALUES(17451,'Dundas','Dundas, Minnesota',21608,41);
INSERT INTO "django_geo_db_city" VALUES(17452,'Elko','Elko, Minnesota',21609,41);
INSERT INTO "django_geo_db_city" VALUES(17453,'Faribault','Faribault, Minnesota',21610,41);
INSERT INTO "django_geo_db_city" VALUES(17454,'Farmington','Farmington, Minnesota',21611,41);
INSERT INTO "django_geo_db_city" VALUES(17455,'Forest Lake','Forest Lake, Minnesota',21612,41);
INSERT INTO "django_geo_db_city" VALUES(17456,'Frontenac','Frontenac, Minnesota',21613,41);
INSERT INTO "django_geo_db_city" VALUES(17457,'Goodhue','Goodhue, Minnesota',21614,41);
INSERT INTO "django_geo_db_city" VALUES(17458,'Grandy','Grandy, Minnesota',21615,41);
INSERT INTO "django_geo_db_city" VALUES(17459,'Grasston','Grasston, Minnesota',21616,41);
INSERT INTO "django_geo_db_city" VALUES(17460,'Hampton','Hampton, Minnesota',21617,41);
INSERT INTO "django_geo_db_city" VALUES(17461,'Harris','Harris, Minnesota',21618,41);
INSERT INTO "django_geo_db_city" VALUES(17462,'Hastings','Hastings, Minnesota',21619,41);
INSERT INTO "django_geo_db_city" VALUES(17463,'Henriette','Henriette, Minnesota',21620,41);
INSERT INTO "django_geo_db_city" VALUES(17464,'Hinckley','Hinckley, Minnesota',21621,41);
INSERT INTO "django_geo_db_city" VALUES(17465,'Hugo','Hugo, Minnesota',21622,41);
INSERT INTO "django_geo_db_city" VALUES(17466,'Isanti','Isanti, Minnesota',21623,41);
INSERT INTO "django_geo_db_city" VALUES(17467,'Lake City','Lake City, Minnesota',21624,41);
INSERT INTO "django_geo_db_city" VALUES(17468,'Lake Elmo','Lake Elmo, Minnesota',21625,41);
INSERT INTO "django_geo_db_city" VALUES(17469,'Lakeland','Lakeland, Minnesota',21626,41);
INSERT INTO "django_geo_db_city" VALUES(17470,'Lakeville','Lakeville, Minnesota',21627,41);
INSERT INTO "django_geo_db_city" VALUES(17471,'Lindstrom','Lindstrom, Minnesota',21628,41);
INSERT INTO "django_geo_db_city" VALUES(17472,'Lonsdale','Lonsdale, Minnesota',21629,41);
INSERT INTO "django_geo_db_city" VALUES(17473,'Marine On Saint Croix','Marine On Saint Croix, Minnesota',21630,41);
INSERT INTO "django_geo_db_city" VALUES(17474,'Medford','Medford, Minnesota',21631,41);
INSERT INTO "django_geo_db_city" VALUES(17475,'Mora','Mora, Minnesota',21632,41);
INSERT INTO "django_geo_db_city" VALUES(17476,'Morristown','Morristown, Minnesota',21633,41);
INSERT INTO "django_geo_db_city" VALUES(17477,'Nerstrand','Nerstrand, Minnesota',21634,41);
INSERT INTO "django_geo_db_city" VALUES(17478,'New Market','New Market, Minnesota',21635,41);
INSERT INTO "django_geo_db_city" VALUES(17479,'Newport','Newport, Minnesota',21636,41);
INSERT INTO "django_geo_db_city" VALUES(17480,'North Branch','North Branch, Minnesota',21637,41);
INSERT INTO "django_geo_db_city" VALUES(17481,'Northfield','Northfield, Minnesota',21638,41);
INSERT INTO "django_geo_db_city" VALUES(17482,'Owatonna','Owatonna, Minnesota',21639,41);
INSERT INTO "django_geo_db_city" VALUES(17483,'Pine City','Pine City, Minnesota',21640,41);
INSERT INTO "django_geo_db_city" VALUES(17484,'Randolph','Randolph, Minnesota',21641,41);
INSERT INTO "django_geo_db_city" VALUES(17485,'Red Wing','Red Wing, Minnesota',21642,41);
INSERT INTO "django_geo_db_city" VALUES(17486,'Rock Creek','Rock Creek, Minnesota',21643,41);
INSERT INTO "django_geo_db_city" VALUES(17487,'Rosemount','Rosemount, Minnesota',21644,41);
INSERT INTO "django_geo_db_city" VALUES(17488,'Rush City','Rush City, Minnesota',21645,41);
INSERT INTO "django_geo_db_city" VALUES(17489,'Saint Francis','Saint Francis, Minnesota',21646,41);
INSERT INTO "django_geo_db_city" VALUES(17490,'Saint Paul Park','Saint Paul Park, Minnesota',21647,41);
INSERT INTO "django_geo_db_city" VALUES(17491,'Sandstone','Sandstone, Minnesota',21648,41);
INSERT INTO "django_geo_db_city" VALUES(17492,'Scandia','Scandia, Minnesota',21649,41);
INSERT INTO "django_geo_db_city" VALUES(17493,'Shafer','Shafer, Minnesota',21650,41);
INSERT INTO "django_geo_db_city" VALUES(17494,'South Saint Paul','South Saint Paul, Minnesota',21651,41);
INSERT INTO "django_geo_db_city" VALUES(17495,'Inver Grove Heights','Inver Grove Heights, Minnesota',21652,41);
INSERT INTO "django_geo_db_city" VALUES(17496,'Stacy','Stacy, Minnesota',21593,41);
INSERT INTO "django_geo_db_city" VALUES(17497,'Stanchfield','Stanchfield, Minnesota',21655,41);
INSERT INTO "django_geo_db_city" VALUES(17498,'Stillwater','Stillwater, Minnesota',21656,41);
INSERT INTO "django_geo_db_city" VALUES(17499,'Taylors Falls','Taylors Falls, Minnesota',21658,41);
INSERT INTO "django_geo_db_city" VALUES(17500,'Vermillion','Vermillion, Minnesota',21659,41);
INSERT INTO "django_geo_db_city" VALUES(17501,'Warsaw','Warsaw, Minnesota',21660,41);
INSERT INTO "django_geo_db_city" VALUES(17502,'Webster','Webster, Minnesota',21661,41);
INSERT INTO "django_geo_db_city" VALUES(17503,'Welch','Welch, Minnesota',21662,41);
INSERT INTO "django_geo_db_city" VALUES(17504,'Willernie','Willernie, Minnesota',21663,41);
INSERT INTO "django_geo_db_city" VALUES(17505,'Wyoming','Wyoming, Minnesota',21664,41);
INSERT INTO "django_geo_db_city" VALUES(17506,'Saint Paul','Saint Paul, Minnesota',21665,41);
INSERT INTO "django_geo_db_city" VALUES(17507,'Mendota','Mendota, Minnesota',21696,41);
INSERT INTO "django_geo_db_city" VALUES(17508,'Duluth','Duluth, Minnesota',21699,41);
INSERT INTO "django_geo_db_city" VALUES(17509,'Kroschel','Kroschel, Minnesota',21700,41);
INSERT INTO "django_geo_db_city" VALUES(17510,'Albertville','Albertville, Minnesota',21701,41);
INSERT INTO "django_geo_db_city" VALUES(17511,'Annandale','Annandale, Minnesota',21702,41);
INSERT INTO "django_geo_db_city" VALUES(17512,'Anoka','Anoka, Minnesota',21703,41);
INSERT INTO "django_geo_db_city" VALUES(17513,'Andover','Andover, Minnesota',21704,41);
INSERT INTO "django_geo_db_city" VALUES(17514,'Hopkins','Hopkins, Minnesota',21705,41);
INSERT INTO "django_geo_db_city" VALUES(17515,'Burnsville','Burnsville, Minnesota',21706,41);
INSERT INTO "django_geo_db_city" VALUES(17516,'Arlington','Arlington, Minnesota',21707,41);
INSERT INTO "django_geo_db_city" VALUES(17517,'Becker','Becker, Minnesota',21708,41);
INSERT INTO "django_geo_db_city" VALUES(17518,'Big Lake','Big Lake, Minnesota',21709,41);
INSERT INTO "django_geo_db_city" VALUES(17519,'Bird Island','Bird Island, Minnesota',21710,41);
INSERT INTO "django_geo_db_city" VALUES(17520,'Osseo','Osseo, Minnesota',21711,41);
INSERT INTO "django_geo_db_city" VALUES(17521,'Brownton','Brownton, Minnesota',21712,41);
INSERT INTO "django_geo_db_city" VALUES(17522,'Buffalo','Buffalo, Minnesota',21713,41);
INSERT INTO "django_geo_db_city" VALUES(17523,'Buffalo Lake','Buffalo Lake, Minnesota',21714,41);
INSERT INTO "django_geo_db_city" VALUES(17524,'Carver','Carver, Minnesota',21715,41);
INSERT INTO "django_geo_db_city" VALUES(17525,'Champlin','Champlin, Minnesota',21716,41);
INSERT INTO "django_geo_db_city" VALUES(17526,'Chanhassen','Chanhassen, Minnesota',21717,41);
INSERT INTO "django_geo_db_city" VALUES(17527,'Chaska','Chaska, Minnesota',21718,41);
INSERT INTO "django_geo_db_city" VALUES(17528,'Clear Lake','Clear Lake, Minnesota',21719,41);
INSERT INTO "django_geo_db_city" VALUES(17529,'Clearwater','Clearwater, Minnesota',21720,41);
INSERT INTO "django_geo_db_city" VALUES(17530,'Cokato','Cokato, Minnesota',21721,41);
INSERT INTO "django_geo_db_city" VALUES(17531,'Cologne','Cologne, Minnesota',21722,41);
INSERT INTO "django_geo_db_city" VALUES(17532,'Crystal Bay','Crystal Bay, Minnesota',21723,41);
INSERT INTO "django_geo_db_city" VALUES(17533,'Darwin','Darwin, Minnesota',21724,41);
INSERT INTO "django_geo_db_city" VALUES(17534,'Dassel','Dassel, Minnesota',21725,41);
INSERT INTO "django_geo_db_city" VALUES(17535,'Dayton','Dayton, Minnesota',21726,41);
INSERT INTO "django_geo_db_city" VALUES(17536,'Delano','Delano, Minnesota',21727,41);
INSERT INTO "django_geo_db_city" VALUES(17537,'Eden Valley','Eden Valley, Minnesota',21728,41);
INSERT INTO "django_geo_db_city" VALUES(17538,'Elk River','Elk River, Minnesota',21729,41);
INSERT INTO "django_geo_db_city" VALUES(17539,'Excelsior','Excelsior, Minnesota',21730,41);
INSERT INTO "django_geo_db_city" VALUES(17540,'Fairfax','Fairfax, Minnesota',21731,41);
INSERT INTO "django_geo_db_city" VALUES(17541,'Franklin','Franklin, Minnesota',21732,41);
INSERT INTO "django_geo_db_city" VALUES(17542,'Gaylord','Gaylord, Minnesota',21733,41);
INSERT INTO "django_geo_db_city" VALUES(17543,'Gibbon','Gibbon, Minnesota',21734,41);
INSERT INTO "django_geo_db_city" VALUES(17544,'Glencoe','Glencoe, Minnesota',21735,41);
INSERT INTO "django_geo_db_city" VALUES(17545,'Green Isle','Green Isle, Minnesota',21737,41);
INSERT INTO "django_geo_db_city" VALUES(17546,'Hamburg','Hamburg, Minnesota',21738,41);
INSERT INTO "django_geo_db_city" VALUES(17547,'Hamel','Hamel, Minnesota',21739,41);
INSERT INTO "django_geo_db_city" VALUES(17548,'Hanover','Hanover, Minnesota',21740,41);
INSERT INTO "django_geo_db_city" VALUES(17549,'Hector','Hector, Minnesota',21741,41);
INSERT INTO "django_geo_db_city" VALUES(17550,'Eden Prairie','Eden Prairie, Minnesota',21743,41);
INSERT INTO "django_geo_db_city" VALUES(17551,'Minnetonka','Minnetonka, Minnesota',21744,41);
INSERT INTO "django_geo_db_city" VALUES(17552,'Maple Plain','Maple Plain, Minnesota',21747,41);
INSERT INTO "django_geo_db_city" VALUES(17553,'Howard Lake','Howard Lake, Minnesota',21748,41);
INSERT INTO "django_geo_db_city" VALUES(17554,'Hutchinson','Hutchinson, Minnesota',21749,41);
INSERT INTO "django_geo_db_city" VALUES(17555,'Jordan','Jordan, Minnesota',21750,41);
INSERT INTO "django_geo_db_city" VALUES(17556,'Kimball','Kimball, Minnesota',21751,41);
INSERT INTO "django_geo_db_city" VALUES(17557,'Lester Prairie','Lester Prairie, Minnesota',21752,41);
INSERT INTO "django_geo_db_city" VALUES(17558,'Litchfield','Litchfield, Minnesota',21753,41);
INSERT INTO "django_geo_db_city" VALUES(17559,'Long Lake','Long Lake, Minnesota',21754,41);
INSERT INTO "django_geo_db_city" VALUES(17560,'Loretto','Loretto, Minnesota',21755,41);
INSERT INTO "django_geo_db_city" VALUES(17561,'Maple Lake','Maple Lake, Minnesota',21756,41);
INSERT INTO "django_geo_db_city" VALUES(17562,'Mayer','Mayer, Minnesota',21758,41);
INSERT INTO "django_geo_db_city" VALUES(17563,'Minnetonka Beach','Minnetonka Beach, Minnesota',21759,41);
INSERT INTO "django_geo_db_city" VALUES(17564,'Monticello','Monticello, Minnesota',21760,41);
INSERT INTO "django_geo_db_city" VALUES(17565,'Montrose','Montrose, Minnesota',21761,41);
INSERT INTO "django_geo_db_city" VALUES(17566,'Mound','Mound, Minnesota',21762,41);
INSERT INTO "django_geo_db_city" VALUES(17567,'New Auburn','New Auburn, Minnesota',21764,41);
INSERT INTO "django_geo_db_city" VALUES(17568,'New Germany','New Germany, Minnesota',21765,41);
INSERT INTO "django_geo_db_city" VALUES(17569,'Norwood','Norwood, Minnesota',21766,41);
INSERT INTO "django_geo_db_city" VALUES(17570,'Plato','Plato, Minnesota',21768,41);
INSERT INTO "django_geo_db_city" VALUES(17571,'Princeton','Princeton, Minnesota',21769,41);
INSERT INTO "django_geo_db_city" VALUES(17572,'Prior Lake','Prior Lake, Minnesota',21770,41);
INSERT INTO "django_geo_db_city" VALUES(17573,'Rockford','Rockford, Minnesota',21771,41);
INSERT INTO "django_geo_db_city" VALUES(17574,'Rogers','Rogers, Minnesota',21772,41);
INSERT INTO "django_geo_db_city" VALUES(17575,'Saint Bonifacius','Saint Bonifacius, Minnesota',21773,41);
INSERT INTO "django_geo_db_city" VALUES(17576,'Saint Michael','Saint Michael, Minnesota',21774,41);
INSERT INTO "django_geo_db_city" VALUES(17577,'Santiago','Santiago, Minnesota',21775,41);
INSERT INTO "django_geo_db_city" VALUES(17578,'Savage','Savage, Minnesota',21776,41);
INSERT INTO "django_geo_db_city" VALUES(17579,'Shakopee','Shakopee, Minnesota',21777,41);
INSERT INTO "django_geo_db_city" VALUES(17580,'Silver Creek','Silver Creek, Minnesota',21778,41);
INSERT INTO "django_geo_db_city" VALUES(17581,'Silver Lake','Silver Lake, Minnesota',21779,41);
INSERT INTO "django_geo_db_city" VALUES(17582,'South Haven','South Haven, Minnesota',21780,41);
INSERT INTO "django_geo_db_city" VALUES(17583,'Spring Park','Spring Park, Minnesota',21782,41);
INSERT INTO "django_geo_db_city" VALUES(17584,'Stewart','Stewart, Minnesota',21783,41);
INSERT INTO "django_geo_db_city" VALUES(17585,'Victoria','Victoria, Minnesota',21784,41);
INSERT INTO "django_geo_db_city" VALUES(17586,'Waconia','Waconia, Minnesota',21785,41);
INSERT INTO "django_geo_db_city" VALUES(17587,'Watertown','Watertown, Minnesota',21786,41);
INSERT INTO "django_geo_db_city" VALUES(17588,'Watkins','Watkins, Minnesota',21787,41);
INSERT INTO "django_geo_db_city" VALUES(17589,'Waverly','Waverly, Minnesota',21788,41);
INSERT INTO "django_geo_db_city" VALUES(17590,'Wayzata','Wayzata, Minnesota',21789,41);
INSERT INTO "django_geo_db_city" VALUES(17591,'Navarre','Navarre, Minnesota',21723,41);
INSERT INTO "django_geo_db_city" VALUES(17592,'Young America','Young America, Minnesota',21781,41);
INSERT INTO "django_geo_db_city" VALUES(17593,'Winsted','Winsted, Minnesota',21790,41);
INSERT INTO "django_geo_db_city" VALUES(17594,'Winthrop','Winthrop, Minnesota',21791,41);
INSERT INTO "django_geo_db_city" VALUES(17595,'Zimmerman','Zimmerman, Minnesota',21793,41);
INSERT INTO "django_geo_db_city" VALUES(17596,'Minneapolis','Minneapolis, Minnesota',21794,41);
INSERT INTO "django_geo_db_city" VALUES(17597,'Beaver Bay','Beaver Bay, Minnesota',21847,41);
INSERT INTO "django_geo_db_city" VALUES(17598,'Brimson','Brimson, Minnesota',21848,41);
INSERT INTO "django_geo_db_city" VALUES(17599,'Finland','Finland, Minnesota',21849,41);
INSERT INTO "django_geo_db_city" VALUES(17600,'Grand Marais','Grand Marais, Minnesota',21850,41);
INSERT INTO "django_geo_db_city" VALUES(17601,'Grand Portage','Grand Portage, Minnesota',21851,41);
INSERT INTO "django_geo_db_city" VALUES(17602,'Hovland','Hovland, Minnesota',21852,41);
INSERT INTO "django_geo_db_city" VALUES(17603,'Isabella','Isabella, Minnesota',21853,41);
INSERT INTO "django_geo_db_city" VALUES(17604,'Knife River','Knife River, Minnesota',21855,41);
INSERT INTO "django_geo_db_city" VALUES(17605,'Lutsen','Lutsen, Minnesota',21856,41);
INSERT INTO "django_geo_db_city" VALUES(17606,'Schroeder','Schroeder, Minnesota',21857,41);
INSERT INTO "django_geo_db_city" VALUES(17607,'Silver Bay','Silver Bay, Minnesota',21858,41);
INSERT INTO "django_geo_db_city" VALUES(17608,'Tofte','Tofte, Minnesota',21859,41);
INSERT INTO "django_geo_db_city" VALUES(17609,'Two Harbors','Two Harbors, Minnesota',21860,41);
INSERT INTO "django_geo_db_city" VALUES(17610,'Barnum','Barnum, Minnesota',21861,41);
INSERT INTO "django_geo_db_city" VALUES(17611,'Adolph','Adolph, Minnesota',21862,41);
INSERT INTO "django_geo_db_city" VALUES(17612,'Alborn','Alborn, Minnesota',21863,41);
INSERT INTO "django_geo_db_city" VALUES(17613,'Angora','Angora, Minnesota',21864,41);
INSERT INTO "django_geo_db_city" VALUES(17614,'Askov','Askov, Minnesota',21865,41);
INSERT INTO "django_geo_db_city" VALUES(17615,'Aurora','Aurora, Minnesota',21866,41);
INSERT INTO "django_geo_db_city" VALUES(17616,'Babbitt','Babbitt, Minnesota',21867,41);
INSERT INTO "django_geo_db_city" VALUES(17617,'Biwabik','Biwabik, Minnesota',21869,41);
INSERT INTO "django_geo_db_city" VALUES(17618,'Bovey','Bovey, Minnesota',21870,41);
INSERT INTO "django_geo_db_city" VALUES(17619,'Britt','Britt, Minnesota',21871,41);
INSERT INTO "django_geo_db_city" VALUES(17620,'Brookston','Brookston, Minnesota',21872,41);
INSERT INTO "django_geo_db_city" VALUES(17621,'Bruno','Bruno, Minnesota',21873,41);
INSERT INTO "django_geo_db_city" VALUES(17622,'Buhl','Buhl, Minnesota',21874,41);
INSERT INTO "django_geo_db_city" VALUES(17623,'Calumet','Calumet, Minnesota',21876,41);
INSERT INTO "django_geo_db_city" VALUES(17624,'Canyon','Canyon, Minnesota',21877,41);
INSERT INTO "django_geo_db_city" VALUES(17625,'Carlton','Carlton, Minnesota',21878,41);
INSERT INTO "django_geo_db_city" VALUES(17626,'Chisholm','Chisholm, Minnesota',21879,41);
INSERT INTO "django_geo_db_city" VALUES(17627,'Cloquet','Cloquet, Minnesota',21880,41);
INSERT INTO "django_geo_db_city" VALUES(17628,'Cohasset','Cohasset, Minnesota',21881,41);
INSERT INTO "django_geo_db_city" VALUES(17629,'Coleraine','Coleraine, Minnesota',21882,41);
INSERT INTO "django_geo_db_city" VALUES(17630,'Cook','Cook, Minnesota',21883,41);
INSERT INTO "django_geo_db_city" VALUES(17631,'Cotton','Cotton, Minnesota',21884,41);
INSERT INTO "django_geo_db_city" VALUES(17632,'Crane Lake','Crane Lake, Minnesota',21885,41);
INSERT INTO "django_geo_db_city" VALUES(17633,'Cromwell','Cromwell, Minnesota',21886,41);
INSERT INTO "django_geo_db_city" VALUES(17634,'Bigfork','Bigfork, Minnesota',21887,41);
INSERT INTO "django_geo_db_city" VALUES(17635,'Grand Rapids','Grand Rapids, Minnesota',21888,41);
INSERT INTO "django_geo_db_city" VALUES(17636,'Ely','Ely, Minnesota',21889,41);
INSERT INTO "django_geo_db_city" VALUES(17637,'Embarrass','Embarrass, Minnesota',21890,41);
INSERT INTO "django_geo_db_city" VALUES(17638,'Esko','Esko, Minnesota',21891,41);
INSERT INTO "django_geo_db_city" VALUES(17639,'Eveleth','Eveleth, Minnesota',21892,41);
INSERT INTO "django_geo_db_city" VALUES(17640,'Finlayson','Finlayson, Minnesota',21893,41);
INSERT INTO "django_geo_db_city" VALUES(17641,'Floodwood','Floodwood, Minnesota',21894,41);
INSERT INTO "django_geo_db_city" VALUES(17642,'Forbes','Forbes, Minnesota',21895,41);
INSERT INTO "django_geo_db_city" VALUES(17643,'Gilbert','Gilbert, Minnesota',21896,41);
INSERT INTO "django_geo_db_city" VALUES(17644,'Goodland','Goodland, Minnesota',21897,41);
INSERT INTO "django_geo_db_city" VALUES(17645,'Hibbing','Hibbing, Minnesota',21899,41);
INSERT INTO "django_geo_db_city" VALUES(17646,'Hill City','Hill City, Minnesota',21900,41);
INSERT INTO "django_geo_db_city" VALUES(17647,'Holyoke','Holyoke, Minnesota',21901,41);
INSERT INTO "django_geo_db_city" VALUES(17648,'Hoyt Lakes','Hoyt Lakes, Minnesota',21902,41);
INSERT INTO "django_geo_db_city" VALUES(17649,'Iron','Iron, Minnesota',21903,41);
INSERT INTO "django_geo_db_city" VALUES(17650,'Jacobson','Jacobson, Minnesota',21904,41);
INSERT INTO "django_geo_db_city" VALUES(17651,'Keewatin','Keewatin, Minnesota',21905,41);
INSERT INTO "django_geo_db_city" VALUES(17652,'Kerrick','Kerrick, Minnesota',21906,41);
INSERT INTO "django_geo_db_city" VALUES(17653,'Kettle River','Kettle River, Minnesota',21907,41);
INSERT INTO "django_geo_db_city" VALUES(17654,'Kinney','Kinney, Minnesota',21908,41);
INSERT INTO "django_geo_db_city" VALUES(17655,'Mcgregor','Mcgregor, Minnesota',21909,41);
INSERT INTO "django_geo_db_city" VALUES(17656,'McKinley','McKinley, Minnesota',21910,41);
INSERT INTO "django_geo_db_city" VALUES(17657,'Makinen','Makinen, Minnesota',21911,41);
INSERT INTO "django_geo_db_city" VALUES(17658,'Marble','Marble, Minnesota',21912,41);
INSERT INTO "django_geo_db_city" VALUES(17659,'Meadowlands','Meadowlands, Minnesota',21913,41);
INSERT INTO "django_geo_db_city" VALUES(17660,'Melrude','Melrude, Minnesota',21914,41);
INSERT INTO "django_geo_db_city" VALUES(17661,'Moose Lake','Moose Lake, Minnesota',21915,41);
INSERT INTO "django_geo_db_city" VALUES(17662,'Mountain Iron','Mountain Iron, Minnesota',21916,41);
INSERT INTO "django_geo_db_city" VALUES(17663,'Nashwauk','Nashwauk, Minnesota',21917,41);
INSERT INTO "django_geo_db_city" VALUES(17664,'Orr','Orr, Minnesota',21918,41);
INSERT INTO "django_geo_db_city" VALUES(17665,'Nett Lake','Nett Lake, Minnesota',21919,41);
INSERT INTO "django_geo_db_city" VALUES(17666,'Pengilly','Pengilly, Minnesota',21920,41);
INSERT INTO "django_geo_db_city" VALUES(17667,'Virginia','Virginia, Minnesota',21862,41);
INSERT INTO "django_geo_db_city" VALUES(17668,'Clark','Clark, Minnesota',21921,41);
INSERT INTO "django_geo_db_city" VALUES(17669,'Saginaw','Saginaw, Minnesota',21922,41);
INSERT INTO "django_geo_db_city" VALUES(17670,'Sawyer','Sawyer, Minnesota',21923,41);
INSERT INTO "django_geo_db_city" VALUES(17671,'Side Lake','Side Lake, Minnesota',21924,41);
INSERT INTO "django_geo_db_city" VALUES(17672,'Soudan','Soudan, Minnesota',21925,41);
INSERT INTO "django_geo_db_city" VALUES(17673,'Sturgeon Lake','Sturgeon Lake, Minnesota',21926,41);
INSERT INTO "django_geo_db_city" VALUES(17674,'Swan River','Swan River, Minnesota',21927,41);
INSERT INTO "django_geo_db_city" VALUES(17675,'Swatara','Swatara, Minnesota',21928,41);
INSERT INTO "django_geo_db_city" VALUES(17676,'Taconite','Taconite, Minnesota',21929,41);
INSERT INTO "django_geo_db_city" VALUES(17677,'Tamarack','Tamarack, Minnesota',21930,41);
INSERT INTO "django_geo_db_city" VALUES(17678,'Tower','Tower, Minnesota',21931,41);
INSERT INTO "django_geo_db_city" VALUES(17679,'Twig','Twig, Minnesota',21862,41);
INSERT INTO "django_geo_db_city" VALUES(17680,'Warba','Warba, Minnesota',21933,41);
INSERT INTO "django_geo_db_city" VALUES(17681,'Willow River','Willow River, Minnesota',21934,41);
INSERT INTO "django_geo_db_city" VALUES(17682,'Winton','Winton, Minnesota',21935,41);
INSERT INTO "django_geo_db_city" VALUES(17683,'Wrenshall','Wrenshall, Minnesota',21936,41);
INSERT INTO "django_geo_db_city" VALUES(17684,'Wright','Wright, Minnesota',21937,41);
INSERT INTO "django_geo_db_city" VALUES(17685,'Rochester','Rochester, Minnesota',21949,41);
INSERT INTO "django_geo_db_city" VALUES(17686,'Adams','Adams, Minnesota',21955,41);
INSERT INTO "django_geo_db_city" VALUES(17687,'Altura','Altura, Minnesota',21956,41);
INSERT INTO "django_geo_db_city" VALUES(17688,'Austin','Austin, Minnesota',21957,41);
INSERT INTO "django_geo_db_city" VALUES(17689,'Blooming Prairie','Blooming Prairie, Minnesota',21958,41);
INSERT INTO "django_geo_db_city" VALUES(17690,'Brownsdale','Brownsdale, Minnesota',21959,41);
INSERT INTO "django_geo_db_city" VALUES(17691,'Brownsville','Brownsville, Minnesota',21960,41);
INSERT INTO "django_geo_db_city" VALUES(17692,'Byron','Byron, Minnesota',21961,41);
INSERT INTO "django_geo_db_city" VALUES(17693,'Caledonia','Caledonia, Minnesota',21962,41);
INSERT INTO "django_geo_db_city" VALUES(17694,'Canton','Canton, Minnesota',21963,41);
INSERT INTO "django_geo_db_city" VALUES(17695,'Chatfield','Chatfield, Minnesota',21964,41);
INSERT INTO "django_geo_db_city" VALUES(17696,'Claremont','Claremont, Minnesota',21965,41);
INSERT INTO "django_geo_db_city" VALUES(17697,'Dakota','Dakota, Minnesota',21966,41);
INSERT INTO "django_geo_db_city" VALUES(17698,'Dexter','Dexter, Minnesota',21967,41);
INSERT INTO "django_geo_db_city" VALUES(17699,'Dodge Center','Dodge Center, Minnesota',21968,41);
INSERT INTO "django_geo_db_city" VALUES(17700,'Dover','Dover, Minnesota',21969,41);
INSERT INTO "django_geo_db_city" VALUES(17701,'Eitzen','Eitzen, Minnesota',21970,41);
INSERT INTO "django_geo_db_city" VALUES(17702,'Elgin','Elgin, Minnesota',21971,41);
INSERT INTO "django_geo_db_city" VALUES(17703,'Elkton','Elkton, Minnesota',21972,41);
INSERT INTO "django_geo_db_city" VALUES(17704,'Eyota','Eyota, Minnesota',21973,41);
INSERT INTO "django_geo_db_city" VALUES(17705,'Fountain','Fountain, Minnesota',21974,41);
INSERT INTO "django_geo_db_city" VALUES(17706,'Grand Meadow','Grand Meadow, Minnesota',21975,41);
INSERT INTO "django_geo_db_city" VALUES(17707,'Harmony','Harmony, Minnesota',21976,41);
INSERT INTO "django_geo_db_city" VALUES(17708,'Hayfield','Hayfield, Minnesota',21977,41);
INSERT INTO "django_geo_db_city" VALUES(17709,'Hokah','Hokah, Minnesota',21978,41);
INSERT INTO "django_geo_db_city" VALUES(17710,'Homer','Homer, Minnesota',21979,41);
INSERT INTO "django_geo_db_city" VALUES(17711,'Houston','Houston, Minnesota',21980,41);
INSERT INTO "django_geo_db_city" VALUES(17712,'Kasson','Kasson, Minnesota',21981,41);
INSERT INTO "django_geo_db_city" VALUES(17713,'Kellogg','Kellogg, Minnesota',21982,41);
INSERT INTO "django_geo_db_city" VALUES(17714,'Kenyon','Kenyon, Minnesota',21983,41);
INSERT INTO "django_geo_db_city" VALUES(17715,'La Crescent','La Crescent, Minnesota',21984,41);
INSERT INTO "django_geo_db_city" VALUES(17716,'Lanesboro','Lanesboro, Minnesota',21985,41);
INSERT INTO "django_geo_db_city" VALUES(17717,'Lansing','Lansing, Minnesota',21986,41);
INSERT INTO "django_geo_db_city" VALUES(17718,'Le Roy','Le Roy, Minnesota',21987,41);
INSERT INTO "django_geo_db_city" VALUES(17719,'Lewiston','Lewiston, Minnesota',21988,41);
INSERT INTO "django_geo_db_city" VALUES(17720,'Lyle','Lyle, Minnesota',21989,41);
INSERT INTO "django_geo_db_city" VALUES(17721,'Mabel','Mabel, Iowa',21990,19);
INSERT INTO "django_geo_db_city" VALUES(17722,'Mantorville','Mantorville, Minnesota',21991,41);
INSERT INTO "django_geo_db_city" VALUES(17723,'Mazeppa','Mazeppa, Minnesota',21992,41);
INSERT INTO "django_geo_db_city" VALUES(17724,'Millville','Millville, Minnesota',21993,41);
INSERT INTO "django_geo_db_city" VALUES(17725,'Minnesota City','Minnesota City, Minnesota',21994,41);
INSERT INTO "django_geo_db_city" VALUES(17726,'Oronoco','Oronoco, Minnesota',21995,41);
INSERT INTO "django_geo_db_city" VALUES(17727,'Ostrander','Ostrander, Minnesota',21996,41);
INSERT INTO "django_geo_db_city" VALUES(17728,'Peterson','Peterson, Minnesota',21997,41);
INSERT INTO "django_geo_db_city" VALUES(17729,'Pine Island','Pine Island, Minnesota',21998,41);
INSERT INTO "django_geo_db_city" VALUES(17730,'Plainview','Plainview, Minnesota',21999,41);
INSERT INTO "django_geo_db_city" VALUES(17731,'Preston','Preston, Minnesota',22000,41);
INSERT INTO "django_geo_db_city" VALUES(17732,'Racine','Racine, Minnesota',22001,41);
INSERT INTO "django_geo_db_city" VALUES(17733,'Reads Landing','Reads Landing, Minnesota',22002,41);
INSERT INTO "django_geo_db_city" VALUES(17734,'Rollingstone','Rollingstone, Minnesota',22003,41);
INSERT INTO "django_geo_db_city" VALUES(17735,'Rose Creek','Rose Creek, Minnesota',22004,41);
INSERT INTO "django_geo_db_city" VALUES(17736,'Rushford','Rushford, Minnesota',22005,41);
INSERT INTO "django_geo_db_city" VALUES(17737,'Saint Charles','Saint Charles, Minnesota',22006,41);
INSERT INTO "django_geo_db_city" VALUES(17738,'Sargeant','Sargeant, Minnesota',22007,41);
INSERT INTO "django_geo_db_city" VALUES(17739,'Spring Grove','Spring Grove, Minnesota',22008,41);
INSERT INTO "django_geo_db_city" VALUES(17740,'Spring Valley','Spring Valley, Minnesota',22009,41);
INSERT INTO "django_geo_db_city" VALUES(17741,'Stewartville','Stewartville, Minnesota',22010,41);
INSERT INTO "django_geo_db_city" VALUES(17742,'Taopi','Taopi, Minnesota',22011,41);
INSERT INTO "django_geo_db_city" VALUES(17743,'West Albany','West Albany, Minnesota',22012,41);
INSERT INTO "django_geo_db_city" VALUES(17744,'Utica','Utica, Minnesota',22013,41);
INSERT INTO "django_geo_db_city" VALUES(17745,'Wabasha','Wabasha, Minnesota',22014,41);
INSERT INTO "django_geo_db_city" VALUES(17746,'Waltham','Waltham, Minnesota',22015,41);
INSERT INTO "django_geo_db_city" VALUES(17747,'Wanamingo','Wanamingo, Minnesota',22016,41);
INSERT INTO "django_geo_db_city" VALUES(17748,'West Concord','West Concord, Minnesota',22017,41);
INSERT INTO "django_geo_db_city" VALUES(17749,'Winona','Winona, Minnesota',22018,41);
INSERT INTO "django_geo_db_city" VALUES(17750,'Stockton','Stockton, Minnesota',22019,41);
INSERT INTO "django_geo_db_city" VALUES(17751,'Wykoff','Wykoff, Minnesota',22020,41);
INSERT INTO "django_geo_db_city" VALUES(17752,'Zumbro Falls','Zumbro Falls, Minnesota',22021,41);
INSERT INTO "django_geo_db_city" VALUES(17753,'Zumbrota','Zumbrota, Minnesota',22022,41);
INSERT INTO "django_geo_db_city" VALUES(17754,'Mankato','Mankato, Minnesota',22023,41);
INSERT INTO "django_geo_db_city" VALUES(17755,'Albert Lea','Albert Lea, Minnesota',22026,41);
INSERT INTO "django_geo_db_city" VALUES(17756,'Alden','Alden, Minnesota',22027,41);
INSERT INTO "django_geo_db_city" VALUES(17757,'Amboy','Amboy, Minnesota',22028,41);
INSERT INTO "django_geo_db_city" VALUES(17758,'Belle Plaine','Belle Plaine, Minnesota',22029,41);
INSERT INTO "django_geo_db_city" VALUES(17759,'Blue Earth','Blue Earth, Minnesota',22030,41);
INSERT INTO "django_geo_db_city" VALUES(17760,'Bricelyn','Bricelyn, Minnesota',22031,41);
INSERT INTO "django_geo_db_city" VALUES(17761,'Clarks Grove','Clarks Grove, Minnesota',22032,41);
INSERT INTO "django_geo_db_city" VALUES(17762,'Cleveland','Cleveland, Minnesota',22033,41);
INSERT INTO "django_geo_db_city" VALUES(17763,'Comfrey','Comfrey, Minnesota',22034,41);
INSERT INTO "django_geo_db_city" VALUES(17764,'Conger','Conger, Minnesota',22035,41);
INSERT INTO "django_geo_db_city" VALUES(17765,'Courtland','Courtland, Minnesota',22036,41);
INSERT INTO "django_geo_db_city" VALUES(17766,'Darfur','Darfur, Minnesota',22037,41);
INSERT INTO "django_geo_db_city" VALUES(17767,'Delavan','Delavan, Minnesota',22038,41);
INSERT INTO "django_geo_db_city" VALUES(17768,'Eagle Lake','Eagle Lake, Minnesota',22039,41);
INSERT INTO "django_geo_db_city" VALUES(17769,'Easton','Easton, Minnesota',22040,41);
INSERT INTO "django_geo_db_city" VALUES(17770,'Ellendale','Ellendale, Minnesota',22041,41);
INSERT INTO "django_geo_db_city" VALUES(17771,'Elmore','Elmore, Iowa',22042,19);
INSERT INTO "django_geo_db_city" VALUES(17772,'Elysian','Elysian, Minnesota',22043,41);
INSERT INTO "django_geo_db_city" VALUES(17773,'Emmons','Emmons, Minnesota',22044,41);
INSERT INTO "django_geo_db_city" VALUES(17774,'Essig','Essig, Minnesota',22045,41);
INSERT INTO "django_geo_db_city" VALUES(17775,'Fairmont','Fairmont, Minnesota',22046,41);
INSERT INTO "django_geo_db_city" VALUES(17776,'Freeborn','Freeborn, Minnesota',22047,41);
INSERT INTO "django_geo_db_city" VALUES(17777,'Frost','Frost, Minnesota',22048,41);
INSERT INTO "django_geo_db_city" VALUES(17778,'Garden City','Garden City, Minnesota',22049,41);
INSERT INTO "django_geo_db_city" VALUES(17779,'Geneva','Geneva, Minnesota',22050,41);
INSERT INTO "django_geo_db_city" VALUES(17780,'Glenville','Glenville, Minnesota',22051,41);
INSERT INTO "django_geo_db_city" VALUES(17781,'Good Thunder','Good Thunder, Minnesota',22052,41);
INSERT INTO "django_geo_db_city" VALUES(17782,'Granada','Granada, Minnesota',22053,41);
INSERT INTO "django_geo_db_city" VALUES(17783,'Hanska','Hanska, Minnesota',22054,41);
INSERT INTO "django_geo_db_city" VALUES(17784,'Hartland','Hartland, Minnesota',22055,41);
INSERT INTO "django_geo_db_city" VALUES(17785,'Hayward','Hayward, Minnesota',22056,41);
INSERT INTO "django_geo_db_city" VALUES(17786,'Henderson','Henderson, Minnesota',22057,41);
INSERT INTO "django_geo_db_city" VALUES(17787,'Hollandale','Hollandale, Minnesota',22058,41);
INSERT INTO "django_geo_db_city" VALUES(17788,'Hope','Hope, Minnesota',22059,41);
INSERT INTO "django_geo_db_city" VALUES(17789,'Huntley','Huntley, Minnesota',22060,41);
INSERT INTO "django_geo_db_city" VALUES(17790,'Janesville','Janesville, Minnesota',22061,41);
INSERT INTO "django_geo_db_city" VALUES(17791,'Kasota','Kasota, Minnesota',22062,41);
INSERT INTO "django_geo_db_city" VALUES(17792,'Kiester','Kiester, Minnesota',22063,41);
INSERT INTO "django_geo_db_city" VALUES(17793,'Kilkenny','Kilkenny, Minnesota',22064,41);
INSERT INTO "django_geo_db_city" VALUES(17794,'Lafayette','Lafayette, Minnesota',22065,41);
INSERT INTO "django_geo_db_city" VALUES(17795,'Lake Crystal','Lake Crystal, Minnesota',22066,41);
INSERT INTO "django_geo_db_city" VALUES(17796,'La Salle','La Salle, Minnesota',22067,41);
INSERT INTO "django_geo_db_city" VALUES(17797,'Le Center','Le Center, Minnesota',22068,41);
INSERT INTO "django_geo_db_city" VALUES(17798,'Le Sueur','Le Sueur, Minnesota',22069,41);
INSERT INTO "django_geo_db_city" VALUES(17799,'Lewisville','Lewisville, Minnesota',22070,41);
INSERT INTO "django_geo_db_city" VALUES(17800,'Madelia','Madelia, Minnesota',22071,41);
INSERT INTO "django_geo_db_city" VALUES(17801,'Madison Lake','Madison Lake, Minnesota',22072,41);
INSERT INTO "django_geo_db_city" VALUES(17802,'Manchester','Manchester, Minnesota',22073,41);
INSERT INTO "django_geo_db_city" VALUES(17803,'Mapleton','Mapleton, Minnesota',22074,41);
INSERT INTO "django_geo_db_city" VALUES(17804,'Minnesota Lake','Minnesota Lake, Minnesota',22075,41);
INSERT INTO "django_geo_db_city" VALUES(17805,'Montgomery','Montgomery, Minnesota',22076,41);
INSERT INTO "django_geo_db_city" VALUES(17806,'New Prague','New Prague, Minnesota',22077,41);
INSERT INTO "django_geo_db_city" VALUES(17807,'New Richland','New Richland, Minnesota',22078,41);
INSERT INTO "django_geo_db_city" VALUES(17808,'New Ulm','New Ulm, Minnesota',22079,41);
INSERT INTO "django_geo_db_city" VALUES(17809,'Nicollet','Nicollet, Minnesota',22080,41);
INSERT INTO "django_geo_db_city" VALUES(17810,'Northrop','Northrop, Minnesota',22081,41);
INSERT INTO "django_geo_db_city" VALUES(17811,'Oakland','Oakland, Minnesota',22082,41);
INSERT INTO "django_geo_db_city" VALUES(17812,'Pemberton','Pemberton, Minnesota',22083,41);
INSERT INTO "django_geo_db_city" VALUES(17813,'Saint Clair','Saint Clair, Minnesota',22084,41);
INSERT INTO "django_geo_db_city" VALUES(17814,'Saint James','Saint James, Minnesota',22085,41);
INSERT INTO "django_geo_db_city" VALUES(17815,'Saint Peter','Saint Peter, Minnesota',22086,41);
INSERT INTO "django_geo_db_city" VALUES(17816,'Sanborn','Sanborn, Minnesota',22087,41);
INSERT INTO "django_geo_db_city" VALUES(17817,'Searles','Searles, Minnesota',22088,41);
INSERT INTO "django_geo_db_city" VALUES(17818,'Sleepy Eye','Sleepy Eye, Minnesota',22089,41);
INSERT INTO "django_geo_db_city" VALUES(17819,'Springfield','Springfield, Minnesota',22090,41);
INSERT INTO "django_geo_db_city" VALUES(17820,'Truman','Truman, Minnesota',22091,41);
INSERT INTO "django_geo_db_city" VALUES(17821,'Twin Lakes','Twin Lakes, Minnesota',22092,41);
INSERT INTO "django_geo_db_city" VALUES(17822,'Vernon Center','Vernon Center, Minnesota',22093,41);
INSERT INTO "django_geo_db_city" VALUES(17823,'Waldorf','Waldorf, Minnesota',22094,41);
INSERT INTO "django_geo_db_city" VALUES(17824,'Waseca','Waseca, Minnesota',22095,41);
INSERT INTO "django_geo_db_city" VALUES(17825,'Waterville','Waterville, Minnesota',22096,41);
INSERT INTO "django_geo_db_city" VALUES(17826,'Wells','Wells, Minnesota',22097,41);
INSERT INTO "django_geo_db_city" VALUES(17827,'Winnebago','Winnebago, Minnesota',22098,41);
INSERT INTO "django_geo_db_city" VALUES(17828,'Windom','Windom, Minnesota',22099,41);
INSERT INTO "django_geo_db_city" VALUES(17829,'Adrian','Adrian, Minnesota',22100,41);
INSERT INTO "django_geo_db_city" VALUES(17830,'Alpha','Alpha, Minnesota',22101,41);
INSERT INTO "django_geo_db_city" VALUES(17831,'Arco','Arco, Minnesota',22102,41);
INSERT INTO "django_geo_db_city" VALUES(17832,'Avoca','Avoca, Minnesota',22103,41);
INSERT INTO "django_geo_db_city" VALUES(17833,'Balaton','Balaton, Minnesota',22104,41);
INSERT INTO "django_geo_db_city" VALUES(17834,'Beaver Creek','Beaver Creek, Minnesota',22105,41);
INSERT INTO "django_geo_db_city" VALUES(17835,'Bigelow','Bigelow, Minnesota',22106,41);
INSERT INTO "django_geo_db_city" VALUES(17836,'Bingham Lake','Bingham Lake, Minnesota',22107,41);
INSERT INTO "django_geo_db_city" VALUES(17837,'Brewster','Brewster, Minnesota',22108,41);
INSERT INTO "django_geo_db_city" VALUES(17838,'Butterfield','Butterfield, Minnesota',22109,41);
INSERT INTO "django_geo_db_city" VALUES(17839,'Ceylon','Ceylon, Minnesota',22110,41);
INSERT INTO "django_geo_db_city" VALUES(17840,'Chandler','Chandler, Minnesota',22111,41);
INSERT INTO "django_geo_db_city" VALUES(17841,'Currie','Currie, Minnesota',22112,41);
INSERT INTO "django_geo_db_city" VALUES(17842,'Dovray','Dovray, Minnesota',22113,41);
INSERT INTO "django_geo_db_city" VALUES(17843,'Graham Lakes','Graham Lakes, Minnesota',22114,41);
INSERT INTO "django_geo_db_city" VALUES(17844,'Dunnell','Dunnell, Minnesota',22115,41);
INSERT INTO "django_geo_db_city" VALUES(17845,'Edgerton','Edgerton, Minnesota',22116,41);
INSERT INTO "django_geo_db_city" VALUES(17846,'Florence','Florence, Minnesota',22118,41);
INSERT INTO "django_geo_db_city" VALUES(17847,'Fulda','Fulda, Minnesota',22119,41);
INSERT INTO "django_geo_db_city" VALUES(17848,'Garvin','Garvin, Minnesota',22120,41);
INSERT INTO "django_geo_db_city" VALUES(17849,'Hardwick','Hardwick, Minnesota',22121,41);
INSERT INTO "django_geo_db_city" VALUES(17850,'Powers','Powers, Minnesota',22122,41);
INSERT INTO "django_geo_db_city" VALUES(17851,'Hendricks','Hendricks, Minnesota',22123,41);
INSERT INTO "django_geo_db_city" VALUES(17852,'Heron Lake','Heron Lake, Minnesota',22124,41);
INSERT INTO "django_geo_db_city" VALUES(17853,'Hills','Hills, Minnesota',22125,41);
INSERT INTO "django_geo_db_city" VALUES(17854,'Holland','Holland, Minnesota',22126,41);
INSERT INTO "django_geo_db_city" VALUES(17855,'Ihlen','Ihlen, Minnesota',22127,41);
INSERT INTO "django_geo_db_city" VALUES(17856,'Iona','Iona, Minnesota',22128,41);
INSERT INTO "django_geo_db_city" VALUES(17857,'Ivanhoe','Ivanhoe, Minnesota',22129,41);
INSERT INTO "django_geo_db_city" VALUES(17858,'Jackson','Jackson, Minnesota',22130,41);
INSERT INTO "django_geo_db_city" VALUES(17859,'Jasper','Jasper, Minnesota',22131,41);
INSERT INTO "django_geo_db_city" VALUES(17860,'Jeffers','Jeffers, Minnesota',22132,41);
INSERT INTO "django_geo_db_city" VALUES(17861,'Kanaranzi','Kanaranzi, Minnesota',22133,41);
INSERT INTO "django_geo_db_city" VALUES(17862,'Kenneth','Kenneth, Minnesota',22134,41);
INSERT INTO "django_geo_db_city" VALUES(17863,'Lake Benton','Lake Benton, Minnesota',22135,41);
INSERT INTO "django_geo_db_city" VALUES(17864,'Lakefield','Lakefield, Minnesota',22136,41);
INSERT INTO "django_geo_db_city" VALUES(17865,'Lake Wilson','Lake Wilson, Minnesota',22137,41);
INSERT INTO "django_geo_db_city" VALUES(17866,'Lamberton','Lamberton, Minnesota',22138,41);
INSERT INTO "django_geo_db_city" VALUES(17867,'Leota','Leota, Minnesota',22139,41);
INSERT INTO "django_geo_db_city" VALUES(17868,'Lismore','Lismore, Minnesota',22140,41);
INSERT INTO "django_geo_db_city" VALUES(17869,'Luverne','Luverne, Minnesota',22141,41);
INSERT INTO "django_geo_db_city" VALUES(17870,'Lynd','Lynd, Minnesota',22142,41);
INSERT INTO "django_geo_db_city" VALUES(17871,'Magnolia','Magnolia, Minnesota',22143,41);
INSERT INTO "django_geo_db_city" VALUES(17872,'Mountain Lake','Mountain Lake, Minnesota',22144,41);
INSERT INTO "django_geo_db_city" VALUES(17873,'Odin','Odin, Minnesota',22145,41);
INSERT INTO "django_geo_db_city" VALUES(17874,'Okabena','Okabena, Minnesota',22146,41);
INSERT INTO "django_geo_db_city" VALUES(17875,'Ormsby','Ormsby, Minnesota',22147,41);
INSERT INTO "django_geo_db_city" VALUES(17876,'Pipestone','Pipestone, Minnesota',22148,41);
INSERT INTO "django_geo_db_city" VALUES(17877,'Reading','Reading, Minnesota',22149,41);
INSERT INTO "django_geo_db_city" VALUES(17878,'Revere','Revere, Minnesota',22150,41);
INSERT INTO "django_geo_db_city" VALUES(17879,'Round Lake','Round Lake, Minnesota',22151,41);
INSERT INTO "django_geo_db_city" VALUES(17880,'Rushmore','Rushmore, Minnesota',22152,41);
INSERT INTO "django_geo_db_city" VALUES(17881,'Russell','Russell, Minnesota',22153,41);
INSERT INTO "django_geo_db_city" VALUES(17882,'Ruthton','Ruthton, Minnesota',22154,41);
INSERT INTO "django_geo_db_city" VALUES(17883,'Sherburn','Sherburn, Minnesota',22155,41);
INSERT INTO "django_geo_db_city" VALUES(17884,'Slayton','Slayton, Minnesota',22156,41);
INSERT INTO "django_geo_db_city" VALUES(17885,'Steen','Steen, Minnesota',22157,41);
INSERT INTO "django_geo_db_city" VALUES(17886,'Storden','Storden, Minnesota',22158,41);
INSERT INTO "django_geo_db_city" VALUES(17887,'Tracy','Tracy, Minnesota',22159,41);
INSERT INTO "django_geo_db_city" VALUES(17888,'Trimont','Trimont, Minnesota',22160,41);
INSERT INTO "django_geo_db_city" VALUES(17889,'Trosky','Trosky, Minnesota',22161,41);
INSERT INTO "django_geo_db_city" VALUES(17890,'Tyler','Tyler, Minnesota',22162,41);
INSERT INTO "django_geo_db_city" VALUES(17891,'Walnut Grove','Walnut Grove, Minnesota',22163,41);
INSERT INTO "django_geo_db_city" VALUES(17892,'Welcome','Welcome, Minnesota',22164,41);
INSERT INTO "django_geo_db_city" VALUES(17893,'Westbrook','Westbrook, Minnesota',22165,41);
INSERT INTO "django_geo_db_city" VALUES(17894,'Wilmont','Wilmont, Minnesota',22166,41);
INSERT INTO "django_geo_db_city" VALUES(17895,'Woodstock','Woodstock, Minnesota',22167,41);
INSERT INTO "django_geo_db_city" VALUES(17896,'Worthington','Worthington, Minnesota',22168,41);
INSERT INTO "django_geo_db_city" VALUES(17897,'Willmar','Willmar, Minnesota',22169,41);
INSERT INTO "django_geo_db_city" VALUES(17898,'Alberta','Alberta, Minnesota',22170,41);
INSERT INTO "django_geo_db_city" VALUES(17899,'Appleton','Appleton, Minnesota',22171,41);
INSERT INTO "django_geo_db_city" VALUES(17900,'Atwater','Atwater, Minnesota',22172,41);
INSERT INTO "django_geo_db_city" VALUES(17901,'Barry','Barry, Minnesota',22173,41);
INSERT INTO "django_geo_db_city" VALUES(17902,'Beardsley','Beardsley, Minnesota',22174,41);
INSERT INTO "django_geo_db_city" VALUES(17903,'Bellingham','Bellingham, Minnesota',22175,41);
INSERT INTO "django_geo_db_city" VALUES(17904,'Belview','Belview, Minnesota',22176,41);
INSERT INTO "django_geo_db_city" VALUES(17905,'Benson','Benson, Minnesota',22177,41);
INSERT INTO "django_geo_db_city" VALUES(17906,'Blomkest','Blomkest, Minnesota',22178,41);
INSERT INTO "django_geo_db_city" VALUES(17907,'Boyd','Boyd, Minnesota',22179,41);
INSERT INTO "django_geo_db_city" VALUES(17908,'Browns Valley','Browns Valley, Minnesota',22180,41);
INSERT INTO "django_geo_db_city" VALUES(17909,'Canby','Canby, Minnesota',22181,41);
INSERT INTO "django_geo_db_city" VALUES(17910,'Chokio','Chokio, Minnesota',22182,41);
INSERT INTO "django_geo_db_city" VALUES(17911,'Clara City','Clara City, Minnesota',22183,41);
INSERT INTO "django_geo_db_city" VALUES(17912,'Clarkfield','Clarkfield, Minnesota',22184,41);
INSERT INTO "django_geo_db_city" VALUES(17913,'Clements','Clements, Minnesota',22185,41);
INSERT INTO "django_geo_db_city" VALUES(17914,'Clinton','Clinton, Minnesota',22186,41);
INSERT INTO "django_geo_db_city" VALUES(17915,'Clontarf','Clontarf, Minnesota',22187,41);
INSERT INTO "django_geo_db_city" VALUES(17916,'Correll','Correll, Minnesota',22188,41);
INSERT INTO "django_geo_db_city" VALUES(17917,'Cosmos','Cosmos, Minnesota',22189,41);
INSERT INTO "django_geo_db_city" VALUES(17918,'Cottonwood','Cottonwood, Minnesota',22190,41);
INSERT INTO "django_geo_db_city" VALUES(17919,'Danube','Danube, Minnesota',22191,41);
INSERT INTO "django_geo_db_city" VALUES(17920,'Danvers','Danvers, Minnesota',22192,41);
INSERT INTO "django_geo_db_city" VALUES(17921,'Dawson','Dawson, Minnesota',22193,41);
INSERT INTO "django_geo_db_city" VALUES(17922,'Donnelly','Donnelly, Minnesota',22194,41);
INSERT INTO "django_geo_db_city" VALUES(17923,'Dumont','Dumont, Minnesota',22195,41);
INSERT INTO "django_geo_db_city" VALUES(17924,'Echo','Echo, Minnesota',22196,41);
INSERT INTO "django_geo_db_city" VALUES(17925,'Ghent','Ghent, Minnesota',22197,41);
INSERT INTO "django_geo_db_city" VALUES(17926,'Graceville','Graceville, Minnesota',22198,41);
INSERT INTO "django_geo_db_city" VALUES(17927,'Granite Falls','Granite Falls, Minnesota',22199,41);
INSERT INTO "django_geo_db_city" VALUES(17928,'Grove City','Grove City, Minnesota',22200,41);
INSERT INTO "django_geo_db_city" VALUES(17929,'Hancock','Hancock, Minnesota',22201,41);
INSERT INTO "django_geo_db_city" VALUES(17930,'Hanley Falls','Hanley Falls, Minnesota',22202,41);
INSERT INTO "django_geo_db_city" VALUES(17931,'Hawick','Hawick, Minnesota',22203,41);
INSERT INTO "django_geo_db_city" VALUES(17932,'Herman','Herman, Minnesota',22204,41);
INSERT INTO "django_geo_db_city" VALUES(17933,'Holloway','Holloway, Minnesota',22205,41);
INSERT INTO "django_geo_db_city" VALUES(17934,'Kandiyohi','Kandiyohi, Minnesota',22206,41);
INSERT INTO "django_geo_db_city" VALUES(17935,'Kerkhoven','Kerkhoven, Minnesota',22207,41);
INSERT INTO "django_geo_db_city" VALUES(17936,'Lake Lillian','Lake Lillian, Minnesota',22208,41);
INSERT INTO "django_geo_db_city" VALUES(17937,'Lucan','Lucan, Minnesota',22209,41);
INSERT INTO "django_geo_db_city" VALUES(17938,'Madison','Madison, Minnesota',22210,41);
INSERT INTO "django_geo_db_city" VALUES(17939,'Marietta','Marietta, Minnesota',22211,41);
INSERT INTO "django_geo_db_city" VALUES(17940,'Marshall','Marshall, Minnesota',22212,41);
INSERT INTO "django_geo_db_city" VALUES(17941,'Maynard','Maynard, Minnesota',22213,41);
INSERT INTO "django_geo_db_city" VALUES(17942,'Milan','Milan, Minnesota',22214,41);
INSERT INTO "django_geo_db_city" VALUES(17943,'Milroy','Milroy, Minnesota',22215,41);
INSERT INTO "django_geo_db_city" VALUES(17944,'Minneota','Minneota, Minnesota',22216,41);
INSERT INTO "django_geo_db_city" VALUES(17945,'Montevideo','Montevideo, Minnesota',22217,41);
INSERT INTO "django_geo_db_city" VALUES(17946,'Morgan','Morgan, Minnesota',22218,41);
INSERT INTO "django_geo_db_city" VALUES(17947,'Morris','Morris, Minnesota',22219,41);
INSERT INTO "django_geo_db_city" VALUES(17948,'Morton','Morton, Minnesota',22220,41);
INSERT INTO "django_geo_db_city" VALUES(17949,'Murdock','Murdock, Minnesota',22221,41);
INSERT INTO "django_geo_db_city" VALUES(17950,'New London','New London, Minnesota',22222,41);
INSERT INTO "django_geo_db_city" VALUES(17951,'Norcross','Norcross, Minnesota',22223,41);
INSERT INTO "django_geo_db_city" VALUES(17952,'Odessa','Odessa, Minnesota',22224,41);
INSERT INTO "django_geo_db_city" VALUES(17953,'Olivia','Olivia, Minnesota',22225,41);
INSERT INTO "django_geo_db_city" VALUES(17954,'Ortonville','Ortonville, Minnesota',22226,41);
INSERT INTO "django_geo_db_city" VALUES(17955,'Pennock','Pennock, Minnesota',22227,41);
INSERT INTO "django_geo_db_city" VALUES(17956,'Porter','Porter, Minnesota',22228,41);
INSERT INTO "django_geo_db_city" VALUES(17957,'Prinsburg','Prinsburg, Minnesota',22229,41);
INSERT INTO "django_geo_db_city" VALUES(17958,'Raymond','Raymond, Minnesota',22230,41);
INSERT INTO "django_geo_db_city" VALUES(17959,'Redwood Falls','Redwood Falls, Minnesota',22231,41);
INSERT INTO "django_geo_db_city" VALUES(17960,'Renville','Renville, Minnesota',22232,41);
INSERT INTO "django_geo_db_city" VALUES(17961,'Sacred Heart','Sacred Heart, Minnesota',22233,41);
INSERT INTO "django_geo_db_city" VALUES(17962,'St. Leo','St. Leo, Minnesota',22234,41);
INSERT INTO "django_geo_db_city" VALUES(17963,'Seaforth','Seaforth, Minnesota',22235,41);
INSERT INTO "django_geo_db_city" VALUES(17964,'Spicer','Spicer, Minnesota',22236,41);
INSERT INTO "django_geo_db_city" VALUES(17965,'Sunburg','Sunburg, Minnesota',22237,41);
INSERT INTO "django_geo_db_city" VALUES(17966,'Taunton','Taunton, Minnesota',22238,41);
INSERT INTO "django_geo_db_city" VALUES(17967,'Vesta','Vesta, Minnesota',22239,41);
INSERT INTO "django_geo_db_city" VALUES(17968,'Wabasso','Wabasso, Minnesota',22240,41);
INSERT INTO "django_geo_db_city" VALUES(17969,'Wanda','Wanda, Minnesota',22241,41);
INSERT INTO "django_geo_db_city" VALUES(17970,'Watson','Watson, Minnesota',22242,41);
INSERT INTO "django_geo_db_city" VALUES(17971,'Wheaton','Wheaton, Minnesota',22243,41);
INSERT INTO "django_geo_db_city" VALUES(17972,'Wood Lake','Wood Lake, Minnesota',22244,41);
INSERT INTO "django_geo_db_city" VALUES(17973,'Saint Cloud','Saint Cloud, Minnesota',22245,41);
INSERT INTO "django_geo_db_city" VALUES(17974,'Albany','Albany, Minnesota',22249,41);
INSERT INTO "django_geo_db_city" VALUES(17975,'Alexandria','Alexandria, Minnesota',22250,41);
INSERT INTO "django_geo_db_city" VALUES(17976,'Ashby','Ashby, Minnesota',22251,41);
INSERT INTO "django_geo_db_city" VALUES(17977,'Avon','Avon, Minnesota',22252,41);
INSERT INTO "django_geo_db_city" VALUES(17978,'Barrett','Barrett, Minnesota',22253,41);
INSERT INTO "django_geo_db_city" VALUES(17979,'Belgrade','Belgrade, Minnesota',22254,41);
INSERT INTO "django_geo_db_city" VALUES(17980,'Bock','Bock, Minnesota',22255,41);
INSERT INTO "django_geo_db_city" VALUES(17981,'Bowlus','Bowlus, Minnesota',22256,41);
INSERT INTO "django_geo_db_city" VALUES(17982,'Brandon','Brandon, Minnesota',22257,41);
INSERT INTO "django_geo_db_city" VALUES(17983,'Brooten','Brooten, Minnesota',22258,41);
INSERT INTO "django_geo_db_city" VALUES(17984,'Buckman','Buckman, Minnesota',22259,41);
INSERT INTO "django_geo_db_city" VALUES(17985,'Burtrum','Burtrum, Minnesota',22260,41);
INSERT INTO "django_geo_db_city" VALUES(17986,'Carlos','Carlos, Minnesota',22261,41);
INSERT INTO "django_geo_db_city" VALUES(17987,'Cold Spring','Cold Spring, Minnesota',22262,41);
INSERT INTO "django_geo_db_city" VALUES(17988,'Collegeville','Collegeville, Minnesota',22263,41);
INSERT INTO "django_geo_db_city" VALUES(17989,'Cyrus','Cyrus, Minnesota',22264,41);
INSERT INTO "django_geo_db_city" VALUES(17990,'Dalton','Dalton, Minnesota',22265,41);
INSERT INTO "django_geo_db_city" VALUES(17991,'Elrosa','Elrosa, Minnesota',22266,41);
INSERT INTO "django_geo_db_city" VALUES(17992,'Evansville','Evansville, Minnesota',22267,41);
INSERT INTO "django_geo_db_city" VALUES(17993,'Farwell','Farwell, Minnesota',22268,41);
INSERT INTO "django_geo_db_city" VALUES(17994,'Flensburg','Flensburg, Minnesota',22269,41);
INSERT INTO "django_geo_db_city" VALUES(17995,'Foley','Foley, Minnesota',22270,41);
INSERT INTO "django_geo_db_city" VALUES(17996,'Foreston','Foreston, Minnesota',22271,41);
INSERT INTO "django_geo_db_city" VALUES(17997,'Freeport','Freeport, Minnesota',22272,41);
INSERT INTO "django_geo_db_city" VALUES(17998,'Garfield','Garfield, Minnesota',22273,41);
INSERT INTO "django_geo_db_city" VALUES(17999,'Gilman','Gilman, Minnesota',22274,41);
INSERT INTO "django_geo_db_city" VALUES(18000,'Glenwood','Glenwood, Minnesota',22275,41);
INSERT INTO "django_geo_db_city" VALUES(18001,'Greenwald','Greenwald, Minnesota',22276,41);
INSERT INTO "django_geo_db_city" VALUES(18002,'Grey Eagle','Grey Eagle, Minnesota',22277,41);
INSERT INTO "django_geo_db_city" VALUES(18003,'Hillman','Hillman, Minnesota',22278,41);
INSERT INTO "django_geo_db_city" VALUES(18004,'Hoffman','Hoffman, Minnesota',22279,41);
INSERT INTO "django_geo_db_city" VALUES(18005,'Holdingford','Holdingford, Minnesota',22280,41);
INSERT INTO "django_geo_db_city" VALUES(18006,'Holmes City','Holmes City, Minnesota',22281,41);
INSERT INTO "django_geo_db_city" VALUES(18007,'Isle','Isle, Minnesota',22282,41);
INSERT INTO "django_geo_db_city" VALUES(18008,'Kensington','Kensington, Minnesota',22283,41);
INSERT INTO "django_geo_db_city" VALUES(18009,'Lastrup','Lastrup, Minnesota',22259,41);
INSERT INTO "django_geo_db_city" VALUES(18010,'Little Falls','Little Falls, Minnesota',22284,41);
INSERT INTO "django_geo_db_city" VALUES(18011,'Long Prairie','Long Prairie, Minnesota',22285,41);
INSERT INTO "django_geo_db_city" VALUES(18012,'Lowry','Lowry, Minnesota',22286,41);
INSERT INTO "django_geo_db_city" VALUES(18013,'McGrath','McGrath, Minnesota',22287,41);
INSERT INTO "django_geo_db_city" VALUES(18014,'Melrose','Melrose, Minnesota',22288,41);
INSERT INTO "django_geo_db_city" VALUES(18015,'Milaca','Milaca, Minnesota',22289,41);
INSERT INTO "django_geo_db_city" VALUES(18016,'Miltona','Miltona, Minnesota',22290,41);
INSERT INTO "django_geo_db_city" VALUES(18017,'Nelson','Nelson, Minnesota',22291,41);
INSERT INTO "django_geo_db_city" VALUES(18018,'New Munich','New Munich, Minnesota',22292,41);
INSERT INTO "django_geo_db_city" VALUES(18019,'Oak Park','Oak Park, Minnesota',22293,41);
INSERT INTO "django_geo_db_city" VALUES(18020,'Ogilvie','Ogilvie, Minnesota',22294,41);
INSERT INTO "django_geo_db_city" VALUES(18021,'Onamia','Onamia, Minnesota',22295,41);
INSERT INTO "django_geo_db_city" VALUES(18022,'Osakis','Osakis, Minnesota',22296,41);
INSERT INTO "django_geo_db_city" VALUES(18023,'Parkers Prairie','Parkers Prairie, Minnesota',22297,41);
INSERT INTO "django_geo_db_city" VALUES(18024,'Paynesville','Paynesville, Minnesota',22298,41);
INSERT INTO "django_geo_db_city" VALUES(18025,'Pease','Pease, Minnesota',22299,41);
INSERT INTO "django_geo_db_city" VALUES(18026,'Pierz','Pierz, Minnesota',22300,41);
INSERT INTO "django_geo_db_city" VALUES(18027,'Bowstring','Bowstring, Minnesota',22301,41);
INSERT INTO "django_geo_db_city" VALUES(18028,'Rice','Rice, Minnesota',22302,41);
INSERT INTO "django_geo_db_city" VALUES(18029,'Richmond','Richmond, Minnesota',22303,41);
INSERT INTO "django_geo_db_city" VALUES(18030,'Rockville','Rockville, Minnesota',22304,41);
INSERT INTO "django_geo_db_city" VALUES(18031,'Roscoe','Roscoe, Minnesota',22305,41);
INSERT INTO "django_geo_db_city" VALUES(18032,'Royalton','Royalton, Minnesota',22307,41);
INSERT INTO "django_geo_db_city" VALUES(18033,'Saint Joseph','Saint Joseph, Minnesota',22308,41);
INSERT INTO "django_geo_db_city" VALUES(18034,'Saint Stephen','Saint Stephen, Minnesota',22309,41);
INSERT INTO "django_geo_db_city" VALUES(18035,'Saint Martin','Saint Martin, Minnesota',22310,41);
INSERT INTO "django_geo_db_city" VALUES(18036,'Sartell','Sartell, Minnesota',22311,41);
INSERT INTO "django_geo_db_city" VALUES(18037,'Sauk Centre','Sauk Centre, Minnesota',22312,41);
INSERT INTO "django_geo_db_city" VALUES(18038,'Sauk Rapids','Sauk Rapids, Minnesota',22313,41);
INSERT INTO "django_geo_db_city" VALUES(18039,'Starbuck','Starbuck, Minnesota',22314,41);
INSERT INTO "django_geo_db_city" VALUES(18040,'Swanville','Swanville, Minnesota',22315,41);
INSERT INTO "django_geo_db_city" VALUES(18041,'Upsala','Upsala, Minnesota',22316,41);
INSERT INTO "django_geo_db_city" VALUES(18042,'Villard','Villard, Minnesota',22317,41);
INSERT INTO "django_geo_db_city" VALUES(18043,'Wahkon','Wahkon, Minnesota',22318,41);
INSERT INTO "django_geo_db_city" VALUES(18044,'Waite Park','Waite Park, Minnesota',22319,41);
INSERT INTO "django_geo_db_city" VALUES(18045,'Mount Morris','Mount Morris, Minnesota',22320,41);
INSERT INTO "django_geo_db_city" VALUES(18046,'West Union','West Union, Minnesota',22321,41);
INSERT INTO "django_geo_db_city" VALUES(18047,'Brainerd','Brainerd, Minnesota',22322,41);
INSERT INTO "django_geo_db_city" VALUES(18048,'Baxter','Baxter, Minnesota',22323,41);
INSERT INTO "django_geo_db_city" VALUES(18049,'Ah Gwah Ching','Ah Gwah Ching, Minnesota',22324,41);
INSERT INTO "django_geo_db_city" VALUES(18050,'Aitkin','Aitkin, Minnesota',22325,41);
INSERT INTO "django_geo_db_city" VALUES(18051,'Acton','Acton, Minnesota',22326,41);
INSERT INTO "django_geo_db_city" VALUES(18052,'Akeley','Akeley, Minnesota',22327,41);
INSERT INTO "django_geo_db_city" VALUES(18053,'Aldrich','Aldrich, Minnesota',22328,41);
INSERT INTO "django_geo_db_city" VALUES(18054,'Backus','Backus, Minnesota',22329,41);
INSERT INTO "django_geo_db_city" VALUES(18055,'Benedict','Benedict, Minnesota',22330,41);
INSERT INTO "django_geo_db_city" VALUES(18056,'Bertha','Bertha, Minnesota',22331,41);
INSERT INTO "django_geo_db_city" VALUES(18057,'Browerville','Browerville, Minnesota',22332,41);
INSERT INTO "django_geo_db_city" VALUES(18058,'Clarissa','Clarissa, Minnesota',22333,41);
INSERT INTO "django_geo_db_city" VALUES(18059,'Crosby','Crosby, Minnesota',22334,41);
INSERT INTO "django_geo_db_city" VALUES(18060,'Crosslake','Crosslake, Minnesota',22335,41);
INSERT INTO "django_geo_db_city" VALUES(18061,'Cushing','Cushing, Minnesota',22336,41);
INSERT INTO "django_geo_db_city" VALUES(18062,'Deerwood','Deerwood, Minnesota',22337,41);
INSERT INTO "django_geo_db_city" VALUES(18063,'Eagle Bend','Eagle Bend, Minnesota',22338,41);
INSERT INTO "django_geo_db_city" VALUES(18064,'Emily','Emily, Minnesota',22339,41);
INSERT INTO "django_geo_db_city" VALUES(18065,'Fifty Lakes','Fifty Lakes, Minnesota',22340,41);
INSERT INTO "django_geo_db_city" VALUES(18066,'Fort Ripley','Fort Ripley, Minnesota',22341,41);
INSERT INTO "django_geo_db_city" VALUES(18067,'Garrison','Garrison, Minnesota',22342,41);
INSERT INTO "django_geo_db_city" VALUES(18068,'Hackensack','Hackensack, Minnesota',22343,41);
INSERT INTO "django_geo_db_city" VALUES(18069,'Hewitt','Hewitt, Minnesota',22344,41);
INSERT INTO "django_geo_db_city" VALUES(18070,'Ironton','Ironton, Minnesota',22345,41);
INSERT INTO "django_geo_db_city" VALUES(18071,'Jenkins','Jenkins, Minnesota',22346,41);
INSERT INTO "django_geo_db_city" VALUES(18072,'Lake George','Lake George, Minnesota',22347,41);
INSERT INTO "django_geo_db_city" VALUES(18073,'Lake Hubert','Lake Hubert, Minnesota',22348,41);
INSERT INTO "django_geo_db_city" VALUES(18074,'Itasca','Itasca, Minnesota',22349,41);
INSERT INTO "django_geo_db_city" VALUES(18075,'Laporte','Laporte, Minnesota',22350,41);
INSERT INTO "django_geo_db_city" VALUES(18076,'Menahga','Menahga, Minnesota',22351,41);
INSERT INTO "django_geo_db_city" VALUES(18077,'Merrifield','Merrifield, Minnesota',22352,41);
INSERT INTO "django_geo_db_city" VALUES(18078,'Motley','Motley, Minnesota',22353,41);
INSERT INTO "django_geo_db_city" VALUES(18079,'Nevis','Nevis, Minnesota',22354,41);
INSERT INTO "django_geo_db_city" VALUES(18080,'Nisswa','Nisswa, Minnesota',22355,41);
INSERT INTO "django_geo_db_city" VALUES(18081,'Palisade','Palisade, Minnesota',22356,41);
INSERT INTO "django_geo_db_city" VALUES(18082,'Park Rapids','Park Rapids, Minnesota',22357,41);
INSERT INTO "django_geo_db_city" VALUES(18083,'Pequot Lakes','Pequot Lakes, Minnesota',22358,41);
INSERT INTO "django_geo_db_city" VALUES(18084,'Pillager','Pillager, Minnesota',22359,41);
INSERT INTO "django_geo_db_city" VALUES(18085,'Pine River','Pine River, Minnesota',22360,41);
INSERT INTO "django_geo_db_city" VALUES(18086,'Randall','Randall, Minnesota',22361,41);
INSERT INTO "django_geo_db_city" VALUES(18087,'Sebeka','Sebeka, Minnesota',22362,41);
INSERT INTO "django_geo_db_city" VALUES(18088,'Nimrod','Nimrod, Minnesota',22363,41);
INSERT INTO "django_geo_db_city" VALUES(18089,'Staples','Staples, Minnesota',22364,41);
INSERT INTO "django_geo_db_city" VALUES(18090,'Verndale','Verndale, Minnesota',22365,41);
INSERT INTO "django_geo_db_city" VALUES(18091,'Wadena','Wadena, Minnesota',22366,41);
INSERT INTO "django_geo_db_city" VALUES(18092,'Walker','Walker, Minnesota',22368,41);
INSERT INTO "django_geo_db_city" VALUES(18093,'Detroit Lakes','Detroit Lakes, Minnesota',22369,41);
INSERT INTO "django_geo_db_city" VALUES(18094,'Lake Eunice','Lake Eunice, Minnesota',22371,41);
INSERT INTO "django_geo_db_city" VALUES(18095,'Ada','Ada, Minnesota',22372,41);
INSERT INTO "django_geo_db_city" VALUES(18096,'Audubon','Audubon, Minnesota',22373,41);
INSERT INTO "django_geo_db_city" VALUES(18097,'Baker','Baker, Minnesota',22374,41);
INSERT INTO "django_geo_db_city" VALUES(18098,'Barnesville','Barnesville, Minnesota',22375,41);
INSERT INTO "django_geo_db_city" VALUES(18099,'Battle Lake','Battle Lake, Minnesota',22376,41);
INSERT INTO "django_geo_db_city" VALUES(18100,'Bejou','Bejou, Minnesota',22377,41);
INSERT INTO "django_geo_db_city" VALUES(18101,'Beltrami','Beltrami, Minnesota',22378,41);
INSERT INTO "django_geo_db_city" VALUES(18102,'Bluffton','Bluffton, Minnesota',22379,41);
INSERT INTO "django_geo_db_city" VALUES(18103,'Borup','Borup, Minnesota',22380,41);
INSERT INTO "django_geo_db_city" VALUES(18104,'Breckenridge','Breckenridge, Minnesota',22381,41);
INSERT INTO "django_geo_db_city" VALUES(18105,'Callaway','Callaway, Minnesota',22382,41);
INSERT INTO "django_geo_db_city" VALUES(18106,'Campbell','Campbell, Minnesota',22383,41);
INSERT INTO "django_geo_db_city" VALUES(18107,'Climax','Climax, Minnesota',22384,41);
INSERT INTO "django_geo_db_city" VALUES(18108,'Clitherall','Clitherall, Minnesota',22385,41);
INSERT INTO "django_geo_db_city" VALUES(18109,'Comstock','Comstock, Minnesota',22386,41);
INSERT INTO "django_geo_db_city" VALUES(18110,'Deer Creek','Deer Creek, Minnesota',22387,41);
INSERT INTO "django_geo_db_city" VALUES(18111,'Dent','Dent, Minnesota',22388,41);
INSERT INTO "django_geo_db_city" VALUES(18112,'Dilworth','Dilworth, Minnesota',22389,41);
INSERT INTO "django_geo_db_city" VALUES(18113,'Elbow Lake','Elbow Lake, Minnesota',22390,41);
INSERT INTO "django_geo_db_city" VALUES(18114,'Elizabeth','Elizabeth, Minnesota',22391,41);
INSERT INTO "django_geo_db_city" VALUES(18115,'Erhard','Erhard, Minnesota',22392,41);
INSERT INTO "django_geo_db_city" VALUES(18116,'Erskine','Erskine, Minnesota',22393,41);
INSERT INTO "django_geo_db_city" VALUES(18117,'Felton','Felton, Minnesota',22394,41);
INSERT INTO "django_geo_db_city" VALUES(18118,'Fergus Falls','Fergus Falls, Minnesota',22395,41);
INSERT INTO "django_geo_db_city" VALUES(18119,'Fertile','Fertile, Minnesota',22397,41);
INSERT INTO "django_geo_db_city" VALUES(18120,'Flom','Flom, Minnesota',22398,41);
INSERT INTO "django_geo_db_city" VALUES(18121,'Fosston','Fosston, Minnesota',22399,41);
INSERT INTO "django_geo_db_city" VALUES(18122,'Foxhome','Foxhome, Minnesota',22400,41);
INSERT INTO "django_geo_db_city" VALUES(18123,'Frazee','Frazee, Minnesota',22401,41);
INSERT INTO "django_geo_db_city" VALUES(18124,'Gary','Gary, Minnesota',22402,41);
INSERT INTO "django_geo_db_city" VALUES(18125,'Georgetown','Georgetown, Minnesota',22403,41);
INSERT INTO "django_geo_db_city" VALUES(18126,'Glyndon','Glyndon, Minnesota',22404,41);
INSERT INTO "django_geo_db_city" VALUES(18127,'Halstad','Halstad, Minnesota',22405,41);
INSERT INTO "django_geo_db_city" VALUES(18128,'Hawley','Hawley, Minnesota',22406,41);
INSERT INTO "django_geo_db_city" VALUES(18129,'Hendrum','Hendrum, Minnesota',22407,41);
INSERT INTO "django_geo_db_city" VALUES(18130,'Henning','Henning, Minnesota',22408,41);
INSERT INTO "django_geo_db_city" VALUES(18131,'Hitterdal','Hitterdal, Minnesota',22409,41);
INSERT INTO "django_geo_db_city" VALUES(18132,'Kent','Kent, Minnesota',22410,41);
INSERT INTO "django_geo_db_city" VALUES(18133,'Lake Park','Lake Park, Minnesota',22411,41);
INSERT INTO "django_geo_db_city" VALUES(18134,'Mcintosh','Mcintosh, Minnesota',22412,41);
INSERT INTO "django_geo_db_city" VALUES(18135,'Mahnomen','Mahnomen, Minnesota',22413,41);
INSERT INTO "django_geo_db_city" VALUES(18136,'Moorhead','Moorhead, Minnesota',22414,41);
INSERT INTO "django_geo_db_city" VALUES(18137,'Nashua','Nashua, Minnesota',22416,41);
INSERT INTO "django_geo_db_city" VALUES(18138,'Naytahwaush','Naytahwaush, Minnesota',22417,41);
INSERT INTO "django_geo_db_city" VALUES(18139,'New York Mills','New York Mills, Minnesota',22418,41);
INSERT INTO "django_geo_db_city" VALUES(18140,'Nielsville','Nielsville, Minnesota',22419,41);
INSERT INTO "django_geo_db_city" VALUES(18141,'Ogema','Ogema, Minnesota',22420,41);
INSERT INTO "django_geo_db_city" VALUES(18142,'Osage','Osage, Minnesota',22421,41);
INSERT INTO "django_geo_db_city" VALUES(18143,'Ottertail','Ottertail, Minnesota',22422,41);
INSERT INTO "django_geo_db_city" VALUES(18144,'Pelican Rapids','Pelican Rapids, Minnesota',22423,41);
INSERT INTO "django_geo_db_city" VALUES(18145,'Perham','Perham, Minnesota',22424,41);
INSERT INTO "django_geo_db_city" VALUES(18146,'Perley','Perley, Minnesota',22425,41);
INSERT INTO "django_geo_db_city" VALUES(18147,'Ponsford','Ponsford, Minnesota',22426,41);
INSERT INTO "django_geo_db_city" VALUES(18148,'Richville','Richville, Minnesota',22427,41);
INSERT INTO "django_geo_db_city" VALUES(18149,'Richwood','Richwood, Minnesota',22370,41);
INSERT INTO "django_geo_db_city" VALUES(18150,'Rochert','Rochert, Minnesota',22428,41);
INSERT INTO "django_geo_db_city" VALUES(18151,'Rothsay','Rothsay, Minnesota',22429,41);
INSERT INTO "django_geo_db_city" VALUES(18152,'Sabin','Sabin, Minnesota',22430,41);
INSERT INTO "django_geo_db_city" VALUES(18153,'Shelly','Shelly, Minnesota',22431,41);
INSERT INTO "django_geo_db_city" VALUES(18154,'Tintah','Tintah, Minnesota',22432,41);
INSERT INTO "django_geo_db_city" VALUES(18155,'Twin Valley','Twin Valley, Minnesota',22433,41);
INSERT INTO "django_geo_db_city" VALUES(18156,'Ulen','Ulen, Minnesota',22434,41);
INSERT INTO "django_geo_db_city" VALUES(18157,'Underwood','Underwood, Minnesota',22435,41);
INSERT INTO "django_geo_db_city" VALUES(18158,'Vergas','Vergas, Minnesota',22436,41);
INSERT INTO "django_geo_db_city" VALUES(18159,'Vining','Vining, Minnesota',22437,41);
INSERT INTO "django_geo_db_city" VALUES(18160,'Waubun','Waubun, Minnesota',22438,41);
INSERT INTO "django_geo_db_city" VALUES(18161,'Wendell','Wendell, Minnesota',22439,41);
INSERT INTO "django_geo_db_city" VALUES(18162,'White Earth','White Earth, Minnesota',22370,41);
INSERT INTO "django_geo_db_city" VALUES(18163,'Winger','Winger, Minnesota',22440,41);
INSERT INTO "django_geo_db_city" VALUES(18164,'Wolf Lake','Wolf Lake, Minnesota',22441,41);
INSERT INTO "django_geo_db_city" VALUES(18165,'Wolverton','Wolverton, Minnesota',22442,41);
INSERT INTO "django_geo_db_city" VALUES(18166,'Bemidji','Bemidji, Minnesota',22443,41);
INSERT INTO "django_geo_db_city" VALUES(18167,'Bagley','Bagley, Minnesota',22445,41);
INSERT INTO "django_geo_db_city" VALUES(18168,'Baudette','Baudette, Minnesota',22446,41);
INSERT INTO "django_geo_db_city" VALUES(18169,'Bena','Bena, Minnesota',22447,41);
INSERT INTO "django_geo_db_city" VALUES(18170,'Big Falls','Big Falls, Minnesota',22448,41);
INSERT INTO "django_geo_db_city" VALUES(18171,'Birchdale','Birchdale, Minnesota',22450,41);
INSERT INTO "django_geo_db_city" VALUES(18172,'Blackduck','Blackduck, Minnesota',22451,41);
INSERT INTO "django_geo_db_city" VALUES(18173,'Cass Lake','Cass Lake, Minnesota',22452,41);
INSERT INTO "django_geo_db_city" VALUES(18174,'Clearbrook','Clearbrook, Minnesota',22453,41);
INSERT INTO "django_geo_db_city" VALUES(18175,'Deer River','Deer River, Minnesota',22454,41);
INSERT INTO "django_geo_db_city" VALUES(18176,'Talmoon','Talmoon, Minnesota',22455,41);
INSERT INTO "django_geo_db_city" VALUES(18177,'Effie','Effie, Minnesota',22456,41);
INSERT INTO "django_geo_db_city" VALUES(18178,'Federal Dam','Federal Dam, Minnesota',22457,41);
INSERT INTO "django_geo_db_city" VALUES(18179,'Fleming','Fleming, Minnesota',22458,41);
INSERT INTO "django_geo_db_city" VALUES(18180,'Gonvick','Gonvick, Minnesota',22459,41);
INSERT INTO "django_geo_db_city" VALUES(18181,'Gully','Gully, Minnesota',22460,41);
INSERT INTO "django_geo_db_city" VALUES(18182,'Hines','Hines, Minnesota',22461,41);
INSERT INTO "django_geo_db_city" VALUES(18183,'International Falls','International Falls, Minnesota',22462,41);
INSERT INTO "django_geo_db_city" VALUES(18184,'Kelliher','Kelliher, Minnesota',22463,41);
INSERT INTO "django_geo_db_city" VALUES(18185,'Lengby','Lengby, Minnesota',22464,41);
INSERT INTO "django_geo_db_city" VALUES(18186,'Leonard','Leonard, Minnesota',22465,41);
INSERT INTO "django_geo_db_city" VALUES(18187,'Littlefork','Littlefork, Minnesota',22466,41);
INSERT INTO "django_geo_db_city" VALUES(18188,'Loman','Loman, Minnesota',22467,41);
INSERT INTO "django_geo_db_city" VALUES(18189,'Longville','Longville, Minnesota',22468,41);
INSERT INTO "django_geo_db_city" VALUES(18190,'Marcell','Marcell, Minnesota',22469,41);
INSERT INTO "django_geo_db_city" VALUES(18191,'Margie','Margie, Minnesota',22470,41);
INSERT INTO "django_geo_db_city" VALUES(18192,'Max','Max, Minnesota',22471,41);
INSERT INTO "django_geo_db_city" VALUES(18193,'Mizpah','Mizpah, Minnesota',22472,41);
INSERT INTO "django_geo_db_city" VALUES(18194,'Northome','Northome, Minnesota',22473,41);
INSERT INTO "django_geo_db_city" VALUES(18195,'Outing','Outing, Minnesota',22474,41);
INSERT INTO "django_geo_db_city" VALUES(18196,'Pennington','Pennington, Minnesota',22475,41);
INSERT INTO "django_geo_db_city" VALUES(18197,'Ponemah','Ponemah, Minnesota',22476,41);
INSERT INTO "django_geo_db_city" VALUES(18198,'Puposky','Puposky, Minnesota',22477,41);
INSERT INTO "django_geo_db_city" VALUES(18199,'Ranier','Ranier, Minnesota',22478,41);
INSERT INTO "django_geo_db_city" VALUES(18200,'Ray','Ray, Minnesota',22479,41);
INSERT INTO "django_geo_db_city" VALUES(18201,'Redby','Redby, Minnesota',22480,41);
INSERT INTO "django_geo_db_city" VALUES(18202,'Redlake','Redlake, Minnesota',22481,41);
INSERT INTO "django_geo_db_city" VALUES(18203,'Remer','Remer, Minnesota',22482,41);
INSERT INTO "django_geo_db_city" VALUES(18204,'Roosevelt','Roosevelt, Minnesota',22483,41);
INSERT INTO "django_geo_db_city" VALUES(18205,'Shevlin','Shevlin, Minnesota',22484,41);
INSERT INTO "django_geo_db_city" VALUES(18206,'Solway','Solway, Minnesota',22485,41);
INSERT INTO "django_geo_db_city" VALUES(18207,'South International Falls','South International Falls, Minnesota',22470,41);
INSERT INTO "django_geo_db_city" VALUES(18208,'Spring Lake','Spring Lake, Minnesota',22486,41);
INSERT INTO "django_geo_db_city" VALUES(18209,'Squaw Lake','Squaw Lake, Minnesota',22487,41);
INSERT INTO "django_geo_db_city" VALUES(18210,'Swift','Swift, Minnesota',22488,41);
INSERT INTO "django_geo_db_city" VALUES(18211,'Tenstrike','Tenstrike, Minnesota',22489,41);
INSERT INTO "django_geo_db_city" VALUES(18212,'Trail','Trail, Minnesota',22490,41);
INSERT INTO "django_geo_db_city" VALUES(18213,'Waskish','Waskish, Minnesota',22491,41);
INSERT INTO "django_geo_db_city" VALUES(18214,'Williams','Williams, Minnesota',22492,41);
INSERT INTO "django_geo_db_city" VALUES(18215,'Wilton','Wilton, Minnesota',22493,41);
INSERT INTO "django_geo_db_city" VALUES(18216,'Wirt','Wirt, Minnesota',22494,41);
INSERT INTO "django_geo_db_city" VALUES(18217,'Thief River Falls','Thief River Falls, Minnesota',22495,41);
INSERT INTO "django_geo_db_city" VALUES(18218,'Alvarado','Alvarado, Minnesota',22496,41);
INSERT INTO "django_geo_db_city" VALUES(18219,'Angle Inlet','Angle Inlet, Minnesota',22497,41);
INSERT INTO "django_geo_db_city" VALUES(18220,'Angus','Angus, Minnesota',22498,41);
INSERT INTO "django_geo_db_city" VALUES(18221,'Argyle','Argyle, Minnesota',22499,41);
INSERT INTO "django_geo_db_city" VALUES(18222,'Badger','Badger, Minnesota',22500,41);
INSERT INTO "django_geo_db_city" VALUES(18223,'Brooks','Brooks, Minnesota',22501,41);
INSERT INTO "django_geo_db_city" VALUES(18224,'Crookston','Crookston, Minnesota',22502,41);
INSERT INTO "django_geo_db_city" VALUES(18225,'Donaldson','Donaldson, Minnesota',22503,41);
INSERT INTO "django_geo_db_city" VALUES(18226,'East Grand Forks','East Grand Forks, Minnesota',22504,41);
INSERT INTO "django_geo_db_city" VALUES(18227,'Euclid','Euclid, Minnesota',22505,41);
INSERT INTO "django_geo_db_city" VALUES(18228,'Fisher','Fisher, Minnesota',22506,41);
INSERT INTO "django_geo_db_city" VALUES(18229,'Gatzke','Gatzke, Minnesota',22507,41);
INSERT INTO "django_geo_db_city" VALUES(18230,'Goodridge','Goodridge, Minnesota',22508,41);
INSERT INTO "django_geo_db_city" VALUES(18231,'Greenbush','Greenbush, Minnesota',22509,41);
INSERT INTO "django_geo_db_city" VALUES(18232,'Grygla','Grygla, Minnesota',22510,41);
INSERT INTO "django_geo_db_city" VALUES(18233,'Hallock','Hallock, Minnesota',22511,41);
INSERT INTO "django_geo_db_city" VALUES(18234,'Halma','Halma, Minnesota',22512,41);
INSERT INTO "django_geo_db_city" VALUES(18235,'Humboldt','Humboldt, Minnesota',22513,41);
INSERT INTO "django_geo_db_city" VALUES(18236,'Karlstad','Karlstad, Minnesota',22514,41);
INSERT INTO "django_geo_db_city" VALUES(18237,'Kennedy','Kennedy, Minnesota',22515,41);
INSERT INTO "django_geo_db_city" VALUES(18238,'Lake Bronson','Lake Bronson, Minnesota',22516,41);
INSERT INTO "django_geo_db_city" VALUES(18239,'Lancaster','Lancaster, Minnesota',22517,41);
INSERT INTO "django_geo_db_city" VALUES(18240,'Mentor','Mentor, Minnesota',22518,41);
INSERT INTO "django_geo_db_city" VALUES(18241,'Middle River','Middle River, Minnesota',22519,41);
INSERT INTO "django_geo_db_city" VALUES(18242,'Newfolden','Newfolden, Minnesota',22520,41);
INSERT INTO "django_geo_db_city" VALUES(18243,'Noyes','Noyes, Minnesota',22521,41);
INSERT INTO "django_geo_db_city" VALUES(18244,'Oak Island','Oak Island, Minnesota',22522,41);
INSERT INTO "django_geo_db_city" VALUES(18245,'Oklee','Oklee, Minnesota',22523,41);
INSERT INTO "django_geo_db_city" VALUES(18246,'Oslo','Oslo, Minnesota',22524,41);
INSERT INTO "django_geo_db_city" VALUES(18247,'Plummer','Plummer, Minnesota',22525,41);
INSERT INTO "django_geo_db_city" VALUES(18248,'Red Lake Falls','Red Lake Falls, Minnesota',22526,41);
INSERT INTO "django_geo_db_city" VALUES(18249,'Roseau','Roseau, Minnesota',22527,41);
INSERT INTO "django_geo_db_city" VALUES(18250,'Saint Hilaire','Saint Hilaire, Minnesota',22528,41);
INSERT INTO "django_geo_db_city" VALUES(18251,'Saint Vincent','Saint Vincent, Minnesota',22529,41);
INSERT INTO "django_geo_db_city" VALUES(18252,'Salol','Salol, Minnesota',22530,41);
INSERT INTO "django_geo_db_city" VALUES(18253,'Stephen','Stephen, Minnesota',22531,41);
INSERT INTO "django_geo_db_city" VALUES(18254,'Strandquist','Strandquist, Minnesota',22532,41);
INSERT INTO "django_geo_db_city" VALUES(18255,'Strathcona','Strathcona, Minnesota',22533,41);
INSERT INTO "django_geo_db_city" VALUES(18256,'Viking','Viking, Minnesota',22534,41);
INSERT INTO "django_geo_db_city" VALUES(18257,'Wannaska','Wannaska, Minnesota',22535,41);
INSERT INTO "django_geo_db_city" VALUES(18258,'Warren','Warren, Minnesota',22536,41);
INSERT INTO "django_geo_db_city" VALUES(18259,'Warroad','Warroad, Minnesota',22537,41);
INSERT INTO "django_geo_db_city" VALUES(18260,'Alcester','Alcester, South Dakota',22538,49);
INSERT INTO "django_geo_db_city" VALUES(18261,'Aurora','Aurora, South Dakota',22539,49);
INSERT INTO "django_geo_db_city" VALUES(18262,'Baltic','Baltic, South Dakota',22540,49);
INSERT INTO "django_geo_db_city" VALUES(18263,'Beresford','Beresford, South Dakota',22541,49);
INSERT INTO "django_geo_db_city" VALUES(18264,'Brandon','Brandon, South Dakota',22542,49);
INSERT INTO "django_geo_db_city" VALUES(18265,'Brookings','Brookings, South Dakota',22543,49);
INSERT INTO "django_geo_db_city" VALUES(18266,'Burbank','Burbank, South Dakota',22545,49);
INSERT INTO "django_geo_db_city" VALUES(18267,'Canistota','Canistota, South Dakota',22546,49);
INSERT INTO "django_geo_db_city" VALUES(18268,'Canton','Canton, South Dakota',22547,49);
INSERT INTO "django_geo_db_city" VALUES(18269,'Centerville','Centerville, South Dakota',22548,49);
INSERT INTO "django_geo_db_city" VALUES(18270,'Chancellor','Chancellor, South Dakota',22549,49);
INSERT INTO "django_geo_db_city" VALUES(18271,'Chester','Chester, South Dakota',22550,49);
INSERT INTO "django_geo_db_city" VALUES(18272,'Colman','Colman, South Dakota',22551,49);
INSERT INTO "django_geo_db_city" VALUES(18273,'Colton','Colton, South Dakota',22552,49);
INSERT INTO "django_geo_db_city" VALUES(18274,'Crooks','Crooks, South Dakota',22553,49);
INSERT INTO "django_geo_db_city" VALUES(18275,'Davis','Davis, South Dakota',22554,49);
INSERT INTO "django_geo_db_city" VALUES(18276,'Dell Rapids','Dell Rapids, South Dakota',22555,49);
INSERT INTO "django_geo_db_city" VALUES(18277,'Egan','Egan, South Dakota',22556,49);
INSERT INTO "django_geo_db_city" VALUES(18278,'Elk Point','Elk Point, South Dakota',22557,49);
INSERT INTO "django_geo_db_city" VALUES(18279,'Elkton','Elkton, South Dakota',22558,49);
INSERT INTO "django_geo_db_city" VALUES(18280,'Fairview','Fairview, South Dakota',22559,49);
INSERT INTO "django_geo_db_city" VALUES(18281,'Flandreau','Flandreau, South Dakota',22560,49);
INSERT INTO "django_geo_db_city" VALUES(18282,'Freeman','Freeman, South Dakota',22561,49);
INSERT INTO "django_geo_db_city" VALUES(18283,'Garretson','Garretson, South Dakota',22562,49);
INSERT INTO "django_geo_db_city" VALUES(18284,'Gayville','Gayville, South Dakota',22563,49);
INSERT INTO "django_geo_db_city" VALUES(18285,'Harrisburg','Harrisburg, South Dakota',22564,49);
INSERT INTO "django_geo_db_city" VALUES(18286,'Hartford','Hartford, South Dakota',22565,49);
INSERT INTO "django_geo_db_city" VALUES(18287,'Hudson','Hudson, South Dakota',22566,49);
INSERT INTO "django_geo_db_city" VALUES(18288,'Humboldt','Humboldt, South Dakota',22567,49);
INSERT INTO "django_geo_db_city" VALUES(18289,'Hurley','Hurley, South Dakota',22568,49);
INSERT INTO "django_geo_db_city" VALUES(18290,'Irene','Irene, South Dakota',22569,49);
INSERT INTO "django_geo_db_city" VALUES(18291,'Jefferson','Jefferson, South Dakota',22570,49);
INSERT INTO "django_geo_db_city" VALUES(18292,'Lennox','Lennox, South Dakota',22571,49);
INSERT INTO "django_geo_db_city" VALUES(18293,'Lesterville','Lesterville, South Dakota',22572,49);
INSERT INTO "django_geo_db_city" VALUES(18294,'Lyons','Lyons, South Dakota',22573,49);
INSERT INTO "django_geo_db_city" VALUES(18295,'Madison','Madison, South Dakota',22574,49);
INSERT INTO "django_geo_db_city" VALUES(18296,'Marion','Marion, South Dakota',22575,49);
INSERT INTO "django_geo_db_city" VALUES(18297,'Meckling','Meckling, South Dakota',22576,49);
INSERT INTO "django_geo_db_city" VALUES(18298,'Menno','Menno, South Dakota',22577,49);
INSERT INTO "django_geo_db_city" VALUES(18299,'Mission Hill','Mission Hill, South Dakota',22578,49);
INSERT INTO "django_geo_db_city" VALUES(18300,'Monroe','Monroe, South Dakota',22579,49);
INSERT INTO "django_geo_db_city" VALUES(18301,'Montrose','Montrose, South Dakota',22580,49);
INSERT INTO "django_geo_db_city" VALUES(18302,'North Sioux City','North Sioux City, South Dakota',22581,49);
INSERT INTO "django_geo_db_city" VALUES(18303,'Nunda','Nunda, South Dakota',22582,49);
INSERT INTO "django_geo_db_city" VALUES(18304,'Oldham','Oldham, South Dakota',22583,49);
INSERT INTO "django_geo_db_city" VALUES(18305,'Olivet','Olivet, South Dakota',22584,49);
INSERT INTO "django_geo_db_city" VALUES(18306,'Parker','Parker, South Dakota',22585,49);
INSERT INTO "django_geo_db_city" VALUES(18307,'Ramona','Ramona, South Dakota',22586,49);
INSERT INTO "django_geo_db_city" VALUES(18308,'Renner','Renner, South Dakota',22587,49);
INSERT INTO "django_geo_db_city" VALUES(18309,'Rowena','Rowena, South Dakota',22588,49);
INSERT INTO "django_geo_db_city" VALUES(18310,'Rutland','Rutland, South Dakota',22589,49);
INSERT INTO "django_geo_db_city" VALUES(18311,'Salem','Salem, South Dakota',22590,49);
INSERT INTO "django_geo_db_city" VALUES(18312,'Scotland','Scotland, South Dakota',22591,49);
INSERT INTO "django_geo_db_city" VALUES(18313,'Sinai','Sinai, South Dakota',22592,49);
INSERT INTO "django_geo_db_city" VALUES(18314,'Springfield','Springfield, South Dakota',22593,49);
INSERT INTO "django_geo_db_city" VALUES(18315,'Tabor','Tabor, South Dakota',22594,49);
INSERT INTO "django_geo_db_city" VALUES(18316,'Tea','Tea, South Dakota',22595,49);
INSERT INTO "django_geo_db_city" VALUES(18317,'Trent','Trent, South Dakota',22596,49);
INSERT INTO "django_geo_db_city" VALUES(18318,'Tyndall','Tyndall, South Dakota',22597,49);
INSERT INTO "django_geo_db_city" VALUES(18319,'Utica','Utica, South Dakota',22598,49);
INSERT INTO "django_geo_db_city" VALUES(18320,'Valley Springs','Valley Springs, South Dakota',22599,49);
INSERT INTO "django_geo_db_city" VALUES(18321,'Vermillion','Vermillion, South Dakota',22600,49);
INSERT INTO "django_geo_db_city" VALUES(18322,'Viborg','Viborg, South Dakota',22601,49);
INSERT INTO "django_geo_db_city" VALUES(18323,'Volga','Volga, South Dakota',22602,49);
INSERT INTO "django_geo_db_city" VALUES(18324,'Volin','Volin, South Dakota',22603,49);
INSERT INTO "django_geo_db_city" VALUES(18325,'Wakonda','Wakonda, South Dakota',22604,49);
INSERT INTO "django_geo_db_city" VALUES(18326,'Ward','Ward, South Dakota',22605,49);
INSERT INTO "django_geo_db_city" VALUES(18327,'Wentworth','Wentworth, South Dakota',22606,49);
INSERT INTO "django_geo_db_city" VALUES(18328,'Winfred','Winfred, South Dakota',22607,49);
INSERT INTO "django_geo_db_city" VALUES(18329,'Worthing','Worthing, South Dakota',22608,49);
INSERT INTO "django_geo_db_city" VALUES(18330,'Yankton','Yankton, South Dakota',22609,49);
INSERT INTO "django_geo_db_city" VALUES(18331,'Sioux Falls','Sioux Falls, South Dakota',22611,49);
INSERT INTO "django_geo_db_city" VALUES(18332,'Buffalo Ridge','Buffalo Ridge, South Dakota',22620,49);
INSERT INTO "django_geo_db_city" VALUES(18333,'Watertown','Watertown, South Dakota',22621,49);
INSERT INTO "django_geo_db_city" VALUES(18334,'Waverly','Waverly, South Dakota',22622,49);
INSERT INTO "django_geo_db_city" VALUES(18335,'Cleveland','Cleveland, South Dakota',22623,49);
INSERT INTO "django_geo_db_city" VALUES(18336,'Arlington','Arlington, South Dakota',22624,49);
INSERT INTO "django_geo_db_city" VALUES(18337,'Astoria','Astoria, South Dakota',22625,49);
INSERT INTO "django_geo_db_city" VALUES(18338,'Badger','Badger, South Dakota',22626,49);
INSERT INTO "django_geo_db_city" VALUES(18339,'Big Stone City','Big Stone City, South Dakota',22627,49);
INSERT INTO "django_geo_db_city" VALUES(18340,'Bradley','Bradley, South Dakota',22628,49);
INSERT INTO "django_geo_db_city" VALUES(18341,'Brandt','Brandt, South Dakota',22629,49);
INSERT INTO "django_geo_db_city" VALUES(18342,'Bristol','Bristol, South Dakota',22630,49);
INSERT INTO "django_geo_db_city" VALUES(18343,'Bruce','Bruce, South Dakota',22631,49);
INSERT INTO "django_geo_db_city" VALUES(18344,'Bryant','Bryant, South Dakota',22632,49);
INSERT INTO "django_geo_db_city" VALUES(18345,'Castlewood','Castlewood, South Dakota',22633,49);
INSERT INTO "django_geo_db_city" VALUES(18346,'Claire City','Claire City, South Dakota',22634,49);
INSERT INTO "django_geo_db_city" VALUES(18347,'Clark','Clark, South Dakota',22635,49);
INSERT INTO "django_geo_db_city" VALUES(18348,'Clear Lake','Clear Lake, South Dakota',22636,49);
INSERT INTO "django_geo_db_city" VALUES(18349,'Corona','Corona, South Dakota',22637,49);
INSERT INTO "django_geo_db_city" VALUES(18350,'De Smet','De Smet, South Dakota',22638,49);
INSERT INTO "django_geo_db_city" VALUES(18351,'Eden','Eden, South Dakota',22640,49);
INSERT INTO "django_geo_db_city" VALUES(18352,'Erwin','Erwin, South Dakota',22641,49);
INSERT INTO "django_geo_db_city" VALUES(18353,'Estelline','Estelline, South Dakota',22642,49);
INSERT INTO "django_geo_db_city" VALUES(18354,'Florence','Florence, South Dakota',22643,49);
INSERT INTO "django_geo_db_city" VALUES(18355,'Garden City','Garden City, South Dakota',22644,49);
INSERT INTO "django_geo_db_city" VALUES(18356,'Gary','Gary, South Dakota',22645,49);
INSERT INTO "django_geo_db_city" VALUES(18357,'Goodwin','Goodwin, South Dakota',22646,49);
INSERT INTO "django_geo_db_city" VALUES(18358,'Grenville','Grenville, South Dakota',22647,49);
INSERT INTO "django_geo_db_city" VALUES(18359,'Hayti','Hayti, South Dakota',22648,49);
INSERT INTO "django_geo_db_city" VALUES(18360,'Hazel','Hazel, South Dakota',22649,49);
INSERT INTO "django_geo_db_city" VALUES(18361,'Henry','Henry, South Dakota',22650,49);
INSERT INTO "django_geo_db_city" VALUES(18362,'Hetland','Hetland, South Dakota',22651,49);
INSERT INTO "django_geo_db_city" VALUES(18363,'Kranzburg','Kranzburg, South Dakota',22652,49);
INSERT INTO "django_geo_db_city" VALUES(18364,'Labolt','Labolt, South Dakota',22653,49);
INSERT INTO "django_geo_db_city" VALUES(18365,'Lake City','Lake City, South Dakota',22654,49);
INSERT INTO "django_geo_db_city" VALUES(18366,'Lake Norden','Lake Norden, South Dakota',22655,49);
INSERT INTO "django_geo_db_city" VALUES(18367,'Lake Preston','Lake Preston, South Dakota',22656,49);
INSERT INTO "django_geo_db_city" VALUES(18368,'Marvin','Marvin, South Dakota',22657,49);
INSERT INTO "django_geo_db_city" VALUES(18369,'Milbank','Milbank, South Dakota',22658,49);
INSERT INTO "django_geo_db_city" VALUES(18370,'New Effington','New Effington, South Dakota',22660,49);
INSERT INTO "django_geo_db_city" VALUES(18371,'Ortley','Ortley, South Dakota',22661,49);
INSERT INTO "django_geo_db_city" VALUES(18372,'Peever','Peever, South Dakota',22662,49);
INSERT INTO "django_geo_db_city" VALUES(18373,'Raymond','Raymond, South Dakota',22663,49);
INSERT INTO "django_geo_db_city" VALUES(18374,'Revillo','Revillo, South Dakota',22664,49);
INSERT INTO "django_geo_db_city" VALUES(18375,'Rosholt','Rosholt, South Dakota',22665,49);
INSERT INTO "django_geo_db_city" VALUES(18376,'Roslyn','Roslyn, South Dakota',22666,49);
INSERT INTO "django_geo_db_city" VALUES(18377,'Sisseton','Sisseton, South Dakota',22667,49);
INSERT INTO "django_geo_db_city" VALUES(18378,'South Shore','South Shore, South Dakota',22668,49);
INSERT INTO "django_geo_db_city" VALUES(18379,'Stockholm','Stockholm, South Dakota',22669,49);
INSERT INTO "django_geo_db_city" VALUES(18380,'Strandburg','Strandburg, South Dakota',22670,49);
INSERT INTO "django_geo_db_city" VALUES(18381,'Summit','Summit, South Dakota',22671,49);
INSERT INTO "django_geo_db_city" VALUES(18382,'Toronto','Toronto, South Dakota',22672,49);
INSERT INTO "django_geo_db_city" VALUES(18383,'Twin Brooks','Twin Brooks, South Dakota',22673,49);
INSERT INTO "django_geo_db_city" VALUES(18384,'Veblen','Veblen, South Dakota',22674,49);
INSERT INTO "django_geo_db_city" VALUES(18385,'Vienna','Vienna, South Dakota',22675,49);
INSERT INTO "django_geo_db_city" VALUES(18386,'Wallace','Wallace, South Dakota',22676,49);
INSERT INTO "django_geo_db_city" VALUES(18387,'Waubay','Waubay, South Dakota',22677,49);
INSERT INTO "django_geo_db_city" VALUES(18388,'Webster','Webster, South Dakota',22678,49);
INSERT INTO "django_geo_db_city" VALUES(18389,'White','White, South Dakota',22679,49);
INSERT INTO "django_geo_db_city" VALUES(18390,'Willow Lake','Willow Lake, South Dakota',22680,49);
INSERT INTO "django_geo_db_city" VALUES(18391,'Wilmot','Wilmot, South Dakota',22681,49);
INSERT INTO "django_geo_db_city" VALUES(18392,'Mitchell','Mitchell, South Dakota',22682,49);
INSERT INTO "django_geo_db_city" VALUES(18393,'Perry','Perry, South Dakota',22683,49);
INSERT INTO "django_geo_db_city" VALUES(18394,'Alexandria','Alexandria, South Dakota',22684,49);
INSERT INTO "django_geo_db_city" VALUES(18395,'Alpena','Alpena, South Dakota',22685,49);
INSERT INTO "django_geo_db_city" VALUES(18396,'Armour','Armour, South Dakota',22686,49);
INSERT INTO "django_geo_db_city" VALUES(18397,'Artesian','Artesian, South Dakota',22687,49);
INSERT INTO "django_geo_db_city" VALUES(18398,'Avon','Avon, South Dakota',22688,49);
INSERT INTO "django_geo_db_city" VALUES(18399,'Bonesteel','Bonesteel, South Dakota',22689,49);
INSERT INTO "django_geo_db_city" VALUES(18400,'Bridgewater','Bridgewater, South Dakota',22690,49);
INSERT INTO "django_geo_db_city" VALUES(18401,'Canova','Canova, South Dakota',22691,49);
INSERT INTO "django_geo_db_city" VALUES(18402,'Carpenter','Carpenter, South Dakota',22692,49);
INSERT INTO "django_geo_db_city" VALUES(18403,'Carthage','Carthage, South Dakota',22693,49);
INSERT INTO "django_geo_db_city" VALUES(18404,'Cavour','Cavour, South Dakota',22694,49);
INSERT INTO "django_geo_db_city" VALUES(18405,'Chamberlain','Chamberlain, South Dakota',22695,49);
INSERT INTO "django_geo_db_city" VALUES(18406,'Corsica','Corsica, South Dakota',22697,49);
INSERT INTO "django_geo_db_city" VALUES(18407,'Dante','Dante, South Dakota',22698,49);
INSERT INTO "django_geo_db_city" VALUES(18408,'Delmont','Delmont, South Dakota',22699,49);
INSERT INTO "django_geo_db_city" VALUES(18409,'Dimock','Dimock, South Dakota',22700,49);
INSERT INTO "django_geo_db_city" VALUES(18410,'Emery','Emery, South Dakota',22701,49);
INSERT INTO "django_geo_db_city" VALUES(18411,'Ethan','Ethan, South Dakota',22702,49);
INSERT INTO "django_geo_db_city" VALUES(18412,'Fairfax','Fairfax, South Dakota',22703,49);
INSERT INTO "django_geo_db_city" VALUES(18413,'Fedora','Fedora, South Dakota',22704,49);
INSERT INTO "django_geo_db_city" VALUES(18414,'Fort Thompson','Fort Thompson, South Dakota',22705,49);
INSERT INTO "django_geo_db_city" VALUES(18415,'Fulton','Fulton, South Dakota',22706,49);
INSERT INTO "django_geo_db_city" VALUES(18416,'Gann Valley','Gann Valley, South Dakota',22707,49);
INSERT INTO "django_geo_db_city" VALUES(18417,'Geddes','Geddes, South Dakota',22708,49);
INSERT INTO "django_geo_db_city" VALUES(18418,'Harrison','Harrison, South Dakota',22709,49);
INSERT INTO "django_geo_db_city" VALUES(18419,'Highmore','Highmore, South Dakota',22710,49);
INSERT INTO "django_geo_db_city" VALUES(18420,'Stephan','Stephan, South Dakota',22711,49);
INSERT INTO "django_geo_db_city" VALUES(18421,'Benton','Benton, South Dakota',22712,49);
INSERT INTO "django_geo_db_city" VALUES(18422,'Hitchcock','Hitchcock, South Dakota',22713,49);
INSERT INTO "django_geo_db_city" VALUES(18423,'Howard','Howard, South Dakota',22714,49);
INSERT INTO "django_geo_db_city" VALUES(18424,'Huron','Huron, South Dakota',22715,49);
INSERT INTO "django_geo_db_city" VALUES(18425,'Iroquois','Iroquois, South Dakota',22716,49);
INSERT INTO "django_geo_db_city" VALUES(18426,'Kaylor','Kaylor, South Dakota',22717,49);
INSERT INTO "django_geo_db_city" VALUES(18427,'Kimball','Kimball, South Dakota',22718,49);
INSERT INTO "django_geo_db_city" VALUES(18428,'Lake Andes','Lake Andes, South Dakota',22719,49);
INSERT INTO "django_geo_db_city" VALUES(18429,'Ravinia','Ravinia, South Dakota',22720,49);
INSERT INTO "django_geo_db_city" VALUES(18430,'Lane','Lane, South Dakota',22721,49);
INSERT INTO "django_geo_db_city" VALUES(18431,'Letcher','Letcher, South Dakota',22722,49);
INSERT INTO "django_geo_db_city" VALUES(18432,'Marty','Marty, South Dakota',22723,49);
INSERT INTO "django_geo_db_city" VALUES(18433,'Miller','Miller, South Dakota',22724,49);
INSERT INTO "django_geo_db_city" VALUES(18434,'Mount Vernon','Mount Vernon, South Dakota',22725,49);
INSERT INTO "django_geo_db_city" VALUES(18435,'New Holland','New Holland, South Dakota',22726,49);
INSERT INTO "django_geo_db_city" VALUES(18436,'Oacoma','Oacoma, South Dakota',22727,49);
INSERT INTO "django_geo_db_city" VALUES(18437,'Parkston','Parkston, South Dakota',22728,49);
INSERT INTO "django_geo_db_city" VALUES(18438,'Pickstown','Pickstown, South Dakota',22729,49);
INSERT INTO "django_geo_db_city" VALUES(18439,'Plankinton','Plankinton, South Dakota',22730,49);
INSERT INTO "django_geo_db_city" VALUES(18440,'Platte','Platte, South Dakota',22731,49);
INSERT INTO "django_geo_db_city" VALUES(18441,'Pukwana','Pukwana, South Dakota',22732,49);
INSERT INTO "django_geo_db_city" VALUES(18442,'Ree Heights','Ree Heights, South Dakota',22733,49);
INSERT INTO "django_geo_db_city" VALUES(18443,'Saint Lawrence','Saint Lawrence, South Dakota',22734,49);
INSERT INTO "django_geo_db_city" VALUES(18444,'Spencer','Spencer, South Dakota',22735,49);
INSERT INTO "django_geo_db_city" VALUES(18445,'Stickney','Stickney, South Dakota',22736,49);
INSERT INTO "django_geo_db_city" VALUES(18446,'Tripp','Tripp, South Dakota',22737,49);
INSERT INTO "django_geo_db_city" VALUES(18447,'Virgil','Virgil, South Dakota',22738,49);
INSERT INTO "django_geo_db_city" VALUES(18448,'Wagner','Wagner, South Dakota',22739,49);
INSERT INTO "django_geo_db_city" VALUES(18449,'Wessington','Wessington, South Dakota',22740,49);
INSERT INTO "django_geo_db_city" VALUES(18450,'Wessington Springs','Wessington Springs, South Dakota',22741,49);
INSERT INTO "django_geo_db_city" VALUES(18451,'White Lake','White Lake, South Dakota',22742,49);
INSERT INTO "django_geo_db_city" VALUES(18452,'Wolsey','Wolsey, South Dakota',22743,49);
INSERT INTO "django_geo_db_city" VALUES(18453,'Woonsocket','Woonsocket, South Dakota',22744,49);
INSERT INTO "django_geo_db_city" VALUES(18454,'Yale','Yale, South Dakota',22745,49);
INSERT INTO "django_geo_db_city" VALUES(18455,'Aberdeen','Aberdeen, South Dakota',22747,49);
INSERT INTO "django_geo_db_city" VALUES(18456,'Akaska','Akaska, South Dakota',22750,49);
INSERT INTO "django_geo_db_city" VALUES(18457,'Amherst','Amherst, South Dakota',22751,49);
INSERT INTO "django_geo_db_city" VALUES(18458,'Andover','Andover, South Dakota',22752,49);
INSERT INTO "django_geo_db_city" VALUES(18459,'Ashton','Ashton, South Dakota',22753,49);
INSERT INTO "django_geo_db_city" VALUES(18460,'Barnard','Barnard, South Dakota',22754,49);
INSERT INTO "django_geo_db_city" VALUES(18461,'Bath','Bath, South Dakota',22755,49);
INSERT INTO "django_geo_db_city" VALUES(18462,'Bowdle','Bowdle, South Dakota',22756,49);
INSERT INTO "django_geo_db_city" VALUES(18463,'Brentford','Brentford, South Dakota',22757,49);
INSERT INTO "django_geo_db_city" VALUES(18464,'Britton','Britton, South Dakota',22758,49);
INSERT INTO "django_geo_db_city" VALUES(18465,'Claremont','Claremont, South Dakota',22759,49);
INSERT INTO "django_geo_db_city" VALUES(18466,'Columbia','Columbia, South Dakota',22760,49);
INSERT INTO "django_geo_db_city" VALUES(18467,'Conde','Conde, South Dakota',22761,49);
INSERT INTO "django_geo_db_city" VALUES(18468,'Cresbard','Cresbard, South Dakota',22762,49);
INSERT INTO "django_geo_db_city" VALUES(18469,'Doland','Doland, South Dakota',22763,49);
INSERT INTO "django_geo_db_city" VALUES(18470,'Eureka','Eureka, South Dakota',22764,49);
INSERT INTO "django_geo_db_city" VALUES(18471,'Faulkton','Faulkton, South Dakota',22765,49);
INSERT INTO "django_geo_db_city" VALUES(18472,'Ferney','Ferney, South Dakota',22766,49);
INSERT INTO "django_geo_db_city" VALUES(18473,'Frankfort','Frankfort, South Dakota',22767,49);
INSERT INTO "django_geo_db_city" VALUES(18474,'Frederick','Frederick, South Dakota',22768,49);
INSERT INTO "django_geo_db_city" VALUES(18475,'Gettysburg','Gettysburg, South Dakota',22769,49);
INSERT INTO "django_geo_db_city" VALUES(18476,'Cambria','Cambria, South Dakota',22770,49);
INSERT INTO "django_geo_db_city" VALUES(18477,'Groton','Groton, South Dakota',22771,49);
INSERT INTO "django_geo_db_city" VALUES(18478,'Hecla','Hecla, South Dakota',22772,49);
INSERT INTO "django_geo_db_city" VALUES(18479,'Hosmer','Hosmer, South Dakota',22773,49);
INSERT INTO "django_geo_db_city" VALUES(18480,'Houghton','Houghton, South Dakota',22774,49);
INSERT INTO "django_geo_db_city" VALUES(18481,'Hoven','Hoven, South Dakota',22775,49);
INSERT INTO "django_geo_db_city" VALUES(18482,'Ipswich','Ipswich, South Dakota',22776,49);
INSERT INTO "django_geo_db_city" VALUES(18483,'Java','Java, South Dakota',22777,49);
INSERT INTO "django_geo_db_city" VALUES(18484,'Langford','Langford, South Dakota',22778,49);
INSERT INTO "django_geo_db_city" VALUES(18485,'Lebanon','Lebanon, South Dakota',22779,49);
INSERT INTO "django_geo_db_city" VALUES(18486,'Leola','Leola, South Dakota',22780,49);
INSERT INTO "django_geo_db_city" VALUES(18487,'Longlake','Longlake, South Dakota',22781,49);
INSERT INTO "django_geo_db_city" VALUES(18488,'Mansfield','Mansfield, South Dakota',22782,49);
INSERT INTO "django_geo_db_city" VALUES(18489,'Mellette','Mellette, South Dakota',22783,49);
INSERT INTO "django_geo_db_city" VALUES(18490,'Mina','Mina, South Dakota',22784,49);
INSERT INTO "django_geo_db_city" VALUES(18491,'Northville','Northville, South Dakota',22785,49);
INSERT INTO "django_geo_db_city" VALUES(18492,'Onaka','Onaka, South Dakota',22786,49);
INSERT INTO "django_geo_db_city" VALUES(18493,'Orient','Orient, South Dakota',22787,49);
INSERT INTO "django_geo_db_city" VALUES(18494,'Pierpont','Pierpont, South Dakota',22788,49);
INSERT INTO "django_geo_db_city" VALUES(18495,'Redfield','Redfield, South Dakota',22789,49);
INSERT INTO "django_geo_db_city" VALUES(18496,'Rockham','Rockham, South Dakota',22790,49);
INSERT INTO "django_geo_db_city" VALUES(18497,'Roscoe','Roscoe, South Dakota',22791,49);
INSERT INTO "django_geo_db_city" VALUES(18498,'Selby','Selby, South Dakota',22792,49);
INSERT INTO "django_geo_db_city" VALUES(18499,'Seneca','Seneca, South Dakota',22793,49);
INSERT INTO "django_geo_db_city" VALUES(18500,'Stratford','Stratford, South Dakota',22794,49);
INSERT INTO "django_geo_db_city" VALUES(18501,'Tolstoy','Tolstoy, South Dakota',22795,49);
INSERT INTO "django_geo_db_city" VALUES(18502,'Tulare','Tulare, South Dakota',22796,49);
INSERT INTO "django_geo_db_city" VALUES(18503,'Turton','Turton, South Dakota',22797,49);
INSERT INTO "django_geo_db_city" VALUES(18504,'Warner','Warner, South Dakota',22798,49);
INSERT INTO "django_geo_db_city" VALUES(18505,'Westport','Westport, South Dakota',22799,49);
INSERT INTO "django_geo_db_city" VALUES(18506,'Pierre','Pierre, South Dakota',22800,49);
INSERT INTO "django_geo_db_city" VALUES(18507,'Agar','Agar, South Dakota',22801,49);
INSERT INTO "django_geo_db_city" VALUES(18508,'Belvidere','Belvidere, South Dakota',22802,49);
INSERT INTO "django_geo_db_city" VALUES(18509,'Blunt','Blunt, South Dakota',22803,49);
INSERT INTO "django_geo_db_city" VALUES(18510,'Burke','Burke, South Dakota',22804,49);
INSERT INTO "django_geo_db_city" VALUES(18511,'Carter','Carter, South Dakota',22805,49);
INSERT INTO "django_geo_db_city" VALUES(18512,'Colome','Colome, South Dakota',22806,49);
INSERT INTO "django_geo_db_city" VALUES(18513,'Dallas','Dallas, South Dakota',22807,49);
INSERT INTO "django_geo_db_city" VALUES(18514,'Draper','Draper, South Dakota',22808,49);
INSERT INTO "django_geo_db_city" VALUES(18515,'Fort Pierre','Fort Pierre, South Dakota',22809,49);
INSERT INTO "django_geo_db_city" VALUES(18516,'Gregory','Gregory, South Dakota',22810,49);
INSERT INTO "django_geo_db_city" VALUES(18517,'Hamill','Hamill, South Dakota',22811,49);
INSERT INTO "django_geo_db_city" VALUES(18518,'Harrold','Harrold, South Dakota',22812,49);
INSERT INTO "django_geo_db_city" VALUES(18519,'Hayes','Hayes, South Dakota',22813,49);
INSERT INTO "django_geo_db_city" VALUES(18520,'Herrick','Herrick, South Dakota',22814,49);
INSERT INTO "django_geo_db_city" VALUES(18521,'Holabird','Holabird, South Dakota',22815,49);
INSERT INTO "django_geo_db_city" VALUES(18522,'Ideal','Ideal, South Dakota',22816,49);
INSERT INTO "django_geo_db_city" VALUES(18523,'Iona','Iona, South Dakota',22817,49);
INSERT INTO "django_geo_db_city" VALUES(18524,'Kadoka','Kadoka, South Dakota',22818,49);
INSERT INTO "django_geo_db_city" VALUES(18525,'Kennebec','Kennebec, South Dakota',22819,49);
INSERT INTO "django_geo_db_city" VALUES(18526,'Long Valley','Long Valley, South Dakota',22820,49);
INSERT INTO "django_geo_db_city" VALUES(18527,'Lower Brule','Lower Brule, South Dakota',22821,49);
INSERT INTO "django_geo_db_city" VALUES(18528,'Martin','Martin, South Dakota',22822,49);
INSERT INTO "django_geo_db_city" VALUES(18529,'Midland','Midland, South Dakota',22823,49);
INSERT INTO "django_geo_db_city" VALUES(18530,'Milesville','Milesville, South Dakota',22824,49);
INSERT INTO "django_geo_db_city" VALUES(18531,'Mission','Mission, South Dakota',22825,49);
INSERT INTO "django_geo_db_city" VALUES(18532,'Mission Ridge','Mission Ridge, South Dakota',22826,49);
INSERT INTO "django_geo_db_city" VALUES(18533,'Murdo','Murdo, South Dakota',22827,49);
INSERT INTO "django_geo_db_city" VALUES(18534,'Norris','Norris, South Dakota',22828,49);
INSERT INTO "django_geo_db_city" VALUES(18535,'Okaton','Okaton, South Dakota',22829,49);
INSERT INTO "django_geo_db_city" VALUES(18536,'Okreek','Okreek, South Dakota',22830,49);
INSERT INTO "django_geo_db_city" VALUES(18537,'Onida','Onida, South Dakota',22831,49);
INSERT INTO "django_geo_db_city" VALUES(18538,'Timber Lake','Timber Lake, South Dakota',22832,49);
INSERT INTO "django_geo_db_city" VALUES(18539,'Parmelee','Parmelee, South Dakota',22833,49);
INSERT INTO "django_geo_db_city" VALUES(18540,'Philip','Philip, South Dakota',22834,49);
INSERT INTO "django_geo_db_city" VALUES(18541,'Presho','Presho, South Dakota',22835,49);
INSERT INTO "django_geo_db_city" VALUES(18542,'Reliance','Reliance, South Dakota',22836,49);
INSERT INTO "django_geo_db_city" VALUES(18543,'Rosebud','Rosebud, South Dakota',22837,49);
INSERT INTO "django_geo_db_city" VALUES(18544,'Saint Charles','Saint Charles, South Dakota',22838,49);
INSERT INTO "django_geo_db_city" VALUES(18545,'Saint Francis','Saint Francis, South Dakota',22839,49);
INSERT INTO "django_geo_db_city" VALUES(18546,'Tuthill','Tuthill, South Dakota',22840,49);
INSERT INTO "django_geo_db_city" VALUES(18547,'Vivian','Vivian, South Dakota',22841,49);
INSERT INTO "django_geo_db_city" VALUES(18548,'Wanblee','Wanblee, South Dakota',22842,49);
INSERT INTO "django_geo_db_city" VALUES(18549,'Wewela','Wewela, South Dakota',22843,49);
INSERT INTO "django_geo_db_city" VALUES(18550,'White River','White River, South Dakota',22844,49);
INSERT INTO "django_geo_db_city" VALUES(18551,'Winner','Winner, South Dakota',22845,49);
INSERT INTO "django_geo_db_city" VALUES(18552,'Witten','Witten, South Dakota',22846,49);
INSERT INTO "django_geo_db_city" VALUES(18553,'Wood','Wood, South Dakota',22847,49);
INSERT INTO "django_geo_db_city" VALUES(18554,'Mobridge','Mobridge, South Dakota',22848,49);
INSERT INTO "django_geo_db_city" VALUES(18555,'Bison','Bison, South Dakota',22849,49);
INSERT INTO "django_geo_db_city" VALUES(18556,'Bullhead','Bullhead, South Dakota',22850,49);
INSERT INTO "django_geo_db_city" VALUES(18557,'Cherry Creek','Cherry Creek, South Dakota',22851,49);
INSERT INTO "django_geo_db_city" VALUES(18558,'Dupree','Dupree, South Dakota',22852,49);
INSERT INTO "django_geo_db_city" VALUES(18559,'Eagle Butte','Eagle Butte, South Dakota',22853,49);
INSERT INTO "django_geo_db_city" VALUES(18560,'Faith','Faith, South Dakota',22854,49);
INSERT INTO "django_geo_db_city" VALUES(18561,'Firesteel','Firesteel, South Dakota',22855,49);
INSERT INTO "django_geo_db_city" VALUES(18562,'Glad Valley','Glad Valley, South Dakota',22856,49);
INSERT INTO "django_geo_db_city" VALUES(18563,'Glencross','Glencross, South Dakota',22857,49);
INSERT INTO "django_geo_db_city" VALUES(18564,'Glenham','Glenham, South Dakota',22858,49);
INSERT INTO "django_geo_db_city" VALUES(18565,'Herreid','Herreid, South Dakota',22859,49);
INSERT INTO "django_geo_db_city" VALUES(18566,'Isabel','Isabel, South Dakota',22860,49);
INSERT INTO "django_geo_db_city" VALUES(18567,'Keldron','Keldron, South Dakota',22861,49);
INSERT INTO "django_geo_db_city" VALUES(18568,'Lantry','Lantry, South Dakota',22862,49);
INSERT INTO "django_geo_db_city" VALUES(18569,'Lemmon','Lemmon, North Dakota',22863,34);
INSERT INTO "django_geo_db_city" VALUES(18570,'Little Eagle','Little Eagle, South Dakota',22864,49);
INSERT INTO "django_geo_db_city" VALUES(18571,'Lodgepole','Lodgepole, South Dakota',22865,49);
INSERT INTO "django_geo_db_city" VALUES(18572,'McIntosh','McIntosh, South Dakota',22866,49);
INSERT INTO "django_geo_db_city" VALUES(18573,'McLaughlin','McLaughlin, South Dakota',22867,49);
INSERT INTO "django_geo_db_city" VALUES(18574,'Mahto','Mahto, South Dakota',22864,49);
INSERT INTO "django_geo_db_city" VALUES(18575,'Meadow','Meadow, South Dakota',22868,49);
INSERT INTO "django_geo_db_city" VALUES(18576,'Morristown','Morristown, South Dakota',22869,49);
INSERT INTO "django_geo_db_city" VALUES(18577,'Mound City','Mound City, South Dakota',22870,49);
INSERT INTO "django_geo_db_city" VALUES(18578,'Parade','Parade, South Dakota',22857,49);
INSERT INTO "django_geo_db_city" VALUES(18579,'Pollock','Pollock, South Dakota',22871,49);
INSERT INTO "django_geo_db_city" VALUES(18580,'Prairie City','Prairie City, South Dakota',22872,49);
INSERT INTO "django_geo_db_city" VALUES(18581,'Ralph','Ralph, South Dakota',22873,49);
INSERT INTO "django_geo_db_city" VALUES(18582,'Reva','Reva, South Dakota',22874,49);
INSERT INTO "django_geo_db_city" VALUES(18583,'Ridgeview','Ridgeview, South Dakota',22875,49);
INSERT INTO "django_geo_db_city" VALUES(18584,'Shadehill','Shadehill, South Dakota',22876,49);
INSERT INTO "django_geo_db_city" VALUES(18585,'Trail City','Trail City, South Dakota',22878,49);
INSERT INTO "django_geo_db_city" VALUES(18586,'Wakpala','Wakpala, South Dakota',22879,49);
INSERT INTO "django_geo_db_city" VALUES(18587,'Walker','Walker, South Dakota',22864,49);
INSERT INTO "django_geo_db_city" VALUES(18588,'Watauga','Watauga, South Dakota',22880,49);
INSERT INTO "django_geo_db_city" VALUES(18589,'Whitehorse','Whitehorse, South Dakota',22881,49);
INSERT INTO "django_geo_db_city" VALUES(18590,'York','York, South Dakota',22883,49);
INSERT INTO "django_geo_db_city" VALUES(18591,'Orange','Orange, North Dakota',22884,34);
INSERT INTO "django_geo_db_city" VALUES(18592,'Rapid City','Rapid City, South Dakota',22885,49);
INSERT INTO "django_geo_db_city" VALUES(18593,'Ellsworth AFB','Ellsworth AFB, South Dakota',22889,49);
INSERT INTO "django_geo_db_city" VALUES(18594,'Bethlehem','Bethlehem, South Dakota',22890,49);
INSERT INTO "django_geo_db_city" VALUES(18595,'Allen','Allen, South Dakota',22892,49);
INSERT INTO "django_geo_db_city" VALUES(18596,'Batesland','Batesland, South Dakota',22893,49);
INSERT INTO "django_geo_db_city" VALUES(18597,'Belle Fourche','Belle Fourche, South Dakota',22894,49);
INSERT INTO "django_geo_db_city" VALUES(18598,'Black Hawk','Black Hawk, South Dakota',22895,49);
INSERT INTO "django_geo_db_city" VALUES(18599,'Box Elder','Box Elder, South Dakota',22896,49);
INSERT INTO "django_geo_db_city" VALUES(18600,'Buffalo','Buffalo, South Dakota',22897,49);
INSERT INTO "django_geo_db_city" VALUES(18601,'Buffalo Gap','Buffalo Gap, South Dakota',22898,49);
INSERT INTO "django_geo_db_city" VALUES(18602,'Camp Crook','Camp Crook, South Dakota',22899,49);
INSERT INTO "django_geo_db_city" VALUES(18603,'Caputa','Caputa, South Dakota',22900,49);
INSERT INTO "django_geo_db_city" VALUES(18604,'Creighton','Creighton, South Dakota',22901,49);
INSERT INTO "django_geo_db_city" VALUES(18605,'Custer','Custer, South Dakota',22902,49);
INSERT INTO "django_geo_db_city" VALUES(18606,'Deadwood','Deadwood, South Dakota',22903,49);
INSERT INTO "django_geo_db_city" VALUES(18607,'Edgemont','Edgemont, South Dakota',22904,49);
INSERT INTO "django_geo_db_city" VALUES(18608,'Elm Springs','Elm Springs, South Dakota',22905,49);
INSERT INTO "django_geo_db_city" VALUES(18609,'Enning','Enning, South Dakota',22906,49);
INSERT INTO "django_geo_db_city" VALUES(18610,'Fairburn','Fairburn, South Dakota',22907,49);
INSERT INTO "django_geo_db_city" VALUES(18611,'Fort Meade','Fort Meade, South Dakota',22908,49);
INSERT INTO "django_geo_db_city" VALUES(18612,'Fruitdale','Fruitdale, South Dakota',22909,49);
INSERT INTO "django_geo_db_city" VALUES(18613,'Hermosa','Hermosa, South Dakota',22910,49);
INSERT INTO "django_geo_db_city" VALUES(18614,'Hill City','Hill City, South Dakota',22911,49);
INSERT INTO "django_geo_db_city" VALUES(18615,'Hot Springs','Hot Springs, South Dakota',22912,49);
INSERT INTO "django_geo_db_city" VALUES(18616,'Howes','Howes, South Dakota',22913,49);
INSERT INTO "django_geo_db_city" VALUES(18617,'Interior','Interior, South Dakota',22914,49);
INSERT INTO "django_geo_db_city" VALUES(18618,'Keystone','Keystone, South Dakota',22915,49);
INSERT INTO "django_geo_db_city" VALUES(18619,'Kyle','Kyle, South Dakota',22916,49);
INSERT INTO "django_geo_db_city" VALUES(18620,'Lead','Lead, South Dakota',22917,49);
INSERT INTO "django_geo_db_city" VALUES(18621,'Ludlow','Ludlow, South Dakota',22918,49);
INSERT INTO "django_geo_db_city" VALUES(18622,'Manderson','Manderson, South Dakota',22919,49);
INSERT INTO "django_geo_db_city" VALUES(18623,'Mud Butte','Mud Butte, South Dakota',22920,49);
INSERT INTO "django_geo_db_city" VALUES(18624,'Nemo','Nemo, South Dakota',22921,49);
INSERT INTO "django_geo_db_city" VALUES(18625,'Newell','Newell, South Dakota',22922,49);
INSERT INTO "django_geo_db_city" VALUES(18626,'New Underwood','New Underwood, South Dakota',22923,49);
INSERT INTO "django_geo_db_city" VALUES(18627,'Nisland','Nisland, South Dakota',22924,49);
INSERT INTO "django_geo_db_city" VALUES(18628,'Oelrichs','Oelrichs, South Dakota',22925,49);
INSERT INTO "django_geo_db_city" VALUES(18629,'Oglala','Oglala, South Dakota',22926,49);
INSERT INTO "django_geo_db_city" VALUES(18630,'Opal','Opal, South Dakota',22927,49);
INSERT INTO "django_geo_db_city" VALUES(18631,'Oral','Oral, South Dakota',22928,49);
INSERT INTO "django_geo_db_city" VALUES(18632,'Owanka','Owanka, South Dakota',22929,49);
INSERT INTO "django_geo_db_city" VALUES(18633,'Piedmont','Piedmont, South Dakota',22930,49);
INSERT INTO "django_geo_db_city" VALUES(18634,'Pine Ridge','Pine Ridge, South Dakota',22931,49);
INSERT INTO "django_geo_db_city" VALUES(18635,'Porcupine','Porcupine, South Dakota',22932,49);
INSERT INTO "django_geo_db_city" VALUES(18636,'Pringle','Pringle, South Dakota',22933,49);
INSERT INTO "django_geo_db_city" VALUES(18637,'Provo','Provo, South Dakota',22934,49);
INSERT INTO "django_geo_db_city" VALUES(18638,'Quinn','Quinn, South Dakota',22935,49);
INSERT INTO "django_geo_db_city" VALUES(18639,'Redig','Redig, South Dakota',22936,49);
INSERT INTO "django_geo_db_city" VALUES(18640,'Red Owl','Red Owl, South Dakota',22937,49);
INSERT INTO "django_geo_db_city" VALUES(18641,'Rochford','Rochford, South Dakota',22938,49);
INSERT INTO "django_geo_db_city" VALUES(18642,'Saint Onge','Saint Onge, South Dakota',22939,49);
INSERT INTO "django_geo_db_city" VALUES(18643,'Scenic','Scenic, South Dakota',22940,49);
INSERT INTO "django_geo_db_city" VALUES(18644,'Smithwick','Smithwick, South Dakota',22941,49);
INSERT INTO "django_geo_db_city" VALUES(18645,'Spearfish','Spearfish, South Dakota',22942,49);
INSERT INTO "django_geo_db_city" VALUES(18646,'Sturgis','Sturgis, South Dakota',22943,49);
INSERT INTO "django_geo_db_city" VALUES(18647,'Union Center','Union Center, South Dakota',22944,49);
INSERT INTO "django_geo_db_city" VALUES(18648,'Vale','Vale, South Dakota',22945,49);
INSERT INTO "django_geo_db_city" VALUES(18649,'Wall','Wall, South Dakota',22946,49);
INSERT INTO "django_geo_db_city" VALUES(18650,'Wasta','Wasta, South Dakota',22947,49);
INSERT INTO "django_geo_db_city" VALUES(18651,'White Owl','White Owl, South Dakota',22948,49);
INSERT INTO "django_geo_db_city" VALUES(18652,'Whitewood','Whitewood, South Dakota',22949,49);
INSERT INTO "django_geo_db_city" VALUES(18653,'Wounded Knee','Wounded Knee, South Dakota',22950,49);
INSERT INTO "django_geo_db_city" VALUES(18654,'Carlisle','Carlisle, South Dakota',22954,49);
INSERT INTO "django_geo_db_city" VALUES(18655,'Big Sioux','Big Sioux, South Dakota',22955,49);
INSERT INTO "django_geo_db_city" VALUES(18656,'Minot','Minot, North Dakota',22956,34);
INSERT INTO "django_geo_db_city" VALUES(18657,'Abercrombie','Abercrombie, North Dakota',22957,34);
INSERT INTO "django_geo_db_city" VALUES(18658,'Absaraka','Absaraka, North Dakota',22958,34);
INSERT INTO "django_geo_db_city" VALUES(18659,'Amenia','Amenia, North Dakota',22959,34);
INSERT INTO "django_geo_db_city" VALUES(18660,'Argusville','Argusville, North Dakota',22960,34);
INSERT INTO "django_geo_db_city" VALUES(18661,'Arthur','Arthur, North Dakota',22961,34);
INSERT INTO "django_geo_db_city" VALUES(18662,'Ayr','Ayr, North Dakota',22962,34);
INSERT INTO "django_geo_db_city" VALUES(18663,'Barney','Barney, North Dakota',22963,34);
INSERT INTO "django_geo_db_city" VALUES(18664,'Blanchard','Blanchard, North Dakota',22964,34);
INSERT INTO "django_geo_db_city" VALUES(18665,'Buffalo','Buffalo, North Dakota',22965,34);
INSERT INTO "django_geo_db_city" VALUES(18666,'Casselton','Casselton, North Dakota',22966,34);
INSERT INTO "django_geo_db_city" VALUES(18667,'Cayuga','Cayuga, North Dakota',22967,34);
INSERT INTO "django_geo_db_city" VALUES(18668,'Chaffee','Chaffee, North Dakota',22968,34);
INSERT INTO "django_geo_db_city" VALUES(18669,'Christine','Christine, North Dakota',22969,34);
INSERT INTO "django_geo_db_city" VALUES(18670,'Clifford','Clifford, North Dakota',22970,34);
INSERT INTO "django_geo_db_city" VALUES(18671,'Cogswell','Cogswell, North Dakota',22971,34);
INSERT INTO "django_geo_db_city" VALUES(18672,'Colfax','Colfax, North Dakota',22972,34);
INSERT INTO "django_geo_db_city" VALUES(18673,'Davenport','Davenport, North Dakota',22973,34);
INSERT INTO "django_geo_db_city" VALUES(18674,'Enderlin','Enderlin, North Dakota',22974,34);
INSERT INTO "django_geo_db_city" VALUES(18675,'Erie','Erie, North Dakota',22975,34);
INSERT INTO "django_geo_db_city" VALUES(18676,'Fairmount','Fairmount, North Dakota',22976,34);
INSERT INTO "django_geo_db_city" VALUES(18677,'Fingal','Fingal, North Dakota',22977,34);
INSERT INTO "django_geo_db_city" VALUES(18678,'Forman','Forman, North Dakota',22978,34);
INSERT INTO "django_geo_db_city" VALUES(18679,'Fort Ransom','Fort Ransom, North Dakota',22979,34);
INSERT INTO "django_geo_db_city" VALUES(18680,'Galesburg','Galesburg, North Dakota',22980,34);
INSERT INTO "django_geo_db_city" VALUES(18681,'Gardner','Gardner, North Dakota',22981,34);
INSERT INTO "django_geo_db_city" VALUES(18682,'Grandin','Grandin, North Dakota',22982,34);
INSERT INTO "django_geo_db_city" VALUES(18683,'Great Bend','Great Bend, North Dakota',22983,34);
INSERT INTO "django_geo_db_city" VALUES(18684,'Gwinner','Gwinner, North Dakota',22984,34);
INSERT INTO "django_geo_db_city" VALUES(18685,'Hankinson','Hankinson, North Dakota',22985,34);
INSERT INTO "django_geo_db_city" VALUES(18686,'Harwood','Harwood, North Dakota',22986,34);
INSERT INTO "django_geo_db_city" VALUES(18687,'Havana','Havana, North Dakota',22987,34);
INSERT INTO "django_geo_db_city" VALUES(18688,'Hillsboro','Hillsboro, North Dakota',22988,34);
INSERT INTO "django_geo_db_city" VALUES(18689,'Hope','Hope, North Dakota',22989,34);
INSERT INTO "django_geo_db_city" VALUES(18690,'Horace','Horace, North Dakota',22990,34);
INSERT INTO "django_geo_db_city" VALUES(18691,'Hunter','Hunter, North Dakota',22991,34);
INSERT INTO "django_geo_db_city" VALUES(18692,'Kathryn','Kathryn, North Dakota',22992,34);
INSERT INTO "django_geo_db_city" VALUES(18693,'Kindred','Kindred, North Dakota',22993,34);
INSERT INTO "django_geo_db_city" VALUES(18694,'Leonard','Leonard, North Dakota',22994,34);
INSERT INTO "django_geo_db_city" VALUES(18695,'Lidgerwood','Lidgerwood, North Dakota',22995,34);
INSERT INTO "django_geo_db_city" VALUES(18696,'Lisbon','Lisbon, North Dakota',22996,34);
INSERT INTO "django_geo_db_city" VALUES(18697,'Luverne','Luverne, North Dakota',22997,34);
INSERT INTO "django_geo_db_city" VALUES(18698,'Mcleod','Mcleod, North Dakota',22998,34);
INSERT INTO "django_geo_db_city" VALUES(18699,'Mantador','Mantador, North Dakota',22999,34);
INSERT INTO "django_geo_db_city" VALUES(18700,'Mapleton','Mapleton, North Dakota',23000,34);
INSERT INTO "django_geo_db_city" VALUES(18701,'Milnor','Milnor, North Dakota',23001,34);
INSERT INTO "django_geo_db_city" VALUES(18702,'Mooreton','Mooreton, North Dakota',23002,34);
INSERT INTO "django_geo_db_city" VALUES(18703,'Nome','Nome, North Dakota',23003,34);
INSERT INTO "django_geo_db_city" VALUES(18704,'Oriska','Oriska, North Dakota',23004,34);
INSERT INTO "django_geo_db_city" VALUES(18705,'Page','Page, North Dakota',23005,34);
INSERT INTO "django_geo_db_city" VALUES(18706,'Pillsbury','Pillsbury, North Dakota',23006,34);
INSERT INTO "django_geo_db_city" VALUES(18707,'Rutland','Rutland, North Dakota',23007,34);
INSERT INTO "django_geo_db_city" VALUES(18708,'Sheldon','Sheldon, North Dakota',23008,34);
INSERT INTO "django_geo_db_city" VALUES(18709,'Stirum','Stirum, North Dakota',23009,34);
INSERT INTO "django_geo_db_city" VALUES(18710,'Tower City','Tower City, North Dakota',23010,34);
INSERT INTO "django_geo_db_city" VALUES(18711,'Valley City','Valley City, North Dakota',23011,34);
INSERT INTO "django_geo_db_city" VALUES(18712,'Wahpeton','Wahpeton, North Dakota',23012,34);
INSERT INTO "django_geo_db_city" VALUES(18713,'Walcott','Walcott, North Dakota',23015,34);
INSERT INTO "django_geo_db_city" VALUES(18714,'West Fargo','West Fargo, North Dakota',23016,34);
INSERT INTO "django_geo_db_city" VALUES(18715,'Wheatland','Wheatland, North Dakota',23017,34);
INSERT INTO "django_geo_db_city" VALUES(18716,'Wyndmere','Wyndmere, North Dakota',23018,34);
INSERT INTO "django_geo_db_city" VALUES(18717,'Fargo','Fargo, North Dakota',23019,34);
INSERT INTO "django_geo_db_city" VALUES(18718,'Grand Forks','Grand Forks, North Dakota',23025,34);
INSERT INTO "django_geo_db_city" VALUES(18719,'Grand Forks AFB','Grand Forks AFB, North Dakota',23028,34);
INSERT INTO "django_geo_db_city" VALUES(18720,'Adams','Adams, North Dakota',23030,34);
INSERT INTO "django_geo_db_city" VALUES(18721,'Aneta','Aneta, North Dakota',23031,34);
INSERT INTO "django_geo_db_city" VALUES(18722,'Ardoch','Ardoch, North Dakota',23032,34);
INSERT INTO "django_geo_db_city" VALUES(18723,'Arvilla','Arvilla, North Dakota',23033,34);
INSERT INTO "django_geo_db_city" VALUES(18724,'Bathgate','Bathgate, North Dakota',23034,34);
INSERT INTO "django_geo_db_city" VALUES(18725,'Buxton','Buxton, North Dakota',23035,34);
INSERT INTO "django_geo_db_city" VALUES(18726,'Caledonia','Caledonia, North Dakota',23036,34);
INSERT INTO "django_geo_db_city" VALUES(18727,'Cavalier','Cavalier, North Dakota',23037,34);
INSERT INTO "django_geo_db_city" VALUES(18728,'Crystal','Crystal, North Dakota',23038,34);
INSERT INTO "django_geo_db_city" VALUES(18729,'Cummings','Cummings, North Dakota',23039,34);
INSERT INTO "django_geo_db_city" VALUES(18730,'Dahlen','Dahlen, North Dakota',23040,34);
INSERT INTO "django_geo_db_city" VALUES(18731,'Drayton','Drayton, North Dakota',23041,34);
INSERT INTO "django_geo_db_city" VALUES(18732,'Edinburg','Edinburg, North Dakota',23042,34);
INSERT INTO "django_geo_db_city" VALUES(18733,'Emerado','Emerado, North Dakota',23043,34);
INSERT INTO "django_geo_db_city" VALUES(18734,'Fairdale','Fairdale, North Dakota',23044,34);
INSERT INTO "django_geo_db_city" VALUES(18735,'Finley','Finley, North Dakota',23045,34);
INSERT INTO "django_geo_db_city" VALUES(18736,'Fordville','Fordville, North Dakota',23046,34);
INSERT INTO "django_geo_db_city" VALUES(18737,'Forest River','Forest River, North Dakota',23047,34);
INSERT INTO "django_geo_db_city" VALUES(18738,'Brantford','Brantford, South Dakota',23048,49);
INSERT INTO "django_geo_db_city" VALUES(18739,'Gilby','Gilby, North Dakota',23049,34);
INSERT INTO "django_geo_db_city" VALUES(18740,'Glasston','Glasston, North Dakota',23050,34);
INSERT INTO "django_geo_db_city" VALUES(18741,'Grafton','Grafton, North Dakota',23051,34);
INSERT INTO "django_geo_db_city" VALUES(18742,'Hamilton','Hamilton, North Dakota',23052,34);
INSERT INTO "django_geo_db_city" VALUES(18743,'Hannah','Hannah, North Dakota',23053,34);
INSERT INTO "django_geo_db_city" VALUES(18744,'Hatton','Hatton, North Dakota',23054,34);
INSERT INTO "django_geo_db_city" VALUES(18745,'Hensel','Hensel, North Dakota',23055,34);
INSERT INTO "django_geo_db_city" VALUES(18746,'Hoople','Hoople, North Dakota',23056,34);
INSERT INTO "django_geo_db_city" VALUES(18747,'Inkster','Inkster, North Dakota',23057,34);
INSERT INTO "django_geo_db_city" VALUES(18748,'Langdon','Langdon, North Dakota',23058,34);
INSERT INTO "django_geo_db_city" VALUES(18749,'Lankin','Lankin, North Dakota',23059,34);
INSERT INTO "django_geo_db_city" VALUES(18750,'Larimore','Larimore, North Dakota',23060,34);
INSERT INTO "django_geo_db_city" VALUES(18751,'Mcville','Mcville, North Dakota',23061,34);
INSERT INTO "django_geo_db_city" VALUES(18752,'Maida','Maida, North Dakota',23062,34);
INSERT INTO "django_geo_db_city" VALUES(18753,'Manvel','Manvel, North Dakota',23063,34);
INSERT INTO "django_geo_db_city" VALUES(18754,'Mayville','Mayville, North Dakota',23064,34);
INSERT INTO "django_geo_db_city" VALUES(18755,'Mekinock','Mekinock, North Dakota',23065,34);
INSERT INTO "django_geo_db_city" VALUES(18756,'Michigan','Michigan, North Dakota',23066,34);
INSERT INTO "django_geo_db_city" VALUES(18757,'Milton','Milton, North Dakota',23067,34);
INSERT INTO "django_geo_db_city" VALUES(18758,'Minto','Minto, North Dakota',23068,34);
INSERT INTO "django_geo_db_city" VALUES(18759,'Mountain','Mountain, North Dakota',23069,34);
INSERT INTO "django_geo_db_city" VALUES(18760,'Neche','Neche, North Dakota',23070,34);
INSERT INTO "django_geo_db_city" VALUES(18761,'Niagara','Niagara, North Dakota',23071,34);
INSERT INTO "django_geo_db_city" VALUES(18762,'Northwood','Northwood, North Dakota',23072,34);
INSERT INTO "django_geo_db_city" VALUES(18763,'Osnabrock','Osnabrock, North Dakota',23073,34);
INSERT INTO "django_geo_db_city" VALUES(18764,'Park River','Park River, North Dakota',23074,34);
INSERT INTO "django_geo_db_city" VALUES(18765,'Pembina','Pembina, North Dakota',23075,34);
INSERT INTO "django_geo_db_city" VALUES(18766,'Petersburg','Petersburg, North Dakota',23076,34);
INSERT INTO "django_geo_db_city" VALUES(18767,'Pisek','Pisek, North Dakota',23077,34);
INSERT INTO "django_geo_db_city" VALUES(18768,'Portland','Portland, North Dakota',23078,34);
INSERT INTO "django_geo_db_city" VALUES(18769,'Reynolds','Reynolds, North Dakota',23079,34);
INSERT INTO "django_geo_db_city" VALUES(18770,'Saint Thomas','Saint Thomas, North Dakota',23080,34);
INSERT INTO "django_geo_db_city" VALUES(18771,'Sharon','Sharon, North Dakota',23081,34);
INSERT INTO "django_geo_db_city" VALUES(18772,'Thompson','Thompson, North Dakota',23082,34);
INSERT INTO "django_geo_db_city" VALUES(18773,'Wales','Wales, North Dakota',23083,34);
INSERT INTO "django_geo_db_city" VALUES(18774,'Walhalla','Walhalla, North Dakota',23084,34);
INSERT INTO "django_geo_db_city" VALUES(18775,'Farmington','Farmington, North Dakota',23085,34);
INSERT INTO "django_geo_db_city" VALUES(18776,'Poplar Grove','Poplar Grove, North Dakota',23086,34);
INSERT INTO "django_geo_db_city" VALUES(18777,'Devils Lake','Devils Lake, North Dakota',23087,34);
INSERT INTO "django_geo_db_city" VALUES(18778,'Agate','Agate, North Dakota',23088,34);
INSERT INTO "django_geo_db_city" VALUES(18779,'Alsen','Alsen, North Dakota',23089,34);
INSERT INTO "django_geo_db_city" VALUES(18780,'Balta','Balta, North Dakota',23090,34);
INSERT INTO "django_geo_db_city" VALUES(18781,'Belcourt','Belcourt, North Dakota',23091,34);
INSERT INTO "django_geo_db_city" VALUES(18782,'Bisbee','Bisbee, North Dakota',23092,34);
INSERT INTO "django_geo_db_city" VALUES(18783,'Bottineau','Bottineau, North Dakota',23093,34);
INSERT INTO "django_geo_db_city" VALUES(18784,'Bremen','Bremen, North Dakota',23094,34);
INSERT INTO "django_geo_db_city" VALUES(18785,'Brinsmade','Brinsmade, North Dakota',23095,34);
INSERT INTO "django_geo_db_city" VALUES(18786,'Brocket','Brocket, North Dakota',23096,34);
INSERT INTO "django_geo_db_city" VALUES(18787,'Calvin','Calvin, North Dakota',23097,34);
INSERT INTO "django_geo_db_city" VALUES(18788,'Cando','Cando, North Dakota',23098,34);
INSERT INTO "django_geo_db_city" VALUES(18789,'Churchs Ferry','Churchs Ferry, North Dakota',23099,34);
INSERT INTO "django_geo_db_city" VALUES(18790,'Crary','Crary, North Dakota',23100,34);
INSERT INTO "django_geo_db_city" VALUES(18791,'Dunseith','Dunseith, North Dakota',23101,34);
INSERT INTO "django_geo_db_city" VALUES(18792,'Edmore','Edmore, North Dakota',23102,34);
INSERT INTO "django_geo_db_city" VALUES(18793,'Egeland','Egeland, North Dakota',23103,34);
INSERT INTO "django_geo_db_city" VALUES(18794,'Esmond','Esmond, North Dakota',23104,34);
INSERT INTO "django_geo_db_city" VALUES(18795,'Sykeston','Sykeston, North Dakota',23105,34);
INSERT INTO "django_geo_db_city" VALUES(18796,'Fort Totten','Fort Totten, North Dakota',23106,34);
INSERT INTO "django_geo_db_city" VALUES(18797,'Hamberg','Hamberg, North Dakota',23107,34);
INSERT INTO "django_geo_db_city" VALUES(18798,'Hampden','Hampden, North Dakota',23108,34);
INSERT INTO "django_geo_db_city" VALUES(18799,'Hansboro','Hansboro, North Dakota',23109,34);
INSERT INTO "django_geo_db_city" VALUES(18800,'Harvey','Harvey, North Dakota',23110,34);
INSERT INTO "django_geo_db_city" VALUES(18801,'Knox','Knox, North Dakota',23111,34);
INSERT INTO "django_geo_db_city" VALUES(18802,'Lakota','Lakota, North Dakota',23112,34);
INSERT INTO "django_geo_db_city" VALUES(18803,'Lawton','Lawton, North Dakota',23113,34);
INSERT INTO "django_geo_db_city" VALUES(18804,'Leeds','Leeds, North Dakota',23114,34);
INSERT INTO "django_geo_db_city" VALUES(18805,'Maddock','Maddock, North Dakota',23115,34);
INSERT INTO "django_geo_db_city" VALUES(18806,'Minnewaukan','Minnewaukan, North Dakota',23116,34);
INSERT INTO "django_geo_db_city" VALUES(18807,'Munich','Munich, North Dakota',23117,34);
INSERT INTO "django_geo_db_city" VALUES(18808,'Mylo','Mylo, North Dakota',23118,34);
INSERT INTO "django_geo_db_city" VALUES(18809,'Nekoma','Nekoma, North Dakota',23119,34);
INSERT INTO "django_geo_db_city" VALUES(18810,'New Rockford','New Rockford, North Dakota',23120,34);
INSERT INTO "django_geo_db_city" VALUES(18811,'Oberon','Oberon, North Dakota',23121,34);
INSERT INTO "django_geo_db_city" VALUES(18812,'Fort Yates','Fort Yates, North Dakota',23122,34);
INSERT INTO "django_geo_db_city" VALUES(18813,'Orrin','Orrin, North Dakota',23123,34);
INSERT INTO "django_geo_db_city" VALUES(18814,'Pekin','Pekin, North Dakota',23124,34);
INSERT INTO "django_geo_db_city" VALUES(18815,'Penn','Penn, North Dakota',23125,34);
INSERT INTO "django_geo_db_city" VALUES(18816,'Perth','Perth, North Dakota',23126,34);
INSERT INTO "django_geo_db_city" VALUES(18817,'Rocklake','Rocklake, North Dakota',23127,34);
INSERT INTO "django_geo_db_city" VALUES(18818,'Rolette','Rolette, North Dakota',23128,34);
INSERT INTO "django_geo_db_city" VALUES(18819,'Rolla','Rolla, North Dakota',23129,34);
INSERT INTO "django_geo_db_city" VALUES(18820,'Rugby','Rugby, North Dakota',23130,34);
INSERT INTO "django_geo_db_city" VALUES(18821,'Saint John','Saint John, North Dakota',23131,34);
INSERT INTO "django_geo_db_city" VALUES(18822,'Saint Michael','Saint Michael, North Dakota',23132,34);
INSERT INTO "django_geo_db_city" VALUES(18823,'Grandfield','Grandfield, North Dakota',23133,34);
INSERT INTO "django_geo_db_city" VALUES(18824,'Sarles','Sarles, North Dakota',23134,34);
INSERT INTO "django_geo_db_city" VALUES(18825,'Sheyenne','Sheyenne, North Dakota',23135,34);
INSERT INTO "django_geo_db_city" VALUES(18826,'Starkweather','Starkweather, North Dakota',23136,34);
INSERT INTO "django_geo_db_city" VALUES(18827,'Tokio','Tokio, North Dakota',23137,34);
INSERT INTO "django_geo_db_city" VALUES(18828,'Tolna','Tolna, North Dakota',23138,34);
INSERT INTO "django_geo_db_city" VALUES(18829,'Warwick','Warwick, North Dakota',23139,34);
INSERT INTO "django_geo_db_city" VALUES(18830,'Webster','Webster, North Dakota',23140,34);
INSERT INTO "django_geo_db_city" VALUES(18831,'Willow City','Willow City, North Dakota',23141,34);
INSERT INTO "django_geo_db_city" VALUES(18832,'Wolford','Wolford, North Dakota',23142,34);
INSERT INTO "django_geo_db_city" VALUES(18833,'York','York, North Dakota',23143,34);
INSERT INTO "django_geo_db_city" VALUES(18834,'Jamestown','Jamestown, North Dakota',23144,34);
INSERT INTO "django_geo_db_city" VALUES(18835,'Ashley','Ashley, North Dakota',23147,34);
INSERT INTO "django_geo_db_city" VALUES(18836,'Berlin','Berlin, North Dakota',23148,34);
INSERT INTO "django_geo_db_city" VALUES(18837,'Binford','Binford, North Dakota',23149,34);
INSERT INTO "django_geo_db_city" VALUES(18838,'Bowdon','Bowdon, North Dakota',23150,34);
INSERT INTO "django_geo_db_city" VALUES(18839,'Buchanan','Buchanan, North Dakota',23151,34);
INSERT INTO "django_geo_db_city" VALUES(18840,'Carrington','Carrington, North Dakota',23152,34);
INSERT INTO "django_geo_db_city" VALUES(18841,'Cathay','Cathay, North Dakota',23153,34);
INSERT INTO "django_geo_db_city" VALUES(18842,'Chaseley','Chaseley, North Dakota',23154,34);
INSERT INTO "django_geo_db_city" VALUES(18843,'Cleveland','Cleveland, North Dakota',23155,34);
INSERT INTO "django_geo_db_city" VALUES(18844,'Cooperstown','Cooperstown, North Dakota',23156,34);
INSERT INTO "django_geo_db_city" VALUES(18845,'Courtenay','Courtenay, North Dakota',23157,34);
INSERT INTO "django_geo_db_city" VALUES(18846,'Dawson','Dawson, North Dakota',23158,34);
INSERT INTO "django_geo_db_city" VALUES(18847,'Dazey','Dazey, North Dakota',23159,34);
INSERT INTO "django_geo_db_city" VALUES(18848,'Denhoff','Denhoff, North Dakota',23160,34);
INSERT INTO "django_geo_db_city" VALUES(18849,'Dickey','Dickey, North Dakota',23161,34);
INSERT INTO "django_geo_db_city" VALUES(18850,'Eckelson','Eckelson, North Dakota',23162,34);
INSERT INTO "django_geo_db_city" VALUES(18851,'Edgeley','Edgeley, North Dakota',23163,34);
INSERT INTO "django_geo_db_city" VALUES(18852,'Ellendale','Ellendale, North Dakota',23164,34);
INSERT INTO "django_geo_db_city" VALUES(18853,'Fessenden','Fessenden, North Dakota',23165,34);
INSERT INTO "django_geo_db_city" VALUES(18854,'Forbes','Forbes, North Dakota',23166,34);
INSERT INTO "django_geo_db_city" VALUES(18855,'Fredonia','Fredonia, North Dakota',23167,34);
INSERT INTO "django_geo_db_city" VALUES(18856,'Fullerton','Fullerton, North Dakota',23168,34);
INSERT INTO "django_geo_db_city" VALUES(18857,'Gackle','Gackle, North Dakota',23169,34);
INSERT INTO "django_geo_db_city" VALUES(18858,'Glenfield','Glenfield, North Dakota',23170,34);
INSERT INTO "django_geo_db_city" VALUES(18859,'Goodrich','Goodrich, North Dakota',23171,34);
INSERT INTO "django_geo_db_city" VALUES(18860,'Grace City','Grace City, North Dakota',23172,34);
INSERT INTO "django_geo_db_city" VALUES(18861,'Hannaford','Hannaford, North Dakota',23173,34);
INSERT INTO "django_geo_db_city" VALUES(18862,'Hurdsfield','Hurdsfield, North Dakota',23174,34);
INSERT INTO "django_geo_db_city" VALUES(18863,'Jessie','Jessie, North Dakota',23175,34);
INSERT INTO "django_geo_db_city" VALUES(18864,'Jud','Jud, North Dakota',23176,34);
INSERT INTO "django_geo_db_city" VALUES(18865,'Kensal','Kensal, North Dakota',23177,34);
INSERT INTO "django_geo_db_city" VALUES(18866,'Kulm','Kulm, North Dakota',23178,34);
INSERT INTO "django_geo_db_city" VALUES(18867,'Lamoure','Lamoure, North Dakota',23179,34);
INSERT INTO "django_geo_db_city" VALUES(18868,'Lehr','Lehr, North Dakota',23180,34);
INSERT INTO "django_geo_db_city" VALUES(18869,'Litchville','Litchville, North Dakota',23181,34);
INSERT INTO "django_geo_db_city" VALUES(18870,'Mcclusky','Mcclusky, North Dakota',23182,34);
INSERT INTO "django_geo_db_city" VALUES(18871,'Mchenry','Mchenry, North Dakota',23183,34);
INSERT INTO "django_geo_db_city" VALUES(18872,'Marion','Marion, North Dakota',23184,34);
INSERT INTO "django_geo_db_city" VALUES(18873,'Medina','Medina, North Dakota',23185,34);
INSERT INTO "django_geo_db_city" VALUES(18874,'Montpelier','Montpelier, North Dakota',23186,34);
INSERT INTO "django_geo_db_city" VALUES(18875,'Oakes','Oakes, North Dakota',23187,34);
INSERT INTO "django_geo_db_city" VALUES(18876,'Pettibone','Pettibone, North Dakota',23188,34);
INSERT INTO "django_geo_db_city" VALUES(18877,'Pingree','Pingree, North Dakota',23189,34);
INSERT INTO "django_geo_db_city" VALUES(18878,'Regan','Regan, North Dakota',23190,34);
INSERT INTO "django_geo_db_city" VALUES(18879,'Robinson','Robinson, North Dakota',23191,34);
INSERT INTO "django_geo_db_city" VALUES(18880,'Rogers','Rogers, North Dakota',23192,34);
INSERT INTO "django_geo_db_city" VALUES(18881,'Sanborn','Sanborn, North Dakota',23193,34);
INSERT INTO "django_geo_db_city" VALUES(18882,'Spiritwood','Spiritwood, North Dakota',23194,34);
INSERT INTO "django_geo_db_city" VALUES(18883,'Steele','Steele, North Dakota',23195,34);
INSERT INTO "django_geo_db_city" VALUES(18884,'Streeter','Streeter, North Dakota',23196,34);
INSERT INTO "django_geo_db_city" VALUES(18885,'Sutton','Sutton, North Dakota',23197,34);
INSERT INTO "django_geo_db_city" VALUES(18886,'Tappen','Tappen, North Dakota',23199,34);
INSERT INTO "django_geo_db_city" VALUES(18887,'Tuttle','Tuttle, North Dakota',23200,34);
INSERT INTO "django_geo_db_city" VALUES(18888,'Venturia','Venturia, North Dakota',23201,34);
INSERT INTO "django_geo_db_city" VALUES(18889,'Verona','Verona, North Dakota',23202,34);
INSERT INTO "django_geo_db_city" VALUES(18890,'Wimbledon','Wimbledon, North Dakota',23203,34);
INSERT INTO "django_geo_db_city" VALUES(18891,'Wing','Wing, North Dakota',23204,34);
INSERT INTO "django_geo_db_city" VALUES(18892,'Wishek','Wishek, North Dakota',23205,34);
INSERT INTO "django_geo_db_city" VALUES(18893,'Woodworth','Woodworth, North Dakota',23206,34);
INSERT INTO "django_geo_db_city" VALUES(18894,'Ypsilanti','Ypsilanti, North Dakota',23207,34);
INSERT INTO "django_geo_db_city" VALUES(18895,'Bismarck','Bismarck, North Dakota',23208,34);
INSERT INTO "django_geo_db_city" VALUES(18896,'Almont','Almont, North Dakota',23214,34);
INSERT INTO "django_geo_db_city" VALUES(18897,'Baldwin','Baldwin, North Dakota',23215,34);
INSERT INTO "django_geo_db_city" VALUES(18898,'Beulah','Beulah, North Dakota',23216,34);
INSERT INTO "django_geo_db_city" VALUES(18899,'Braddock','Braddock, North Dakota',23217,34);
INSERT INTO "django_geo_db_city" VALUES(18900,'Cannon Ball','Cannon Ball, North Dakota',23218,34);
INSERT INTO "django_geo_db_city" VALUES(18901,'Carson','Carson, North Dakota',23219,34);
INSERT INTO "django_geo_db_city" VALUES(18902,'Center','Center, North Dakota',23220,34);
INSERT INTO "django_geo_db_city" VALUES(18903,'Coleharbor','Coleharbor, North Dakota',23221,34);
INSERT INTO "django_geo_db_city" VALUES(18904,'Driscoll','Driscoll, North Dakota',23222,34);
INSERT INTO "django_geo_db_city" VALUES(18905,'Elgin','Elgin, North Dakota',23223,34);
INSERT INTO "django_geo_db_city" VALUES(18906,'Flasher','Flasher, North Dakota',23224,34);
INSERT INTO "django_geo_db_city" VALUES(18907,'Garrison','Garrison, North Dakota',23226,34);
INSERT INTO "django_geo_db_city" VALUES(18908,'Golden Valley','Golden Valley, North Dakota',23227,34);
INSERT INTO "django_geo_db_city" VALUES(18909,'Hague','Hague, North Dakota',23228,34);
INSERT INTO "django_geo_db_city" VALUES(18910,'Hazelton','Hazelton, North Dakota',23229,34);
INSERT INTO "django_geo_db_city" VALUES(18911,'Hazen','Hazen, North Dakota',23230,34);
INSERT INTO "django_geo_db_city" VALUES(18912,'Kintyre','Kintyre, North Dakota',23231,34);
INSERT INTO "django_geo_db_city" VALUES(18913,'Linton','Linton, North Dakota',23232,34);
INSERT INTO "django_geo_db_city" VALUES(18914,'Mckenzie','Mckenzie, North Dakota',23233,34);
INSERT INTO "django_geo_db_city" VALUES(18915,'Mandan','Mandan, North Dakota',23234,34);
INSERT INTO "django_geo_db_city" VALUES(18916,'Menoken','Menoken, North Dakota',23235,34);
INSERT INTO "django_geo_db_city" VALUES(18917,'Mercer','Mercer, North Dakota',23236,34);
INSERT INTO "django_geo_db_city" VALUES(18918,'Moffit','Moffit, North Dakota',23237,34);
INSERT INTO "django_geo_db_city" VALUES(18919,'Napoleon','Napoleon, North Dakota',23238,34);
INSERT INTO "django_geo_db_city" VALUES(18920,'New Leipzig','New Leipzig, North Dakota',23239,34);
INSERT INTO "django_geo_db_city" VALUES(18921,'New Salem','New Salem, North Dakota',23240,34);
INSERT INTO "django_geo_db_city" VALUES(18922,'Raleigh','Raleigh, North Dakota',23241,34);
INSERT INTO "django_geo_db_city" VALUES(18923,'Riverdale','Riverdale, North Dakota',23242,34);
INSERT INTO "django_geo_db_city" VALUES(18924,'Saint Anthony','Saint Anthony, North Dakota',23243,34);
INSERT INTO "django_geo_db_city" VALUES(18925,'Selfridge','Selfridge, North Dakota',23244,34);
INSERT INTO "django_geo_db_city" VALUES(18926,'Shields','Shields, North Dakota',23245,34);
INSERT INTO "django_geo_db_city" VALUES(18927,'Solen','Solen, North Dakota',23246,34);
INSERT INTO "django_geo_db_city" VALUES(18928,'Stanton','Stanton, North Dakota',23247,34);
INSERT INTO "django_geo_db_city" VALUES(18929,'Sterling','Sterling, North Dakota',23248,34);
INSERT INTO "django_geo_db_city" VALUES(18930,'Strasburg','Strasburg, North Dakota',23249,34);
INSERT INTO "django_geo_db_city" VALUES(18931,'Turtle Lake','Turtle Lake, North Dakota',23250,34);
INSERT INTO "django_geo_db_city" VALUES(18932,'Underwood','Underwood, North Dakota',23251,34);
INSERT INTO "django_geo_db_city" VALUES(18933,'Washburn','Washburn, North Dakota',23252,34);
INSERT INTO "django_geo_db_city" VALUES(18934,'Wilton','Wilton, North Dakota',23253,34);
INSERT INTO "django_geo_db_city" VALUES(18935,'Zap','Zap, North Dakota',23254,34);
INSERT INTO "django_geo_db_city" VALUES(18936,'Zeeland','Zeeland, North Dakota',23255,34);
INSERT INTO "django_geo_db_city" VALUES(18937,'Dickinson','Dickinson, North Dakota',23256,34);
INSERT INTO "django_geo_db_city" VALUES(18938,'Amidon','Amidon, North Dakota',23258,34);
INSERT INTO "django_geo_db_city" VALUES(18939,'Beach','Beach, North Dakota',23259,34);
INSERT INTO "django_geo_db_city" VALUES(18940,'Belfield','Belfield, North Dakota',23260,34);
INSERT INTO "django_geo_db_city" VALUES(18941,'Bowman','Bowman, North Dakota',23261,34);
INSERT INTO "django_geo_db_city" VALUES(18942,'Dodge','Dodge, North Dakota',23262,34);
INSERT INTO "django_geo_db_city" VALUES(18943,'Dunn Center','Dunn Center, North Dakota',23263,34);
INSERT INTO "django_geo_db_city" VALUES(18944,'Fairfield','Fairfield, North Dakota',23264,34);
INSERT INTO "django_geo_db_city" VALUES(18945,'Gladstone','Gladstone, North Dakota',23265,34);
INSERT INTO "django_geo_db_city" VALUES(18946,'Glen Ullin','Glen Ullin, North Dakota',23266,34);
INSERT INTO "django_geo_db_city" VALUES(18947,'Golva','Golva, North Dakota',23267,34);
INSERT INTO "django_geo_db_city" VALUES(18948,'Grassy Butte','Grassy Butte, North Dakota',23268,34);
INSERT INTO "django_geo_db_city" VALUES(18949,'Halliday','Halliday, North Dakota',23269,34);
INSERT INTO "django_geo_db_city" VALUES(18950,'Hebron','Hebron, North Dakota',23270,34);
INSERT INTO "django_geo_db_city" VALUES(18951,'Hettinger','Hettinger, North Dakota',23271,34);
INSERT INTO "django_geo_db_city" VALUES(18952,'Killdeer','Killdeer, North Dakota',23272,34);
INSERT INTO "django_geo_db_city" VALUES(18953,'Lefor','Lefor, North Dakota',23273,34);
INSERT INTO "django_geo_db_city" VALUES(18954,'Manning','Manning, North Dakota',23274,34);
INSERT INTO "django_geo_db_city" VALUES(18955,'Marmarth','Marmarth, North Dakota',23275,34);
INSERT INTO "django_geo_db_city" VALUES(18956,'Marshall','Marshall, North Dakota',23276,34);
INSERT INTO "django_geo_db_city" VALUES(18957,'Medora','Medora, North Dakota',23277,34);
INSERT INTO "django_geo_db_city" VALUES(18958,'Mott','Mott, North Dakota',23278,34);
INSERT INTO "django_geo_db_city" VALUES(18959,'New England','New England, North Dakota',23279,34);
INSERT INTO "django_geo_db_city" VALUES(18960,'Reeder','Reeder, North Dakota',23280,34);
INSERT INTO "django_geo_db_city" VALUES(18961,'Regent','Regent, North Dakota',23281,34);
INSERT INTO "django_geo_db_city" VALUES(18962,'Rhame','Rhame, North Dakota',23282,34);
INSERT INTO "django_geo_db_city" VALUES(18963,'Richardton','Richardton, North Dakota',23283,34);
INSERT INTO "django_geo_db_city" VALUES(18964,'Scranton','Scranton, North Dakota',23284,34);
INSERT INTO "django_geo_db_city" VALUES(18965,'Sentinel Butte','Sentinel Butte, North Dakota',23285,34);
INSERT INTO "django_geo_db_city" VALUES(18966,'South Heart','South Heart, North Dakota',23286,34);
INSERT INTO "django_geo_db_city" VALUES(18967,'Taylor','Taylor, North Dakota',23287,34);
INSERT INTO "django_geo_db_city" VALUES(18968,'Minot AFB','Minot AFB, North Dakota',23292,34);
INSERT INTO "django_geo_db_city" VALUES(18969,'Anamoose','Anamoose, North Dakota',23295,34);
INSERT INTO "django_geo_db_city" VALUES(18970,'Antler','Antler, North Dakota',23296,34);
INSERT INTO "django_geo_db_city" VALUES(18971,'Balfour','Balfour, North Dakota',23297,34);
INSERT INTO "django_geo_db_city" VALUES(18972,'Bantry','Bantry, North Dakota',23298,34);
INSERT INTO "django_geo_db_city" VALUES(18973,'Benedict','Benedict, North Dakota',23299,34);
INSERT INTO "django_geo_db_city" VALUES(18974,'Berthold','Berthold, North Dakota',23300,34);
INSERT INTO "django_geo_db_city" VALUES(18975,'Bowbells','Bowbells, North Dakota',23301,34);
INSERT INTO "django_geo_db_city" VALUES(18976,'Burlington','Burlington, North Dakota',23302,34);
INSERT INTO "django_geo_db_city" VALUES(18977,'Butte','Butte, North Dakota',23303,34);
INSERT INTO "django_geo_db_city" VALUES(18978,'Carpio','Carpio, North Dakota',23304,34);
INSERT INTO "django_geo_db_city" VALUES(18979,'Columbus','Columbus, North Dakota',23305,34);
INSERT INTO "django_geo_db_city" VALUES(18980,'Crosby','Crosby, North Dakota',23306,34);
INSERT INTO "django_geo_db_city" VALUES(18981,'Deering','Deering, North Dakota',23307,34);
INSERT INTO "django_geo_db_city" VALUES(18982,'Des Lacs','Des Lacs, North Dakota',23308,34);
INSERT INTO "django_geo_db_city" VALUES(18983,'Donnybrook','Donnybrook, North Dakota',23309,34);
INSERT INTO "django_geo_db_city" VALUES(18984,'Douglas','Douglas, North Dakota',23310,34);
INSERT INTO "django_geo_db_city" VALUES(18985,'Drake','Drake, North Dakota',23311,34);
INSERT INTO "django_geo_db_city" VALUES(18986,'Flaxton','Flaxton, North Dakota',23312,34);
INSERT INTO "django_geo_db_city" VALUES(18987,'Glenburn','Glenburn, North Dakota',23313,34);
INSERT INTO "django_geo_db_city" VALUES(18988,'Granville','Granville, North Dakota',23314,34);
INSERT INTO "django_geo_db_city" VALUES(18989,'Karlsruhe','Karlsruhe, North Dakota',23315,34);
INSERT INTO "django_geo_db_city" VALUES(18990,'Kenmare','Kenmare, North Dakota',23316,34);
INSERT INTO "django_geo_db_city" VALUES(18991,'Kief','Kief, North Dakota',23317,34);
INSERT INTO "django_geo_db_city" VALUES(18992,'Kramer','Kramer, North Dakota',23318,34);
INSERT INTO "django_geo_db_city" VALUES(18993,'Lansford','Lansford, North Dakota',23319,34);
INSERT INTO "django_geo_db_city" VALUES(18994,'Lignite','Lignite, North Dakota',23320,34);
INSERT INTO "django_geo_db_city" VALUES(18995,'Mcgregor','Mcgregor, North Dakota',23321,34);
INSERT INTO "django_geo_db_city" VALUES(18996,'Makoti','Makoti, North Dakota',23322,34);
INSERT INTO "django_geo_db_city" VALUES(18997,'Mandaree','Mandaree, North Dakota',23323,34);
INSERT INTO "django_geo_db_city" VALUES(18998,'Martin','Martin, North Dakota',23324,34);
INSERT INTO "django_geo_db_city" VALUES(18999,'Max','Max, North Dakota',23325,34);
INSERT INTO "django_geo_db_city" VALUES(19000,'Maxbass','Maxbass, North Dakota',23326,34);
INSERT INTO "django_geo_db_city" VALUES(19001,'Mohall','Mohall, North Dakota',23327,34);
INSERT INTO "django_geo_db_city" VALUES(19002,'Newburg','Newburg, North Dakota',23328,34);
INSERT INTO "django_geo_db_city" VALUES(19003,'New Town','New Town, North Dakota',23329,34);
INSERT INTO "django_geo_db_city" VALUES(19004,'Clay','Clay, North Dakota',23330,34);
INSERT INTO "django_geo_db_city" VALUES(19005,'Noonan','Noonan, North Dakota',23331,34);
INSERT INTO "django_geo_db_city" VALUES(19006,'Norwich','Norwich, North Dakota',23332,34);
INSERT INTO "django_geo_db_city" VALUES(19007,'Palermo','Palermo, North Dakota',23333,34);
INSERT INTO "django_geo_db_city" VALUES(19008,'Parshall','Parshall, North Dakota',23334,34);
INSERT INTO "django_geo_db_city" VALUES(19009,'Plaza','Plaza, North Dakota',23335,34);
INSERT INTO "django_geo_db_city" VALUES(19010,'Portal','Portal, North Dakota',23336,34);
INSERT INTO "django_geo_db_city" VALUES(19011,'Powers Lake','Powers Lake, North Dakota',23337,34);
INSERT INTO "django_geo_db_city" VALUES(19012,'Roseglen','Roseglen, North Dakota',23338,34);
INSERT INTO "django_geo_db_city" VALUES(19013,'Ross','Ross, North Dakota',23339,34);
INSERT INTO "django_geo_db_city" VALUES(19014,'Ruso','Ruso, North Dakota',23340,34);
INSERT INTO "django_geo_db_city" VALUES(19015,'Ryder','Ryder, North Dakota',23341,34);
INSERT INTO "django_geo_db_city" VALUES(19016,'Sawyer','Sawyer, North Dakota',23342,34);
INSERT INTO "django_geo_db_city" VALUES(19017,'Sherwood','Sherwood, North Dakota',23343,34);
INSERT INTO "django_geo_db_city" VALUES(19018,'Souris','Souris, North Dakota',23344,34);
INSERT INTO "django_geo_db_city" VALUES(19019,'Stanley','Stanley, North Dakota',23345,34);
INSERT INTO "django_geo_db_city" VALUES(19020,'Surrey','Surrey, North Dakota',23346,34);
INSERT INTO "django_geo_db_city" VALUES(19021,'Tolley','Tolley, North Dakota',23347,34);
INSERT INTO "django_geo_db_city" VALUES(19022,'Towner','Towner, North Dakota',23348,34);
INSERT INTO "django_geo_db_city" VALUES(19023,'Upham','Upham, North Dakota',23349,34);
INSERT INTO "django_geo_db_city" VALUES(19024,'Velva','Velva, North Dakota',23350,34);
INSERT INTO "django_geo_db_city" VALUES(19025,'Voltaire','Voltaire, North Dakota',23351,34);
INSERT INTO "django_geo_db_city" VALUES(19026,'Westhope','Westhope, North Dakota',23352,34);
INSERT INTO "django_geo_db_city" VALUES(19027,'White Earth','White Earth, North Dakota',23353,34);
INSERT INTO "django_geo_db_city" VALUES(19028,'Wildrose','Wildrose, North Dakota',23354,34);
INSERT INTO "django_geo_db_city" VALUES(19029,'Williston','Williston, North Dakota',23355,34);
INSERT INTO "django_geo_db_city" VALUES(19030,'Alamo','Alamo, North Dakota',23357,34);
INSERT INTO "django_geo_db_city" VALUES(19031,'Alexander','Alexander, North Dakota',23358,34);
INSERT INTO "django_geo_db_city" VALUES(19032,'Westby','Westby, North Dakota',23359,34);
INSERT INTO "django_geo_db_city" VALUES(19033,'Ambrose','Ambrose, North Dakota',23360,34);
INSERT INTO "django_geo_db_city" VALUES(19034,'Arnegard','Arnegard, North Dakota',23361,34);
INSERT INTO "django_geo_db_city" VALUES(19035,'Cartwright','Cartwright, North Dakota',23362,34);
INSERT INTO "django_geo_db_city" VALUES(19036,'Epping','Epping, North Dakota',23363,34);
INSERT INTO "django_geo_db_city" VALUES(19037,'Fortuna','Fortuna, North Dakota',23364,34);
INSERT INTO "django_geo_db_city" VALUES(19038,'Grenora','Grenora, North Dakota',23365,34);
INSERT INTO "django_geo_db_city" VALUES(19039,'Keene','Keene, North Dakota',23366,34);
INSERT INTO "django_geo_db_city" VALUES(19040,'Ray','Ray, North Dakota',23367,34);
INSERT INTO "django_geo_db_city" VALUES(19041,'Tioga','Tioga, North Dakota',23368,34);
INSERT INTO "django_geo_db_city" VALUES(19042,'Trenton','Trenton, North Dakota',23369,34);
INSERT INTO "django_geo_db_city" VALUES(19043,'Watford City','Watford City, North Dakota',23370,34);
INSERT INTO "django_geo_db_city" VALUES(19044,'Zahl','Zahl, North Dakota',23371,34);
INSERT INTO "django_geo_db_city" VALUES(19045,'Colquhoun','Colquhoun, North Dakota',23373,34);
INSERT INTO "django_geo_db_city" VALUES(19046,'Roundup','Roundup, Montana',23374,26);
INSERT INTO "django_geo_db_city" VALUES(19047,'Absarokee','Absarokee, Montana',23375,26);
INSERT INTO "django_geo_db_city" VALUES(19048,'Acton','Acton, Montana',23376,26);
INSERT INTO "django_geo_db_city" VALUES(19049,'Ashland','Ashland, Montana',23377,26);
INSERT INTO "django_geo_db_city" VALUES(19050,'Ballantine','Ballantine, Montana',23379,26);
INSERT INTO "django_geo_db_city" VALUES(19051,'Bearcreek','Bearcreek, Montana',23380,26);
INSERT INTO "django_geo_db_city" VALUES(19052,'Belfry','Belfry, Montana',23381,26);
INSERT INTO "django_geo_db_city" VALUES(19053,'Bighorn','Bighorn, Montana',23382,26);
INSERT INTO "django_geo_db_city" VALUES(19054,'Big Timber','Big Timber, Montana',23383,26);
INSERT INTO "django_geo_db_city" VALUES(19055,'Birney','Birney, Montana',23384,26);
INSERT INTO "django_geo_db_city" VALUES(19056,'Boyd','Boyd, Montana',23385,26);
INSERT INTO "django_geo_db_city" VALUES(19057,'Bridger','Bridger, Montana',23386,26);
INSERT INTO "django_geo_db_city" VALUES(19058,'Broadview','Broadview, Montana',23387,26);
INSERT INTO "django_geo_db_city" VALUES(19059,'Busby','Busby, Montana',23388,26);
INSERT INTO "django_geo_db_city" VALUES(19060,'Clyde Park','Clyde Park, Montana',23389,26);
INSERT INTO "django_geo_db_city" VALUES(19061,'Columbus','Columbus, Montana',23390,26);
INSERT INTO "django_geo_db_city" VALUES(19062,'Cooke City','Cooke City, Montana',23391,26);
INSERT INTO "django_geo_db_city" VALUES(19063,'Crow Agency','Crow Agency, Montana',23392,26);
INSERT INTO "django_geo_db_city" VALUES(19064,'Custer','Custer, Montana',23393,26);
INSERT INTO "django_geo_db_city" VALUES(19065,'Decker','Decker, Montana',23394,26);
INSERT INTO "django_geo_db_city" VALUES(19066,'Edgar','Edgar, Montana',23395,26);
INSERT INTO "django_geo_db_city" VALUES(19067,'Emigrant','Emigrant, Montana',23396,26);
INSERT INTO "django_geo_db_city" VALUES(19068,'Fishtail','Fishtail, Montana',23397,26);
INSERT INTO "django_geo_db_city" VALUES(19069,'Fromberg','Fromberg, Montana',23398,26);
INSERT INTO "django_geo_db_city" VALUES(19070,'Gardiner','Gardiner, Montana',23399,26);
INSERT INTO "django_geo_db_city" VALUES(19071,'Garryowen','Garryowen, Montana',23400,26);
INSERT INTO "django_geo_db_city" VALUES(19072,'Grass Range','Grass Range, Montana',23401,26);
INSERT INTO "django_geo_db_city" VALUES(19073,'Greycliff','Greycliff, Montana',23402,26);
INSERT INTO "django_geo_db_city" VALUES(19074,'Hardin','Hardin, Montana',23403,26);
INSERT INTO "django_geo_db_city" VALUES(19075,'Yellowtail','Yellowtail, Montana',23404,26);
INSERT INTO "django_geo_db_city" VALUES(19076,'Harlowton','Harlowton, Montana',23405,26);
INSERT INTO "django_geo_db_city" VALUES(19077,'Huntley','Huntley, Montana',23406,26);
INSERT INTO "django_geo_db_city" VALUES(19078,'Hysham','Hysham, Montana',23407,26);
INSERT INTO "django_geo_db_city" VALUES(19079,'Ingomar','Ingomar, Montana',23408,26);
INSERT INTO "django_geo_db_city" VALUES(19080,'Joliet','Joliet, Montana',23409,26);
INSERT INTO "django_geo_db_city" VALUES(19081,'Lame Deer','Lame Deer, Montana',23410,26);
INSERT INTO "django_geo_db_city" VALUES(19082,'Laurel','Laurel, Montana',23411,26);
INSERT INTO "django_geo_db_city" VALUES(19083,'Lavina','Lavina, Montana',23412,26);
INSERT INTO "django_geo_db_city" VALUES(19084,'Livingston','Livingston, Montana',23413,26);
INSERT INTO "django_geo_db_city" VALUES(19085,'Lodge Grass','Lodge Grass, Montana',23414,26);
INSERT INTO "django_geo_db_city" VALUES(19086,'McLeod','McLeod, Montana',23415,26);
INSERT INTO "django_geo_db_city" VALUES(19087,'Martinsdale','Martinsdale, Montana',23416,26);
INSERT INTO "django_geo_db_city" VALUES(19088,'Melstone','Melstone, Montana',23417,26);
INSERT INTO "django_geo_db_city" VALUES(19089,'Melville','Melville, Montana',23418,26);
INSERT INTO "django_geo_db_city" VALUES(19090,'Molt','Molt, Montana',23419,26);
INSERT INTO "django_geo_db_city" VALUES(19091,'Mosby','Mosby, Montana',23420,26);
INSERT INTO "django_geo_db_city" VALUES(19092,'Musselshell','Musselshell, Montana',23421,26);
INSERT INTO "django_geo_db_city" VALUES(19093,'Nye','Nye, Montana',23422,26);
INSERT INTO "django_geo_db_city" VALUES(19094,'Otter','Otter, Montana',23423,26);
INSERT INTO "django_geo_db_city" VALUES(19095,'Park City','Park City, Montana',23424,26);
INSERT INTO "django_geo_db_city" VALUES(19096,'Pompeys Pillar','Pompeys Pillar, Montana',23425,26);
INSERT INTO "django_geo_db_city" VALUES(19097,'Pray','Pray, Montana',23426,26);
INSERT INTO "django_geo_db_city" VALUES(19098,'Pryor','Pryor, Montana',23427,26);
INSERT INTO "django_geo_db_city" VALUES(19099,'Rapelje','Rapelje, Montana',23428,26);
INSERT INTO "django_geo_db_city" VALUES(19100,'Red Lodge','Red Lodge, Montana',23429,26);
INSERT INTO "django_geo_db_city" VALUES(19101,'Reed Point','Reed Point, Montana',23430,26);
INSERT INTO "django_geo_db_city" VALUES(19102,'Roberts','Roberts, Montana',23431,26);
INSERT INTO "django_geo_db_city" VALUES(19103,'Roscoe','Roscoe, Montana',23432,26);
INSERT INTO "django_geo_db_city" VALUES(19104,'Ryegate','Ryegate, Montana',23435,26);
INSERT INTO "django_geo_db_city" VALUES(19105,'Saint Xavier','Saint Xavier, Montana',23436,26);
INSERT INTO "django_geo_db_city" VALUES(19106,'Sanders','Sanders, Montana',23437,26);
INSERT INTO "django_geo_db_city" VALUES(19107,'Sand Springs','Sand Springs, Montana',23438,26);
INSERT INTO "django_geo_db_city" VALUES(19108,'Shawmut','Shawmut, Montana',23439,26);
INSERT INTO "django_geo_db_city" VALUES(19109,'Shepherd','Shepherd, Montana',23440,26);
INSERT INTO "django_geo_db_city" VALUES(19110,'Silver Gate','Silver Gate, Montana',23441,26);
INSERT INTO "django_geo_db_city" VALUES(19111,'Springdale','Springdale, Montana',23442,26);
INSERT INTO "django_geo_db_city" VALUES(19112,'Sumatra','Sumatra, Montana',23378,26);
INSERT INTO "django_geo_db_city" VALUES(19113,'Teigen','Teigen, Montana',23443,26);
INSERT INTO "django_geo_db_city" VALUES(19114,'Two Dot','Two Dot, Montana',23444,26);
INSERT INTO "django_geo_db_city" VALUES(19115,'Wilsall','Wilsall, Montana',23445,26);
INSERT INTO "django_geo_db_city" VALUES(19116,'Winnett','Winnett, Montana',23446,26);
INSERT INTO "django_geo_db_city" VALUES(19117,'Worden','Worden, Montana',23447,26);
INSERT INTO "django_geo_db_city" VALUES(19118,'Wyola','Wyola, Montana',23448,26);
INSERT INTO "django_geo_db_city" VALUES(19119,'Billings','Billings, Montana',23449,26);
INSERT INTO "django_geo_db_city" VALUES(19120,'Wolf Point','Wolf Point, Montana',23455,26);
INSERT INTO "django_geo_db_city" VALUES(19121,'Antelope','Antelope, Montana',23456,26);
INSERT INTO "django_geo_db_city" VALUES(19122,'Bainville','Bainville, Montana',23457,26);
INSERT INTO "django_geo_db_city" VALUES(19123,'Brockton','Brockton, Montana',23458,26);
INSERT INTO "django_geo_db_city" VALUES(19124,'Brockway','Brockway, Montana',23459,26);
INSERT INTO "django_geo_db_city" VALUES(19125,'Circle','Circle, Montana',23460,26);
INSERT INTO "django_geo_db_city" VALUES(19126,'Crane','Crane, Montana',23461,26);
INSERT INTO "django_geo_db_city" VALUES(19127,'Culbertson','Culbertson, Montana',23462,26);
INSERT INTO "django_geo_db_city" VALUES(19128,'Dagmar','Dagmar, Montana',23463,26);
INSERT INTO "django_geo_db_city" VALUES(19129,'Fairview','Fairview, Montana',23464,26);
INSERT INTO "django_geo_db_city" VALUES(19130,'Flaxville','Flaxville, Montana',23465,26);
INSERT INTO "django_geo_db_city" VALUES(19131,'Fort Peck','Fort Peck, Montana',23466,26);
INSERT INTO "django_geo_db_city" VALUES(19132,'Frazer','Frazer, Montana',23467,26);
INSERT INTO "django_geo_db_city" VALUES(19133,'Froid','Froid, Montana',23468,26);
INSERT INTO "django_geo_db_city" VALUES(19134,'Glasgow','Glasgow, Montana',23469,26);
INSERT INTO "django_geo_db_city" VALUES(19135,'Saint Marie','Saint Marie, Montana',23470,26);
INSERT INTO "django_geo_db_city" VALUES(19136,'Glentana','Glentana, Montana',23471,26);
INSERT INTO "django_geo_db_city" VALUES(19137,'Hinsdale','Hinsdale, Montana',23472,26);
INSERT INTO "django_geo_db_city" VALUES(19138,'Homestead','Homestead, Montana',23473,26);
INSERT INTO "django_geo_db_city" VALUES(19139,'Lambert','Lambert, Montana',23474,26);
INSERT INTO "django_geo_db_city" VALUES(19140,'Larslan','Larslan, Montana',23475,26);
INSERT INTO "django_geo_db_city" VALUES(19141,'McCabe','McCabe, Montana',23476,26);
INSERT INTO "django_geo_db_city" VALUES(19142,'Medicine Lake','Medicine Lake, Montana',23477,26);
INSERT INTO "django_geo_db_city" VALUES(19143,'Nashua','Nashua, Montana',23478,26);
INSERT INTO "django_geo_db_city" VALUES(19144,'Opheim','Opheim, Montana',23479,26);
INSERT INTO "django_geo_db_city" VALUES(19145,'Outlook','Outlook, Montana',23480,26);
INSERT INTO "django_geo_db_city" VALUES(19146,'Peerless','Peerless, Montana',23481,26);
INSERT INTO "django_geo_db_city" VALUES(19147,'Plentywood','Plentywood, Montana',23482,26);
INSERT INTO "django_geo_db_city" VALUES(19148,'Poplar','Poplar, Montana',23483,26);
INSERT INTO "django_geo_db_city" VALUES(19149,'Raymond','Raymond, Montana',23484,26);
INSERT INTO "django_geo_db_city" VALUES(19150,'Redstone','Redstone, Montana',23485,26);
INSERT INTO "django_geo_db_city" VALUES(19151,'Reserve','Reserve, Montana',23486,26);
INSERT INTO "django_geo_db_city" VALUES(19152,'Richey','Richey, Montana',23487,26);
INSERT INTO "django_geo_db_city" VALUES(19153,'Richland','Richland, Montana',23488,26);
INSERT INTO "django_geo_db_city" VALUES(19154,'Saco','Saco, Montana',23489,26);
INSERT INTO "django_geo_db_city" VALUES(19155,'Savage','Savage, Montana',23490,26);
INSERT INTO "django_geo_db_city" VALUES(19156,'Scobey','Scobey, Montana',23491,26);
INSERT INTO "django_geo_db_city" VALUES(19157,'Sidney','Sidney, Montana',23492,26);
INSERT INTO "django_geo_db_city" VALUES(19158,'Vandalia','Vandalia, Montana',23471,26);
INSERT INTO "django_geo_db_city" VALUES(19159,'Vida','Vida, Montana',23493,26);
INSERT INTO "django_geo_db_city" VALUES(19160,'Westby','Westby, Montana',23494,26);
INSERT INTO "django_geo_db_city" VALUES(19161,'Whitetail','Whitetail, Montana',23495,26);
INSERT INTO "django_geo_db_city" VALUES(19162,'Miles City','Miles City, Montana',23496,26);
INSERT INTO "django_geo_db_city" VALUES(19163,'Alzada','Alzada, Montana',23497,26);
INSERT INTO "django_geo_db_city" VALUES(19164,'Angela','Angela, Montana',23378,26);
INSERT INTO "django_geo_db_city" VALUES(19165,'Baker','Baker, Montana',23498,26);
INSERT INTO "django_geo_db_city" VALUES(19166,'Biddle','Biddle, Montana',23499,26);
INSERT INTO "django_geo_db_city" VALUES(19167,'Bloomfield','Bloomfield, Montana',23500,26);
INSERT INTO "django_geo_db_city" VALUES(19168,'Boyes','Boyes, Montana',23501,26);
INSERT INTO "django_geo_db_city" VALUES(19169,'Broadus','Broadus, Montana',23502,26);
INSERT INTO "django_geo_db_city" VALUES(19170,'Brusett','Brusett, Montana',23503,26);
INSERT INTO "django_geo_db_city" VALUES(19171,'Capitol','Capitol, Montana',23501,26);
INSERT INTO "django_geo_db_city" VALUES(19172,'Cohagen','Cohagen, Montana',23504,26);
INSERT INTO "django_geo_db_city" VALUES(19173,'Colstrip','Colstrip, Montana',23505,26);
INSERT INTO "django_geo_db_city" VALUES(19174,'Ekalaka','Ekalaka, Montana',23506,26);
INSERT INTO "django_geo_db_city" VALUES(19175,'Fallon','Fallon, Montana',23507,26);
INSERT INTO "django_geo_db_city" VALUES(19176,'Forsyth','Forsyth, Montana',23508,26);
INSERT INTO "django_geo_db_city" VALUES(19177,'Glendive','Glendive, Montana',23509,26);
INSERT INTO "django_geo_db_city" VALUES(19178,'Hammond','Hammond, Montana',23510,26);
INSERT INTO "django_geo_db_city" VALUES(19179,'Hathaway','Hathaway, Montana',23511,26);
INSERT INTO "django_geo_db_city" VALUES(19180,'Ismay','Ismay, Montana',23512,26);
INSERT INTO "django_geo_db_city" VALUES(19181,'Jordan','Jordan, Montana',23513,26);
INSERT INTO "django_geo_db_city" VALUES(19182,'Kinsey','Kinsey, Montana',23514,26);
INSERT INTO "django_geo_db_city" VALUES(19183,'Lindsay','Lindsay, Montana',23515,26);
INSERT INTO "django_geo_db_city" VALUES(19184,'Mildred','Mildred, Montana',23516,26);
INSERT INTO "django_geo_db_city" VALUES(19185,'Olive','Olive, Montana',23517,26);
INSERT INTO "django_geo_db_city" VALUES(19186,'Plevna','Plevna, Montana',23518,26);
INSERT INTO "django_geo_db_city" VALUES(19187,'Powderville','Powderville, Montana',23519,26);
INSERT INTO "django_geo_db_city" VALUES(19188,'Rosebud','Rosebud, Montana',23520,26);
INSERT INTO "django_geo_db_city" VALUES(19189,'Sonnette','Sonnette, Montana',23521,26);
INSERT INTO "django_geo_db_city" VALUES(19190,'Terry','Terry, Montana',23522,26);
INSERT INTO "django_geo_db_city" VALUES(19191,'Volborg','Volborg, Montana',23523,26);
INSERT INTO "django_geo_db_city" VALUES(19192,'Wibaux','Wibaux, Montana',23524,26);
INSERT INTO "django_geo_db_city" VALUES(19193,'Willard','Willard, Montana',23525,26);
INSERT INTO "django_geo_db_city" VALUES(19194,'Shelby','Shelby, Montana',23526,26);
INSERT INTO "django_geo_db_city" VALUES(19195,'Great Falls','Great Falls, Montana',23527,26);
INSERT INTO "django_geo_db_city" VALUES(19196,'Malmstrom A F B','Malmstrom A F B, Montana',23528,26);
INSERT INTO "django_geo_db_city" VALUES(19197,'Augusta','Augusta, Montana',23533,26);
INSERT INTO "django_geo_db_city" VALUES(19198,'Babb','Babb, Montana',23534,26);
INSERT INTO "django_geo_db_city" VALUES(19199,'Belt','Belt, Montana',23535,26);
INSERT INTO "django_geo_db_city" VALUES(19200,'Black Eagle','Black Eagle, Montana',23536,26);
INSERT INTO "django_geo_db_city" VALUES(19201,'Brady','Brady, Montana',23537,26);
INSERT INTO "django_geo_db_city" VALUES(19202,'Browning','Browning, Montana',23538,26);
INSERT INTO "django_geo_db_city" VALUES(19203,'Buffalo','Buffalo, Montana',23539,26);
INSERT INTO "django_geo_db_city" VALUES(19204,'Bynum','Bynum, Montana',23540,26);
INSERT INTO "django_geo_db_city" VALUES(19205,'Carter','Carter, Montana',23541,26);
INSERT INTO "django_geo_db_city" VALUES(19206,'Cascade','Cascade, Montana',23542,26);
INSERT INTO "django_geo_db_city" VALUES(19207,'Choteau','Choteau, Montana',23543,26);
INSERT INTO "django_geo_db_city" VALUES(19208,'Coffee Creek','Coffee Creek, Montana',23544,26);
INSERT INTO "django_geo_db_city" VALUES(19209,'Conrad','Conrad, Montana',23545,26);
INSERT INTO "django_geo_db_city" VALUES(19210,'Cut Bank','Cut Bank, Montana',23546,26);
INSERT INTO "django_geo_db_city" VALUES(19211,'Denton','Denton, Montana',23547,26);
INSERT INTO "django_geo_db_city" VALUES(19212,'Dupuyer','Dupuyer, Montana',23548,26);
INSERT INTO "django_geo_db_city" VALUES(19213,'Dutton','Dutton, Montana',23549,26);
INSERT INTO "django_geo_db_city" VALUES(19214,'East Glacier Park','East Glacier Park, Montana',23550,26);
INSERT INTO "django_geo_db_city" VALUES(19215,'Ethridge','Ethridge, Montana',23551,26);
INSERT INTO "django_geo_db_city" VALUES(19216,'Fairfield','Fairfield, Montana',23552,26);
INSERT INTO "django_geo_db_city" VALUES(19217,'Floweree','Floweree, Montana',23553,26);
INSERT INTO "django_geo_db_city" VALUES(19218,'Forestgrove','Forestgrove, Montana',23554,26);
INSERT INTO "django_geo_db_city" VALUES(19219,'Fort Benton','Fort Benton, Montana',23555,26);
INSERT INTO "django_geo_db_city" VALUES(19220,'Fort Shaw','Fort Shaw, Montana',23556,26);
INSERT INTO "django_geo_db_city" VALUES(19221,'Galata','Galata, Montana',23557,26);
INSERT INTO "django_geo_db_city" VALUES(19222,'Garneill','Garneill, Montana',23558,26);
INSERT INTO "django_geo_db_city" VALUES(19223,'Geraldine','Geraldine, Montana',23559,26);
INSERT INTO "django_geo_db_city" VALUES(19224,'Geyser','Geyser, Montana',23560,26);
INSERT INTO "django_geo_db_city" VALUES(19225,'Heart Butte','Heart Butte, Montana',23561,26);
INSERT INTO "django_geo_db_city" VALUES(19226,'Highwood','Highwood, Montana',23562,26);
INSERT INTO "django_geo_db_city" VALUES(19227,'Hilger','Hilger, Montana',23563,26);
INSERT INTO "django_geo_db_city" VALUES(19228,'Hobson','Hobson, Montana',23564,26);
INSERT INTO "django_geo_db_city" VALUES(19229,'Judith Gap','Judith Gap, Montana',23565,26);
INSERT INTO "django_geo_db_city" VALUES(19230,'Kevin','Kevin, Montana',23566,26);
INSERT INTO "django_geo_db_city" VALUES(19231,'Ledger','Ledger, Montana',23567,26);
INSERT INTO "django_geo_db_city" VALUES(19232,'Lewistown','Lewistown, Montana',23568,26);
INSERT INTO "django_geo_db_city" VALUES(19233,'Loma','Loma, Montana',23569,26);
INSERT INTO "django_geo_db_city" VALUES(19234,'Lothair','Lothair, Montana',23551,26);
INSERT INTO "django_geo_db_city" VALUES(19235,'Moccasin','Moccasin, Montana',23570,26);
INSERT INTO "django_geo_db_city" VALUES(19236,'Monarch','Monarch, Montana',23571,26);
INSERT INTO "django_geo_db_city" VALUES(19237,'Moore','Moore, Montana',23572,26);
INSERT INTO "django_geo_db_city" VALUES(19238,'Neihart','Neihart, Montana',23573,26);
INSERT INTO "django_geo_db_city" VALUES(19239,'Oilmont','Oilmont, Montana',23574,26);
INSERT INTO "django_geo_db_city" VALUES(19240,'Pendroy','Pendroy, Montana',23575,26);
INSERT INTO "django_geo_db_city" VALUES(19241,'Power','Power, Montana',23576,26);
INSERT INTO "django_geo_db_city" VALUES(19242,'Raynesford','Raynesford, Montana',23577,26);
INSERT INTO "django_geo_db_city" VALUES(19243,'Roy','Roy, Montana',23578,26);
INSERT INTO "django_geo_db_city" VALUES(19244,'Sand Coulee','Sand Coulee, Montana',23579,26);
INSERT INTO "django_geo_db_city" VALUES(19245,'Santa Rita','Santa Rita, Montana',23580,26);
INSERT INTO "django_geo_db_city" VALUES(19246,'Simms','Simms, Montana',23582,26);
INSERT INTO "django_geo_db_city" VALUES(19247,'Stanford','Stanford, Montana',23583,26);
INSERT INTO "django_geo_db_city" VALUES(19248,'Stockett','Stockett, Montana',23584,26);
INSERT INTO "django_geo_db_city" VALUES(19249,'Sunburst','Sunburst, Montana',23585,26);
INSERT INTO "django_geo_db_city" VALUES(19250,'Sun River','Sun River, Montana',23586,26);
INSERT INTO "django_geo_db_city" VALUES(19251,'Sweet Grass','Sweet Grass, Montana',23587,26);
INSERT INTO "django_geo_db_city" VALUES(19252,'Ulm','Ulm, Montana',23588,26);
INSERT INTO "django_geo_db_city" VALUES(19253,'Valier','Valier, Montana',23589,26);
INSERT INTO "django_geo_db_city" VALUES(19254,'Vaughn','Vaughn, Montana',23590,26);
INSERT INTO "django_geo_db_city" VALUES(19255,'Winifred','Winifred, Montana',23591,26);
INSERT INTO "django_geo_db_city" VALUES(19256,'Havre','Havre, Montana',23592,26);
INSERT INTO "django_geo_db_city" VALUES(19257,'Big Sandy','Big Sandy, Montana',23594,26);
INSERT INTO "django_geo_db_city" VALUES(19258,'Box Elder','Box Elder, Montana',23595,26);
INSERT INTO "django_geo_db_city" VALUES(19259,'Chester','Chester, Montana',23596,26);
INSERT INTO "django_geo_db_city" VALUES(19260,'Chinook','Chinook, Montana',23597,26);
INSERT INTO "django_geo_db_city" VALUES(19261,'Dodson','Dodson, Montana',23598,26);
INSERT INTO "django_geo_db_city" VALUES(19262,'Gildford','Gildford, Montana',23599,26);
INSERT INTO "django_geo_db_city" VALUES(19263,'Harlem','Harlem, Montana',23600,26);
INSERT INTO "django_geo_db_city" VALUES(19264,'Hays','Hays, Montana',23601,26);
INSERT INTO "django_geo_db_city" VALUES(19265,'Hingham','Hingham, Montana',23602,26);
INSERT INTO "django_geo_db_city" VALUES(19266,'Hogeland','Hogeland, Montana',23603,26);
INSERT INTO "django_geo_db_city" VALUES(19267,'Inverness','Inverness, Montana',23604,26);
INSERT INTO "django_geo_db_city" VALUES(19268,'Joplin','Joplin, Montana',23605,26);
INSERT INTO "django_geo_db_city" VALUES(19269,'Kremlin','Kremlin, Montana',23606,26);
INSERT INTO "django_geo_db_city" VALUES(19270,'Lloyd','Lloyd, Montana',23607,26);
INSERT INTO "django_geo_db_city" VALUES(19271,'Loring','Loring, Montana',23608,26);
INSERT INTO "django_geo_db_city" VALUES(19272,'Malta','Malta, Montana',23609,26);
INSERT INTO "django_geo_db_city" VALUES(19273,'Rudyard','Rudyard, Montana',23610,26);
INSERT INTO "django_geo_db_city" VALUES(19274,'Turner','Turner, Montana',23611,26);
INSERT INTO "django_geo_db_city" VALUES(19275,'Whitewater','Whitewater, Montana',23612,26);
INSERT INTO "django_geo_db_city" VALUES(19276,'Whitlash','Whitlash, Montana',23613,26);
INSERT INTO "django_geo_db_city" VALUES(19277,'Zortman','Zortman, Montana',23614,26);
INSERT INTO "django_geo_db_city" VALUES(19278,'Zurich','Zurich, Montana',23615,26);
INSERT INTO "django_geo_db_city" VALUES(19279,'Helena','Helena, Montana',23616,26);
INSERT INTO "django_geo_db_city" VALUES(19280,'Basin','Basin, Montana',23623,26);
INSERT INTO "django_geo_db_city" VALUES(19281,'Boulder','Boulder, Montana',23624,26);
INSERT INTO "django_geo_db_city" VALUES(19282,'Canyon Creek','Canyon Creek, Montana',23625,26);
INSERT INTO "django_geo_db_city" VALUES(19283,'Clancy','Clancy, Montana',23626,26);
INSERT INTO "django_geo_db_city" VALUES(19284,'East Helena','East Helena, Montana',23627,26);
INSERT INTO "django_geo_db_city" VALUES(19285,'Fort Harrison','Fort Harrison, Montana',23628,26);
INSERT INTO "django_geo_db_city" VALUES(19286,'Jefferson City','Jefferson City, Montana',23629,26);
INSERT INTO "django_geo_db_city" VALUES(19287,'Lincoln','Lincoln, Montana',23630,26);
INSERT INTO "django_geo_db_city" VALUES(19288,'Marysville','Marysville, Montana',23631,26);
INSERT INTO "django_geo_db_city" VALUES(19289,'Radersburg','Radersburg, Montana',23632,26);
INSERT INTO "django_geo_db_city" VALUES(19290,'Ringling','Ringling, Montana',23633,26);
INSERT INTO "django_geo_db_city" VALUES(19291,'Toston','Toston, Montana',23634,26);
INSERT INTO "django_geo_db_city" VALUES(19292,'Townsend','Townsend, Montana',23635,26);
INSERT INTO "django_geo_db_city" VALUES(19293,'White Sulphur Springs','White Sulphur Springs, Montana',23636,26);
INSERT INTO "django_geo_db_city" VALUES(19294,'Winston','Winston, Montana',23637,26);
INSERT INTO "django_geo_db_city" VALUES(19295,'Wolf Creek','Wolf Creek, Montana',23638,26);
INSERT INTO "django_geo_db_city" VALUES(19296,'Butte','Butte, Montana',23639,26);
INSERT INTO "django_geo_db_city" VALUES(19297,'Alder','Alder, Montana',23641,26);
INSERT INTO "django_geo_db_city" VALUES(19298,'Anaconda','Anaconda, Montana',23642,26);
INSERT INTO "django_geo_db_city" VALUES(19299,'Avon','Avon, Montana',23643,26);
INSERT INTO "django_geo_db_city" VALUES(19300,'Belgrade','Belgrade, Montana',23644,26);
INSERT INTO "django_geo_db_city" VALUES(19301,'Bozeman','Bozeman, Montana',23645,26);
INSERT INTO "django_geo_db_city" VALUES(19302,'Big Sky','Big Sky, Montana',23646,26);
INSERT INTO "django_geo_db_city" VALUES(19303,'Cameron','Cameron, Montana',23649,26);
INSERT INTO "django_geo_db_city" VALUES(19304,'Cardwell','Cardwell, Montana',23650,26);
INSERT INTO "django_geo_db_city" VALUES(19305,'Deer Lodge','Deer Lodge, Montana',23651,26);
INSERT INTO "django_geo_db_city" VALUES(19306,'Dell','Dell, Montana',23652,26);
INSERT INTO "django_geo_db_city" VALUES(19307,'Dillon','Dillon, Montana',23653,26);
INSERT INTO "django_geo_db_city" VALUES(19308,'Divide','Divide, Montana',23654,26);
INSERT INTO "django_geo_db_city" VALUES(19309,'Elliston','Elliston, Montana',23655,26);
INSERT INTO "django_geo_db_city" VALUES(19310,'Ennis','Ennis, Montana',23656,26);
INSERT INTO "django_geo_db_city" VALUES(19311,'Gallatin Gateway','Gallatin Gateway, Montana',23657,26);
INSERT INTO "django_geo_db_city" VALUES(19312,'Garrison','Garrison, Montana',23658,26);
INSERT INTO "django_geo_db_city" VALUES(19313,'Glen','Glen, Montana',23652,26);
INSERT INTO "django_geo_db_city" VALUES(19314,'Gold Creek','Gold Creek, Montana',23659,26);
INSERT INTO "django_geo_db_city" VALUES(19315,'Harrison','Harrison, Montana',23660,26);
INSERT INTO "django_geo_db_city" VALUES(19316,'Jackson','Jackson, Montana',23661,26);
INSERT INTO "django_geo_db_city" VALUES(19317,'Lima','Lima, Montana',23662,26);
INSERT INTO "django_geo_db_city" VALUES(19318,'McAllister','McAllister, Montana',23663,26);
INSERT INTO "django_geo_db_city" VALUES(19319,'Manhattan','Manhattan, Montana',23664,26);
INSERT INTO "django_geo_db_city" VALUES(19320,'Melrose','Melrose, Montana',23665,26);
INSERT INTO "django_geo_db_city" VALUES(19321,'Norris','Norris, Montana',23666,26);
INSERT INTO "django_geo_db_city" VALUES(19322,'Polaris','Polaris, Montana',23667,26);
INSERT INTO "django_geo_db_city" VALUES(19323,'Pony','Pony, Montana',23668,26);
INSERT INTO "django_geo_db_city" VALUES(19324,'Ramsay','Ramsay, Montana',23669,26);
INSERT INTO "django_geo_db_city" VALUES(19325,'Sheridan','Sheridan, Montana',23670,26);
INSERT INTO "django_geo_db_city" VALUES(19326,'Silver Star','Silver Star, Montana',23672,26);
INSERT INTO "django_geo_db_city" VALUES(19327,'Three Forks','Three Forks, Montana',23673,26);
INSERT INTO "django_geo_db_city" VALUES(19328,'Twin Bridges','Twin Bridges, Montana',23674,26);
INSERT INTO "django_geo_db_city" VALUES(19329,'Virginia City','Virginia City, Montana',23675,26);
INSERT INTO "django_geo_db_city" VALUES(19330,'Warm Springs','Warm Springs, Montana',23676,26);
INSERT INTO "django_geo_db_city" VALUES(19331,'West Yellowstone','West Yellowstone, Montana',23677,26);
INSERT INTO "django_geo_db_city" VALUES(19332,'Whitehall','Whitehall, Montana',23678,26);
INSERT INTO "django_geo_db_city" VALUES(19333,'Willow Creek','Willow Creek, Montana',23679,26);
INSERT INTO "django_geo_db_city" VALUES(19334,'Wisdom','Wisdom, Montana',23680,26);
INSERT INTO "django_geo_db_city" VALUES(19335,'Wise River','Wise River, Montana',23681,26);
INSERT INTO "django_geo_db_city" VALUES(19336,'Missoula','Missoula, Montana',23686,26);
INSERT INTO "django_geo_db_city" VALUES(19337,'Four Corners','Four Corners, Montana',23693,26);
INSERT INTO "django_geo_db_city" VALUES(19338,'Alberton','Alberton, Montana',23694,26);
INSERT INTO "django_geo_db_city" VALUES(19339,'Arlee','Arlee, Montana',23695,26);
INSERT INTO "django_geo_db_city" VALUES(19340,'Bonner','Bonner, Montana',23696,26);
INSERT INTO "django_geo_db_city" VALUES(19341,'Charlo','Charlo, Montana',23697,26);
INSERT INTO "django_geo_db_city" VALUES(19342,'Clinton','Clinton, Montana',23698,26);
INSERT INTO "django_geo_db_city" VALUES(19343,'Condon','Condon, Montana',23699,26);
INSERT INTO "django_geo_db_city" VALUES(19344,'Conner','Conner, Montana',23700,26);
INSERT INTO "django_geo_db_city" VALUES(19345,'Corvallis','Corvallis, Montana',23701,26);
INSERT INTO "django_geo_db_city" VALUES(19346,'Darby','Darby, Montana',23702,26);
INSERT INTO "django_geo_db_city" VALUES(19347,'De Borgia','De Borgia, Montana',23703,26);
INSERT INTO "django_geo_db_city" VALUES(19348,'Dixon','Dixon, Montana',23704,26);
INSERT INTO "django_geo_db_city" VALUES(19349,'Drummond','Drummond, Montana',23705,26);
INSERT INTO "django_geo_db_city" VALUES(19350,'Florence','Florence, Montana',23706,26);
INSERT INTO "django_geo_db_city" VALUES(19351,'Frenchtown','Frenchtown, Montana',23707,26);
INSERT INTO "django_geo_db_city" VALUES(19352,'Grantsdale','Grantsdale, Montana',23708,26);
INSERT INTO "django_geo_db_city" VALUES(19353,'Greenough','Greenough, Montana',23709,26);
INSERT INTO "django_geo_db_city" VALUES(19354,'Hall','Hall, Montana',23710,26);
INSERT INTO "django_geo_db_city" VALUES(19355,'Hamilton','Hamilton, Montana',23711,26);
INSERT INTO "django_geo_db_city" VALUES(19356,'Pinesdale','Pinesdale, Montana',23712,26);
INSERT INTO "django_geo_db_city" VALUES(19357,'Haugan','Haugan, Montana',23713,26);
INSERT INTO "django_geo_db_city" VALUES(19358,'Helmville','Helmville, Montana',23714,26);
INSERT INTO "django_geo_db_city" VALUES(19359,'Heron','Heron, Montana',23715,26);
INSERT INTO "django_geo_db_city" VALUES(19360,'Hot Springs','Hot Springs, Montana',23716,26);
INSERT INTO "django_geo_db_city" VALUES(19361,'Huson','Huson, Montana',23717,26);
INSERT INTO "django_geo_db_city" VALUES(19362,'Lolo','Lolo, Montana',23718,26);
INSERT INTO "django_geo_db_city" VALUES(19363,'Lonepine','Lonepine, Montana',23719,26);
INSERT INTO "django_geo_db_city" VALUES(19364,'Milltown','Milltown, Montana',23720,26);
INSERT INTO "django_geo_db_city" VALUES(19365,'Noxon','Noxon, Montana',23721,26);
INSERT INTO "django_geo_db_city" VALUES(19366,'Ovando','Ovando, Montana',23722,26);
INSERT INTO "django_geo_db_city" VALUES(19367,'Pablo','Pablo, Montana',23723,26);
INSERT INTO "django_geo_db_city" VALUES(19368,'Paradise','Paradise, Montana',23724,26);
INSERT INTO "django_geo_db_city" VALUES(19369,'Philipsburg','Philipsburg, Montana',23725,26);
INSERT INTO "django_geo_db_city" VALUES(19370,'Plains','Plains, Montana',23726,26);
INSERT INTO "django_geo_db_city" VALUES(19371,'Polson','Polson, Montana',23727,26);
INSERT INTO "django_geo_db_city" VALUES(19372,'Ravalli','Ravalli, Montana',23728,26);
INSERT INTO "django_geo_db_city" VALUES(19373,'Ronan','Ronan, Montana',23729,26);
INSERT INTO "django_geo_db_city" VALUES(19374,'Saint Ignatius','Saint Ignatius, Montana',23730,26);
INSERT INTO "django_geo_db_city" VALUES(19375,'Saint Regis','Saint Regis, Montana',23731,26);
INSERT INTO "django_geo_db_city" VALUES(19376,'Saltese','Saltese, Montana',23732,26);
INSERT INTO "django_geo_db_city" VALUES(19377,'Seeley Lake','Seeley Lake, Montana',23733,26);
INSERT INTO "django_geo_db_city" VALUES(19378,'Stevensville','Stevensville, Montana',23734,26);
INSERT INTO "django_geo_db_city" VALUES(19379,'Sula','Sula, Montana',23735,26);
INSERT INTO "django_geo_db_city" VALUES(19380,'Superior','Superior, Montana',23736,26);
INSERT INTO "django_geo_db_city" VALUES(19381,'Thompson Falls','Thompson Falls, Montana',23737,26);
INSERT INTO "django_geo_db_city" VALUES(19382,'Trout Creek','Trout Creek, Montana',23738,26);
INSERT INTO "django_geo_db_city" VALUES(19383,'Victor','Victor, Montana',23739,26);
INSERT INTO "django_geo_db_city" VALUES(19384,'Kalispell','Kalispell, Montana',23740,26);
INSERT INTO "django_geo_db_city" VALUES(19385,'Big Arm','Big Arm, Montana',23744,26);
INSERT INTO "django_geo_db_city" VALUES(19386,'Bigfork','Bigfork, Montana',23745,26);
INSERT INTO "django_geo_db_city" VALUES(19387,'Columbia Falls','Columbia Falls, Montana',23746,26);
INSERT INTO "django_geo_db_city" VALUES(19388,'Coram','Coram, Montana',23747,26);
INSERT INTO "django_geo_db_city" VALUES(19389,'Dayton','Dayton, Montana',23748,26);
INSERT INTO "django_geo_db_city" VALUES(19390,'Elmo','Elmo, Montana',23749,26);
INSERT INTO "django_geo_db_city" VALUES(19391,'Essex','Essex, Montana',23750,26);
INSERT INTO "django_geo_db_city" VALUES(19392,'Eureka','Eureka, Montana',23751,26);
INSERT INTO "django_geo_db_city" VALUES(19393,'Fortine','Fortine, Montana',23752,26);
INSERT INTO "django_geo_db_city" VALUES(19394,'Hungry Horse','Hungry Horse, Montana',23753,26);
INSERT INTO "django_geo_db_city" VALUES(19395,'Kila','Kila, Montana',23754,26);
INSERT INTO "django_geo_db_city" VALUES(19396,'Lake McDonald','Lake McDonald, Montana',23755,26);
INSERT INTO "django_geo_db_city" VALUES(19397,'Lakeside','Lakeside, Montana',23756,26);
INSERT INTO "django_geo_db_city" VALUES(19398,'Libby','Libby, Montana',23757,26);
INSERT INTO "django_geo_db_city" VALUES(19399,'Marion','Marion, Montana',23758,26);
INSERT INTO "django_geo_db_city" VALUES(19400,'Martin City','Martin City, Montana',23759,26);
INSERT INTO "django_geo_db_city" VALUES(19401,'Olney','Olney, Montana',23760,26);
INSERT INTO "django_geo_db_city" VALUES(19402,'Polebridge','Polebridge, Montana',23761,26);
INSERT INTO "django_geo_db_city" VALUES(19403,'Proctor','Proctor, Montana',23762,26);
INSERT INTO "django_geo_db_city" VALUES(19404,'Rexford','Rexford, Montana',23763,26);
INSERT INTO "django_geo_db_city" VALUES(19405,'Rollins','Rollins, Montana',23764,26);
INSERT INTO "django_geo_db_city" VALUES(19406,'Somers','Somers, Montana',23765,26);
INSERT INTO "django_geo_db_city" VALUES(19407,'Stryker','Stryker, Montana',23766,26);
INSERT INTO "django_geo_db_city" VALUES(19408,'Trego','Trego, Montana',23767,26);
INSERT INTO "django_geo_db_city" VALUES(19409,'Troy','Troy, Montana',23768,26);
INSERT INTO "django_geo_db_city" VALUES(19410,'West Glacier','West Glacier, Montana',23769,26);
INSERT INTO "django_geo_db_city" VALUES(19411,'Whitefish','Whitefish, Montana',23770,26);
INSERT INTO "django_geo_db_city" VALUES(19412,'Alden','Alden, Illinois',23771,17);
INSERT INTO "django_geo_db_city" VALUES(19413,'Antioch','Antioch, Illinois',23772,17);
INSERT INTO "django_geo_db_city" VALUES(19414,'Arlington Heights','Arlington Heights, Illinois',23773,17);
INSERT INTO "django_geo_db_city" VALUES(19415,'Elk Grove Village','Elk Grove Village, Illinois',23776,17);
INSERT INTO "django_geo_db_city" VALUES(19416,'Rolling Meadows','Rolling Meadows, Illinois',23777,17);
INSERT INTO "django_geo_db_city" VALUES(19417,'Barrington','Barrington, Illinois',23778,17);
INSERT INTO "django_geo_db_city" VALUES(19418,'Crystal Lake','Crystal Lake, Illinois',23780,17);
INSERT INTO "django_geo_db_city" VALUES(19419,'Cary','Cary, Illinois',23781,17);
INSERT INTO "django_geo_db_city" VALUES(19420,'Deerfield','Deerfield, Illinois',23783,17);
INSERT INTO "django_geo_db_city" VALUES(19421,'Des Plaines','Des Plaines, Illinois',23784,17);
INSERT INTO "django_geo_db_city" VALUES(19422,'Fox Lake','Fox Lake, Illinois',23788,17);
INSERT INTO "django_geo_db_city" VALUES(19423,'Fox River Grove','Fox River Grove, Illinois',23789,17);
INSERT INTO "django_geo_db_city" VALUES(19424,'Glencoe','Glencoe, Illinois',23790,17);
INSERT INTO "django_geo_db_city" VALUES(19425,'Glenview','Glenview, Illinois',23791,17);
INSERT INTO "django_geo_db_city" VALUES(19426,'Glenview Nas','Glenview Nas, Illinois',23775,17);
INSERT INTO "django_geo_db_city" VALUES(19427,'Golf','Golf, Illinois',23792,17);
INSERT INTO "django_geo_db_city" VALUES(19428,'Grayslake','Grayslake, Illinois',23793,17);
INSERT INTO "django_geo_db_city" VALUES(19429,'Gurnee','Gurnee, Illinois',23794,17);
INSERT INTO "django_geo_db_city" VALUES(19430,'Harvard','Harvard, Illinois',23795,17);
INSERT INTO "django_geo_db_city" VALUES(19431,'Hebron','Hebron, Illinois',23796,17);
INSERT INTO "django_geo_db_city" VALUES(19432,'Highland Park','Highland Park, Illinois',23797,17);
INSERT INTO "django_geo_db_city" VALUES(19433,'Fort Sheridan','Fort Sheridan, Illinois',23798,17);
INSERT INTO "django_geo_db_city" VALUES(19434,'Palatine','Palatine, Illinois',23799,17);
INSERT INTO "django_geo_db_city" VALUES(19435,'Highwood','Highwood, Illinois',23800,17);
INSERT INTO "django_geo_db_city" VALUES(19436,'Ingleside','Ingleside, Illinois',23801,17);
INSERT INTO "django_geo_db_city" VALUES(19437,'Island Lake','Island Lake, Illinois',23802,17);
INSERT INTO "django_geo_db_city" VALUES(19438,'Kenilworth','Kenilworth, Illinois',23803,17);
INSERT INTO "django_geo_db_city" VALUES(19439,'Lake Bluff','Lake Bluff, Illinois',23804,17);
INSERT INTO "django_geo_db_city" VALUES(19440,'Lake Forest','Lake Forest, Illinois',23805,17);
INSERT INTO "django_geo_db_city" VALUES(19441,'Lake Villa','Lake Villa, Illinois',23806,17);
INSERT INTO "django_geo_db_city" VALUES(19442,'Lake Zurich','Lake Zurich, Illinois',23807,17);
INSERT INTO "django_geo_db_city" VALUES(19443,'Libertyville','Libertyville, Illinois',23808,17);
INSERT INTO "django_geo_db_city" VALUES(19444,'Long Grove','Long Grove, Illinois',23809,17);
INSERT INTO "django_geo_db_city" VALUES(19445,'Mchenry','Mchenry, Illinois',23810,17);
INSERT INTO "django_geo_db_city" VALUES(19446,'Morton Grove','Morton Grove, Illinois',23811,17);
INSERT INTO "django_geo_db_city" VALUES(19447,'McHenry','McHenry, Illinois',23812,17);
INSERT INTO "django_geo_db_city" VALUES(19448,'Mount Prospect','Mount Prospect, Illinois',23813,17);
INSERT INTO "django_geo_db_city" VALUES(19449,'Mundelein','Mundelein, Illinois',23814,17);
INSERT INTO "django_geo_db_city" VALUES(19450,'Vernon Hills','Vernon Hills, Illinois',23815,17);
INSERT INTO "django_geo_db_city" VALUES(19451,'Northbrook','Northbrook, Illinois',23816,17);
INSERT INTO "django_geo_db_city" VALUES(19452,'North Chicago','North Chicago, Illinois',23817,17);
INSERT INTO "django_geo_db_city" VALUES(19453,'Park Ridge','Park Ridge, Illinois',23819,17);
INSERT INTO "django_geo_db_city" VALUES(19454,'Lincolnshire','Lincolnshire, Illinois',23820,17);
INSERT INTO "django_geo_db_city" VALUES(19455,'Prospect Heights','Prospect Heights, Illinois',23821,17);
INSERT INTO "django_geo_db_city" VALUES(19456,'Richmond','Richmond, Illinois',23822,17);
INSERT INTO "django_geo_db_city" VALUES(19457,'Ringwood','Ringwood, Illinois',23823,17);
INSERT INTO "django_geo_db_city" VALUES(19458,'Round Lake','Round Lake, Illinois',23824,17);
INSERT INTO "django_geo_db_city" VALUES(19459,'Russell','Russell, Illinois',23779,17);
INSERT INTO "django_geo_db_city" VALUES(19460,'Skokie','Skokie, Illinois',23826,17);
INSERT INTO "django_geo_db_city" VALUES(19461,'Waukegan','Waukegan, Illinois',23779,17);
INSERT INTO "django_geo_db_city" VALUES(19462,'Solon Mills','Solon Mills, Illinois',23828,17);
INSERT INTO "django_geo_db_city" VALUES(19463,'Spring Grove','Spring Grove, Illinois',23829,17);
INSERT INTO "django_geo_db_city" VALUES(19464,'Techny','Techny, Illinois',23830,17);
INSERT INTO "django_geo_db_city" VALUES(19465,'Wadsworth','Wadsworth, Illinois',23831,17);
INSERT INTO "django_geo_db_city" VALUES(19466,'Wauconda','Wauconda, Illinois',23832,17);
INSERT INTO "django_geo_db_city" VALUES(19467,'Great Lakes','Great Lakes, Illinois',23836,17);
INSERT INTO "django_geo_db_city" VALUES(19468,'Buffalo Grove','Buffalo Grove, Illinois',23837,17);
INSERT INTO "django_geo_db_city" VALUES(19469,'Wheeling','Wheeling, Illinois',23838,17);
INSERT INTO "django_geo_db_city" VALUES(19470,'Wilmette','Wilmette, Illinois',23839,17);
INSERT INTO "django_geo_db_city" VALUES(19471,'Winnetka','Winnetka, Illinois',23840,17);
INSERT INTO "django_geo_db_city" VALUES(19472,'Winthrop Harbor','Winthrop Harbor, Illinois',23841,17);
INSERT INTO "django_geo_db_city" VALUES(19473,'Wonder Lake','Wonder Lake, Illinois',23842,17);
INSERT INTO "django_geo_db_city" VALUES(19474,'Woodstock','Woodstock, Illinois',23843,17);
INSERT INTO "django_geo_db_city" VALUES(19475,'Zion','Zion, Illinois',23844,17);
INSERT INTO "django_geo_db_city" VALUES(19476,'Addison','Addison, Illinois',23845,17);
INSERT INTO "django_geo_db_city" VALUES(19477,'Algonquin','Algonquin, Illinois',23846,17);
INSERT INTO "django_geo_db_city" VALUES(19478,'Bartlett','Bartlett, Illinois',23847,17);
INSERT INTO "django_geo_db_city" VALUES(19479,'Bellwood','Bellwood, Illinois',23848,17);
INSERT INTO "django_geo_db_city" VALUES(19480,'Bensenville','Bensenville, Illinois',23849,17);
INSERT INTO "django_geo_db_city" VALUES(19481,'Streamwood','Streamwood, Illinois',23851,17);
INSERT INTO "django_geo_db_city" VALUES(19482,'Bloomingdale','Bloomingdale, Illinois',23852,17);
INSERT INTO "django_geo_db_city" VALUES(19483,'Burlington','Burlington, Illinois',23853,17);
INSERT INTO "django_geo_db_city" VALUES(19484,'Carpentersville','Carpentersville, Illinois',23854,17);
INSERT INTO "django_geo_db_city" VALUES(19485,'Clare','Clare, Illinois',23855,17);
INSERT INTO "django_geo_db_city" VALUES(19486,'Cortland','Cortland, Illinois',23856,17);
INSERT INTO "django_geo_db_city" VALUES(19487,'Creston','Creston, Illinois',23857,17);
INSERT INTO "django_geo_db_city" VALUES(19488,'Dekalb','Dekalb, Illinois',23858,17);
INSERT INTO "django_geo_db_city" VALUES(19489,'Carol Stream','Carol Stream, Illinois',23849,17);
INSERT INTO "django_geo_db_city" VALUES(19490,'Dundee','Dundee, Illinois',23859,17);
INSERT INTO "django_geo_db_city" VALUES(19491,'Elburn','Elburn, Illinois',23860,17);
INSERT INTO "django_geo_db_city" VALUES(19492,'Elgin','Elgin, Illinois',23861,17);
INSERT INTO "django_geo_db_city" VALUES(19493,'Elmhurst','Elmhurst, Illinois',23865,17);
INSERT INTO "django_geo_db_city" VALUES(19494,'Milton','Milton, Illinois',23866,17);
INSERT INTO "django_geo_db_city" VALUES(19495,'Esmond','Esmond, Illinois',23867,17);
INSERT INTO "django_geo_db_city" VALUES(19496,'Forest Park','Forest Park, Illinois',23868,17);
INSERT INTO "django_geo_db_city" VALUES(19497,'Franklin Park','Franklin Park, Illinois',23869,17);
INSERT INTO "django_geo_db_city" VALUES(19498,'Hanover Park','Hanover Park, Illinois',23870,17);
INSERT INTO "django_geo_db_city" VALUES(19499,'Geneva','Geneva, Illinois',23871,17);
INSERT INTO "django_geo_db_city" VALUES(19500,'Genoa','Genoa, Illinois',23872,17);
INSERT INTO "django_geo_db_city" VALUES(19501,'Gilberts','Gilberts, Illinois',23873,17);
INSERT INTO "django_geo_db_city" VALUES(19502,'Glen Ellyn','Glen Ellyn, Illinois',23874,17);
INSERT INTO "django_geo_db_city" VALUES(19503,'Glendale Heights','Glendale Heights, Illinois',23875,17);
INSERT INTO "django_geo_db_city" VALUES(19504,'Hampshire','Hampshire, Illinois',23876,17);
INSERT INTO "django_geo_db_city" VALUES(19505,'Hines','Hines, Illinois',23877,17);
INSERT INTO "django_geo_db_city" VALUES(19506,'Huntley','Huntley, Illinois',23878,17);
INSERT INTO "django_geo_db_city" VALUES(19507,'Itasca','Itasca, Illinois',23879,17);
INSERT INTO "django_geo_db_city" VALUES(19508,'Kaneville','Kaneville, Illinois',23880,17);
INSERT INTO "django_geo_db_city" VALUES(19509,'Kingston','Kingston, Illinois',23881,17);
INSERT INTO "django_geo_db_city" VALUES(19510,'Kirkland','Kirkland, Illinois',23882,17);
INSERT INTO "django_geo_db_city" VALUES(19511,'Lafox','Lafox, Illinois',23880,17);
INSERT INTO "django_geo_db_city" VALUES(19512,'Lombard','Lombard, Illinois',23883,17);
INSERT INTO "django_geo_db_city" VALUES(19513,'Dement','Dement, Illinois',23884,17);
INSERT INTO "django_geo_db_city" VALUES(19514,'Malta','Malta, Illinois',23885,17);
INSERT INTO "django_geo_db_city" VALUES(19515,'Maple Park','Maple Park, Illinois',23886,17);
INSERT INTO "django_geo_db_city" VALUES(19516,'Marengo','Marengo, Illinois',23887,17);
INSERT INTO "django_geo_db_city" VALUES(19517,'Maywood','Maywood, Illinois',23888,17);
INSERT INTO "django_geo_db_city" VALUES(19518,'Westchester','Westchester, Illinois',23889,17);
INSERT INTO "django_geo_db_city" VALUES(19519,'Broadview','Broadview, Illinois',23890,17);
INSERT INTO "django_geo_db_city" VALUES(19520,'Lake in the Hills','Lake in the Hills, Illinois',23891,17);
INSERT INTO "django_geo_db_city" VALUES(19521,'Medinah','Medinah, Illinois',23892,17);
INSERT INTO "django_geo_db_city" VALUES(19522,'Schaumburg','Schaumburg, Illinois',23775,17);
INSERT INTO "django_geo_db_city" VALUES(19523,'Melrose Park','Melrose Park, Illinois',23893,17);
INSERT INTO "django_geo_db_city" VALUES(19524,'Hillside','Hillside, Illinois',23894,17);
INSERT INTO "django_geo_db_city" VALUES(19525,'Berkeley','Berkeley, Illinois',23895,17);
INSERT INTO "django_geo_db_city" VALUES(19526,'Stone Park','Stone Park, Illinois',23897,17);
INSERT INTO "django_geo_db_city" VALUES(19527,'Plato Center','Plato Center, Illinois',23898,17);
INSERT INTO "django_geo_db_city" VALUES(19528,'River Grove','River Grove, Illinois',23899,17);
INSERT INTO "django_geo_db_city" VALUES(19529,'Roselle','Roselle, Illinois',23900,17);
INSERT INTO "django_geo_db_city" VALUES(19530,'Saint Charles','Saint Charles, Illinois',23902,17);
INSERT INTO "django_geo_db_city" VALUES(19531,'Schiller Park','Schiller Park, Illinois',23904,17);
INSERT INTO "django_geo_db_city" VALUES(19532,'South Elgin','South Elgin, Illinois',23905,17);
INSERT INTO "django_geo_db_city" VALUES(19533,'Sycamore','Sycamore, Illinois',23906,17);
INSERT INTO "django_geo_db_city" VALUES(19534,'Hoffman Estates','Hoffman Estates, Illinois',23907,17);
INSERT INTO "django_geo_db_city" VALUES(19535,'Union','Union, Illinois',23908,17);
INSERT INTO "django_geo_db_city" VALUES(19536,'Villa Park','Villa Park, Illinois',23909,17);
INSERT INTO "django_geo_db_city" VALUES(19537,'Virgil','Virgil, Illinois',23910,17);
INSERT INTO "django_geo_db_city" VALUES(19538,'Wasco','Wasco, Illinois',23880,17);
INSERT INTO "django_geo_db_city" VALUES(19539,'Wayne','Wayne, Illinois',23911,17);
INSERT INTO "django_geo_db_city" VALUES(19540,'West Chicago','West Chicago, Illinois',23912,17);
INSERT INTO "django_geo_db_city" VALUES(19541,'Wheaton','Wheaton, Illinois',23913,17);
INSERT INTO "django_geo_db_city" VALUES(19542,'Winfield','Winfield, Illinois',23915,17);
INSERT INTO "django_geo_db_city" VALUES(19543,'Wood Dale','Wood Dale, Illinois',23916,17);
INSERT INTO "django_geo_db_city" VALUES(19544,'Evanston','Evanston, Illinois',23922,17);
INSERT INTO "django_geo_db_city" VALUES(19545,'Oak Park','Oak Park, Illinois',23927,17);
INSERT INTO "django_geo_db_city" VALUES(19546,'River Forest','River Forest, Illinois',23930,17);
INSERT INTO "django_geo_db_city" VALUES(19547,'Beecher','Beecher, Illinois',23932,17);
INSERT INTO "django_geo_db_city" VALUES(19548,'Berwyn','Berwyn, Illinois',23933,17);
INSERT INTO "django_geo_db_city" VALUES(19549,'Blue Island','Blue Island, Illinois',23934,17);
INSERT INTO "django_geo_db_city" VALUES(19550,'Braceville','Braceville, Illinois',23935,17);
INSERT INTO "django_geo_db_city" VALUES(19551,'Braidwood','Braidwood, Illinois',23936,17);
INSERT INTO "django_geo_db_city" VALUES(19552,'Calumet City','Calumet City, Illinois',23937,17);
INSERT INTO "django_geo_db_city" VALUES(19553,'Channahon','Channahon, Illinois',23938,17);
INSERT INTO "django_geo_db_city" VALUES(19554,'Chicago Heights','Chicago Heights, Illinois',23939,17);
INSERT INTO "django_geo_db_city" VALUES(19555,'Chicago Ridge','Chicago Ridge, Illinois',23940,17);
INSERT INTO "django_geo_db_city" VALUES(19556,'Coal City','Coal City, Illinois',23941,17);
INSERT INTO "django_geo_db_city" VALUES(19557,'Crete','Crete, Illinois',23942,17);
INSERT INTO "django_geo_db_city" VALUES(19558,'Dolton','Dolton, Illinois',23943,17);
INSERT INTO "django_geo_db_city" VALUES(19559,'Dwight','Dwight, Illinois',23944,17);
INSERT INTO "django_geo_db_city" VALUES(19560,'Elwood','Elwood, Illinois',23945,17);
INSERT INTO "django_geo_db_city" VALUES(19561,'Flossmoor','Flossmoor, Illinois',23946,17);
INSERT INTO "django_geo_db_city" VALUES(19562,'Frankfort','Frankfort, Illinois',23947,17);
INSERT INTO "django_geo_db_city" VALUES(19563,'Gardner','Gardner, Illinois',23948,17);
INSERT INTO "django_geo_db_city" VALUES(19564,'Glenwood','Glenwood, Illinois',23949,17);
INSERT INTO "django_geo_db_city" VALUES(19565,'Harvey','Harvey, Illinois',23950,17);
INSERT INTO "django_geo_db_city" VALUES(19566,'Hazel Crest','Hazel Crest, Illinois',23951,17);
INSERT INTO "django_geo_db_city" VALUES(19567,'Homewood','Homewood, Illinois',23952,17);
INSERT INTO "django_geo_db_city" VALUES(19568,'Joliet','Joliet, Illinois',23953,17);
INSERT INTO "django_geo_db_city" VALUES(19569,'Kinsman','Kinsman, Illinois',23959,17);
INSERT INTO "django_geo_db_city" VALUES(19570,'Lansing','Lansing, Illinois',23960,17);
INSERT INTO "django_geo_db_city" VALUES(19571,'Lemont','Lemont, Illinois',23961,17);
INSERT INTO "django_geo_db_city" VALUES(19572,'Bolingbrook','Bolingbrook, Illinois',23962,17);
INSERT INTO "django_geo_db_city" VALUES(19573,'Lockport','Lockport, Illinois',23963,17);
INSERT INTO "django_geo_db_city" VALUES(19574,'Manhattan','Manhattan, Illinois',23964,17);
INSERT INTO "django_geo_db_city" VALUES(19575,'Matteson','Matteson, Illinois',23965,17);
INSERT INTO "django_geo_db_city" VALUES(19576,'Mazon','Mazon, Illinois',23966,17);
INSERT INTO "django_geo_db_city" VALUES(19577,'Midlothian','Midlothian, Illinois',23967,17);
INSERT INTO "django_geo_db_city" VALUES(19578,'Romeoville','Romeoville, Illinois',23968,17);
INSERT INTO "django_geo_db_city" VALUES(19579,'Minooka','Minooka, Illinois',23969,17);
INSERT INTO "django_geo_db_city" VALUES(19580,'Mokena','Mokena, Illinois',23970,17);
INSERT INTO "django_geo_db_city" VALUES(19581,'Monee','Monee, Illinois',23971,17);
INSERT INTO "django_geo_db_city" VALUES(19582,'Morris','Morris, Illinois',23972,17);
INSERT INTO "django_geo_db_city" VALUES(19583,'New Lenox','New Lenox, Illinois',23973,17);
INSERT INTO "django_geo_db_city" VALUES(19584,'Oak Forest','Oak Forest, Illinois',23974,17);
INSERT INTO "django_geo_db_city" VALUES(19585,'Oak Lawn','Oak Lawn, Illinois',23975,17);
INSERT INTO "django_geo_db_city" VALUES(19586,'Bridgeview','Bridgeview, Illinois',23976,17);
INSERT INTO "django_geo_db_city" VALUES(19587,'Hometown','Hometown, Illinois',23977,17);
INSERT INTO "django_geo_db_city" VALUES(19588,'Hickory Hills','Hickory Hills, Illinois',23978,17);
INSERT INTO "django_geo_db_city" VALUES(19589,'Justice','Justice, Illinois',23979,17);
INSERT INTO "django_geo_db_city" VALUES(19590,'Burbank','Burbank, Illinois',23980,17);
INSERT INTO "django_geo_db_city" VALUES(19591,'Odell','Odell, Illinois',23981,17);
INSERT INTO "django_geo_db_city" VALUES(19592,'Olympia Fields','Olympia Fields, Illinois',23982,17);
INSERT INTO "django_geo_db_city" VALUES(19593,'Orland Park','Orland Park, Illinois',23983,17);
INSERT INTO "django_geo_db_city" VALUES(19594,'Palos Heights','Palos Heights, Illinois',23984,17);
INSERT INTO "django_geo_db_city" VALUES(19595,'Palos Park','Palos Park, Illinois',23985,17);
INSERT INTO "django_geo_db_city" VALUES(19596,'Palos Hills','Palos Hills, Illinois',23986,17);
INSERT INTO "django_geo_db_city" VALUES(19597,'Park Forest','Park Forest, Illinois',23987,17);
INSERT INTO "django_geo_db_city" VALUES(19598,'Peotone','Peotone, Illinois',23989,17);
INSERT INTO "django_geo_db_city" VALUES(19599,'Posen','Posen, Illinois',23990,17);
INSERT INTO "django_geo_db_city" VALUES(19600,'Ransom','Ransom, Illinois',23991,17);
INSERT INTO "django_geo_db_city" VALUES(19601,'Richton Park','Richton Park, Illinois',23992,17);
INSERT INTO "django_geo_db_city" VALUES(19602,'Robbins','Robbins, Illinois',23993,17);
INSERT INTO "django_geo_db_city" VALUES(19603,'South Holland','South Holland, Illinois',23994,17);
INSERT INTO "django_geo_db_city" VALUES(19604,'South Wilmington','South Wilmington, Illinois',23995,17);
INSERT INTO "django_geo_db_city" VALUES(19605,'Steger','Steger, Illinois',23996,17);
INSERT INTO "django_geo_db_city" VALUES(19606,'Thornton','Thornton, Illinois',23997,17);
INSERT INTO "django_geo_db_city" VALUES(19607,'Tinley Park','Tinley Park, Illinois',23998,17);
INSERT INTO "django_geo_db_city" VALUES(19608,'Country Club Hills','Country Club Hills, Illinois',23999,17);
INSERT INTO "django_geo_db_city" VALUES(19609,'Verona','Verona, Illinois',24000,17);
INSERT INTO "django_geo_db_city" VALUES(19610,'Willow Springs','Willow Springs, Illinois',24001,17);
INSERT INTO "django_geo_db_city" VALUES(19611,'Wilmington','Wilmington, Illinois',24002,17);
INSERT INTO "django_geo_db_city" VALUES(19612,'Worth','Worth, Illinois',24003,17);
INSERT INTO "django_geo_db_city" VALUES(19613,'Bedford Park','Bedford Park, Illinois',23775,17);
INSERT INTO "django_geo_db_city" VALUES(19614,'Summit Argo','Summit Argo, Illinois',24005,17);
INSERT INTO "django_geo_db_city" VALUES(19615,'Aurora','Aurora, Illinois',24006,17);
INSERT INTO "django_geo_db_city" VALUES(19616,'Batavia','Batavia, Illinois',24009,17);
INSERT INTO "django_geo_db_city" VALUES(19617,'Big Rock','Big Rock, Illinois',24010,17);
INSERT INTO "django_geo_db_city" VALUES(19618,'Bristol','Bristol, Illinois',24011,17);
INSERT INTO "django_geo_db_city" VALUES(19619,'Brookfield','Brookfield, Illinois',24012,17);
INSERT INTO "django_geo_db_city" VALUES(19620,'Clarendon Hills','Clarendon Hills, Illinois',24013,17);
INSERT INTO "django_geo_db_city" VALUES(19621,'Downers Grove','Downers Grove, Illinois',24014,17);
INSERT INTO "django_geo_db_city" VALUES(19622,'Woodridge','Woodridge, Illinois',24016,17);
INSERT INTO "django_geo_db_city" VALUES(19623,'Earlville','Earlville, Illinois',24017,17);
INSERT INTO "django_geo_db_city" VALUES(19624,'Eola','Eola, Illinois',24018,17);
INSERT INTO "django_geo_db_city" VALUES(19625,'Hinckley','Hinckley, Illinois',24019,17);
INSERT INTO "django_geo_db_city" VALUES(19626,'Hinsdale','Hinsdale, Illinois',24020,17);
INSERT INTO "django_geo_db_city" VALUES(19627,'Oak Brook','Oak Brook, Illinois',24021,17);
INSERT INTO "django_geo_db_city" VALUES(19628,'La Grange','La Grange, Illinois',24022,17);
INSERT INTO "django_geo_db_city" VALUES(19629,'La Grange Park','La Grange Park, Illinois',24023,17);
INSERT INTO "django_geo_db_city" VALUES(19630,'Lee','Lee, Illinois',24024,17);
INSERT INTO "django_geo_db_city" VALUES(19631,'Leland','Leland, Illinois',24025,17);
INSERT INTO "django_geo_db_city" VALUES(19632,'Lisle','Lisle, Illinois',24026,17);
INSERT INTO "django_geo_db_city" VALUES(19633,'Lyons','Lyons, Illinois',24027,17);
INSERT INTO "django_geo_db_city" VALUES(19634,'Millbrook','Millbrook, Illinois',24028,17);
INSERT INTO "django_geo_db_city" VALUES(19635,'Millington','Millington, Illinois',24029,17);
INSERT INTO "django_geo_db_city" VALUES(19636,'Montgomery','Montgomery, Illinois',24030,17);
INSERT INTO "django_geo_db_city" VALUES(19637,'Mooseheart','Mooseheart, Illinois',24031,17);
INSERT INTO "django_geo_db_city" VALUES(19638,'Naperville','Naperville, Illinois',24032,17);
INSERT INTO "django_geo_db_city" VALUES(19639,'Newark','Newark, Illinois',24033,17);
INSERT INTO "django_geo_db_city" VALUES(19640,'North Aurora','North Aurora, Illinois',24034,17);
INSERT INTO "django_geo_db_city" VALUES(19641,'Oswego','Oswego, Illinois',24035,17);
INSERT INTO "django_geo_db_city" VALUES(19642,'Plainfield','Plainfield, Illinois',24036,17);
INSERT INTO "django_geo_db_city" VALUES(19643,'Plano','Plano, Illinois',24037,17);
INSERT INTO "django_geo_db_city" VALUES(19644,'Riverside','Riverside, Illinois',24038,17);
INSERT INTO "django_geo_db_city" VALUES(19645,'Sandwich','Sandwich, Illinois',24039,17);
INSERT INTO "django_geo_db_city" VALUES(19646,'Serena','Serena, Illinois',24040,17);
INSERT INTO "django_geo_db_city" VALUES(19647,'Shabbona','Shabbona, Illinois',24041,17);
INSERT INTO "django_geo_db_city" VALUES(19648,'Sheridan','Sheridan, Illinois',24042,17);
INSERT INTO "django_geo_db_city" VALUES(19649,'Somonauk','Somonauk, Illinois',24043,17);
INSERT INTO "django_geo_db_city" VALUES(19650,'Steward','Steward, Illinois',24044,17);
INSERT INTO "django_geo_db_city" VALUES(19651,'Sugar Grove','Sugar Grove, Illinois',24045,17);
INSERT INTO "django_geo_db_city" VALUES(19652,'Warrenville','Warrenville, Illinois',24046,17);
INSERT INTO "django_geo_db_city" VALUES(19653,'Waterman','Waterman, Illinois',24047,17);
INSERT INTO "django_geo_db_city" VALUES(19654,'Wedron','Wedron, Illinois',24048,17);
INSERT INTO "django_geo_db_city" VALUES(19655,'Western Springs','Western Springs, Illinois',24049,17);
INSERT INTO "django_geo_db_city" VALUES(19656,'Westmont','Westmont, Illinois',24050,17);
INSERT INTO "django_geo_db_city" VALUES(19657,'Yorkville','Yorkville, Illinois',24051,17);
INSERT INTO "django_geo_db_city" VALUES(19658,'Darien','Darien, Illinois',24052,17);
INSERT INTO "django_geo_db_city" VALUES(19659,'Fox Valley','Fox Valley, Illinois',23849,17);
INSERT INTO "django_geo_db_city" VALUES(19660,'Chicago','Chicago, Illinois',24057,17);
INSERT INTO "django_geo_db_city" VALUES(19661,'Amf Ohare','Amf Ohare, Illinois',24114,17);
INSERT INTO "django_geo_db_city" VALUES(19662,'Harwood Heights','Harwood Heights, Illinois',24117,17);
INSERT INTO "django_geo_db_city" VALUES(19663,'Elmwood Park','Elmwood Park, Illinois',24118,17);
INSERT INTO "django_geo_db_city" VALUES(19664,'Lincolnwood','Lincolnwood, Illinois',24119,17);
INSERT INTO "django_geo_db_city" VALUES(19665,'Niles','Niles, Illinois',24120,17);
INSERT INTO "django_geo_db_city" VALUES(19666,'Alsip','Alsip, Illinois',24121,17);
INSERT INTO "django_geo_db_city" VALUES(19667,'Cicero','Cicero, Illinois',24122,17);
INSERT INTO "django_geo_db_city" VALUES(19668,'Evergreen Park','Evergreen Park, Illinois',24123,17);
INSERT INTO "django_geo_db_city" VALUES(19669,'Riverdale','Riverdale, Illinois',24124,17);
INSERT INTO "django_geo_db_city" VALUES(19670,'Kankakee','Kankakee, Illinois',24125,17);
INSERT INTO "django_geo_db_city" VALUES(19671,'Aroma Park','Aroma Park, Illinois',24127,17);
INSERT INTO "django_geo_db_city" VALUES(19672,'Ashkum','Ashkum, Illinois',24128,17);
INSERT INTO "django_geo_db_city" VALUES(19673,'Beaverville','Beaverville, Illinois',24129,17);
INSERT INTO "django_geo_db_city" VALUES(19674,'Bonfield','Bonfield, Illinois',24130,17);
INSERT INTO "django_geo_db_city" VALUES(19675,'Bourbonnais','Bourbonnais, Illinois',24131,17);
INSERT INTO "django_geo_db_city" VALUES(19676,'Bradley','Bradley, Illinois',24132,17);
INSERT INTO "django_geo_db_city" VALUES(19677,'Buckingham','Buckingham, Illinois',24133,17);
INSERT INTO "django_geo_db_city" VALUES(19678,'Buckley','Buckley, Illinois',24134,17);
INSERT INTO "django_geo_db_city" VALUES(19679,'Cabery','Cabery, Illinois',24135,17);
INSERT INTO "django_geo_db_city" VALUES(19680,'Campus','Campus, Illinois',24136,17);
INSERT INTO "django_geo_db_city" VALUES(19681,'Chatsworth','Chatsworth, Illinois',24137,17);
INSERT INTO "django_geo_db_city" VALUES(19682,'Chebanse','Chebanse, Illinois',24138,17);
INSERT INTO "django_geo_db_city" VALUES(19683,'Cissna Park','Cissna Park, Illinois',24139,17);
INSERT INTO "django_geo_db_city" VALUES(19684,'Claytonville','Claytonville, Illinois',24140,17);
INSERT INTO "django_geo_db_city" VALUES(19685,'Clifton','Clifton, Illinois',24141,17);
INSERT INTO "django_geo_db_city" VALUES(19686,'Crescent City','Crescent City, Illinois',24142,17);
INSERT INTO "django_geo_db_city" VALUES(19687,'Cullom','Cullom, Illinois',24143,17);
INSERT INTO "django_geo_db_city" VALUES(19688,'Danforth','Danforth, Illinois',24144,17);
INSERT INTO "django_geo_db_city" VALUES(19689,'Donovan','Donovan, Illinois',24145,17);
INSERT INTO "django_geo_db_city" VALUES(19690,'East Lynn','East Lynn, Illinois',24146,17);
INSERT INTO "django_geo_db_city" VALUES(19691,'Elliott','Elliott, Illinois',24147,17);
INSERT INTO "django_geo_db_city" VALUES(19692,'Emington','Emington, Illinois',24148,17);
INSERT INTO "django_geo_db_city" VALUES(19693,'Essex','Essex, Illinois',24149,17);
INSERT INTO "django_geo_db_city" VALUES(19694,'Gibson City','Gibson City, Illinois',24150,17);
INSERT INTO "django_geo_db_city" VALUES(19695,'Gilman','Gilman, Illinois',24151,17);
INSERT INTO "django_geo_db_city" VALUES(19696,'Goodwine','Goodwine, Illinois',24152,17);
INSERT INTO "django_geo_db_city" VALUES(19697,'Grant Park','Grant Park, Illinois',24153,17);
INSERT INTO "django_geo_db_city" VALUES(19698,'Herscher','Herscher, Illinois',24154,17);
INSERT INTO "django_geo_db_city" VALUES(19699,'Hoopeston','Hoopeston, Illinois',24155,17);
INSERT INTO "django_geo_db_city" VALUES(19700,'Hopkins Park','Hopkins Park, Illinois',24126,17);
INSERT INTO "django_geo_db_city" VALUES(19701,'Iroquois','Iroquois, Illinois',24156,17);
INSERT INTO "django_geo_db_city" VALUES(19702,'Kempton','Kempton, Illinois',24157,17);
INSERT INTO "django_geo_db_city" VALUES(19703,'Loda','Loda, Illinois',24158,17);
INSERT INTO "django_geo_db_city" VALUES(19704,'Ludlow','Ludlow, Illinois',24159,17);
INSERT INTO "django_geo_db_city" VALUES(19705,'Manteno','Manteno, Illinois',24160,17);
INSERT INTO "django_geo_db_city" VALUES(19706,'Martinton','Martinton, Illinois',24161,17);
INSERT INTO "django_geo_db_city" VALUES(19707,'Melvin','Melvin, Illinois',24162,17);
INSERT INTO "django_geo_db_city" VALUES(19708,'Milford','Milford, Illinois',24163,17);
INSERT INTO "django_geo_db_city" VALUES(19709,'Momence','Momence, Illinois',24164,17);
INSERT INTO "django_geo_db_city" VALUES(19710,'Onarga','Onarga, Illinois',24165,17);
INSERT INTO "django_geo_db_city" VALUES(19711,'Papineau','Papineau, Illinois',24166,17);
INSERT INTO "django_geo_db_city" VALUES(19712,'Paxton','Paxton, Illinois',24167,17);
INSERT INTO "django_geo_db_city" VALUES(19713,'Piper City','Piper City, Illinois',24168,17);
INSERT INTO "django_geo_db_city" VALUES(19714,'Rankin','Rankin, Illinois',24169,17);
INSERT INTO "django_geo_db_city" VALUES(19715,'Reddick','Reddick, Illinois',24170,17);
INSERT INTO "django_geo_db_city" VALUES(19716,'Roberts','Roberts, Illinois',24171,17);
INSERT INTO "django_geo_db_city" VALUES(19717,'Rossville','Rossville, Illinois',24172,17);
INSERT INTO "django_geo_db_city" VALUES(19718,'Saint Anne','Saint Anne, Illinois',24173,17);
INSERT INTO "django_geo_db_city" VALUES(19719,'Sheldon','Sheldon, Illinois',24174,17);
INSERT INTO "django_geo_db_city" VALUES(19720,'Stockland','Stockland, Illinois',24175,17);
INSERT INTO "django_geo_db_city" VALUES(19721,'Thawville','Thawville, Illinois',24176,17);
INSERT INTO "django_geo_db_city" VALUES(19722,'Union Hill','Union Hill, Illinois',24177,17);
INSERT INTO "django_geo_db_city" VALUES(19723,'Watseka','Watseka, Illinois',24178,17);
INSERT INTO "django_geo_db_city" VALUES(19724,'Wellington','Wellington, Illinois',24179,17);
INSERT INTO "django_geo_db_city" VALUES(19725,'Woodland','Woodland, Illinois',24180,17);
INSERT INTO "django_geo_db_city" VALUES(19726,'Apple River','Apple River, Illinois',24181,17);
INSERT INTO "django_geo_db_city" VALUES(19727,'Ashton','Ashton, Illinois',24182,17);
INSERT INTO "django_geo_db_city" VALUES(19728,'Baileyville','Baileyville, Illinois',24183,17);
INSERT INTO "django_geo_db_city" VALUES(19729,'Belvidere','Belvidere, Illinois',24184,17);
INSERT INTO "django_geo_db_city" VALUES(19730,'Byron','Byron, Illinois',24185,17);
INSERT INTO "django_geo_db_city" VALUES(19731,'Caledonia','Caledonia, Illinois',24186,17);
INSERT INTO "django_geo_db_city" VALUES(19732,'Capron','Capron, Illinois',24187,17);
INSERT INTO "django_geo_db_city" VALUES(19733,'Cedarville','Cedarville, Illinois',24188,17);
INSERT INTO "django_geo_db_city" VALUES(19734,'Chadwick','Chadwick, Illinois',24189,17);
INSERT INTO "django_geo_db_city" VALUES(19735,'Chana','Chana, Illinois',24190,17);
INSERT INTO "django_geo_db_city" VALUES(19736,'Cherry Valley','Cherry Valley, Illinois',24191,17);
INSERT INTO "django_geo_db_city" VALUES(19737,'Coleta','Coleta, Illinois',24192,17);
INSERT INTO "django_geo_db_city" VALUES(19738,'Dakota','Dakota, Illinois',24193,17);
INSERT INTO "django_geo_db_city" VALUES(19739,'Davis','Davis, Illinois',24194,17);
INSERT INTO "django_geo_db_city" VALUES(19740,'Davis Junction','Davis Junction, Illinois',24195,17);
INSERT INTO "django_geo_db_city" VALUES(19741,'Dixon','Dixon, Illinois',24196,17);
INSERT INTO "django_geo_db_city" VALUES(19742,'Durand','Durand, Illinois',24197,17);
INSERT INTO "django_geo_db_city" VALUES(19743,'East Dubuque','East Dubuque, Illinois',24198,17);
INSERT INTO "django_geo_db_city" VALUES(19744,'Eleroy','Eleroy, Illinois',24199,17);
INSERT INTO "django_geo_db_city" VALUES(19745,'Elizabeth','Elizabeth, Illinois',24200,17);
INSERT INTO "django_geo_db_city" VALUES(19746,'Forreston','Forreston, Illinois',24201,17);
INSERT INTO "django_geo_db_city" VALUES(19747,'Franklin Grove','Franklin Grove, Illinois',24202,17);
INSERT INTO "django_geo_db_city" VALUES(19748,'Freeport','Freeport, Illinois',24203,17);
INSERT INTO "django_geo_db_city" VALUES(19749,'Galena','Galena, Illinois',24204,17);
INSERT INTO "django_geo_db_city" VALUES(19750,'Galt','Galt, Illinois',24205,17);
INSERT INTO "django_geo_db_city" VALUES(19751,'Garden Prairie','Garden Prairie, Illinois',24206,17);
INSERT INTO "django_geo_db_city" VALUES(19752,'German Valley','German Valley, Illinois',24207,17);
INSERT INTO "django_geo_db_city" VALUES(19753,'Hanover','Hanover, Illinois',24208,17);
INSERT INTO "django_geo_db_city" VALUES(19754,'Harmon','Harmon, Illinois',24209,17);
INSERT INTO "django_geo_db_city" VALUES(19755,'Holcomb','Holcomb, Illinois',24210,17);
INSERT INTO "django_geo_db_city" VALUES(19756,'Kent','Kent, Illinois',24211,17);
INSERT INTO "django_geo_db_city" VALUES(19757,'Lanark','Lanark, Illinois',24212,17);
INSERT INTO "django_geo_db_city" VALUES(19758,'Leaf River','Leaf River, Illinois',24213,17);
INSERT INTO "django_geo_db_city" VALUES(19759,'Lena','Lena, Illinois',24214,17);
INSERT INTO "django_geo_db_city" VALUES(19760,'Lindenwood','Lindenwood, Illinois',24215,17);
INSERT INTO "django_geo_db_city" VALUES(19761,'McConnell','McConnell, Illinois',24216,17);
INSERT INTO "django_geo_db_city" VALUES(19762,'Milledgeville','Milledgeville, Illinois',24217,17);
INSERT INTO "django_geo_db_city" VALUES(19763,'Monroe Center','Monroe Center, Illinois',24218,17);
INSERT INTO "django_geo_db_city" VALUES(19764,'Mount Carroll','Mount Carroll, Illinois',24219,17);
INSERT INTO "django_geo_db_city" VALUES(19765,'Mount Morris','Mount Morris, Illinois',24220,17);
INSERT INTO "django_geo_db_city" VALUES(19766,'Nachusa','Nachusa, Illinois',24221,17);
INSERT INTO "django_geo_db_city" VALUES(19767,'Nelson','Nelson, Illinois',24222,17);
INSERT INTO "django_geo_db_city" VALUES(19768,'Nora','Nora, Illinois',24223,17);
INSERT INTO "django_geo_db_city" VALUES(19769,'Orangeville','Orangeville, Illinois',24224,17);
INSERT INTO "django_geo_db_city" VALUES(19770,'Oregon','Oregon, Illinois',24225,17);
INSERT INTO "django_geo_db_city" VALUES(19771,'Pearl City','Pearl City, Illinois',24226,17);
INSERT INTO "django_geo_db_city" VALUES(19772,'Pecatonica','Pecatonica, Illinois',24227,17);
INSERT INTO "django_geo_db_city" VALUES(19773,'Polo','Polo, Illinois',24228,17);
INSERT INTO "django_geo_db_city" VALUES(19774,'Poplar Grove','Poplar Grove, Illinois',24229,17);
INSERT INTO "django_geo_db_city" VALUES(19775,'Ridott','Ridott, Illinois',24230,17);
INSERT INTO "django_geo_db_city" VALUES(19776,'Rochelle','Rochelle, Illinois',24231,17);
INSERT INTO "django_geo_db_city" VALUES(19777,'Rock City','Rock City, Illinois',24232,17);
INSERT INTO "django_geo_db_city" VALUES(19778,'Rock Falls','Rock Falls, Illinois',24233,17);
INSERT INTO "django_geo_db_city" VALUES(19779,'Rockton','Rockton, Illinois',24234,17);
INSERT INTO "django_geo_db_city" VALUES(19780,'Roscoe','Roscoe, Illinois',24235,17);
INSERT INTO "django_geo_db_city" VALUES(19781,'Savanna','Savanna, Illinois',24236,17);
INSERT INTO "django_geo_db_city" VALUES(19782,'Scales Mound','Scales Mound, Illinois',24237,17);
INSERT INTO "django_geo_db_city" VALUES(19783,'Scioto Mills','Scioto Mills, Illinois',24238,17);
INSERT INTO "django_geo_db_city" VALUES(19784,'Seward','Seward, Illinois',24239,17);
INSERT INTO "django_geo_db_city" VALUES(19785,'Shannon','Shannon, Illinois',24240,17);
INSERT INTO "django_geo_db_city" VALUES(19786,'Shirland','Shirland, Illinois',24241,17);
INSERT INTO "django_geo_db_city" VALUES(19787,'South Beloit','South Beloit, Illinois',24242,17);
INSERT INTO "django_geo_db_city" VALUES(19788,'Sterling','Sterling, Illinois',24243,17);
INSERT INTO "django_geo_db_city" VALUES(19789,'Stillman Valley','Stillman Valley, Illinois',24244,17);
INSERT INTO "django_geo_db_city" VALUES(19790,'Stockton','Stockton, Illinois',24245,17);
INSERT INTO "django_geo_db_city" VALUES(19791,'Warren','Warren, Illinois',24246,17);
INSERT INTO "django_geo_db_city" VALUES(19792,'Winnebago','Winnebago, Illinois',24247,17);
INSERT INTO "django_geo_db_city" VALUES(19793,'Winslow','Winslow, Illinois',24248,17);
INSERT INTO "django_geo_db_city" VALUES(19794,'Woosung','Woosung, Illinois',24249,17);
INSERT INTO "django_geo_db_city" VALUES(19795,'Rockford','Rockford, Illinois',24250,17);
INSERT INTO "django_geo_db_city" VALUES(19796,'Loves Park','Loves Park, Illinois',24257,17);
INSERT INTO "django_geo_db_city" VALUES(19797,'Machesney Park','Machesney Park, Illinois',24260,17);
INSERT INTO "django_geo_db_city" VALUES(19798,'Rock Island','Rock Island, Illinois',24261,17);
INSERT INTO "django_geo_db_city" VALUES(19799,'Albany','Albany, Illinois',24264,17);
INSERT INTO "django_geo_db_city" VALUES(19800,'Aledo','Aledo, Illinois',24265,17);
INSERT INTO "django_geo_db_city" VALUES(19801,'Andalusia','Andalusia, Illinois',24266,17);
INSERT INTO "django_geo_db_city" VALUES(19802,'Andover','Andover, Illinois',24267,17);
INSERT INTO "django_geo_db_city" VALUES(19803,'Annawan','Annawan, Illinois',24268,17);
INSERT INTO "django_geo_db_city" VALUES(19804,'Atkinson','Atkinson, Illinois',24269,17);
INSERT INTO "django_geo_db_city" VALUES(19805,'Barstow','Barstow, Illinois',24270,17);
INSERT INTO "django_geo_db_city" VALUES(19806,'Buffalo Prairie','Buffalo Prairie, Illinois',24271,17);
INSERT INTO "django_geo_db_city" VALUES(19807,'Cambridge','Cambridge, Illinois',24272,17);
INSERT INTO "django_geo_db_city" VALUES(19808,'Carbon Cliff','Carbon Cliff, Illinois',24273,17);
INSERT INTO "django_geo_db_city" VALUES(19809,'Coal Valley','Coal Valley, Illinois',24274,17);
INSERT INTO "django_geo_db_city" VALUES(19810,'Colona','Colona, Illinois',24275,17);
INSERT INTO "django_geo_db_city" VALUES(19811,'Cordova','Cordova, Illinois',24276,17);
INSERT INTO "django_geo_db_city" VALUES(19812,'Deer Grove','Deer Grove, Illinois',24277,17);
INSERT INTO "django_geo_db_city" VALUES(19813,'East Moline','East Moline, Illinois',24278,17);
INSERT INTO "django_geo_db_city" VALUES(19814,'Erie','Erie, Illinois',24279,17);
INSERT INTO "django_geo_db_city" VALUES(19815,'Fenton','Fenton, Illinois',24280,17);
INSERT INTO "django_geo_db_city" VALUES(19816,'Fulton','Fulton, Illinois',24281,17);
INSERT INTO "django_geo_db_city" VALUES(19817,'Geneseo','Geneseo, Illinois',24282,17);
INSERT INTO "django_geo_db_city" VALUES(19818,'Hampton','Hampton, Illinois',24283,17);
INSERT INTO "django_geo_db_city" VALUES(19819,'Hillsdale','Hillsdale, Illinois',24284,17);
INSERT INTO "django_geo_db_city" VALUES(19820,'Hooppole','Hooppole, Illinois',24285,17);
INSERT INTO "django_geo_db_city" VALUES(19821,'Illinois City','Illinois City, Illinois',24286,17);
INSERT INTO "django_geo_db_city" VALUES(19822,'Joy','Joy, Illinois',24287,17);
INSERT INTO "django_geo_db_city" VALUES(19823,'Lyndon','Lyndon, Illinois',24288,17);
INSERT INTO "django_geo_db_city" VALUES(19824,'Lynn Center','Lynn Center, Illinois',24289,17);
INSERT INTO "django_geo_db_city" VALUES(19825,'Matherville','Matherville, Illinois',24290,17);
INSERT INTO "django_geo_db_city" VALUES(19826,'Milan','Milan, Illinois',24291,17);
INSERT INTO "django_geo_db_city" VALUES(19827,'Moline','Moline, Illinois',24292,17);
INSERT INTO "django_geo_db_city" VALUES(19828,'Morrison','Morrison, Illinois',24293,17);
INSERT INTO "django_geo_db_city" VALUES(19829,'New Boston','New Boston, Illinois',24294,17);
INSERT INTO "django_geo_db_city" VALUES(19830,'Orion','Orion, Illinois',24295,17);
INSERT INTO "django_geo_db_city" VALUES(19831,'Osco','Osco, Illinois',24296,17);
INSERT INTO "django_geo_db_city" VALUES(19832,'Port Byron','Port Byron, Illinois',24297,17);
INSERT INTO "django_geo_db_city" VALUES(19833,'Preemption','Preemption, Illinois',24298,17);
INSERT INTO "django_geo_db_city" VALUES(19834,'Prophetstown','Prophetstown, Illinois',24299,17);
INSERT INTO "django_geo_db_city" VALUES(19835,'Rapids City','Rapids City, Illinois',24300,17);
INSERT INTO "django_geo_db_city" VALUES(19836,'Reynolds','Reynolds, Illinois',24301,17);
INSERT INTO "django_geo_db_city" VALUES(19837,'Sherrard','Sherrard, Illinois',24302,17);
INSERT INTO "django_geo_db_city" VALUES(19838,'Silvis','Silvis, Illinois',24303,17);
INSERT INTO "django_geo_db_city" VALUES(19839,'Tampico','Tampico, Illinois',24304,17);
INSERT INTO "django_geo_db_city" VALUES(19840,'Taylor Ridge','Taylor Ridge, Illinois',24305,17);
INSERT INTO "django_geo_db_city" VALUES(19841,'Thomson','Thomson, Illinois',24306,17);
INSERT INTO "django_geo_db_city" VALUES(19842,'La Salle','La Salle, Illinois',24308,17);
INSERT INTO "django_geo_db_city" VALUES(19843,'Amboy','Amboy, Illinois',24309,17);
INSERT INTO "django_geo_db_city" VALUES(19844,'Ancona','Ancona, Illinois',24310,17);
INSERT INTO "django_geo_db_city" VALUES(19845,'Arlington','Arlington, Illinois',24311,17);
INSERT INTO "django_geo_db_city" VALUES(19846,'Blackstone','Blackstone, Illinois',24312,17);
INSERT INTO "django_geo_db_city" VALUES(19847,'Buda','Buda, Illinois',24313,17);
INSERT INTO "django_geo_db_city" VALUES(19848,'Bureau','Bureau, Illinois',24314,17);
INSERT INTO "django_geo_db_city" VALUES(19849,'Cedar Point','Cedar Point, Illinois',24315,17);
INSERT INTO "django_geo_db_city" VALUES(19850,'Cherry','Cherry, Illinois',24316,17);
INSERT INTO "django_geo_db_city" VALUES(19851,'Compton','Compton, Illinois',24317,17);
INSERT INTO "django_geo_db_city" VALUES(19852,'Cornell','Cornell, Illinois',24318,17);
INSERT INTO "django_geo_db_city" VALUES(19853,'Dalzell','Dalzell, Illinois',24319,17);
INSERT INTO "django_geo_db_city" VALUES(19854,'Dana','Dana, Illinois',24320,17);
INSERT INTO "django_geo_db_city" VALUES(19855,'Depue','Depue, Illinois',24321,17);
INSERT INTO "django_geo_db_city" VALUES(19856,'Dover','Dover, Illinois',24322,17);
INSERT INTO "django_geo_db_city" VALUES(19857,'Eldena','Eldena, Illinois',24323,17);
INSERT INTO "django_geo_db_city" VALUES(19858,'Grand Ridge','Grand Ridge, Illinois',24324,17);
INSERT INTO "django_geo_db_city" VALUES(19859,'Granville','Granville, Illinois',24325,17);
INSERT INTO "django_geo_db_city" VALUES(19860,'Hennepin','Hennepin, Illinois',24326,17);
INSERT INTO "django_geo_db_city" VALUES(19861,'Kasbeer','Kasbeer, Illinois',24327,17);
INSERT INTO "django_geo_db_city" VALUES(19862,'Ladd','Ladd, Illinois',24328,17);
INSERT INTO "django_geo_db_city" VALUES(19863,'La Moille','La Moille, Illinois',24329,17);
INSERT INTO "django_geo_db_city" VALUES(19864,'Lee Center','Lee Center, Illinois',24330,17);
INSERT INTO "django_geo_db_city" VALUES(19865,'Leonore','Leonore, Illinois',24331,17);
INSERT INTO "django_geo_db_city" VALUES(19866,'Long Point','Long Point, Illinois',24332,17);
INSERT INTO "django_geo_db_city" VALUES(19867,'Lostant','Lostant, Illinois',24333,17);
INSERT INTO "django_geo_db_city" VALUES(19868,'McNabb','McNabb, Illinois',24334,17);
INSERT INTO "django_geo_db_city" VALUES(19869,'Magnolia','Magnolia, Illinois',24335,17);
INSERT INTO "django_geo_db_city" VALUES(19870,'Malden','Malden, Illinois',24336,17);
INSERT INTO "django_geo_db_city" VALUES(19871,'Manlius','Manlius, Illinois',24337,17);
INSERT INTO "django_geo_db_city" VALUES(19872,'Mark','Mark, Illinois',24338,17);
INSERT INTO "django_geo_db_city" VALUES(19873,'Marseilles','Marseilles, Illinois',24339,17);
INSERT INTO "django_geo_db_city" VALUES(19874,'Mendota','Mendota, Illinois',24340,17);
INSERT INTO "django_geo_db_city" VALUES(19875,'Mineral','Mineral, Illinois',24341,17);
INSERT INTO "django_geo_db_city" VALUES(19876,'Neponset','Neponset, Illinois',24342,17);
INSERT INTO "django_geo_db_city" VALUES(19877,'New Bedford','New Bedford, Illinois',24343,17);
INSERT INTO "django_geo_db_city" VALUES(19878,'Oglesby','Oglesby, Illinois',24344,17);
INSERT INTO "django_geo_db_city" VALUES(19879,'Ohio','Ohio, Illinois',24345,17);
INSERT INTO "django_geo_db_city" VALUES(19880,'Ottawa','Ottawa, Illinois',24346,17);
INSERT INTO "django_geo_db_city" VALUES(19881,'Paw Paw','Paw Paw, Illinois',24347,17);
INSERT INTO "django_geo_db_city" VALUES(19882,'Peru','Peru, Illinois',24348,17);
INSERT INTO "django_geo_db_city" VALUES(19883,'Princeton','Princeton, Illinois',24349,17);
INSERT INTO "django_geo_db_city" VALUES(19884,'Rutland','Rutland, Illinois',24350,17);
INSERT INTO "django_geo_db_city" VALUES(19885,'Seatonville','Seatonville, Illinois',24351,17);
INSERT INTO "django_geo_db_city" VALUES(19886,'Seneca','Seneca, Illinois',24352,17);
INSERT INTO "django_geo_db_city" VALUES(19887,'Sheffield','Sheffield, Illinois',24353,17);
INSERT INTO "django_geo_db_city" VALUES(19888,'Spring Valley','Spring Valley, Illinois',24354,17);
INSERT INTO "django_geo_db_city" VALUES(19889,'Standard','Standard, Illinois',24355,17);
INSERT INTO "django_geo_db_city" VALUES(19890,'Streator','Streator, Illinois',24356,17);
INSERT INTO "django_geo_db_city" VALUES(19891,'Sublette','Sublette, Illinois',24357,17);
INSERT INTO "django_geo_db_city" VALUES(19892,'Tiskilwa','Tiskilwa, Illinois',24358,17);
INSERT INTO "django_geo_db_city" VALUES(19893,'Toluca','Toluca, Illinois',24359,17);
INSERT INTO "django_geo_db_city" VALUES(19894,'Tonica','Tonica, Illinois',24360,17);
INSERT INTO "django_geo_db_city" VALUES(19895,'Triumph','Triumph, Illinois',24361,17);
INSERT INTO "django_geo_db_city" VALUES(19896,'Troy Grove','Troy Grove, Illinois',24362,17);
INSERT INTO "django_geo_db_city" VALUES(19897,'Utica','Utica, Illinois',24363,17);
INSERT INTO "django_geo_db_city" VALUES(19898,'Van Orin','Van Orin, Illinois',24364,17);
INSERT INTO "django_geo_db_city" VALUES(19899,'Varna','Varna, Illinois',24365,17);
INSERT INTO "django_geo_db_city" VALUES(19900,'Walnut','Walnut, Illinois',24366,17);
INSERT INTO "django_geo_db_city" VALUES(19901,'Wenona','Wenona, Illinois',24367,17);
INSERT INTO "django_geo_db_city" VALUES(19902,'West Brooklyn','West Brooklyn, Illinois',24368,17);
INSERT INTO "django_geo_db_city" VALUES(19903,'Wyanet','Wyanet, Illinois',24369,17);
INSERT INTO "django_geo_db_city" VALUES(19904,'Galesburg','Galesburg, Illinois',24370,17);
INSERT INTO "django_geo_db_city" VALUES(19905,'Abingdon','Abingdon, Illinois',24372,17);
INSERT INTO "django_geo_db_city" VALUES(19906,'Adair','Adair, Illinois',24373,17);
INSERT INTO "django_geo_db_city" VALUES(19907,'Alexis','Alexis, Illinois',24374,17);
INSERT INTO "django_geo_db_city" VALUES(19908,'Alpha','Alpha, Illinois',24375,17);
INSERT INTO "django_geo_db_city" VALUES(19909,'Altona','Altona, Illinois',24376,17);
INSERT INTO "django_geo_db_city" VALUES(19910,'Avon','Avon, Illinois',24377,17);
INSERT INTO "django_geo_db_city" VALUES(19911,'Bardolph','Bardolph, Illinois',24378,17);
INSERT INTO "django_geo_db_city" VALUES(19912,'Berwick','Berwick, Illinois',24379,17);
INSERT INTO "django_geo_db_city" VALUES(19913,'Biggsville','Biggsville, Illinois',24380,17);
INSERT INTO "django_geo_db_city" VALUES(19914,'Bishop Hill','Bishop Hill, Illinois',24381,17);
INSERT INTO "django_geo_db_city" VALUES(19915,'Blandinsville','Blandinsville, Illinois',24382,17);
INSERT INTO "django_geo_db_city" VALUES(19916,'Bradford','Bradford, Illinois',24383,17);
INSERT INTO "django_geo_db_city" VALUES(19917,'Bushnell','Bushnell, Illinois',24384,17);
INSERT INTO "django_geo_db_city" VALUES(19918,'Cameron','Cameron, Illinois',24385,17);
INSERT INTO "django_geo_db_city" VALUES(19919,'Camp Grove','Camp Grove, Illinois',24386,17);
INSERT INTO "django_geo_db_city" VALUES(19920,'Carman','Carman, Illinois',24387,17);
INSERT INTO "django_geo_db_city" VALUES(19921,'Castleton','Castleton, Illinois',24388,17);
INSERT INTO "django_geo_db_city" VALUES(19922,'Cuba','Cuba, Illinois',24389,17);
INSERT INTO "django_geo_db_city" VALUES(19923,'Dahinda','Dahinda, Illinois',24390,17);
INSERT INTO "django_geo_db_city" VALUES(19924,'East Galesburg','East Galesburg, Illinois',24391,17);
INSERT INTO "django_geo_db_city" VALUES(19925,'Ellisville','Ellisville, Illinois',24392,17);
INSERT INTO "django_geo_db_city" VALUES(19926,'Fairview','Fairview, Illinois',24393,17);
INSERT INTO "django_geo_db_city" VALUES(19927,'Fiatt','Fiatt, Illinois',24394,17);
INSERT INTO "django_geo_db_city" VALUES(19928,'Galva','Galva, Illinois',24395,17);
INSERT INTO "django_geo_db_city" VALUES(19929,'Gerlaw','Gerlaw, Illinois',24396,17);
INSERT INTO "django_geo_db_city" VALUES(19930,'Gilson','Gilson, Illinois',24397,17);
INSERT INTO "django_geo_db_city" VALUES(19931,'Gladstone','Gladstone, Illinois',24398,17);
INSERT INTO "django_geo_db_city" VALUES(19932,'Good Hope','Good Hope, Illinois',24399,17);
INSERT INTO "django_geo_db_city" VALUES(19933,'Henderson','Henderson, Illinois',24400,17);
INSERT INTO "django_geo_db_city" VALUES(19934,'Industry','Industry, Illinois',24401,17);
INSERT INTO "django_geo_db_city" VALUES(19935,'Ipava','Ipava, Illinois',24402,17);
INSERT INTO "django_geo_db_city" VALUES(19936,'Keithsburg','Keithsburg, Illinois',24403,17);
INSERT INTO "django_geo_db_city" VALUES(19937,'Kewanee','Kewanee, Illinois',24404,17);
INSERT INTO "django_geo_db_city" VALUES(19938,'Kirkwood','Kirkwood, Illinois',24405,17);
INSERT INTO "django_geo_db_city" VALUES(19939,'Knoxville','Knoxville, Illinois',24406,17);
INSERT INTO "django_geo_db_city" VALUES(19940,'La Fayette','La Fayette, Illinois',24407,17);
INSERT INTO "django_geo_db_city" VALUES(19941,'La Harpe','La Harpe, Illinois',24408,17);
INSERT INTO "django_geo_db_city" VALUES(19942,'Laura','Laura, Illinois',24409,17);
INSERT INTO "django_geo_db_city" VALUES(19943,'Littleton','Littleton, Illinois',24410,17);
INSERT INTO "django_geo_db_city" VALUES(19944,'Little York','Little York, Illinois',24411,17);
INSERT INTO "django_geo_db_city" VALUES(19945,'Lomax','Lomax, Illinois',24412,17);
INSERT INTO "django_geo_db_city" VALUES(19946,'Macomb','Macomb, Illinois',24413,17);
INSERT INTO "django_geo_db_city" VALUES(19947,'Maquon','Maquon, Illinois',24415,17);
INSERT INTO "django_geo_db_city" VALUES(19948,'Marietta','Marietta, Illinois',24416,17);
INSERT INTO "django_geo_db_city" VALUES(19949,'Media','Media, Illinois',24417,17);
INSERT INTO "django_geo_db_city" VALUES(19950,'Monmouth','Monmouth, Illinois',24418,17);
INSERT INTO "django_geo_db_city" VALUES(19951,'New Windsor','New Windsor, Illinois',24419,17);
INSERT INTO "django_geo_db_city" VALUES(19952,'North Henderson','North Henderson, Illinois',24420,17);
INSERT INTO "django_geo_db_city" VALUES(19953,'Oneida','Oneida, Illinois',24421,17);
INSERT INTO "django_geo_db_city" VALUES(19954,'Opheim','Opheim, Illinois',24422,17);
INSERT INTO "django_geo_db_city" VALUES(19955,'Oquawka','Oquawka, Illinois',24423,17);
INSERT INTO "django_geo_db_city" VALUES(19956,'Prairie City','Prairie City, Illinois',24424,17);
INSERT INTO "django_geo_db_city" VALUES(19957,'Raritan','Raritan, Illinois',24425,17);
INSERT INTO "django_geo_db_city" VALUES(19958,'Rio','Rio, Illinois',24426,17);
INSERT INTO "django_geo_db_city" VALUES(19959,'Roseville','Roseville, Illinois',24427,17);
INSERT INTO "django_geo_db_city" VALUES(19960,'Saint Augustine','Saint Augustine, Illinois',24428,17);
INSERT INTO "django_geo_db_city" VALUES(19961,'Sciota','Sciota, Illinois',24429,17);
INSERT INTO "django_geo_db_city" VALUES(19962,'Seaton','Seaton, Illinois',24430,17);
INSERT INTO "django_geo_db_city" VALUES(19963,'Smithfield','Smithfield, Illinois',24431,17);
INSERT INTO "django_geo_db_city" VALUES(19964,'Smithshire','Smithshire, Illinois',24432,17);
INSERT INTO "django_geo_db_city" VALUES(19965,'Speer','Speer, Illinois',24433,17);
INSERT INTO "django_geo_db_city" VALUES(19966,'Stronghurst','Stronghurst, Illinois',24434,17);
INSERT INTO "django_geo_db_city" VALUES(19967,'Table Grove','Table Grove, Illinois',24435,17);
INSERT INTO "django_geo_db_city" VALUES(19968,'Toulon','Toulon, Illinois',24436,17);
INSERT INTO "django_geo_db_city" VALUES(19969,'Vermont','Vermont, Illinois',24437,17);
INSERT INTO "django_geo_db_city" VALUES(19970,'Victoria','Victoria, Illinois',24438,17);
INSERT INTO "django_geo_db_city" VALUES(19971,'Viola','Viola, Illinois',24439,17);
INSERT INTO "django_geo_db_city" VALUES(19972,'Wataga','Wataga, Illinois',24440,17);
INSERT INTO "django_geo_db_city" VALUES(19973,'Williamsfield','Williamsfield, Illinois',24441,17);
INSERT INTO "django_geo_db_city" VALUES(19974,'Woodhull','Woodhull, Illinois',24442,17);
INSERT INTO "django_geo_db_city" VALUES(19975,'Wyoming','Wyoming, Illinois',24443,17);
INSERT INTO "django_geo_db_city" VALUES(19976,'Astoria','Astoria, Illinois',24444,17);
INSERT INTO "django_geo_db_city" VALUES(19977,'Benson','Benson, Illinois',24445,17);
INSERT INTO "django_geo_db_city" VALUES(19978,'Brimfield','Brimfield, Illinois',24446,17);
INSERT INTO "django_geo_db_city" VALUES(19979,'Bryant','Bryant, Illinois',24448,17);
INSERT INTO "django_geo_db_city" VALUES(19980,'Canton','Canton, Illinois',24449,17);
INSERT INTO "django_geo_db_city" VALUES(19981,'Chillicothe','Chillicothe, Illinois',24450,17);
INSERT INTO "django_geo_db_city" VALUES(19982,'Dunfermline','Dunfermline, Illinois',24451,17);
INSERT INTO "django_geo_db_city" VALUES(19983,'Dunlap','Dunlap, Illinois',24452,17);
INSERT INTO "django_geo_db_city" VALUES(19984,'Edelstein','Edelstein, Illinois',24453,17);
INSERT INTO "django_geo_db_city" VALUES(19985,'Edwards','Edwards, Illinois',24454,17);
INSERT INTO "django_geo_db_city" VALUES(19986,'Elmwood','Elmwood, Illinois',24455,17);
INSERT INTO "django_geo_db_city" VALUES(19987,'Eureka','Eureka, Illinois',24456,17);
INSERT INTO "django_geo_db_city" VALUES(19988,'Farmington','Farmington, Illinois',24457,17);
INSERT INTO "django_geo_db_city" VALUES(19989,'Forest City','Forest City, Illinois',24458,17);
INSERT INTO "django_geo_db_city" VALUES(19990,'Glasford','Glasford, Illinois',24459,17);
INSERT INTO "django_geo_db_city" VALUES(19991,'Green Valley','Green Valley, Illinois',24460,17);
INSERT INTO "django_geo_db_city" VALUES(19992,'Groveland','Groveland, Illinois',24461,17);
INSERT INTO "django_geo_db_city" VALUES(19993,'Hanna City','Hanna City, Illinois',24462,17);
INSERT INTO "django_geo_db_city" VALUES(19994,'Henry','Henry, Illinois',24463,17);
INSERT INTO "django_geo_db_city" VALUES(19995,'Kingston Mines','Kingston Mines, Illinois',24464,17);
INSERT INTO "django_geo_db_city" VALUES(19996,'Lacon','Lacon, Illinois',24465,17);
INSERT INTO "django_geo_db_city" VALUES(19997,'La Rose','La Rose, Illinois',24466,17);
INSERT INTO "django_geo_db_city" VALUES(19998,'Lewistown','Lewistown, Illinois',24467,17);
INSERT INTO "django_geo_db_city" VALUES(19999,'Liverpool','Liverpool, Illinois',24468,17);
INSERT INTO "django_geo_db_city" VALUES(20000,'London Mills','London Mills, Illinois',24469,17);
INSERT INTO "django_geo_db_city" VALUES(20001,'Lowpoint','Lowpoint, Illinois',24470,17);
INSERT INTO "django_geo_db_city" VALUES(20002,'Manito','Manito, Illinois',24471,17);
INSERT INTO "django_geo_db_city" VALUES(20003,'Mapleton','Mapleton, Illinois',24472,17);
INSERT INTO "django_geo_db_city" VALUES(20004,'Metamora','Metamora, Illinois',24473,17);
INSERT INTO "django_geo_db_city" VALUES(20005,'Morton','Morton, Illinois',24474,17);
INSERT INTO "django_geo_db_city" VALUES(20006,'Mossville','Mossville, Illinois',24475,17);
INSERT INTO "django_geo_db_city" VALUES(20007,'Norris','Norris, Illinois',24394,17);
INSERT INTO "django_geo_db_city" VALUES(20008,'Pekin','Pekin, Illinois',24476,17);
INSERT INTO "django_geo_db_city" VALUES(20009,'Princeville','Princeville, Illinois',24479,17);
INSERT INTO "django_geo_db_city" VALUES(20010,'Putnam','Putnam, Illinois',24480,17);
INSERT INTO "django_geo_db_city" VALUES(20011,'Roanoke','Roanoke, Illinois',24481,17);
INSERT INTO "django_geo_db_city" VALUES(20012,'Rome','Rome, Illinois',24482,17);
INSERT INTO "django_geo_db_city" VALUES(20013,'Saint David','Saint David, Illinois',24483,17);
INSERT INTO "django_geo_db_city" VALUES(20014,'South Pekin','South Pekin, Illinois',24484,17);
INSERT INTO "django_geo_db_city" VALUES(20015,'Sparland','Sparland, Illinois',24485,17);
INSERT INTO "django_geo_db_city" VALUES(20016,'Topeka','Topeka, Illinois',24486,17);
INSERT INTO "django_geo_db_city" VALUES(20017,'Tremont','Tremont, Illinois',24487,17);
INSERT INTO "django_geo_db_city" VALUES(20018,'Trivoli','Trivoli, Illinois',24488,17);
INSERT INTO "django_geo_db_city" VALUES(20019,'Washburn','Washburn, Illinois',24489,17);
INSERT INTO "django_geo_db_city" VALUES(20020,'Washington','Washington, Illinois',24490,17);
INSERT INTO "django_geo_db_city" VALUES(20021,'Yates City','Yates City, Illinois',24491,17);
INSERT INTO "django_geo_db_city" VALUES(20022,'Richland','Richland, Illinois',24492,17);
INSERT INTO "django_geo_db_city" VALUES(20023,'Garrett','Garrett, Illinois',24494,17);
INSERT INTO "django_geo_db_city" VALUES(20024,'Peoria','Peoria, Illinois',24495,17);
INSERT INTO "django_geo_db_city" VALUES(20025,'Creve Coeur','Creve Coeur, Illinois',24502,17);
INSERT INTO "django_geo_db_city" VALUES(20026,'East Peoria','East Peoria, Illinois',24503,17);
INSERT INTO "django_geo_db_city" VALUES(20027,'Carlock','Carlock, Illinois',24520,17);
INSERT INTO "django_geo_db_city" VALUES(20028,'Bloomington','Bloomington, Illinois',24521,17);
INSERT INTO "django_geo_db_city" VALUES(20029,'Anchor','Anchor, Illinois',24526,17);
INSERT INTO "django_geo_db_city" VALUES(20030,'Armington','Armington, Illinois',24527,17);
INSERT INTO "django_geo_db_city" VALUES(20031,'Arrowsmith','Arrowsmith, Illinois',24528,17);
INSERT INTO "django_geo_db_city" VALUES(20032,'Atlanta','Atlanta, Illinois',24529,17);
INSERT INTO "django_geo_db_city" VALUES(20033,'Bellflower','Bellflower, Illinois',24530,17);
INSERT INTO "django_geo_db_city" VALUES(20034,'Chenoa','Chenoa, Illinois',24532,17);
INSERT INTO "django_geo_db_city" VALUES(20035,'Clinton','Clinton, Illinois',24533,17);
INSERT INTO "django_geo_db_city" VALUES(20036,'Colfax','Colfax, Illinois',24534,17);
INSERT INTO "django_geo_db_city" VALUES(20037,'Congerville','Congerville, Illinois',24535,17);
INSERT INTO "django_geo_db_city" VALUES(20038,'Cooksville','Cooksville, Illinois',24536,17);
INSERT INTO "django_geo_db_city" VALUES(20039,'Cropsey','Cropsey, Illinois',24537,17);
INSERT INTO "django_geo_db_city" VALUES(20040,'Danvers','Danvers, Illinois',24538,17);
INSERT INTO "django_geo_db_city" VALUES(20041,'Deer Creek','Deer Creek, Illinois',24539,17);
INSERT INTO "django_geo_db_city" VALUES(20042,'Delavan','Delavan, Illinois',24540,17);
INSERT INTO "django_geo_db_city" VALUES(20043,'Dewitt','Dewitt, Illinois',24541,17);
INSERT INTO "django_geo_db_city" VALUES(20044,'Downs','Downs, Illinois',24542,17);
INSERT INTO "django_geo_db_city" VALUES(20045,'Ellsworth','Ellsworth, Illinois',24543,17);
INSERT INTO "django_geo_db_city" VALUES(20046,'El Paso','El Paso, Illinois',24544,17);
INSERT INTO "django_geo_db_city" VALUES(20047,'Fairbury','Fairbury, Illinois',24545,17);
INSERT INTO "django_geo_db_city" VALUES(20048,'Flanagan','Flanagan, Illinois',24546,17);
INSERT INTO "django_geo_db_city" VALUES(20049,'Forrest','Forrest, Illinois',24547,17);
INSERT INTO "django_geo_db_city" VALUES(20050,'Goodfield','Goodfield, Illinois',24548,17);
INSERT INTO "django_geo_db_city" VALUES(20051,'Graymont','Graymont, Illinois',24549,17);
INSERT INTO "django_geo_db_city" VALUES(20052,'Gridley','Gridley, Illinois',24550,17);
INSERT INTO "django_geo_db_city" VALUES(20053,'Heyworth','Heyworth, Illinois',24551,17);
INSERT INTO "django_geo_db_city" VALUES(20054,'Hopedale','Hopedale, Illinois',24552,17);
INSERT INTO "django_geo_db_city" VALUES(20055,'Hudson','Hudson, Illinois',24553,17);
INSERT INTO "django_geo_db_city" VALUES(20056,'Kenney','Kenney, Illinois',24554,17);
INSERT INTO "django_geo_db_city" VALUES(20057,'Lane','Lane, Illinois',24555,17);
INSERT INTO "django_geo_db_city" VALUES(20058,'Lawndale','Lawndale, Illinois',24556,17);
INSERT INTO "django_geo_db_city" VALUES(20059,'Le Roy','Le Roy, Illinois',24557,17);
INSERT INTO "django_geo_db_city" VALUES(20060,'Lexington','Lexington, Illinois',24558,17);
INSERT INTO "django_geo_db_city" VALUES(20061,'McLean','McLean, Illinois',24559,17);
INSERT INTO "django_geo_db_city" VALUES(20062,'Mackinaw','Mackinaw, Illinois',24560,17);
INSERT INTO "django_geo_db_city" VALUES(20063,'Maroa','Maroa, Illinois',24561,17);
INSERT INTO "django_geo_db_city" VALUES(20064,'Merna','Merna, Illinois',24562,17);
INSERT INTO "django_geo_db_city" VALUES(20065,'Minier','Minier, Illinois',24563,17);
INSERT INTO "django_geo_db_city" VALUES(20066,'Minonk','Minonk, Illinois',24564,17);
INSERT INTO "django_geo_db_city" VALUES(20067,'Normal','Normal, Illinois',24565,17);
INSERT INTO "django_geo_db_city" VALUES(20068,'Pontiac','Pontiac, Illinois',24566,17);
INSERT INTO "django_geo_db_city" VALUES(20069,'Towanda','Towanda, Illinois',24567,17);
INSERT INTO "django_geo_db_city" VALUES(20070,'Saunemin','Saunemin, Illinois',24568,17);
INSERT INTO "django_geo_db_city" VALUES(20071,'Saybrook','Saybrook, Illinois',24569,17);
INSERT INTO "django_geo_db_city" VALUES(20072,'Secor','Secor, Illinois',24570,17);
INSERT INTO "django_geo_db_city" VALUES(20073,'Shirley','Shirley, Illinois',24571,17);
INSERT INTO "django_geo_db_city" VALUES(20074,'Sibley','Sibley, Illinois',24572,17);
INSERT INTO "django_geo_db_city" VALUES(20075,'Stanford','Stanford, Illinois',24573,17);
INSERT INTO "django_geo_db_city" VALUES(20076,'Strawn','Strawn, Illinois',24574,17);
INSERT INTO "django_geo_db_city" VALUES(20077,'Wapella','Wapella, Illinois',24576,17);
INSERT INTO "django_geo_db_city" VALUES(20078,'Waynesville','Waynesville, Illinois',24577,17);
INSERT INTO "django_geo_db_city" VALUES(20079,'Urbana','Urbana, Illinois',24580,17);
INSERT INTO "django_geo_db_city" VALUES(20080,'Allerton','Allerton, Illinois',24583,17);
INSERT INTO "django_geo_db_city" VALUES(20081,'Alvin','Alvin, Illinois',24584,17);
INSERT INTO "django_geo_db_city" VALUES(20082,'Armstrong','Armstrong, Illinois',24585,17);
INSERT INTO "django_geo_db_city" VALUES(20083,'Bement','Bement, Illinois',24586,17);
INSERT INTO "django_geo_db_city" VALUES(20084,'Bismarck','Bismarck, Illinois',24587,17);
INSERT INTO "django_geo_db_city" VALUES(20085,'Bondville','Bondville, Illinois',24588,17);
INSERT INTO "django_geo_db_city" VALUES(20086,'Broadlands','Broadlands, Illinois',24589,17);
INSERT INTO "django_geo_db_city" VALUES(20087,'Catlin','Catlin, Illinois',24590,17);
INSERT INTO "django_geo_db_city" VALUES(20088,'Cerro Gordo','Cerro Gordo, Illinois',24591,17);
INSERT INTO "django_geo_db_city" VALUES(20089,'Champaign','Champaign, Illinois',24593,17);
INSERT INTO "django_geo_db_city" VALUES(20090,'Cisco','Cisco, Illinois',24598,17);
INSERT INTO "django_geo_db_city" VALUES(20091,'Collison','Collison, Illinois',24599,17);
INSERT INTO "django_geo_db_city" VALUES(20092,'Danville','Danville, Illinois',24600,17);
INSERT INTO "django_geo_db_city" VALUES(20093,'Tilton','Tilton, Illinois',24601,17);
INSERT INTO "django_geo_db_city" VALUES(20094,'De Land','De Land, Illinois',24603,17);
INSERT INTO "django_geo_db_city" VALUES(20095,'Dewey','Dewey, Illinois',24604,17);
INSERT INTO "django_geo_db_city" VALUES(20096,'Fairmount','Fairmount, Illinois',24605,17);
INSERT INTO "django_geo_db_city" VALUES(20097,'Farmer City','Farmer City, Illinois',24606,17);
INSERT INTO "django_geo_db_city" VALUES(20098,'Fisher','Fisher, Illinois',24607,17);
INSERT INTO "django_geo_db_city" VALUES(20099,'Fithian','Fithian, Illinois',24608,17);
INSERT INTO "django_geo_db_city" VALUES(20100,'Foosland','Foosland, Illinois',24609,17);
INSERT INTO "django_geo_db_city" VALUES(20101,'Georgetown','Georgetown, Illinois',24610,17);
INSERT INTO "django_geo_db_city" VALUES(20102,'Gifford','Gifford, Illinois',24611,17);
INSERT INTO "django_geo_db_city" VALUES(20103,'Henning','Henning, Illinois',24612,17);
INSERT INTO "django_geo_db_city" VALUES(20104,'Homer','Homer, Illinois',24613,17);
INSERT INTO "django_geo_db_city" VALUES(20105,'Indianola','Indianola, Illinois',24614,17);
INSERT INTO "django_geo_db_city" VALUES(20106,'Ivesdale','Ivesdale, Illinois',24615,17);
INSERT INTO "django_geo_db_city" VALUES(20107,'Longview','Longview, Illinois',24616,17);
INSERT INTO "django_geo_db_city" VALUES(20108,'Mahomet','Mahomet, Illinois',24617,17);
INSERT INTO "django_geo_db_city" VALUES(20109,'Mansfield','Mansfield, Illinois',24618,17);
INSERT INTO "django_geo_db_city" VALUES(20110,'Milmine','Milmine, Illinois',24619,17);
INSERT INTO "django_geo_db_city" VALUES(20111,'Monticello','Monticello, Illinois',24620,17);
INSERT INTO "django_geo_db_city" VALUES(20112,'Muncie','Muncie, Illinois',24621,17);
INSERT INTO "django_geo_db_city" VALUES(20113,'Oakwood','Oakwood, Illinois',24622,17);
INSERT INTO "django_geo_db_city" VALUES(20114,'Ogden','Ogden, Illinois',24623,17);
INSERT INTO "django_geo_db_city" VALUES(20115,'Penfield','Penfield, Illinois',24624,17);
INSERT INTO "django_geo_db_city" VALUES(20116,'Pesotum','Pesotum, Illinois',24625,17);
INSERT INTO "django_geo_db_city" VALUES(20117,'Philo','Philo, Illinois',24626,17);
INSERT INTO "django_geo_db_city" VALUES(20118,'Potomac','Potomac, Illinois',24627,17);
INSERT INTO "django_geo_db_city" VALUES(20119,'Rantoul','Rantoul, Illinois',24628,17);
INSERT INTO "django_geo_db_city" VALUES(20120,'Ridge Farm','Ridge Farm, Illinois',24629,17);
INSERT INTO "django_geo_db_city" VALUES(20121,'Royal','Royal, Illinois',24630,17);
INSERT INTO "django_geo_db_city" VALUES(20122,'Sadorus','Sadorus, Illinois',24631,17);
INSERT INTO "django_geo_db_city" VALUES(20123,'Saint Joseph','Saint Joseph, Illinois',24632,17);
INSERT INTO "django_geo_db_city" VALUES(20124,'Savoy','Savoy, Illinois',24633,17);
INSERT INTO "django_geo_db_city" VALUES(20125,'Seymour','Seymour, Illinois',24634,17);
INSERT INTO "django_geo_db_city" VALUES(20126,'Sidell','Sidell, Illinois',24635,17);
INSERT INTO "django_geo_db_city" VALUES(20127,'Sidney','Sidney, Illinois',24636,17);
INSERT INTO "django_geo_db_city" VALUES(20128,'Thomasboro','Thomasboro, Illinois',24637,17);
INSERT INTO "django_geo_db_city" VALUES(20129,'Tolono','Tolono, Illinois',24638,17);
INSERT INTO "django_geo_db_city" VALUES(20130,'Weldon','Weldon, Illinois',24639,17);
INSERT INTO "django_geo_db_city" VALUES(20131,'Westville','Westville, Illinois',24640,17);
INSERT INTO "django_geo_db_city" VALUES(20132,'White Heath','White Heath, Illinois',24641,17);
INSERT INTO "django_geo_db_city" VALUES(20133,'Arcola','Arcola, Illinois',24643,17);
INSERT INTO "django_geo_db_city" VALUES(20134,'Arthur','Arthur, Illinois',24644,17);
INSERT INTO "django_geo_db_city" VALUES(20135,'Ashmore','Ashmore, Illinois',24645,17);
INSERT INTO "django_geo_db_city" VALUES(20136,'Atwood','Atwood, Illinois',24646,17);
INSERT INTO "django_geo_db_city" VALUES(20137,'Bethany','Bethany, Illinois',24647,17);
INSERT INTO "django_geo_db_city" VALUES(20138,'Brocton','Brocton, Illinois',24648,17);
INSERT INTO "django_geo_db_city" VALUES(20139,'Camargo','Camargo, Illinois',24649,17);
INSERT INTO "django_geo_db_city" VALUES(20140,'Charleston','Charleston, Illinois',24650,17);
INSERT INTO "django_geo_db_city" VALUES(20141,'Chrisman','Chrisman, Illinois',24651,17);
INSERT INTO "django_geo_db_city" VALUES(20142,'Dalton City','Dalton City, Illinois',24652,17);
INSERT INTO "django_geo_db_city" VALUES(20143,'Gays','Gays, Illinois',24653,17);
INSERT INTO "django_geo_db_city" VALUES(20144,'Hammond','Hammond, Illinois',24654,17);
INSERT INTO "django_geo_db_city" VALUES(20145,'Hindsboro','Hindsboro, Illinois',24655,17);
INSERT INTO "django_geo_db_city" VALUES(20146,'Humboldt','Humboldt, Illinois',24656,17);
INSERT INTO "django_geo_db_city" VALUES(20147,'Hume','Hume, Illinois',24657,17);
INSERT INTO "django_geo_db_city" VALUES(20148,'Kansas','Kansas, Illinois',24658,17);
INSERT INTO "django_geo_db_city" VALUES(20149,'La Place','La Place, Illinois',24659,17);
INSERT INTO "django_geo_db_city" VALUES(20150,'Lovington','Lovington, Illinois',24660,17);
INSERT INTO "django_geo_db_city" VALUES(20151,'Mattoon','Mattoon, Illinois',24661,17);
INSERT INTO "django_geo_db_city" VALUES(20152,'Metcalf','Metcalf, Illinois',24662,17);
INSERT INTO "django_geo_db_city" VALUES(20153,'Murdock','Murdock, Illinois',24663,17);
INSERT INTO "django_geo_db_city" VALUES(20154,'Newman','Newman, Illinois',24664,17);
INSERT INTO "django_geo_db_city" VALUES(20155,'Oakland','Oakland, Illinois',24665,17);
INSERT INTO "django_geo_db_city" VALUES(20156,'Paris','Paris, Illinois',24666,17);
INSERT INTO "django_geo_db_city" VALUES(20157,'Redmon','Redmon, Illinois',24667,17);
INSERT INTO "django_geo_db_city" VALUES(20158,'Sullivan','Sullivan, Illinois',24668,17);
INSERT INTO "django_geo_db_city" VALUES(20159,'Tuscola','Tuscola, Illinois',24669,17);
INSERT INTO "django_geo_db_city" VALUES(20160,'Vermilion','Vermilion, Illinois',24670,17);
INSERT INTO "django_geo_db_city" VALUES(20161,'Villa Grove','Villa Grove, Illinois',24671,17);
INSERT INTO "django_geo_db_city" VALUES(20162,'Windsor','Windsor, Illinois',24672,17);
INSERT INTO "django_geo_db_city" VALUES(20163,'Alhambra','Alhambra, Illinois',24673,17);
INSERT INTO "django_geo_db_city" VALUES(20164,'Alton','Alton, Illinois',24674,17);
INSERT INTO "django_geo_db_city" VALUES(20165,'Medora','Medora, Illinois',24675,17);
INSERT INTO "django_geo_db_city" VALUES(20166,'Batchtown','Batchtown, Illinois',24676,17);
INSERT INTO "django_geo_db_city" VALUES(20167,'Benld','Benld, Illinois',24677,17);
INSERT INTO "django_geo_db_city" VALUES(20168,'Bethalto','Bethalto, Illinois',24678,17);
INSERT INTO "django_geo_db_city" VALUES(20169,'Bingham','Bingham, Illinois',24679,17);
INSERT INTO "django_geo_db_city" VALUES(20170,'Brighton','Brighton, Illinois',24680,17);
INSERT INTO "django_geo_db_city" VALUES(20171,'Brussels','Brussels, Illinois',24681,17);
INSERT INTO "django_geo_db_city" VALUES(20172,'Bunker Hill','Bunker Hill, Illinois',24682,17);
INSERT INTO "django_geo_db_city" VALUES(20173,'Butler','Butler, Illinois',24683,17);
INSERT INTO "django_geo_db_city" VALUES(20174,'Carrollton','Carrollton, Illinois',24684,17);
INSERT INTO "django_geo_db_city" VALUES(20175,'Coffeen','Coffeen, Illinois',24685,17);
INSERT INTO "django_geo_db_city" VALUES(20176,'Cottage Hills','Cottage Hills, Illinois',24686,17);
INSERT INTO "django_geo_db_city" VALUES(20177,'Donnellson','Donnellson, Illinois',24687,17);
INSERT INTO "django_geo_db_city" VALUES(20178,'Dorsey','Dorsey, Illinois',24688,17);
INSERT INTO "django_geo_db_city" VALUES(20179,'Dow','Dow, Illinois',24689,17);
INSERT INTO "django_geo_db_city" VALUES(20180,'Eagarville','Eagarville, Illinois',24690,17);
INSERT INTO "django_geo_db_city" VALUES(20181,'East Alton','East Alton, Illinois',24691,17);
INSERT INTO "django_geo_db_city" VALUES(20182,'Edwardsville','Edwardsville, Illinois',24692,17);
INSERT INTO "django_geo_db_city" VALUES(20183,'Eldred','Eldred, Illinois',24694,17);
INSERT INTO "django_geo_db_city" VALUES(20184,'Elsah','Elsah, Illinois',24695,17);
INSERT INTO "django_geo_db_city" VALUES(20185,'Fidelity','Fidelity, Illinois',24696,17);
INSERT INTO "django_geo_db_city" VALUES(20186,'Fieldon','Fieldon, Illinois',24697,17);
INSERT INTO "django_geo_db_city" VALUES(20187,'Fillmore','Fillmore, Illinois',24698,17);
INSERT INTO "django_geo_db_city" VALUES(20188,'Gillespie','Gillespie, Illinois',24699,17);
INSERT INTO "django_geo_db_city" VALUES(20189,'Glen Carbon','Glen Carbon, Illinois',24700,17);
INSERT INTO "django_geo_db_city" VALUES(20190,'Godfrey','Godfrey, Illinois',24701,17);
INSERT INTO "django_geo_db_city" VALUES(20191,'Golden Eagle','Golden Eagle, Illinois',24702,17);
INSERT INTO "django_geo_db_city" VALUES(20192,'Grafton','Grafton, Illinois',24703,17);
INSERT INTO "django_geo_db_city" VALUES(20193,'Granite City','Granite City, Illinois',24704,17);
INSERT INTO "django_geo_db_city" VALUES(20194,'Brushy Mound','Brushy Mound, Illinois',24705,17);
INSERT INTO "django_geo_db_city" VALUES(20195,'Greenfield','Greenfield, Illinois',24706,17);
INSERT INTO "django_geo_db_city" VALUES(20196,'Hamburg','Hamburg, Illinois',24707,17);
INSERT INTO "django_geo_db_city" VALUES(20197,'Hamel','Hamel, Illinois',24708,17);
INSERT INTO "django_geo_db_city" VALUES(20198,'Hardin','Hardin, Illinois',24709,17);
INSERT INTO "django_geo_db_city" VALUES(20199,'Hartford','Hartford, Illinois',24710,17);
INSERT INTO "django_geo_db_city" VALUES(20200,'Hillsboro','Hillsboro, Illinois',24711,17);
INSERT INTO "django_geo_db_city" VALUES(20201,'Hillview','Hillview, Illinois',24712,17);
INSERT INTO "django_geo_db_city" VALUES(20202,'Irving','Irving, Illinois',24713,17);
INSERT INTO "django_geo_db_city" VALUES(20203,'Jerseyville','Jerseyville, Illinois',24714,17);
INSERT INTO "django_geo_db_city" VALUES(20204,'Kampsville','Kampsville, Illinois',24715,17);
INSERT INTO "django_geo_db_city" VALUES(20205,'Kane','Kane, Illinois',24716,17);
INSERT INTO "django_geo_db_city" VALUES(20206,'Litchfield','Litchfield, Illinois',24717,17);
INSERT INTO "django_geo_db_city" VALUES(20207,'Livingston','Livingston, Illinois',24718,17);
INSERT INTO "django_geo_db_city" VALUES(20208,'Lovejoy','Lovejoy, Illinois',24719,17);
INSERT INTO "django_geo_db_city" VALUES(20209,'Madison','Madison, Illinois',24720,17);
INSERT INTO "django_geo_db_city" VALUES(20210,'Marine','Marine, Illinois',24721,17);
INSERT INTO "django_geo_db_city" VALUES(20211,'Maryville','Maryville, Illinois',24722,17);
INSERT INTO "django_geo_db_city" VALUES(20212,'Michael','Michael, Illinois',24724,17);
INSERT INTO "django_geo_db_city" VALUES(20213,'Moro','Moro, Illinois',24725,17);
INSERT INTO "django_geo_db_city" VALUES(20214,'Mount Olive','Mount Olive, Illinois',24726,17);
INSERT INTO "django_geo_db_city" VALUES(20215,'Mozier','Mozier, Illinois',24727,17);
INSERT INTO "django_geo_db_city" VALUES(20216,'National Stock Yards','National Stock Yards, Illinois',24728,17);
INSERT INTO "django_geo_db_city" VALUES(20217,'New Douglas','New Douglas, Illinois',24729,17);
INSERT INTO "django_geo_db_city" VALUES(20218,'Nokomis','Nokomis, Illinois',24730,17);
INSERT INTO "django_geo_db_city" VALUES(20219,'Ohlman','Ohlman, Illinois',24731,17);
INSERT INTO "django_geo_db_city" VALUES(20220,'Panama','Panama, Illinois',24732,17);
INSERT INTO "django_geo_db_city" VALUES(20221,'Patterson','Patterson, Illinois',24733,17);
INSERT INTO "django_geo_db_city" VALUES(20222,'Piasa','Piasa, Illinois',24734,17);
INSERT INTO "django_geo_db_city" VALUES(20223,'Ramsey','Ramsey, Illinois',24735,17);
INSERT INTO "django_geo_db_city" VALUES(20224,'Rockbridge','Rockbridge, Illinois',24736,17);
INSERT INTO "django_geo_db_city" VALUES(20225,'Roodhouse','Roodhouse, Illinois',24737,17);
INSERT INTO "django_geo_db_city" VALUES(20226,'Rosamond','Rosamond, Illinois',24738,17);
INSERT INTO "django_geo_db_city" VALUES(20227,'Roxana','Roxana, Illinois',24739,17);
INSERT INTO "django_geo_db_city" VALUES(20228,'Sawyerville','Sawyerville, Illinois',24740,17);
INSERT INTO "django_geo_db_city" VALUES(20229,'Sorento','Sorento, Illinois',24741,17);
INSERT INTO "django_geo_db_city" VALUES(20230,'South Roxana','South Roxana, Illinois',24742,17);
INSERT INTO "django_geo_db_city" VALUES(20231,'Staunton','Staunton, Illinois',24743,17);
INSERT INTO "django_geo_db_city" VALUES(20232,'Taylor Springs','Taylor Springs, Illinois',24744,17);
INSERT INTO "django_geo_db_city" VALUES(20233,'Venice','Venice, Illinois',24745,17);
INSERT INTO "django_geo_db_city" VALUES(20234,'Walshville','Walshville, Illinois',24746,17);
INSERT INTO "django_geo_db_city" VALUES(20235,'White Hall','White Hall, Illinois',24747,17);
INSERT INTO "django_geo_db_city" VALUES(20236,'Wilsonville','Wilsonville, Illinois',24748,17);
INSERT INTO "django_geo_db_city" VALUES(20237,'Witt','Witt, Illinois',24749,17);
INSERT INTO "django_geo_db_city" VALUES(20238,'Wood River','Wood River, Illinois',24750,17);
INSERT INTO "django_geo_db_city" VALUES(20239,'Worden','Worden, Illinois',24751,17);
INSERT INTO "django_geo_db_city" VALUES(20240,'Wrights','Wrights, Illinois',24752,17);
INSERT INTO "django_geo_db_city" VALUES(20241,'East Saint Louis','East Saint Louis, Illinois',24753,17);
INSERT INTO "django_geo_db_city" VALUES(20242,'Fairview Heights','Fairview Heights, Illinois',24760,17);
INSERT INTO "django_geo_db_city" VALUES(20243,'Addieville','Addieville, Illinois',24761,17);
INSERT INTO "django_geo_db_city" VALUES(20244,'Albers','Albers, Illinois',24762,17);
INSERT INTO "django_geo_db_city" VALUES(20245,'Aviston','Aviston, Illinois',24763,17);
INSERT INTO "django_geo_db_city" VALUES(20246,'Baldwin','Baldwin, Illinois',24764,17);
INSERT INTO "django_geo_db_city" VALUES(20247,'Bartelso','Bartelso, Illinois',24765,17);
INSERT INTO "django_geo_db_city" VALUES(20248,'Beckemeyer','Beckemeyer, Illinois',24766,17);
INSERT INTO "django_geo_db_city" VALUES(20249,'Belleville','Belleville, Illinois',24767,17);
INSERT INTO "django_geo_db_city" VALUES(20250,'Mascoutah','Mascoutah, Illinois',24769,17);
INSERT INTO "django_geo_db_city" VALUES(20251,'Scott Air Force Base','Scott Air Force Base, Illinois',24771,17);
INSERT INTO "django_geo_db_city" VALUES(20252,'Breese','Breese, Illinois',24773,17);
INSERT INTO "django_geo_db_city" VALUES(20253,'Carlyle','Carlyle, Illinois',24774,17);
INSERT INTO "django_geo_db_city" VALUES(20254,'Caseyville','Caseyville, Illinois',24775,17);
INSERT INTO "django_geo_db_city" VALUES(20255,'Chester','Chester, Illinois',24776,17);
INSERT INTO "django_geo_db_city" VALUES(20256,'Collinsville','Collinsville, Illinois',24777,17);
INSERT INTO "django_geo_db_city" VALUES(20257,'Columbia','Columbia, Illinois',24778,17);
INSERT INTO "django_geo_db_city" VALUES(20258,'Coulterville','Coulterville, Illinois',24779,17);
INSERT INTO "django_geo_db_city" VALUES(20259,'Cutler','Cutler, Illinois',24780,17);
INSERT INTO "django_geo_db_city" VALUES(20260,'Dupo','Dupo, Illinois',24781,17);
INSERT INTO "django_geo_db_city" VALUES(20261,'East Carondelet','East Carondelet, Illinois',24782,17);
INSERT INTO "django_geo_db_city" VALUES(20262,'Ellis Grove','Ellis Grove, Illinois',24783,17);
INSERT INTO "django_geo_db_city" VALUES(20263,'Evansville','Evansville, Illinois',24784,17);
INSERT INTO "django_geo_db_city" VALUES(20264,'Freeburg','Freeburg, Illinois',24785,17);
INSERT INTO "django_geo_db_city" VALUES(20265,'Fults','Fults, Illinois',24786,17);
INSERT INTO "django_geo_db_city" VALUES(20266,'Germantown','Germantown, Illinois',24787,17);
INSERT INTO "django_geo_db_city" VALUES(20267,'Greenville','Greenville, Illinois',24788,17);
INSERT INTO "django_geo_db_city" VALUES(20268,'Hagarstown','Hagarstown, Illinois',24789,17);
INSERT INTO "django_geo_db_city" VALUES(20269,'Hecker','Hecker, Illinois',24790,17);
INSERT INTO "django_geo_db_city" VALUES(20270,'Highland','Highland, Illinois',24791,17);
INSERT INTO "django_geo_db_city" VALUES(20271,'Hoffman','Hoffman, Illinois',24792,17);
INSERT INTO "django_geo_db_city" VALUES(20272,'Huey','Huey, Illinois',24793,17);
INSERT INTO "django_geo_db_city" VALUES(20273,'Keyesport','Keyesport, Illinois',24794,17);
INSERT INTO "django_geo_db_city" VALUES(20274,'Lebanon','Lebanon, Illinois',24795,17);
INSERT INTO "django_geo_db_city" VALUES(20275,'Lenzburg','Lenzburg, Illinois',24796,17);
INSERT INTO "django_geo_db_city" VALUES(20276,'Maeystown','Maeystown, Illinois',24797,17);
INSERT INTO "django_geo_db_city" VALUES(20277,'Marissa','Marissa, Illinois',24798,17);
INSERT INTO "django_geo_db_city" VALUES(20278,'Menard','Menard, Illinois',24800,17);
INSERT INTO "django_geo_db_city" VALUES(20279,'Millstadt','Millstadt, Illinois',24801,17);
INSERT INTO "django_geo_db_city" VALUES(20280,'Modoc','Modoc, Illinois',24802,17);
INSERT INTO "django_geo_db_city" VALUES(20281,'Mulberry Grove','Mulberry Grove, Illinois',24803,17);
INSERT INTO "django_geo_db_city" VALUES(20282,'Nashville','Nashville, Illinois',24804,17);
INSERT INTO "django_geo_db_city" VALUES(20283,'New Athens','New Athens, Illinois',24805,17);
INSERT INTO "django_geo_db_city" VALUES(20284,'New Baden','New Baden, Illinois',24806,17);
INSERT INTO "django_geo_db_city" VALUES(20285,'New Memphis','New Memphis, Illinois',24807,17);
INSERT INTO "django_geo_db_city" VALUES(20286,'Oakdale','Oakdale, Illinois',24808,17);
INSERT INTO "django_geo_db_city" VALUES(20287,'O Fallon','O Fallon, Illinois',24809,17);
INSERT INTO "django_geo_db_city" VALUES(20288,'Okawville','Okawville, Illinois',24811,17);
INSERT INTO "django_geo_db_city" VALUES(20289,'Percy','Percy, Illinois',24812,17);
INSERT INTO "django_geo_db_city" VALUES(20290,'Pierron','Pierron, Illinois',24813,17);
INSERT INTO "django_geo_db_city" VALUES(20291,'Pinckneyville','Pinckneyville, Illinois',24814,17);
INSERT INTO "django_geo_db_city" VALUES(20292,'Pocahontas','Pocahontas, Illinois',24815,17);
INSERT INTO "django_geo_db_city" VALUES(20293,'Prairie Du Rocher','Prairie Du Rocher, Illinois',24816,17);
INSERT INTO "django_geo_db_city" VALUES(20294,'Red Bud','Red Bud, Illinois',24817,17);
INSERT INTO "django_geo_db_city" VALUES(20295,'Renault','Renault, Illinois',24818,17);
INSERT INTO "django_geo_db_city" VALUES(20296,'Rockwood','Rockwood, Illinois',24819,17);
INSERT INTO "django_geo_db_city" VALUES(20297,'Saint Jacob','Saint Jacob, Illinois',24820,17);
INSERT INTO "django_geo_db_city" VALUES(20298,'Saint Libory','Saint Libory, Illinois',24821,17);
INSERT INTO "django_geo_db_city" VALUES(20299,'Shattuc','Shattuc, Illinois',24822,17);
INSERT INTO "django_geo_db_city" VALUES(20300,'Smithboro','Smithboro, Illinois',24823,17);
INSERT INTO "django_geo_db_city" VALUES(20301,'Smithton','Smithton, Illinois',24824,17);
INSERT INTO "django_geo_db_city" VALUES(20302,'Sparta','Sparta, Illinois',24825,17);
INSERT INTO "django_geo_db_city" VALUES(20303,'Steeleville','Steeleville, Illinois',24826,17);
INSERT INTO "django_geo_db_city" VALUES(20304,'Summerfield','Summerfield, Illinois',24827,17);
INSERT INTO "django_geo_db_city" VALUES(20305,'Tilden','Tilden, Illinois',24828,17);
INSERT INTO "django_geo_db_city" VALUES(20306,'Trenton','Trenton, Illinois',24829,17);
INSERT INTO "django_geo_db_city" VALUES(20307,'Troy','Troy, Illinois',24830,17);
INSERT INTO "django_geo_db_city" VALUES(20308,'Valmeyer','Valmeyer, Illinois',24831,17);
INSERT INTO "django_geo_db_city" VALUES(20309,'Walsh','Walsh, Illinois',24832,17);
INSERT INTO "django_geo_db_city" VALUES(20310,'Waterloo','Waterloo, Illinois',24833,17);
INSERT INTO "django_geo_db_city" VALUES(20311,'Quincy','Quincy, Illinois',24834,17);
INSERT INTO "django_geo_db_city" VALUES(20312,'Adrian','Adrian, Illinois',24837,17);
INSERT INTO "django_geo_db_city" VALUES(20313,'Augusta','Augusta, Illinois',24838,17);
INSERT INTO "django_geo_db_city" VALUES(20314,'Barry','Barry, Illinois',24839,17);
INSERT INTO "django_geo_db_city" VALUES(20315,'Basco','Basco, Illinois',24840,17);
INSERT INTO "django_geo_db_city" VALUES(20316,'Baylis','Baylis, Illinois',24841,17);
INSERT INTO "django_geo_db_city" VALUES(20317,'Bowen','Bowen, Illinois',24842,17);
INSERT INTO "django_geo_db_city" VALUES(20318,'Burnside','Burnside, Illinois',24843,17);
INSERT INTO "django_geo_db_city" VALUES(20319,'Camden','Camden, Illinois',24844,17);
INSERT INTO "django_geo_db_city" VALUES(20320,'Camp Point','Camp Point, Illinois',24845,17);
INSERT INTO "django_geo_db_city" VALUES(20321,'Carthage','Carthage, Illinois',24846,17);
INSERT INTO "django_geo_db_city" VALUES(20322,'Chambersburg','Chambersburg, Illinois',24847,17);
INSERT INTO "django_geo_db_city" VALUES(20323,'Clayton','Clayton, Illinois',24848,17);
INSERT INTO "django_geo_db_city" VALUES(20324,'Coatsburg','Coatsburg, Illinois',24849,17);
INSERT INTO "django_geo_db_city" VALUES(20325,'Colchester','Colchester, Illinois',24850,17);
INSERT INTO "django_geo_db_city" VALUES(20326,'Colusa','Colusa, Illinois',24851,17);
INSERT INTO "django_geo_db_city" VALUES(20327,'Dallas City','Dallas City, Illinois',24852,17);
INSERT INTO "django_geo_db_city" VALUES(20328,'Elvaston','Elvaston, Illinois',24853,17);
INSERT INTO "django_geo_db_city" VALUES(20329,'Ferris','Ferris, Illinois',24854,17);
INSERT INTO "django_geo_db_city" VALUES(20330,'Fowler','Fowler, Illinois',24855,17);
INSERT INTO "django_geo_db_city" VALUES(20331,'Golden','Golden, Illinois',24856,17);
INSERT INTO "django_geo_db_city" VALUES(20332,'Griggsville','Griggsville, Illinois',24857,17);
INSERT INTO "django_geo_db_city" VALUES(20333,'Hamilton','Hamilton, Illinois',24858,17);
INSERT INTO "django_geo_db_city" VALUES(20334,'Hull','Hull, Illinois',24859,17);
INSERT INTO "django_geo_db_city" VALUES(20335,'Huntsville','Huntsville, Illinois',24860,17);
INSERT INTO "django_geo_db_city" VALUES(20336,'Kinderhook','Kinderhook, Illinois',24861,17);
INSERT INTO "django_geo_db_city" VALUES(20337,'La Prairie','La Prairie, Illinois',24862,17);
INSERT INTO "django_geo_db_city" VALUES(20338,'Liberty','Liberty, Illinois',24863,17);
INSERT INTO "django_geo_db_city" VALUES(20339,'Lima','Lima, Illinois',24864,17);
INSERT INTO "django_geo_db_city" VALUES(20340,'Loraine','Loraine, Illinois',24865,17);
INSERT INTO "django_geo_db_city" VALUES(20341,'Mendon','Mendon, Illinois',24866,17);
INSERT INTO "django_geo_db_city" VALUES(20342,'Mount Sterling','Mount Sterling, Illinois',24868,17);
INSERT INTO "django_geo_db_city" VALUES(20343,'Nauvoo','Nauvoo, Illinois',24869,17);
INSERT INTO "django_geo_db_city" VALUES(20344,'Nebo','Nebo, Illinois',24870,17);
INSERT INTO "django_geo_db_city" VALUES(20345,'New Canton','New Canton, Illinois',24871,17);
INSERT INTO "django_geo_db_city" VALUES(20346,'New Salem','New Salem, Illinois',24872,17);
INSERT INTO "django_geo_db_city" VALUES(20347,'Niota','Niota, Illinois',24873,17);
INSERT INTO "django_geo_db_city" VALUES(20348,'Paloma','Paloma, Illinois',24874,17);
INSERT INTO "django_geo_db_city" VALUES(20349,'Payson','Payson, Illinois',24875,17);
INSERT INTO "django_geo_db_city" VALUES(20350,'Pearl','Pearl, Illinois',24876,17);
INSERT INTO "django_geo_db_city" VALUES(20351,'Perry','Perry, Illinois',24877,17);
INSERT INTO "django_geo_db_city" VALUES(20352,'Pittsfield','Pittsfield, Illinois',24878,17);
INSERT INTO "django_geo_db_city" VALUES(20353,'Plainville','Plainville, Illinois',24879,17);
INSERT INTO "django_geo_db_city" VALUES(20354,'Pleasant Hill','Pleasant Hill, Illinois',24880,17);
INSERT INTO "django_geo_db_city" VALUES(20355,'Plymouth','Plymouth, Illinois',24881,17);
INSERT INTO "django_geo_db_city" VALUES(20356,'Rockport','Rockport, Illinois',24882,17);
INSERT INTO "django_geo_db_city" VALUES(20357,'Sutter','Sutter, Illinois',24883,17);
INSERT INTO "django_geo_db_city" VALUES(20358,'Tennessee','Tennessee, Illinois',24884,17);
INSERT INTO "django_geo_db_city" VALUES(20359,'Timewell','Timewell, Illinois',24885,17);
INSERT INTO "django_geo_db_city" VALUES(20360,'Ursa','Ursa, Illinois',24886,17);
INSERT INTO "django_geo_db_city" VALUES(20361,'Versailles','Versailles, Illinois',24887,17);
INSERT INTO "django_geo_db_city" VALUES(20362,'Warsaw','Warsaw, Illinois',24888,17);
INSERT INTO "django_geo_db_city" VALUES(20363,'West Point','West Point, Illinois',24889,17);
INSERT INTO "django_geo_db_city" VALUES(20364,'Equality','Equality, Illinois',24890,17);
INSERT INTO "django_geo_db_city" VALUES(20365,'Effingham','Effingham, Illinois',24891,17);
INSERT INTO "django_geo_db_city" VALUES(20366,'Summit','Summit, Illinois',24892,17);
INSERT INTO "django_geo_db_city" VALUES(20367,'Allendale','Allendale, Illinois',24893,17);
INSERT INTO "django_geo_db_city" VALUES(20368,'Altamont','Altamont, Illinois',24894,17);
INSERT INTO "django_geo_db_city" VALUES(20369,'Annapolis','Annapolis, Illinois',24895,17);
INSERT INTO "django_geo_db_city" VALUES(20370,'Beecher City','Beecher City, Illinois',24896,17);
INSERT INTO "django_geo_db_city" VALUES(20371,'Birds','Birds, Illinois',24897,17);
INSERT INTO "django_geo_db_city" VALUES(20372,'Bridgeport','Bridgeport, Illinois',24898,17);
INSERT INTO "django_geo_db_city" VALUES(20373,'Brownstown','Brownstown, Illinois',24899,17);
INSERT INTO "django_geo_db_city" VALUES(20374,'Calhoun','Calhoun, Illinois',24900,17);
INSERT INTO "django_geo_db_city" VALUES(20375,'Casey','Casey, Illinois',24901,17);
INSERT INTO "django_geo_db_city" VALUES(20376,'Claremont','Claremont, Illinois',24902,17);
INSERT INTO "django_geo_db_city" VALUES(20377,'Cowden','Cowden, Illinois',24903,17);
INSERT INTO "django_geo_db_city" VALUES(20378,'Dennison','Dennison, Illinois',24904,17);
INSERT INTO "django_geo_db_city" VALUES(20379,'Dieterich','Dieterich, Illinois',24905,17);
INSERT INTO "django_geo_db_city" VALUES(20380,'Dundas','Dundas, Illinois',24906,17);
INSERT INTO "django_geo_db_city" VALUES(20381,'Edgewood','Edgewood, Illinois',24907,17);
INSERT INTO "django_geo_db_city" VALUES(20382,'Flat Rock','Flat Rock, Illinois',24908,17);
INSERT INTO "django_geo_db_city" VALUES(20383,'Greenup','Greenup, Illinois',24909,17);
INSERT INTO "django_geo_db_city" VALUES(20384,'Herrick','Herrick, Illinois',24910,17);
INSERT INTO "django_geo_db_city" VALUES(20385,'Hidalgo','Hidalgo, Illinois',24911,17);
INSERT INTO "django_geo_db_city" VALUES(20386,'Hutsonville','Hutsonville, Illinois',24912,17);
INSERT INTO "django_geo_db_city" VALUES(20387,'Ingraham','Ingraham, Illinois',24913,17);
INSERT INTO "django_geo_db_city" VALUES(20388,'Janesville','Janesville, Illinois',24914,17);
INSERT INTO "django_geo_db_city" VALUES(20389,'Jewett','Jewett, Illinois',24915,17);
INSERT INTO "django_geo_db_city" VALUES(20390,'Lakewood','Lakewood, Illinois',24916,17);
INSERT INTO "django_geo_db_city" VALUES(20391,'Lawrenceville','Lawrenceville, Illinois',24917,17);
INSERT INTO "django_geo_db_city" VALUES(20392,'Lerna','Lerna, Illinois',24918,17);
INSERT INTO "django_geo_db_city" VALUES(20393,'Marshall','Marshall, Illinois',24919,17);
INSERT INTO "django_geo_db_city" VALUES(20394,'Martinsville','Martinsville, Illinois',24920,17);
INSERT INTO "django_geo_db_city" VALUES(20395,'Mason','Mason, Illinois',24921,17);
INSERT INTO "django_geo_db_city" VALUES(20396,'Mode','Mode, Illinois',24922,17);
INSERT INTO "django_geo_db_city" VALUES(20397,'Montrose','Montrose, Illinois',24923,17);
INSERT INTO "django_geo_db_city" VALUES(20398,'Mount Erie','Mount Erie, Illinois',24924,17);
INSERT INTO "django_geo_db_city" VALUES(20399,'Neoga','Neoga, Illinois',24925,17);
INSERT INTO "django_geo_db_city" VALUES(20400,'Newton','Newton, Illinois',24926,17);
INSERT INTO "django_geo_db_city" VALUES(20401,'Oblong','Oblong, Illinois',24927,17);
INSERT INTO "django_geo_db_city" VALUES(20402,'Olney','Olney, Illinois',24928,17);
INSERT INTO "django_geo_db_city" VALUES(20403,'Palestine','Palestine, Illinois',24929,17);
INSERT INTO "django_geo_db_city" VALUES(20404,'Parkersburg','Parkersburg, Illinois',24930,17);
INSERT INTO "django_geo_db_city" VALUES(20405,'Robinson','Robinson, Illinois',24931,17);
INSERT INTO "django_geo_db_city" VALUES(20406,'Saint Elmo','Saint Elmo, Illinois',24932,17);
INSERT INTO "django_geo_db_city" VALUES(20407,'Sainte Marie','Sainte Marie, Illinois',24933,17);
INSERT INTO "django_geo_db_city" VALUES(20408,'Saint Francisville','Saint Francisville, Illinois',24934,17);
INSERT INTO "django_geo_db_city" VALUES(20409,'Shumway','Shumway, Illinois',24935,17);
INSERT INTO "django_geo_db_city" VALUES(20410,'Sigel','Sigel, Illinois',24936,17);
INSERT INTO "django_geo_db_city" VALUES(20411,'Stewardson','Stewardson, Illinois',24937,17);
INSERT INTO "django_geo_db_city" VALUES(20412,'Stoy','Stoy, Illinois',24938,17);
INSERT INTO "django_geo_db_city" VALUES(20413,'Strasburg','Strasburg, Illinois',24939,17);
INSERT INTO "django_geo_db_city" VALUES(20414,'Sumner','Sumner, Illinois',24940,17);
INSERT INTO "django_geo_db_city" VALUES(20415,'Teutopolis','Teutopolis, Illinois',24941,17);
INSERT INTO "django_geo_db_city" VALUES(20416,'Toledo','Toledo, Illinois',24942,17);
INSERT INTO "django_geo_db_city" VALUES(20417,'Trilla','Trilla, Illinois',24943,17);
INSERT INTO "django_geo_db_city" VALUES(20418,'Vandalia','Vandalia, Illinois',24944,17);
INSERT INTO "django_geo_db_city" VALUES(20419,'Watson','Watson, Illinois',24945,17);
INSERT INTO "django_geo_db_city" VALUES(20420,'Westfield','Westfield, Illinois',24946,17);
INSERT INTO "django_geo_db_city" VALUES(20421,'West Liberty','West Liberty, Illinois',24947,17);
INSERT INTO "django_geo_db_city" VALUES(20422,'West Salem','West Salem, Illinois',24948,17);
INSERT INTO "django_geo_db_city" VALUES(20423,'West Union','West Union, Illinois',24949,17);
INSERT INTO "django_geo_db_city" VALUES(20424,'West York','West York, Illinois',24950,17);
INSERT INTO "django_geo_db_city" VALUES(20425,'Wheeler','Wheeler, Illinois',24951,17);
INSERT INTO "django_geo_db_city" VALUES(20426,'Willow Hill','Willow Hill, Illinois',24952,17);
INSERT INTO "django_geo_db_city" VALUES(20427,'Yale','Yale, Illinois',24953,17);
INSERT INTO "django_geo_db_city" VALUES(20428,'Argenta','Argenta, Illinois',24954,17);
INSERT INTO "django_geo_db_city" VALUES(20429,'Assumption','Assumption, Illinois',24955,17);
INSERT INTO "django_geo_db_city" VALUES(20430,'Atwater','Atwater, Illinois',24956,17);
INSERT INTO "django_geo_db_city" VALUES(20431,'Beason','Beason, Illinois',24957,17);
INSERT INTO "django_geo_db_city" VALUES(20432,'Blue Mound','Blue Mound, Illinois',24958,17);
INSERT INTO "django_geo_db_city" VALUES(20433,'Boody','Boody, Illinois',24959,17);
INSERT INTO "django_geo_db_city" VALUES(20434,'Buffalo','Buffalo, Illinois',24960,17);
INSERT INTO "django_geo_db_city" VALUES(20435,'Bulpitt','Bulpitt, Illinois',24961,17);
INSERT INTO "django_geo_db_city" VALUES(20436,'Chestnut','Chestnut, Illinois',24962,17);
INSERT INTO "django_geo_db_city" VALUES(20437,'Cornland','Cornland, Illinois',24963,17);
INSERT INTO "django_geo_db_city" VALUES(20438,'Dawson','Dawson, Illinois',24964,17);
INSERT INTO "django_geo_db_city" VALUES(20439,'Decatur','Decatur, Illinois',24965,17);
INSERT INTO "django_geo_db_city" VALUES(20440,'Divernon','Divernon, Illinois',24970,17);
INSERT INTO "django_geo_db_city" VALUES(20441,'Edinburg','Edinburg, Illinois',24971,17);
INSERT INTO "django_geo_db_city" VALUES(20442,'Elwin','Elwin, Illinois',24972,17);
INSERT INTO "django_geo_db_city" VALUES(20443,'Farmersville','Farmersville, Illinois',24973,17);
INSERT INTO "django_geo_db_city" VALUES(20444,'Findlay','Findlay, Illinois',24974,17);
INSERT INTO "django_geo_db_city" VALUES(20445,'Forsyth','Forsyth, Illinois',24975,17);
INSERT INTO "django_geo_db_city" VALUES(20446,'Glenarm','Glenarm, Illinois',24976,17);
INSERT INTO "django_geo_db_city" VALUES(20447,'Harristown','Harristown, Illinois',24977,17);
INSERT INTO "django_geo_db_city" VALUES(20448,'Harvel','Harvel, Illinois',24978,17);
INSERT INTO "django_geo_db_city" VALUES(20449,'Illiopolis','Illiopolis, Illinois',24979,17);
INSERT INTO "django_geo_db_city" VALUES(20450,'Kincaid','Kincaid, Illinois',24980,17);
INSERT INTO "django_geo_db_city" VALUES(20451,'Lake Fork','Lake Fork, Illinois',24981,17);
INSERT INTO "django_geo_db_city" VALUES(20452,'Latham','Latham, Illinois',24982,17);
INSERT INTO "django_geo_db_city" VALUES(20453,'Macon','Macon, Illinois',24983,17);
INSERT INTO "django_geo_db_city" VALUES(20454,'Mechanicsburg','Mechanicsburg, Illinois',24984,17);
INSERT INTO "django_geo_db_city" VALUES(20455,'Morrisonville','Morrisonville, Illinois',24985,17);
INSERT INTO "django_geo_db_city" VALUES(20456,'Mount Auburn','Mount Auburn, Illinois',24986,17);
INSERT INTO "django_geo_db_city" VALUES(20457,'Mount Pulaski','Mount Pulaski, Illinois',24987,17);
INSERT INTO "django_geo_db_city" VALUES(20458,'Mt Zion','Mt Zion, Illinois',24988,17);
INSERT INTO "django_geo_db_city" VALUES(20459,'Moweaqua','Moweaqua, Illinois',24989,17);
INSERT INTO "django_geo_db_city" VALUES(20460,'Niantic','Niantic, Illinois',24990,17);
INSERT INTO "django_geo_db_city" VALUES(20461,'Oakley','Oakley, Illinois',24991,17);
INSERT INTO "django_geo_db_city" VALUES(20462,'Oconee','Oconee, Illinois',24992,17);
INSERT INTO "django_geo_db_city" VALUES(20463,'Oreana','Oreana, Illinois',24993,17);
INSERT INTO "django_geo_db_city" VALUES(20464,'Owaneco','Owaneco, Illinois',24994,17);
INSERT INTO "django_geo_db_city" VALUES(20465,'Palmer','Palmer, Illinois',24995,17);
INSERT INTO "django_geo_db_city" VALUES(20466,'Pana','Pana, Illinois',24996,17);
INSERT INTO "django_geo_db_city" VALUES(20467,'Pawnee','Pawnee, Illinois',24997,17);
INSERT INTO "django_geo_db_city" VALUES(20468,'Raymond','Raymond, Illinois',24998,17);
INSERT INTO "django_geo_db_city" VALUES(20469,'Riverton','Riverton, Illinois',24999,17);
INSERT INTO "django_geo_db_city" VALUES(20470,'Rochester','Rochester, Illinois',25000,17);
INSERT INTO "django_geo_db_city" VALUES(20471,'Shelbyville','Shelbyville, Illinois',25001,17);
INSERT INTO "django_geo_db_city" VALUES(20472,'Stonington','Stonington, Illinois',25002,17);
INSERT INTO "django_geo_db_city" VALUES(20473,'Taylorville','Taylorville, Illinois',25003,17);
INSERT INTO "django_geo_db_city" VALUES(20474,'Tovey','Tovey, Illinois',25004,17);
INSERT INTO "django_geo_db_city" VALUES(20475,'Tower Hill','Tower Hill, Illinois',25005,17);
INSERT INTO "django_geo_db_city" VALUES(20476,'Waggoner','Waggoner, Illinois',25006,17);
INSERT INTO "django_geo_db_city" VALUES(20477,'Warrensburg','Warrensburg, Illinois',25007,17);
INSERT INTO "django_geo_db_city" VALUES(20478,'Alexander','Alexander, Illinois',25008,17);
INSERT INTO "django_geo_db_city" VALUES(20479,'Emden','Emden, Illinois',25009,17);
INSERT INTO "django_geo_db_city" VALUES(20480,'Alsey','Alsey, Illinois',25010,17);
INSERT INTO "django_geo_db_city" VALUES(20481,'Arenzville','Arenzville, Illinois',25011,17);
INSERT INTO "django_geo_db_city" VALUES(20482,'Ashland','Ashland, Illinois',25012,17);
INSERT INTO "django_geo_db_city" VALUES(20483,'Athens','Athens, Illinois',25013,17);
INSERT INTO "django_geo_db_city" VALUES(20484,'Auburn','Auburn, Illinois',25014,17);
INSERT INTO "django_geo_db_city" VALUES(20485,'Philadelphia','Philadelphia, Illinois',25015,17);
INSERT INTO "django_geo_db_city" VALUES(20486,'Bath','Bath, Illinois',25016,17);
INSERT INTO "django_geo_db_city" VALUES(20487,'Beardstown','Beardstown, Illinois',25017,17);
INSERT INTO "django_geo_db_city" VALUES(20488,'Bluffs','Bluffs, Illinois',25018,17);
INSERT INTO "django_geo_db_city" VALUES(20489,'Bluff Springs','Bluff Springs, Illinois',25019,17);
INSERT INTO "django_geo_db_city" VALUES(20490,'Oakford','Oakford, Illinois',25020,17);
INSERT INTO "django_geo_db_city" VALUES(20491,'Browning','Browning, Illinois',25021,17);
INSERT INTO "django_geo_db_city" VALUES(20492,'Cantrall','Cantrall, Illinois',25022,17);
INSERT INTO "django_geo_db_city" VALUES(20493,'Carlinville','Carlinville, Illinois',25023,17);
INSERT INTO "django_geo_db_city" VALUES(20494,'Chandlerville','Chandlerville, Illinois',25024,17);
INSERT INTO "django_geo_db_city" VALUES(20495,'Chapin','Chapin, Illinois',25025,17);
INSERT INTO "django_geo_db_city" VALUES(20496,'Chatham','Chatham, Illinois',25026,17);
INSERT INTO "django_geo_db_city" VALUES(20497,'Chesterfield','Chesterfield, Illinois',25027,17);
INSERT INTO "django_geo_db_city" VALUES(20498,'Concord','Concord, Illinois',25028,17);
INSERT INTO "django_geo_db_city" VALUES(20499,'Easton','Easton, Illinois',25029,17);
INSERT INTO "django_geo_db_city" VALUES(20500,'Elkhart','Elkhart, Illinois',25030,17);
INSERT INTO "django_geo_db_city" VALUES(20501,'Franklin','Franklin, Illinois',25032,17);
INSERT INTO "django_geo_db_city" VALUES(20502,'Frederick','Frederick, Illinois',25033,17);
INSERT INTO "django_geo_db_city" VALUES(20503,'Girard','Girard, Illinois',25034,17);
INSERT INTO "django_geo_db_city" VALUES(20504,'Greenview','Greenview, Illinois',25035,17);
INSERT INTO "django_geo_db_city" VALUES(20505,'Hartsburg','Hartsburg, Illinois',25036,17);
INSERT INTO "django_geo_db_city" VALUES(20506,'Havana','Havana, Illinois',25037,17);
INSERT INTO "django_geo_db_city" VALUES(20507,'Herrin','Herrin, Illinois',25038,17);
INSERT INTO "django_geo_db_city" VALUES(20508,'Hettick','Hettick, Illinois',25039,17);
INSERT INTO "django_geo_db_city" VALUES(20509,'Jacksonville','Jacksonville, Illinois',25040,17);
INSERT INTO "django_geo_db_city" VALUES(20510,'Kilbourne','Kilbourne, Illinois',25043,17);
INSERT INTO "django_geo_db_city" VALUES(20511,'Lincoln','Lincoln, Illinois',25044,17);
INSERT INTO "django_geo_db_city" VALUES(20512,'Lincoln''S New Salem','Lincoln''S New Salem, Illinois',25045,17);
INSERT INTO "django_geo_db_city" VALUES(20513,'Literberry','Literberry, Illinois',25046,17);
INSERT INTO "django_geo_db_city" VALUES(20514,'Loami','Loami, Illinois',25047,17);
INSERT INTO "django_geo_db_city" VALUES(20515,'Lowder','Lowder, Illinois',25048,17);
INSERT INTO "django_geo_db_city" VALUES(20516,'Manchester','Manchester, Illinois',25049,17);
INSERT INTO "django_geo_db_city" VALUES(20517,'Mason City','Mason City, Illinois',25050,17);
INSERT INTO "django_geo_db_city" VALUES(20518,'Meredosia','Meredosia, Illinois',25051,17);
INSERT INTO "django_geo_db_city" VALUES(20519,'Middletown','Middletown, Illinois',25052,17);
INSERT INTO "django_geo_db_city" VALUES(20520,'Modesto','Modesto, Illinois',25053,17);
INSERT INTO "django_geo_db_city" VALUES(20521,'Murrayville','Murrayville, Illinois',25054,17);
INSERT INTO "django_geo_db_city" VALUES(20522,'New Berlin','New Berlin, Illinois',25055,17);
INSERT INTO "django_geo_db_city" VALUES(20523,'New Holland','New Holland, Illinois',25056,17);
INSERT INTO "django_geo_db_city" VALUES(20524,'Nilwood','Nilwood, Illinois',25057,17);
INSERT INTO "django_geo_db_city" VALUES(20525,'Palmyra','Palmyra, Illinois',25059,17);
INSERT INTO "django_geo_db_city" VALUES(20526,'Petersburg','Petersburg, Illinois',25060,17);
INSERT INTO "django_geo_db_city" VALUES(20527,'Hillyard','Hillyard, Illinois',25061,17);
INSERT INTO "django_geo_db_city" VALUES(20528,'Pleasant Plains','Pleasant Plains, Illinois',25062,17);
INSERT INTO "django_geo_db_city" VALUES(20529,'Rushville','Rushville, Illinois',25063,17);
INSERT INTO "django_geo_db_city" VALUES(20530,'San Jose','San Jose, Illinois',25064,17);
INSERT INTO "django_geo_db_city" VALUES(20531,'Scottville','Scottville, Illinois',25065,17);
INSERT INTO "django_geo_db_city" VALUES(20532,'Sherman','Sherman, Illinois',25066,17);
INSERT INTO "django_geo_db_city" VALUES(20533,'Shipman','Shipman, Illinois',25067,17);
INSERT INTO "django_geo_db_city" VALUES(20534,'Standard City','Standard City, Illinois',25068,17);
INSERT INTO "django_geo_db_city" VALUES(20535,'Tallula','Tallula, Illinois',25069,17);
INSERT INTO "django_geo_db_city" VALUES(20536,'Thayer','Thayer, Illinois',25070,17);
INSERT INTO "django_geo_db_city" VALUES(20537,'Virden','Virden, Illinois',25071,17);
INSERT INTO "django_geo_db_city" VALUES(20538,'Virginia','Virginia, Illinois',25072,17);
INSERT INTO "django_geo_db_city" VALUES(20539,'Waverly','Waverly, Illinois',25073,17);
INSERT INTO "django_geo_db_city" VALUES(20540,'Williamsville','Williamsville, Illinois',25074,17);
INSERT INTO "django_geo_db_city" VALUES(20541,'Winchester','Winchester, Illinois',25075,17);
INSERT INTO "django_geo_db_city" VALUES(20542,'Woodson','Woodson, Illinois',25076,17);
INSERT INTO "django_geo_db_city" VALUES(20543,'Springfield','Springfield, Illinois',25077,17);
INSERT INTO "django_geo_db_city" VALUES(20544,'Ullin','Ullin, Illinois',25087,17);
INSERT INTO "django_geo_db_city" VALUES(20545,'Centralia','Centralia, Illinois',25088,17);
INSERT INTO "django_geo_db_city" VALUES(20546,'Hoyleton','Hoyleton, Illinois',25089,17);
INSERT INTO "django_geo_db_city" VALUES(20547,'Akin','Akin, Illinois',25090,17);
INSERT INTO "django_geo_db_city" VALUES(20548,'Albion','Albion, Illinois',25091,17);
INSERT INTO "django_geo_db_city" VALUES(20549,'Alma','Alma, Illinois',25092,17);
INSERT INTO "django_geo_db_city" VALUES(20550,'Ashley','Ashley, Illinois',25093,17);
INSERT INTO "django_geo_db_city" VALUES(20551,'Barnhill','Barnhill, Illinois',25094,17);
INSERT INTO "django_geo_db_city" VALUES(20552,'Belle Rive','Belle Rive, Illinois',25095,17);
INSERT INTO "django_geo_db_city" VALUES(20553,'Bellmont','Bellmont, Illinois',25096,17);
INSERT INTO "django_geo_db_city" VALUES(20554,'Benton','Benton, Illinois',25097,17);
INSERT INTO "django_geo_db_city" VALUES(20555,'Bluford','Bluford, Illinois',25098,17);
INSERT INTO "django_geo_db_city" VALUES(20556,'Bone Gap','Bone Gap, Illinois',25099,17);
INSERT INTO "django_geo_db_city" VALUES(20557,'Bonnie','Bonnie, Illinois',25100,17);
INSERT INTO "django_geo_db_city" VALUES(20558,'Broughton','Broughton, Illinois',25101,17);
INSERT INTO "django_geo_db_city" VALUES(20559,'Browns','Browns, Illinois',25102,17);
INSERT INTO "django_geo_db_city" VALUES(20560,'Buckner','Buckner, Illinois',25103,17);
INSERT INTO "django_geo_db_city" VALUES(20561,'Burnt Prairie','Burnt Prairie, Illinois',25104,17);
INSERT INTO "django_geo_db_city" VALUES(20562,'Carmi','Carmi, Illinois',25105,17);
INSERT INTO "django_geo_db_city" VALUES(20563,'Christopher','Christopher, Illinois',25106,17);
INSERT INTO "django_geo_db_city" VALUES(20564,'Cisne','Cisne, Illinois',25107,17);
INSERT INTO "django_geo_db_city" VALUES(20565,'Clay City','Clay City, Illinois',25108,17);
INSERT INTO "django_geo_db_city" VALUES(20566,'Coello','Coello, Illinois',25109,17);
INSERT INTO "django_geo_db_city" VALUES(20567,'Crossville','Crossville, Illinois',25110,17);
INSERT INTO "django_geo_db_city" VALUES(20568,'Dahlgren','Dahlgren, Illinois',25111,17);
INSERT INTO "django_geo_db_city" VALUES(20569,'Dale','Dale, Illinois',25112,17);
INSERT INTO "django_geo_db_city" VALUES(20570,'Dix','Dix, Illinois',25113,17);
INSERT INTO "django_geo_db_city" VALUES(20571,'Du Bois','Du Bois, Illinois',25114,17);
INSERT INTO "django_geo_db_city" VALUES(20572,'Du Quoin','Du Quoin, Illinois',25115,17);
INSERT INTO "django_geo_db_city" VALUES(20573,'Ellery','Ellery, Illinois',25116,17);
INSERT INTO "django_geo_db_city" VALUES(20574,'Emma','Emma, Illinois',25117,17);
INSERT INTO "django_geo_db_city" VALUES(20575,'Enfield','Enfield, Illinois',25118,17);
INSERT INTO "django_geo_db_city" VALUES(20576,'Ewing','Ewing, Illinois',25119,17);
INSERT INTO "django_geo_db_city" VALUES(20577,'Fairfield','Fairfield, Illinois',25120,17);
INSERT INTO "django_geo_db_city" VALUES(20578,'Farina','Farina, Illinois',25121,17);
INSERT INTO "django_geo_db_city" VALUES(20579,'Flora','Flora, Illinois',25122,17);
INSERT INTO "django_geo_db_city" VALUES(20580,'Frankfort Heights','Frankfort Heights, Illinois',25090,17);
INSERT INTO "django_geo_db_city" VALUES(20581,'Freeman Spur','Freeman Spur, Illinois',25123,17);
INSERT INTO "django_geo_db_city" VALUES(20582,'Geff','Geff, Illinois',25124,17);
INSERT INTO "django_geo_db_city" VALUES(20583,'Golden Gate','Golden Gate, Illinois',25125,17);
INSERT INTO "django_geo_db_city" VALUES(20584,'Grayville','Grayville, Illinois',25126,17);
INSERT INTO "django_geo_db_city" VALUES(20585,'Herald','Herald, Illinois',25127,17);
INSERT INTO "django_geo_db_city" VALUES(20586,'Ina','Ina, Illinois',25128,17);
INSERT INTO "django_geo_db_city" VALUES(20587,'Iola','Iola, Illinois',25129,17);
INSERT INTO "django_geo_db_city" VALUES(20588,'Irvington','Irvington, Illinois',25130,17);
INSERT INTO "django_geo_db_city" VALUES(20589,'Iuka','Iuka, Illinois',25131,17);
INSERT INTO "django_geo_db_city" VALUES(20590,'Johnsonville','Johnsonville, Illinois',25132,17);
INSERT INTO "django_geo_db_city" VALUES(20591,'Keenes','Keenes, Illinois',25133,17);
INSERT INTO "django_geo_db_city" VALUES(20592,'Keensburg','Keensburg, Illinois',25134,17);
INSERT INTO "django_geo_db_city" VALUES(20593,'Kell','Kell, Illinois',25135,17);
INSERT INTO "django_geo_db_city" VALUES(20594,'Kinmundy','Kinmundy, Illinois',25136,17);
INSERT INTO "django_geo_db_city" VALUES(20595,'Lancaster','Lancaster, Illinois',25137,17);
INSERT INTO "django_geo_db_city" VALUES(20596,'Logan','Logan, Illinois',25090,17);
INSERT INTO "django_geo_db_city" VALUES(20597,'Loogootee','Loogootee, Illinois',25138,17);
INSERT INTO "django_geo_db_city" VALUES(20598,'Louisville','Louisville, Illinois',25139,17);
INSERT INTO "django_geo_db_city" VALUES(20599,'McLeansboro','McLeansboro, Illinois',25140,17);
INSERT INTO "django_geo_db_city" VALUES(20600,'Macedonia','Macedonia, Illinois',25141,17);
INSERT INTO "django_geo_db_city" VALUES(20601,'Maunie','Maunie, Illinois',25142,17);
INSERT INTO "django_geo_db_city" VALUES(20602,'Mill Shoals','Mill Shoals, Illinois',25143,17);
INSERT INTO "django_geo_db_city" VALUES(20603,'Mount Carmel','Mount Carmel, Illinois',25144,17);
INSERT INTO "django_geo_db_city" VALUES(20604,'Mount Vernon','Mount Vernon, Illinois',25145,17);
INSERT INTO "django_geo_db_city" VALUES(20605,'Mulkeytown','Mulkeytown, Illinois',25146,17);
INSERT INTO "django_geo_db_city" VALUES(20606,'Nason','Nason, Illinois',25147,17);
INSERT INTO "django_geo_db_city" VALUES(20607,'New Haven','New Haven, Illinois',25148,17);
INSERT INTO "django_geo_db_city" VALUES(20608,'Noble','Noble, Illinois',25149,17);
INSERT INTO "django_geo_db_city" VALUES(20609,'Norris City','Norris City, Illinois',25150,17);
INSERT INTO "django_geo_db_city" VALUES(20610,'Odin','Odin, Illinois',25151,17);
INSERT INTO "django_geo_db_city" VALUES(20611,'Omaha','Omaha, Illinois',25152,17);
INSERT INTO "django_geo_db_city" VALUES(20612,'Opdyke','Opdyke, Illinois',25153,17);
INSERT INTO "django_geo_db_city" VALUES(20613,'Orient','Orient, Illinois',25154,17);
INSERT INTO "django_geo_db_city" VALUES(20614,'Patoka','Patoka, Illinois',25155,17);
INSERT INTO "django_geo_db_city" VALUES(20615,'Radom','Radom, Illinois',25156,17);
INSERT INTO "django_geo_db_city" VALUES(20616,'Richview','Richview, Illinois',25157,17);
INSERT INTO "django_geo_db_city" VALUES(20617,'Rinard','Rinard, Illinois',25158,17);
INSERT INTO "django_geo_db_city" VALUES(20618,'Sailor Springs','Sailor Springs, Illinois',25159,17);
INSERT INTO "django_geo_db_city" VALUES(20619,'Saint Peter','Saint Peter, Illinois',25160,17);
INSERT INTO "django_geo_db_city" VALUES(20620,'Salem','Salem, Illinois',25161,17);
INSERT INTO "django_geo_db_city" VALUES(20621,'Sandoval','Sandoval, Illinois',25162,17);
INSERT INTO "django_geo_db_city" VALUES(20622,'Scheller','Scheller, Illinois',25163,17);
INSERT INTO "django_geo_db_city" VALUES(20623,'Sesser','Sesser, Illinois',25164,17);
INSERT INTO "django_geo_db_city" VALUES(20624,'Shobonier','Shobonier, Illinois',25165,17);
INSERT INTO "django_geo_db_city" VALUES(20625,'Sims','Sims, Illinois',25166,17);
INSERT INTO "django_geo_db_city" VALUES(20626,'Springerton','Springerton, Illinois',25167,17);
INSERT INTO "django_geo_db_city" VALUES(20627,'Tamaroa','Tamaroa, Illinois',25168,17);
INSERT INTO "django_geo_db_city" VALUES(20628,'Texico','Texico, Illinois',25169,17);
INSERT INTO "django_geo_db_city" VALUES(20629,'Thompsonville','Thompsonville, Illinois',25170,17);
INSERT INTO "django_geo_db_city" VALUES(20630,'Valier','Valier, Illinois',25171,17);
INSERT INTO "django_geo_db_city" VALUES(20631,'Vernon','Vernon, Illinois',25172,17);
INSERT INTO "django_geo_db_city" VALUES(20632,'Walnut Hill','Walnut Hill, Illinois',25173,17);
INSERT INTO "django_geo_db_city" VALUES(20633,'Waltonville','Waltonville, Illinois',25174,17);
INSERT INTO "django_geo_db_city" VALUES(20634,'Wayne City','Wayne City, Illinois',25175,17);
INSERT INTO "django_geo_db_city" VALUES(20635,'West Frankfort','West Frankfort, Illinois',25176,17);
INSERT INTO "django_geo_db_city" VALUES(20636,'Whittington','Whittington, Illinois',25177,17);
INSERT INTO "django_geo_db_city" VALUES(20637,'Woodlawn','Woodlawn, Illinois',25178,17);
INSERT INTO "django_geo_db_city" VALUES(20638,'Xenia','Xenia, Illinois',25179,17);
INSERT INTO "django_geo_db_city" VALUES(20639,'Carbondale','Carbondale, Illinois',25180,17);
INSERT INTO "django_geo_db_city" VALUES(20640,'Alto Pass','Alto Pass, Illinois',25182,17);
INSERT INTO "django_geo_db_city" VALUES(20641,'Anna','Anna, Illinois',25183,17);
INSERT INTO "django_geo_db_city" VALUES(20642,'Ava','Ava, Illinois',25184,17);
INSERT INTO "django_geo_db_city" VALUES(20643,'Belknap','Belknap, Illinois',25185,17);
INSERT INTO "django_geo_db_city" VALUES(20644,'Boles','Boles, Illinois',25186,17);
INSERT INTO "django_geo_db_city" VALUES(20645,'Brookport','Brookport, Illinois',25187,17);
INSERT INTO "django_geo_db_city" VALUES(20646,'Buncombe','Buncombe, Illinois',25188,17);
INSERT INTO "django_geo_db_city" VALUES(20647,'Cache','Cache, Illinois',25189,17);
INSERT INTO "django_geo_db_city" VALUES(20648,'Cairo','Cairo, Illinois',25190,17);
INSERT INTO "django_geo_db_city" VALUES(20649,'Cambria','Cambria, Illinois',25191,17);
INSERT INTO "django_geo_db_city" VALUES(20650,'Campbell Hill','Campbell Hill, Illinois',25192,17);
INSERT INTO "django_geo_db_city" VALUES(20651,'Carrier Mills','Carrier Mills, Illinois',25193,17);
INSERT INTO "django_geo_db_city" VALUES(20652,'Carterville','Carterville, Illinois',25194,17);
INSERT INTO "django_geo_db_city" VALUES(20653,'Cave In Rock','Cave In Rock, Illinois',25195,17);
INSERT INTO "django_geo_db_city" VALUES(20654,'Cobden','Cobden, Illinois',25196,17);
INSERT INTO "django_geo_db_city" VALUES(20655,'Colp','Colp, Illinois',25197,17);
INSERT INTO "django_geo_db_city" VALUES(20656,'Creal Springs','Creal Springs, Illinois',25198,17);
INSERT INTO "django_geo_db_city" VALUES(20657,'Cypress','Cypress, Illinois',25199,17);
INSERT INTO "django_geo_db_city" VALUES(20658,'De Soto','De Soto, Illinois',25200,17);
INSERT INTO "django_geo_db_city" VALUES(20659,'Dongola','Dongola, Illinois',25201,17);
INSERT INTO "django_geo_db_city" VALUES(20660,'Dowell','Dowell, Illinois',25202,17);
INSERT INTO "django_geo_db_city" VALUES(20661,'Eddyville','Eddyville, Illinois',25203,17);
INSERT INTO "django_geo_db_city" VALUES(20662,'Eldorado','Eldorado, Illinois',25204,17);
INSERT INTO "django_geo_db_city" VALUES(20663,'Elizabethtown','Elizabethtown, Illinois',25205,17);
INSERT INTO "django_geo_db_city" VALUES(20664,'Elkville','Elkville, Illinois',25206,17);
INSERT INTO "django_geo_db_city" VALUES(20665,'Energy','Energy, Illinois',25207,17);
INSERT INTO "django_geo_db_city" VALUES(20666,'Galatia','Galatia, Illinois',25209,17);
INSERT INTO "django_geo_db_city" VALUES(20667,'Golconda','Golconda, Illinois',25210,17);
INSERT INTO "django_geo_db_city" VALUES(20668,'Goreville','Goreville, Illinois',25211,17);
INSERT INTO "django_geo_db_city" VALUES(20669,'Gorham','Gorham, Illinois',25212,17);
INSERT INTO "django_geo_db_city" VALUES(20670,'Grand Chain','Grand Chain, Illinois',25213,17);
INSERT INTO "django_geo_db_city" VALUES(20671,'Grand Tower','Grand Tower, Illinois',25214,17);
INSERT INTO "django_geo_db_city" VALUES(20672,'Grantsburg','Grantsburg, Illinois',25215,17);
INSERT INTO "django_geo_db_city" VALUES(20673,'Hamletsburg','Hamletsburg, Illinois',25216,17);
INSERT INTO "django_geo_db_city" VALUES(20674,'Harrisburg','Harrisburg, Illinois',25217,17);
INSERT INTO "django_geo_db_city" VALUES(20675,'Herod','Herod, Illinois',25218,17);
INSERT INTO "django_geo_db_city" VALUES(20676,'Hurst','Hurst, Illinois',25220,17);
INSERT INTO "django_geo_db_city" VALUES(20677,'Jacob','Jacob, Illinois',25221,17);
INSERT INTO "django_geo_db_city" VALUES(20678,'Johnston City','Johnston City, Illinois',25222,17);
INSERT INTO "django_geo_db_city" VALUES(20679,'Jonesboro','Jonesboro, Illinois',25223,17);
INSERT INTO "django_geo_db_city" VALUES(20680,'Joppa','Joppa, Illinois',25224,17);
INSERT INTO "django_geo_db_city" VALUES(20681,'Junction','Junction, Illinois',25225,17);
INSERT INTO "django_geo_db_city" VALUES(20682,'Karbers Ridge','Karbers Ridge, Illinois',25226,17);
INSERT INTO "django_geo_db_city" VALUES(20683,'Karnak','Karnak, Illinois',25227,17);
INSERT INTO "django_geo_db_city" VALUES(20684,'McClure','McClure, Illinois',25228,17);
INSERT INTO "django_geo_db_city" VALUES(20685,'Makanda','Makanda, Illinois',25229,17);
INSERT INTO "django_geo_db_city" VALUES(20686,'Marion','Marion, Illinois',25230,17);
INSERT INTO "django_geo_db_city" VALUES(20687,'Metropolis','Metropolis, Illinois',25231,17);
INSERT INTO "django_geo_db_city" VALUES(20688,'Millcreek','Millcreek, Illinois',25232,17);
INSERT INTO "django_geo_db_city" VALUES(20689,'Miller City','Miller City, Illinois',25233,17);
INSERT INTO "django_geo_db_city" VALUES(20690,'Mound City','Mound City, Illinois',25234,17);
INSERT INTO "django_geo_db_city" VALUES(20691,'Mounds','Mounds, Illinois',25235,17);
INSERT INTO "django_geo_db_city" VALUES(20692,'Muddy','Muddy, Illinois',25236,17);
INSERT INTO "django_geo_db_city" VALUES(20693,'Murphysboro','Murphysboro, Illinois',25237,17);
INSERT INTO "django_geo_db_city" VALUES(20694,'New Burnside','New Burnside, Illinois',25238,17);
INSERT INTO "django_geo_db_city" VALUES(20695,'Olive Branch','Olive Branch, Illinois',25239,17);
INSERT INTO "django_geo_db_city" VALUES(20696,'Olmsted','Olmsted, Illinois',25240,17);
INSERT INTO "django_geo_db_city" VALUES(20697,'Oraville','Oraville, Illinois',25181,17);
INSERT INTO "django_geo_db_city" VALUES(20698,'Ozark','Ozark, Illinois',25241,17);
INSERT INTO "django_geo_db_city" VALUES(20699,'Perks','Perks, Illinois',25242,17);
INSERT INTO "django_geo_db_city" VALUES(20700,'Pittsburg','Pittsburg, Illinois',25243,17);
INSERT INTO "django_geo_db_city" VALUES(20701,'Pomona','Pomona, Illinois',25244,17);
INSERT INTO "django_geo_db_city" VALUES(20702,'Pulaski','Pulaski, Illinois',25245,17);
INSERT INTO "django_geo_db_city" VALUES(20703,'Raleigh','Raleigh, Illinois',25246,17);
INSERT INTO "django_geo_db_city" VALUES(20704,'Ridgway','Ridgway, Illinois',25247,17);
INSERT INTO "django_geo_db_city" VALUES(20705,'Rosiclare','Rosiclare, Illinois',25248,17);
INSERT INTO "django_geo_db_city" VALUES(20706,'Royalton','Royalton, Illinois',25249,17);
INSERT INTO "django_geo_db_city" VALUES(20707,'Shawneetown','Shawneetown, Illinois',25250,17);
INSERT INTO "django_geo_db_city" VALUES(20708,'Simpson','Simpson, Illinois',25251,17);
INSERT INTO "django_geo_db_city" VALUES(20709,'Stonefort','Stonefort, Illinois',25252,17);
INSERT INTO "django_geo_db_city" VALUES(20710,'Tamms','Tamms, Illinois',25253,17);
INSERT INTO "django_geo_db_city" VALUES(20711,'Thebes','Thebes, Illinois',25254,17);
INSERT INTO "django_geo_db_city" VALUES(20712,'Tunnel Hill','Tunnel Hill, Illinois',25255,17);
INSERT INTO "django_geo_db_city" VALUES(20713,'Unity','Unity, Illinois',25257,17);
INSERT INTO "django_geo_db_city" VALUES(20714,'Vergennes','Vergennes, Illinois',25258,17);
INSERT INTO "django_geo_db_city" VALUES(20715,'Vienna','Vienna, Illinois',25259,17);
INSERT INTO "django_geo_db_city" VALUES(20716,'Villa Ridge','Villa Ridge, Illinois',25260,17);
INSERT INTO "django_geo_db_city" VALUES(20717,'Willisville','Willisville, Illinois',25261,17);
INSERT INTO "django_geo_db_city" VALUES(20718,'Wolf Lake','Wolf Lake, Illinois',25262,17);
INSERT INTO "django_geo_db_city" VALUES(20719,'Zeigler','Zeigler, Illinois',25263,17);
INSERT INTO "django_geo_db_city" VALUES(20720,'Allenton','Allenton, Missouri',25264,43);
INSERT INTO "django_geo_db_city" VALUES(20721,'Chesterfield','Chesterfield, Missouri',25265,43);
INSERT INTO "django_geo_db_city" VALUES(20722,'Arnold','Arnold, Missouri',25266,43);
INSERT INTO "django_geo_db_city" VALUES(20723,'Ballwin','Ballwin, Missouri',25267,43);
INSERT INTO "django_geo_db_city" VALUES(20724,'Barnhart','Barnhart, Missouri',25268,43);
INSERT INTO "django_geo_db_city" VALUES(20725,'Beaufort','Beaufort, Missouri',25269,43);
INSERT INTO "django_geo_db_city" VALUES(20726,'Berger','Berger, Missouri',25270,43);
INSERT INTO "django_geo_db_city" VALUES(20727,'Catawissa','Catawissa, Missouri',25271,43);
INSERT INTO "django_geo_db_city" VALUES(20728,'Cedar Hill','Cedar Hill, Missouri',25272,43);
INSERT INTO "django_geo_db_city" VALUES(20729,'Crystal City','Crystal City, Missouri',25274,43);
INSERT INTO "django_geo_db_city" VALUES(20730,'De Soto','De Soto, Missouri',25275,43);
INSERT INTO "django_geo_db_city" VALUES(20731,'Dittmer','Dittmer, Missouri',25277,43);
INSERT INTO "django_geo_db_city" VALUES(20732,'Eureka','Eureka, Missouri',25278,43);
INSERT INTO "django_geo_db_city" VALUES(20733,'Fenton','Fenton, Missouri',25279,43);
INSERT INTO "django_geo_db_city" VALUES(20734,'Festus','Festus, Missouri',25280,43);
INSERT INTO "django_geo_db_city" VALUES(20735,'Fletcher','Fletcher, Missouri',25281,43);
INSERT INTO "django_geo_db_city" VALUES(20736,'Florissant','Florissant, Missouri',25282,43);
INSERT INTO "django_geo_db_city" VALUES(20737,'French Village','French Village, Missouri',25285,43);
INSERT INTO "django_geo_db_city" VALUES(20738,'Gerald','Gerald, Missouri',25286,43);
INSERT INTO "django_geo_db_city" VALUES(20739,'Glencoe','Glencoe, Missouri',25287,43);
INSERT INTO "django_geo_db_city" VALUES(20740,'Gray Summit','Gray Summit, Missouri',25288,43);
INSERT INTO "django_geo_db_city" VALUES(20741,'Grover','Grover, Missouri',25289,43);
INSERT INTO "django_geo_db_city" VALUES(20742,'Grubville','Grubville, Missouri',25290,43);
INSERT INTO "django_geo_db_city" VALUES(20743,'Hazelwood','Hazelwood, Missouri',25291,43);
INSERT INTO "django_geo_db_city" VALUES(20744,'Maryland Heights','Maryland Heights, Missouri',25292,43);
INSERT INTO "django_geo_db_city" VALUES(20745,'Bridgeton','Bridgeton, Missouri',25293,43);
INSERT INTO "django_geo_db_city" VALUES(20746,'Earth City','Earth City, Missouri',25264,43);
INSERT INTO "django_geo_db_city" VALUES(20747,'Hematite','Hematite, Missouri',25294,43);
INSERT INTO "django_geo_db_city" VALUES(20748,'Herculaneum','Herculaneum, Missouri',25295,43);
INSERT INTO "django_geo_db_city" VALUES(20749,'High Ridge','High Ridge, Missouri',25296,43);
INSERT INTO "django_geo_db_city" VALUES(20750,'Hillsboro','Hillsboro, Missouri',25297,43);
INSERT INTO "django_geo_db_city" VALUES(20751,'House Springs','House Springs, Missouri',25298,43);
INSERT INTO "django_geo_db_city" VALUES(20752,'Imperial','Imperial, Missouri',25299,43);
INSERT INTO "django_geo_db_city" VALUES(20753,'Kimmswick','Kimmswick, Missouri',25300,43);
INSERT INTO "django_geo_db_city" VALUES(20754,'Labadie','Labadie, Missouri',25301,43);
INSERT INTO "django_geo_db_city" VALUES(20755,'Leslie','Leslie, Missouri',25302,43);
INSERT INTO "django_geo_db_city" VALUES(20756,'Liguori','Liguori, Missouri',25303,43);
INSERT INTO "django_geo_db_city" VALUES(20757,'Lonedell','Lonedell, Missouri',25304,43);
INSERT INTO "django_geo_db_city" VALUES(20758,'Luebbering','Luebbering, Missouri',25305,43);
INSERT INTO "django_geo_db_city" VALUES(20759,'Mapaville','Mapaville, Missouri',25300,43);
INSERT INTO "django_geo_db_city" VALUES(20760,'Morse Mill','Morse Mill, Missouri',25306,43);
INSERT INTO "django_geo_db_city" VALUES(20761,'New Haven','New Haven, Missouri',25307,43);
INSERT INTO "django_geo_db_city" VALUES(20762,'Pacific','Pacific, Missouri',25308,43);
INSERT INTO "django_geo_db_city" VALUES(20763,'Pevely','Pevely, Missouri',25309,43);
INSERT INTO "django_geo_db_city" VALUES(20764,'Richwoods','Richwoods, Missouri',25310,43);
INSERT INTO "django_geo_db_city" VALUES(20765,'Robertsville','Robertsville, Missouri',25311,43);
INSERT INTO "django_geo_db_city" VALUES(20766,'Saint Albans','Saint Albans, Missouri',25312,43);
INSERT INTO "django_geo_db_city" VALUES(20767,'Saint Ann','Saint Ann, Missouri',25313,43);
INSERT INTO "django_geo_db_city" VALUES(20768,'Saint Clair','Saint Clair, Missouri',25314,43);
INSERT INTO "django_geo_db_city" VALUES(20769,'Stanton','Stanton, Missouri',25315,43);
INSERT INTO "django_geo_db_city" VALUES(20770,'Sullivan','Sullivan, Missouri',25316,43);
INSERT INTO "django_geo_db_city" VALUES(20771,'Union','Union, Missouri',25317,43);
INSERT INTO "django_geo_db_city" VALUES(20772,'Valles Mines','Valles Mines, Missouri',25318,43);
INSERT INTO "django_geo_db_city" VALUES(20773,'Valley Park','Valley Park, Missouri',25319,43);
INSERT INTO "django_geo_db_city" VALUES(20774,'Villa Ridge','Villa Ridge, Missouri',25320,43);
INSERT INTO "django_geo_db_city" VALUES(20775,'Washington','Washington, Missouri',25321,43);
INSERT INTO "django_geo_db_city" VALUES(20776,'Rosebud','Rosebud, Missouri',25322,43);
INSERT INTO "django_geo_db_city" VALUES(20777,'Saint Louis','Saint Louis, Missouri',25323,43);
INSERT INTO "django_geo_db_city" VALUES(20778,'Saint Charles','Saint Charles, Missouri',25369,43);
INSERT INTO "django_geo_db_city" VALUES(20779,'Annada','Annada, Missouri',25373,43);
INSERT INTO "django_geo_db_city" VALUES(20780,'Augusta','Augusta, Missouri',25374,43);
INSERT INTO "django_geo_db_city" VALUES(20781,'Bellflower','Bellflower, Missouri',25375,43);
INSERT INTO "django_geo_db_city" VALUES(20782,'Bowling Green','Bowling Green, Missouri',25376,43);
INSERT INTO "django_geo_db_city" VALUES(20783,'Clarksville','Clarksville, Missouri',25377,43);
INSERT INTO "django_geo_db_city" VALUES(20784,'Cottleville','Cottleville, Missouri',25378,43);
INSERT INTO "django_geo_db_city" VALUES(20785,'Curryville','Curryville, Missouri',25379,43);
INSERT INTO "django_geo_db_city" VALUES(20786,'Defiance','Defiance, Missouri',25380,43);
INSERT INTO "django_geo_db_city" VALUES(20787,'Dutzow','Dutzow, Missouri',25381,43);
INSERT INTO "django_geo_db_city" VALUES(20788,'Elsberry','Elsberry, Missouri',25382,43);
INSERT INTO "django_geo_db_city" VALUES(20789,'Eolia','Eolia, Missouri',25383,43);
INSERT INTO "django_geo_db_city" VALUES(20790,'Farber','Farber, Missouri',25384,43);
INSERT INTO "django_geo_db_city" VALUES(20791,'Flinthill','Flinthill, Missouri',25378,43);
INSERT INTO "django_geo_db_city" VALUES(20792,'Foley','Foley, Missouri',25385,43);
INSERT INTO "django_geo_db_city" VALUES(20793,'Foristell','Foristell, Missouri',25386,43);
INSERT INTO "django_geo_db_city" VALUES(20794,'Hawk Point','Hawk Point, Missouri',25387,43);
INSERT INTO "django_geo_db_city" VALUES(20795,'High Hill','High Hill, Missouri',25388,43);
INSERT INTO "django_geo_db_city" VALUES(20796,'Jonesburg','Jonesburg, Missouri',25389,43);
INSERT INTO "django_geo_db_city" VALUES(20797,'Laddonia','Laddonia, Missouri',25390,43);
INSERT INTO "django_geo_db_city" VALUES(20798,'Louisiana','Louisiana, Missouri',25391,43);
INSERT INTO "django_geo_db_city" VALUES(20799,'Marthasville','Marthasville, Missouri',25392,43);
INSERT INTO "django_geo_db_city" VALUES(20800,'Middletown','Middletown, Missouri',25393,43);
INSERT INTO "django_geo_db_city" VALUES(20801,'Montgomery City','Montgomery City, Missouri',25394,43);
INSERT INTO "django_geo_db_city" VALUES(20802,'Moscow Mills','Moscow Mills, Missouri',25395,43);
INSERT INTO "django_geo_db_city" VALUES(20803,'New Florence','New Florence, Missouri',25396,43);
INSERT INTO "django_geo_db_city" VALUES(20804,'New Melle','New Melle, Missouri',25397,43);
INSERT INTO "django_geo_db_city" VALUES(20805,'O Fallon','O Fallon, Missouri',25398,43);
INSERT INTO "django_geo_db_city" VALUES(20806,'Lake Saint Louis','Lake Saint Louis, Missouri',25399,43);
INSERT INTO "django_geo_db_city" VALUES(20807,'Old Monroe','Old Monroe, Missouri',25400,43);
INSERT INTO "django_geo_db_city" VALUES(20808,'Olney','Olney, Missouri',25401,43);
INSERT INTO "django_geo_db_city" VALUES(20809,'Paynesville','Paynesville, Missouri',25402,43);
INSERT INTO "django_geo_db_city" VALUES(20810,'Portage Des Sioux','Portage Des Sioux, Missouri',25403,43);
INSERT INTO "django_geo_db_city" VALUES(20811,'Perryville','Perryville, Missouri',25404,43);
INSERT INTO "django_geo_db_city" VALUES(20812,'Saint Peters','Saint Peters, Missouri',25405,43);
INSERT INTO "django_geo_db_city" VALUES(20813,'Silex','Silex, Missouri',25406,43);
INSERT INTO "django_geo_db_city" VALUES(20814,'Treloar','Treloar, Missouri',25407,43);
INSERT INTO "django_geo_db_city" VALUES(20815,'Troy','Troy, Missouri',25408,43);
INSERT INTO "django_geo_db_city" VALUES(20816,'Truxton','Truxton, Missouri',25409,43);
INSERT INTO "django_geo_db_city" VALUES(20817,'Vandalia','Vandalia, Missouri',25410,43);
INSERT INTO "django_geo_db_city" VALUES(20818,'Warrenton','Warrenton, Missouri',25411,43);
INSERT INTO "django_geo_db_city" VALUES(20819,'Wellsville','Wellsville, Missouri',25412,43);
INSERT INTO "django_geo_db_city" VALUES(20820,'Wentzville','Wentzville, Missouri',25413,43);
INSERT INTO "django_geo_db_city" VALUES(20821,'West Alton','West Alton, Missouri',25414,43);
INSERT INTO "django_geo_db_city" VALUES(20822,'Whiteside','Whiteside, Missouri',25415,43);
INSERT INTO "django_geo_db_city" VALUES(20823,'Williamsburg','Williamsburg, Missouri',25416,43);
INSERT INTO "django_geo_db_city" VALUES(20824,'Winfield','Winfield, Missouri',25417,43);
INSERT INTO "django_geo_db_city" VALUES(20825,'Wright City','Wright City, Missouri',25418,43);
INSERT INTO "django_geo_db_city" VALUES(20826,'Hannibal','Hannibal, Missouri',25419,43);
INSERT INTO "django_geo_db_city" VALUES(20827,'Alexandria','Alexandria, Missouri',25420,43);
INSERT INTO "django_geo_db_city" VALUES(20828,'Anabel','Anabel, Missouri',25421,43);
INSERT INTO "django_geo_db_city" VALUES(20829,'Arbela','Arbela, Missouri',25422,43);
INSERT INTO "django_geo_db_city" VALUES(20830,'Ashburn','Ashburn, Missouri',25423,43);
INSERT INTO "django_geo_db_city" VALUES(20831,'Bethel','Bethel, Missouri',25424,43);
INSERT INTO "django_geo_db_city" VALUES(20832,'Canton','Canton, Missouri',25425,43);
INSERT INTO "django_geo_db_city" VALUES(20833,'Center','Center, Missouri',25426,43);
INSERT INTO "django_geo_db_city" VALUES(20834,'Clarence','Clarence, Missouri',25427,43);
INSERT INTO "django_geo_db_city" VALUES(20835,'Durham','Durham, Missouri',25428,43);
INSERT INTO "django_geo_db_city" VALUES(20836,'Emden','Emden, Missouri',25429,43);
INSERT INTO "django_geo_db_city" VALUES(20837,'Ewing','Ewing, Missouri',25430,43);
INSERT INTO "django_geo_db_city" VALUES(20838,'Frankford','Frankford, Missouri',25431,43);
INSERT INTO "django_geo_db_city" VALUES(20839,'Granger','Granger, Missouri',25432,43);
INSERT INTO "django_geo_db_city" VALUES(20840,'Hunnewell','Hunnewell, Missouri',25433,43);
INSERT INTO "django_geo_db_city" VALUES(20841,'Kahoka','Kahoka, Missouri',25434,43);
INSERT INTO "django_geo_db_city" VALUES(20842,'Knox City','Knox City, Missouri',25435,43);
INSERT INTO "django_geo_db_city" VALUES(20843,'La Belle','La Belle, Missouri',25436,43);
INSERT INTO "django_geo_db_city" VALUES(20844,'La Grange','La Grange, Missouri',25437,43);
INSERT INTO "django_geo_db_city" VALUES(20845,'Lentner','Lentner, Missouri',25438,43);
INSERT INTO "django_geo_db_city" VALUES(20846,'Leonard','Leonard, Missouri',25439,43);
INSERT INTO "django_geo_db_city" VALUES(20847,'Lewistown','Lewistown, Missouri',25440,43);
INSERT INTO "django_geo_db_city" VALUES(20848,'Luray','Luray, Missouri',25441,43);
INSERT INTO "django_geo_db_city" VALUES(20849,'Maywood','Maywood, Missouri',25442,43);
INSERT INTO "django_geo_db_city" VALUES(20850,'Monroe City','Monroe City, Missouri',25443,43);
INSERT INTO "django_geo_db_city" VALUES(20851,'Monticello','Monticello, Missouri',25444,43);
INSERT INTO "django_geo_db_city" VALUES(20852,'Newark','Newark, Missouri',25445,43);
INSERT INTO "django_geo_db_city" VALUES(20853,'New London','New London, Missouri',25446,43);
INSERT INTO "django_geo_db_city" VALUES(20854,'Novelty','Novelty, Missouri',25447,43);
INSERT INTO "django_geo_db_city" VALUES(20855,'Palmyra','Palmyra, Missouri',25448,43);
INSERT INTO "django_geo_db_city" VALUES(20856,'Perry','Perry, Missouri',25449,43);
INSERT INTO "django_geo_db_city" VALUES(20857,'Philadelphia','Philadelphia, Missouri',25450,43);
INSERT INTO "django_geo_db_city" VALUES(20858,'Plevna','Plevna, Missouri',25451,43);
INSERT INTO "django_geo_db_city" VALUES(20859,'Revere','Revere, Missouri',25452,43);
INSERT INTO "django_geo_db_city" VALUES(20860,'Saint Patrick','Saint Patrick, Missouri',25453,43);
INSERT INTO "django_geo_db_city" VALUES(20861,'Saverton','Saverton, Missouri',25454,43);
INSERT INTO "django_geo_db_city" VALUES(20862,'Shelbina','Shelbina, Missouri',25455,43);
INSERT INTO "django_geo_db_city" VALUES(20863,'Shelbyville','Shelbyville, Missouri',25456,43);
INSERT INTO "django_geo_db_city" VALUES(20864,'Taylor','Taylor, Missouri',25457,43);
INSERT INTO "django_geo_db_city" VALUES(20865,'Wayland','Wayland, Missouri',25458,43);
INSERT INTO "django_geo_db_city" VALUES(20866,'Williamstown','Williamstown, Missouri',25459,43);
INSERT INTO "django_geo_db_city" VALUES(20867,'Wyaconda','Wyaconda, Missouri',25460,43);
INSERT INTO "django_geo_db_city" VALUES(20868,'Kirksville','Kirksville, Missouri',25462,43);
INSERT INTO "django_geo_db_city" VALUES(20869,'Atlanta','Atlanta, Missouri',25463,43);
INSERT INTO "django_geo_db_city" VALUES(20870,'Baring','Baring, Missouri',25464,43);
INSERT INTO "django_geo_db_city" VALUES(20871,'Bevier','Bevier, Missouri',25465,43);
INSERT INTO "django_geo_db_city" VALUES(20872,'Brashear','Brashear, Missouri',25466,43);
INSERT INTO "django_geo_db_city" VALUES(20873,'Callao','Callao, Missouri',25467,43);
INSERT INTO "django_geo_db_city" VALUES(20874,'Coatsville','Coatsville, Missouri',25468,43);
INSERT INTO "django_geo_db_city" VALUES(20875,'Downing','Downing, Missouri',25469,43);
INSERT INTO "django_geo_db_city" VALUES(20876,'Edina','Edina, Missouri',25470,43);
INSERT INTO "django_geo_db_city" VALUES(20877,'Elmer','Elmer, Missouri',25471,43);
INSERT INTO "django_geo_db_city" VALUES(20878,'Ethel','Ethel, Missouri',25472,43);
INSERT INTO "django_geo_db_city" VALUES(20879,'Gibbs','Gibbs, Missouri',25473,43);
INSERT INTO "django_geo_db_city" VALUES(20880,'Glenwood','Glenwood, Missouri',25474,43);
INSERT INTO "django_geo_db_city" VALUES(20881,'Gorin','Gorin, Missouri',25475,43);
INSERT INTO "django_geo_db_city" VALUES(20882,'Green Castle','Green Castle, Missouri',25476,43);
INSERT INTO "django_geo_db_city" VALUES(20883,'Green City','Green City, Missouri',25477,43);
INSERT INTO "django_geo_db_city" VALUES(20884,'Greentop','Greentop, Missouri',25478,43);
INSERT INTO "django_geo_db_city" VALUES(20885,'Hurdland','Hurdland, Missouri',25479,43);
INSERT INTO "django_geo_db_city" VALUES(20886,'Lancaster','Lancaster, Missouri',25480,43);
INSERT INTO "django_geo_db_city" VALUES(20887,'La Plata','La Plata, Missouri',25481,43);
INSERT INTO "django_geo_db_city" VALUES(20888,'Livonia','Livonia, Missouri',25482,43);
INSERT INTO "django_geo_db_city" VALUES(20889,'Macon','Macon, Missouri',25483,43);
INSERT INTO "django_geo_db_city" VALUES(20890,'Memphis','Memphis, Missouri',25484,43);
INSERT INTO "django_geo_db_city" VALUES(20891,'Milan','Milan, Missouri',25485,43);
INSERT INTO "django_geo_db_city" VALUES(20892,'New Boston','New Boston, Missouri',25486,43);
INSERT INTO "django_geo_db_city" VALUES(20893,'New Cambria','New Cambria, Missouri',25487,43);
INSERT INTO "django_geo_db_city" VALUES(20894,'Novinger','Novinger, Missouri',25488,43);
INSERT INTO "django_geo_db_city" VALUES(20895,'Pollock','Pollock, Missouri',25489,43);
INSERT INTO "django_geo_db_city" VALUES(20896,'Queen City','Queen City, Missouri',25490,43);
INSERT INTO "django_geo_db_city" VALUES(20897,'Rutledge','Rutledge, Missouri',25491,43);
INSERT INTO "django_geo_db_city" VALUES(20898,'Unionville','Unionville, Missouri',25492,43);
INSERT INTO "django_geo_db_city" VALUES(20899,'Winigan','Winigan, Missouri',25493,43);
INSERT INTO "django_geo_db_city" VALUES(20900,'Worthington','Worthington, Missouri',25494,43);
INSERT INTO "django_geo_db_city" VALUES(20901,'Clay','Clay, Missouri',25495,43);
INSERT INTO "django_geo_db_city" VALUES(20902,'Park Hills','Park Hills, Missouri',25496,43);
INSERT INTO "django_geo_db_city" VALUES(20903,'Annapolis','Annapolis, Missouri',25497,43);
INSERT INTO "django_geo_db_city" VALUES(20904,'Arcadia','Arcadia, Missouri',25498,43);
INSERT INTO "django_geo_db_city" VALUES(20905,'Belgrade','Belgrade, Missouri',25499,43);
INSERT INTO "django_geo_db_city" VALUES(20906,'Belleview','Belleview, Missouri',25500,43);
INSERT INTO "django_geo_db_city" VALUES(20907,'Bismarck','Bismarck, Missouri',25501,43);
INSERT INTO "django_geo_db_city" VALUES(20908,'Black','Black, Missouri',25502,43);
INSERT INTO "django_geo_db_city" VALUES(20909,'Blackwell','Blackwell, Missouri',25503,43);
INSERT INTO "django_geo_db_city" VALUES(20910,'Bloomsdale','Bloomsdale, Missouri',25504,43);
INSERT INTO "django_geo_db_city" VALUES(20911,'Bonne Terre','Bonne Terre, Missouri',25505,43);
INSERT INTO "django_geo_db_city" VALUES(20912,'Bunker','Bunker, Missouri',25506,43);
INSERT INTO "django_geo_db_city" VALUES(20913,'Cadet','Cadet, Missouri',25507,43);
INSERT INTO "django_geo_db_city" VALUES(20914,'Caledonia','Caledonia, Missouri',25508,43);
INSERT INTO "django_geo_db_city" VALUES(20915,'Cascade','Cascade, Missouri',25509,43);
INSERT INTO "django_geo_db_city" VALUES(20916,'Centerville','Centerville, Missouri',25510,43);
INSERT INTO "django_geo_db_city" VALUES(20917,'Des Arc','Des Arc, Missouri',25511,43);
INSERT INTO "django_geo_db_city" VALUES(20918,'Doe Run','Doe Run, Missouri',25512,43);
INSERT INTO "django_geo_db_city" VALUES(20919,'Ellington','Ellington, Missouri',25513,43);
INSERT INTO "django_geo_db_city" VALUES(20920,'Farmington','Farmington, Missouri',25514,43);
INSERT INTO "django_geo_db_city" VALUES(20921,'Fredericktown','Fredericktown, Missouri',25515,43);
INSERT INTO "django_geo_db_city" VALUES(20922,'Glover','Glover, Missouri',25516,43);
INSERT INTO "django_geo_db_city" VALUES(20923,'Irondale','Irondale, Missouri',25517,43);
INSERT INTO "django_geo_db_city" VALUES(20924,'Ironton','Ironton, Missouri',25518,43);
INSERT INTO "django_geo_db_city" VALUES(20925,'Knob Lick','Knob Lick, Missouri',25519,43);
INSERT INTO "django_geo_db_city" VALUES(20926,'Leadwood','Leadwood, Missouri',25520,43);
INSERT INTO "django_geo_db_city" VALUES(20927,'Lesterville','Lesterville, Missouri',25521,43);
INSERT INTO "django_geo_db_city" VALUES(20928,'Marquand','Marquand, Missouri',25522,43);
INSERT INTO "django_geo_db_city" VALUES(20929,'Middle Brook','Middle Brook, Missouri',25523,43);
INSERT INTO "django_geo_db_city" VALUES(20930,'Mineral Point','Mineral Point, Missouri',25524,43);
INSERT INTO "django_geo_db_city" VALUES(20931,'New Offenburg','New Offenburg, Missouri',25525,43);
INSERT INTO "django_geo_db_city" VALUES(20932,'Patton','Patton, Missouri',25526,43);
INSERT INTO "django_geo_db_city" VALUES(20933,'Pilot Knob','Pilot Knob, Missouri',25527,43);
INSERT INTO "django_geo_db_city" VALUES(20934,'Potosi','Potosi, Missouri',25528,43);
INSERT INTO "django_geo_db_city" VALUES(20935,'Redford','Redford, Missouri',25529,43);
INSERT INTO "django_geo_db_city" VALUES(20936,'Reynolds','Reynolds, Missouri',25530,43);
INSERT INTO "django_geo_db_city" VALUES(20937,'Sainte Genevieve','Sainte Genevieve, Missouri',25531,43);
INSERT INTO "django_geo_db_city" VALUES(20938,'Saint Mary','Saint Mary, Missouri',25532,43);
INSERT INTO "django_geo_db_city" VALUES(20939,'Tiff','Tiff, Missouri',25533,43);
INSERT INTO "django_geo_db_city" VALUES(20940,'Vulcan','Vulcan, Missouri',25534,43);
INSERT INTO "django_geo_db_city" VALUES(20941,'Cape Girardeau','Cape Girardeau, Missouri',25535,43);
INSERT INTO "django_geo_db_city" VALUES(20942,'Advance','Advance, Missouri',25539,43);
INSERT INTO "django_geo_db_city" VALUES(20943,'Altenburg','Altenburg, Missouri',25540,43);
INSERT INTO "django_geo_db_city" VALUES(20944,'Bell City','Bell City, Missouri',25541,43);
INSERT INTO "django_geo_db_city" VALUES(20945,'Benton','Benton, Missouri',25542,43);
INSERT INTO "django_geo_db_city" VALUES(20946,'Brazeau','Brazeau, Missouri',25543,43);
INSERT INTO "django_geo_db_city" VALUES(20947,'Brownwood','Brownwood, Missouri',25544,43);
INSERT INTO "django_geo_db_city" VALUES(20948,'Burfordville','Burfordville, Missouri',25545,43);
INSERT INTO "django_geo_db_city" VALUES(20949,'Chaffee','Chaffee, Missouri',25546,43);
INSERT INTO "django_geo_db_city" VALUES(20950,'Commerce','Commerce, Missouri',25547,43);
INSERT INTO "django_geo_db_city" VALUES(20951,'Daisy','Daisy, Missouri',25548,43);
INSERT INTO "django_geo_db_city" VALUES(20952,'Delta','Delta, Missouri',25549,43);
INSERT INTO "django_geo_db_city" VALUES(20953,'Dutchtown','Dutchtown, Missouri',25550,43);
INSERT INTO "django_geo_db_city" VALUES(20954,'Farrar','Farrar, Missouri',25551,43);
INSERT INTO "django_geo_db_city" VALUES(20955,'Friedheim','Friedheim, Missouri',25552,43);
INSERT INTO "django_geo_db_city" VALUES(20956,'Frohna','Frohna, Missouri',25553,43);
INSERT INTO "django_geo_db_city" VALUES(20957,'Gipsy','Gipsy, Missouri',25554,43);
INSERT INTO "django_geo_db_city" VALUES(20958,'Glenallen','Glenallen, Missouri',25555,43);
INSERT INTO "django_geo_db_city" VALUES(20959,'Gordonville','Gordonville, Missouri',25556,43);
INSERT INTO "django_geo_db_city" VALUES(20960,'Grassy','Grassy, Missouri',25557,43);
INSERT INTO "django_geo_db_city" VALUES(20961,'Jackson','Jackson, Missouri',25558,43);
INSERT INTO "django_geo_db_city" VALUES(20962,'Kelso','Kelso, Missouri',25559,43);
INSERT INTO "django_geo_db_city" VALUES(20963,'Leopold','Leopold, Missouri',25560,43);
INSERT INTO "django_geo_db_city" VALUES(20964,'McGee','McGee, Missouri',25561,43);
INSERT INTO "django_geo_db_city" VALUES(20965,'Marble Hill','Marble Hill, Missouri',25562,43);
INSERT INTO "django_geo_db_city" VALUES(20966,'Millersville','Millersville, Missouri',25563,43);
INSERT INTO "django_geo_db_city" VALUES(20967,'Morley','Morley, Missouri',25564,43);
INSERT INTO "django_geo_db_city" VALUES(20968,'Oak Ridge','Oak Ridge, Missouri',25565,43);
INSERT INTO "django_geo_db_city" VALUES(20969,'Old Appleton','Old Appleton, Missouri',25566,43);
INSERT INTO "django_geo_db_city" VALUES(20970,'Oran','Oran, Missouri',25567,43);
INSERT INTO "django_geo_db_city" VALUES(20971,'Painton','Painton, Missouri',25568,43);
INSERT INTO "django_geo_db_city" VALUES(20972,'Perkins','Perkins, Missouri',25569,43);
INSERT INTO "django_geo_db_city" VALUES(20973,'McBride','McBride, Missouri',25551,43);
INSERT INTO "django_geo_db_city" VALUES(20974,'Pocahontas','Pocahontas, Missouri',25571,43);
INSERT INTO "django_geo_db_city" VALUES(20975,'Scott City','Scott City, Missouri',25572,43);
INSERT INTO "django_geo_db_city" VALUES(20976,'Sedgewickville','Sedgewickville, Missouri',25573,43);
INSERT INTO "django_geo_db_city" VALUES(20977,'Sturdivant','Sturdivant, Missouri',25574,43);
INSERT INTO "django_geo_db_city" VALUES(20978,'Uniontown','Uniontown, Missouri',25575,43);
INSERT INTO "django_geo_db_city" VALUES(20979,'Vanduser','Vanduser, Missouri',25576,43);
INSERT INTO "django_geo_db_city" VALUES(20980,'Whitewater','Whitewater, Missouri',25577,43);
INSERT INTO "django_geo_db_city" VALUES(20981,'Zalma','Zalma, Missouri',25578,43);
INSERT INTO "django_geo_db_city" VALUES(20982,'Sikeston','Sikeston, Missouri',25579,43);
INSERT INTO "django_geo_db_city" VALUES(20983,'Blodgett','Blodgett, Missouri',25580,43);
INSERT INTO "django_geo_db_city" VALUES(20984,'Anniston','Anniston, Missouri',25581,43);
INSERT INTO "django_geo_db_city" VALUES(20985,'Arbyrd','Arbyrd, Missouri',25582,43);
INSERT INTO "django_geo_db_city" VALUES(20986,'Bernie','Bernie, Missouri',25583,43);
INSERT INTO "django_geo_db_city" VALUES(20987,'Bertrand','Bertrand, Missouri',25584,43);
INSERT INTO "django_geo_db_city" VALUES(20988,'Bloomfield','Bloomfield, Missouri',25586,43);
INSERT INTO "django_geo_db_city" VALUES(20989,'Braggadocio','Braggadocio, Missouri',25587,43);
INSERT INTO "django_geo_db_city" VALUES(20990,'Bragg City','Bragg City, Missouri',25588,43);
INSERT INTO "django_geo_db_city" VALUES(20991,'Canalou','Canalou, Missouri',25589,43);
INSERT INTO "django_geo_db_city" VALUES(20992,'Cardwell','Cardwell, Missouri',25590,43);
INSERT INTO "django_geo_db_city" VALUES(20993,'Caruthersville','Caruthersville, Missouri',25591,43);
INSERT INTO "django_geo_db_city" VALUES(20994,'Wyatt','Wyatt, Missouri',25592,43);
INSERT INTO "django_geo_db_city" VALUES(20995,'Catron','Catron, Missouri',25593,43);
INSERT INTO "django_geo_db_city" VALUES(20996,'Charleston','Charleston, Missouri',25594,43);
INSERT INTO "django_geo_db_city" VALUES(20997,'Clarkton','Clarkton, Missouri',25595,43);
INSERT INTO "django_geo_db_city" VALUES(20998,'Conran','Conran, Missouri',25596,43);
INSERT INTO "django_geo_db_city" VALUES(20999,'Cooter','Cooter, Missouri',25597,43);
INSERT INTO "django_geo_db_city" VALUES(21000,'Deering','Deering, Missouri',25598,43);
INSERT INTO "django_geo_db_city" VALUES(21001,'Dexter','Dexter, Missouri',25599,43);
INSERT INTO "django_geo_db_city" VALUES(21002,'East Prairie','East Prairie, Missouri',25600,43);
INSERT INTO "django_geo_db_city" VALUES(21003,'Essex','Essex, Missouri',25601,43);
INSERT INTO "django_geo_db_city" VALUES(21004,'Gibson','Gibson, Missouri',25602,43);
INSERT INTO "django_geo_db_city" VALUES(21005,'Gideon','Gideon, Missouri',25603,43);
INSERT INTO "django_geo_db_city" VALUES(21006,'Gobler','Gobler, Missouri',25604,43);
INSERT INTO "django_geo_db_city" VALUES(21007,'Grayridge','Grayridge, Missouri',25605,43);
INSERT INTO "django_geo_db_city" VALUES(21008,'Hayti','Hayti, Missouri',25606,43);
INSERT INTO "django_geo_db_city" VALUES(21009,'Holcomb','Holcomb, Missouri',25607,43);
INSERT INTO "django_geo_db_city" VALUES(21010,'Holland','Holland, Missouri',25608,43);
INSERT INTO "django_geo_db_city" VALUES(21011,'Hornersville','Hornersville, Missouri',25609,43);
INSERT INTO "django_geo_db_city" VALUES(21012,'Kennett','Kennett, Missouri',25610,43);
INSERT INTO "django_geo_db_city" VALUES(21013,'Independence','Independence, Missouri',25611,43);
INSERT INTO "django_geo_db_city" VALUES(21014,'Kewanee','Kewanee, Missouri',25612,43);
INSERT INTO "django_geo_db_city" VALUES(21015,'Lilbourn','Lilbourn, Missouri',25613,43);
INSERT INTO "django_geo_db_city" VALUES(21016,'Malden','Malden, Missouri',25614,43);
INSERT INTO "django_geo_db_city" VALUES(21017,'Marston','Marston, Missouri',25615,43);
INSERT INTO "django_geo_db_city" VALUES(21018,'Matthews','Matthews, Missouri',25616,43);
INSERT INTO "django_geo_db_city" VALUES(21019,'Morehouse','Morehouse, Missouri',25617,43);
INSERT INTO "django_geo_db_city" VALUES(21020,'New Madrid','New Madrid, Missouri',25618,43);
INSERT INTO "django_geo_db_city" VALUES(21021,'Parma','Parma, Missouri',25619,43);
INSERT INTO "django_geo_db_city" VALUES(21022,'Pascola','Pascola, Missouri',25620,43);
INSERT INTO "django_geo_db_city" VALUES(21023,'Portageville','Portageville, Missouri',25622,43);
INSERT INTO "django_geo_db_city" VALUES(21024,'Risco','Risco, Missouri',25623,43);
INSERT INTO "django_geo_db_city" VALUES(21025,'Rives','Rives, Missouri',25624,43);
INSERT INTO "django_geo_db_city" VALUES(21026,'Senath','Senath, Missouri',25625,43);
INSERT INTO "django_geo_db_city" VALUES(21027,'Steele','Steele, Missouri',25626,43);
INSERT INTO "django_geo_db_city" VALUES(21028,'Tallapoosa','Tallapoosa, Missouri',25627,43);
INSERT INTO "django_geo_db_city" VALUES(21029,'Wardell','Wardell, Missouri',25628,43);
INSERT INTO "django_geo_db_city" VALUES(21030,'Whiteoak','Whiteoak, Missouri',25629,43);
INSERT INTO "django_geo_db_city" VALUES(21031,'Wolf Island','Wolf Island, Missouri',25630,43);
INSERT INTO "django_geo_db_city" VALUES(21032,'Poplar Bluff','Poplar Bluff, Missouri',25632,43);
INSERT INTO "django_geo_db_city" VALUES(21033,'Briar','Briar, Missouri',25634,43);
INSERT INTO "django_geo_db_city" VALUES(21034,'Broseley','Broseley, Missouri',25635,43);
INSERT INTO "django_geo_db_city" VALUES(21035,'Campbell','Campbell, Missouri',25636,43);
INSERT INTO "django_geo_db_city" VALUES(21036,'Clubb','Clubb, Missouri',25637,43);
INSERT INTO "django_geo_db_city" VALUES(21037,'Doniphan','Doniphan, Missouri',25638,43);
INSERT INTO "django_geo_db_city" VALUES(21038,'Dudley','Dudley, Missouri',25639,43);
INSERT INTO "django_geo_db_city" VALUES(21039,'Ellsinore','Ellsinore, Missouri',25640,43);
INSERT INTO "django_geo_db_city" VALUES(21040,'Fagus','Fagus, Missouri',25641,43);
INSERT INTO "django_geo_db_city" VALUES(21041,'Fairdealing','Fairdealing, Missouri',25642,43);
INSERT INTO "django_geo_db_city" VALUES(21042,'Fisk','Fisk, Missouri',25643,43);
INSERT INTO "django_geo_db_city" VALUES(21043,'Fremont','Fremont, Missouri',25644,43);
INSERT INTO "django_geo_db_city" VALUES(21044,'Gatewood','Gatewood, Missouri',25645,43);
INSERT INTO "django_geo_db_city" VALUES(21045,'Grandin','Grandin, Missouri',25646,43);
INSERT INTO "django_geo_db_city" VALUES(21046,'Greenville','Greenville, Missouri',25647,43);
INSERT INTO "django_geo_db_city" VALUES(21047,'Harviell','Harviell, Missouri',25648,43);
INSERT INTO "django_geo_db_city" VALUES(21048,'Hiram','Hiram, Missouri',25649,43);
INSERT INTO "django_geo_db_city" VALUES(21049,'Lodi','Lodi, Missouri',25509,43);
INSERT INTO "django_geo_db_city" VALUES(21050,'Lowndes','Lowndes, Missouri',25650,43);
INSERT INTO "django_geo_db_city" VALUES(21051,'Mill Spring','Mill Spring, Missouri',25651,43);
INSERT INTO "django_geo_db_city" VALUES(21052,'Naylor','Naylor, Missouri',25652,43);
INSERT INTO "django_geo_db_city" VALUES(21053,'Neelyville','Neelyville, Missouri',25653,43);
INSERT INTO "django_geo_db_city" VALUES(21054,'Oxly','Oxly, Missouri',25654,43);
INSERT INTO "django_geo_db_city" VALUES(21055,'Patterson','Patterson, Missouri',25655,43);
INSERT INTO "django_geo_db_city" VALUES(21056,'Piedmont','Piedmont, Missouri',25656,43);
INSERT INTO "django_geo_db_city" VALUES(21057,'Puxico','Puxico, Missouri',25657,43);
INSERT INTO "django_geo_db_city" VALUES(21058,'Qulin','Qulin, Missouri',25658,43);
INSERT INTO "django_geo_db_city" VALUES(21059,'Rombauer','Rombauer, Missouri',25633,43);
INSERT INTO "django_geo_db_city" VALUES(21060,'Shook','Shook, Missouri',25659,43);
INSERT INTO "django_geo_db_city" VALUES(21061,'Silva','Silva, Missouri',25660,43);
INSERT INTO "django_geo_db_city" VALUES(21062,'Van Buren','Van Buren, Missouri',25661,43);
INSERT INTO "django_geo_db_city" VALUES(21063,'Wappapello','Wappapello, Missouri',25662,43);
INSERT INTO "django_geo_db_city" VALUES(21064,'Williamsville','Williamsville, Missouri',25663,43);
INSERT INTO "django_geo_db_city" VALUES(21065,'Alma','Alma, Missouri',25664,43);
INSERT INTO "django_geo_db_city" VALUES(21066,'Bates City','Bates City, Missouri',25665,43);
INSERT INTO "django_geo_db_city" VALUES(21067,'Belton','Belton, Missouri',25666,43);
INSERT INTO "django_geo_db_city" VALUES(21068,'Blue Springs','Blue Springs, Missouri',25667,43);
INSERT INTO "django_geo_db_city" VALUES(21069,'Buckner','Buckner, Missouri',25670,43);
INSERT INTO "django_geo_db_city" VALUES(21070,'Camden','Camden, Missouri',25671,43);
INSERT INTO "django_geo_db_city" VALUES(21071,'Camden Point','Camden Point, Missouri',25672,43);
INSERT INTO "django_geo_db_city" VALUES(21072,'Centerview','Centerview, Missouri',25673,43);
INSERT INTO "django_geo_db_city" VALUES(21073,'Concordia','Concordia, Missouri',25674,43);
INSERT INTO "django_geo_db_city" VALUES(21074,'Corder','Corder, Missouri',25675,43);
INSERT INTO "django_geo_db_city" VALUES(21075,'Dover','Dover, Missouri',25676,43);
INSERT INTO "django_geo_db_city" VALUES(21076,'Excelsior Springs','Excelsior Springs, Missouri',25677,43);
INSERT INTO "django_geo_db_city" VALUES(21077,'Farley','Farley, Missouri',25678,43);
INSERT INTO "django_geo_db_city" VALUES(21078,'Grain Valley','Grain Valley, Missouri',25679,43);
INSERT INTO "django_geo_db_city" VALUES(21079,'Grandview','Grandview, Missouri',25680,43);
INSERT INTO "django_geo_db_city" VALUES(21080,'Greenwood','Greenwood, Missouri',25681,43);
INSERT INTO "django_geo_db_city" VALUES(21081,'Hardin','Hardin, Missouri',25682,43);
INSERT INTO "django_geo_db_city" VALUES(21082,'Henrietta','Henrietta, Missouri',25683,43);
INSERT INTO "django_geo_db_city" VALUES(21083,'Higginsville','Higginsville, Missouri',25684,43);
INSERT INTO "django_geo_db_city" VALUES(21084,'Holden','Holden, Missouri',25685,43);
INSERT INTO "django_geo_db_city" VALUES(21085,'Holt','Holt, Missouri',25686,43);
INSERT INTO "django_geo_db_city" VALUES(21086,'Kearney','Kearney, Missouri',25696,43);
INSERT INTO "django_geo_db_city" VALUES(21087,'Kingsville','Kingsville, Missouri',25697,43);
INSERT INTO "django_geo_db_city" VALUES(21088,'Lawson','Lawson, Missouri',25698,43);
INSERT INTO "django_geo_db_city" VALUES(21089,'Lees Summit','Lees Summit, Missouri',25699,43);
INSERT INTO "django_geo_db_city" VALUES(21090,'Levasy','Levasy, Missouri',25702,43);
INSERT INTO "django_geo_db_city" VALUES(21091,'Lexington','Lexington, Missouri',25703,43);
INSERT INTO "django_geo_db_city" VALUES(21092,'Liberty','Liberty, Missouri',25704,43);
INSERT INTO "django_geo_db_city" VALUES(21093,'Lone Jack','Lone Jack, Missouri',25706,43);
INSERT INTO "django_geo_db_city" VALUES(21094,'Mayview','Mayview, Missouri',25707,43);
INSERT INTO "django_geo_db_city" VALUES(21095,'Missouri City','Missouri City, Missouri',25708,43);
INSERT INTO "django_geo_db_city" VALUES(21096,'Mosby','Mosby, Missouri',25709,43);
INSERT INTO "django_geo_db_city" VALUES(21097,'Napoleon','Napoleon, Missouri',25710,43);
INSERT INTO "django_geo_db_city" VALUES(21098,'Oak Grove','Oak Grove, Missouri',25711,43);
INSERT INTO "django_geo_db_city" VALUES(21099,'Odessa','Odessa, Missouri',25712,43);
INSERT INTO "django_geo_db_city" VALUES(21100,'Orrick','Orrick, Missouri',25713,43);
INSERT INTO "django_geo_db_city" VALUES(21101,'Peculiar','Peculiar, Missouri',25714,43);
INSERT INTO "django_geo_db_city" VALUES(21102,'Platte City','Platte City, Missouri',25715,43);
INSERT INTO "django_geo_db_city" VALUES(21103,'Pleasant Hill','Pleasant Hill, Missouri',25716,43);
INSERT INTO "django_geo_db_city" VALUES(21104,'Raymore','Raymore, Missouri',25719,43);
INSERT INTO "django_geo_db_city" VALUES(21105,'Rayville','Rayville, Missouri',25720,43);
INSERT INTO "django_geo_db_city" VALUES(21106,'Richmond','Richmond, Missouri',25721,43);
INSERT INTO "django_geo_db_city" VALUES(21107,'Sibley','Sibley, Missouri',25723,43);
INSERT INTO "django_geo_db_city" VALUES(21108,'Smithville','Smithville, Missouri',25724,43);
INSERT INTO "django_geo_db_city" VALUES(21109,'Strasburg','Strasburg, Missouri',25725,43);
INSERT INTO "django_geo_db_city" VALUES(21110,'Waldron','Waldron, Missouri',25726,43);
INSERT INTO "django_geo_db_city" VALUES(21111,'Warrensburg','Warrensburg, Missouri',25727,43);
INSERT INTO "django_geo_db_city" VALUES(21112,'Waverly','Waverly, Missouri',25728,43);
INSERT INTO "django_geo_db_city" VALUES(21113,'Wellington','Wellington, Missouri',25729,43);
INSERT INTO "django_geo_db_city" VALUES(21114,'Weston','Weston, Missouri',25730,43);
INSERT INTO "django_geo_db_city" VALUES(21115,'Kansas City','Kansas City, Missouri',25731,43);
INSERT INTO "django_geo_db_city" VALUES(21116,'Riverside','Riverside, Missouri',25768,43);
INSERT INTO "django_geo_db_city" VALUES(21117,'Agency','Agency, Missouri',25785,43);
INSERT INTO "django_geo_db_city" VALUES(21118,'Albany','Albany, Missouri',25786,43);
INSERT INTO "django_geo_db_city" VALUES(21119,'Allendale','Allendale, Missouri',25787,43);
INSERT INTO "django_geo_db_city" VALUES(21120,'Amazonia','Amazonia, Missouri',25788,43);
INSERT INTO "django_geo_db_city" VALUES(21121,'Amity','Amity, Missouri',25789,43);
INSERT INTO "django_geo_db_city" VALUES(21122,'Barnard','Barnard, Missouri',25790,43);
INSERT INTO "django_geo_db_city" VALUES(21123,'Bethany','Bethany, Missouri',25791,43);
INSERT INTO "django_geo_db_city" VALUES(21124,'Blythedale','Blythedale, Missouri',25792,43);
INSERT INTO "django_geo_db_city" VALUES(21125,'Bolckow','Bolckow, Missouri',25793,43);
INSERT INTO "django_geo_db_city" VALUES(21126,'Burlington Junction','Burlington Junction, Missouri',25794,43);
INSERT INTO "django_geo_db_city" VALUES(21127,'Cameron','Cameron, Missouri',25795,43);
INSERT INTO "django_geo_db_city" VALUES(21128,'Clarksdale','Clarksdale, Missouri',25796,43);
INSERT INTO "django_geo_db_city" VALUES(21129,'Clearmont','Clearmont, Missouri',25797,43);
INSERT INTO "django_geo_db_city" VALUES(21130,'Clyde','Clyde, Missouri',25798,43);
INSERT INTO "django_geo_db_city" VALUES(21131,'Conception','Conception, Missouri',25799,43);
INSERT INTO "django_geo_db_city" VALUES(21132,'Conception Junction','Conception Junction, Missouri',25800,43);
INSERT INTO "django_geo_db_city" VALUES(21133,'Cosby','Cosby, Missouri',25801,43);
INSERT INTO "django_geo_db_city" VALUES(21134,'Craig','Craig, Missouri',25802,43);
INSERT INTO "django_geo_db_city" VALUES(21135,'Darlington','Darlington, Missouri',25803,43);
INSERT INTO "django_geo_db_city" VALUES(21136,'Dearborn','Dearborn, Missouri',25804,43);
INSERT INTO "django_geo_db_city" VALUES(21137,'De Kalb','De Kalb, Missouri',25805,43);
INSERT INTO "django_geo_db_city" VALUES(21138,'Denver','Denver, Missouri',25806,43);
INSERT INTO "django_geo_db_city" VALUES(21139,'Eagleville','Eagleville, Missouri',25807,43);
INSERT INTO "django_geo_db_city" VALUES(21140,'Easton','Easton, Missouri',25808,43);
INSERT INTO "django_geo_db_city" VALUES(21141,'Edgerton','Edgerton, Missouri',25809,43);
INSERT INTO "django_geo_db_city" VALUES(21142,'Elmo','Elmo, Missouri',25810,43);
INSERT INTO "django_geo_db_city" VALUES(21143,'Fairfax','Fairfax, Missouri',25811,43);
INSERT INTO "django_geo_db_city" VALUES(21144,'Fairport','Fairport, Missouri',25812,43);
INSERT INTO "django_geo_db_city" VALUES(21145,'Faucett','Faucett, Missouri',25813,43);
INSERT INTO "django_geo_db_city" VALUES(21146,'Fillmore','Fillmore, Missouri',25814,43);
INSERT INTO "django_geo_db_city" VALUES(21147,'Forest City','Forest City, Missouri',25815,43);
INSERT INTO "django_geo_db_city" VALUES(21148,'Gentry','Gentry, Missouri',25816,43);
INSERT INTO "django_geo_db_city" VALUES(21149,'Gower','Gower, Missouri',25817,43);
INSERT INTO "django_geo_db_city" VALUES(21150,'Graham','Graham, Missouri',25818,43);
INSERT INTO "django_geo_db_city" VALUES(21151,'Grant City','Grant City, Missouri',25819,43);
INSERT INTO "django_geo_db_city" VALUES(21152,'Guilford','Guilford, Missouri',25820,43);
INSERT INTO "django_geo_db_city" VALUES(21153,'Hatfield','Hatfield, Missouri',25821,43);
INSERT INTO "django_geo_db_city" VALUES(21154,'Helena','Helena, Missouri',25822,43);
INSERT INTO "django_geo_db_city" VALUES(21155,'Hopkins','Hopkins, Missouri',25823,43);
INSERT INTO "django_geo_db_city" VALUES(21156,'King City','King City, Missouri',25824,43);
INSERT INTO "django_geo_db_city" VALUES(21157,'Polk','Polk, Missouri',25825,43);
INSERT INTO "django_geo_db_city" VALUES(21158,'Lathrop','Lathrop, Missouri',25826,43);
INSERT INTO "django_geo_db_city" VALUES(21159,'Maitland','Maitland, Missouri',25827,43);
INSERT INTO "django_geo_db_city" VALUES(21160,'Martinsville','Martinsville, Missouri',25828,43);
INSERT INTO "django_geo_db_city" VALUES(21161,'Maryville','Maryville, Missouri',25829,43);
INSERT INTO "django_geo_db_city" VALUES(21162,'Maysville','Maysville, Missouri',25830,43);
INSERT INTO "django_geo_db_city" VALUES(21163,'Mound City','Mound City, Missouri',25831,43);
INSERT INTO "django_geo_db_city" VALUES(21164,'New Hampton','New Hampton, Missouri',25832,43);
INSERT INTO "django_geo_db_city" VALUES(21165,'Oregon','Oregon, Missouri',25833,43);
INSERT INTO "django_geo_db_city" VALUES(21166,'Osborn','Osborn, Missouri',25834,43);
INSERT INTO "django_geo_db_city" VALUES(21167,'Parnell','Parnell, Missouri',25835,43);
INSERT INTO "django_geo_db_city" VALUES(21168,'Pickering','Pickering, Missouri',25836,43);
INSERT INTO "django_geo_db_city" VALUES(21169,'Plattsburg','Plattsburg, Missouri',25837,43);
INSERT INTO "django_geo_db_city" VALUES(21170,'Quitman','Quitman, Missouri',25838,43);
INSERT INTO "django_geo_db_city" VALUES(21171,'Ravenwood','Ravenwood, Missouri',25839,43);
INSERT INTO "django_geo_db_city" VALUES(21172,'Rea','Rea, Missouri',25840,43);
INSERT INTO "django_geo_db_city" VALUES(21173,'Ridgeway','Ridgeway, Missouri',25841,43);
INSERT INTO "django_geo_db_city" VALUES(21174,'Rock Port','Rock Port, Missouri',25842,43);
INSERT INTO "django_geo_db_city" VALUES(21175,'Rosendale','Rosendale, Missouri',25843,43);
INSERT INTO "django_geo_db_city" VALUES(21176,'Rushville','Rushville, Missouri',25844,43);
INSERT INTO "django_geo_db_city" VALUES(21177,'Savannah','Savannah, Missouri',25845,43);
INSERT INTO "django_geo_db_city" VALUES(21178,'Sheridan','Sheridan, Missouri',25846,43);
INSERT INTO "django_geo_db_city" VALUES(21179,'Skidmore','Skidmore, Missouri',25847,43);
INSERT INTO "django_geo_db_city" VALUES(21180,'Stanberry','Stanberry, Missouri',25848,43);
INSERT INTO "django_geo_db_city" VALUES(21181,'Stewartsville','Stewartsville, Missouri',25849,43);
INSERT INTO "django_geo_db_city" VALUES(21182,'Tarkio','Tarkio, Missouri',25850,43);
INSERT INTO "django_geo_db_city" VALUES(21183,'Trimble','Trimble, Missouri',25851,43);
INSERT INTO "django_geo_db_city" VALUES(21184,'Turney','Turney, Missouri',25852,43);
INSERT INTO "django_geo_db_city" VALUES(21185,'Union Star','Union Star, Missouri',25853,43);
INSERT INTO "django_geo_db_city" VALUES(21186,'Watson','Watson, Missouri',25854,43);
INSERT INTO "django_geo_db_city" VALUES(21187,'Weatherby','Weatherby, Missouri',25855,43);
INSERT INTO "django_geo_db_city" VALUES(21188,'Westboro','Westboro, Missouri',25856,43);
INSERT INTO "django_geo_db_city" VALUES(21189,'Worth','Worth, Missouri',25857,43);
INSERT INTO "django_geo_db_city" VALUES(21190,'Saint Joseph','Saint Joseph, Missouri',25858,43);
INSERT INTO "django_geo_db_city" VALUES(21191,'Blue Mound','Blue Mound, Missouri',25865,43);
INSERT INTO "django_geo_db_city" VALUES(21192,'Chillicothe','Chillicothe, Missouri',25866,43);
INSERT INTO "django_geo_db_city" VALUES(21193,'Altamont','Altamont, Missouri',25867,43);
INSERT INTO "django_geo_db_city" VALUES(21194,'Fairview','Fairview, Missouri',25868,43);
INSERT INTO "django_geo_db_city" VALUES(21195,'Bogard','Bogard, Missouri',25869,43);
INSERT INTO "django_geo_db_city" VALUES(21196,'Bosworth','Bosworth, Missouri',25870,43);
INSERT INTO "django_geo_db_city" VALUES(21197,'Braymer','Braymer, Missouri',25871,43);
INSERT INTO "django_geo_db_city" VALUES(21198,'Breckenridge','Breckenridge, Missouri',25872,43);
INSERT INTO "django_geo_db_city" VALUES(21199,'Brookfield','Brookfield, Missouri',25873,43);
INSERT INTO "django_geo_db_city" VALUES(21200,'Browning','Browning, Missouri',25875,43);
INSERT INTO "django_geo_db_city" VALUES(21201,'Bucklin','Bucklin, Missouri',25876,43);
INSERT INTO "django_geo_db_city" VALUES(21202,'Cainsville','Cainsville, Missouri',25877,43);
INSERT INTO "django_geo_db_city" VALUES(21203,'Carrollton','Carrollton, Missouri',25878,43);
INSERT INTO "django_geo_db_city" VALUES(21204,'Chula','Chula, Missouri',25879,43);
INSERT INTO "django_geo_db_city" VALUES(21205,'Coffey','Coffey, Missouri',25880,43);
INSERT INTO "django_geo_db_city" VALUES(21206,'Cowgill','Cowgill, Missouri',25881,43);
INSERT INTO "django_geo_db_city" VALUES(21207,'Dawn','Dawn, Missouri',25882,43);
INSERT INTO "django_geo_db_city" VALUES(21208,'De Witt','De Witt, Missouri',25883,43);
INSERT INTO "django_geo_db_city" VALUES(21209,'Gallatin','Gallatin, Missouri',25884,43);
INSERT INTO "django_geo_db_city" VALUES(21210,'Galt','Galt, Missouri',25885,43);
INSERT INTO "django_geo_db_city" VALUES(21211,'Gilman City','Gilman City, Missouri',25886,43);
INSERT INTO "django_geo_db_city" VALUES(21212,'Hale','Hale, Missouri',25887,43);
INSERT INTO "django_geo_db_city" VALUES(21213,'Hamilton','Hamilton, Missouri',25888,43);
INSERT INTO "django_geo_db_city" VALUES(21214,'Harris','Harris, Missouri',25889,43);
INSERT INTO "django_geo_db_city" VALUES(21215,'Humphreys','Humphreys, Missouri',25890,43);
INSERT INTO "django_geo_db_city" VALUES(21216,'Jameson','Jameson, Missouri',25891,43);
INSERT INTO "django_geo_db_city" VALUES(21217,'Jamesport','Jamesport, Missouri',25892,43);
INSERT INTO "django_geo_db_city" VALUES(21218,'Kidder','Kidder, Missouri',25893,43);
INSERT INTO "django_geo_db_city" VALUES(21219,'Kingston','Kingston, Missouri',25894,43);
INSERT INTO "django_geo_db_city" VALUES(21220,'Laclede','Laclede, Missouri',25895,43);
INSERT INTO "django_geo_db_city" VALUES(21221,'Laredo','Laredo, Missouri',25896,43);
INSERT INTO "django_geo_db_city" VALUES(21222,'Linneus','Linneus, Missouri',25897,43);
INSERT INTO "django_geo_db_city" VALUES(21223,'Lock Springs','Lock Springs, Missouri',25898,43);
INSERT INTO "django_geo_db_city" VALUES(21224,'Lucerne','Lucerne, Missouri',25899,43);
INSERT INTO "django_geo_db_city" VALUES(21225,'Ludlow','Ludlow, Missouri',25900,43);
INSERT INTO "django_geo_db_city" VALUES(21226,'McFall','McFall, Missouri',25901,43);
INSERT INTO "django_geo_db_city" VALUES(21227,'Marceline','Marceline, Missouri',25902,43);
INSERT INTO "django_geo_db_city" VALUES(21228,'Meadville','Meadville, Missouri',25903,43);
INSERT INTO "django_geo_db_city" VALUES(21229,'Mendon','Mendon, Missouri',25904,43);
INSERT INTO "django_geo_db_city" VALUES(21230,'Mercer','Mercer, Missouri',25905,43);
INSERT INTO "django_geo_db_city" VALUES(21231,'Mooresville','Mooresville, Missouri',25906,43);
INSERT INTO "django_geo_db_city" VALUES(21232,'Mount Moriah','Mount Moriah, Missouri',25907,43);
INSERT INTO "django_geo_db_city" VALUES(21233,'Newtown','Newtown, Missouri',25908,43);
INSERT INTO "django_geo_db_city" VALUES(21234,'Norborne','Norborne, Missouri',25909,43);
INSERT INTO "django_geo_db_city" VALUES(21235,'Pattonsburg','Pattonsburg, Missouri',25910,43);
INSERT INTO "django_geo_db_city" VALUES(21236,'Polo','Polo, Missouri',25911,43);
INSERT INTO "django_geo_db_city" VALUES(21237,'Powersville','Powersville, Missouri',25912,43);
INSERT INTO "django_geo_db_city" VALUES(21238,'Princeton','Princeton, Missouri',25913,43);
INSERT INTO "django_geo_db_city" VALUES(21239,'Purdin','Purdin, Missouri',25914,43);
INSERT INTO "django_geo_db_city" VALUES(21240,'Rothville','Rothville, Missouri',25915,43);
INSERT INTO "django_geo_db_city" VALUES(21241,'Spickard','Spickard, Missouri',25917,43);
INSERT INTO "django_geo_db_city" VALUES(21242,'Stet','Stet, Missouri',25918,43);
INSERT INTO "django_geo_db_city" VALUES(21243,'Sumner','Sumner, Missouri',25919,43);
INSERT INTO "django_geo_db_city" VALUES(21244,'Tina','Tina, Missouri',25920,43);
INSERT INTO "django_geo_db_city" VALUES(21245,'Trenton','Trenton, Missouri',25921,43);
INSERT INTO "django_geo_db_city" VALUES(21246,'Utica','Utica, Missouri',25922,43);
INSERT INTO "django_geo_db_city" VALUES(21247,'Wakenda','Wakenda, Missouri',25923,43);
INSERT INTO "django_geo_db_city" VALUES(21248,'Wheeling','Wheeling, Missouri',25924,43);
INSERT INTO "django_geo_db_city" VALUES(21249,'Winston','Winston, Missouri',25925,43);
INSERT INTO "django_geo_db_city" VALUES(21250,'Harrisonville','Harrisonville, Missouri',25926,43);
INSERT INTO "django_geo_db_city" VALUES(21251,'Adrian','Adrian, Missouri',25927,43);
INSERT INTO "django_geo_db_city" VALUES(21252,'Amoret','Amoret, Missouri',25928,43);
INSERT INTO "django_geo_db_city" VALUES(21253,'Amsterdam','Amsterdam, Missouri',25929,43);
INSERT INTO "django_geo_db_city" VALUES(21254,'Appleton City','Appleton City, Missouri',25930,43);
INSERT INTO "django_geo_db_city" VALUES(21255,'Archie','Archie, Missouri',25931,43);
INSERT INTO "django_geo_db_city" VALUES(21256,'Blairstown','Blairstown, Missouri',25932,43);
INSERT INTO "django_geo_db_city" VALUES(21257,'Bronaugh','Bronaugh, Missouri',25933,43);
INSERT INTO "django_geo_db_city" VALUES(21258,'Butler','Butler, Missouri',25934,43);
INSERT INTO "django_geo_db_city" VALUES(21259,'Chilhowee','Chilhowee, Missouri',25935,43);
INSERT INTO "django_geo_db_city" VALUES(21260,'Cleveland','Cleveland, Missouri',25936,43);
INSERT INTO "django_geo_db_city" VALUES(21261,'Clinton','Clinton, Missouri',25937,43);
INSERT INTO "django_geo_db_city" VALUES(21262,'Collins','Collins, Missouri',25938,43);
INSERT INTO "django_geo_db_city" VALUES(21263,'Creighton','Creighton, Missouri',25939,43);
INSERT INTO "django_geo_db_city" VALUES(21264,'Deepwater','Deepwater, Missouri',25940,43);
INSERT INTO "django_geo_db_city" VALUES(21265,'Deerfield','Deerfield, Missouri',25941,43);
INSERT INTO "django_geo_db_city" VALUES(21266,'Drexel','Drexel, Missouri',25942,43);
INSERT INTO "django_geo_db_city" VALUES(21267,'East Lynne','East Lynne, Missouri',25943,43);
INSERT INTO "django_geo_db_city" VALUES(21268,'El Dorado Springs','El Dorado Springs, Missouri',25944,43);
INSERT INTO "django_geo_db_city" VALUES(21269,'Foster','Foster, Missouri',25945,43);
INSERT INTO "django_geo_db_city" VALUES(21270,'Freeman','Freeman, Missouri',25946,43);
INSERT INTO "django_geo_db_city" VALUES(21271,'Garden City','Garden City, Missouri',25947,43);
INSERT INTO "django_geo_db_city" VALUES(21272,'Golden City','Golden City, Missouri',25948,43);
INSERT INTO "django_geo_db_city" VALUES(21273,'Harwood','Harwood, Missouri',25949,43);
INSERT INTO "django_geo_db_city" VALUES(21274,'Horton','Horton, Missouri',25950,43);
INSERT INTO "django_geo_db_city" VALUES(21275,'Hume','Hume, Missouri',25951,43);
INSERT INTO "django_geo_db_city" VALUES(21276,'Jasper','Jasper, Missouri',25952,43);
INSERT INTO "django_geo_db_city" VALUES(21277,'Jerico Springs','Jerico Springs, Missouri',25953,43);
INSERT INTO "django_geo_db_city" VALUES(21278,'Lamar','Lamar, Missouri',25954,43);
INSERT INTO "django_geo_db_city" VALUES(21279,'Leeton','Leeton, Missouri',25955,43);
INSERT INTO "django_geo_db_city" VALUES(21280,'Liberal','Liberal, Missouri',25956,43);
INSERT INTO "django_geo_db_city" VALUES(21281,'Lowry City','Lowry City, Missouri',25957,43);
INSERT INTO "django_geo_db_city" VALUES(21282,'Metz','Metz, Missouri',25958,43);
INSERT INTO "django_geo_db_city" VALUES(21283,'Milford','Milford, Missouri',25959,43);
INSERT INTO "django_geo_db_city" VALUES(21284,'Milo','Milo, Missouri',25960,43);
INSERT INTO "django_geo_db_city" VALUES(21285,'Mindenmines','Mindenmines, Missouri',25961,43);
INSERT INTO "django_geo_db_city" VALUES(21286,'Montrose','Montrose, Missouri',25962,43);
INSERT INTO "django_geo_db_city" VALUES(21287,'Moundville','Moundville, Missouri',25963,43);
INSERT INTO "django_geo_db_city" VALUES(21288,'Nevada','Nevada, Missouri',25964,43);
INSERT INTO "django_geo_db_city" VALUES(21289,'Osceola','Osceola, Missouri',25965,43);
INSERT INTO "django_geo_db_city" VALUES(21290,'Passaic','Passaic, Missouri',25966,43);
INSERT INTO "django_geo_db_city" VALUES(21291,'Richards','Richards, Missouri',25967,43);
INSERT INTO "django_geo_db_city" VALUES(21292,'Rich Hill','Rich Hill, Missouri',25968,43);
INSERT INTO "django_geo_db_city" VALUES(21293,'Rockville','Rockville, Missouri',25969,43);
INSERT INTO "django_geo_db_city" VALUES(21294,'Roscoe','Roscoe, Missouri',25970,43);
INSERT INTO "django_geo_db_city" VALUES(21295,'Schell City','Schell City, Missouri',25971,43);
INSERT INTO "django_geo_db_city" VALUES(21296,'Sheldon','Sheldon, Missouri',25972,43);
INSERT INTO "django_geo_db_city" VALUES(21297,'Urich','Urich, Missouri',25973,43);
INSERT INTO "django_geo_db_city" VALUES(21298,'Vista','Vista, Missouri',25974,43);
INSERT INTO "django_geo_db_city" VALUES(21299,'Walker','Walker, Missouri',25975,43);
INSERT INTO "django_geo_db_city" VALUES(21300,'Joplin','Joplin, Missouri',25976,43);
INSERT INTO "django_geo_db_city" VALUES(21301,'Goodman','Goodman, Missouri',25979,43);
INSERT INTO "django_geo_db_city" VALUES(21302,'Alba','Alba, Missouri',25980,43);
INSERT INTO "django_geo_db_city" VALUES(21303,'Anderson','Anderson, Missouri',25981,43);
INSERT INTO "django_geo_db_city" VALUES(21304,'Asbury','Asbury, Missouri',25982,43);
INSERT INTO "django_geo_db_city" VALUES(21305,'Avilla','Avilla, Missouri',25983,43);
INSERT INTO "django_geo_db_city" VALUES(21306,'Carl Junction','Carl Junction, Missouri',25984,43);
INSERT INTO "django_geo_db_city" VALUES(21307,'Carterville','Carterville, Missouri',25985,43);
INSERT INTO "django_geo_db_city" VALUES(21308,'Carthage','Carthage, Missouri',25986,43);
INSERT INTO "django_geo_db_city" VALUES(21309,'Diamond','Diamond, Missouri',25987,43);
INSERT INTO "django_geo_db_city" VALUES(21310,'Duenweg','Duenweg, Missouri',25988,43);
INSERT INTO "django_geo_db_city" VALUES(21311,'Granby','Granby, Missouri',25991,43);
INSERT INTO "django_geo_db_city" VALUES(21312,'Lanagan','Lanagan, Missouri',25992,43);
INSERT INTO "django_geo_db_city" VALUES(21313,'La Russell','La Russell, Missouri',25993,43);
INSERT INTO "django_geo_db_city" VALUES(21314,'Neck City','Neck City, Missouri',25994,43);
INSERT INTO "django_geo_db_city" VALUES(21315,'Neosho','Neosho, Missouri',25995,43);
INSERT INTO "django_geo_db_city" VALUES(21316,'Newtonia','Newtonia, Missouri',25996,43);
INSERT INTO "django_geo_db_city" VALUES(21317,'Noel','Noel, Missouri',25997,43);
INSERT INTO "django_geo_db_city" VALUES(21318,'Oronogo','Oronogo, Missouri',25998,43);
INSERT INTO "django_geo_db_city" VALUES(21319,'Pineville','Pineville, Missouri',25999,43);
INSERT INTO "django_geo_db_city" VALUES(21320,'Purcell','Purcell, Missouri',26000,43);
INSERT INTO "django_geo_db_city" VALUES(21321,'Racine','Racine, Missouri',26001,43);
INSERT INTO "django_geo_db_city" VALUES(21322,'Reeds','Reeds, Missouri',26002,43);
INSERT INTO "django_geo_db_city" VALUES(21323,'Rocky Comfort','Rocky Comfort, Missouri',26003,43);
INSERT INTO "django_geo_db_city" VALUES(21324,'Sarcoxie','Sarcoxie, Missouri',26004,43);
INSERT INTO "django_geo_db_city" VALUES(21325,'South West City','South West City, Missouri',26005,43);
INSERT INTO "django_geo_db_city" VALUES(21326,'Saginaw','Saginaw, Missouri',26006,43);
INSERT INTO "django_geo_db_city" VALUES(21327,'Seneca','Seneca, Missouri',26007,43);
INSERT INTO "django_geo_db_city" VALUES(21328,'Stark City','Stark City, Missouri',26008,43);
INSERT INTO "django_geo_db_city" VALUES(21329,'Stella','Stella, Missouri',26009,43);
INSERT INTO "django_geo_db_city" VALUES(21330,'Tiff City','Tiff City, Missouri',26010,43);
INSERT INTO "django_geo_db_city" VALUES(21331,'Waco','Waco, Missouri',25977,43);
INSERT INTO "django_geo_db_city" VALUES(21332,'Webb City','Webb City, Missouri',26011,43);
INSERT INTO "django_geo_db_city" VALUES(21333,'Wentworth','Wentworth, Missouri',26012,43);
INSERT INTO "django_geo_db_city" VALUES(21334,'Wheaton','Wheaton, Missouri',26013,43);
INSERT INTO "django_geo_db_city" VALUES(21335,'Argyle','Argyle, Missouri',26015,43);
INSERT INTO "django_geo_db_city" VALUES(21336,'Ashland','Ashland, Missouri',26016,43);
INSERT INTO "django_geo_db_city" VALUES(21337,'Barnett','Barnett, Missouri',26017,43);
INSERT INTO "django_geo_db_city" VALUES(21338,'Belle','Belle, Missouri',26018,43);
INSERT INTO "django_geo_db_city" VALUES(21339,'Bland','Bland, Missouri',26019,43);
INSERT INTO "django_geo_db_city" VALUES(21340,'Bonnots Mill','Bonnots Mill, Missouri',26020,43);
INSERT INTO "django_geo_db_city" VALUES(21341,'Brumley','Brumley, Missouri',26021,43);
INSERT INTO "django_geo_db_city" VALUES(21342,'California','California, Missouri',26022,43);
INSERT INTO "django_geo_db_city" VALUES(21343,'Camdenton','Camdenton, Missouri',26023,43);
INSERT INTO "django_geo_db_city" VALUES(21344,'Cedar City','Cedar City, Missouri',26024,43);
INSERT INTO "django_geo_db_city" VALUES(21345,'Centertown','Centertown, Missouri',26025,43);
INSERT INTO "django_geo_db_city" VALUES(21346,'Chamois','Chamois, Missouri',26026,43);
INSERT INTO "django_geo_db_city" VALUES(21347,'Clarksburg','Clarksburg, Missouri',26027,43);
INSERT INTO "django_geo_db_city" VALUES(21348,'Eldon','Eldon, Missouri',26028,43);
INSERT INTO "django_geo_db_city" VALUES(21349,'Etterville','Etterville, Missouri',26029,43);
INSERT INTO "django_geo_db_city" VALUES(21350,'Eugene','Eugene, Missouri',26030,43);
INSERT INTO "django_geo_db_city" VALUES(21351,'Fortuna','Fortuna, Missouri',26031,43);
INSERT INTO "django_geo_db_city" VALUES(21352,'Freeburg','Freeburg, Missouri',26032,43);
INSERT INTO "django_geo_db_city" VALUES(21353,'Gasconade','Gasconade, Missouri',26033,43);
INSERT INTO "django_geo_db_city" VALUES(21354,'Gravois Mills','Gravois Mills, Missouri',26034,43);
INSERT INTO "django_geo_db_city" VALUES(21355,'Laurie','Laurie, Missouri',26035,43);
INSERT INTO "django_geo_db_city" VALUES(21356,'Hartsburg','Hartsburg, Missouri',26036,43);
INSERT INTO "django_geo_db_city" VALUES(21357,'Henley','Henley, Missouri',26037,43);
INSERT INTO "django_geo_db_city" VALUES(21358,'Hermann','Hermann, Missouri',26038,43);
INSERT INTO "django_geo_db_city" VALUES(21359,'High Point','High Point, Missouri',26039,43);
INSERT INTO "django_geo_db_city" VALUES(21360,'Holts Summit','Holts Summit, Missouri',26040,43);
INSERT INTO "django_geo_db_city" VALUES(21361,'Jamestown','Jamestown, Missouri',26041,43);
INSERT INTO "django_geo_db_city" VALUES(21362,'Kaiser','Kaiser, Missouri',26042,43);
INSERT INTO "django_geo_db_city" VALUES(21363,'Koeltztown','Koeltztown, Missouri',26043,43);
INSERT INTO "django_geo_db_city" VALUES(21364,'Lake Ozark','Lake Ozark, Missouri',26044,43);
INSERT INTO "django_geo_db_city" VALUES(21365,'Latham','Latham, Missouri',26045,43);
INSERT INTO "django_geo_db_city" VALUES(21366,'Linn','Linn, Missouri',26046,43);
INSERT INTO "django_geo_db_city" VALUES(21367,'Linn Creek','Linn Creek, Missouri',26047,43);
INSERT INTO "django_geo_db_city" VALUES(21368,'Lohman','Lohman, Missouri',26048,43);
INSERT INTO "django_geo_db_city" VALUES(21369,'Loose Creek','Loose Creek, Missouri',26049,43);
INSERT INTO "django_geo_db_city" VALUES(21370,'McGirk','McGirk, Missouri',26039,43);
INSERT INTO "django_geo_db_city" VALUES(21371,'Meta','Meta, Missouri',26050,43);
INSERT INTO "django_geo_db_city" VALUES(21372,'Mokane','Mokane, Missouri',26051,43);
INSERT INTO "django_geo_db_city" VALUES(21373,'Morrison','Morrison, Missouri',26052,43);
INSERT INTO "django_geo_db_city" VALUES(21374,'Mount Sterling','Mount Sterling, Missouri',26053,43);
INSERT INTO "django_geo_db_city" VALUES(21375,'New Bloomfield','New Bloomfield, Missouri',26054,43);
INSERT INTO "django_geo_db_city" VALUES(21376,'Olean','Olean, Missouri',26055,43);
INSERT INTO "django_geo_db_city" VALUES(21377,'Osage Beach','Osage Beach, Missouri',26056,43);
INSERT INTO "django_geo_db_city" VALUES(21378,'Owensville','Owensville, Missouri',26057,43);
INSERT INTO "django_geo_db_city" VALUES(21379,'Portland','Portland, Missouri',26058,43);
INSERT INTO "django_geo_db_city" VALUES(21380,'Prairie Home','Prairie Home, Missouri',26059,43);
INSERT INTO "django_geo_db_city" VALUES(21381,'Rhineland','Rhineland, Missouri',26060,43);
INSERT INTO "django_geo_db_city" VALUES(21382,'Rocky Mount','Rocky Mount, Missouri',26061,43);
INSERT INTO "django_geo_db_city" VALUES(21383,'Russellville','Russellville, Missouri',26062,43);
INSERT INTO "django_geo_db_city" VALUES(21384,'Saint Elizabeth','Saint Elizabeth, Missouri',26063,43);
INSERT INTO "django_geo_db_city" VALUES(21385,'Saint Thomas','Saint Thomas, Missouri',26064,43);
INSERT INTO "django_geo_db_city" VALUES(21386,'Steedman','Steedman, Missouri',26065,43);
INSERT INTO "django_geo_db_city" VALUES(21387,'Stover','Stover, Missouri',26066,43);
INSERT INTO "django_geo_db_city" VALUES(21388,'Sunrise Beach','Sunrise Beach, Missouri',26067,43);
INSERT INTO "django_geo_db_city" VALUES(21389,'Tebbetts','Tebbetts, Missouri',26068,43);
INSERT INTO "django_geo_db_city" VALUES(21390,'Tipton','Tipton, Missouri',26069,43);
INSERT INTO "django_geo_db_city" VALUES(21391,'Tuscumbia','Tuscumbia, Missouri',26070,43);
INSERT INTO "django_geo_db_city" VALUES(21392,'Ulman','Ulman, Missouri',26071,43);
INSERT INTO "django_geo_db_city" VALUES(21393,'Versailles','Versailles, Missouri',26072,43);
INSERT INTO "django_geo_db_city" VALUES(21394,'Westphalia','Westphalia, Missouri',26073,43);
INSERT INTO "django_geo_db_city" VALUES(21395,'Jefferson City','Jefferson City, Missouri',26074,43);
INSERT INTO "django_geo_db_city" VALUES(21396,'Columbia','Columbia, Missouri',26077,43);
INSERT INTO "django_geo_db_city" VALUES(21397,'Armstrong','Armstrong, Missouri',26084,43);
INSERT INTO "django_geo_db_city" VALUES(21398,'Auxvasse','Auxvasse, Missouri',26085,43);
INSERT INTO "django_geo_db_city" VALUES(21399,'Benton City','Benton City, Missouri',26086,43);
INSERT INTO "django_geo_db_city" VALUES(21400,'Boonville','Boonville, Missouri',26087,43);
INSERT INTO "django_geo_db_city" VALUES(21401,'Brunswick','Brunswick, Missouri',26088,43);
INSERT INTO "django_geo_db_city" VALUES(21402,'Bunceton','Bunceton, Missouri',26089,43);
INSERT INTO "django_geo_db_city" VALUES(21403,'Cairo','Cairo, Missouri',26090,43);
INSERT INTO "django_geo_db_city" VALUES(21404,'Centralia','Centralia, Missouri',26091,43);
INSERT INTO "django_geo_db_city" VALUES(21405,'Clark','Clark, Missouri',26092,43);
INSERT INTO "django_geo_db_city" VALUES(21406,'Clifton Hill','Clifton Hill, Missouri',26093,43);
INSERT INTO "django_geo_db_city" VALUES(21407,'Dalton','Dalton, Missouri',26094,43);
INSERT INTO "django_geo_db_city" VALUES(21408,'Excello','Excello, Missouri',26095,43);
INSERT INTO "django_geo_db_city" VALUES(21409,'Fayette','Fayette, Missouri',26096,43);
INSERT INTO "django_geo_db_city" VALUES(21410,'Franklin','Franklin, Missouri',26097,43);
INSERT INTO "django_geo_db_city" VALUES(21411,'Fulton','Fulton, Missouri',26098,43);
INSERT INTO "django_geo_db_city" VALUES(21412,'Glasgow','Glasgow, Missouri',26099,43);
INSERT INTO "django_geo_db_city" VALUES(21413,'Hallsville','Hallsville, Missouri',26100,43);
INSERT INTO "django_geo_db_city" VALUES(21414,'Harrisburg','Harrisburg, Missouri',26101,43);
INSERT INTO "django_geo_db_city" VALUES(21415,'Higbee','Higbee, Missouri',26102,43);
INSERT INTO "django_geo_db_city" VALUES(21416,'Holliday','Holliday, Missouri',26103,43);
INSERT INTO "django_geo_db_city" VALUES(21417,'Huntsville','Huntsville, Missouri',26104,43);
INSERT INTO "django_geo_db_city" VALUES(21418,'Jacksonville','Jacksonville, Missouri',26105,43);
INSERT INTO "django_geo_db_city" VALUES(21419,'Keytesville','Keytesville, Missouri',26106,43);
INSERT INTO "django_geo_db_city" VALUES(21420,'Kingdom City','Kingdom City, Missouri',26107,43);
INSERT INTO "django_geo_db_city" VALUES(21421,'Madison','Madison, Missouri',26108,43);
INSERT INTO "django_geo_db_city" VALUES(21422,'Martinsburg','Martinsburg, Missouri',26109,43);
INSERT INTO "django_geo_db_city" VALUES(21423,'Mexico','Mexico, Missouri',26110,43);
INSERT INTO "django_geo_db_city" VALUES(21424,'Moberly','Moberly, Missouri',26111,43);
INSERT INTO "django_geo_db_city" VALUES(21425,'New Franklin','New Franklin, Missouri',26112,43);
INSERT INTO "django_geo_db_city" VALUES(21426,'Paris','Paris, Missouri',26113,43);
INSERT INTO "django_geo_db_city" VALUES(21427,'Pilot Grove','Pilot Grove, Missouri',26114,43);
INSERT INTO "django_geo_db_city" VALUES(21428,'Renick','Renick, Missouri',26115,43);
INSERT INTO "django_geo_db_city" VALUES(21429,'Rocheport','Rocheport, Missouri',26116,43);
INSERT INTO "django_geo_db_city" VALUES(21430,'Rush Hill','Rush Hill, Missouri',26117,43);
INSERT INTO "django_geo_db_city" VALUES(21431,'Salisbury','Salisbury, Missouri',26118,43);
INSERT INTO "django_geo_db_city" VALUES(21432,'Santa Fe','Santa Fe, Missouri',26119,43);
INSERT INTO "django_geo_db_city" VALUES(21433,'Stoutsville','Stoutsville, Missouri',26120,43);
INSERT INTO "django_geo_db_city" VALUES(21434,'Sturgeon','Sturgeon, Missouri',26121,43);
INSERT INTO "django_geo_db_city" VALUES(21435,'Thompson','Thompson, Missouri',26122,43);
INSERT INTO "django_geo_db_city" VALUES(21436,'Triplett','Triplett, Missouri',26123,43);
INSERT INTO "django_geo_db_city" VALUES(21437,'Wooldridge','Wooldridge, Missouri',26124,43);
INSERT INTO "django_geo_db_city" VALUES(21438,'Mid Missouri','Mid Missouri, Missouri',26081,43);
INSERT INTO "django_geo_db_city" VALUES(21439,'Sedalia','Sedalia, Missouri',26125,43);
INSERT INTO "django_geo_db_city" VALUES(21440,'Whiteman Air Force Base','Whiteman Air Force Base, Missouri',26127,43);
INSERT INTO "django_geo_db_city" VALUES(21441,'Arrow Rock','Arrow Rock, Missouri',26128,43);
INSERT INTO "django_geo_db_city" VALUES(21442,'Blackburn','Blackburn, Missouri',26129,43);
INSERT INTO "django_geo_db_city" VALUES(21443,'Blackwater','Blackwater, Missouri',26130,43);
INSERT INTO "django_geo_db_city" VALUES(21444,'Calhoun','Calhoun, Missouri',26131,43);
INSERT INTO "django_geo_db_city" VALUES(21445,'Climax Springs','Climax Springs, Missouri',26132,43);
INSERT INTO "django_geo_db_city" VALUES(21446,'Cole Camp','Cole Camp, Missouri',26133,43);
INSERT INTO "django_geo_db_city" VALUES(21447,'Edwards','Edwards, Missouri',26134,43);
INSERT INTO "django_geo_db_city" VALUES(21448,'Emma','Emma, Missouri',26135,43);
INSERT INTO "django_geo_db_city" VALUES(21449,'Florence','Florence, Missouri',26136,43);
INSERT INTO "django_geo_db_city" VALUES(21450,'Gilliam','Gilliam, Missouri',26137,43);
INSERT INTO "django_geo_db_city" VALUES(21451,'Green Ridge','Green Ridge, Missouri',26138,43);
INSERT INTO "django_geo_db_city" VALUES(21452,'Houstonia','Houstonia, Missouri',26139,43);
INSERT INTO "django_geo_db_city" VALUES(21453,'Hughesville','Hughesville, Missouri',26140,43);
INSERT INTO "django_geo_db_city" VALUES(21454,'Ionia','Ionia, Missouri',26141,43);
INSERT INTO "django_geo_db_city" VALUES(21455,'Knob Noster','Knob Noster, Missouri',26142,43);
INSERT INTO "django_geo_db_city" VALUES(21456,'La Monte','La Monte, Missouri',26143,43);
INSERT INTO "django_geo_db_city" VALUES(21457,'Lincoln','Lincoln, Missouri',26144,43);
INSERT INTO "django_geo_db_city" VALUES(21458,'Malta Bend','Malta Bend, Missouri',26145,43);
INSERT INTO "django_geo_db_city" VALUES(21459,'Marshall','Marshall, Missouri',26146,43);
INSERT INTO "django_geo_db_city" VALUES(21460,'Miami','Miami, Missouri',26147,43);
INSERT INTO "django_geo_db_city" VALUES(21461,'Mora','Mora, Missouri',26148,43);
INSERT INTO "django_geo_db_city" VALUES(21462,'Nelson','Nelson, Missouri',26149,43);
INSERT INTO "django_geo_db_city" VALUES(21463,'Otterville','Otterville, Missouri',26150,43);
INSERT INTO "django_geo_db_city" VALUES(21464,'Slater','Slater, Missouri',26151,43);
INSERT INTO "django_geo_db_city" VALUES(21465,'Smithton','Smithton, Missouri',26152,43);
INSERT INTO "django_geo_db_city" VALUES(21466,'Sweet Springs','Sweet Springs, Missouri',26153,43);
INSERT INTO "django_geo_db_city" VALUES(21467,'Syracuse','Syracuse, Missouri',26154,43);
INSERT INTO "django_geo_db_city" VALUES(21468,'Warsaw','Warsaw, Missouri',26155,43);
INSERT INTO "django_geo_db_city" VALUES(21469,'Windsor','Windsor, Missouri',26156,43);
INSERT INTO "django_geo_db_city" VALUES(21470,'Rolla','Rolla, Missouri',26157,43);
INSERT INTO "django_geo_db_city" VALUES(21471,'Cuba','Cuba, Missouri',26160,43);
INSERT INTO "django_geo_db_city" VALUES(21472,'Bendavis','Bendavis, Missouri',26161,43);
INSERT INTO "django_geo_db_city" VALUES(21473,'Beulah','Beulah, Missouri',26162,43);
INSERT INTO "django_geo_db_city" VALUES(21474,'Birch Tree','Birch Tree, Missouri',26163,43);
INSERT INTO "django_geo_db_city" VALUES(21475,'Bixby','Bixby, Missouri',26164,43);
INSERT INTO "django_geo_db_city" VALUES(21476,'Boss','Boss, Missouri',26165,43);
INSERT INTO "django_geo_db_city" VALUES(21477,'Bourbon','Bourbon, Missouri',26166,43);
INSERT INTO "django_geo_db_city" VALUES(21478,'Brinktown','Brinktown, Missouri',26167,43);
INSERT INTO "django_geo_db_city" VALUES(21479,'Bucyrus','Bucyrus, Missouri',26168,43);
INSERT INTO "django_geo_db_city" VALUES(21480,'Cherryville','Cherryville, Missouri',26169,43);
INSERT INTO "django_geo_db_city" VALUES(21481,'Cook Station','Cook Station, Missouri',26170,43);
INSERT INTO "django_geo_db_city" VALUES(21482,'Crocker','Crocker, Missouri',26171,43);
INSERT INTO "django_geo_db_city" VALUES(21483,'Davisville','Davisville, Missouri',26173,43);
INSERT INTO "django_geo_db_city" VALUES(21484,'Devils Elbow','Devils Elbow, Missouri',26174,43);
INSERT INTO "django_geo_db_city" VALUES(21485,'Dixon','Dixon, Missouri',26175,43);
INSERT INTO "django_geo_db_city" VALUES(21486,'Duke','Duke, Missouri',26176,43);
INSERT INTO "django_geo_db_city" VALUES(21487,'Edgar Springs','Edgar Springs, Missouri',26177,43);
INSERT INTO "django_geo_db_city" VALUES(21488,'Eldridge','Eldridge, Missouri',26178,43);
INSERT INTO "django_geo_db_city" VALUES(21489,'Elk Creek','Elk Creek, Missouri',26179,43);
INSERT INTO "django_geo_db_city" VALUES(21490,'Eminence','Eminence, Missouri',26180,43);
INSERT INTO "django_geo_db_city" VALUES(21491,'Eunice','Eunice, Missouri',26181,43);
INSERT INTO "django_geo_db_city" VALUES(21492,'Falcon','Falcon, Missouri',26182,43);
INSERT INTO "django_geo_db_city" VALUES(21493,'Fort Leonard Wood','Fort Leonard Wood, Missouri',26183,43);
INSERT INTO "django_geo_db_city" VALUES(21494,'Hartshorn','Hartshorn, Missouri',26184,43);
INSERT INTO "django_geo_db_city" VALUES(21495,'Houston','Houston, Missouri',26185,43);
INSERT INTO "django_geo_db_city" VALUES(21496,'Huggins','Huggins, Missouri',26186,43);
INSERT INTO "django_geo_db_city" VALUES(21497,'Iberia','Iberia, Missouri',26187,43);
INSERT INTO "django_geo_db_city" VALUES(21498,'Jadwin','Jadwin, Missouri',26189,43);
INSERT INTO "django_geo_db_city" VALUES(21499,'Jerome','Jerome, Missouri',26190,43);
INSERT INTO "django_geo_db_city" VALUES(21500,'Lake Spring','Lake Spring, Missouri',26192,43);
INSERT INTO "django_geo_db_city" VALUES(21501,'Laquey','Laquey, Missouri',26193,43);
INSERT INTO "django_geo_db_city" VALUES(21502,'Leasburg','Leasburg, Missouri',26194,43);
INSERT INTO "django_geo_db_city" VALUES(21503,'Lebanon','Lebanon, Missouri',26195,43);
INSERT INTO "django_geo_db_city" VALUES(21504,'Lecoma','Lecoma, Missouri',26196,43);
INSERT INTO "django_geo_db_city" VALUES(21505,'Lenox','Lenox, Missouri',26197,43);
INSERT INTO "django_geo_db_city" VALUES(21506,'Licking','Licking, Missouri',26198,43);
INSERT INTO "django_geo_db_city" VALUES(21507,'Lynchburg','Lynchburg, Missouri',26199,43);
INSERT INTO "django_geo_db_city" VALUES(21508,'Montier','Montier, Missouri',26200,43);
INSERT INTO "django_geo_db_city" VALUES(21509,'Mountain View','Mountain View, Missouri',26201,43);
INSERT INTO "django_geo_db_city" VALUES(21510,'Newburg','Newburg, Missouri',26202,43);
INSERT INTO "django_geo_db_city" VALUES(21511,'Plato','Plato, Missouri',26203,43);
INSERT INTO "django_geo_db_city" VALUES(21512,'Raymondville','Raymondville, Missouri',26204,43);
INSERT INTO "django_geo_db_city" VALUES(21513,'Richland','Richland, Missouri',26205,43);
INSERT INTO "django_geo_db_city" VALUES(21514,'Roby','Roby, Missouri',26206,43);
INSERT INTO "django_geo_db_city" VALUES(21515,'Saint James','Saint James, Missouri',26207,43);
INSERT INTO "django_geo_db_city" VALUES(21516,'Salem','Salem, Missouri',26208,43);
INSERT INTO "django_geo_db_city" VALUES(21517,'Solo','Solo, Missouri',26209,43);
INSERT INTO "django_geo_db_city" VALUES(21518,'Steelville','Steelville, Missouri',26210,43);
INSERT INTO "django_geo_db_city" VALUES(21519,'Viburnum','Viburnum, Missouri',26211,43);
INSERT INTO "django_geo_db_city" VALUES(21520,'Stoutland','Stoutland, Missouri',26212,43);
INSERT INTO "django_geo_db_city" VALUES(21521,'Success','Success, Missouri',26213,43);
INSERT INTO "django_geo_db_city" VALUES(21522,'Summersville','Summersville, Missouri',26214,43);
INSERT INTO "django_geo_db_city" VALUES(21523,'Swedeborg','Swedeborg, Missouri',26215,43);
INSERT INTO "django_geo_db_city" VALUES(21524,'Teresita','Teresita, Missouri',26200,43);
INSERT INTO "django_geo_db_city" VALUES(21525,'West Plains','West Plains, Missouri',26216,43);
INSERT INTO "django_geo_db_city" VALUES(21526,'Vichy','Vichy, Missouri',26217,43);
INSERT INTO "django_geo_db_city" VALUES(21527,'Vienna','Vienna, Missouri',26218,43);
INSERT INTO "django_geo_db_city" VALUES(21528,'Waynesville','Waynesville, Missouri',26219,43);
INSERT INTO "django_geo_db_city" VALUES(21529,'St. Robert','St. Robert, Missouri',26220,43);
INSERT INTO "django_geo_db_city" VALUES(21530,'Wesco','Wesco, Missouri',26221,43);
INSERT INTO "django_geo_db_city" VALUES(21531,'Winona','Winona, Missouri',26223,43);
INSERT INTO "django_geo_db_city" VALUES(21532,'Yukon','Yukon, Missouri',26224,43);
INSERT INTO "django_geo_db_city" VALUES(21533,'Long Lane','Long Lane, Missouri',26225,43);
INSERT INTO "django_geo_db_city" VALUES(21534,'Montreal','Montreal, Missouri',26226,43);
INSERT INTO "django_geo_db_city" VALUES(21535,'Aldrich','Aldrich, Missouri',26227,43);
INSERT INTO "django_geo_db_city" VALUES(21536,'Springfield','Springfield, Missouri',26228,43);
INSERT INTO "django_geo_db_city" VALUES(21537,'Arcola','Arcola, Missouri',26229,43);
INSERT INTO "django_geo_db_city" VALUES(21538,'Ash Grove','Ash Grove, Missouri',26230,43);
INSERT INTO "django_geo_db_city" VALUES(21539,'Aurora','Aurora, Missouri',26231,43);
INSERT INTO "django_geo_db_city" VALUES(21540,'Alton','Alton, Missouri',26232,43);
INSERT INTO "django_geo_db_city" VALUES(21541,'Caplinger Mills','Caplinger Mills, Missouri',26233,43);
INSERT INTO "django_geo_db_city" VALUES(21542,'Ava','Ava, Missouri',26234,43);
INSERT INTO "django_geo_db_city" VALUES(21543,'Bakersfield','Bakersfield, Missouri',26235,43);
INSERT INTO "django_geo_db_city" VALUES(21544,'Billings','Billings, Missouri',26236,43);
INSERT INTO "django_geo_db_city" VALUES(21545,'Blue Eye','Blue Eye, Missouri',26237,43);
INSERT INTO "django_geo_db_city" VALUES(21546,'Bois D Arc','Bois D Arc, Missouri',26238,43);
INSERT INTO "django_geo_db_city" VALUES(21547,'Bolivar','Bolivar, Missouri',26239,43);
INSERT INTO "django_geo_db_city" VALUES(21548,'Bradleyville','Bradleyville, Missouri',26240,43);
INSERT INTO "django_geo_db_city" VALUES(21549,'Branson','Branson, Missouri',26241,43);
INSERT INTO "django_geo_db_city" VALUES(21550,'Brighton','Brighton, Missouri',26243,43);
INSERT INTO "django_geo_db_city" VALUES(21551,'Brixey','Brixey, Missouri',26244,43);
INSERT INTO "django_geo_db_city" VALUES(21552,'Brookline Station','Brookline Station, Missouri',26245,43);
INSERT INTO "django_geo_db_city" VALUES(21553,'Bruner','Bruner, Missouri',26246,43);
INSERT INTO "django_geo_db_city" VALUES(21554,'Buffalo','Buffalo, Missouri',26247,43);
INSERT INTO "django_geo_db_city" VALUES(21555,'Butterfield','Butterfield, Missouri',26248,43);
INSERT INTO "django_geo_db_city" VALUES(21556,'Cape Fair','Cape Fair, Missouri',26249,43);
INSERT INTO "django_geo_db_city" VALUES(21557,'Cassville','Cassville, Missouri',26250,43);
INSERT INTO "django_geo_db_city" VALUES(21558,'Caulfield','Caulfield, Missouri',26251,43);
INSERT INTO "django_geo_db_city" VALUES(21559,'Cedarcreek','Cedarcreek, Missouri',26252,43);
INSERT INTO "django_geo_db_city" VALUES(21560,'Chadwick','Chadwick, Missouri',26253,43);
INSERT INTO "django_geo_db_city" VALUES(21561,'Chestnutridge','Chestnutridge, Missouri',26254,43);
INSERT INTO "django_geo_db_city" VALUES(21562,'Clever','Clever, Missouri',26255,43);
INSERT INTO "django_geo_db_city" VALUES(21563,'Conway','Conway, Missouri',26256,43);
INSERT INTO "django_geo_db_city" VALUES(21564,'Crane','Crane, Missouri',26257,43);
INSERT INTO "django_geo_db_city" VALUES(21565,'Cross Timbers','Cross Timbers, Missouri',26258,43);
INSERT INTO "django_geo_db_city" VALUES(21566,'Dadeville','Dadeville, Missouri',26259,43);
INSERT INTO "django_geo_db_city" VALUES(21567,'Diggins','Diggins, Missouri',26260,43);
INSERT INTO "django_geo_db_city" VALUES(21568,'Dora','Dora, Missouri',26261,43);
INSERT INTO "django_geo_db_city" VALUES(21569,'Drury','Drury, Missouri',26262,43);
INSERT INTO "django_geo_db_city" VALUES(21570,'Dunnegan','Dunnegan, Missouri',26263,43);
INSERT INTO "django_geo_db_city" VALUES(21571,'Eagle Rock','Eagle Rock, Missouri',26264,43);
INSERT INTO "django_geo_db_city" VALUES(21572,'Elkland','Elkland, Missouri',26265,43);
INSERT INTO "django_geo_db_city" VALUES(21573,'Eudora','Eudora, Missouri',26266,43);
INSERT INTO "django_geo_db_city" VALUES(21574,'Everton','Everton, Missouri',26267,43);
INSERT INTO "django_geo_db_city" VALUES(21575,'Exeter','Exeter, Missouri',26268,43);
INSERT INTO "django_geo_db_city" VALUES(21576,'Fair Grove','Fair Grove, Missouri',26269,43);
INSERT INTO "django_geo_db_city" VALUES(21577,'Fair Play','Fair Play, Missouri',26270,43);
INSERT INTO "django_geo_db_city" VALUES(21578,'Flemington','Flemington, Missouri',26271,43);
INSERT INTO "django_geo_db_city" VALUES(21579,'Fordland','Fordland, Missouri',26272,43);
INSERT INTO "django_geo_db_city" VALUES(21580,'Forsyth','Forsyth, Missouri',26273,43);
INSERT INTO "django_geo_db_city" VALUES(21581,'Freistatt','Freistatt, Missouri',26274,43);
INSERT INTO "django_geo_db_city" VALUES(21582,'Gainesville','Gainesville, Missouri',26275,43);
INSERT INTO "django_geo_db_city" VALUES(21583,'Galena','Galena, Missouri',26276,43);
INSERT INTO "django_geo_db_city" VALUES(21584,'Garrison','Garrison, Missouri',26277,43);
INSERT INTO "django_geo_db_city" VALUES(21585,'Golden','Golden, Missouri',26278,43);
INSERT INTO "django_geo_db_city" VALUES(21586,'Goodson','Goodson, Missouri',26279,43);
INSERT INTO "django_geo_db_city" VALUES(21587,'Graff','Graff, Missouri',26280,43);
INSERT INTO "django_geo_db_city" VALUES(21588,'Greenfield','Greenfield, Missouri',26281,43);
INSERT INTO "django_geo_db_city" VALUES(21589,'Grovespring','Grovespring, Missouri',26282,43);
INSERT INTO "django_geo_db_city" VALUES(21590,'Half Way','Half Way, Missouri',26283,43);
INSERT INTO "django_geo_db_city" VALUES(21591,'Halltown','Halltown, Missouri',26284,43);
INSERT INTO "django_geo_db_city" VALUES(21592,'Hardenville','Hardenville, Missouri',26285,43);
INSERT INTO "django_geo_db_city" VALUES(21593,'Hartville','Hartville, Missouri',26286,43);
INSERT INTO "django_geo_db_city" VALUES(21594,'Hermitage','Hermitage, Missouri',26287,43);
INSERT INTO "django_geo_db_city" VALUES(21595,'Highlandville','Highlandville, Missouri',26288,43);
INSERT INTO "django_geo_db_city" VALUES(21596,'Hollister','Hollister, Missouri',26289,43);
INSERT INTO "django_geo_db_city" VALUES(21597,'Humansville','Humansville, Missouri',26291,43);
INSERT INTO "django_geo_db_city" VALUES(21598,'Hurley','Hurley, Missouri',26292,43);
INSERT INTO "django_geo_db_city" VALUES(21599,'Isabella','Isabella, Missouri',26293,43);
INSERT INTO "django_geo_db_city" VALUES(21600,'Kirbyville','Kirbyville, Missouri',26294,43);
INSERT INTO "django_geo_db_city" VALUES(21601,'Kissee Mills','Kissee Mills, Missouri',26295,43);
INSERT INTO "django_geo_db_city" VALUES(21602,'Lampe','Lampe, Missouri',26296,43);
INSERT INTO "django_geo_db_city" VALUES(21603,'Lockwood','Lockwood, Missouri',26297,43);
INSERT INTO "django_geo_db_city" VALUES(21604,'Morris','Morris, Missouri',26298,43);
INSERT INTO "django_geo_db_city" VALUES(21605,'Louisburg','Louisburg, Missouri',26299,43);
INSERT INTO "django_geo_db_city" VALUES(21606,'Kimberling City','Kimberling City, Missouri',26300,43);
INSERT INTO "django_geo_db_city" VALUES(21607,'Brandsville','Brandsville, Missouri',26301,43);
INSERT INTO "django_geo_db_city" VALUES(21608,'Cabool','Cabool, Missouri',26302,43);
INSERT INTO "django_geo_db_city" VALUES(21609,'Couch','Couch, Missouri',26303,43);
INSERT INTO "django_geo_db_city" VALUES(21610,'Koshkonong','Koshkonong, Missouri',26304,43);
INSERT INTO "django_geo_db_city" VALUES(21611,'McClurg','McClurg, Missouri',26305,43);
INSERT INTO "django_geo_db_city" VALUES(21612,'Macomb','Macomb, Missouri',26306,43);
INSERT INTO "django_geo_db_city" VALUES(21613,'Mansfield','Mansfield, Missouri',26307,43);
INSERT INTO "django_geo_db_city" VALUES(21614,'Marionville','Marionville, Missouri',26308,43);
INSERT INTO "django_geo_db_city" VALUES(21615,'Marshfield','Marshfield, Missouri',26309,43);
INSERT INTO "django_geo_db_city" VALUES(21616,'Miller','Miller, Missouri',26310,43);
INSERT INTO "django_geo_db_city" VALUES(21617,'Monett','Monett, Missouri',26311,43);
INSERT INTO "django_geo_db_city" VALUES(21618,'Morrisville','Morrisville, Missouri',26312,43);
INSERT INTO "django_geo_db_city" VALUES(21619,'Mountain Grove','Mountain Grove, Missouri',26313,43);
INSERT INTO "django_geo_db_city" VALUES(21620,'Mount Vernon','Mount Vernon, Missouri',26314,43);
INSERT INTO "django_geo_db_city" VALUES(21621,'Niangua','Niangua, Missouri',26315,43);
INSERT INTO "django_geo_db_city" VALUES(21622,'Nixa','Nixa, Missouri',26316,43);
INSERT INTO "django_geo_db_city" VALUES(21623,'Noble','Noble, Missouri',26317,43);
INSERT INTO "django_geo_db_city" VALUES(21624,'Norwood','Norwood, Missouri',26318,43);
INSERT INTO "django_geo_db_city" VALUES(21625,'Oldfield','Oldfield, Missouri',26319,43);
INSERT INTO "django_geo_db_city" VALUES(21626,'Ozark','Ozark, Missouri',26320,43);
INSERT INTO "django_geo_db_city" VALUES(21627,'Phillipsburg','Phillipsburg, Missouri',26321,43);
INSERT INTO "django_geo_db_city" VALUES(21628,'Pierce City','Pierce City, Missouri',26322,43);
INSERT INTO "django_geo_db_city" VALUES(21629,'Pittsburg','Pittsburg, Missouri',26323,43);
INSERT INTO "django_geo_db_city" VALUES(21630,'Pleasant Hope','Pleasant Hope, Missouri',26324,43);
INSERT INTO "django_geo_db_city" VALUES(21631,'Point Lookout','Point Lookout, Missouri',26325,43);
INSERT INTO "django_geo_db_city" VALUES(21632,'Ponce De Leon','Ponce De Leon, Missouri',26327,43);
INSERT INTO "django_geo_db_city" VALUES(21633,'Pontiac','Pontiac, Missouri',26328,43);
INSERT INTO "django_geo_db_city" VALUES(21634,'Powell','Powell, Missouri',26329,43);
INSERT INTO "django_geo_db_city" VALUES(21635,'Powersite','Powersite, Missouri',26330,43);
INSERT INTO "django_geo_db_city" VALUES(21636,'Preston','Preston, Missouri',26331,43);
INSERT INTO "django_geo_db_city" VALUES(21637,'Protem','Protem, Arkansas',26332,4);
INSERT INTO "django_geo_db_city" VALUES(21638,'Purdy','Purdy, Missouri',26333,43);
INSERT INTO "django_geo_db_city" VALUES(21639,'Quincy','Quincy, Missouri',26334,43);
INSERT INTO "django_geo_db_city" VALUES(21640,'Reeds Spring','Reeds Spring, Missouri',26335,43);
INSERT INTO "django_geo_db_city" VALUES(21641,'Republic','Republic, Missouri',26336,43);
INSERT INTO "django_geo_db_city" VALUES(21642,'Ridgedale','Ridgedale, Missouri',26337,43);
INSERT INTO "django_geo_db_city" VALUES(21643,'Rockaway Beach','Rockaway Beach, Missouri',26338,43);
INSERT INTO "django_geo_db_city" VALUES(21644,'Rockbridge','Rockbridge, Missouri',26285,43);
INSERT INTO "django_geo_db_city" VALUES(21645,'Rogersville','Rogersville, Missouri',26339,43);
INSERT INTO "django_geo_db_city" VALUES(21646,'Rueter','Rueter, Missouri',26340,43);
INSERT INTO "django_geo_db_city" VALUES(21647,'Seligman','Seligman, Missouri',26341,43);
INSERT INTO "django_geo_db_city" VALUES(21648,'Seymour','Seymour, Missouri',26342,43);
INSERT INTO "django_geo_db_city" VALUES(21649,'Shell Knob','Shell Knob, Missouri',26343,43);
INSERT INTO "django_geo_db_city" VALUES(21650,'South Greenfield','South Greenfield, Missouri',26344,43);
INSERT INTO "django_geo_db_city" VALUES(21651,'Sparta','Sparta, Missouri',26345,43);
INSERT INTO "django_geo_db_city" VALUES(21652,'Spokane','Spokane, Missouri',26346,43);
INSERT INTO "django_geo_db_city" VALUES(21653,'Squires','Squires, Missouri',26347,43);
INSERT INTO "django_geo_db_city" VALUES(21654,'Stotts City','Stotts City, Missouri',26348,43);
INSERT INTO "django_geo_db_city" VALUES(21655,'Strafford','Strafford, Missouri',26349,43);
INSERT INTO "django_geo_db_city" VALUES(21656,'Taneyville','Taneyville, Missouri',26350,43);
INSERT INTO "django_geo_db_city" VALUES(21657,'Tecumseh','Tecumseh, Missouri',26351,43);
INSERT INTO "django_geo_db_city" VALUES(21658,'Theodosia','Theodosia, Arkansas',26352,4);
INSERT INTO "django_geo_db_city" VALUES(21659,'Thornfield','Thornfield, Missouri',26353,43);
INSERT INTO "django_geo_db_city" VALUES(21660,'Tunas','Tunas, Missouri',26354,43);
INSERT INTO "django_geo_db_city" VALUES(21661,'Turners','Turners, Missouri',26355,43);
INSERT INTO "django_geo_db_city" VALUES(21662,'Udall','Udall, Missouri',26356,43);
INSERT INTO "django_geo_db_city" VALUES(21663,'Urbana','Urbana, Missouri',26357,43);
INSERT INTO "django_geo_db_city" VALUES(21664,'Vanzant','Vanzant, Missouri',26358,43);
INSERT INTO "django_geo_db_city" VALUES(21665,'Verona','Verona, Missouri',26359,43);
INSERT INTO "django_geo_db_city" VALUES(21666,'Walnut Grove','Walnut Grove, Missouri',26360,43);
INSERT INTO "django_geo_db_city" VALUES(21667,'Walnut Shade','Walnut Shade, Missouri',26361,43);
INSERT INTO "django_geo_db_city" VALUES(21668,'Washburn','Washburn, Missouri',26362,43);
INSERT INTO "django_geo_db_city" VALUES(21669,'Wasola','Wasola, Missouri',26363,43);
INSERT INTO "django_geo_db_city" VALUES(21670,'Weaubleau','Weaubleau, Missouri',26364,43);
INSERT INTO "django_geo_db_city" VALUES(21671,'South Fork','South Fork, Missouri',26366,43);
INSERT INTO "django_geo_db_city" VALUES(21672,'Moody','Moody, Missouri',26367,43);
INSERT INTO "django_geo_db_city" VALUES(21673,'Myrtle','Myrtle, Missouri',26368,43);
INSERT INTO "django_geo_db_city" VALUES(21674,'Wheatland','Wheatland, Missouri',26369,43);
INSERT INTO "django_geo_db_city" VALUES(21675,'Willard','Willard, Missouri',26370,43);
INSERT INTO "django_geo_db_city" VALUES(21676,'Windyville','Windyville, Missouri',26371,43);
INSERT INTO "django_geo_db_city" VALUES(21677,'Zanoni','Zanoni, Missouri',26372,43);
INSERT INTO "django_geo_db_city" VALUES(21678,'Stockton','Stockton, Missouri',26373,43);
INSERT INTO "django_geo_db_city" VALUES(21679,'Macks Creek','Macks Creek, Missouri',26374,43);
INSERT INTO "django_geo_db_city" VALUES(21680,'Roach','Roach, Missouri',26375,43);
INSERT INTO "django_geo_db_city" VALUES(21681,'Peace Valley','Peace Valley, Missouri',26376,43);
INSERT INTO "django_geo_db_city" VALUES(21682,'Pomona','Pomona, Missouri',26377,43);
INSERT INTO "django_geo_db_city" VALUES(21683,'Pottersville','Pottersville, Missouri',26378,43);
INSERT INTO "django_geo_db_city" VALUES(21684,'Thayer','Thayer, Missouri',26379,43);
INSERT INTO "django_geo_db_city" VALUES(21685,'Willow Springs','Willow Springs, Missouri',26380,43);
INSERT INTO "django_geo_db_city" VALUES(21686,'Atchison','Atchison, Kansas',26390,20);
INSERT INTO "django_geo_db_city" VALUES(21687,'Baldwin City','Baldwin City, Kansas',26391,20);
INSERT INTO "django_geo_db_city" VALUES(21688,'Basehor','Basehor, Kansas',26392,20);
INSERT INTO "django_geo_db_city" VALUES(21689,'Bendena','Bendena, Kansas',26393,20);
INSERT INTO "django_geo_db_city" VALUES(21690,'Blue Mound','Blue Mound, Kansas',26394,20);
INSERT INTO "django_geo_db_city" VALUES(21691,'Bonner Springs','Bonner Springs, Kansas',26395,20);
INSERT INTO "django_geo_db_city" VALUES(21692,'Bucyrus','Bucyrus, Kansas',26396,20);
INSERT INTO "django_geo_db_city" VALUES(21693,'Centerville','Centerville, Kansas',26397,20);
INSERT INTO "django_geo_db_city" VALUES(21694,'Colony','Colony, Kansas',26398,20);
INSERT INTO "django_geo_db_city" VALUES(21695,'Cummings','Cummings, Kansas',26399,20);
INSERT INTO "django_geo_db_city" VALUES(21696,'Denton','Denton, Kansas',26400,20);
INSERT INTO "django_geo_db_city" VALUES(21697,'De Soto','De Soto, Kansas',26401,20);
INSERT INTO "django_geo_db_city" VALUES(21698,'Clearview City','Clearview City, Kansas',26402,20);
INSERT INTO "django_geo_db_city" VALUES(21699,'Easton','Easton, Kansas',26403,20);
INSERT INTO "django_geo_db_city" VALUES(21700,'Edgerton','Edgerton, Kansas',26404,20);
INSERT INTO "django_geo_db_city" VALUES(21701,'Effingham','Effingham, Kansas',26405,20);
INSERT INTO "django_geo_db_city" VALUES(21702,'Elwood','Elwood, Kansas',26406,20);
INSERT INTO "django_geo_db_city" VALUES(21703,'Eudora','Eudora, Kansas',26407,20);
INSERT INTO "django_geo_db_city" VALUES(21704,'Fontana','Fontana, Kansas',26408,20);
INSERT INTO "django_geo_db_city" VALUES(21705,'Fort Leavenworth','Fort Leavenworth, Kansas',26409,20);
INSERT INTO "django_geo_db_city" VALUES(21706,'Gardner','Gardner, Kansas',26410,20);
INSERT INTO "django_geo_db_city" VALUES(21707,'New Century','New Century, Kansas',26411,20);
INSERT INTO "django_geo_db_city" VALUES(21708,'Garnett','Garnett, Kansas',26412,20);
INSERT INTO "django_geo_db_city" VALUES(21709,'Greeley','Greeley, Kansas',26413,20);
INSERT INTO "django_geo_db_city" VALUES(21710,'Highland','Highland, Kansas',26414,20);
INSERT INTO "django_geo_db_city" VALUES(21711,'Hillsdale','Hillsdale, Kansas',26415,20);
INSERT INTO "django_geo_db_city" VALUES(21712,'Kincaid','Kincaid, Kansas',26416,20);
INSERT INTO "django_geo_db_city" VALUES(21713,'La Cygne','La Cygne, Kansas',26417,20);
INSERT INTO "django_geo_db_city" VALUES(21714,'Lancaster','Lancaster, Kansas',26418,20);
INSERT INTO "django_geo_db_city" VALUES(21715,'Lane','Lane, Kansas',26419,20);
INSERT INTO "django_geo_db_city" VALUES(21716,'Lansing','Lansing, Kansas',26420,20);
INSERT INTO "django_geo_db_city" VALUES(21717,'Lawrence','Lawrence, Kansas',26421,20);
INSERT INTO "django_geo_db_city" VALUES(21718,'Leavenworth','Leavenworth, Kansas',26425,20);
INSERT INTO "django_geo_db_city" VALUES(21719,'Lecompton','Lecompton, Kansas',26427,20);
INSERT INTO "django_geo_db_city" VALUES(21720,'Olathe','Olathe, Kansas',26428,20);
INSERT INTO "django_geo_db_city" VALUES(21721,'Linwood','Linwood, Kansas',26429,20);
INSERT INTO "django_geo_db_city" VALUES(21722,'Louisburg','Louisburg, Kansas',26430,20);
INSERT INTO "django_geo_db_city" VALUES(21723,'McLouth','McLouth, Kansas',26431,20);
INSERT INTO "django_geo_db_city" VALUES(21724,'Mound City','Mound City, Kansas',26432,20);
INSERT INTO "django_geo_db_city" VALUES(21725,'Muscotah','Muscotah, Kansas',26433,20);
INSERT INTO "django_geo_db_city" VALUES(21726,'Nortonville','Nortonville, Kansas',26434,20);
INSERT INTO "django_geo_db_city" VALUES(21727,'Osawatomie','Osawatomie, Kansas',26437,20);
INSERT INTO "django_geo_db_city" VALUES(21728,'Oskaloosa','Oskaloosa, Kansas',26438,20);
INSERT INTO "django_geo_db_city" VALUES(21729,'Ottawa','Ottawa, Kansas',26439,20);
INSERT INTO "django_geo_db_city" VALUES(21730,'Ozawkie','Ozawkie, Kansas',26440,20);
INSERT INTO "django_geo_db_city" VALUES(21731,'Paola','Paola, Kansas',26441,20);
INSERT INTO "django_geo_db_city" VALUES(21732,'Parker','Parker, Kansas',26442,20);
INSERT INTO "django_geo_db_city" VALUES(21733,'Perry','Perry, Kansas',26443,20);
INSERT INTO "django_geo_db_city" VALUES(21734,'Pleasanton','Pleasanton, Kansas',26444,20);
INSERT INTO "django_geo_db_city" VALUES(21735,'Pomona','Pomona, Kansas',26445,20);
INSERT INTO "django_geo_db_city" VALUES(21736,'Potter','Potter, Kansas',26446,20);
INSERT INTO "django_geo_db_city" VALUES(21737,'Princeton','Princeton, Kansas',26447,20);
INSERT INTO "django_geo_db_city" VALUES(21738,'Rantoul','Rantoul, Kansas',26448,20);
INSERT INTO "django_geo_db_city" VALUES(21739,'Richmond','Richmond, Kansas',26449,20);
INSERT INTO "django_geo_db_city" VALUES(21740,'Wolf River','Wolf River, Kansas',26450,20);
INSERT INTO "django_geo_db_city" VALUES(21741,'Spring Hill','Spring Hill, Kansas',26451,20);
INSERT INTO "django_geo_db_city" VALUES(21742,'Stilwell','Stilwell, Kansas',26452,20);
INSERT INTO "django_geo_db_city" VALUES(21743,'Tonganoxie','Tonganoxie, Kansas',26453,20);
INSERT INTO "django_geo_db_city" VALUES(21744,'Troy','Troy, Kansas',26454,20);
INSERT INTO "django_geo_db_city" VALUES(21745,'Valley Falls','Valley Falls, Kansas',26455,20);
INSERT INTO "django_geo_db_city" VALUES(21746,'Wathena','Wathena, Kansas',26456,20);
INSERT INTO "django_geo_db_city" VALUES(21747,'Welda','Welda, Kansas',26457,20);
INSERT INTO "django_geo_db_city" VALUES(21748,'Wellsville','Wellsville, Kansas',26458,20);
INSERT INTO "django_geo_db_city" VALUES(21749,'Westphalia','Westphalia, Kansas',26459,20);
INSERT INTO "django_geo_db_city" VALUES(21750,'White Cloud','White Cloud, Kansas',26460,20);
INSERT INTO "django_geo_db_city" VALUES(21751,'Williamsburg','Williamsburg, Kansas',26461,20);
INSERT INTO "django_geo_db_city" VALUES(21752,'Winchester','Winchester, Kansas',26462,20);
INSERT INTO "django_geo_db_city" VALUES(21753,'Kansas City','Kansas City, Kansas',26463,20);
INSERT INTO "django_geo_db_city" VALUES(21754,'Edwardsville','Edwardsville, Kansas',26473,20);
INSERT INTO "django_geo_db_city" VALUES(21755,'Centralia','Centralia, Kansas',26476,20);
INSERT INTO "django_geo_db_city" VALUES(21756,'Morrill','Morrill, Kansas',26477,20);
INSERT INTO "django_geo_db_city" VALUES(21757,'Shawnee Mission','Shawnee Mission, Kansas',26478,20);
INSERT INTO "django_geo_db_city" VALUES(21758,'Robinson','Robinson, Kansas',26503,20);
INSERT INTO "django_geo_db_city" VALUES(21759,'Lincoln','Lincoln, Kansas',26504,20);
INSERT INTO "django_geo_db_city" VALUES(21760,'Alma','Alma, Kansas',26505,20);
INSERT INTO "django_geo_db_city" VALUES(21761,'Auburn','Auburn, Kansas',26506,20);
INSERT INTO "django_geo_db_city" VALUES(21762,'Axtell','Axtell, Kansas',26507,20);
INSERT INTO "django_geo_db_city" VALUES(21763,'Baileyville','Baileyville, Kansas',26508,20);
INSERT INTO "django_geo_db_city" VALUES(21764,'Beattie','Beattie, Kansas',26509,20);
INSERT INTO "django_geo_db_city" VALUES(21765,'Belvue','Belvue, Kansas',26510,20);
INSERT INTO "django_geo_db_city" VALUES(21766,'Bern','Bern, Kansas',26511,20);
INSERT INTO "django_geo_db_city" VALUES(21767,'Berryton','Berryton, Kansas',26512,20);
INSERT INTO "django_geo_db_city" VALUES(21768,'Blue Rapids','Blue Rapids, Kansas',26513,20);
INSERT INTO "django_geo_db_city" VALUES(21769,'Bremen','Bremen, Kansas',26514,20);
INSERT INTO "django_geo_db_city" VALUES(21770,'Burlingame','Burlingame, Kansas',26515,20);
INSERT INTO "django_geo_db_city" VALUES(21771,'Carbondale','Carbondale, Kansas',26516,20);
INSERT INTO "django_geo_db_city" VALUES(21772,'Circleville','Circleville, Kansas',26518,20);
INSERT INTO "django_geo_db_city" VALUES(21773,'Corning','Corning, Kansas',26519,20);
INSERT INTO "django_geo_db_city" VALUES(21774,'Delia','Delia, Kansas',26520,20);
INSERT INTO "django_geo_db_city" VALUES(21775,'Denison','Denison, Kansas',26521,20);
INSERT INTO "django_geo_db_city" VALUES(21776,'Dover','Dover, Kansas',26522,20);
INSERT INTO "django_geo_db_city" VALUES(21777,'Emmett','Emmett, Kansas',26523,20);
INSERT INTO "django_geo_db_city" VALUES(21778,'Eskridge','Eskridge, Kansas',26524,20);
INSERT INTO "django_geo_db_city" VALUES(21779,'Everest','Everest, Kansas',26525,20);
INSERT INTO "django_geo_db_city" VALUES(21780,'Fairview','Fairview, Kansas',26526,20);
INSERT INTO "django_geo_db_city" VALUES(21781,'Fostoria','Fostoria, Kansas',26527,20);
INSERT INTO "django_geo_db_city" VALUES(21782,'Frankfort','Frankfort, Kansas',26528,20);
INSERT INTO "django_geo_db_city" VALUES(21783,'Goff','Goff, Kansas',26529,20);
INSERT INTO "django_geo_db_city" VALUES(21784,'Grantville','Grantville, Kansas',26530,20);
INSERT INTO "django_geo_db_city" VALUES(21785,'Harveyville','Harveyville, Kansas',26531,20);
INSERT INTO "django_geo_db_city" VALUES(21786,'Havensville','Havensville, Kansas',26532,20);
INSERT INTO "django_geo_db_city" VALUES(21787,'Hiawatha','Hiawatha, Kansas',26533,20);
INSERT INTO "django_geo_db_city" VALUES(21788,'Holton','Holton, Kansas',26534,20);
INSERT INTO "django_geo_db_city" VALUES(21789,'Home','Home, Kansas',26535,20);
INSERT INTO "django_geo_db_city" VALUES(21790,'Horton','Horton, Kansas',26536,20);
INSERT INTO "django_geo_db_city" VALUES(21791,'Hoyt','Hoyt, Kansas',26537,20);
INSERT INTO "django_geo_db_city" VALUES(21792,'Junction City','Junction City, Kansas',26538,20);
INSERT INTO "django_geo_db_city" VALUES(21793,'Fort Riley','Fort Riley, Kansas',26539,20);
INSERT INTO "django_geo_db_city" VALUES(21794,'Leonardville','Leonardville, Kansas',26540,20);
INSERT INTO "django_geo_db_city" VALUES(21795,'Louisville','Louisville, Kansas',26541,20);
INSERT INTO "django_geo_db_city" VALUES(21796,'Lyndon','Lyndon, Kansas',26542,20);
INSERT INTO "django_geo_db_city" VALUES(21797,'Weir','Weir, Kansas',26543,20);
INSERT INTO "django_geo_db_city" VALUES(21798,'McFarland','McFarland, Kansas',26544,20);
INSERT INTO "django_geo_db_city" VALUES(21799,'Manhattan','Manhattan, Kansas',26545,20);
INSERT INTO "django_geo_db_city" VALUES(21800,'Maple Hill','Maple Hill, Kansas',26549,20);
INSERT INTO "django_geo_db_city" VALUES(21801,'Marysville','Marysville, Kansas',26550,20);
INSERT INTO "django_geo_db_city" VALUES(21802,'Mayetta','Mayetta, Kansas',26551,20);
INSERT INTO "django_geo_db_city" VALUES(21803,'Melvern','Melvern, Kansas',26552,20);
INSERT INTO "django_geo_db_city" VALUES(21804,'Meriden','Meriden, Kansas',26553,20);
INSERT INTO "django_geo_db_city" VALUES(21805,'Milford','Milford, Kansas',26554,20);
INSERT INTO "django_geo_db_city" VALUES(21806,'Netawaka','Netawaka, Kansas',26556,20);
INSERT INTO "django_geo_db_city" VALUES(21807,'Ogden','Ogden, Kansas',26557,20);
INSERT INTO "django_geo_db_city" VALUES(21808,'Oketo','Oketo, Kansas',26558,20);
INSERT INTO "django_geo_db_city" VALUES(21809,'Olsburg','Olsburg, Kansas',26559,20);
INSERT INTO "django_geo_db_city" VALUES(21810,'Onaga','Onaga, Kansas',26560,20);
INSERT INTO "django_geo_db_city" VALUES(21811,'Oneida','Oneida, Kansas',26561,20);
INSERT INTO "django_geo_db_city" VALUES(21812,'Osage City','Osage City, Kansas',26562,20);
INSERT INTO "django_geo_db_city" VALUES(21813,'Overbrook','Overbrook, Kansas',26563,20);
INSERT INTO "django_geo_db_city" VALUES(21814,'Paxico','Paxico, Kansas',26564,20);
INSERT INTO "django_geo_db_city" VALUES(21815,'Powhattan','Powhattan, Kansas',26565,20);
INSERT INTO "django_geo_db_city" VALUES(21816,'Quenemo','Quenemo, Kansas',26566,20);
INSERT INTO "django_geo_db_city" VALUES(21817,'Riley','Riley, Kansas',26567,20);
INSERT INTO "django_geo_db_city" VALUES(21818,'Rossville','Rossville, Kansas',26569,20);
INSERT INTO "django_geo_db_city" VALUES(21819,'Sabetha','Sabetha, Kansas',26570,20);
INSERT INTO "django_geo_db_city" VALUES(21820,'Saint George','Saint George, Kansas',26571,20);
INSERT INTO "django_geo_db_city" VALUES(21821,'Saint Marys','Saint Marys, Kansas',26572,20);
INSERT INTO "django_geo_db_city" VALUES(21822,'Scranton','Scranton, Kansas',26573,20);
INSERT INTO "django_geo_db_city" VALUES(21823,'Seneca','Seneca, Kansas',26574,20);
INSERT INTO "django_geo_db_city" VALUES(21824,'Silver Lake','Silver Lake, Kansas',26575,20);
INSERT INTO "django_geo_db_city" VALUES(21825,'Soldier','Soldier, Kansas',26576,20);
INSERT INTO "django_geo_db_city" VALUES(21826,'Summerfield','Summerfield, Kansas',26577,20);
INSERT INTO "django_geo_db_city" VALUES(21827,'Tecumseh','Tecumseh, Kansas',26578,20);
INSERT INTO "django_geo_db_city" VALUES(21828,'Vassar','Vassar, Kansas',26579,20);
INSERT INTO "django_geo_db_city" VALUES(21829,'Vermillion','Vermillion, Kansas',26580,20);
INSERT INTO "django_geo_db_city" VALUES(21830,'Wakarusa','Wakarusa, Kansas',26581,20);
INSERT INTO "django_geo_db_city" VALUES(21831,'Wamego','Wamego, Kansas',26582,20);
INSERT INTO "django_geo_db_city" VALUES(21832,'Waterville','Waterville, Kansas',26583,20);
INSERT INTO "django_geo_db_city" VALUES(21833,'Westmoreland','Westmoreland, Kansas',26584,20);
INSERT INTO "django_geo_db_city" VALUES(21834,'Wetmore','Wetmore, Kansas',26585,20);
INSERT INTO "django_geo_db_city" VALUES(21835,'Wheaton','Wheaton, Kansas',26586,20);
INSERT INTO "django_geo_db_city" VALUES(21836,'Whiting','Whiting, Kansas',26587,20);
INSERT INTO "django_geo_db_city" VALUES(21837,'Randolph','Randolph, Kansas',26588,20);
INSERT INTO "django_geo_db_city" VALUES(21838,'Topeka','Topeka, Kansas',26590,20);
INSERT INTO "django_geo_db_city" VALUES(21839,'St. George','St. George, Kansas',26608,20);
INSERT INTO "django_geo_db_city" VALUES(21840,'Fort Scott','Fort Scott, Kansas',26610,20);
INSERT INTO "django_geo_db_city" VALUES(21841,'Altoona','Altoona, Kansas',26611,20);
INSERT INTO "django_geo_db_city" VALUES(21842,'Arcadia','Arcadia, Kansas',26612,20);
INSERT INTO "django_geo_db_city" VALUES(21843,'Arma','Arma, Kansas',26613,20);
INSERT INTO "django_geo_db_city" VALUES(21844,'Baxter Springs','Baxter Springs, Kansas',26614,20);
INSERT INTO "django_geo_db_city" VALUES(21845,'Benedict','Benedict, Kansas',26615,20);
INSERT INTO "django_geo_db_city" VALUES(21846,'Bronson','Bronson, Kansas',26616,20);
INSERT INTO "django_geo_db_city" VALUES(21847,'Buffalo','Buffalo, Kansas',26617,20);
INSERT INTO "django_geo_db_city" VALUES(21848,'Chanute','Chanute, Kansas',26618,20);
INSERT INTO "django_geo_db_city" VALUES(21849,'Cherokee','Cherokee, Kansas',26620,20);
INSERT INTO "django_geo_db_city" VALUES(21850,'Columbus','Columbus, Kansas',26621,20);
INSERT INTO "django_geo_db_city" VALUES(21851,'Coyville','Coyville, Kansas',26622,20);
INSERT INTO "django_geo_db_city" VALUES(21852,'Crestline','Crestline, Kansas',26623,20);
INSERT INTO "django_geo_db_city" VALUES(21853,'Elsmore','Elsmore, Kansas',26624,20);
INSERT INTO "django_geo_db_city" VALUES(21854,'Erie','Erie, Kansas',26625,20);
INSERT INTO "django_geo_db_city" VALUES(21855,'Farlington','Farlington, Kansas',26626,20);
INSERT INTO "django_geo_db_city" VALUES(21856,'Franklin','Franklin, Kansas',26627,20);
INSERT INTO "django_geo_db_city" VALUES(21857,'Fredonia','Fredonia, Kansas',26628,20);
INSERT INTO "django_geo_db_city" VALUES(21858,'Fulton','Fulton, Kansas',26629,20);
INSERT INTO "django_geo_db_city" VALUES(21859,'Galena','Galena, Kansas',26630,20);
INSERT INTO "django_geo_db_city" VALUES(21860,'Galesburg','Galesburg, Kansas',26631,20);
INSERT INTO "django_geo_db_city" VALUES(21861,'Gas','Gas, Kansas',26633,20);
INSERT INTO "django_geo_db_city" VALUES(21862,'Girard','Girard, Kansas',26634,20);
INSERT INTO "django_geo_db_city" VALUES(21863,'Hepler','Hepler, Kansas',26635,20);
INSERT INTO "django_geo_db_city" VALUES(21864,'Neodesha','Neodesha, Kansas',26636,20);
INSERT INTO "django_geo_db_city" VALUES(21865,'Humboldt','Humboldt, Kansas',26637,20);
INSERT INTO "django_geo_db_city" VALUES(21866,'Iola','Iola, Kansas',26638,20);
INSERT INTO "django_geo_db_city" VALUES(21867,'La Harpe','La Harpe, Kansas',26639,20);
INSERT INTO "django_geo_db_city" VALUES(21868,'Ross','Ross, Kansas',26640,20);
INSERT INTO "django_geo_db_city" VALUES(21869,'McCune','McCune, Kansas',26641,20);
INSERT INTO "django_geo_db_city" VALUES(21870,'Mapleton','Mapleton, Kansas',26642,20);
INSERT INTO "django_geo_db_city" VALUES(21871,'Moran','Moran, Kansas',26643,20);
INSERT INTO "django_geo_db_city" VALUES(21872,'Mulberry','Mulberry, Kansas',26644,20);
INSERT INTO "django_geo_db_city" VALUES(21873,'Neosho Falls','Neosho Falls, Kansas',26646,20);
INSERT INTO "django_geo_db_city" VALUES(21874,'New Albany','New Albany, Kansas',26647,20);
INSERT INTO "django_geo_db_city" VALUES(21875,'Opolis','Opolis, Kansas',26648,20);
INSERT INTO "django_geo_db_city" VALUES(21876,'Piqua','Piqua, Kansas',26649,20);
INSERT INTO "django_geo_db_city" VALUES(21877,'Pittsburg','Pittsburg, Kansas',26650,20);
INSERT INTO "django_geo_db_city" VALUES(21878,'Frontenac','Frontenac, Kansas',26651,20);
INSERT INTO "django_geo_db_city" VALUES(21879,'Prescott','Prescott, Kansas',26652,20);
INSERT INTO "django_geo_db_city" VALUES(21880,'Redfield','Redfield, Kansas',26653,20);
INSERT INTO "django_geo_db_city" VALUES(21881,'Riverton','Riverton, Kansas',26654,20);
INSERT INTO "django_geo_db_city" VALUES(21882,'Saint Paul','Saint Paul, Kansas',26655,20);
INSERT INTO "django_geo_db_city" VALUES(21883,'Savonburg','Savonburg, Kansas',26656,20);
INSERT INTO "django_geo_db_city" VALUES(21884,'Scammon','Scammon, Kansas',26657,20);
INSERT INTO "django_geo_db_city" VALUES(21885,'Stark','Stark, Kansas',26658,20);
INSERT INTO "django_geo_db_city" VALUES(21886,'Thayer','Thayer, Kansas',26659,20);
INSERT INTO "django_geo_db_city" VALUES(21887,'Toronto','Toronto, Kansas',26660,20);
INSERT INTO "django_geo_db_city" VALUES(21888,'Treece','Treece, Kansas',26661,20);
INSERT INTO "django_geo_db_city" VALUES(21889,'Uniontown','Uniontown, Kansas',26662,20);
INSERT INTO "django_geo_db_city" VALUES(21890,'Walnut','Walnut, Kansas',26663,20);
INSERT INTO "django_geo_db_city" VALUES(21891,'West Mineral','West Mineral, Kansas',26665,20);
INSERT INTO "django_geo_db_city" VALUES(21892,'Yates Center','Yates Center, Kansas',26666,20);
INSERT INTO "django_geo_db_city" VALUES(21893,'Emporia','Emporia, Kansas',26667,20);
INSERT INTO "django_geo_db_city" VALUES(21894,'Admire','Admire, Kansas',26669,20);
INSERT INTO "django_geo_db_city" VALUES(21895,'Allen','Allen, Kansas',26670,20);
INSERT INTO "django_geo_db_city" VALUES(21896,'Alta Vista','Alta Vista, Kansas',26671,20);
INSERT INTO "django_geo_db_city" VALUES(21897,'Americus','Americus, Kansas',26672,20);
INSERT INTO "django_geo_db_city" VALUES(21898,'Burdick','Burdick, Kansas',26673,20);
INSERT INTO "django_geo_db_city" VALUES(21899,'Burlington','Burlington, Kansas',26674,20);
INSERT INTO "django_geo_db_city" VALUES(21900,'Burns','Burns, Kansas',26675,20);
INSERT INTO "django_geo_db_city" VALUES(21901,'Cassoday','Cassoday, Kansas',26676,20);
INSERT INTO "django_geo_db_city" VALUES(21902,'Cedar Point','Cedar Point, Kansas',26677,20);
INSERT INTO "django_geo_db_city" VALUES(21903,'Cottonwood Falls','Cottonwood Falls, Kansas',26678,20);
INSERT INTO "django_geo_db_city" VALUES(21904,'Council Grove','Council Grove, Kansas',26679,20);
INSERT INTO "django_geo_db_city" VALUES(21905,'Dwight','Dwight, Kansas',26680,20);
INSERT INTO "django_geo_db_city" VALUES(21906,'Elmdale','Elmdale, Kansas',26681,20);
INSERT INTO "django_geo_db_city" VALUES(21907,'Florence','Florence, Kansas',26682,20);
INSERT INTO "django_geo_db_city" VALUES(21908,'Gridley','Gridley, Kansas',26683,20);
INSERT INTO "django_geo_db_city" VALUES(21909,'Hamilton','Hamilton, Kansas',26684,20);
INSERT INTO "django_geo_db_city" VALUES(21910,'Hartford','Hartford, Kansas',26685,20);
INSERT INTO "django_geo_db_city" VALUES(21911,'Lamont','Lamont, Kansas',26686,20);
INSERT INTO "django_geo_db_city" VALUES(21912,'Lebo','Lebo, Kansas',26687,20);
INSERT INTO "django_geo_db_city" VALUES(21913,'Le Roy','Le Roy, Kansas',26688,20);
INSERT INTO "django_geo_db_city" VALUES(21914,'Lincolnville','Lincolnville, Kansas',26689,20);
INSERT INTO "django_geo_db_city" VALUES(21915,'Lost Springs','Lost Springs, Kansas',26690,20);
INSERT INTO "django_geo_db_city" VALUES(21916,'Madison','Madison, Kansas',26691,20);
INSERT INTO "django_geo_db_city" VALUES(21917,'Marion','Marion, Kansas',26692,20);
INSERT INTO "django_geo_db_city" VALUES(21918,'Matfield Green','Matfield Green, Kansas',26693,20);
INSERT INTO "django_geo_db_city" VALUES(21919,'Neal','Neal, Kansas',26694,20);
INSERT INTO "django_geo_db_city" VALUES(21920,'Neosho Rapids','Neosho Rapids, Kansas',26695,20);
INSERT INTO "django_geo_db_city" VALUES(21921,'Olpe','Olpe, Kansas',26696,20);
INSERT INTO "django_geo_db_city" VALUES(21922,'Peabody','Peabody, Kansas',26697,20);
INSERT INTO "django_geo_db_city" VALUES(21923,'Reading','Reading, Kansas',26698,20);
INSERT INTO "django_geo_db_city" VALUES(21924,'Strong City','Strong City, Kansas',26699,20);
INSERT INTO "django_geo_db_city" VALUES(21925,'Virgil','Virgil, Kansas',26700,20);
INSERT INTO "django_geo_db_city" VALUES(21926,'Waverly','Waverly, Kansas',26701,20);
INSERT INTO "django_geo_db_city" VALUES(21927,'White City','White City, Kansas',26702,20);
INSERT INTO "django_geo_db_city" VALUES(21928,'Wilsey','Wilsey, Kansas',26703,20);
INSERT INTO "django_geo_db_city" VALUES(21929,'Concordia','Concordia, Kansas',26704,20);
INSERT INTO "django_geo_db_city" VALUES(21930,'Agenda','Agenda, Kansas',26705,20);
INSERT INTO "django_geo_db_city" VALUES(21931,'Athol','Athol, Kansas',26706,20);
INSERT INTO "django_geo_db_city" VALUES(21932,'Barnes','Barnes, Kansas',26707,20);
INSERT INTO "django_geo_db_city" VALUES(21933,'Belleville','Belleville, Kansas',26708,20);
INSERT INTO "django_geo_db_city" VALUES(21934,'Burr Oak','Burr Oak, Kansas',26709,20);
INSERT INTO "django_geo_db_city" VALUES(21935,'Clifton','Clifton, Kansas',26710,20);
INSERT INTO "django_geo_db_city" VALUES(21936,'Clyde','Clyde, Kansas',26711,20);
INSERT INTO "django_geo_db_city" VALUES(21937,'Courtland','Courtland, Kansas',26712,20);
INSERT INTO "django_geo_db_city" VALUES(21938,'Cuba','Cuba, Kansas',26713,20);
INSERT INTO "django_geo_db_city" VALUES(21939,'Esbon','Esbon, Kansas',26714,20);
INSERT INTO "django_geo_db_city" VALUES(21940,'Formoso','Formoso, Kansas',26715,20);
INSERT INTO "django_geo_db_city" VALUES(21941,'Greenleaf','Greenleaf, Kansas',26716,20);
INSERT INTO "django_geo_db_city" VALUES(21942,'Haddam','Haddam, Kansas',26717,20);
INSERT INTO "django_geo_db_city" VALUES(21943,'Hanover','Hanover, Kansas',26718,20);
INSERT INTO "django_geo_db_city" VALUES(21944,'Hollenberg','Hollenberg, Kansas',26719,20);
INSERT INTO "django_geo_db_city" VALUES(21945,'Jamestown','Jamestown, Kansas',26720,20);
INSERT INTO "django_geo_db_city" VALUES(21946,'Jewell','Jewell, Kansas',26721,20);
INSERT INTO "django_geo_db_city" VALUES(21947,'Kensington','Kensington, Kansas',26722,20);
INSERT INTO "django_geo_db_city" VALUES(21948,'Lebanon','Lebanon, Kansas',26723,20);
INSERT INTO "django_geo_db_city" VALUES(21949,'Linn','Linn, Kansas',26724,20);
INSERT INTO "django_geo_db_city" VALUES(21950,'Mahaska','Mahaska, Kansas',26725,20);
INSERT INTO "django_geo_db_city" VALUES(21951,'Mankato','Mankato, Kansas',26726,20);
INSERT INTO "django_geo_db_city" VALUES(21952,'Morrowville','Morrowville, Kansas',26727,20);
INSERT INTO "django_geo_db_city" VALUES(21953,'Munden','Munden, Kansas',26728,20);
INSERT INTO "django_geo_db_city" VALUES(21954,'Narka','Narka, Kansas',26729,20);
INSERT INTO "django_geo_db_city" VALUES(21955,'Norway','Norway, Kansas',26730,20);
INSERT INTO "django_geo_db_city" VALUES(21956,'Palmer','Palmer, Kansas',26731,20);
INSERT INTO "django_geo_db_city" VALUES(21957,'Randall','Randall, Kansas',26732,20);
INSERT INTO "django_geo_db_city" VALUES(21958,'Republic','Republic, Kansas',26733,20);
INSERT INTO "django_geo_db_city" VALUES(21959,'Scandia','Scandia, Kansas',26734,20);
INSERT INTO "django_geo_db_city" VALUES(21960,'Smith Center','Smith Center, Kansas',26735,20);
INSERT INTO "django_geo_db_city" VALUES(21961,'Washington','Washington, Kansas',26736,20);
INSERT INTO "django_geo_db_city" VALUES(21962,'Webber','Webber, Kansas',26738,20);
INSERT INTO "django_geo_db_city" VALUES(21963,'Andale','Andale, Kansas',26740,20);
INSERT INTO "django_geo_db_city" VALUES(21964,'Andover','Andover, Kansas',26741,20);
INSERT INTO "django_geo_db_city" VALUES(21965,'Anthony','Anthony, Kansas',26742,20);
INSERT INTO "django_geo_db_city" VALUES(21966,'Argonia','Argonia, Kansas',26743,20);
INSERT INTO "django_geo_db_city" VALUES(21967,'Arkansas City','Arkansas City, Kansas',26744,20);
INSERT INTO "django_geo_db_city" VALUES(21968,'Atlanta','Atlanta, Kansas',26745,20);
INSERT INTO "django_geo_db_city" VALUES(21969,'Attica','Attica, Kansas',26746,20);
INSERT INTO "django_geo_db_city" VALUES(21970,'Augusta','Augusta, Kansas',26747,20);
INSERT INTO "django_geo_db_city" VALUES(21971,'Beaumont','Beaumont, Kansas',26748,20);
INSERT INTO "django_geo_db_city" VALUES(21972,'Belle Plaine','Belle Plaine, Kansas',26749,20);
INSERT INTO "django_geo_db_city" VALUES(21973,'Bentley','Bentley, Kansas',26750,20);
INSERT INTO "django_geo_db_city" VALUES(21974,'Benton','Benton, Kansas',26751,20);
INSERT INTO "django_geo_db_city" VALUES(21975,'Bluff City','Bluff City, Kansas',26752,20);
INSERT INTO "django_geo_db_city" VALUES(21976,'Burden','Burden, Kansas',26753,20);
INSERT INTO "django_geo_db_city" VALUES(21977,'Burrton','Burrton, Kansas',26754,20);
INSERT INTO "django_geo_db_city" VALUES(21978,'Byers','Byers, Kansas',26755,20);
INSERT INTO "django_geo_db_city" VALUES(21979,'Caldwell','Caldwell, Kansas',26756,20);
INSERT INTO "django_geo_db_city" VALUES(21980,'Cambridge','Cambridge, Kansas',26757,20);
INSERT INTO "django_geo_db_city" VALUES(21981,'Cedar Vale','Cedar Vale, Kansas',26758,20);
INSERT INTO "django_geo_db_city" VALUES(21982,'Cheney','Cheney, Kansas',26759,20);
INSERT INTO "django_geo_db_city" VALUES(21983,'Clearwater','Clearwater, Kansas',26760,20);
INSERT INTO "django_geo_db_city" VALUES(21984,'Coats','Coats, Kansas',26761,20);
INSERT INTO "django_geo_db_city" VALUES(21985,'Coldwater','Coldwater, Kansas',26762,20);
INSERT INTO "django_geo_db_city" VALUES(21986,'Colwich','Colwich, Kansas',26763,20);
INSERT INTO "django_geo_db_city" VALUES(21987,'Conway Springs','Conway Springs, Kansas',26764,20);
INSERT INTO "django_geo_db_city" VALUES(21988,'Richland','Richland, Kansas',26765,20);
INSERT INTO "django_geo_db_city" VALUES(21989,'Cunningham','Cunningham, Kansas',26766,20);
INSERT INTO "django_geo_db_city" VALUES(21990,'Danville','Danville, Kansas',26767,20);
INSERT INTO "django_geo_db_city" VALUES(21991,'Derby','Derby, Kansas',26768,20);
INSERT INTO "django_geo_db_city" VALUES(21992,'Dexter','Dexter, Kansas',26769,20);
INSERT INTO "django_geo_db_city" VALUES(21993,'Douglass','Douglass, Kansas',26770,20);
INSERT INTO "django_geo_db_city" VALUES(21994,'Elbing','Elbing, Kansas',26771,20);
INSERT INTO "django_geo_db_city" VALUES(21995,'El Dorado','El Dorado, Kansas',26772,20);
INSERT INTO "django_geo_db_city" VALUES(21996,'Eureka','Eureka, Kansas',26773,20);
INSERT INTO "django_geo_db_city" VALUES(21997,'Fall River','Fall River, Kansas',26774,20);
INSERT INTO "django_geo_db_city" VALUES(21998,'Freeport','Freeport, Kansas',26775,20);
INSERT INTO "django_geo_db_city" VALUES(21999,'Garden Plain','Garden Plain, Kansas',26776,20);
INSERT INTO "django_geo_db_city" VALUES(22000,'Geuda Springs','Geuda Springs, Kansas',26777,20);
INSERT INTO "django_geo_db_city" VALUES(22001,'Goddard','Goddard, Kansas',26778,20);
INSERT INTO "django_geo_db_city" VALUES(22002,'Goessel','Goessel, Kansas',26779,20);
INSERT INTO "django_geo_db_city" VALUES(22003,'Greensburg','Greensburg, Kansas',26780,20);
INSERT INTO "django_geo_db_city" VALUES(22004,'Greenwich','Greenwich, Kansas',26781,20);
INSERT INTO "django_geo_db_city" VALUES(22005,'Halstead','Halstead, Kansas',26782,20);
INSERT INTO "django_geo_db_city" VALUES(22006,'Hardtner','Hardtner, Kansas',26783,20);
INSERT INTO "django_geo_db_city" VALUES(22007,'Harper','Harper, Kansas',26784,20);
INSERT INTO "django_geo_db_city" VALUES(22008,'Haviland','Haviland, Kansas',26785,20);
INSERT INTO "django_geo_db_city" VALUES(22009,'Haysville','Haysville, Kansas',26786,20);
INSERT INTO "django_geo_db_city" VALUES(22010,'Hazelton','Hazelton, Kansas',26787,20);
INSERT INTO "django_geo_db_city" VALUES(22011,'Hesston','Hesston, Kansas',26788,20);
INSERT INTO "django_geo_db_city" VALUES(22012,'Hillsboro','Hillsboro, Kansas',26789,20);
INSERT INTO "django_geo_db_city" VALUES(22013,'Isabel','Isabel, Kansas',26790,20);
INSERT INTO "django_geo_db_city" VALUES(22014,'Iuka','Iuka, Kansas',26791,20);
INSERT INTO "django_geo_db_city" VALUES(22015,'Kechi','Kechi, Kansas',26792,20);
INSERT INTO "django_geo_db_city" VALUES(22016,'Kingman','Kingman, Kansas',26793,20);
INSERT INTO "django_geo_db_city" VALUES(22017,'Ninnescah','Ninnescah, Kansas',26794,20);
INSERT INTO "django_geo_db_city" VALUES(22018,'Kiowa','Kiowa, Kansas',26795,20);
INSERT INTO "django_geo_db_city" VALUES(22019,'Lake City','Lake City, Kansas',26796,20);
INSERT INTO "django_geo_db_city" VALUES(22020,'Latham','Latham, Kansas',26797,20);
INSERT INTO "django_geo_db_city" VALUES(22021,'Lehigh','Lehigh, Kansas',26798,20);
INSERT INTO "django_geo_db_city" VALUES(22022,'Leon','Leon, Kansas',26799,20);
INSERT INTO "django_geo_db_city" VALUES(22023,'Maize','Maize, Kansas',26800,20);
INSERT INTO "django_geo_db_city" VALUES(22024,'Maple City','Maple City, Kansas',26801,20);
INSERT INTO "django_geo_db_city" VALUES(22025,'Mayfield','Mayfield, Kansas',26802,20);
INSERT INTO "django_geo_db_city" VALUES(22026,'Medicine Lodge','Medicine Lodge, Kansas',26803,20);
INSERT INTO "django_geo_db_city" VALUES(22027,'Milan','Milan, Kansas',26804,20);
INSERT INTO "django_geo_db_city" VALUES(22028,'Milton','Milton, Kansas',26805,20);
INSERT INTO "django_geo_db_city" VALUES(22029,'Moundridge','Moundridge, Kansas',26806,20);
INSERT INTO "django_geo_db_city" VALUES(22030,'Mount Hope','Mount Hope, Kansas',26807,20);
INSERT INTO "django_geo_db_city" VALUES(22031,'Mullinville','Mullinville, Kansas',26808,20);
INSERT INTO "django_geo_db_city" VALUES(22032,'Mulvane','Mulvane, Kansas',26809,20);
INSERT INTO "django_geo_db_city" VALUES(22033,'Murdock','Murdock, Kansas',26810,20);
INSERT INTO "django_geo_db_city" VALUES(22034,'Nashville','Nashville, Kansas',26811,20);
INSERT INTO "django_geo_db_city" VALUES(22035,'Newton','Newton, Kansas',26812,20);
INSERT INTO "django_geo_db_city" VALUES(22036,'North Newton','North Newton, Kansas',26813,20);
INSERT INTO "django_geo_db_city" VALUES(22037,'Norwich','Norwich, Kansas',26814,20);
INSERT INTO "django_geo_db_city" VALUES(22038,'Oxford','Oxford, Kansas',26815,20);
INSERT INTO "django_geo_db_city" VALUES(22039,'Peck','Peck, Kansas',26816,20);
INSERT INTO "django_geo_db_city" VALUES(22040,'Piedmont','Piedmont, Kansas',26817,20);
INSERT INTO "django_geo_db_city" VALUES(22041,'Potwin','Potwin, Kansas',26818,20);
INSERT INTO "django_geo_db_city" VALUES(22042,'Pratt','Pratt, Kansas',26819,20);
INSERT INTO "django_geo_db_city" VALUES(22043,'Protection','Protection, Kansas',26820,20);
INSERT INTO "django_geo_db_city" VALUES(22044,'Rago','Rago, Kansas',26821,20);
INSERT INTO "django_geo_db_city" VALUES(22045,'Rock','Rock, Kansas',26822,20);
INSERT INTO "django_geo_db_city" VALUES(22046,'Rosalia','Rosalia, Kansas',26823,20);
INSERT INTO "django_geo_db_city" VALUES(22047,'Rose Hill','Rose Hill, Kansas',26824,20);
INSERT INTO "django_geo_db_city" VALUES(22048,'Sawyer','Sawyer, Kansas',26825,20);
INSERT INTO "django_geo_db_city" VALUES(22049,'Sedgwick','Sedgwick, Kansas',26826,20);
INSERT INTO "django_geo_db_city" VALUES(22050,'Severy','Severy, Kansas',26827,20);
INSERT INTO "django_geo_db_city" VALUES(22051,'Sharon','Sharon, Kansas',26828,20);
INSERT INTO "django_geo_db_city" VALUES(22052,'South Haven','South Haven, Kansas',26829,20);
INSERT INTO "django_geo_db_city" VALUES(22053,'Spivey','Spivey, Kansas',26830,20);
INSERT INTO "django_geo_db_city" VALUES(22054,'Sun City','Sun City, Kansas',26831,20);
INSERT INTO "django_geo_db_city" VALUES(22055,'Towanda','Towanda, Kansas',26832,20);
INSERT INTO "django_geo_db_city" VALUES(22056,'Udall','Udall, Kansas',26833,20);
INSERT INTO "django_geo_db_city" VALUES(22057,'Valley Center','Valley Center, Kansas',26834,20);
INSERT INTO "django_geo_db_city" VALUES(22058,'Viola','Viola, Kansas',26835,20);
INSERT INTO "django_geo_db_city" VALUES(22059,'Waldron','Waldron, Kansas',26836,20);
INSERT INTO "django_geo_db_city" VALUES(22060,'Walton','Walton, Kansas',26837,20);
INSERT INTO "django_geo_db_city" VALUES(22061,'Wellington','Wellington, Kansas',26838,20);
INSERT INTO "django_geo_db_city" VALUES(22062,'Whitewater','Whitewater, Kansas',26839,20);
INSERT INTO "django_geo_db_city" VALUES(22063,'Wilmore','Wilmore, Kansas',26840,20);
INSERT INTO "django_geo_db_city" VALUES(22064,'Winfield','Winfield, Kansas',26841,20);
INSERT INTO "django_geo_db_city" VALUES(22065,'Zenda','Zenda, Kansas',26842,20);
INSERT INTO "django_geo_db_city" VALUES(22066,'Wichita','Wichita, Kansas',26843,20);
INSERT INTO "django_geo_db_city" VALUES(22067,'McConnell A F B','McConnell A F B, Kansas',26863,20);
INSERT INTO "django_geo_db_city" VALUES(22068,'Independence','Independence, Kansas',26876,20);
INSERT INTO "django_geo_db_city" VALUES(22069,'Altamont','Altamont, Kansas',26877,20);
INSERT INTO "django_geo_db_city" VALUES(22070,'Bartlett','Bartlett, Kansas',26878,20);
INSERT INTO "django_geo_db_city" VALUES(22071,'Caney','Caney, Kansas',26879,20);
INSERT INTO "django_geo_db_city" VALUES(22072,'Chautauqua','Chautauqua, Kansas',26880,20);
INSERT INTO "django_geo_db_city" VALUES(22073,'Cherryvale','Cherryvale, Kansas',26881,20);
INSERT INTO "django_geo_db_city" VALUES(22074,'Chetopa','Chetopa, Kansas',26882,20);
INSERT INTO "django_geo_db_city" VALUES(22075,'Coffeyville','Coffeyville, Kansas',26883,20);
INSERT INTO "django_geo_db_city" VALUES(22076,'Howard','Howard, Kansas',26884,20);
INSERT INTO "django_geo_db_city" VALUES(22077,'Dearing','Dearing, Kansas',26885,20);
INSERT INTO "django_geo_db_city" VALUES(22078,'Dennis','Dennis, Kansas',26886,20);
INSERT INTO "django_geo_db_city" VALUES(22079,'Edna','Edna, Kansas',26887,20);
INSERT INTO "django_geo_db_city" VALUES(22080,'Elk City','Elk City, Kansas',26888,20);
INSERT INTO "django_geo_db_city" VALUES(22081,'Elk Falls','Elk Falls, Kansas',26889,20);
INSERT INTO "django_geo_db_city" VALUES(22082,'Grenola','Grenola, Kansas',26890,20);
INSERT INTO "django_geo_db_city" VALUES(22083,'Havana','Havana, Kansas',26891,20);
INSERT INTO "django_geo_db_city" VALUES(22084,'Liberty','Liberty, Kansas',26893,20);
INSERT INTO "django_geo_db_city" VALUES(22085,'Longton','Longton, Kansas',26894,20);
INSERT INTO "django_geo_db_city" VALUES(22086,'Moline','Moline, Kansas',26895,20);
INSERT INTO "django_geo_db_city" VALUES(22087,'Mound Valley','Mound Valley, Kansas',26896,20);
INSERT INTO "django_geo_db_city" VALUES(22088,'Niotaze','Niotaze, Kansas',26897,20);
INSERT INTO "django_geo_db_city" VALUES(22089,'Oswego','Oswego, Kansas',26898,20);
INSERT INTO "django_geo_db_city" VALUES(22090,'Parsons','Parsons, Kansas',26899,20);
INSERT INTO "django_geo_db_city" VALUES(22091,'Peru','Peru, Kansas',26900,20);
INSERT INTO "django_geo_db_city" VALUES(22092,'Sedan','Sedan, Kansas',26901,20);
INSERT INTO "django_geo_db_city" VALUES(22093,'Sycamore','Sycamore, Kansas',26902,20);
INSERT INTO "django_geo_db_city" VALUES(22094,'Tyro','Tyro, Kansas',26903,20);
INSERT INTO "django_geo_db_city" VALUES(22095,'Salina','Salina, Kansas',26904,20);
INSERT INTO "django_geo_db_city" VALUES(22096,'Abilene','Abilene, Kansas',26906,20);
INSERT INTO "django_geo_db_city" VALUES(22097,'Assaria','Assaria, Kansas',26908,20);
INSERT INTO "django_geo_db_city" VALUES(22098,'Aurora','Aurora, Kansas',26909,20);
INSERT INTO "django_geo_db_city" VALUES(22099,'Barnard','Barnard, Kansas',26910,20);
INSERT INTO "django_geo_db_city" VALUES(22100,'Union','Union, Kansas',26911,20);
INSERT INTO "django_geo_db_city" VALUES(22101,'Beloit','Beloit, Kansas',26912,20);
INSERT INTO "django_geo_db_city" VALUES(22102,'Bennington','Bennington, Kansas',26913,20);
INSERT INTO "django_geo_db_city" VALUES(22103,'Beverly','Beverly, Kansas',26914,20);
INSERT INTO "django_geo_db_city" VALUES(22104,'Brookville','Brookville, Kansas',26915,20);
INSERT INTO "django_geo_db_city" VALUES(22105,'Bushton','Bushton, Kansas',26916,20);
INSERT INTO "django_geo_db_city" VALUES(22106,'Canton','Canton, Kansas',26917,20);
INSERT INTO "django_geo_db_city" VALUES(22107,'Cawker City','Cawker City, Kansas',26918,20);
INSERT INTO "django_geo_db_city" VALUES(22108,'Chapman','Chapman, Kansas',26919,20);
INSERT INTO "django_geo_db_city" VALUES(22109,'Clay Center','Clay Center, Kansas',26920,20);
INSERT INTO "django_geo_db_city" VALUES(22110,'Delphos','Delphos, Kansas',26922,20);
INSERT INTO "django_geo_db_city" VALUES(22111,'Downs','Downs, Kansas',26923,20);
INSERT INTO "django_geo_db_city" VALUES(22112,'Durham','Durham, Kansas',26924,20);
INSERT INTO "django_geo_db_city" VALUES(22113,'Ellsworth','Ellsworth, Kansas',26925,20);
INSERT INTO "django_geo_db_city" VALUES(22114,'Enterprise','Enterprise, Kansas',26926,20);
INSERT INTO "django_geo_db_city" VALUES(22115,'Falun','Falun, Kansas',26927,20);
INSERT INTO "django_geo_db_city" VALUES(22116,'Galva','Galva, Kansas',26928,20);
INSERT INTO "django_geo_db_city" VALUES(22117,'Geneseo','Geneseo, Kansas',26929,20);
INSERT INTO "django_geo_db_city" VALUES(22118,'Glasco','Glasco, Kansas',26930,20);
INSERT INTO "django_geo_db_city" VALUES(22119,'Glen Elder','Glen Elder, Kansas',26931,20);
INSERT INTO "django_geo_db_city" VALUES(22120,'Green','Green, Kansas',26932,20);
INSERT INTO "django_geo_db_city" VALUES(22121,'Gypsum','Gypsum, Kansas',26933,20);
INSERT INTO "django_geo_db_city" VALUES(22122,'Herington','Herington, Kansas',26934,20);
INSERT INTO "django_geo_db_city" VALUES(22123,'Holyrood','Holyrood, Kansas',26935,20);
INSERT INTO "django_geo_db_city" VALUES(22124,'Hope','Hope, Kansas',26936,20);
INSERT INTO "django_geo_db_city" VALUES(22125,'Hunter','Hunter, Kansas',26937,20);
INSERT INTO "django_geo_db_city" VALUES(22126,'Kanopolis','Kanopolis, Kansas',26938,20);
INSERT INTO "django_geo_db_city" VALUES(22127,'Lindsborg','Lindsborg, Kansas',26940,20);
INSERT INTO "django_geo_db_city" VALUES(22128,'Little River','Little River, Kansas',26941,20);
INSERT INTO "django_geo_db_city" VALUES(22129,'Longford','Longford, Kansas',26942,20);
INSERT INTO "django_geo_db_city" VALUES(22130,'Lorraine','Lorraine, Kansas',26943,20);
INSERT INTO "django_geo_db_city" VALUES(22131,'Mcpherson','Mcpherson, Kansas',26944,20);
INSERT INTO "django_geo_db_city" VALUES(22132,'Marquette','Marquette, Kansas',26945,20);
INSERT INTO "django_geo_db_city" VALUES(22133,'Miltonvale','Miltonvale, Kansas',26946,20);
INSERT INTO "django_geo_db_city" VALUES(22134,'Minneapolis','Minneapolis, Kansas',26947,20);
INSERT INTO "django_geo_db_city" VALUES(22135,'Morganville','Morganville, Kansas',26948,20);
INSERT INTO "django_geo_db_city" VALUES(22136,'New Cambria','New Cambria, Kansas',26949,20);
INSERT INTO "django_geo_db_city" VALUES(22137,'Osborne','Osborne, Kansas',26951,20);
INSERT INTO "django_geo_db_city" VALUES(22138,'Portis','Portis, Kansas',26952,20);
INSERT INTO "django_geo_db_city" VALUES(22139,'Ramona','Ramona, Kansas',26953,20);
INSERT INTO "django_geo_db_city" VALUES(22140,'Roxbury','Roxbury, Kansas',26954,20);
INSERT INTO "django_geo_db_city" VALUES(22141,'Simpson','Simpson, Kansas',26955,20);
INSERT INTO "django_geo_db_city" VALUES(22142,'Smolan','Smolan, Kansas',26956,20);
INSERT INTO "django_geo_db_city" VALUES(22143,'Solomon','Solomon, Kansas',26957,20);
INSERT INTO "django_geo_db_city" VALUES(22144,'Sylvan Grove','Sylvan Grove, Kansas',26958,20);
INSERT INTO "django_geo_db_city" VALUES(22145,'Talmage','Talmage, Kansas',26959,20);
INSERT INTO "django_geo_db_city" VALUES(22146,'Tampa','Tampa, Kansas',26960,20);
INSERT INTO "django_geo_db_city" VALUES(22147,'Tescott','Tescott, Kansas',26961,20);
INSERT INTO "django_geo_db_city" VALUES(22148,'Tipton','Tipton, Kansas',26962,20);
INSERT INTO "django_geo_db_city" VALUES(22149,'Wakefield','Wakefield, Kansas',26963,20);
INSERT INTO "django_geo_db_city" VALUES(22150,'Wilson','Wilson, Kansas',26965,20);
INSERT INTO "django_geo_db_city" VALUES(22151,'Windom','Windom, Kansas',26966,20);
INSERT INTO "django_geo_db_city" VALUES(22152,'Woodbine','Woodbine, Kansas',26967,20);
INSERT INTO "django_geo_db_city" VALUES(22153,'Hutchinson','Hutchinson, Kansas',26969,20);
INSERT INTO "django_geo_db_city" VALUES(22154,'South Hutchinson','South Hutchinson, Kansas',26972,20);
INSERT INTO "django_geo_db_city" VALUES(22155,'Abbyville','Abbyville, Kansas',26973,20);
INSERT INTO "django_geo_db_city" VALUES(22156,'Albert','Albert, Kansas',26974,20);
INSERT INTO "django_geo_db_city" VALUES(22157,'Alden','Alden, Kansas',26975,20);
INSERT INTO "django_geo_db_city" VALUES(22158,'Alexander','Alexander, Kansas',26976,20);
INSERT INTO "django_geo_db_city" VALUES(22159,'Arlington','Arlington, Kansas',26977,20);
INSERT INTO "django_geo_db_city" VALUES(22160,'Arnold','Arnold, Kansas',26978,20);
INSERT INTO "django_geo_db_city" VALUES(22161,'Bazine','Bazine, Kansas',26979,20);
INSERT INTO "django_geo_db_city" VALUES(22162,'Beeler','Beeler, Kansas',26980,20);
INSERT INTO "django_geo_db_city" VALUES(22163,'Belpre','Belpre, Kansas',26981,20);
INSERT INTO "django_geo_db_city" VALUES(22164,'Bison','Bison, Kansas',26982,20);
INSERT INTO "django_geo_db_city" VALUES(22165,'Brownell','Brownell, Kansas',26983,20);
INSERT INTO "django_geo_db_city" VALUES(22166,'Buhler','Buhler, Kansas',26984,20);
INSERT INTO "django_geo_db_city" VALUES(22167,'Burdett','Burdett, Kansas',26985,20);
INSERT INTO "django_geo_db_city" VALUES(22168,'Chase','Chase, Kansas',26986,20);
INSERT INTO "django_geo_db_city" VALUES(22169,'Claflin','Claflin, Kansas',26987,20);
INSERT INTO "django_geo_db_city" VALUES(22170,'Ellinwood','Ellinwood, Kansas',26988,20);
INSERT INTO "django_geo_db_city" VALUES(22171,'Garfield','Garfield, Kansas',26989,20);
INSERT INTO "django_geo_db_city" VALUES(22172,'Great Bend','Great Bend, Kansas',26990,20);
INSERT INTO "django_geo_db_city" VALUES(22173,'Haven','Haven, Kansas',26991,20);
INSERT INTO "django_geo_db_city" VALUES(22174,'Hoisington','Hoisington, Kansas',26992,20);
INSERT INTO "django_geo_db_city" VALUES(22175,'Hudson','Hudson, Kansas',26993,20);
INSERT INTO "django_geo_db_city" VALUES(22176,'Inman','Inman, Kansas',26994,20);
INSERT INTO "django_geo_db_city" VALUES(22177,'Kinsley','Kinsley, Kansas',26995,20);
INSERT INTO "django_geo_db_city" VALUES(22178,'La Crosse','La Crosse, Kansas',26996,20);
INSERT INTO "django_geo_db_city" VALUES(22179,'Larned','Larned, Kansas',26997,20);
INSERT INTO "django_geo_db_city" VALUES(22180,'Lewis','Lewis, Kansas',26998,20);
INSERT INTO "django_geo_db_city" VALUES(22181,'Liebenthal','Liebenthal, Kansas',26999,20);
INSERT INTO "django_geo_db_city" VALUES(22182,'Lyons','Lyons, Kansas',27000,20);
INSERT INTO "django_geo_db_city" VALUES(22183,'McCracken','McCracken, Kansas',27001,20);
INSERT INTO "django_geo_db_city" VALUES(22184,'Macksville','Macksville, Kansas',27002,20);
INSERT INTO "django_geo_db_city" VALUES(22185,'Nekoma','Nekoma, Kansas',27003,20);
INSERT INTO "django_geo_db_city" VALUES(22186,'Ness City','Ness City, Kansas',27004,20);
INSERT INTO "django_geo_db_city" VALUES(22187,'Nickerson','Nickerson, Kansas',27005,20);
INSERT INTO "django_geo_db_city" VALUES(22188,'Offerle','Offerle, Kansas',27006,20);
INSERT INTO "django_geo_db_city" VALUES(22189,'Olmitz','Olmitz, Kansas',27007,20);
INSERT INTO "django_geo_db_city" VALUES(22190,'Otis','Otis, Kansas',27008,20);
INSERT INTO "django_geo_db_city" VALUES(22191,'Partridge','Partridge, Kansas',27009,20);
INSERT INTO "django_geo_db_city" VALUES(22192,'Pawnee Rock','Pawnee Rock, Kansas',27010,20);
INSERT INTO "django_geo_db_city" VALUES(22193,'Plevna','Plevna, Kansas',27011,20);
INSERT INTO "django_geo_db_city" VALUES(22194,'Pretty Prairie','Pretty Prairie, Kansas',27012,20);
INSERT INTO "django_geo_db_city" VALUES(22195,'Ransom','Ransom, Kansas',27013,20);
INSERT INTO "django_geo_db_city" VALUES(22196,'Raymond','Raymond, Kansas',27014,20);
INSERT INTO "django_geo_db_city" VALUES(22197,'Rozel','Rozel, Kansas',27015,20);
INSERT INTO "django_geo_db_city" VALUES(22198,'Rush Center','Rush Center, Kansas',27016,20);
INSERT INTO "django_geo_db_city" VALUES(22199,'Saint John','Saint John, Kansas',27017,20);
INSERT INTO "django_geo_db_city" VALUES(22200,'Stafford','Stafford, Kansas',27018,20);
INSERT INTO "django_geo_db_city" VALUES(22201,'Sterling','Sterling, Kansas',27019,20);
INSERT INTO "django_geo_db_city" VALUES(22202,'Sylvia','Sylvia, Kansas',27020,20);
INSERT INTO "django_geo_db_city" VALUES(22203,'Turon','Turon, Kansas',27021,20);
INSERT INTO "django_geo_db_city" VALUES(22204,'Utica','Utica, Kansas',27022,20);
INSERT INTO "django_geo_db_city" VALUES(22205,'Yoder','Yoder, Kansas',27023,20);
INSERT INTO "django_geo_db_city" VALUES(22206,'Hays','Hays, Kansas',27024,20);
INSERT INTO "django_geo_db_city" VALUES(22207,'Agra','Agra, Kansas',27025,20);
INSERT INTO "django_geo_db_city" VALUES(22208,'Almena','Almena, Kansas',27026,20);
INSERT INTO "django_geo_db_city" VALUES(22209,'Alton','Alton, Kansas',27027,20);
INSERT INTO "django_geo_db_city" VALUES(22210,'Bogue','Bogue, Kansas',27028,20);
INSERT INTO "django_geo_db_city" VALUES(22211,'Bunker Hill','Bunker Hill, Kansas',27029,20);
INSERT INTO "django_geo_db_city" VALUES(22212,'Catharine','Catharine, Kansas',27030,20);
INSERT INTO "django_geo_db_city" VALUES(22213,'Cedar','Cedar, Kansas',27031,20);
INSERT INTO "django_geo_db_city" VALUES(22214,'Clayton','Clayton, Kansas',27032,20);
INSERT INTO "django_geo_db_city" VALUES(22215,'Collyer','Collyer, Kansas',27034,20);
INSERT INTO "django_geo_db_city" VALUES(22216,'Damar','Damar, Kansas',27035,20);
INSERT INTO "django_geo_db_city" VALUES(22217,'Dorrance','Dorrance, Kansas',27036,20);
INSERT INTO "django_geo_db_city" VALUES(22218,'Dresden','Dresden, Kansas',27037,20);
INSERT INTO "django_geo_db_city" VALUES(22219,'Ellis','Ellis, Kansas',27038,20);
INSERT INTO "django_geo_db_city" VALUES(22220,'Gaylord','Gaylord, Kansas',27039,20);
INSERT INTO "django_geo_db_city" VALUES(22221,'Glade','Glade, Kansas',27040,20);
INSERT INTO "django_geo_db_city" VALUES(22222,'Gorham','Gorham, Kansas',27041,20);
INSERT INTO "django_geo_db_city" VALUES(22223,'Hill City','Hill City, Kansas',27042,20);
INSERT INTO "django_geo_db_city" VALUES(22224,'Jennings','Jennings, Kansas',27043,20);
INSERT INTO "django_geo_db_city" VALUES(22225,'Kirwin','Kirwin, Kansas',27044,20);
INSERT INTO "django_geo_db_city" VALUES(22226,'Lenora','Lenora, Kansas',27045,20);
INSERT INTO "django_geo_db_city" VALUES(22227,'Logan','Logan, Kansas',27046,20);
INSERT INTO "django_geo_db_city" VALUES(22228,'Long Island','Long Island, Kansas',27047,20);
INSERT INTO "django_geo_db_city" VALUES(22229,'Lucas','Lucas, Kansas',27048,20);
INSERT INTO "django_geo_db_city" VALUES(22230,'Luray','Luray, Kansas',27049,20);
INSERT INTO "django_geo_db_city" VALUES(22231,'Morland','Morland, Kansas',27050,20);
INSERT INTO "django_geo_db_city" VALUES(22232,'Natoma','Natoma, Kansas',27051,20);
INSERT INTO "django_geo_db_city" VALUES(22233,'Norcatur','Norcatur, Kansas',27052,20);
INSERT INTO "django_geo_db_city" VALUES(22234,'Norton','Norton, Kansas',27053,20);
INSERT INTO "django_geo_db_city" VALUES(22235,'Ogallah','Ogallah, Kansas',27054,20);
INSERT INTO "django_geo_db_city" VALUES(22236,'Palco','Palco, Kansas',27055,20);
INSERT INTO "django_geo_db_city" VALUES(22237,'Paradise','Paradise, Kansas',27056,20);
INSERT INTO "django_geo_db_city" VALUES(22238,'Penokee','Penokee, Kansas',27057,20);
INSERT INTO "django_geo_db_city" VALUES(22239,'Pfeifer','Pfeifer, Kansas',27058,20);
INSERT INTO "django_geo_db_city" VALUES(22240,'Phillipsburg','Phillipsburg, Kansas',27059,20);
INSERT INTO "django_geo_db_city" VALUES(22241,'Plainville','Plainville, Kansas',27060,20);
INSERT INTO "django_geo_db_city" VALUES(22242,'Prairie View','Prairie View, Kansas',27061,20);
INSERT INTO "django_geo_db_city" VALUES(22243,'Russell','Russell, Kansas',27062,20);
INSERT INTO "django_geo_db_city" VALUES(22244,'Schoenchen','Schoenchen, Kansas',27064,20);
INSERT INTO "django_geo_db_city" VALUES(22245,'Stockton','Stockton, Kansas',27065,20);
INSERT INTO "django_geo_db_city" VALUES(22246,'Stuttgart','Stuttgart, Kansas',27066,20);
INSERT INTO "django_geo_db_city" VALUES(22247,'Victoria','Victoria, Kansas',27067,20);
INSERT INTO "django_geo_db_city" VALUES(22248,'Wa Keeney','Wa Keeney, Kansas',27068,20);
INSERT INTO "django_geo_db_city" VALUES(22249,'Waldo','Waldo, Kansas',27069,20);
INSERT INTO "django_geo_db_city" VALUES(22250,'Walker','Walker, Kansas',27070,20);
INSERT INTO "django_geo_db_city" VALUES(22251,'Woodston','Woodston, Kansas',27071,20);
INSERT INTO "django_geo_db_city" VALUES(22252,'Colby','Colby, Kansas',27072,20);
INSERT INTO "django_geo_db_city" VALUES(22253,'Atwood','Atwood, Kansas',27073,20);
INSERT INTO "django_geo_db_city" VALUES(22254,'Bird City','Bird City, Kansas',27074,20);
INSERT INTO "django_geo_db_city" VALUES(22255,'Brewster','Brewster, Kansas',27075,20);
INSERT INTO "django_geo_db_city" VALUES(22256,'Edson','Edson, Kansas',27076,20);
INSERT INTO "django_geo_db_city" VALUES(22257,'Gem','Gem, Kansas',27077,20);
INSERT INTO "django_geo_db_city" VALUES(22258,'Goodland','Goodland, Kansas',27078,20);
INSERT INTO "django_geo_db_city" VALUES(22259,'Gove','Gove, Kansas',27079,20);
INSERT INTO "django_geo_db_city" VALUES(22260,'Grainfield','Grainfield, Kansas',27080,20);
INSERT INTO "django_geo_db_city" VALUES(22261,'Grinnell','Grinnell, Kansas',27081,20);
INSERT INTO "django_geo_db_city" VALUES(22262,'Herndon','Herndon, Kansas',27082,20);
INSERT INTO "django_geo_db_city" VALUES(22263,'Hoxie','Hoxie, Kansas',27083,20);
INSERT INTO "django_geo_db_city" VALUES(22264,'Kanorado','Kanorado, Kansas',27084,20);
INSERT INTO "django_geo_db_city" VALUES(22265,'Levant','Levant, Kansas',27085,20);
INSERT INTO "django_geo_db_city" VALUES(22266,'Ludell','Ludell, Kansas',27086,20);
INSERT INTO "django_geo_db_city" VALUES(22267,'McDonald','McDonald, Kansas',27087,20);
INSERT INTO "django_geo_db_city" VALUES(22268,'Monument','Monument, Kansas',27088,20);
INSERT INTO "django_geo_db_city" VALUES(22269,'Oakley','Oakley, Kansas',27089,20);
INSERT INTO "django_geo_db_city" VALUES(22270,'Oberlin','Oberlin, Kansas',27090,20);
INSERT INTO "django_geo_db_city" VALUES(22271,'Park','Park, Kansas',27091,20);
INSERT INTO "django_geo_db_city" VALUES(22272,'Quinter','Quinter, Kansas',27092,20);
INSERT INTO "django_geo_db_city" VALUES(22273,'Rexford','Rexford, Kansas',27093,20);
INSERT INTO "django_geo_db_city" VALUES(22274,'Saint Francis','Saint Francis, Kansas',27094,20);
INSERT INTO "django_geo_db_city" VALUES(22275,'Selden','Selden, Kansas',27095,20);
INSERT INTO "django_geo_db_city" VALUES(22276,'Sharon Springs','Sharon Springs, Kansas',27096,20);
INSERT INTO "django_geo_db_city" VALUES(22277,'Wallace','Wallace, Kansas',27097,20);
INSERT INTO "django_geo_db_city" VALUES(22278,'Weskan','Weskan, Kansas',27098,20);
INSERT INTO "django_geo_db_city" VALUES(22279,'Winona','Winona, Kansas',27099,20);
INSERT INTO "django_geo_db_city" VALUES(22280,'Dodge City','Dodge City, Kansas',27100,20);
INSERT INTO "django_geo_db_city" VALUES(22281,'Ashland','Ashland, Kansas',27101,20);
INSERT INTO "django_geo_db_city" VALUES(22282,'Bucklin','Bucklin, Kansas',27102,20);
INSERT INTO "django_geo_db_city" VALUES(22283,'Cimarron','Cimarron, Kansas',27103,20);
INSERT INTO "django_geo_db_city" VALUES(22284,'Coolidge','Coolidge, Kansas',27104,20);
INSERT INTO "django_geo_db_city" VALUES(22285,'Copeland','Copeland, Kansas',27105,20);
INSERT INTO "django_geo_db_city" VALUES(22286,'Deerfield','Deerfield, Kansas',27106,20);
INSERT INTO "django_geo_db_city" VALUES(22287,'Dighton','Dighton, Kansas',27107,20);
INSERT INTO "django_geo_db_city" VALUES(22288,'Englewood','Englewood, Kansas',27108,20);
INSERT INTO "django_geo_db_city" VALUES(22289,'Ensign','Ensign, Kansas',27109,20);
INSERT INTO "django_geo_db_city" VALUES(22290,'Ford','Ford, Kansas',27110,20);
INSERT INTO "django_geo_db_city" VALUES(22291,'Fowler','Fowler, Kansas',27111,20);
INSERT INTO "django_geo_db_city" VALUES(22292,'Bloom','Bloom, Kansas',27112,20);
INSERT INTO "django_geo_db_city" VALUES(22293,'Garden City','Garden City, Kansas',27113,20);
INSERT INTO "django_geo_db_city" VALUES(22294,'Hanston','Hanston, Kansas',27114,20);
INSERT INTO "django_geo_db_city" VALUES(22295,'Healy','Healy, Kansas',27115,20);
INSERT INTO "django_geo_db_city" VALUES(22296,'Holcomb','Holcomb, Kansas',27116,20);
INSERT INTO "django_geo_db_city" VALUES(22297,'Ingalls','Ingalls, Kansas',27118,20);
INSERT INTO "django_geo_db_city" VALUES(22298,'Jetmore','Jetmore, Kansas',27119,20);
INSERT INTO "django_geo_db_city" VALUES(22299,'Johnson','Johnson, Kansas',27120,20);
INSERT INTO "django_geo_db_city" VALUES(22300,'Kendall','Kendall, Kansas',27122,20);
INSERT INTO "django_geo_db_city" VALUES(22301,'Sodville','Sodville, Kansas',27123,20);
INSERT INTO "django_geo_db_city" VALUES(22302,'Kismet','Kismet, Kansas',27124,20);
INSERT INTO "django_geo_db_city" VALUES(22303,'Lakin','Lakin, Kansas',27125,20);
INSERT INTO "django_geo_db_city" VALUES(22304,'Leoti','Leoti, Kansas',27126,20);
INSERT INTO "django_geo_db_city" VALUES(22305,'Manter','Manter, Kansas',27127,20);
INSERT INTO "django_geo_db_city" VALUES(22306,'Marienthal','Marienthal, Kansas',27128,20);
INSERT INTO "django_geo_db_city" VALUES(22307,'Meade','Meade, Kansas',27129,20);
INSERT INTO "django_geo_db_city" VALUES(22308,'Minneola','Minneola, Kansas',27130,20);
INSERT INTO "django_geo_db_city" VALUES(22309,'Montezuma','Montezuma, Kansas',27131,20);
INSERT INTO "django_geo_db_city" VALUES(22310,'Pierceville','Pierceville, Kansas',27132,20);
INSERT INTO "django_geo_db_city" VALUES(22311,'Plains','Plains, Kansas',27133,20);
INSERT INTO "django_geo_db_city" VALUES(22312,'Satanta','Satanta, Kansas',27134,20);
INSERT INTO "django_geo_db_city" VALUES(22313,'Scott City','Scott City, Kansas',27135,20);
INSERT INTO "django_geo_db_city" VALUES(22314,'Spearville','Spearville, Kansas',27136,20);
INSERT INTO "django_geo_db_city" VALUES(22315,'Sublette','Sublette, Kansas',27137,20);
INSERT INTO "django_geo_db_city" VALUES(22316,'Syracuse','Syracuse, Kansas',27138,20);
INSERT INTO "django_geo_db_city" VALUES(22317,'Tribune','Tribune, Kansas',27139,20);
INSERT INTO "django_geo_db_city" VALUES(22318,'Ulysses','Ulysses, Kansas',27140,20);
INSERT INTO "django_geo_db_city" VALUES(22319,'Wright','Wright, Kansas',27141,20);
INSERT INTO "django_geo_db_city" VALUES(22320,'Liberal','Liberal, Kansas',27142,20);
INSERT INTO "django_geo_db_city" VALUES(22321,'Colfax','Colfax, Kansas',27144,20);
INSERT INTO "django_geo_db_city" VALUES(22322,'Elkhart','Elkhart, Kansas',27145,20);
INSERT INTO "django_geo_db_city" VALUES(22323,'Hugoton','Hugoton, Kansas',27146,20);
INSERT INTO "django_geo_db_city" VALUES(22324,'Moscow','Moscow, Kansas',27147,20);
INSERT INTO "django_geo_db_city" VALUES(22325,'Richfield','Richfield, Kansas',27148,20);
INSERT INTO "django_geo_db_city" VALUES(22326,'Rolla','Rolla, Kansas',27149,20);
INSERT INTO "django_geo_db_city" VALUES(22327,'Abie','Abie, Nebraska',27150,27);
INSERT INTO "django_geo_db_city" VALUES(22328,'Arlington','Arlington, Nebraska',27151,27);
INSERT INTO "django_geo_db_city" VALUES(22329,'Ashland','Ashland, Nebraska',27152,27);
INSERT INTO "django_geo_db_city" VALUES(22330,'Bancroft','Bancroft, Nebraska',27153,27);
INSERT INTO "django_geo_db_city" VALUES(22331,'Bellevue','Bellevue, Nebraska',27154,27);
INSERT INTO "django_geo_db_city" VALUES(22332,'Bennington','Bennington, Nebraska',27155,27);
INSERT INTO "django_geo_db_city" VALUES(22333,'Blair','Blair, Nebraska',27156,27);
INSERT INTO "django_geo_db_city" VALUES(22334,'Boys Town','Boys Town, Nebraska',27158,27);
INSERT INTO "django_geo_db_city" VALUES(22335,'Bruno','Bruno, Nebraska',27159,27);
INSERT INTO "django_geo_db_city" VALUES(22336,'Cedar Bluffs','Cedar Bluffs, Nebraska',27160,27);
INSERT INTO "django_geo_db_city" VALUES(22337,'Cedar Creek','Cedar Creek, Nebraska',27161,27);
INSERT INTO "django_geo_db_city" VALUES(22338,'Ceresco','Ceresco, Nebraska',27162,27);
INSERT INTO "django_geo_db_city" VALUES(22339,'Colon','Colon, Nebraska',27163,27);
INSERT INTO "django_geo_db_city" VALUES(22340,'Craig','Craig, Nebraska',27164,27);
INSERT INTO "django_geo_db_city" VALUES(22341,'Decatur','Decatur, Nebraska',27165,27);
INSERT INTO "django_geo_db_city" VALUES(22342,'Elkhorn','Elkhorn, Nebraska',27166,27);
INSERT INTO "django_geo_db_city" VALUES(22343,'Fort Calhoun','Fort Calhoun, Nebraska',27167,27);
INSERT INTO "django_geo_db_city" VALUES(22344,'Fremont','Fremont, Nebraska',27168,27);
INSERT INTO "django_geo_db_city" VALUES(22345,'Gretna','Gretna, Nebraska',27170,27);
INSERT INTO "django_geo_db_city" VALUES(22346,'Herman','Herman, Nebraska',27171,27);
INSERT INTO "django_geo_db_city" VALUES(22347,'Homer','Homer, Nebraska',27172,27);
INSERT INTO "django_geo_db_city" VALUES(22348,'Hooper','Hooper, Nebraska',27173,27);
INSERT INTO "django_geo_db_city" VALUES(22349,'Linwood','Linwood, Nebraska',27174,27);
INSERT INTO "django_geo_db_city" VALUES(22350,'Ithaca','Ithaca, Nebraska',27175,27);
INSERT INTO "django_geo_db_city" VALUES(22351,'Kennard','Kennard, Nebraska',27176,27);
INSERT INTO "django_geo_db_city" VALUES(22352,'Leshara','Leshara, Nebraska',27177,27);
INSERT INTO "django_geo_db_city" VALUES(22353,'Louisville','Louisville, Nebraska',27179,27);
INSERT INTO "django_geo_db_city" VALUES(22354,'Lyons','Lyons, Nebraska',27180,27);
INSERT INTO "django_geo_db_city" VALUES(22355,'Macy','Macy, Nebraska',27181,27);
INSERT INTO "django_geo_db_city" VALUES(22356,'Malmo','Malmo, Nebraska',27182,27);
INSERT INTO "django_geo_db_city" VALUES(22357,'Mead','Mead, Nebraska',27183,27);
INSERT INTO "django_geo_db_city" VALUES(22358,'Memphis','Memphis, Nebraska',27184,27);
INSERT INTO "django_geo_db_city" VALUES(22359,'Nickerson','Nickerson, Nebraska',27185,27);
INSERT INTO "django_geo_db_city" VALUES(22360,'Oakland','Oakland, Nebraska',27186,27);
INSERT INTO "django_geo_db_city" VALUES(22361,'Papillion','Papillion, Nebraska',27187,27);
INSERT INTO "django_geo_db_city" VALUES(22362,'Pender','Pender, Nebraska',27188,27);
INSERT INTO "django_geo_db_city" VALUES(22363,'Plattsmouth','Plattsmouth, Nebraska',27189,27);
INSERT INTO "django_geo_db_city" VALUES(22364,'Prague','Prague, Nebraska',27190,27);
INSERT INTO "django_geo_db_city" VALUES(22365,'Richfield','Richfield, Nebraska',27191,27);
INSERT INTO "django_geo_db_city" VALUES(22366,'Rosalie','Rosalie, Nebraska',27192,27);
INSERT INTO "django_geo_db_city" VALUES(22367,'St Columbans','St Columbans, Nebraska',27193,27);
INSERT INTO "django_geo_db_city" VALUES(22368,'Scribner','Scribner, Nebraska',27194,27);
INSERT INTO "django_geo_db_city" VALUES(22369,'South Bend','South Bend, Nebraska',27195,27);
INSERT INTO "django_geo_db_city" VALUES(22370,'Springfield','Springfield, Nebraska',27196,27);
INSERT INTO "django_geo_db_city" VALUES(22371,'Tekamah','Tekamah, Nebraska',27197,27);
INSERT INTO "django_geo_db_city" VALUES(22372,'Thurston','Thurston, Nebraska',27198,27);
INSERT INTO "django_geo_db_city" VALUES(22373,'Uehling','Uehling, Nebraska',27199,27);
INSERT INTO "django_geo_db_city" VALUES(22374,'Valley','Valley, Nebraska',27200,27);
INSERT INTO "django_geo_db_city" VALUES(22375,'Valparaiso','Valparaiso, Nebraska',27201,27);
INSERT INTO "django_geo_db_city" VALUES(22376,'Wahoo','Wahoo, Nebraska',27202,27);
INSERT INTO "django_geo_db_city" VALUES(22377,'Walthill','Walthill, Nebraska',27203,27);
INSERT INTO "django_geo_db_city" VALUES(22378,'Washington','Washington, Nebraska',27204,27);
INSERT INTO "django_geo_db_city" VALUES(22379,'Waterloo','Waterloo, Nebraska',27205,27);
INSERT INTO "django_geo_db_city" VALUES(22380,'Weston','Weston, Nebraska',27206,27);
INSERT INTO "django_geo_db_city" VALUES(22381,'Winnebago','Winnebago, Nebraska',27207,27);
INSERT INTO "django_geo_db_city" VALUES(22382,'Winslow','Winslow, Nebraska',27208,27);
INSERT INTO "django_geo_db_city" VALUES(22383,'Yutan','Yutan, Nebraska',27209,27);
INSERT INTO "django_geo_db_city" VALUES(22384,'Omaha','Omaha, Nebraska',27210,27);
INSERT INTO "django_geo_db_city" VALUES(22385,'Offutt A F B','Offutt A F B, Nebraska',27220,27);
INSERT INTO "django_geo_db_city" VALUES(22386,'La Vista','La Vista, Nebraska',27229,27);
INSERT INTO "django_geo_db_city" VALUES(22387,'Central City','Central City, Nebraska',27246,27);
INSERT INTO "django_geo_db_city" VALUES(22388,'Adams','Adams, Nebraska',27248,27);
INSERT INTO "django_geo_db_city" VALUES(22389,'Alexandria','Alexandria, Nebraska',27249,27);
INSERT INTO "django_geo_db_city" VALUES(22390,'Alvo','Alvo, Nebraska',27250,27);
INSERT INTO "django_geo_db_city" VALUES(22391,'Auburn','Auburn, Nebraska',27251,27);
INSERT INTO "django_geo_db_city" VALUES(22392,'Avoca','Avoca, Nebraska',27252,27);
INSERT INTO "django_geo_db_city" VALUES(22393,'Barneston','Barneston, Nebraska',27253,27);
INSERT INTO "django_geo_db_city" VALUES(22394,'Beatrice','Beatrice, Nebraska',27254,27);
INSERT INTO "django_geo_db_city" VALUES(22395,'Beaver Crossing','Beaver Crossing, Nebraska',27255,27);
INSERT INTO "django_geo_db_city" VALUES(22396,'Bee','Bee, Nebraska',27256,27);
INSERT INTO "django_geo_db_city" VALUES(22397,'Belvidere','Belvidere, Nebraska',27257,27);
INSERT INTO "django_geo_db_city" VALUES(22398,'Benedict','Benedict, Nebraska',27258,27);
INSERT INTO "django_geo_db_city" VALUES(22399,'Bennet','Bennet, Nebraska',27259,27);
INSERT INTO "django_geo_db_city" VALUES(22400,'Blue Springs','Blue Springs, Nebraska',27260,27);
INSERT INTO "django_geo_db_city" VALUES(22401,'Bradshaw','Bradshaw, Nebraska',27261,27);
INSERT INTO "django_geo_db_city" VALUES(22402,'Brock','Brock, Nebraska',27262,27);
INSERT INTO "django_geo_db_city" VALUES(22403,'Brownville','Brownville, Nebraska',27263,27);
INSERT INTO "django_geo_db_city" VALUES(22404,'Bruning','Bruning, Nebraska',27264,27);
INSERT INTO "django_geo_db_city" VALUES(22405,'Burchard','Burchard, Nebraska',27265,27);
INSERT INTO "django_geo_db_city" VALUES(22406,'Burr','Burr, Nebraska',27266,27);
INSERT INTO "django_geo_db_city" VALUES(22407,'Byron','Byron, Nebraska',27267,27);
INSERT INTO "django_geo_db_city" VALUES(22408,'Carleton','Carleton, Nebraska',27268,27);
INSERT INTO "django_geo_db_city" VALUES(22409,'Chester','Chester, Nebraska',27269,27);
INSERT INTO "django_geo_db_city" VALUES(22410,'Clatonia','Clatonia, Nebraska',27270,27);
INSERT INTO "django_geo_db_city" VALUES(22411,'Cook','Cook, Nebraska',27271,27);
INSERT INTO "django_geo_db_city" VALUES(22412,'Cordova','Cordova, Nebraska',27272,27);
INSERT INTO "django_geo_db_city" VALUES(22413,'Cortland','Cortland, Nebraska',27273,27);
INSERT INTO "django_geo_db_city" VALUES(22414,'Crab Orchard','Crab Orchard, Nebraska',27274,27);
INSERT INTO "django_geo_db_city" VALUES(22415,'Crete','Crete, Nebraska',27275,27);
INSERT INTO "django_geo_db_city" VALUES(22416,'Davenport','Davenport, Nebraska',27276,27);
INSERT INTO "django_geo_db_city" VALUES(22417,'Davey','Davey, Nebraska',27277,27);
INSERT INTO "django_geo_db_city" VALUES(22418,'Dawson','Dawson, Nebraska',27278,27);
INSERT INTO "django_geo_db_city" VALUES(22419,'Daykin','Daykin, Nebraska',27279,27);
INSERT INTO "django_geo_db_city" VALUES(22420,'Denton','Denton, Nebraska',27280,27);
INSERT INTO "django_geo_db_city" VALUES(22421,'Deshler','Deshler, Nebraska',27281,27);
INSERT INTO "django_geo_db_city" VALUES(22422,'De Witt','De Witt, Nebraska',27282,27);
INSERT INTO "django_geo_db_city" VALUES(22423,'Diller','Diller, Nebraska',27283,27);
INSERT INTO "django_geo_db_city" VALUES(22424,'Dorchester','Dorchester, Nebraska',27284,27);
INSERT INTO "django_geo_db_city" VALUES(22425,'Douglas','Douglas, Nebraska',27285,27);
INSERT INTO "django_geo_db_city" VALUES(22426,'Du Bois','Du Bois, Nebraska',27286,27);
INSERT INTO "django_geo_db_city" VALUES(22427,'Dunbar','Dunbar, Nebraska',27287,27);
INSERT INTO "django_geo_db_city" VALUES(22428,'Eagle','Eagle, Nebraska',27288,27);
INSERT INTO "django_geo_db_city" VALUES(22429,'Elk Creek','Elk Creek, Nebraska',27289,27);
INSERT INTO "django_geo_db_city" VALUES(22430,'Elmwood','Elmwood, Nebraska',27290,27);
INSERT INTO "django_geo_db_city" VALUES(22431,'Endicott','Endicott, Nebraska',27291,27);
INSERT INTO "django_geo_db_city" VALUES(22432,'Exeter','Exeter, Nebraska',27292,27);
INSERT INTO "django_geo_db_city" VALUES(22433,'Fairbury','Fairbury, Nebraska',27293,27);
INSERT INTO "django_geo_db_city" VALUES(22434,'Fairmont','Fairmont, Nebraska',27294,27);
INSERT INTO "django_geo_db_city" VALUES(22435,'Falls City','Falls City, Nebraska',27295,27);
INSERT INTO "django_geo_db_city" VALUES(22436,'Filley','Filley, Nebraska',27296,27);
INSERT INTO "django_geo_db_city" VALUES(22437,'Firth','Firth, Nebraska',27297,27);
INSERT INTO "django_geo_db_city" VALUES(22438,'Friend','Friend, Nebraska',27298,27);
INSERT INTO "django_geo_db_city" VALUES(22439,'Garland','Garland, Nebraska',27299,27);
INSERT INTO "django_geo_db_city" VALUES(22440,'Geneva','Geneva, Nebraska',27300,27);
INSERT INTO "django_geo_db_city" VALUES(22441,'Gilead','Gilead, Nebraska',27301,27);
INSERT INTO "django_geo_db_city" VALUES(22442,'Goehner','Goehner, Nebraska',27302,27);
INSERT INTO "django_geo_db_city" VALUES(22443,'Grafton','Grafton, Nebraska',27303,27);
INSERT INTO "django_geo_db_city" VALUES(22444,'Greenwood','Greenwood, Nebraska',27304,27);
INSERT INTO "django_geo_db_city" VALUES(22445,'Gresham','Gresham, Nebraska',27305,27);
INSERT INTO "django_geo_db_city" VALUES(22446,'Hallam','Hallam, Nebraska',27306,27);
INSERT INTO "django_geo_db_city" VALUES(22447,'Hebron','Hebron, Nebraska',27307,27);
INSERT INTO "django_geo_db_city" VALUES(22448,'Henderson','Henderson, Nebraska',27308,27);
INSERT INTO "django_geo_db_city" VALUES(22449,'Hickman','Hickman, Nebraska',27309,27);
INSERT INTO "django_geo_db_city" VALUES(22450,'Holmesville','Holmesville, Nebraska',27310,27);
INSERT INTO "django_geo_db_city" VALUES(22451,'Hubbell','Hubbell, Nebraska',27311,27);
INSERT INTO "django_geo_db_city" VALUES(22452,'Humboldt','Humboldt, Nebraska',27312,27);
INSERT INTO "django_geo_db_city" VALUES(22453,'Jansen','Jansen, Nebraska',27313,27);
INSERT INTO "django_geo_db_city" VALUES(22454,'Johnson','Johnson, Nebraska',27314,27);
INSERT INTO "django_geo_db_city" VALUES(22455,'Lewiston','Lewiston, Nebraska',27315,27);
INSERT INTO "django_geo_db_city" VALUES(22456,'Liberty','Liberty, Nebraska',27316,27);
INSERT INTO "django_geo_db_city" VALUES(22457,'Lorton','Lorton, Nebraska',27317,27);
INSERT INTO "django_geo_db_city" VALUES(22458,'McCool Junction','McCool Junction, Nebraska',27318,27);
INSERT INTO "django_geo_db_city" VALUES(22459,'Malcolm','Malcolm, Nebraska',27319,27);
INSERT INTO "django_geo_db_city" VALUES(22460,'Manley','Manley, Nebraska',27320,27);
INSERT INTO "django_geo_db_city" VALUES(22461,'Martell','Martell, Nebraska',27321,27);
INSERT INTO "django_geo_db_city" VALUES(22462,'Milford','Milford, Nebraska',27322,27);
INSERT INTO "django_geo_db_city" VALUES(22463,'Milligan','Milligan, Nebraska',27323,27);
INSERT INTO "django_geo_db_city" VALUES(22464,'Murdock','Murdock, Nebraska',27324,27);
INSERT INTO "django_geo_db_city" VALUES(22465,'Murray','Murray, Nebraska',27325,27);
INSERT INTO "django_geo_db_city" VALUES(22466,'Nebraska City','Nebraska City, Nebraska',27326,27);
INSERT INTO "django_geo_db_city" VALUES(22467,'Nehawka','Nehawka, Nebraska',27327,27);
INSERT INTO "django_geo_db_city" VALUES(22468,'Nemaha','Nemaha, Nebraska',27328,27);
INSERT INTO "django_geo_db_city" VALUES(22469,'Odell','Odell, Nebraska',27329,27);
INSERT INTO "django_geo_db_city" VALUES(22470,'Ohiowa','Ohiowa, Nebraska',27330,27);
INSERT INTO "django_geo_db_city" VALUES(22471,'Otoe','Otoe, Nebraska',27331,27);
INSERT INTO "django_geo_db_city" VALUES(22472,'Palmyra','Palmyra, Nebraska',27332,27);
INSERT INTO "django_geo_db_city" VALUES(22473,'Panama','Panama, Nebraska',27333,27);
INSERT INTO "django_geo_db_city" VALUES(22474,'Pawnee City','Pawnee City, Nebraska',27334,27);
INSERT INTO "django_geo_db_city" VALUES(22475,'Peru','Peru, Nebraska',27335,27);
INSERT INTO "django_geo_db_city" VALUES(22476,'Pickrell','Pickrell, Nebraska',27336,27);
INSERT INTO "django_geo_db_city" VALUES(22477,'Pleasant Dale','Pleasant Dale, Nebraska',27337,27);
INSERT INTO "django_geo_db_city" VALUES(22478,'Plymouth','Plymouth, Nebraska',27338,27);
INSERT INTO "django_geo_db_city" VALUES(22479,'Raymond','Raymond, Nebraska',27339,27);
INSERT INTO "django_geo_db_city" VALUES(22480,'Reynolds','Reynolds, Nebraska',27340,27);
INSERT INTO "django_geo_db_city" VALUES(22481,'Roca','Roca, Nebraska',27341,27);
INSERT INTO "django_geo_db_city" VALUES(22482,'Rulo','Rulo, Nebraska',27342,27);
INSERT INTO "django_geo_db_city" VALUES(22483,'Salem','Salem, Nebraska',27343,27);
INSERT INTO "django_geo_db_city" VALUES(22484,'Seward','Seward, Nebraska',27344,27);
INSERT INTO "django_geo_db_city" VALUES(22485,'Shickley','Shickley, Nebraska',27345,27);
INSERT INTO "django_geo_db_city" VALUES(22486,'Shubert','Shubert, Nebraska',27346,27);
INSERT INTO "django_geo_db_city" VALUES(22487,'Sprague','Sprague, Nebraska',27347,27);
INSERT INTO "django_geo_db_city" VALUES(22488,'Staplehurst','Staplehurst, Nebraska',27348,27);
INSERT INTO "django_geo_db_city" VALUES(22489,'Steele City','Steele City, Nebraska',27349,27);
INSERT INTO "django_geo_db_city" VALUES(22490,'Steinauer','Steinauer, Nebraska',27350,27);
INSERT INTO "django_geo_db_city" VALUES(22491,'Stella','Stella, Nebraska',27351,27);
INSERT INTO "django_geo_db_city" VALUES(22492,'Sterling','Sterling, Nebraska',27352,27);
INSERT INTO "django_geo_db_city" VALUES(22493,'Strang','Strang, Nebraska',27353,27);
INSERT INTO "django_geo_db_city" VALUES(22494,'Swanton','Swanton, Nebraska',27354,27);
INSERT INTO "django_geo_db_city" VALUES(22495,'Syracuse','Syracuse, Nebraska',27355,27);
INSERT INTO "django_geo_db_city" VALUES(22496,'Table Rock','Table Rock, Nebraska',27356,27);
INSERT INTO "django_geo_db_city" VALUES(22497,'Talmage','Talmage, Nebraska',27357,27);
INSERT INTO "django_geo_db_city" VALUES(22498,'Tecumseh','Tecumseh, Nebraska',27358,27);
INSERT INTO "django_geo_db_city" VALUES(22499,'Ong','Ong, Nebraska',27359,27);
INSERT INTO "django_geo_db_city" VALUES(22500,'Tobias','Tobias, Nebraska',27360,27);
INSERT INTO "django_geo_db_city" VALUES(22501,'Unadilla','Unadilla, Nebraska',27361,27);
INSERT INTO "django_geo_db_city" VALUES(22502,'Union','Union, Nebraska',27362,27);
INSERT INTO "django_geo_db_city" VALUES(22503,'Utica','Utica, Nebraska',27363,27);
INSERT INTO "django_geo_db_city" VALUES(22504,'Verdon','Verdon, Nebraska',27364,27);
INSERT INTO "django_geo_db_city" VALUES(22505,'Virginia','Virginia, Nebraska',27365,27);
INSERT INTO "django_geo_db_city" VALUES(22506,'Waco','Waco, Nebraska',27366,27);
INSERT INTO "django_geo_db_city" VALUES(22507,'Walton','Walton, Nebraska',27367,27);
INSERT INTO "django_geo_db_city" VALUES(22508,'Waverly','Waverly, Nebraska',27368,27);
INSERT INTO "django_geo_db_city" VALUES(22509,'Weeping Water','Weeping Water, Nebraska',27369,27);
INSERT INTO "django_geo_db_city" VALUES(22510,'Western','Western, Nebraska',27370,27);
INSERT INTO "django_geo_db_city" VALUES(22511,'Wilber','Wilber, Nebraska',27371,27);
INSERT INTO "django_geo_db_city" VALUES(22512,'Wymore','Wymore, Nebraska',27372,27);
INSERT INTO "django_geo_db_city" VALUES(22513,'York','York, Nebraska',27373,27);
INSERT INTO "django_geo_db_city" VALUES(22514,'Lincoln','Lincoln, Nebraska',27374,27);
INSERT INTO "django_geo_db_city" VALUES(22515,'Columbus','Columbus, Nebraska',27400,27);
INSERT INTO "django_geo_db_city" VALUES(22516,'Albion','Albion, Nebraska',27402,27);
INSERT INTO "django_geo_db_city" VALUES(22517,'Ames','Ames, Nebraska',27403,27);
INSERT INTO "django_geo_db_city" VALUES(22518,'Bartlett','Bartlett, Nebraska',27404,27);
INSERT INTO "django_geo_db_city" VALUES(22519,'Belgrade','Belgrade, Nebraska',27405,27);
INSERT INTO "django_geo_db_city" VALUES(22520,'Bellwood','Bellwood, Nebraska',27406,27);
INSERT INTO "django_geo_db_city" VALUES(22521,'Brainard','Brainard, Nebraska',27407,27);
INSERT INTO "django_geo_db_city" VALUES(22522,'Cedar Rapids','Cedar Rapids, Nebraska',27408,27);
INSERT INTO "django_geo_db_city" VALUES(22523,'Clarks','Clarks, Nebraska',27409,27);
INSERT INTO "django_geo_db_city" VALUES(22524,'Clarkson','Clarkson, Nebraska',27410,27);
INSERT INTO "django_geo_db_city" VALUES(22525,'Creston','Creston, Nebraska',27411,27);
INSERT INTO "django_geo_db_city" VALUES(22526,'David City','David City, Nebraska',27412,27);
INSERT INTO "django_geo_db_city" VALUES(22527,'Dodge','Dodge, Nebraska',27413,27);
INSERT INTO "django_geo_db_city" VALUES(22528,'Duncan','Duncan, Nebraska',27414,27);
INSERT INTO "django_geo_db_city" VALUES(22529,'Dwight','Dwight, Nebraska',27415,27);
INSERT INTO "django_geo_db_city" VALUES(22530,'Elgin','Elgin, Nebraska',27416,27);
INSERT INTO "django_geo_db_city" VALUES(22531,'Ericson','Ericson, Nebraska',27417,27);
INSERT INTO "django_geo_db_city" VALUES(22532,'Fullerton','Fullerton, Nebraska',27418,27);
INSERT INTO "django_geo_db_city" VALUES(22533,'Genoa','Genoa, Nebraska',27419,27);
INSERT INTO "django_geo_db_city" VALUES(22534,'Howells','Howells, Nebraska',27420,27);
INSERT INTO "django_geo_db_city" VALUES(22535,'Humphrey','Humphrey, Nebraska',27421,27);
INSERT INTO "django_geo_db_city" VALUES(22536,'Leigh','Leigh, Nebraska',27422,27);
INSERT INTO "django_geo_db_city" VALUES(22537,'Lindsay','Lindsay, Nebraska',27423,27);
INSERT INTO "django_geo_db_city" VALUES(22538,'Monroe','Monroe, Nebraska',27424,27);
INSERT INTO "django_geo_db_city" VALUES(22539,'Morse Bluff','Morse Bluff, Nebraska',27425,27);
INSERT INTO "django_geo_db_city" VALUES(22540,'North Bend','North Bend, Nebraska',27426,27);
INSERT INTO "django_geo_db_city" VALUES(22541,'Osceola','Osceola, Nebraska',27427,27);
INSERT INTO "django_geo_db_city" VALUES(22542,'Petersburg','Petersburg, Nebraska',27428,27);
INSERT INTO "django_geo_db_city" VALUES(22543,'Platte Center','Platte Center, Nebraska',27429,27);
INSERT INTO "django_geo_db_city" VALUES(22544,'Polk','Polk, Nebraska',27430,27);
INSERT INTO "django_geo_db_city" VALUES(22545,'Primrose','Primrose, Nebraska',27431,27);
INSERT INTO "django_geo_db_city" VALUES(22546,'Rising City','Rising City, Nebraska',27432,27);
INSERT INTO "django_geo_db_city" VALUES(22547,'Rogers','Rogers, Nebraska',27433,27);
INSERT INTO "django_geo_db_city" VALUES(22548,'Saint Edward','Saint Edward, Nebraska',27434,27);
INSERT INTO "django_geo_db_city" VALUES(22549,'Schuyler','Schuyler, Nebraska',27435,27);
INSERT INTO "django_geo_db_city" VALUES(22550,'Shelby','Shelby, Nebraska',27436,27);
INSERT INTO "django_geo_db_city" VALUES(22551,'Silver Creek','Silver Creek, Nebraska',27437,27);
INSERT INTO "django_geo_db_city" VALUES(22552,'Snyder','Snyder, Nebraska',27438,27);
INSERT INTO "django_geo_db_city" VALUES(22553,'Spalding','Spalding, Nebraska',27439,27);
INSERT INTO "django_geo_db_city" VALUES(22554,'Stromsburg','Stromsburg, Nebraska',27440,27);
INSERT INTO "django_geo_db_city" VALUES(22555,'Surprise','Surprise, Nebraska',27441,27);
INSERT INTO "django_geo_db_city" VALUES(22556,'Ulysses','Ulysses, Nebraska',27442,27);
INSERT INTO "django_geo_db_city" VALUES(22557,'Norfolk','Norfolk, Nebraska',27443,27);
INSERT INTO "django_geo_db_city" VALUES(22558,'Allen','Allen, Nebraska',27445,27);
INSERT INTO "django_geo_db_city" VALUES(22559,'Amelia','Amelia, Nebraska',27446,27);
INSERT INTO "django_geo_db_city" VALUES(22560,'Atkinson','Atkinson, Nebraska',27447,27);
INSERT INTO "django_geo_db_city" VALUES(22561,'Bassett','Bassett, Nebraska',27448,27);
INSERT INTO "django_geo_db_city" VALUES(22562,'Battle Creek','Battle Creek, Nebraska',27449,27);
INSERT INTO "django_geo_db_city" VALUES(22563,'Beemer','Beemer, Nebraska',27450,27);
INSERT INTO "django_geo_db_city" VALUES(22564,'Belden','Belden, Nebraska',27451,27);
INSERT INTO "django_geo_db_city" VALUES(22565,'Bloomfield','Bloomfield, Nebraska',27452,27);
INSERT INTO "django_geo_db_city" VALUES(22566,'Bristow','Bristow, Nebraska',27453,27);
INSERT INTO "django_geo_db_city" VALUES(22567,'Brunswick','Brunswick, Nebraska',27454,27);
INSERT INTO "django_geo_db_city" VALUES(22568,'Butte','Butte, Nebraska',27455,27);
INSERT INTO "django_geo_db_city" VALUES(22569,'Carroll','Carroll, Nebraska',27456,27);
INSERT INTO "django_geo_db_city" VALUES(22570,'Center','Center, Nebraska',27457,27);
INSERT INTO "django_geo_db_city" VALUES(22571,'Chambers','Chambers, Nebraska',27458,27);
INSERT INTO "django_geo_db_city" VALUES(22572,'Clearwater','Clearwater, Nebraska',27459,27);
INSERT INTO "django_geo_db_city" VALUES(22573,'Coleridge','Coleridge, Nebraska',27460,27);
INSERT INTO "django_geo_db_city" VALUES(22574,'Concord','Concord, Nebraska',27461,27);
INSERT INTO "django_geo_db_city" VALUES(22575,'Creighton','Creighton, Nebraska',27462,27);
INSERT INTO "django_geo_db_city" VALUES(22576,'Crofton','Crofton, Nebraska',27463,27);
INSERT INTO "django_geo_db_city" VALUES(22577,'Dakota City','Dakota City, Nebraska',27464,27);
INSERT INTO "django_geo_db_city" VALUES(22578,'Dixon','Dixon, Nebraska',27465,27);
INSERT INTO "django_geo_db_city" VALUES(22579,'Emerson','Emerson, Nebraska',27466,27);
INSERT INTO "django_geo_db_city" VALUES(22580,'Emmet','Emmet, Nebraska',27467,27);
INSERT INTO "django_geo_db_city" VALUES(22581,'Ewing','Ewing, Nebraska',27468,27);
INSERT INTO "django_geo_db_city" VALUES(22582,'Fordyce','Fordyce, Nebraska',27469,27);
INSERT INTO "django_geo_db_city" VALUES(22583,'Foster','Foster, Nebraska',27470,27);
INSERT INTO "django_geo_db_city" VALUES(22584,'Hadar','Hadar, Nebraska',27471,27);
INSERT INTO "django_geo_db_city" VALUES(22585,'Hartington','Hartington, Nebraska',27472,27);
INSERT INTO "django_geo_db_city" VALUES(22586,'Hoskins','Hoskins, Nebraska',27473,27);
INSERT INTO "django_geo_db_city" VALUES(22587,'Hubbard','Hubbard, Nebraska',27474,27);
INSERT INTO "django_geo_db_city" VALUES(22588,'Inman','Inman, Nebraska',27475,27);
INSERT INTO "django_geo_db_city" VALUES(22589,'Jackson','Jackson, Nebraska',27476,27);
INSERT INTO "django_geo_db_city" VALUES(22590,'Laurel','Laurel, Nebraska',27477,27);
INSERT INTO "django_geo_db_city" VALUES(22591,'Lynch','Lynch, Nebraska',27478,27);
INSERT INTO "django_geo_db_city" VALUES(22592,'Mclean','Mclean, Nebraska',27479,27);
INSERT INTO "django_geo_db_city" VALUES(22593,'Madison','Madison, Nebraska',27480,27);
INSERT INTO "django_geo_db_city" VALUES(22594,'Magnet','Magnet, Nebraska',27481,27);
INSERT INTO "django_geo_db_city" VALUES(22595,'Maskell','Maskell, Nebraska',27482,27);
INSERT INTO "django_geo_db_city" VALUES(22596,'Meadow Grove','Meadow Grove, Nebraska',27483,27);
INSERT INTO "django_geo_db_city" VALUES(22597,'Mills','Mills, Nebraska',27484,27);
INSERT INTO "django_geo_db_city" VALUES(22598,'Naper','Naper, Nebraska',27485,27);
INSERT INTO "django_geo_db_city" VALUES(22599,'Neligh','Neligh, Nebraska',27486,27);
INSERT INTO "django_geo_db_city" VALUES(22600,'Newcastle','Newcastle, Nebraska',27487,27);
INSERT INTO "django_geo_db_city" VALUES(22601,'Newman Grove','Newman Grove, Nebraska',27488,27);
INSERT INTO "django_geo_db_city" VALUES(22602,'Newport','Newport, Nebraska',27489,27);
INSERT INTO "django_geo_db_city" VALUES(22603,'Niobrara','Niobrara, Nebraska',27490,27);
INSERT INTO "django_geo_db_city" VALUES(22604,'Oakdale','Oakdale, Nebraska',27491,27);
INSERT INTO "django_geo_db_city" VALUES(22605,'Oneill','Oneill, Nebraska',27492,27);
INSERT INTO "django_geo_db_city" VALUES(22606,'Orchard','Orchard, Nebraska',27493,27);
INSERT INTO "django_geo_db_city" VALUES(22607,'Osmond','Osmond, Nebraska',27494,27);
INSERT INTO "django_geo_db_city" VALUES(22608,'Page','Page, Nebraska',27495,27);
INSERT INTO "django_geo_db_city" VALUES(22609,'Pierce','Pierce, Nebraska',27496,27);
INSERT INTO "django_geo_db_city" VALUES(22610,'Pilger','Pilger, Nebraska',27497,27);
INSERT INTO "django_geo_db_city" VALUES(22611,'Plainview','Plainview, Nebraska',27498,27);
INSERT INTO "django_geo_db_city" VALUES(22612,'Ponca','Ponca, Nebraska',27499,27);
INSERT INTO "django_geo_db_city" VALUES(22613,'Randolph','Randolph, Nebraska',27500,27);
INSERT INTO "django_geo_db_city" VALUES(22614,'Rose','Rose, Nebraska',27501,27);
INSERT INTO "django_geo_db_city" VALUES(22615,'Royal','Royal, Nebraska',27502,27);
INSERT INTO "django_geo_db_city" VALUES(22616,'Saint Helena','Saint Helena, Nebraska',27503,27);
INSERT INTO "django_geo_db_city" VALUES(22617,'South Sioux City','South Sioux City, Nebraska',27504,27);
INSERT INTO "django_geo_db_city" VALUES(22618,'Spencer','Spencer, Nebraska',27505,27);
INSERT INTO "django_geo_db_city" VALUES(22619,'Springview','Springview, Nebraska',27506,27);
INSERT INTO "django_geo_db_city" VALUES(22620,'Stanton','Stanton, Nebraska',27507,27);
INSERT INTO "django_geo_db_city" VALUES(22621,'Stuart','Stuart, Nebraska',27508,27);
INSERT INTO "django_geo_db_city" VALUES(22622,'Tilden','Tilden, Nebraska',27509,27);
INSERT INTO "django_geo_db_city" VALUES(22623,'Verdel','Verdel, Nebraska',27510,27);
INSERT INTO "django_geo_db_city" VALUES(22624,'Verdigre','Verdigre, Nebraska',27511,27);
INSERT INTO "django_geo_db_city" VALUES(22625,'Wakefield','Wakefield, Nebraska',27512,27);
INSERT INTO "django_geo_db_city" VALUES(22626,'Waterbury','Waterbury, Nebraska',27513,27);
INSERT INTO "django_geo_db_city" VALUES(22627,'Wausa','Wausa, Nebraska',27514,27);
INSERT INTO "django_geo_db_city" VALUES(22628,'Wayne','Wayne, Nebraska',27515,27);
INSERT INTO "django_geo_db_city" VALUES(22629,'West Point','West Point, Nebraska',27516,27);
INSERT INTO "django_geo_db_city" VALUES(22630,'Winnetoon','Winnetoon, Nebraska',27517,27);
INSERT INTO "django_geo_db_city" VALUES(22631,'Winside','Winside, Nebraska',27518,27);
INSERT INTO "django_geo_db_city" VALUES(22632,'Wisner','Wisner, Nebraska',27519,27);
INSERT INTO "django_geo_db_city" VALUES(22633,'Wynot','Wynot, Nebraska',27520,27);
INSERT INTO "django_geo_db_city" VALUES(22634,'Sutton','Sutton, Nebraska',27521,27);
INSERT INTO "django_geo_db_city" VALUES(22635,'Grand Island','Grand Island, Nebraska',27522,27);
INSERT INTO "django_geo_db_city" VALUES(22636,'Alda','Alda, Nebraska',27525,27);
INSERT INTO "django_geo_db_city" VALUES(22637,'Amherst','Amherst, Nebraska',27526,27);
INSERT INTO "django_geo_db_city" VALUES(22638,'Anselmo','Anselmo, Nebraska',27527,27);
INSERT INTO "django_geo_db_city" VALUES(22639,'Ansley','Ansley, Nebraska',27528,27);
INSERT INTO "django_geo_db_city" VALUES(22640,'Arcadia','Arcadia, Nebraska',27529,27);
INSERT INTO "django_geo_db_city" VALUES(22641,'Archer','Archer, Nebraska',27530,27);
INSERT INTO "django_geo_db_city" VALUES(22642,'Ashton','Ashton, Nebraska',27531,27);
INSERT INTO "django_geo_db_city" VALUES(22643,'Aurora','Aurora, Nebraska',27532,27);
INSERT INTO "django_geo_db_city" VALUES(22644,'Berwyn','Berwyn, Nebraska',27533,27);
INSERT INTO "django_geo_db_city" VALUES(22645,'Boelus','Boelus, Nebraska',27534,27);
INSERT INTO "django_geo_db_city" VALUES(22646,'Brewster','Brewster, Nebraska',27535,27);
INSERT INTO "django_geo_db_city" VALUES(22647,'Broken Bow','Broken Bow, Nebraska',27536,27);
INSERT INTO "django_geo_db_city" VALUES(22648,'Burwell','Burwell, Nebraska',27537,27);
INSERT INTO "django_geo_db_city" VALUES(22649,'Cairo','Cairo, Nebraska',27538,27);
INSERT INTO "django_geo_db_city" VALUES(22650,'Callaway','Callaway, Nebraska',27539,27);
INSERT INTO "django_geo_db_city" VALUES(22651,'Chapman','Chapman, Nebraska',27541,27);
INSERT INTO "django_geo_db_city" VALUES(22652,'Comstock','Comstock, Nebraska',27542,27);
INSERT INTO "django_geo_db_city" VALUES(22653,'Dannebrog','Dannebrog, Nebraska',27543,27);
INSERT INTO "django_geo_db_city" VALUES(22654,'Doniphan','Doniphan, Nebraska',27544,27);
INSERT INTO "django_geo_db_city" VALUES(22655,'Dunning','Dunning, Nebraska',27545,27);
INSERT INTO "django_geo_db_city" VALUES(22656,'Eddyville','Eddyville, Nebraska',27546,27);
INSERT INTO "django_geo_db_city" VALUES(22657,'Elba','Elba, Nebraska',27547,27);
INSERT INTO "django_geo_db_city" VALUES(22658,'Elm Creek','Elm Creek, Nebraska',27548,27);
INSERT INTO "django_geo_db_city" VALUES(22659,'Elyria','Elyria, Nebraska',27549,27);
INSERT INTO "django_geo_db_city" VALUES(22660,'Farwell','Farwell, Nebraska',27550,27);
INSERT INTO "django_geo_db_city" VALUES(22661,'Gibbon','Gibbon, Nebraska',27551,27);
INSERT INTO "django_geo_db_city" VALUES(22662,'Giltner','Giltner, Nebraska',27552,27);
INSERT INTO "django_geo_db_city" VALUES(22663,'Greeley','Greeley, Nebraska',27553,27);
INSERT INTO "django_geo_db_city" VALUES(22664,'Hampton','Hampton, Nebraska',27554,27);
INSERT INTO "django_geo_db_city" VALUES(22665,'Hazard','Hazard, Nebraska',27555,27);
INSERT INTO "django_geo_db_city" VALUES(22666,'Kearney','Kearney, Nebraska',27556,27);
INSERT INTO "django_geo_db_city" VALUES(22667,'Hordville','Hordville, Nebraska',27557,27);
INSERT INTO "django_geo_db_city" VALUES(22668,'Lexington','Lexington, Nebraska',27561,27);
INSERT INTO "django_geo_db_city" VALUES(22669,'Litchfield','Litchfield, Nebraska',27562,27);
INSERT INTO "django_geo_db_city" VALUES(22670,'Loup City','Loup City, Nebraska',27563,27);
INSERT INTO "django_geo_db_city" VALUES(22671,'Marquette','Marquette, Nebraska',27564,27);
INSERT INTO "django_geo_db_city" VALUES(22672,'Mason City','Mason City, Nebraska',27565,27);
INSERT INTO "django_geo_db_city" VALUES(22673,'Merna','Merna, Nebraska',27566,27);
INSERT INTO "django_geo_db_city" VALUES(22674,'Miller','Miller, Nebraska',27567,27);
INSERT INTO "django_geo_db_city" VALUES(22675,'North Loup','North Loup, Nebraska',27568,27);
INSERT INTO "django_geo_db_city" VALUES(22676,'Oconto','Oconto, Nebraska',27569,27);
INSERT INTO "django_geo_db_city" VALUES(22677,'Odessa','Odessa, Nebraska',27570,27);
INSERT INTO "django_geo_db_city" VALUES(22678,'Ord','Ord, Nebraska',27571,27);
INSERT INTO "django_geo_db_city" VALUES(22679,'Overton','Overton, Nebraska',27572,27);
INSERT INTO "django_geo_db_city" VALUES(22680,'Palmer','Palmer, Nebraska',27573,27);
INSERT INTO "django_geo_db_city" VALUES(22681,'Phillips','Phillips, Nebraska',27574,27);
INSERT INTO "django_geo_db_city" VALUES(22682,'Pleasanton','Pleasanton, Nebraska',27575,27);
INSERT INTO "django_geo_db_city" VALUES(22683,'Martin','Martin, Nebraska',27576,27);
INSERT INTO "django_geo_db_city" VALUES(22684,'Ravenna','Ravenna, Nebraska',27577,27);
INSERT INTO "django_geo_db_city" VALUES(22685,'Riverdale','Riverdale, Nebraska',27578,27);
INSERT INTO "django_geo_db_city" VALUES(22686,'Rockville','Rockville, Nebraska',27579,27);
INSERT INTO "django_geo_db_city" VALUES(22687,'Saint Libory','Saint Libory, Nebraska',27580,27);
INSERT INTO "django_geo_db_city" VALUES(22688,'Saint Paul','Saint Paul, Nebraska',27581,27);
INSERT INTO "django_geo_db_city" VALUES(22689,'Sargent','Sargent, Nebraska',27582,27);
INSERT INTO "django_geo_db_city" VALUES(22690,'Scotia','Scotia, Nebraska',27583,27);
INSERT INTO "django_geo_db_city" VALUES(22691,'Shelton','Shelton, Nebraska',27584,27);
INSERT INTO "django_geo_db_city" VALUES(22692,'Sumner','Sumner, Nebraska',27585,27);
INSERT INTO "django_geo_db_city" VALUES(22693,'Taylor','Taylor, Nebraska',27586,27);
INSERT INTO "django_geo_db_city" VALUES(22694,'Weissert','Weissert, Nebraska',27587,27);
INSERT INTO "django_geo_db_city" VALUES(22695,'Westerville','Westerville, Nebraska',27588,27);
INSERT INTO "django_geo_db_city" VALUES(22696,'Wolbach','Wolbach, Nebraska',27589,27);
INSERT INTO "django_geo_db_city" VALUES(22697,'Wood River','Wood River, Nebraska',27590,27);
INSERT INTO "django_geo_db_city" VALUES(22698,'Hastings','Hastings, Nebraska',27591,27);
INSERT INTO "django_geo_db_city" VALUES(22699,'Alma','Alma, Nebraska',27593,27);
INSERT INTO "django_geo_db_city" VALUES(22700,'Arapahoe','Arapahoe, Nebraska',27594,27);
INSERT INTO "django_geo_db_city" VALUES(22701,'Atlanta','Atlanta, Nebraska',27595,27);
INSERT INTO "django_geo_db_city" VALUES(22702,'Axtell','Axtell, Nebraska',27596,27);
INSERT INTO "django_geo_db_city" VALUES(22703,'Ayr','Ayr, Nebraska',27597,27);
INSERT INTO "django_geo_db_city" VALUES(22704,'Beaver City','Beaver City, Nebraska',27598,27);
INSERT INTO "django_geo_db_city" VALUES(22705,'Bertrand','Bertrand, Nebraska',27599,27);
INSERT INTO "django_geo_db_city" VALUES(22706,'Bladen','Bladen, Nebraska',27600,27);
INSERT INTO "django_geo_db_city" VALUES(22707,'Bloomington','Bloomington, Nebraska',27601,27);
INSERT INTO "django_geo_db_city" VALUES(22708,'Blue Hill','Blue Hill, Nebraska',27602,27);
INSERT INTO "django_geo_db_city" VALUES(22709,'Campbell','Campbell, Nebraska',27603,27);
INSERT INTO "django_geo_db_city" VALUES(22710,'Clay Center','Clay Center, Nebraska',27604,27);
INSERT INTO "django_geo_db_city" VALUES(22711,'Deweese','Deweese, Nebraska',27605,27);
INSERT INTO "django_geo_db_city" VALUES(22712,'Edgar','Edgar, Nebraska',27606,27);
INSERT INTO "django_geo_db_city" VALUES(22713,'Edison','Edison, Nebraska',27607,27);
INSERT INTO "django_geo_db_city" VALUES(22714,'Elwood','Elwood, Nebraska',27608,27);
INSERT INTO "django_geo_db_city" VALUES(22715,'Fairfield','Fairfield, Nebraska',27609,27);
INSERT INTO "django_geo_db_city" VALUES(22716,'Franklin','Franklin, Nebraska',27610,27);
INSERT INTO "django_geo_db_city" VALUES(22717,'Funk','Funk, Nebraska',27611,27);
INSERT INTO "django_geo_db_city" VALUES(22718,'Glenvil','Glenvil, Nebraska',27612,27);
INSERT INTO "django_geo_db_city" VALUES(22719,'Guide Rock','Guide Rock, Nebraska',27613,27);
INSERT INTO "django_geo_db_city" VALUES(22720,'Hardy','Hardy, Nebraska',27614,27);
INSERT INTO "django_geo_db_city" VALUES(22721,'Harvard','Harvard, Nebraska',27615,27);
INSERT INTO "django_geo_db_city" VALUES(22722,'Heartwell','Heartwell, Nebraska',27616,27);
INSERT INTO "django_geo_db_city" VALUES(22723,'Hendley','Hendley, Nebraska',27617,27);
INSERT INTO "django_geo_db_city" VALUES(22724,'Hildreth','Hildreth, Nebraska',27618,27);
INSERT INTO "django_geo_db_city" VALUES(22725,'Holbrook','Holbrook, Nebraska',27619,27);
INSERT INTO "django_geo_db_city" VALUES(22726,'Holdrege','Holdrege, Nebraska',27620,27);
INSERT INTO "django_geo_db_city" VALUES(22727,'Holstein','Holstein, Nebraska',27621,27);
INSERT INTO "django_geo_db_city" VALUES(22728,'Inavale','Inavale, Nebraska',27622,27);
INSERT INTO "django_geo_db_city" VALUES(22729,'Inland','Inland, Nebraska',27623,27);
INSERT INTO "django_geo_db_city" VALUES(22730,'Juniata','Juniata, Nebraska',27624,27);
INSERT INTO "django_geo_db_city" VALUES(22731,'Kenesaw','Kenesaw, Nebraska',27625,27);
INSERT INTO "django_geo_db_city" VALUES(22732,'Lawrence','Lawrence, Nebraska',27626,27);
INSERT INTO "django_geo_db_city" VALUES(22733,'Loomis','Loomis, Nebraska',27627,27);
INSERT INTO "django_geo_db_city" VALUES(22734,'Minden','Minden, Nebraska',27628,27);
INSERT INTO "django_geo_db_city" VALUES(22735,'Naponee','Naponee, Nebraska',27629,27);
INSERT INTO "django_geo_db_city" VALUES(22736,'Nelson','Nelson, Nebraska',27630,27);
INSERT INTO "django_geo_db_city" VALUES(22737,'Norman','Norman, Nebraska',27631,27);
INSERT INTO "django_geo_db_city" VALUES(22738,'Oak','Oak, Nebraska',27632,27);
INSERT INTO "django_geo_db_city" VALUES(22739,'Orleans','Orleans, Nebraska',27633,27);
INSERT INTO "django_geo_db_city" VALUES(22740,'Oxford','Oxford, Nebraska',27634,27);
INSERT INTO "django_geo_db_city" VALUES(22741,'Ragan','Ragan, Nebraska',27635,27);
INSERT INTO "django_geo_db_city" VALUES(22742,'Red Cloud','Red Cloud, Nebraska',27636,27);
INSERT INTO "django_geo_db_city" VALUES(22743,'Republican City','Republican City, Nebraska',27637,27);
INSERT INTO "django_geo_db_city" VALUES(22744,'Riverton','Riverton, Nebraska',27638,27);
INSERT INTO "django_geo_db_city" VALUES(22745,'Roseland','Roseland, Nebraska',27639,27);
INSERT INTO "django_geo_db_city" VALUES(22746,'Ruskin','Ruskin, Nebraska',27640,27);
INSERT INTO "django_geo_db_city" VALUES(22747,'Saronville','Saronville, Nebraska',27641,27);
INSERT INTO "django_geo_db_city" VALUES(22748,'Smithfield','Smithfield, Nebraska',27642,27);
INSERT INTO "django_geo_db_city" VALUES(22749,'Stamford','Stamford, Nebraska',27643,27);
INSERT INTO "django_geo_db_city" VALUES(22750,'Superior','Superior, Nebraska',27644,27);
INSERT INTO "django_geo_db_city" VALUES(22751,'Trumbull','Trumbull, Nebraska',27646,27);
INSERT INTO "django_geo_db_city" VALUES(22752,'Upland','Upland, Nebraska',27647,27);
INSERT INTO "django_geo_db_city" VALUES(22753,'Wilcox','Wilcox, Nebraska',27648,27);
INSERT INTO "django_geo_db_city" VALUES(22754,'McCook','McCook, Nebraska',27649,27);
INSERT INTO "django_geo_db_city" VALUES(22755,'Bartley','Bartley, Nebraska',27650,27);
INSERT INTO "django_geo_db_city" VALUES(22756,'Benkelman','Benkelman, Nebraska',27651,27);
INSERT INTO "django_geo_db_city" VALUES(22757,'Cambridge','Cambridge, Nebraska',27652,27);
INSERT INTO "django_geo_db_city" VALUES(22758,'Champion','Champion, Nebraska',27653,27);
INSERT INTO "django_geo_db_city" VALUES(22759,'Culbertson','Culbertson, Nebraska',27654,27);
INSERT INTO "django_geo_db_city" VALUES(22760,'Curtis','Curtis, Nebraska',27655,27);
INSERT INTO "django_geo_db_city" VALUES(22761,'Danbury','Danbury, Nebraska',27656,27);
INSERT INTO "django_geo_db_city" VALUES(22762,'Enders','Enders, Nebraska',27657,27);
INSERT INTO "django_geo_db_city" VALUES(22763,'Eustis','Eustis, Nebraska',27658,27);
INSERT INTO "django_geo_db_city" VALUES(22764,'Farnam','Farnam, Nebraska',27659,27);
INSERT INTO "django_geo_db_city" VALUES(22765,'Haigler','Haigler, Nebraska',27660,27);
INSERT INTO "django_geo_db_city" VALUES(22766,'Hamlet','Hamlet, Nebraska',27661,27);
INSERT INTO "django_geo_db_city" VALUES(22767,'Hayes Center','Hayes Center, Nebraska',27662,27);
INSERT INTO "django_geo_db_city" VALUES(22768,'Imperial','Imperial, Nebraska',27663,27);
INSERT INTO "django_geo_db_city" VALUES(22769,'Indianola','Indianola, Nebraska',27664,27);
INSERT INTO "django_geo_db_city" VALUES(22770,'Lebanon','Lebanon, Nebraska',27665,27);
INSERT INTO "django_geo_db_city" VALUES(22771,'Max','Max, Nebraska',27666,27);
INSERT INTO "django_geo_db_city" VALUES(22772,'Maywood','Maywood, Nebraska',27667,27);
INSERT INTO "django_geo_db_city" VALUES(22773,'Moorefield','Moorefield, Nebraska',27668,27);
INSERT INTO "django_geo_db_city" VALUES(22774,'Palisade','Palisade, Nebraska',27669,27);
INSERT INTO "django_geo_db_city" VALUES(22775,'Parks','Parks, Nebraska',27670,27);
INSERT INTO "django_geo_db_city" VALUES(22776,'Stockville','Stockville, Nebraska',27671,27);
INSERT INTO "django_geo_db_city" VALUES(22777,'Stratton','Stratton, Nebraska',27672,27);
INSERT INTO "django_geo_db_city" VALUES(22778,'Trenton','Trenton, Nebraska',27673,27);
INSERT INTO "django_geo_db_city" VALUES(22779,'Wauneta','Wauneta, Nebraska',27674,27);
INSERT INTO "django_geo_db_city" VALUES(22780,'Wilsonville','Wilsonville, Nebraska',27675,27);
INSERT INTO "django_geo_db_city" VALUES(22781,'North Platte','North Platte, Nebraska',27676,27);
INSERT INTO "django_geo_db_city" VALUES(22782,'Arnold','Arnold, Nebraska',27678,27);
INSERT INTO "django_geo_db_city" VALUES(22783,'Arthur','Arthur, Nebraska',27679,27);
INSERT INTO "django_geo_db_city" VALUES(22784,'Big Springs','Big Springs, Nebraska',27680,27);
INSERT INTO "django_geo_db_city" VALUES(22785,'Brady','Brady, Nebraska',27681,27);
INSERT INTO "django_geo_db_city" VALUES(22786,'Broadwater','Broadwater, Nebraska',27682,27);
INSERT INTO "django_geo_db_city" VALUES(22787,'Brule','Brule, Nebraska',27683,27);
INSERT INTO "django_geo_db_city" VALUES(22788,'Bushnell','Bushnell, Nebraska',27684,27);
INSERT INTO "django_geo_db_city" VALUES(22789,'Chappell','Chappell, Nebraska',27685,27);
INSERT INTO "django_geo_db_city" VALUES(22790,'Cozad','Cozad, Nebraska',27686,27);
INSERT INTO "django_geo_db_city" VALUES(22791,'Dalton','Dalton, Nebraska',27687,27);
INSERT INTO "django_geo_db_city" VALUES(22792,'Dickens','Dickens, Nebraska',27688,27);
INSERT INTO "django_geo_db_city" VALUES(22793,'Dix','Dix, Nebraska',27689,27);
INSERT INTO "django_geo_db_city" VALUES(22794,'Elsie','Elsie, Nebraska',27690,27);
INSERT INTO "django_geo_db_city" VALUES(22795,'Elsmere','Elsmere, Nebraska',27691,27);
INSERT INTO "django_geo_db_city" VALUES(22796,'Gothenburg','Gothenburg, Nebraska',27692,27);
INSERT INTO "django_geo_db_city" VALUES(22797,'Grant','Grant, Nebraska',27693,27);
INSERT INTO "django_geo_db_city" VALUES(22798,'Gurley','Gurley, Nebraska',27694,27);
INSERT INTO "django_geo_db_city" VALUES(22799,'Halsey','Halsey, Nebraska',27695,27);
INSERT INTO "django_geo_db_city" VALUES(22800,'Hershey','Hershey, Nebraska',27696,27);
INSERT INTO "django_geo_db_city" VALUES(22801,'Keystone','Keystone, Nebraska',27697,27);
INSERT INTO "django_geo_db_city" VALUES(22802,'Kimball','Kimball, Nebraska',27698,27);
INSERT INTO "django_geo_db_city" VALUES(22803,'Lemoyne','Lemoyne, Nebraska',27699,27);
INSERT INTO "django_geo_db_city" VALUES(22804,'Lewellen','Lewellen, Nebraska',27700,27);
INSERT INTO "django_geo_db_city" VALUES(22805,'Lisco','Lisco, Nebraska',27701,27);
INSERT INTO "django_geo_db_city" VALUES(22806,'Lodgepole','Lodgepole, Nebraska',27702,27);
INSERT INTO "django_geo_db_city" VALUES(22807,'Madrid','Madrid, Nebraska',27703,27);
INSERT INTO "django_geo_db_city" VALUES(22808,'Maxwell','Maxwell, Nebraska',27704,27);
INSERT INTO "django_geo_db_city" VALUES(22809,'Mullen','Mullen, Nebraska',27705,27);
INSERT INTO "django_geo_db_city" VALUES(22810,'Ogallala','Ogallala, Nebraska',27706,27);
INSERT INTO "django_geo_db_city" VALUES(22811,'Oshkosh','Oshkosh, Nebraska',27707,27);
INSERT INTO "django_geo_db_city" VALUES(22812,'Paxton','Paxton, Nebraska',27708,27);
INSERT INTO "django_geo_db_city" VALUES(22813,'Potter','Potter, Nebraska',27709,27);
INSERT INTO "django_geo_db_city" VALUES(22814,'Purdum','Purdum, Nebraska',27710,27);
INSERT INTO "django_geo_db_city" VALUES(22815,'Sidney','Sidney, Nebraska',27711,27);
INSERT INTO "django_geo_db_city" VALUES(22816,'Seneca','Seneca, Nebraska',27712,27);
INSERT INTO "django_geo_db_city" VALUES(22817,'Stapleton','Stapleton, Nebraska',27714,27);
INSERT INTO "django_geo_db_city" VALUES(22818,'Sutherland','Sutherland, Nebraska',27715,27);
INSERT INTO "django_geo_db_city" VALUES(22819,'Thedford','Thedford, Nebraska',27716,27);
INSERT INTO "django_geo_db_city" VALUES(22820,'Tryon','Tryon, Nebraska',27717,27);
INSERT INTO "django_geo_db_city" VALUES(22821,'Venango','Venango, Nebraska',27718,27);
INSERT INTO "django_geo_db_city" VALUES(22822,'Wallace','Wallace, Nebraska',27719,27);
INSERT INTO "django_geo_db_city" VALUES(22823,'Wellfleet','Wellfleet, Nebraska',27720,27);
INSERT INTO "django_geo_db_city" VALUES(22824,'Willow Island','Willow Island, Nebraska',27721,27);
INSERT INTO "django_geo_db_city" VALUES(22825,'Valentine','Valentine, Nebraska',27723,27);
INSERT INTO "django_geo_db_city" VALUES(22826,'Ainsworth','Ainsworth, Nebraska',27724,27);
INSERT INTO "django_geo_db_city" VALUES(22827,'Cody','Cody, Nebraska',27725,27);
INSERT INTO "django_geo_db_city" VALUES(22828,'Crookston','Crookston, Nebraska',27726,27);
INSERT INTO "django_geo_db_city" VALUES(22829,'Johnstown','Johnstown, Nebraska',27727,27);
INSERT INTO "django_geo_db_city" VALUES(22830,'Kilgore','Kilgore, Nebraska',27728,27);
INSERT INTO "django_geo_db_city" VALUES(22831,'Long Pine','Long Pine, Nebraska',27729,27);
INSERT INTO "django_geo_db_city" VALUES(22832,'Merriman','Merriman, Nebraska',27730,27);
INSERT INTO "django_geo_db_city" VALUES(22833,'Nenzel','Nenzel, Nebraska',27731,27);
INSERT INTO "django_geo_db_city" VALUES(22834,'Sparks','Sparks, Nebraska',27732,27);
INSERT INTO "django_geo_db_city" VALUES(22835,'Wood Lake','Wood Lake, Nebraska',27733,27);
INSERT INTO "django_geo_db_city" VALUES(22836,'Alliance','Alliance, Nebraska',27734,27);
INSERT INTO "django_geo_db_city" VALUES(22837,'Angora','Angora, Nebraska',27735,27);
INSERT INTO "django_geo_db_city" VALUES(22838,'Ashby','Ashby, Nebraska',27736,27);
INSERT INTO "django_geo_db_city" VALUES(22839,'Bayard','Bayard, Nebraska',27737,27);
INSERT INTO "django_geo_db_city" VALUES(22840,'Bingham','Bingham, Nebraska',27738,27);
INSERT INTO "django_geo_db_city" VALUES(22841,'Bridgeport','Bridgeport, Nebraska',27739,27);
INSERT INTO "django_geo_db_city" VALUES(22842,'Chadron','Chadron, Nebraska',27740,27);
INSERT INTO "django_geo_db_city" VALUES(22843,'Crawford','Crawford, Nebraska',27741,27);
INSERT INTO "django_geo_db_city" VALUES(22844,'Ellsworth','Ellsworth, Nebraska',27742,27);
INSERT INTO "django_geo_db_city" VALUES(22845,'Gering','Gering, Nebraska',27743,27);
INSERT INTO "django_geo_db_city" VALUES(22846,'Gordon','Gordon, Nebraska',27744,27);
INSERT INTO "django_geo_db_city" VALUES(22847,'Harrisburg','Harrisburg, Nebraska',27745,27);
INSERT INTO "django_geo_db_city" VALUES(22848,'Harrison','Harrison, Nebraska',27746,27);
INSERT INTO "django_geo_db_city" VALUES(22849,'Hay Springs','Hay Springs, Nebraska',27747,27);
INSERT INTO "django_geo_db_city" VALUES(22850,'Hemingford','Hemingford, Nebraska',27748,27);
INSERT INTO "django_geo_db_city" VALUES(22851,'Henry','Henry, Nebraska',27749,27);
INSERT INTO "django_geo_db_city" VALUES(22852,'Hyannis','Hyannis, Nebraska',27750,27);
INSERT INTO "django_geo_db_city" VALUES(22853,'Lakeside','Lakeside, Nebraska',27751,27);
INSERT INTO "django_geo_db_city" VALUES(22854,'Lyman','Lyman, Nebraska',27752,27);
INSERT INTO "django_geo_db_city" VALUES(22855,'Mcgrew','Mcgrew, Nebraska',27753,27);
INSERT INTO "django_geo_db_city" VALUES(22856,'Marsland','Marsland, Nebraska',27754,27);
INSERT INTO "django_geo_db_city" VALUES(22857,'Melbeta','Melbeta, Nebraska',27755,27);
INSERT INTO "django_geo_db_city" VALUES(22858,'Minatare','Minatare, Nebraska',27756,27);
INSERT INTO "django_geo_db_city" VALUES(22859,'Mitchell','Mitchell, Nebraska',27757,27);
INSERT INTO "django_geo_db_city" VALUES(22860,'Morrill','Morrill, Nebraska',27758,27);
INSERT INTO "django_geo_db_city" VALUES(22861,'Rushville','Rushville, Nebraska',27759,27);
INSERT INTO "django_geo_db_city" VALUES(22862,'Scottsbluff','Scottsbluff, Nebraska',27760,27);
INSERT INTO "django_geo_db_city" VALUES(22863,'Whiteclay','Whiteclay, Nebraska',27762,27);
INSERT INTO "django_geo_db_city" VALUES(22864,'Whitman','Whitman, Nebraska',27763,27);
INSERT INTO "django_geo_db_city" VALUES(22865,'Whitney','Whitney, Nebraska',27764,27);
INSERT INTO "django_geo_db_city" VALUES(22866,'Laplace','Laplace, Louisiana',27765,22);
INSERT INTO "django_geo_db_city" VALUES(22867,'Metairie','Metairie, Louisiana',27766,22);
INSERT INTO "django_geo_db_city" VALUES(22868,'Jefferson','Jefferson, Louisiana',27772,22);
INSERT INTO "django_geo_db_city" VALUES(22869,'Des Allemands','Des Allemands, Louisiana',27773,22);
INSERT INTO "django_geo_db_city" VALUES(22870,'Ama','Ama, Louisiana',27774,22);
INSERT INTO "django_geo_db_city" VALUES(22871,'Arabi','Arabi, Louisiana',27775,22);
INSERT INTO "django_geo_db_city" VALUES(22872,'Barataria','Barataria, Louisiana',27776,22);
INSERT INTO "django_geo_db_city" VALUES(22873,'Belle Chasse','Belle Chasse, Louisiana',27777,22);
INSERT INTO "django_geo_db_city" VALUES(22874,'Boothville','Boothville, Louisiana',27778,22);
INSERT INTO "django_geo_db_city" VALUES(22875,'Boutte','Boutte, Louisiana',27779,22);
INSERT INTO "django_geo_db_city" VALUES(22876,'Braithwaite','Braithwaite, Louisiana',27780,22);
INSERT INTO "django_geo_db_city" VALUES(22877,'Buras','Buras, Louisiana',27781,22);
INSERT INTO "django_geo_db_city" VALUES(22878,'Carlisle','Carlisle, Louisiana',27782,22);
INSERT INTO "django_geo_db_city" VALUES(22879,'Chalmette','Chalmette, Louisiana',27783,22);
INSERT INTO "django_geo_db_city" VALUES(22880,'Davant','Davant, Louisiana',27785,22);
INSERT INTO "django_geo_db_city" VALUES(22881,'Destrehan','Destrehan, Louisiana',27786,22);
INSERT INTO "django_geo_db_city" VALUES(22882,'Reserve','Reserve, Louisiana',27787,22);
INSERT INTO "django_geo_db_city" VALUES(22883,'Edgard','Edgard, Louisiana',27788,22);
INSERT INTO "django_geo_db_city" VALUES(22884,'Empire','Empire, Louisiana',27789,22);
INSERT INTO "django_geo_db_city" VALUES(22885,'Garyville','Garyville, Louisiana',27790,22);
INSERT INTO "django_geo_db_city" VALUES(22886,'Gramercy','Gramercy, Louisiana',27791,22);
INSERT INTO "django_geo_db_city" VALUES(22887,'Gretna','Gretna, Louisiana',27792,22);
INSERT INTO "django_geo_db_city" VALUES(22888,'Hahnville','Hahnville, Louisiana',27794,22);
INSERT INTO "django_geo_db_city" VALUES(22889,'Harvey','Harvey, Louisiana',27795,22);
INSERT INTO "django_geo_db_city" VALUES(22890,'Kenner','Kenner, Louisiana',27796,22);
INSERT INTO "django_geo_db_city" VALUES(22891,'Killona','Killona, Louisiana',27798,22);
INSERT INTO "django_geo_db_city" VALUES(22892,'Lafitte','Lafitte, Louisiana',27799,22);
INSERT INTO "django_geo_db_city" VALUES(22893,'La Place','La Place, Louisiana',27800,22);
INSERT INTO "django_geo_db_city" VALUES(22894,'Luling','Luling, Louisiana',27802,22);
INSERT INTO "django_geo_db_city" VALUES(22895,'Lutcher','Lutcher, Louisiana',27803,22);
INSERT INTO "django_geo_db_city" VALUES(22896,'Marrero','Marrero, Louisiana',27804,22);
INSERT INTO "django_geo_db_city" VALUES(22897,'Meraux','Meraux, Louisiana',27805,22);
INSERT INTO "django_geo_db_city" VALUES(22898,'Mount Airy','Mount Airy, Louisiana',27806,22);
INSERT INTO "django_geo_db_city" VALUES(22899,'New Sarpy','New Sarpy, Louisiana',27807,22);
INSERT INTO "django_geo_db_city" VALUES(22900,'Norco','Norco, Louisiana',27808,22);
INSERT INTO "django_geo_db_city" VALUES(22901,'Paradis','Paradis, Louisiana',27809,22);
INSERT INTO "django_geo_db_city" VALUES(22902,'Pilottown','Pilottown, Louisiana',27810,22);
INSERT INTO "django_geo_db_city" VALUES(22903,'Pointe A La Hache','Pointe A La Hache, Louisiana',27811,22);
INSERT INTO "django_geo_db_city" VALUES(22904,'Port Sulphur','Port Sulphur, Louisiana',27812,22);
INSERT INTO "django_geo_db_city" VALUES(22905,'Saint Bernard','Saint Bernard, Louisiana',27814,22);
INSERT INTO "django_geo_db_city" VALUES(22906,'Saint James','Saint James, Louisiana',27815,22);
INSERT INTO "django_geo_db_city" VALUES(22907,'Saint Rose','Saint Rose, Louisiana',27816,22);
INSERT INTO "django_geo_db_city" VALUES(22908,'Vacherie','Vacherie, Louisiana',27817,22);
INSERT INTO "django_geo_db_city" VALUES(22909,'Venice','Venice, Louisiana',27818,22);
INSERT INTO "django_geo_db_city" VALUES(22910,'Violet','Violet, Louisiana',27819,22);
INSERT INTO "django_geo_db_city" VALUES(22911,'Westwego','Westwego, Louisiana',27821,22);
INSERT INTO "django_geo_db_city" VALUES(22912,'New Orleans','New Orleans, Louisiana',27822,22);
INSERT INTO "django_geo_db_city" VALUES(22913,'Thibodaux','Thibodaux, Louisiana',27850,22);
INSERT INTO "django_geo_db_city" VALUES(22914,'Pierre Part','Pierre Part, Louisiana',27853,22);
INSERT INTO "django_geo_db_city" VALUES(22915,'Amelia','Amelia, Louisiana',27854,22);
INSERT INTO "django_geo_db_city" VALUES(22916,'Belle Rose','Belle Rose, Louisiana',27855,22);
INSERT INTO "django_geo_db_city" VALUES(22917,'Berwick','Berwick, Louisiana',27856,22);
INSERT INTO "django_geo_db_city" VALUES(22918,'Bourg','Bourg, Louisiana',27857,22);
INSERT INTO "django_geo_db_city" VALUES(22919,'Chauvin','Chauvin, Louisiana',27858,22);
INSERT INTO "django_geo_db_city" VALUES(22920,'Cut Off','Cut Off, Louisiana',27859,22);
INSERT INTO "django_geo_db_city" VALUES(22921,'Donaldsonville','Donaldsonville, Louisiana',27860,22);
INSERT INTO "django_geo_db_city" VALUES(22922,'Donner','Donner, Louisiana',27861,22);
INSERT INTO "django_geo_db_city" VALUES(22923,'Dulac','Dulac, Louisiana',27862,22);
INSERT INTO "django_geo_db_city" VALUES(22924,'Galliano','Galliano, Louisiana',27863,22);
INSERT INTO "django_geo_db_city" VALUES(22925,'Gheens','Gheens, Louisiana',27864,22);
INSERT INTO "django_geo_db_city" VALUES(22926,'Gibson','Gibson, Louisiana',27865,22);
INSERT INTO "django_geo_db_city" VALUES(22927,'Golden Meadow','Golden Meadow, Louisiana',27866,22);
INSERT INTO "django_geo_db_city" VALUES(22928,'Grand Isle','Grand Isle, Louisiana',27867,22);
INSERT INTO "django_geo_db_city" VALUES(22929,'Gray','Gray, Louisiana',27868,22);
INSERT INTO "django_geo_db_city" VALUES(22930,'Houma','Houma, Louisiana',27869,22);
INSERT INTO "django_geo_db_city" VALUES(22931,'Kraemer','Kraemer, Louisiana',27874,22);
INSERT INTO "django_geo_db_city" VALUES(22932,'Labadieville','Labadieville, Louisiana',27875,22);
INSERT INTO "django_geo_db_city" VALUES(22933,'Larose','Larose, Louisiana',27876,22);
INSERT INTO "django_geo_db_city" VALUES(22934,'Lockport','Lockport, Louisiana',27877,22);
INSERT INTO "django_geo_db_city" VALUES(22935,'Mathews','Mathews, Louisiana',27878,22);
INSERT INTO "django_geo_db_city" VALUES(22936,'Modeste','Modeste, Louisiana',27879,22);
INSERT INTO "django_geo_db_city" VALUES(22937,'Montegut','Montegut, Louisiana',27880,22);
INSERT INTO "django_geo_db_city" VALUES(22938,'Morgan City','Morgan City, Louisiana',27881,22);
INSERT INTO "django_geo_db_city" VALUES(22939,'Cankton','Cankton, Louisiana',27883,22);
INSERT INTO "django_geo_db_city" VALUES(22940,'Napoleonville','Napoleonville, Louisiana',27884,22);
INSERT INTO "django_geo_db_city" VALUES(22941,'Paincourtville','Paincourtville, Louisiana',27885,22);
INSERT INTO "django_geo_db_city" VALUES(22942,'Patterson','Patterson, Louisiana',27886,22);
INSERT INTO "django_geo_db_city" VALUES(22943,'Plattenville','Plattenville, Louisiana',27887,22);
INSERT INTO "django_geo_db_city" VALUES(22944,'Raceland','Raceland, Louisiana',27888,22);
INSERT INTO "django_geo_db_city" VALUES(22945,'Schriever','Schriever, Louisiana',27889,22);
INSERT INTO "django_geo_db_city" VALUES(22946,'Theriot','Theriot, Louisiana',27890,22);
INSERT INTO "django_geo_db_city" VALUES(22947,'Hammond','Hammond, Louisiana',27891,22);
INSERT INTO "django_geo_db_city" VALUES(22948,'Abita Springs','Abita Springs, Louisiana',27895,22);
INSERT INTO "django_geo_db_city" VALUES(22949,'Akers','Akers, Louisiana',27896,22);
INSERT INTO "django_geo_db_city" VALUES(22950,'Amite','Amite, Louisiana',27897,22);
INSERT INTO "django_geo_db_city" VALUES(22951,'Angie','Angie, Louisiana',27898,22);
INSERT INTO "django_geo_db_city" VALUES(22952,'Bogalusa','Bogalusa, Louisiana',27899,22);
INSERT INTO "django_geo_db_city" VALUES(22953,'Sun','Sun, Louisiana',27900,22);
INSERT INTO "django_geo_db_city" VALUES(22954,'Bush','Bush, Louisiana',27902,22);
INSERT INTO "django_geo_db_city" VALUES(22955,'Covington','Covington, Louisiana',27903,22);
INSERT INTO "django_geo_db_city" VALUES(22956,'Fluker','Fluker, Louisiana',27907,22);
INSERT INTO "django_geo_db_city" VALUES(22957,'Folsom','Folsom, Louisiana',27908,22);
INSERT INTO "django_geo_db_city" VALUES(22958,'Franklinton','Franklinton, Louisiana',27909,22);
INSERT INTO "django_geo_db_city" VALUES(22959,'Mandeville','Mandeville, Louisiana',27910,22);
INSERT INTO "django_geo_db_city" VALUES(22960,'Greensburg','Greensburg, Louisiana',27911,22);
INSERT INTO "django_geo_db_city" VALUES(22961,'Husser','Husser, Louisiana',27912,22);
INSERT INTO "django_geo_db_city" VALUES(22962,'Independence','Independence, Louisiana',27913,22);
INSERT INTO "django_geo_db_city" VALUES(22963,'Kentwood','Kentwood, Louisiana',27914,22);
INSERT INTO "django_geo_db_city" VALUES(22964,'Lacombe','Lacombe, Louisiana',27915,22);
INSERT INTO "django_geo_db_city" VALUES(22965,'Loranger','Loranger, Louisiana',27916,22);
INSERT INTO "django_geo_db_city" VALUES(22966,'Madisonville','Madisonville, Louisiana',27917,22);
INSERT INTO "django_geo_db_city" VALUES(22967,'Maurepas','Maurepas, Louisiana',27919,22);
INSERT INTO "django_geo_db_city" VALUES(22968,'Mount Hermon','Mount Hermon, Louisiana',27920,22);
INSERT INTO "django_geo_db_city" VALUES(22969,'Natalbany','Natalbany, Louisiana',27921,22);
INSERT INTO "django_geo_db_city" VALUES(22970,'Pearl River','Pearl River, Louisiana',27922,22);
INSERT INTO "django_geo_db_city" VALUES(22971,'Pine Grove','Pine Grove, Louisiana',27923,22);
INSERT INTO "django_geo_db_city" VALUES(22972,'Ponchatoula','Ponchatoula, Louisiana',27924,22);
INSERT INTO "django_geo_db_city" VALUES(22973,'Robert','Robert, Louisiana',27925,22);
INSERT INTO "django_geo_db_city" VALUES(22974,'Roseland','Roseland, Louisiana',27926,22);
INSERT INTO "django_geo_db_city" VALUES(22975,'Saint Benedict','Saint Benedict, Louisiana',27927,22);
INSERT INTO "django_geo_db_city" VALUES(22976,'Slidell','Slidell, Louisiana',27928,22);
INSERT INTO "django_geo_db_city" VALUES(22977,'Springfield','Springfield, Louisiana',27931,22);
INSERT INTO "django_geo_db_city" VALUES(22978,'Talisheek','Talisheek, Louisiana',27933,22);
INSERT INTO "django_geo_db_city" VALUES(22979,'Tangipahoa','Tangipahoa, Louisiana',27934,22);
INSERT INTO "django_geo_db_city" VALUES(22980,'Tickfaw','Tickfaw, Louisiana',27935,22);
INSERT INTO "django_geo_db_city" VALUES(22981,'Lafayette','Lafayette, Louisiana',27940,22);
INSERT INTO "django_geo_db_city" VALUES(22982,'Abbeville','Abbeville, Louisiana',27949,22);
INSERT INTO "django_geo_db_city" VALUES(22983,'Arnaudville','Arnaudville, Louisiana',27951,22);
INSERT INTO "django_geo_db_city" VALUES(22984,'Avery Island','Avery Island, Louisiana',27952,22);
INSERT INTO "django_geo_db_city" VALUES(22985,'Baldwin','Baldwin, Louisiana',27953,22);
INSERT INTO "django_geo_db_city" VALUES(22986,'Basile','Basile, Louisiana',27954,22);
INSERT INTO "django_geo_db_city" VALUES(22987,'Branch','Branch, Louisiana',27955,22);
INSERT INTO "django_geo_db_city" VALUES(22988,'Breaux Bridge','Breaux Bridge, Louisiana',27956,22);
INSERT INTO "django_geo_db_city" VALUES(22989,'Broussard','Broussard, Louisiana',27957,22);
INSERT INTO "django_geo_db_city" VALUES(22990,'Cade','Cade, Louisiana',27958,22);
INSERT INTO "django_geo_db_city" VALUES(22991,'Carencro','Carencro, Louisiana',27959,22);
INSERT INTO "django_geo_db_city" VALUES(22992,'Cecilia','Cecilia, Louisiana',27960,22);
INSERT INTO "django_geo_db_city" VALUES(22993,'Centerville','Centerville, Louisiana',27961,22);
INSERT INTO "django_geo_db_city" VALUES(22994,'Charenton','Charenton, Louisiana',27962,22);
INSERT INTO "django_geo_db_city" VALUES(22995,'Chataignier','Chataignier, Louisiana',27963,22);
INSERT INTO "django_geo_db_city" VALUES(22996,'Church Point','Church Point, Louisiana',27964,22);
INSERT INTO "django_geo_db_city" VALUES(22997,'Crowley','Crowley, Louisiana',27965,22);
INSERT INTO "django_geo_db_city" VALUES(22998,'Delcambre','Delcambre, Louisiana',27967,22);
INSERT INTO "django_geo_db_city" VALUES(22999,'Duson','Duson, Louisiana',27968,22);
INSERT INTO "django_geo_db_city" VALUES(23000,'Egan','Egan, Louisiana',27969,22);
INSERT INTO "django_geo_db_city" VALUES(23001,'Elton','Elton, Louisiana',27970,22);
INSERT INTO "django_geo_db_city" VALUES(23002,'Erath','Erath, Louisiana',27971,22);
INSERT INTO "django_geo_db_city" VALUES(23003,'Estherwood','Estherwood, Louisiana',27972,22);
INSERT INTO "django_geo_db_city" VALUES(23004,'Eunice','Eunice, Louisiana',27973,22);
INSERT INTO "django_geo_db_city" VALUES(23005,'Evangeline','Evangeline, Louisiana',27974,22);
INSERT INTO "django_geo_db_city" VALUES(23006,'Franklin','Franklin, Louisiana',27975,22);
INSERT INTO "django_geo_db_city" VALUES(23007,'Garden City','Garden City, Louisiana',27976,22);
INSERT INTO "django_geo_db_city" VALUES(23008,'Grand Coteau','Grand Coteau, Louisiana',27977,22);
INSERT INTO "django_geo_db_city" VALUES(23009,'Gueydan','Gueydan, Louisiana',27978,22);
INSERT INTO "django_geo_db_city" VALUES(23010,'Iota','Iota, Louisiana',27979,22);
INSERT INTO "django_geo_db_city" VALUES(23011,'Jeanerette','Jeanerette, Louisiana',27980,22);
INSERT INTO "django_geo_db_city" VALUES(23012,'Jennings','Jennings, Louisiana',27981,22);
INSERT INTO "django_geo_db_city" VALUES(23013,'Kaplan','Kaplan, Louisiana',27982,22);
INSERT INTO "django_geo_db_city" VALUES(23014,'Lake Arthur','Lake Arthur, Louisiana',27983,22);
INSERT INTO "django_geo_db_city" VALUES(23015,'Lawtell','Lawtell, Louisiana',27984,22);
INSERT INTO "django_geo_db_city" VALUES(23016,'Leonville','Leonville, Louisiana',27985,22);
INSERT INTO "django_geo_db_city" VALUES(23017,'Loreauville','Loreauville, Louisiana',27986,22);
INSERT INTO "django_geo_db_city" VALUES(23018,'Mamou','Mamou, Louisiana',27987,22);
INSERT INTO "django_geo_db_city" VALUES(23019,'Maurice','Maurice, Louisiana',27988,22);
INSERT INTO "django_geo_db_city" VALUES(23020,'Mermentau','Mermentau, Louisiana',27989,22);
INSERT INTO "django_geo_db_city" VALUES(23021,'Milton','Milton, Louisiana',27990,22);
INSERT INTO "django_geo_db_city" VALUES(23022,'Morse','Morse, Louisiana',27991,22);
INSERT INTO "django_geo_db_city" VALUES(23023,'New Iberia','New Iberia, Louisiana',27992,22);
INSERT INTO "django_geo_db_city" VALUES(23024,'Lydia','Lydia, Louisiana',27995,22);
INSERT INTO "django_geo_db_city" VALUES(23025,'Opelousas','Opelousas, Louisiana',27996,22);
INSERT INTO "django_geo_db_city" VALUES(23026,'Perry','Perry, Louisiana',27998,22);
INSERT INTO "django_geo_db_city" VALUES(23027,'Pine Prairie','Pine Prairie, Louisiana',27999,22);
INSERT INTO "django_geo_db_city" VALUES(23028,'Port Barre','Port Barre, Louisiana',28000,22);
INSERT INTO "django_geo_db_city" VALUES(23029,'Rayne','Rayne, Louisiana',28001,22);
INSERT INTO "django_geo_db_city" VALUES(23030,'Reddell','Reddell, Louisiana',28002,22);
INSERT INTO "django_geo_db_city" VALUES(23031,'Roanoke','Roanoke, Louisiana',28003,22);
INSERT INTO "django_geo_db_city" VALUES(23032,'Saint Martinville','Saint Martinville, Louisiana',28004,22);
INSERT INTO "django_geo_db_city" VALUES(23033,'Scott','Scott, Louisiana',28005,22);
INSERT INTO "django_geo_db_city" VALUES(23034,'Sunset','Sunset, Louisiana',28006,22);
INSERT INTO "django_geo_db_city" VALUES(23035,'Turkey Creek','Turkey Creek, Louisiana',28007,22);
INSERT INTO "django_geo_db_city" VALUES(23036,'Ville Platte','Ville Platte, Louisiana',28008,22);
INSERT INTO "django_geo_db_city" VALUES(23037,'Washington','Washington, Louisiana',28009,22);
INSERT INTO "django_geo_db_city" VALUES(23038,'Welsh','Welsh, Louisiana',28010,22);
INSERT INTO "django_geo_db_city" VALUES(23039,'Youngsville','Youngsville, Louisiana',28011,22);
INSERT INTO "django_geo_db_city" VALUES(23040,'Lake Charles','Lake Charles, Louisiana',28014,22);
INSERT INTO "django_geo_db_city" VALUES(23041,'Bell City','Bell City, Louisiana',28020,22);
INSERT INTO "django_geo_db_city" VALUES(23042,'Cameron','Cameron, Louisiana',28021,22);
INSERT INTO "django_geo_db_city" VALUES(23043,'Creole','Creole, Louisiana',28022,22);
INSERT INTO "django_geo_db_city" VALUES(23044,'Dequincy','Dequincy, Louisiana',28023,22);
INSERT INTO "django_geo_db_city" VALUES(23045,'Deridder','Deridder, Louisiana',28024,22);
INSERT INTO "django_geo_db_city" VALUES(23046,'Dry Creek','Dry Creek, Louisiana',28025,22);
INSERT INTO "django_geo_db_city" VALUES(23047,'Elizabeth','Elizabeth, Louisiana',28026,22);
INSERT INTO "django_geo_db_city" VALUES(23048,'Evans','Evans, Louisiana',28027,22);
INSERT INTO "django_geo_db_city" VALUES(23049,'Fenton','Fenton, Louisiana',28028,22);
INSERT INTO "django_geo_db_city" VALUES(23050,'Fullerton','Fullerton, Louisiana',28029,22);
INSERT INTO "django_geo_db_city" VALUES(23051,'Grand Chenier','Grand Chenier, Louisiana',28030,22);
INSERT INTO "django_geo_db_city" VALUES(23052,'Grant','Grant, Louisiana',28031,22);
INSERT INTO "django_geo_db_city" VALUES(23053,'Hackberry','Hackberry, Louisiana',28032,22);
INSERT INTO "django_geo_db_city" VALUES(23054,'Hayes','Hayes, Louisiana',28033,22);
INSERT INTO "django_geo_db_city" VALUES(23055,'Iowa','Iowa, Louisiana',28034,22);
INSERT INTO "django_geo_db_city" VALUES(23056,'Kinder','Kinder, Louisiana',28035,22);
INSERT INTO "django_geo_db_city" VALUES(23057,'Lacassine','Lacassine, Louisiana',28036,22);
INSERT INTO "django_geo_db_city" VALUES(23058,'Leblanc','Leblanc, Louisiana',28037,22);
INSERT INTO "django_geo_db_city" VALUES(23059,'Longville','Longville, Louisiana',28038,22);
INSERT INTO "django_geo_db_city" VALUES(23060,'Merryville','Merryville, Louisiana',28039,22);
INSERT INTO "django_geo_db_city" VALUES(23061,'Mittie','Mittie, Louisiana',28040,22);
INSERT INTO "django_geo_db_city" VALUES(23062,'Oberlin','Oberlin, Louisiana',28041,22);
INSERT INTO "django_geo_db_city" VALUES(23063,'Pitkin','Pitkin, Louisiana',28042,22);
INSERT INTO "django_geo_db_city" VALUES(23064,'Ragley','Ragley, Louisiana',28043,22);
INSERT INTO "django_geo_db_city" VALUES(23065,'Reeves','Reeves, Louisiana',28044,22);
INSERT INTO "django_geo_db_city" VALUES(23066,'Rosepine','Rosepine, Louisiana',28045,22);
INSERT INTO "django_geo_db_city" VALUES(23067,'Singer','Singer, Louisiana',28046,22);
INSERT INTO "django_geo_db_city" VALUES(23068,'Starks','Starks, Louisiana',28047,22);
INSERT INTO "django_geo_db_city" VALUES(23069,'Sugartown','Sugartown, Louisiana',28048,22);
INSERT INTO "django_geo_db_city" VALUES(23070,'Sulphur','Sulphur, Louisiana',28049,22);
INSERT INTO "django_geo_db_city" VALUES(23071,'Vinton','Vinton, Louisiana',28051,22);
INSERT INTO "django_geo_db_city" VALUES(23072,'Westlake','Westlake, Louisiana',28052,22);
INSERT INTO "django_geo_db_city" VALUES(23073,'Baker','Baker, Louisiana',28053,22);
INSERT INTO "django_geo_db_city" VALUES(23074,'Denham Springs','Denham Springs, Louisiana',28054,22);
INSERT INTO "django_geo_db_city" VALUES(23075,'Gonzales','Gonzales, Louisiana',27879,22);
INSERT INTO "django_geo_db_city" VALUES(23076,'Addis','Addis, Louisiana',28055,22);
INSERT INTO "django_geo_db_city" VALUES(23077,'Albany','Albany, Louisiana',28056,22);
INSERT INTO "django_geo_db_city" VALUES(23078,'Angola','Angola, Louisiana',28057,22);
INSERT INTO "django_geo_db_city" VALUES(23079,'Batchelor','Batchelor, Louisiana',28059,22);
INSERT INTO "django_geo_db_city" VALUES(23080,'Bayou Goula','Bayou Goula, Louisiana',28060,22);
INSERT INTO "django_geo_db_city" VALUES(23081,'Blanks','Blanks, Louisiana',28061,22);
INSERT INTO "django_geo_db_city" VALUES(23082,'Brittany','Brittany, Louisiana',28062,22);
INSERT INTO "django_geo_db_city" VALUES(23083,'Brusly','Brusly, Louisiana',28063,22);
INSERT INTO "django_geo_db_city" VALUES(23084,'Bueche','Bueche, Louisiana',28064,22);
INSERT INTO "django_geo_db_city" VALUES(23085,'Carville','Carville, Louisiana',28065,22);
INSERT INTO "django_geo_db_city" VALUES(23086,'Clinton','Clinton, Louisiana',28066,22);
INSERT INTO "django_geo_db_city" VALUES(23087,'Convent','Convent, Louisiana',28067,22);
INSERT INTO "django_geo_db_city" VALUES(23088,'Darrow','Darrow, Louisiana',28068,22);
INSERT INTO "django_geo_db_city" VALUES(23089,'Duplessis','Duplessis, Louisiana',28071,22);
INSERT INTO "django_geo_db_city" VALUES(23090,'Erwinville','Erwinville, Louisiana',28072,22);
INSERT INTO "django_geo_db_city" VALUES(23091,'Ethel','Ethel, Louisiana',28073,22);
INSERT INTO "django_geo_db_city" VALUES(23092,'Fordoche','Fordoche, Louisiana',28074,22);
INSERT INTO "django_geo_db_city" VALUES(23093,'French Settlement','French Settlement, Louisiana',28075,22);
INSERT INTO "django_geo_db_city" VALUES(23094,'Geismar','Geismar, Louisiana',28076,22);
INSERT INTO "django_geo_db_city" VALUES(23095,'Glynn','Glynn, Louisiana',28077,22);
INSERT INTO "django_geo_db_city" VALUES(23096,'Burnside','Burnside, Louisiana',27879,22);
INSERT INTO "django_geo_db_city" VALUES(23097,'Greenwell Springs','Greenwell Springs, Louisiana',28079,22);
INSERT INTO "django_geo_db_city" VALUES(23098,'Grosse Tete','Grosse Tete, Louisiana',28080,22);
INSERT INTO "django_geo_db_city" VALUES(23099,'Hester','Hester, Louisiana',28081,22);
INSERT INTO "django_geo_db_city" VALUES(23100,'Holden','Holden, Louisiana',28082,22);
INSERT INTO "django_geo_db_city" VALUES(23101,'Innis','Innis, Louisiana',28083,22);
INSERT INTO "django_geo_db_city" VALUES(23102,'Jackson','Jackson, Louisiana',28084,22);
INSERT INTO "django_geo_db_city" VALUES(23103,'Jarreau','Jarreau, Louisiana',28085,22);
INSERT INTO "django_geo_db_city" VALUES(23104,'Krotz Springs','Krotz Springs, Louisiana',28086,22);
INSERT INTO "django_geo_db_city" VALUES(23105,'Labarre','Labarre, Louisiana',28087,22);
INSERT INTO "django_geo_db_city" VALUES(23106,'Lakeland','Lakeland, Louisiana',28088,22);
INSERT INTO "django_geo_db_city" VALUES(23107,'Lettsworth','Lettsworth, Louisiana',28089,22);
INSERT INTO "django_geo_db_city" VALUES(23108,'Livingston','Livingston, Louisiana',28090,22);
INSERT INTO "django_geo_db_city" VALUES(23109,'Livonia','Livonia, Louisiana',28091,22);
INSERT INTO "django_geo_db_city" VALUES(23110,'Lottie','Lottie, Louisiana',28092,22);
INSERT INTO "django_geo_db_city" VALUES(23111,'Maringouin','Maringouin, Louisiana',28093,22);
INSERT INTO "django_geo_db_city" VALUES(23112,'Morganza','Morganza, Louisiana',28094,22);
INSERT INTO "django_geo_db_city" VALUES(23113,'New Roads','New Roads, Louisiana',28095,22);
INSERT INTO "django_geo_db_city" VALUES(23114,'Norwood','Norwood, Louisiana',28096,22);
INSERT INTO "django_geo_db_city" VALUES(23115,'Oscar','Oscar, Louisiana',28097,22);
INSERT INTO "django_geo_db_city" VALUES(23116,'Paulina','Paulina, Louisiana',28098,22);
INSERT INTO "django_geo_db_city" VALUES(23117,'Plaquemine','Plaquemine, Louisiana',28099,22);
INSERT INTO "django_geo_db_city" VALUES(23118,'Port Allen','Port Allen, Louisiana',28100,22);
INSERT INTO "django_geo_db_city" VALUES(23119,'Prairieville','Prairieville, Louisiana',28101,22);
INSERT INTO "django_geo_db_city" VALUES(23120,'Pride','Pride, Louisiana',28102,22);
INSERT INTO "django_geo_db_city" VALUES(23121,'Rosedale','Rosedale, Louisiana',28103,22);
INSERT INTO "django_geo_db_city" VALUES(23122,'Rougon','Rougon, Louisiana',28104,22);
INSERT INTO "django_geo_db_city" VALUES(23123,'Saint Amant','Saint Amant, Louisiana',28105,22);
INSERT INTO "django_geo_db_city" VALUES(23124,'Saint Francisville','Saint Francisville, Louisiana',28106,22);
INSERT INTO "django_geo_db_city" VALUES(23125,'Saint Gabriel','Saint Gabriel, Louisiana',28107,22);
INSERT INTO "django_geo_db_city" VALUES(23126,'Slaughter','Slaughter, Louisiana',28108,22);
INSERT INTO "django_geo_db_city" VALUES(23127,'Sorrento','Sorrento, Louisiana',28109,22);
INSERT INTO "django_geo_db_city" VALUES(23128,'Sunshine','Sunshine, Louisiana',28110,22);
INSERT INTO "django_geo_db_city" VALUES(23129,'Torbert','Torbert, Louisiana',28111,22);
INSERT INTO "django_geo_db_city" VALUES(23130,'Tunica','Tunica, Louisiana',28112,22);
INSERT INTO "django_geo_db_city" VALUES(23131,'Ventress','Ventress, Louisiana',28113,22);
INSERT INTO "django_geo_db_city" VALUES(23132,'Wakefield','Wakefield, Louisiana',28114,22);
INSERT INTO "django_geo_db_city" VALUES(23133,'Walker','Walker, Louisiana',28115,22);
INSERT INTO "django_geo_db_city" VALUES(23134,'Watson','Watson, Louisiana',28116,22);
INSERT INTO "django_geo_db_city" VALUES(23135,'Weyanoke','Weyanoke, Louisiana',28117,22);
INSERT INTO "django_geo_db_city" VALUES(23136,'White Castle','White Castle, Louisiana',28118,22);
INSERT INTO "django_geo_db_city" VALUES(23137,'Wilson','Wilson, Louisiana',28119,22);
INSERT INTO "django_geo_db_city" VALUES(23138,'Zachary','Zachary, Louisiana',28120,22);
INSERT INTO "django_geo_db_city" VALUES(23139,'Uncle Sam','Uncle Sam, Louisiana',28121,22);
INSERT INTO "django_geo_db_city" VALUES(23140,'Baton Rouge','Baton Rouge, Louisiana',28122,22);
INSERT INTO "django_geo_db_city" VALUES(23141,'Arcadia','Arcadia, Louisiana',28150,22);
INSERT INTO "django_geo_db_city" VALUES(23142,'Ashland','Ashland, Louisiana',28151,22);
INSERT INTO "django_geo_db_city" VALUES(23143,'Athens','Athens, Louisiana',28152,22);
INSERT INTO "django_geo_db_city" VALUES(23144,'Belcher','Belcher, Louisiana',28153,22);
INSERT INTO "django_geo_db_city" VALUES(23145,'Benton','Benton, Louisiana',28154,22);
INSERT INTO "django_geo_db_city" VALUES(23146,'Bethany','Bethany, Louisiana',28155,22);
INSERT INTO "django_geo_db_city" VALUES(23147,'Bienville','Bienville, Louisiana',28156,22);
INSERT INTO "django_geo_db_city" VALUES(23148,'Blanchard','Blanchard, Louisiana',28157,22);
INSERT INTO "django_geo_db_city" VALUES(23149,'Castor','Castor, Louisiana',28158,22);
INSERT INTO "django_geo_db_city" VALUES(23150,'Cotton Valley','Cotton Valley, Louisiana',28159,22);
INSERT INTO "django_geo_db_city" VALUES(23151,'Coushatta','Coushatta, Louisiana',28160,22);
INSERT INTO "django_geo_db_city" VALUES(23152,'Cullen','Cullen, Louisiana',28161,22);
INSERT INTO "django_geo_db_city" VALUES(23153,'Doyline','Doyline, Louisiana',28162,22);
INSERT INTO "django_geo_db_city" VALUES(23154,'Dubberly','Dubberly, Louisiana',28163,22);
INSERT INTO "django_geo_db_city" VALUES(23155,'East Point','East Point, Louisiana',28164,22);
INSERT INTO "django_geo_db_city" VALUES(23156,'Frierson','Frierson, Louisiana',28165,22);
INSERT INTO "django_geo_db_city" VALUES(23157,'Gibsland','Gibsland, Louisiana',28166,22);
INSERT INTO "django_geo_db_city" VALUES(23158,'Gilliam','Gilliam, Louisiana',28167,22);
INSERT INTO "django_geo_db_city" VALUES(23159,'Gloster','Gloster, Louisiana',28168,22);
INSERT INTO "django_geo_db_city" VALUES(23160,'Goldonna','Goldonna, Louisiana',28169,22);
INSERT INTO "django_geo_db_city" VALUES(23161,'Grand Cane','Grand Cane, Louisiana',28170,22);
INSERT INTO "django_geo_db_city" VALUES(23162,'Greenwood','Greenwood, Louisiana',28171,22);
INSERT INTO "django_geo_db_city" VALUES(23163,'Hall Summit','Hall Summit, Louisiana',28172,22);
INSERT INTO "django_geo_db_city" VALUES(23164,'Harmon','Harmon, Louisiana',28164,22);
INSERT INTO "django_geo_db_city" VALUES(23165,'Haughton','Haughton, Louisiana',28173,22);
INSERT INTO "django_geo_db_city" VALUES(23166,'Haynesville','Haynesville, Louisiana',28174,22);
INSERT INTO "django_geo_db_city" VALUES(23167,'Heflin','Heflin, Louisiana',28175,22);
INSERT INTO "django_geo_db_city" VALUES(23168,'Homer','Homer, Louisiana',28176,22);
INSERT INTO "django_geo_db_city" VALUES(23169,'Hosston','Hosston, Louisiana',28177,22);
INSERT INTO "django_geo_db_city" VALUES(23170,'Ida','Ida, Louisiana',28178,22);
INSERT INTO "django_geo_db_city" VALUES(23171,'Jamestown','Jamestown, Louisiana',28179,22);
INSERT INTO "django_geo_db_city" VALUES(23172,'Keatchie','Keatchie, Louisiana',28180,22);
INSERT INTO "django_geo_db_city" VALUES(23173,'Keithville','Keithville, Louisiana',28181,22);
INSERT INTO "django_geo_db_city" VALUES(23174,'Lisbon','Lisbon, Louisiana',28182,22);
INSERT INTO "django_geo_db_city" VALUES(23175,'Logansport','Logansport, Louisiana',28183,22);
INSERT INTO "django_geo_db_city" VALUES(23176,'Longstreet','Longstreet, Louisiana',28184,22);
INSERT INTO "django_geo_db_city" VALUES(23177,'Elm Grove','Elm Grove, Louisiana',28185,22);
INSERT INTO "django_geo_db_city" VALUES(23178,'Mansfield','Mansfield, Louisiana',28186,22);
INSERT INTO "django_geo_db_city" VALUES(23179,'South Mansfield','South Mansfield, Louisiana',28187,22);
INSERT INTO "django_geo_db_city" VALUES(23180,'Minden','Minden, Louisiana',28188,22);
INSERT INTO "django_geo_db_city" VALUES(23181,'Mooringsport','Mooringsport, Louisiana',28191,22);
INSERT INTO "django_geo_db_city" VALUES(23182,'Oil City','Oil City, Louisiana',28192,22);
INSERT INTO "django_geo_db_city" VALUES(23183,'Pelican','Pelican, Louisiana',28193,22);
INSERT INTO "django_geo_db_city" VALUES(23184,'Plain Dealing','Plain Dealing, Louisiana',28194,22);
INSERT INTO "django_geo_db_city" VALUES(23185,'Pleasant Hill','Pleasant Hill, Louisiana',28195,22);
INSERT INTO "django_geo_db_city" VALUES(23186,'Powhatan','Powhatan, Louisiana',28196,22);
INSERT INTO "django_geo_db_city" VALUES(23187,'Princeton','Princeton, Louisiana',28197,22);
INSERT INTO "django_geo_db_city" VALUES(23188,'Ringgold','Ringgold, Louisiana',28198,22);
INSERT INTO "django_geo_db_city" VALUES(23189,'Rodessa','Rodessa, Louisiana',28199,22);
INSERT INTO "django_geo_db_city" VALUES(23190,'Saline','Saline, Louisiana',28200,22);
INSERT INTO "django_geo_db_city" VALUES(23191,'Sarepta','Sarepta, Louisiana',28201,22);
INSERT INTO "django_geo_db_city" VALUES(23192,'Shongaloo','Shongaloo, Louisiana',28202,22);
INSERT INTO "django_geo_db_city" VALUES(23193,'Sibley','Sibley, Louisiana',28203,22);
INSERT INTO "django_geo_db_city" VALUES(23194,'Springhill','Springhill, Louisiana',28204,22);
INSERT INTO "django_geo_db_city" VALUES(23195,'Stonewall','Stonewall, Louisiana',28206,22);
INSERT INTO "django_geo_db_city" VALUES(23196,'Summerfield','Summerfield, Louisiana',28207,22);
INSERT INTO "django_geo_db_city" VALUES(23197,'Taylor','Taylor, Louisiana',28208,22);
INSERT INTO "django_geo_db_city" VALUES(23198,'Vivian','Vivian, Louisiana',28209,22);
INSERT INTO "django_geo_db_city" VALUES(23199,'Shreveport','Shreveport, Louisiana',28211,22);
INSERT INTO "django_geo_db_city" VALUES(23200,'Barksdale AFB','Barksdale AFB, Louisiana',28220,22);
INSERT INTO "django_geo_db_city" VALUES(23201,'Bossier City','Bossier City, Louisiana',28221,22);
INSERT INTO "django_geo_db_city" VALUES(23202,'Monroe','Monroe, Louisiana',28228,22);
INSERT INTO "django_geo_db_city" VALUES(23203,'Archibald','Archibald, Louisiana',28235,22);
INSERT INTO "django_geo_db_city" VALUES(23204,'Baskin','Baskin, Louisiana',28236,22);
INSERT INTO "django_geo_db_city" VALUES(23205,'Bastrop','Bastrop, Louisiana',28237,22);
INSERT INTO "django_geo_db_city" VALUES(23206,'Bernice','Bernice, Louisiana',28239,22);
INSERT INTO "django_geo_db_city" VALUES(23207,'Bonita','Bonita, Louisiana',28240,22);
INSERT INTO "django_geo_db_city" VALUES(23208,'Calhoun','Calhoun, Louisiana',28241,22);
INSERT INTO "django_geo_db_city" VALUES(23209,'Chatham','Chatham, Louisiana',28242,22);
INSERT INTO "django_geo_db_city" VALUES(23210,'Choudrant','Choudrant, Louisiana',28243,22);
INSERT INTO "django_geo_db_city" VALUES(23211,'Collinston','Collinston, Louisiana',28244,22);
INSERT INTO "django_geo_db_city" VALUES(23212,'Crowville','Crowville, Louisiana',28245,22);
INSERT INTO "django_geo_db_city" VALUES(23213,'Delhi','Delhi, Louisiana',28246,22);
INSERT INTO "django_geo_db_city" VALUES(23214,'Delta','Delta, Louisiana',28247,22);
INSERT INTO "django_geo_db_city" VALUES(23215,'Downsville','Downsville, Louisiana',28248,22);
INSERT INTO "django_geo_db_city" VALUES(23216,'Dubach','Dubach, Louisiana',28249,22);
INSERT INTO "django_geo_db_city" VALUES(23217,'Epps','Epps, Louisiana',28250,22);
INSERT INTO "django_geo_db_city" VALUES(23218,'Eros','Eros, Louisiana',28251,22);
INSERT INTO "django_geo_db_city" VALUES(23219,'Fairbanks','Fairbanks, Louisiana',28231,22);
INSERT INTO "django_geo_db_city" VALUES(23220,'Farmerville','Farmerville, Louisiana',28252,22);
INSERT INTO "django_geo_db_city" VALUES(23221,'Forest','Forest, Louisiana',28253,22);
INSERT INTO "django_geo_db_city" VALUES(23222,'Fort Necessity','Fort Necessity, Louisiana',28254,22);
INSERT INTO "django_geo_db_city" VALUES(23223,'Grambling','Grambling, Louisiana',28255,22);
INSERT INTO "django_geo_db_city" VALUES(23224,'Hodge','Hodge, Louisiana',28256,22);
INSERT INTO "django_geo_db_city" VALUES(23225,'Jigger','Jigger, Louisiana',28245,22);
INSERT INTO "django_geo_db_city" VALUES(23226,'Jones','Jones, Louisiana',28257,22);
INSERT INTO "django_geo_db_city" VALUES(23227,'Jonesboro','Jonesboro, Louisiana',28258,22);
INSERT INTO "django_geo_db_city" VALUES(23228,'Kilbourne','Kilbourne, Louisiana',28259,22);
INSERT INTO "django_geo_db_city" VALUES(23229,'Lake Providence','Lake Providence, Louisiana',28260,22);
INSERT INTO "django_geo_db_city" VALUES(23230,'Lillie','Lillie, Louisiana',28261,22);
INSERT INTO "django_geo_db_city" VALUES(23231,'Mangham','Mangham, Louisiana',28262,22);
INSERT INTO "django_geo_db_city" VALUES(23232,'Marion','Marion, Louisiana',28263,22);
INSERT INTO "django_geo_db_city" VALUES(23233,'Mer Rouge','Mer Rouge, Louisiana',28264,22);
INSERT INTO "django_geo_db_city" VALUES(23234,'Oak Grove','Oak Grove, Louisiana',28265,22);
INSERT INTO "django_geo_db_city" VALUES(23235,'Oak Ridge','Oak Ridge, Louisiana',28266,22);
INSERT INTO "django_geo_db_city" VALUES(23236,'Pioneer','Pioneer, Louisiana',28267,22);
INSERT INTO "django_geo_db_city" VALUES(23237,'Quitman','Quitman, Louisiana',28268,22);
INSERT INTO "django_geo_db_city" VALUES(23238,'Rayville','Rayville, Louisiana',28269,22);
INSERT INTO "django_geo_db_city" VALUES(23239,'Ruston','Ruston, Louisiana',28270,22);
INSERT INTO "django_geo_db_city" VALUES(23240,'Simsboro','Simsboro, Louisiana',28273,22);
INSERT INTO "django_geo_db_city" VALUES(23241,'Sondheimer','Sondheimer, Louisiana',28274,22);
INSERT INTO "django_geo_db_city" VALUES(23242,'Spearsville','Spearsville, Louisiana',28275,22);
INSERT INTO "django_geo_db_city" VALUES(23243,'Start','Start, Louisiana',28276,22);
INSERT INTO "django_geo_db_city" VALUES(23244,'Sterlington','Sterlington, Louisiana',28277,22);
INSERT INTO "django_geo_db_city" VALUES(23245,'Swartz','Swartz, Louisiana',28231,22);
INSERT INTO "django_geo_db_city" VALUES(23246,'Tallulah','Tallulah, Louisiana',28278,22);
INSERT INTO "django_geo_db_city" VALUES(23247,'Transylvania','Transylvania, Louisiana',28279,22);
INSERT INTO "django_geo_db_city" VALUES(23248,'West Monroe','West Monroe, Louisiana',28280,22);
INSERT INTO "django_geo_db_city" VALUES(23249,'Winnsboro','Winnsboro, Louisiana',28282,22);
INSERT INTO "django_geo_db_city" VALUES(23250,'Alexandria','Alexandria, Louisiana',28283,22);
INSERT INTO "django_geo_db_city" VALUES(23251,'Acme','Acme, Louisiana',28290,22);
INSERT INTO "django_geo_db_city" VALUES(23252,'Bordelonville','Bordelonville, Louisiana',28291,22);
INSERT INTO "django_geo_db_city" VALUES(23253,'Bunkie','Bunkie, Louisiana',28292,22);
INSERT INTO "django_geo_db_city" VALUES(23254,'Center Point','Center Point, Louisiana',28293,22);
INSERT INTO "django_geo_db_city" VALUES(23255,'Chase','Chase, Louisiana',28245,22);
INSERT INTO "django_geo_db_city" VALUES(23256,'Cheneyville','Cheneyville, Louisiana',28294,22);
INSERT INTO "django_geo_db_city" VALUES(23257,'Clayton','Clayton, Louisiana',28295,22);
INSERT INTO "django_geo_db_city" VALUES(23258,'Cottonport','Cottonport, Louisiana',28296,22);
INSERT INTO "django_geo_db_city" VALUES(23259,'Deville','Deville, Louisiana',28297,22);
INSERT INTO "django_geo_db_city" VALUES(23260,'Dupont','Dupont, Louisiana',28298,22);
INSERT INTO "django_geo_db_city" VALUES(23261,'Echo','Echo, Louisiana',28299,22);
INSERT INTO "django_geo_db_city" VALUES(23262,'Effie','Effie, Louisiana',28300,22);
INSERT INTO "django_geo_db_city" VALUES(23263,'Evergreen','Evergreen, Louisiana',28301,22);
INSERT INTO "django_geo_db_city" VALUES(23264,'Ferriday','Ferriday, Louisiana',28302,22);
INSERT INTO "django_geo_db_city" VALUES(23265,'Gilbert','Gilbert, Louisiana',28303,22);
INSERT INTO "django_geo_db_city" VALUES(23266,'Hamburg','Hamburg, Louisiana',28304,22);
INSERT INTO "django_geo_db_city" VALUES(23267,'Harrisonburg','Harrisonburg, Louisiana',28305,22);
INSERT INTO "django_geo_db_city" VALUES(23268,'Hessmer','Hessmer, Louisiana',28306,22);
INSERT INTO "django_geo_db_city" VALUES(23269,'Jena','Jena, Louisiana',28307,22);
INSERT INTO "django_geo_db_city" VALUES(23270,'Jonesville','Jonesville, Louisiana',28308,22);
INSERT INTO "django_geo_db_city" VALUES(23271,'Lebeau','Lebeau, Louisiana',28309,22);
INSERT INTO "django_geo_db_city" VALUES(23272,'Lecompte','Lecompte, Louisiana',28310,22);
INSERT INTO "django_geo_db_city" VALUES(23273,'Libuse','Libuse, Louisiana',28287,22);
INSERT INTO "django_geo_db_city" VALUES(23274,'Mansura','Mansura, Louisiana',28311,22);
INSERT INTO "django_geo_db_city" VALUES(23275,'Marksville','Marksville, Louisiana',28312,22);
INSERT INTO "django_geo_db_city" VALUES(23276,'Melville','Melville, Louisiana',28313,22);
INSERT INTO "django_geo_db_city" VALUES(23277,'Monterey','Monterey, Louisiana',28314,22);
INSERT INTO "django_geo_db_city" VALUES(23278,'Moreauville','Moreauville, Louisiana',28315,22);
INSERT INTO "django_geo_db_city" VALUES(23279,'Morrow','Morrow, Louisiana',28316,22);
INSERT INTO "django_geo_db_city" VALUES(23280,'Newellton','Newellton, Louisiana',28317,22);
INSERT INTO "django_geo_db_city" VALUES(23281,'Palmetto','Palmetto, Louisiana',28318,22);
INSERT INTO "django_geo_db_city" VALUES(23282,'Pineville','Pineville, Louisiana',28287,22);
INSERT INTO "django_geo_db_city" VALUES(23283,'Plaucheville','Plaucheville, Louisiana',28321,22);
INSERT INTO "django_geo_db_city" VALUES(23284,'Rhinehart','Rhinehart, Louisiana',28322,22);
INSERT INTO "django_geo_db_city" VALUES(23285,'Ruby','Ruby, Louisiana',28287,22);
INSERT INTO "django_geo_db_city" VALUES(23286,'Saint Joseph','Saint Joseph, Louisiana',28323,22);
INSERT INTO "django_geo_db_city" VALUES(23287,'Saint Landry','Saint Landry, Louisiana',28324,22);
INSERT INTO "django_geo_db_city" VALUES(23288,'Sicily Island','Sicily Island, Louisiana',28325,22);
INSERT INTO "django_geo_db_city" VALUES(23289,'Simmesport','Simmesport, Louisiana',28326,22);
INSERT INTO "django_geo_db_city" VALUES(23290,'Trout','Trout, Louisiana',28327,22);
INSERT INTO "django_geo_db_city" VALUES(23291,'Vidalia','Vidalia, Louisiana',28328,22);
INSERT INTO "django_geo_db_city" VALUES(23292,'Waterproof','Waterproof, Louisiana',28329,22);
INSERT INTO "django_geo_db_city" VALUES(23293,'Wildsville','Wildsville, Louisiana',28330,22);
INSERT INTO "django_geo_db_city" VALUES(23294,'Wisner','Wisner, Louisiana',28331,22);
INSERT INTO "django_geo_db_city" VALUES(23295,'Aimwell','Aimwell, Louisiana',28332,22);
INSERT INTO "django_geo_db_city" VALUES(23296,'Anacoco','Anacoco, Louisiana',28333,22);
INSERT INTO "django_geo_db_city" VALUES(23297,'Atlanta','Atlanta, Louisiana',28334,22);
INSERT INTO "django_geo_db_city" VALUES(23298,'Ball','Ball, Louisiana',28335,22);
INSERT INTO "django_geo_db_city" VALUES(23299,'Belmont','Belmont, Louisiana',28336,22);
INSERT INTO "django_geo_db_city" VALUES(23300,'Bentley','Bentley, Louisiana',28337,22);
INSERT INTO "django_geo_db_city" VALUES(23301,'Boyce','Boyce, Louisiana',28338,22);
INSERT INTO "django_geo_db_city" VALUES(23302,'Calvin','Calvin, Louisiana',28339,22);
INSERT INTO "django_geo_db_city" VALUES(23303,'Campti','Campti, Louisiana',28340,22);
INSERT INTO "django_geo_db_city" VALUES(23304,'Clarence','Clarence, Louisiana',28341,22);
INSERT INTO "django_geo_db_city" VALUES(23305,'Clarks','Clarks, Louisiana',28342,22);
INSERT INTO "django_geo_db_city" VALUES(23306,'Cloutierville','Cloutierville, Louisiana',28343,22);
INSERT INTO "django_geo_db_city" VALUES(23307,'Colfax','Colfax, Louisiana',28344,22);
INSERT INTO "django_geo_db_city" VALUES(23308,'Columbia','Columbia, Louisiana',28345,22);
INSERT INTO "django_geo_db_city" VALUES(23309,'Converse','Converse, Louisiana',28346,22);
INSERT INTO "django_geo_db_city" VALUES(23310,'Dodson','Dodson, Louisiana',28347,22);
INSERT INTO "django_geo_db_city" VALUES(23311,'Dry Prong','Dry Prong, Louisiana',28348,22);
INSERT INTO "django_geo_db_city" VALUES(23312,'Elmer','Elmer, Louisiana',28349,22);
INSERT INTO "django_geo_db_city" VALUES(23313,'Enterprise','Enterprise, Louisiana',28350,22);
INSERT INTO "django_geo_db_city" VALUES(23314,'Fisher','Fisher, Louisiana',28351,22);
INSERT INTO "django_geo_db_city" VALUES(23315,'Flatwoods','Flatwoods, Louisiana',28352,22);
INSERT INTO "django_geo_db_city" VALUES(23316,'Flora','Flora, Louisiana',28353,22);
INSERT INTO "django_geo_db_city" VALUES(23317,'Florien','Florien, Louisiana',28354,22);
INSERT INTO "django_geo_db_city" VALUES(23318,'Forest Hill','Forest Hill, Louisiana',28355,22);
INSERT INTO "django_geo_db_city" VALUES(23319,'Gardner','Gardner, Louisiana',28356,22);
INSERT INTO "django_geo_db_city" VALUES(23320,'Georgetown','Georgetown, Louisiana',28357,22);
INSERT INTO "django_geo_db_city" VALUES(23321,'Glenmora','Glenmora, Louisiana',28358,22);
INSERT INTO "django_geo_db_city" VALUES(23322,'Gorum','Gorum, Louisiana',28359,22);
INSERT INTO "django_geo_db_city" VALUES(23323,'Grayson','Grayson, Louisiana',28360,22);
INSERT INTO "django_geo_db_city" VALUES(23324,'McNary','McNary, Louisiana',28361,22);
INSERT INTO "django_geo_db_city" VALUES(23325,'Hineston','Hineston, Louisiana',28362,22);
INSERT INTO "django_geo_db_city" VALUES(23326,'Hornbeck','Hornbeck, Louisiana',28363,22);
INSERT INTO "django_geo_db_city" VALUES(23327,'Joyce','Joyce, Louisiana',28364,22);
INSERT INTO "django_geo_db_city" VALUES(23328,'Kelly','Kelly, Louisiana',28365,22);
INSERT INTO "django_geo_db_city" VALUES(23329,'Kurthwood','Kurthwood, Louisiana',28366,22);
INSERT INTO "django_geo_db_city" VALUES(23330,'Lacamp','Lacamp, Louisiana',28367,22);
INSERT INTO "django_geo_db_city" VALUES(23331,'Leesville','Leesville, Louisiana',28368,22);
INSERT INTO "django_geo_db_city" VALUES(23332,'Lena','Lena, Louisiana',28369,22);
INSERT INTO "django_geo_db_city" VALUES(23333,'Longleaf','Longleaf, Louisiana',28287,22);
INSERT INTO "django_geo_db_city" VALUES(23334,'Many','Many, Louisiana',28370,22);
INSERT INTO "django_geo_db_city" VALUES(23335,'Marthaville','Marthaville, Louisiana',28371,22);
INSERT INTO "django_geo_db_city" VALUES(23336,'Melrose','Melrose, Louisiana',28372,22);
INSERT INTO "django_geo_db_city" VALUES(23337,'Montgomery','Montgomery, Louisiana',28373,22);
INSERT INTO "django_geo_db_city" VALUES(23338,'Mora','Mora, Louisiana',28374,22);
INSERT INTO "django_geo_db_city" VALUES(23339,'Natchez','Natchez, Louisiana',28375,22);
INSERT INTO "django_geo_db_city" VALUES(23340,'Natchitoches','Natchitoches, Louisiana',28376,22);
INSERT INTO "django_geo_db_city" VALUES(23341,'Negreet','Negreet, Louisiana',28379,22);
INSERT INTO "django_geo_db_city" VALUES(23342,'Newllano','Newllano, Louisiana',28380,22);
INSERT INTO "django_geo_db_city" VALUES(23343,'Noble','Noble, Louisiana',28381,22);
INSERT INTO "django_geo_db_city" VALUES(23344,'Oakdale','Oakdale, Louisiana',28382,22);
INSERT INTO "django_geo_db_city" VALUES(23345,'Olla','Olla, Louisiana',28383,22);
INSERT INTO "django_geo_db_city" VALUES(23346,'Otis','Otis, Louisiana',28384,22);
INSERT INTO "django_geo_db_city" VALUES(23347,'Pollock','Pollock, Louisiana',28385,22);
INSERT INTO "django_geo_db_city" VALUES(23348,'Provencal','Provencal, Louisiana',28386,22);
INSERT INTO "django_geo_db_city" VALUES(23349,'Robeline','Robeline, Louisiana',28387,22);
INSERT INTO "django_geo_db_city" VALUES(23350,'Saint Maurice','Saint Maurice, Louisiana',28388,22);
INSERT INTO "django_geo_db_city" VALUES(23351,'Sieper','Sieper, Louisiana',28389,22);
INSERT INTO "django_geo_db_city" VALUES(23352,'Sikes','Sikes, Louisiana',28390,22);
INSERT INTO "django_geo_db_city" VALUES(23353,'Simpson','Simpson, Louisiana',28391,22);
INSERT INTO "django_geo_db_city" VALUES(23354,'Slagle','Slagle, Louisiana',28029,22);
INSERT INTO "django_geo_db_city" VALUES(23355,'Tioga','Tioga, Louisiana',28392,22);
INSERT INTO "django_geo_db_city" VALUES(23356,'Tullos','Tullos, Louisiana',28393,22);
INSERT INTO "django_geo_db_city" VALUES(23357,'Urania','Urania, Louisiana',28394,22);
INSERT INTO "django_geo_db_city" VALUES(23358,'Verda','Verda, Louisiana',28395,22);
INSERT INTO "django_geo_db_city" VALUES(23359,'Winnfield','Winnfield, Louisiana',28396,22);
INSERT INTO "django_geo_db_city" VALUES(23360,'Woodworth','Woodworth, Louisiana',28397,22);
INSERT INTO "django_geo_db_city" VALUES(23361,'Zwolle','Zwolle, Louisiana',28398,22);
INSERT INTO "django_geo_db_city" VALUES(23362,'Pine Bluff','Pine Bluff, Arkansas',28401,4);
INSERT INTO "django_geo_db_city" VALUES(23363,'White Hall','White Hall, Arkansas',28402,4);
INSERT INTO "django_geo_db_city" VALUES(23364,'Arkansas City','Arkansas City, Arkansas',28407,4);
INSERT INTO "django_geo_db_city" VALUES(23365,'Banks','Banks, Arkansas',28408,4);
INSERT INTO "django_geo_db_city" VALUES(23366,'Crossett','Crossett, Arkansas',28409,4);
INSERT INTO "django_geo_db_city" VALUES(23367,'Dermott','Dermott, Arkansas',28410,4);
INSERT INTO "django_geo_db_city" VALUES(23368,'Dumas','Dumas, Arkansas',28411,4);
INSERT INTO "django_geo_db_city" VALUES(23369,'Eudora','Eudora, Arkansas',28412,4);
INSERT INTO "django_geo_db_city" VALUES(23370,'Fountain Hill','Fountain Hill, Arkansas',28413,4);
INSERT INTO "django_geo_db_city" VALUES(23371,'Gould','Gould, Arkansas',28414,4);
INSERT INTO "django_geo_db_city" VALUES(23372,'Grady','Grady, Arkansas',28415,4);
INSERT INTO "django_geo_db_city" VALUES(23373,'Hamburg','Hamburg, Arkansas',28416,4);
INSERT INTO "django_geo_db_city" VALUES(23374,'Hermitage','Hermitage, Arkansas',28417,4);
INSERT INTO "django_geo_db_city" VALUES(23375,'Jennie','Jennie, Arkansas',28418,4);
INSERT INTO "django_geo_db_city" VALUES(23376,'Jerome','Jerome, Arkansas',28419,4);
INSERT INTO "django_geo_db_city" VALUES(23377,'Jersey','Jersey, Arkansas',28420,4);
INSERT INTO "django_geo_db_city" VALUES(23378,'Kingsland','Kingsland, Arkansas',28421,4);
INSERT INTO "django_geo_db_city" VALUES(23379,'Lake Village','Lake Village, Arkansas',28422,4);
INSERT INTO "django_geo_db_city" VALUES(23380,'McGehee','McGehee, Arkansas',28423,4);
INSERT INTO "django_geo_db_city" VALUES(23381,'Monticello','Monticello, Arkansas',28424,4);
INSERT INTO "django_geo_db_city" VALUES(23382,'Montrose','Montrose, Arkansas',28426,4);
INSERT INTO "django_geo_db_city" VALUES(23383,'Moscow','Moscow, Arkansas',28427,4);
INSERT INTO "django_geo_db_city" VALUES(23384,'New Edinburg','New Edinburg, Arkansas',28428,4);
INSERT INTO "django_geo_db_city" VALUES(23385,'Parkdale','Parkdale, Arkansas',28429,4);
INSERT INTO "django_geo_db_city" VALUES(23386,'Pickens','Pickens, Arkansas',28430,4);
INSERT INTO "django_geo_db_city" VALUES(23387,'Portland','Portland, Arkansas',28431,4);
INSERT INTO "django_geo_db_city" VALUES(23388,'Rison','Rison, Arkansas',28432,4);
INSERT INTO "django_geo_db_city" VALUES(23389,'Star City','Star City, Arkansas',28434,4);
INSERT INTO "django_geo_db_city" VALUES(23390,'Tillar','Tillar, Arkansas',28435,4);
INSERT INTO "django_geo_db_city" VALUES(23391,'Warren','Warren, Arkansas',28436,4);
INSERT INTO "django_geo_db_city" VALUES(23392,'Watson','Watson, Arkansas',28437,4);
INSERT INTO "django_geo_db_city" VALUES(23393,'Wilmar','Wilmar, Arkansas',28438,4);
INSERT INTO "django_geo_db_city" VALUES(23394,'Wilmot','Wilmot, Arkansas',28439,4);
INSERT INTO "django_geo_db_city" VALUES(23395,'Winchester','Winchester, Arkansas',28440,4);
INSERT INTO "django_geo_db_city" VALUES(23396,'Yorktown','Yorktown, Arkansas',28441,4);
INSERT INTO "django_geo_db_city" VALUES(23397,'Camden','Camden, Arkansas',28443,4);
INSERT INTO "django_geo_db_city" VALUES(23398,'Bearden','Bearden, Arkansas',28445,4);
INSERT INTO "django_geo_db_city" VALUES(23399,'Beirne','Beirne, Arkansas',28446,4);
INSERT INTO "django_geo_db_city" VALUES(23400,'Bluff City','Bluff City, Arkansas',28447,4);
INSERT INTO "django_geo_db_city" VALUES(23401,'Calion','Calion, Arkansas',28448,4);
INSERT INTO "django_geo_db_city" VALUES(23402,'Carthage','Carthage, Arkansas',28449,4);
INSERT INTO "django_geo_db_city" VALUES(23403,'Chidester','Chidester, Arkansas',28450,4);
INSERT INTO "django_geo_db_city" VALUES(23404,'Curtis','Curtis, Arkansas',28451,4);
INSERT INTO "django_geo_db_city" VALUES(23405,'El Dorado','El Dorado, Arkansas',28452,4);
INSERT INTO "django_geo_db_city" VALUES(23406,'Emerson','Emerson, Arkansas',28454,4);
INSERT INTO "django_geo_db_city" VALUES(23407,'Fordyce','Fordyce, Arkansas',28455,4);
INSERT INTO "django_geo_db_city" VALUES(23408,'Gurdon','Gurdon, Arkansas',28456,4);
INSERT INTO "django_geo_db_city" VALUES(23409,'Hampton','Hampton, Arkansas',28457,4);
INSERT INTO "django_geo_db_city" VALUES(23410,'Harrell','Harrell, Arkansas',28458,4);
INSERT INTO "django_geo_db_city" VALUES(23411,'Huttig','Huttig, Arkansas',28459,4);
INSERT INTO "django_geo_db_city" VALUES(23412,'Ivan','Ivan, Arkansas',28460,4);
INSERT INTO "django_geo_db_city" VALUES(23413,'Junction City','Junction City, Arkansas',28461,4);
INSERT INTO "django_geo_db_city" VALUES(23414,'Lawson','Lawson, Arkansas',28453,4);
INSERT INTO "django_geo_db_city" VALUES(23415,'Louann','Louann, Arkansas',28462,4);
INSERT INTO "django_geo_db_city" VALUES(23416,'McNeil','McNeil, Arkansas',28463,4);
INSERT INTO "django_geo_db_city" VALUES(23417,'Magnolia','Magnolia, Arkansas',28464,4);
INSERT INTO "django_geo_db_city" VALUES(23418,'Mount Holly','Mount Holly, Arkansas',28466,4);
INSERT INTO "django_geo_db_city" VALUES(23419,'Norphlet','Norphlet, Arkansas',28467,4);
INSERT INTO "django_geo_db_city" VALUES(23420,'Smackover','Smackover, Arkansas',28468,4);
INSERT INTO "django_geo_db_city" VALUES(23421,'Sparkman','Sparkman, Arkansas',28469,4);
INSERT INTO "django_geo_db_city" VALUES(23422,'Stephens','Stephens, Arkansas',28470,4);
INSERT INTO "django_geo_db_city" VALUES(23423,'Strong','Strong, Arkansas',28471,4);
INSERT INTO "django_geo_db_city" VALUES(23424,'Thornton','Thornton, Arkansas',28472,4);
INSERT INTO "django_geo_db_city" VALUES(23425,'Urbana','Urbana, Arkansas',28453,4);
INSERT INTO "django_geo_db_city" VALUES(23426,'Village','Village, Arkansas',28474,4);
INSERT INTO "django_geo_db_city" VALUES(23427,'Waldo','Waldo, Arkansas',28475,4);
INSERT INTO "django_geo_db_city" VALUES(23428,'Whelen Springs','Whelen Springs, Arkansas',28476,4);
INSERT INTO "django_geo_db_city" VALUES(23429,'Hope','Hope, Arkansas',28477,4);
INSERT INTO "django_geo_db_city" VALUES(23430,'Alleene','Alleene, Arkansas',28479,4);
INSERT INTO "django_geo_db_city" VALUES(23431,'Ashdown','Ashdown, Arkansas',28480,4);
INSERT INTO "django_geo_db_city" VALUES(23432,'Ben Lomond','Ben Lomond, Arkansas',28481,4);
INSERT INTO "django_geo_db_city" VALUES(23433,'Blevins','Blevins, Arkansas',28482,4);
INSERT INTO "django_geo_db_city" VALUES(23434,'Bradley','Bradley, Arkansas',28483,4);
INSERT INTO "django_geo_db_city" VALUES(23435,'Buckner','Buckner, Arkansas',28484,4);
INSERT INTO "django_geo_db_city" VALUES(23436,'Cale','Cale, Arkansas',28485,4);
INSERT INTO "django_geo_db_city" VALUES(23437,'Columbus','Columbus, Arkansas',28486,4);
INSERT INTO "django_geo_db_city" VALUES(23438,'De Queen','De Queen, Arkansas',28487,4);
INSERT INTO "django_geo_db_city" VALUES(23439,'Dierks','Dierks, Arkansas',28488,4);
INSERT INTO "django_geo_db_city" VALUES(23440,'Doddridge','Doddridge, Arkansas',28489,4);
INSERT INTO "django_geo_db_city" VALUES(23441,'Emmet','Emmet, Arkansas',28490,4);
INSERT INTO "django_geo_db_city" VALUES(23442,'Foreman','Foreman, Arkansas',28491,4);
INSERT INTO "django_geo_db_city" VALUES(23443,'Fouke','Fouke, Arkansas',28492,4);
INSERT INTO "django_geo_db_city" VALUES(23444,'Fulton','Fulton, Arkansas',28493,4);
INSERT INTO "django_geo_db_city" VALUES(23445,'Garland City','Garland City, Arkansas',28494,4);
INSERT INTO "django_geo_db_city" VALUES(23446,'Genoa','Genoa, Arkansas',28495,4);
INSERT INTO "django_geo_db_city" VALUES(23447,'Gillham','Gillham, Arkansas',28496,4);
INSERT INTO "django_geo_db_city" VALUES(23448,'Horatio','Horatio, Arkansas',28497,4);
INSERT INTO "django_geo_db_city" VALUES(23449,'Laneburg','Laneburg, Arkansas',28485,4);
INSERT INTO "django_geo_db_city" VALUES(23450,'Lewisville','Lewisville, Arkansas',28498,4);
INSERT INTO "django_geo_db_city" VALUES(23451,'Lockesburg','Lockesburg, Arkansas',28499,4);
INSERT INTO "django_geo_db_city" VALUES(23452,'McCaskill','McCaskill, Arkansas',28500,4);
INSERT INTO "django_geo_db_city" VALUES(23453,'Mineral Springs','Mineral Springs, Arkansas',28501,4);
INSERT INTO "django_geo_db_city" VALUES(23454,'Nashville','Nashville, Arkansas',28502,4);
INSERT INTO "django_geo_db_city" VALUES(23455,'Ogden','Ogden, Arkansas',28503,4);
INSERT INTO "django_geo_db_city" VALUES(23456,'Texarkana','Texarkana, Arkansas',28504,4);
INSERT INTO "django_geo_db_city" VALUES(23457,'Ozan','Ozan, Arkansas',28505,4);
INSERT INTO "django_geo_db_city" VALUES(23458,'Prescott','Prescott, Arkansas',28506,4);
INSERT INTO "django_geo_db_city" VALUES(23459,'Rosston','Rosston, Arkansas',28507,4);
INSERT INTO "django_geo_db_city" VALUES(23460,'Saratoga','Saratoga, Arkansas',28508,4);
INSERT INTO "django_geo_db_city" VALUES(23461,'Stamps','Stamps, Arkansas',28509,4);
INSERT INTO "django_geo_db_city" VALUES(23462,'Taylor','Taylor, Arkansas',28510,4);
INSERT INTO "django_geo_db_city" VALUES(23463,'Washington','Washington, Arkansas',28511,4);
INSERT INTO "django_geo_db_city" VALUES(23464,'Willisville','Willisville, Arkansas',28485,4);
INSERT INTO "django_geo_db_city" VALUES(23465,'Wilton','Wilton, Arkansas',28512,4);
INSERT INTO "django_geo_db_city" VALUES(23466,'Winthrop','Winthrop, Arkansas',28513,4);
INSERT INTO "django_geo_db_city" VALUES(23467,'Hot Springs National Park','Hot Springs National Park, Arkansas',28514,4);
INSERT INTO "django_geo_db_city" VALUES(23468,'Hot Springs','Hot Springs, Arkansas',28516,4);
INSERT INTO "django_geo_db_city" VALUES(23469,'Hot Springs Village','Hot Springs Village, Arkansas',28517,4);
INSERT INTO "django_geo_db_city" VALUES(23470,'Alpine','Alpine, Arkansas',28446,4);
INSERT INTO "django_geo_db_city" VALUES(23471,'Amity','Amity, Arkansas',28520,4);
INSERT INTO "django_geo_db_city" VALUES(23472,'Antoine','Antoine, Arkansas',28521,4);
INSERT INTO "django_geo_db_city" VALUES(23473,'Arkadelphia','Arkadelphia, Arkansas',28522,4);
INSERT INTO "django_geo_db_city" VALUES(23474,'Bismarck','Bismarck, Arkansas',28523,4);
INSERT INTO "django_geo_db_city" VALUES(23475,'Board Camp','Board Camp, Arkansas',28524,4);
INSERT INTO "django_geo_db_city" VALUES(23476,'Bonnerdale','Bonnerdale, Arkansas',28525,4);
INSERT INTO "django_geo_db_city" VALUES(23477,'Caddo Gap','Caddo Gap, Arkansas',28526,4);
INSERT INTO "django_geo_db_city" VALUES(23478,'Cove','Cove, Arkansas',28527,4);
INSERT INTO "django_geo_db_city" VALUES(23479,'Delight','Delight, Arkansas',28528,4);
INSERT INTO "django_geo_db_city" VALUES(23480,'Donaldson','Donaldson, Arkansas',28529,4);
INSERT INTO "django_geo_db_city" VALUES(23481,'Friendship','Friendship, Arkansas',28530,4);
INSERT INTO "django_geo_db_city" VALUES(23482,'Glenwood','Glenwood, Arkansas',28531,4);
INSERT INTO "django_geo_db_city" VALUES(23483,'Grannis','Grannis, Arkansas',28532,4);
INSERT INTO "django_geo_db_city" VALUES(23484,'Hatfield','Hatfield, Arkansas',28533,4);
INSERT INTO "django_geo_db_city" VALUES(23485,'Hatton','Hatton, Arkansas',28534,4);
INSERT INTO "django_geo_db_city" VALUES(23486,'Jessieville','Jessieville, Arkansas',28535,4);
INSERT INTO "django_geo_db_city" VALUES(23487,'Kirby','Kirby, Arkansas',28536,4);
INSERT INTO "django_geo_db_city" VALUES(23488,'Langley','Langley, Arkansas',28537,4);
INSERT INTO "django_geo_db_city" VALUES(23489,'Mena','Mena, Arkansas',28538,4);
INSERT INTO "django_geo_db_city" VALUES(23490,'Mountain Pine','Mountain Pine, Arkansas',28539,4);
INSERT INTO "django_geo_db_city" VALUES(23491,'Mount Ida','Mount Ida, Arkansas',28540,4);
INSERT INTO "django_geo_db_city" VALUES(23492,'Murfreesboro','Murfreesboro, Arkansas',28541,4);
INSERT INTO "django_geo_db_city" VALUES(23493,'Newhope','Newhope, Arkansas',28542,4);
INSERT INTO "django_geo_db_city" VALUES(23494,'Norman','Norman, Arkansas',28543,4);
INSERT INTO "django_geo_db_city" VALUES(23495,'Oden','Oden, Arkansas',28544,4);
INSERT INTO "django_geo_db_city" VALUES(23496,'Okolona','Okolona, Arkansas',28545,4);
INSERT INTO "django_geo_db_city" VALUES(23497,'Pearcy','Pearcy, Arkansas',28546,4);
INSERT INTO "django_geo_db_city" VALUES(23498,'Pencil Bluff','Pencil Bluff, Arkansas',28547,4);
INSERT INTO "django_geo_db_city" VALUES(23499,'Royal','Royal, Arkansas',28549,4);
INSERT INTO "django_geo_db_city" VALUES(23500,'Sims','Sims, Arkansas',28550,4);
INSERT INTO "django_geo_db_city" VALUES(23501,'Story','Story, Arkansas',28551,4);
INSERT INTO "django_geo_db_city" VALUES(23502,'Umpire','Umpire, Arkansas',28552,4);
INSERT INTO "django_geo_db_city" VALUES(23503,'Vandervoort','Vandervoort, Arkansas',28553,4);
INSERT INTO "django_geo_db_city" VALUES(23504,'Wickes','Wickes, Arkansas',28554,4);
INSERT INTO "django_geo_db_city" VALUES(23505,'Adona','Adona, Arkansas',28555,4);
INSERT INTO "django_geo_db_city" VALUES(23506,'Alexander','Alexander, Arkansas',28556,4);
INSERT INTO "django_geo_db_city" VALUES(23507,'Almyra','Almyra, Arkansas',28557,4);
INSERT INTO "django_geo_db_city" VALUES(23508,'Altheimer','Altheimer, Arkansas',28558,4);
INSERT INTO "django_geo_db_city" VALUES(23509,'Amagon','Amagon, Arkansas',28559,4);
INSERT INTO "django_geo_db_city" VALUES(23510,'Augusta','Augusta, Arkansas',28560,4);
INSERT INTO "django_geo_db_city" VALUES(23511,'Austin','Austin, Arkansas',28561,4);
INSERT INTO "django_geo_db_city" VALUES(23512,'Bald Knob','Bald Knob, Arkansas',28562,4);
INSERT INTO "django_geo_db_city" VALUES(23513,'Bauxite','Bauxite, Arkansas',28563,4);
INSERT INTO "django_geo_db_city" VALUES(23514,'Beebe','Beebe, Arkansas',28564,4);
INSERT INTO "django_geo_db_city" VALUES(23515,'Bee Branch','Bee Branch, Arkansas',28565,4);
INSERT INTO "django_geo_db_city" VALUES(23516,'Beedeville','Beedeville, Arkansas',28566,4);
INSERT INTO "django_geo_db_city" VALUES(23517,'Benton','Benton, Arkansas',28567,4);
INSERT INTO "django_geo_db_city" VALUES(23518,'Bigelow','Bigelow, Arkansas',28568,4);
INSERT INTO "django_geo_db_city" VALUES(23519,'Biscoe','Biscoe, Arkansas',28569,4);
INSERT INTO "django_geo_db_city" VALUES(23520,'North Little Rock','North Little Rock, Arkansas',28571,4);
INSERT INTO "django_geo_db_city" VALUES(23521,'Bradford','Bradford, Arkansas',28572,4);
INSERT INTO "django_geo_db_city" VALUES(23522,'Brinkley','Brinkley, Arkansas',28573,4);
INSERT INTO "django_geo_db_city" VALUES(23523,'Bryant','Bryant, Arkansas',28574,4);
INSERT INTO "django_geo_db_city" VALUES(23524,'Cabot','Cabot, Arkansas',28575,4);
INSERT INTO "django_geo_db_city" VALUES(23525,'Carlisle','Carlisle, Arkansas',28576,4);
INSERT INTO "django_geo_db_city" VALUES(23526,'Casa','Casa, Arkansas',28577,4);
INSERT INTO "django_geo_db_city" VALUES(23527,'Casscoe','Casscoe, Arkansas',28578,4);
INSERT INTO "django_geo_db_city" VALUES(23528,'Center Ridge','Center Ridge, Arkansas',28579,4);
INSERT INTO "django_geo_db_city" VALUES(23529,'Choctaw','Choctaw, Arkansas',28580,4);
INSERT INTO "django_geo_db_city" VALUES(23530,'Clarendon','Clarendon, Arkansas',28581,4);
INSERT INTO "django_geo_db_city" VALUES(23531,'Cleveland','Cleveland, Arkansas',28582,4);
INSERT INTO "django_geo_db_city" VALUES(23532,'Clinton','Clinton, Arkansas',28583,4);
INSERT INTO "django_geo_db_city" VALUES(23533,'Conway','Conway, Arkansas',28584,4);
INSERT INTO "django_geo_db_city" VALUES(23534,'Cotton Plant','Cotton Plant, Arkansas',28587,4);
INSERT INTO "django_geo_db_city" VALUES(23535,'Coy','Coy, Arkansas',28588,4);
INSERT INTO "django_geo_db_city" VALUES(23536,'Crocketts Bluff','Crocketts Bluff, Arkansas',28589,4);
INSERT INTO "django_geo_db_city" VALUES(23537,'Damascus','Damascus, Arkansas',28590,4);
INSERT INTO "django_geo_db_city" VALUES(23538,'Des Arc','Des Arc, Arkansas',28591,4);
INSERT INTO "django_geo_db_city" VALUES(23539,'De Valls Bluff','De Valls Bluff, Arkansas',28592,4);
INSERT INTO "django_geo_db_city" VALUES(23540,'De Witt','De Witt, Arkansas',28593,4);
INSERT INTO "django_geo_db_city" VALUES(23541,'Diaz','Diaz, Arkansas',28594,4);
INSERT INTO "django_geo_db_city" VALUES(23542,'Edgemont','Edgemont, Arkansas',28595,4);
INSERT INTO "django_geo_db_city" VALUES(23543,'El Paso','El Paso, Arkansas',28596,4);
INSERT INTO "django_geo_db_city" VALUES(23544,'England','England, Arkansas',28597,4);
INSERT INTO "django_geo_db_city" VALUES(23545,'Enola','Enola, Arkansas',28598,4);
INSERT INTO "django_geo_db_city" VALUES(23546,'Ethel','Ethel, Arkansas',28599,4);
INSERT INTO "django_geo_db_city" VALUES(23547,'Fox','Fox, Arkansas',28600,4);
INSERT INTO "django_geo_db_city" VALUES(23548,'Garner','Garner, Arkansas',28601,4);
INSERT INTO "django_geo_db_city" VALUES(23549,'College Station','College Station, Arkansas',28602,4);
INSERT INTO "django_geo_db_city" VALUES(23550,'Gillett','Gillett, Arkansas',28603,4);
INSERT INTO "django_geo_db_city" VALUES(23551,'Grapevine','Grapevine, Arkansas',28604,4);
INSERT INTO "django_geo_db_city" VALUES(23552,'Greenbrier','Greenbrier, Arkansas',28605,4);
INSERT INTO "django_geo_db_city" VALUES(23553,'Gregory','Gregory, Arkansas',28606,4);
INSERT INTO "django_geo_db_city" VALUES(23554,'Griffithville','Griffithville, Arkansas',28607,4);
INSERT INTO "django_geo_db_city" VALUES(23555,'Guy','Guy, Arkansas',28608,4);
INSERT INTO "django_geo_db_city" VALUES(23556,'Hattieville','Hattieville, Arkansas',28609,4);
INSERT INTO "django_geo_db_city" VALUES(23557,'Hazen','Hazen, Arkansas',28610,4);
INSERT INTO "django_geo_db_city" VALUES(23558,'Hensley','Hensley, Arkansas',28611,4);
INSERT INTO "django_geo_db_city" VALUES(23559,'Hickory Plains','Hickory Plains, Arkansas',28612,4);
INSERT INTO "django_geo_db_city" VALUES(23560,'Higden','Higden, Arkansas',28613,4);
INSERT INTO "django_geo_db_city" VALUES(23561,'Higginson','Higginson, Arkansas',28614,4);
INSERT INTO "django_geo_db_city" VALUES(23562,'Holly Grove','Holly Grove, Arkansas',28615,4);
INSERT INTO "django_geo_db_city" VALUES(23563,'Houston','Houston, Arkansas',28616,4);
INSERT INTO "django_geo_db_city" VALUES(23564,'Howell','Howell, Arkansas',28606,4);
INSERT INTO "django_geo_db_city" VALUES(23565,'Humnoke','Humnoke, Arkansas',28617,4);
INSERT INTO "django_geo_db_city" VALUES(23566,'Humphrey','Humphrey, Arkansas',28618,4);
INSERT INTO "django_geo_db_city" VALUES(23567,'Hunter','Hunter, Arkansas',28619,4);
INSERT INTO "django_geo_db_city" VALUES(23568,'Jacksonport','Jacksonport, Arkansas',28620,4);
INSERT INTO "django_geo_db_city" VALUES(23569,'Jacksonville','Jacksonville, Arkansas',28621,4);
INSERT INTO "django_geo_db_city" VALUES(23570,'Jefferson','Jefferson, Arkansas',28623,4);
INSERT INTO "django_geo_db_city" VALUES(23571,'Jerusalem','Jerusalem, Arkansas',28624,4);
INSERT INTO "django_geo_db_city" VALUES(23572,'Judsonia','Judsonia, Arkansas',28625,4);
INSERT INTO "django_geo_db_city" VALUES(23573,'Kensett','Kensett, Arkansas',28626,4);
INSERT INTO "django_geo_db_city" VALUES(23574,'Keo','Keo, Arkansas',28627,4);
INSERT INTO "django_geo_db_city" VALUES(23575,'Leola','Leola, Arkansas',28628,4);
INSERT INTO "django_geo_db_city" VALUES(23576,'Letona','Letona, Arkansas',28629,4);
INSERT INTO "django_geo_db_city" VALUES(23577,'Lonoke','Lonoke, Arkansas',28630,4);
INSERT INTO "django_geo_db_city" VALUES(23578,'Lonsdale','Lonsdale, Arkansas',28631,4);
INSERT INTO "django_geo_db_city" VALUES(23579,'Fairfield Bay','Fairfield Bay, Arkansas',28632,4);
INSERT INTO "django_geo_db_city" VALUES(23580,'Little Rock Air Force Base','Little Rock Air Force Base, Arkansas',28635,4);
INSERT INTO "django_geo_db_city" VALUES(23581,'McCrory','McCrory, Arkansas',28636,4);
INSERT INTO "django_geo_db_city" VALUES(23582,'McRae','McRae, Arkansas',28637,4);
INSERT INTO "django_geo_db_city" VALUES(23583,'Mabelvale','Mabelvale, Arkansas',28638,4);
INSERT INTO "django_geo_db_city" VALUES(23584,'Malvern','Malvern, Arkansas',28639,4);
INSERT INTO "django_geo_db_city" VALUES(23585,'Jones Mill','Jones Mill, Arkansas',28640,4);
INSERT INTO "django_geo_db_city" VALUES(23586,'Mayflower','Mayflower, Arkansas',28641,4);
INSERT INTO "django_geo_db_city" VALUES(23587,'Menifee','Menifee, Arkansas',28642,4);
INSERT INTO "django_geo_db_city" VALUES(23588,'Monroe','Monroe, Arkansas',28643,4);
INSERT INTO "django_geo_db_city" VALUES(23589,'Morrilton','Morrilton, Arkansas',28644,4);
INSERT INTO "django_geo_db_city" VALUES(23590,'Mount Vernon','Mount Vernon, Arkansas',28645,4);
INSERT INTO "django_geo_db_city" VALUES(23591,'Newport','Newport, Arkansas',28646,4);
INSERT INTO "django_geo_db_city" VALUES(23592,'Maumelle','Maumelle, Arkansas',28647,4);
INSERT INTO "django_geo_db_city" VALUES(23593,'Sherwood','Sherwood, Arkansas',28653,4);
INSERT INTO "django_geo_db_city" VALUES(23594,'Pangburn','Pangburn, Arkansas',28654,4);
INSERT INTO "django_geo_db_city" VALUES(23595,'Paron','Paron, Arkansas',28655,4);
INSERT INTO "django_geo_db_city" VALUES(23596,'Patterson','Patterson, Arkansas',28656,4);
INSERT INTO "django_geo_db_city" VALUES(23597,'Perry','Perry, Arkansas',28657,4);
INSERT INTO "django_geo_db_city" VALUES(23598,'Perryville','Perryville, Arkansas',28658,4);
INSERT INTO "django_geo_db_city" VALUES(23599,'Plumerville','Plumerville, Arkansas',28659,4);
INSERT INTO "django_geo_db_city" VALUES(23600,'Poyen','Poyen, Arkansas',28660,4);
INSERT INTO "django_geo_db_city" VALUES(23601,'Prattsville','Prattsville, Arkansas',28661,4);
INSERT INTO "django_geo_db_city" VALUES(23602,'Prim','Prim, Arkansas',28662,4);
INSERT INTO "django_geo_db_city" VALUES(23603,'Quitman','Quitman, Arkansas',28663,4);
INSERT INTO "django_geo_db_city" VALUES(23604,'Redfield','Redfield, Arkansas',28664,4);
INSERT INTO "django_geo_db_city" VALUES(23605,'Reydell','Reydell, Arkansas',28665,4);
INSERT INTO "django_geo_db_city" VALUES(23606,'Roe','Roe, Arkansas',28666,4);
INSERT INTO "django_geo_db_city" VALUES(23607,'Roland','Roland, Arkansas',28667,4);
INSERT INTO "django_geo_db_city" VALUES(23608,'Romance','Romance, Arkansas',28668,4);
INSERT INTO "django_geo_db_city" VALUES(23609,'Rose Bud','Rose Bud, Arkansas',28669,4);
INSERT INTO "django_geo_db_city" VALUES(23610,'Russell','Russell, Arkansas',28670,4);
INSERT INTO "django_geo_db_city" VALUES(23611,'Saint Charles','Saint Charles, Arkansas',28671,4);
INSERT INTO "django_geo_db_city" VALUES(23612,'Scotland','Scotland, Arkansas',28672,4);
INSERT INTO "django_geo_db_city" VALUES(23613,'Scott','Scott, Arkansas',28673,4);
INSERT INTO "django_geo_db_city" VALUES(23614,'Searcy','Searcy, Arkansas',28674,4);
INSERT INTO "django_geo_db_city" VALUES(23615,'Sheridan','Sheridan, Arkansas',28677,4);
INSERT INTO "django_geo_db_city" VALUES(23616,'Sherrill','Sherrill, Arkansas',28678,4);
INSERT INTO "django_geo_db_city" VALUES(23617,'Shirley','Shirley, Arkansas',28679,4);
INSERT INTO "django_geo_db_city" VALUES(23618,'Solgohachia','Solgohachia, Arkansas',28680,4);
INSERT INTO "django_geo_db_city" VALUES(23619,'Springfield','Springfield, Arkansas',28681,4);
INSERT INTO "django_geo_db_city" VALUES(23620,'Stuttgart','Stuttgart, Arkansas',28682,4);
INSERT INTO "django_geo_db_city" VALUES(23621,'Sweet Home','Sweet Home, Arkansas',28683,4);
INSERT INTO "django_geo_db_city" VALUES(23622,'Thida','Thida, Arkansas',28684,4);
INSERT INTO "django_geo_db_city" VALUES(23623,'Tichnor','Tichnor, Arkansas',28685,4);
INSERT INTO "django_geo_db_city" VALUES(23624,'Traskwood','Traskwood, Arkansas',28686,4);
INSERT INTO "django_geo_db_city" VALUES(23625,'Tucker','Tucker, Arkansas',28687,4);
INSERT INTO "django_geo_db_city" VALUES(23626,'Tupelo','Tupelo, Arkansas',28688,4);
INSERT INTO "django_geo_db_city" VALUES(23627,'Ulm','Ulm, Arkansas',28689,4);
INSERT INTO "django_geo_db_city" VALUES(23628,'Vilonia','Vilonia, Arkansas',28690,4);
INSERT INTO "django_geo_db_city" VALUES(23629,'Wabbaseka','Wabbaseka, Arkansas',28691,4);
INSERT INTO "django_geo_db_city" VALUES(23630,'Ward','Ward, Arkansas',28692,4);
INSERT INTO "django_geo_db_city" VALUES(23631,'West Point','West Point, Arkansas',28693,4);
INSERT INTO "django_geo_db_city" VALUES(23632,'Wilburn','Wilburn, Arkansas',28694,4);
INSERT INTO "django_geo_db_city" VALUES(23633,'Woodson','Woodson, Arkansas',28695,4);
INSERT INTO "django_geo_db_city" VALUES(23634,'Wooster','Wooster, Arkansas',28696,4);
INSERT INTO "django_geo_db_city" VALUES(23635,'Wright','Wright, Arkansas',28697,4);
INSERT INTO "django_geo_db_city" VALUES(23636,'Wrightsville','Wrightsville, Arkansas',28698,4);
INSERT INTO "django_geo_db_city" VALUES(23637,'Little Rock','Little Rock, Arkansas',28700,4);
INSERT INTO "django_geo_db_city" VALUES(23638,'West Memphis','West Memphis, Arkansas',28718,4);
INSERT INTO "django_geo_db_city" VALUES(23639,'Armorel','Armorel, Arkansas',28720,4);
INSERT INTO "django_geo_db_city" VALUES(23640,'Aubrey','Aubrey, Arkansas',28721,4);
INSERT INTO "django_geo_db_city" VALUES(23641,'Barton','Barton, Arkansas',28722,4);
INSERT INTO "django_geo_db_city" VALUES(23642,'Bassett','Bassett, Arkansas',28723,4);
INSERT INTO "django_geo_db_city" VALUES(23643,'Birdeye','Birdeye, Arkansas',28724,4);
INSERT INTO "django_geo_db_city" VALUES(23644,'Blytheville','Blytheville, Arkansas',28725,4);
INSERT INTO "django_geo_db_city" VALUES(23645,'Gosnell','Gosnell, Arkansas',28726,4);
INSERT INTO "django_geo_db_city" VALUES(23646,'Brickeys','Brickeys, Arkansas',28727,4);
INSERT INTO "django_geo_db_city" VALUES(23647,'Burdette','Burdette, Arkansas',28728,4);
INSERT INTO "django_geo_db_city" VALUES(23648,'Caldwell','Caldwell, Arkansas',28729,4);
INSERT INTO "django_geo_db_city" VALUES(23649,'Cherry Valley','Cherry Valley, Arkansas',28730,4);
INSERT INTO "django_geo_db_city" VALUES(23650,'Clarkedale','Clarkedale, Arkansas',28731,4);
INSERT INTO "django_geo_db_city" VALUES(23651,'Colt','Colt, Arkansas',28732,4);
INSERT INTO "django_geo_db_city" VALUES(23652,'Crawfordsville','Crawfordsville, Arkansas',28733,4);
INSERT INTO "django_geo_db_city" VALUES(23653,'Crumrod','Crumrod, Arkansas',28734,4);
INSERT INTO "django_geo_db_city" VALUES(23654,'Driver','Driver, Arkansas',28735,4);
INSERT INTO "django_geo_db_city" VALUES(23655,'Dyess','Dyess, Arkansas',28736,4);
INSERT INTO "django_geo_db_city" VALUES(23656,'Earle','Earle, Arkansas',28737,4);
INSERT INTO "django_geo_db_city" VALUES(23657,'Edmondson','Edmondson, Arkansas',28738,4);
INSERT INTO "django_geo_db_city" VALUES(23658,'Elaine','Elaine, Arkansas',28739,4);
INSERT INTO "django_geo_db_city" VALUES(23659,'Forrest City','Forrest City, Arkansas',28740,4);
INSERT INTO "django_geo_db_city" VALUES(23660,'Frenchmans Bayou','Frenchmans Bayou, Arkansas',28742,4);
INSERT INTO "django_geo_db_city" VALUES(23661,'Gilmore','Gilmore, Arkansas',28743,4);
INSERT INTO "django_geo_db_city" VALUES(23662,'Goodwin','Goodwin, Arkansas',28744,4);
INSERT INTO "django_geo_db_city" VALUES(23663,'Haynes','Haynes, Arkansas',28745,4);
INSERT INTO "django_geo_db_city" VALUES(23664,'Helena','Helena, Arkansas',28746,4);
INSERT INTO "django_geo_db_city" VALUES(23665,'Marked Tree','Marked Tree, Arkansas',28747,4);
INSERT INTO "django_geo_db_city" VALUES(23666,'Heth','Heth, Arkansas',28748,4);
INSERT INTO "django_geo_db_city" VALUES(23667,'Hickory Ridge','Hickory Ridge, Arkansas',28749,4);
INSERT INTO "django_geo_db_city" VALUES(23668,'Hughes','Hughes, Arkansas',28750,4);
INSERT INTO "django_geo_db_city" VALUES(23669,'Joiner','Joiner, Arkansas',28751,4);
INSERT INTO "django_geo_db_city" VALUES(23670,'Keiser','Keiser, Arkansas',28752,4);
INSERT INTO "django_geo_db_city" VALUES(23671,'La Grange','La Grange, Arkansas',28753,4);
INSERT INTO "django_geo_db_city" VALUES(23672,'Lambrook','Lambrook, Arkansas',28754,4);
INSERT INTO "django_geo_db_city" VALUES(23673,'Lepanto','Lepanto, Arkansas',28755,4);
INSERT INTO "django_geo_db_city" VALUES(23674,'Lexa','Lexa, Arkansas',28756,4);
INSERT INTO "django_geo_db_city" VALUES(23675,'Luxora','Luxora, Arkansas',28757,4);
INSERT INTO "django_geo_db_city" VALUES(23676,'Madison','Madison, Arkansas',28758,4);
INSERT INTO "django_geo_db_city" VALUES(23677,'Marianna','Marianna, Arkansas',28759,4);
INSERT INTO "django_geo_db_city" VALUES(23678,'Marion','Marion, Arkansas',28760,4);
INSERT INTO "django_geo_db_city" VALUES(23679,'Marvell','Marvell, Arkansas',28762,4);
INSERT INTO "django_geo_db_city" VALUES(23680,'Mellwood','Mellwood, Arkansas',28763,4);
INSERT INTO "django_geo_db_city" VALUES(23681,'Moro','Moro, Arkansas',28764,4);
INSERT INTO "django_geo_db_city" VALUES(23682,'Oneida','Oneida, Arkansas',28765,4);
INSERT INTO "django_geo_db_city" VALUES(23683,'Osceola','Osceola, Arkansas',28766,4);
INSERT INTO "django_geo_db_city" VALUES(23684,'Palestine','Palestine, Arkansas',28767,4);
INSERT INTO "django_geo_db_city" VALUES(23685,'Parkin','Parkin, Arkansas',28768,4);
INSERT INTO "django_geo_db_city" VALUES(23686,'Poplar Grove','Poplar Grove, Arkansas',28769,4);
INSERT INTO "django_geo_db_city" VALUES(23687,'Proctor','Proctor, Arkansas',28770,4);
INSERT INTO "django_geo_db_city" VALUES(23688,'Rivervale','Rivervale, Arkansas',28771,4);
INSERT INTO "django_geo_db_city" VALUES(23689,'Snow Lake','Snow Lake, Arkansas',28772,4);
INSERT INTO "django_geo_db_city" VALUES(23690,'Tomato','Tomato, Arkansas',28726,4);
INSERT INTO "django_geo_db_city" VALUES(23691,'Turner','Turner, Arkansas',28773,4);
INSERT INTO "django_geo_db_city" VALUES(23692,'Turrell','Turrell, Arkansas',28774,4);
INSERT INTO "django_geo_db_city" VALUES(23693,'Twist','Twist, Arkansas',28775,4);
INSERT INTO "django_geo_db_city" VALUES(23694,'Tyronza','Tyronza, Arkansas',28776,4);
INSERT INTO "django_geo_db_city" VALUES(23695,'Vanndale','Vanndale, Arkansas',28777,4);
INSERT INTO "django_geo_db_city" VALUES(23696,'Wabash','Wabash, Arkansas',28778,4);
INSERT INTO "django_geo_db_city" VALUES(23697,'West Helena','West Helena, Arkansas',28779,4);
INSERT INTO "django_geo_db_city" VALUES(23698,'West Ridge','West Ridge, Arkansas',28726,4);
INSERT INTO "django_geo_db_city" VALUES(23699,'Wheatley','Wheatley, Arkansas',28780,4);
INSERT INTO "django_geo_db_city" VALUES(23700,'Widener','Widener, Arkansas',28781,4);
INSERT INTO "django_geo_db_city" VALUES(23701,'Wilson','Wilson, Arkansas',28782,4);
INSERT INTO "django_geo_db_city" VALUES(23702,'Wynne','Wynne, Arkansas',28783,4);
INSERT INTO "django_geo_db_city" VALUES(23703,'Jonesboro','Jonesboro, Arkansas',28784,4);
INSERT INTO "django_geo_db_city" VALUES(23704,'Alicia','Alicia, Arkansas',28788,4);
INSERT INTO "django_geo_db_city" VALUES(23705,'Bay','Bay, Arkansas',28789,4);
INSERT INTO "django_geo_db_city" VALUES(23706,'Beech Grove','Beech Grove, Arkansas',28790,4);
INSERT INTO "django_geo_db_city" VALUES(23707,'Biggers','Biggers, Arkansas',28791,4);
INSERT INTO "django_geo_db_city" VALUES(23708,'Black Oak','Black Oak, Arkansas',28792,4);
INSERT INTO "django_geo_db_city" VALUES(23709,'Black Rock','Black Rock, Arkansas',28793,4);
INSERT INTO "django_geo_db_city" VALUES(23710,'Bono','Bono, Arkansas',28794,4);
INSERT INTO "django_geo_db_city" VALUES(23711,'Brookland','Brookland, Arkansas',28795,4);
INSERT INTO "django_geo_db_city" VALUES(23712,'Caraway','Caraway, Arkansas',28796,4);
INSERT INTO "django_geo_db_city" VALUES(23713,'Cash','Cash, Arkansas',28797,4);
INSERT INTO "django_geo_db_city" VALUES(23714,'Corning','Corning, Arkansas',28798,4);
INSERT INTO "django_geo_db_city" VALUES(23715,'Tuckerman','Tuckerman, Arkansas',28799,4);
INSERT INTO "django_geo_db_city" VALUES(23716,'Datto','Datto, Arkansas',28800,4);
INSERT INTO "django_geo_db_city" VALUES(23717,'Delaplaine','Delaplaine, Arkansas',28801,4);
INSERT INTO "django_geo_db_city" VALUES(23718,'Dell','Dell, Arkansas',28802,4);
INSERT INTO "django_geo_db_city" VALUES(23719,'Egypt','Egypt, Arkansas',28803,4);
INSERT INTO "django_geo_db_city" VALUES(23720,'Etowah','Etowah, Arkansas',28804,4);
INSERT INTO "django_geo_db_city" VALUES(23721,'Fisher','Fisher, Arkansas',28805,4);
INSERT INTO "django_geo_db_city" VALUES(23722,'Greenway','Greenway, Arkansas',28806,4);
INSERT INTO "django_geo_db_city" VALUES(23723,'Grubbs','Grubbs, Arkansas',28807,4);
INSERT INTO "django_geo_db_city" VALUES(23724,'Harrisburg','Harrisburg, Arkansas',28808,4);
INSERT INTO "django_geo_db_city" VALUES(23725,'Hoxie','Hoxie, Arkansas',28809,4);
INSERT INTO "django_geo_db_city" VALUES(23726,'Imboden','Imboden, Arkansas',28810,4);
INSERT INTO "django_geo_db_city" VALUES(23727,'Knobel','Knobel, Arkansas',28811,4);
INSERT INTO "django_geo_db_city" VALUES(23728,'Lafe','Lafe, Arkansas',28812,4);
INSERT INTO "django_geo_db_city" VALUES(23729,'Lake City','Lake City, Arkansas',28813,4);
INSERT INTO "django_geo_db_city" VALUES(23730,'Leachville','Leachville, Arkansas',28814,4);
INSERT INTO "django_geo_db_city" VALUES(23731,'Light','Light, Arkansas',28815,4);
INSERT INTO "django_geo_db_city" VALUES(23732,'Lynn','Lynn, Arkansas',28816,4);
INSERT INTO "django_geo_db_city" VALUES(23733,'McDougal','McDougal, Arkansas',28817,4);
INSERT INTO "django_geo_db_city" VALUES(23734,'Manila','Manila, Arkansas',28818,4);
INSERT INTO "django_geo_db_city" VALUES(23735,'Marmaduke','Marmaduke, Arkansas',28819,4);
INSERT INTO "django_geo_db_city" VALUES(23736,'Maynard','Maynard, Arkansas',28820,4);
INSERT INTO "django_geo_db_city" VALUES(23737,'Minturn','Minturn, Arkansas',28821,4);
INSERT INTO "django_geo_db_city" VALUES(23738,'Monette','Monette, Arkansas',28822,4);
INSERT INTO "django_geo_db_city" VALUES(23739,'O Kean','O Kean, Arkansas',28824,4);
INSERT INTO "django_geo_db_city" VALUES(23740,'Paragould','Paragould, Arkansas',28825,4);
INSERT INTO "django_geo_db_city" VALUES(23741,'Peach Orchard','Peach Orchard, Arkansas',28828,4);
INSERT INTO "django_geo_db_city" VALUES(23742,'Piggott','Piggott, Arkansas',28829,4);
INSERT INTO "django_geo_db_city" VALUES(23743,'Pocahontas','Pocahontas, Arkansas',28830,4);
INSERT INTO "django_geo_db_city" VALUES(23744,'Pollard','Pollard, Arkansas',28831,4);
INSERT INTO "django_geo_db_city" VALUES(23745,'Portia','Portia, Arkansas',28832,4);
INSERT INTO "django_geo_db_city" VALUES(23746,'Powhatan','Powhatan, Arkansas',28833,4);
INSERT INTO "django_geo_db_city" VALUES(23747,'Ravenden','Ravenden, Arkansas',28834,4);
INSERT INTO "django_geo_db_city" VALUES(23748,'Ravenden Springs','Ravenden Springs, Arkansas',28835,4);
INSERT INTO "django_geo_db_city" VALUES(23749,'Rector','Rector, Arkansas',28836,4);
INSERT INTO "django_geo_db_city" VALUES(23750,'Reyno','Reyno, Arkansas',28837,4);
INSERT INTO "django_geo_db_city" VALUES(23751,'Saint Francis','Saint Francis, Arkansas',28838,4);
INSERT INTO "django_geo_db_city" VALUES(23752,'Sedgwick','Sedgwick, Arkansas',28839,4);
INSERT INTO "django_geo_db_city" VALUES(23753,'Smithville','Smithville, Arkansas',28840,4);
INSERT INTO "django_geo_db_city" VALUES(23754,'State University','State University, Arkansas',28841,4);
INSERT INTO "django_geo_db_city" VALUES(23755,'Strawberry','Strawberry, Arkansas',28842,4);
INSERT INTO "django_geo_db_city" VALUES(23756,'Success','Success, Arkansas',28843,4);
INSERT INTO "django_geo_db_city" VALUES(23757,'Swifton','Swifton, Arkansas',28844,4);
INSERT INTO "django_geo_db_city" VALUES(23758,'Trumann','Trumann, Arkansas',28845,4);
INSERT INTO "django_geo_db_city" VALUES(23759,'Walcott','Walcott, Arkansas',28847,4);
INSERT INTO "django_geo_db_city" VALUES(23760,'Waldenburg','Waldenburg, Arkansas',28848,4);
INSERT INTO "django_geo_db_city" VALUES(23761,'Walnut Ridge','Walnut Ridge, Arkansas',28849,4);
INSERT INTO "django_geo_db_city" VALUES(23762,'Warm Springs','Warm Springs, Arkansas',28851,4);
INSERT INTO "django_geo_db_city" VALUES(23763,'Weiner','Weiner, Arkansas',28852,4);
INSERT INTO "django_geo_db_city" VALUES(23764,'Williford','Williford, Arkansas',28853,4);
INSERT INTO "django_geo_db_city" VALUES(23765,'Batesville','Batesville, Arkansas',28854,4);
INSERT INTO "django_geo_db_city" VALUES(23766,'Horseshoe Bend','Horseshoe Bend, Arkansas',28856,4);
INSERT INTO "django_geo_db_city" VALUES(23767,'Ash Flat','Ash Flat, Arkansas',28857,4);
INSERT INTO "django_geo_db_city" VALUES(23768,'Bexar','Bexar, Arkansas',28858,4);
INSERT INTO "django_geo_db_city" VALUES(23769,'Boswell','Boswell, Arkansas',28859,4);
INSERT INTO "django_geo_db_city" VALUES(23770,'Brockwell','Brockwell, Arkansas',28860,4);
INSERT INTO "django_geo_db_city" VALUES(23771,'Calico Rock','Calico Rock, Arkansas',28861,4);
INSERT INTO "django_geo_db_city" VALUES(23772,'Camp','Camp, Arkansas',28862,4);
INSERT INTO "django_geo_db_city" VALUES(23773,'Cave City','Cave City, Arkansas',28863,4);
INSERT INTO "django_geo_db_city" VALUES(23774,'Charlotte','Charlotte, Arkansas',28864,4);
INSERT INTO "django_geo_db_city" VALUES(23775,'Concord','Concord, Arkansas',28865,4);
INSERT INTO "django_geo_db_city" VALUES(23776,'Cord','Cord, Arkansas',28866,4);
INSERT INTO "django_geo_db_city" VALUES(23777,'Cherokee Village','Cherokee Village, Arkansas',28867,4);
INSERT INTO "django_geo_db_city" VALUES(23778,'Cushman','Cushman, Arkansas',28868,4);
INSERT INTO "django_geo_db_city" VALUES(23779,'Desha','Desha, Arkansas',28869,4);
INSERT INTO "django_geo_db_city" VALUES(23780,'Dolph','Dolph, Arkansas',28870,4);
INSERT INTO "django_geo_db_city" VALUES(23781,'Drasco','Drasco, Arkansas',28872,4);
INSERT INTO "django_geo_db_city" VALUES(23782,'Elizabeth','Elizabeth, Arkansas',28873,4);
INSERT INTO "django_geo_db_city" VALUES(23783,'Evening Shade','Evening Shade, Arkansas',28874,4);
INSERT INTO "django_geo_db_city" VALUES(23784,'Fifty Six','Fifty Six, Arkansas',28875,4);
INSERT INTO "django_geo_db_city" VALUES(23785,'Floral','Floral, Arkansas',28876,4);
INSERT INTO "django_geo_db_city" VALUES(23786,'Franklin','Franklin, Arkansas',28877,4);
INSERT INTO "django_geo_db_city" VALUES(23787,'Gamaliel','Gamaliel, Arkansas',28878,4);
INSERT INTO "django_geo_db_city" VALUES(23788,'Gepp','Gepp, Arkansas',28879,4);
INSERT INTO "django_geo_db_city" VALUES(23789,'Glencoe','Glencoe, Arkansas',28880,4);
INSERT INTO "django_geo_db_city" VALUES(23790,'Guion','Guion, Arkansas',28881,4);
INSERT INTO "django_geo_db_city" VALUES(23791,'Hardy','Hardy, Arkansas',28882,4);
INSERT INTO "django_geo_db_city" VALUES(23792,'Heber Springs','Heber Springs, Arkansas',28883,4);
INSERT INTO "django_geo_db_city" VALUES(23793,'Henderson','Henderson, Arkansas',28884,4);
INSERT INTO "django_geo_db_city" VALUES(23794,'Ida','Ida, Arkansas',28886,4);
INSERT INTO "django_geo_db_city" VALUES(23795,'Locust Grove','Locust Grove, Arkansas',28887,4);
INSERT INTO "django_geo_db_city" VALUES(23796,'Magness','Magness, Arkansas',28888,4);
INSERT INTO "django_geo_db_city" VALUES(23797,'Mammoth Spring','Mammoth Spring, Arkansas',28889,4);
INSERT INTO "django_geo_db_city" VALUES(23798,'Marcella','Marcella, Arkansas',28890,4);
INSERT INTO "django_geo_db_city" VALUES(23799,'Melbourne','Melbourne, Arkansas',28891,4);
INSERT INTO "django_geo_db_city" VALUES(23800,'Moko','Moko, Arkansas',28892,4);
INSERT INTO "django_geo_db_city" VALUES(23801,'Salem','Salem, Arkansas',28893,4);
INSERT INTO "django_geo_db_city" VALUES(23802,'Mountain View','Mountain View, Arkansas',28894,4);
INSERT INTO "django_geo_db_city" VALUES(23803,'Mount Pleasant','Mount Pleasant, Arkansas',28895,4);
INSERT INTO "django_geo_db_city" VALUES(23804,'Newark','Newark, Arkansas',28896,4);
INSERT INTO "django_geo_db_city" VALUES(23805,'Oil Trough','Oil Trough, Arkansas',28897,4);
INSERT INTO "django_geo_db_city" VALUES(23806,'Oxford','Oxford, Arkansas',28898,4);
INSERT INTO "django_geo_db_city" VALUES(23807,'Pineville','Pineville, Arkansas',28899,4);
INSERT INTO "django_geo_db_city" VALUES(23808,'Pleasant Grove','Pleasant Grove, Arkansas',28900,4);
INSERT INTO "django_geo_db_city" VALUES(23809,'Pleasant Plains','Pleasant Plains, Arkansas',28901,4);
INSERT INTO "django_geo_db_city" VALUES(23810,'Poughkeepsie','Poughkeepsie, Arkansas',28902,4);
INSERT INTO "django_geo_db_city" VALUES(23811,'Rosie','Rosie, Arkansas',28903,4);
INSERT INTO "django_geo_db_city" VALUES(23812,'Saffell','Saffell, Arkansas',28904,4);
INSERT INTO "django_geo_db_city" VALUES(23813,'Sage','Sage, Arkansas',28905,4);
INSERT INTO "django_geo_db_city" VALUES(23814,'Salado','Salado, Arkansas',28906,4);
INSERT INTO "django_geo_db_city" VALUES(23815,'Sidney','Sidney, Arkansas',28908,4);
INSERT INTO "django_geo_db_city" VALUES(23816,'Sturkie','Sturkie, Arkansas',28909,4);
INSERT INTO "django_geo_db_city" VALUES(23817,'Sulphur Rock','Sulphur Rock, Arkansas',28910,4);
INSERT INTO "django_geo_db_city" VALUES(23818,'Tumbling Shoals','Tumbling Shoals, Arkansas',28911,4);
INSERT INTO "django_geo_db_city" VALUES(23819,'Viola','Viola, Arkansas',28912,4);
INSERT INTO "django_geo_db_city" VALUES(23820,'Violet Hill','Violet Hill, Arkansas',28913,4);
INSERT INTO "django_geo_db_city" VALUES(23821,'Wideman','Wideman, Arkansas',28914,4);
INSERT INTO "django_geo_db_city" VALUES(23822,'Wiseman','Wiseman, Arkansas',28915,4);
INSERT INTO "django_geo_db_city" VALUES(23823,'Harrison','Harrison, Arkansas',28916,4);
INSERT INTO "django_geo_db_city" VALUES(23824,'Alco','Alco, Arkansas',28918,4);
INSERT INTO "django_geo_db_city" VALUES(23825,'Alpena','Alpena, Arkansas',28919,4);
INSERT INTO "django_geo_db_city" VALUES(23826,'Beaver','Beaver, Arkansas',28920,4);
INSERT INTO "django_geo_db_city" VALUES(23827,'Bergman','Bergman, Arkansas',28921,4);
INSERT INTO "django_geo_db_city" VALUES(23828,'Berryville','Berryville, Arkansas',28922,4);
INSERT INTO "django_geo_db_city" VALUES(23829,'Big Flat','Big Flat, Arkansas',28923,4);
INSERT INTO "django_geo_db_city" VALUES(23830,'Bull Shoals','Bull Shoals, Arkansas',28924,4);
INSERT INTO "django_geo_db_city" VALUES(23831,'Clarkridge','Clarkridge, Arkansas',28925,4);
INSERT INTO "django_geo_db_city" VALUES(23832,'Compton','Compton, Arkansas',28926,4);
INSERT INTO "django_geo_db_city" VALUES(23833,'Cotter','Cotter, Arkansas',28927,4);
INSERT INTO "django_geo_db_city" VALUES(23834,'Deer','Deer, Arkansas',28928,4);
INSERT INTO "django_geo_db_city" VALUES(23835,'Dennard','Dennard, Arkansas',28929,4);
INSERT INTO "django_geo_db_city" VALUES(23836,'Diamond City','Diamond City, Arkansas',28930,4);
INSERT INTO "django_geo_db_city" VALUES(23837,'Eureka Springs','Eureka Springs, Arkansas',28931,4);
INSERT INTO "django_geo_db_city" VALUES(23838,'Everton','Everton, Arkansas',28933,4);
INSERT INTO "django_geo_db_city" VALUES(23839,'Flippin','Flippin, Arkansas',28934,4);
INSERT INTO "django_geo_db_city" VALUES(23840,'Gassville','Gassville, Arkansas',28935,4);
INSERT INTO "django_geo_db_city" VALUES(23841,'Gilbert','Gilbert, Arkansas',28936,4);
INSERT INTO "django_geo_db_city" VALUES(23842,'Green Forest','Green Forest, Arkansas',28937,4);
INSERT INTO "django_geo_db_city" VALUES(23843,'Harriet','Harriet, Arkansas',28938,4);
INSERT INTO "django_geo_db_city" VALUES(23844,'Hasty','Hasty, Arkansas',28939,4);
INSERT INTO "django_geo_db_city" VALUES(23845,'Jasper','Jasper, Arkansas',28940,4);
INSERT INTO "django_geo_db_city" VALUES(23846,'Lakeview','Lakeview, Arkansas',28941,4);
INSERT INTO "django_geo_db_city" VALUES(23847,'Lead Hill','Lead Hill, Arkansas',28942,4);
INSERT INTO "django_geo_db_city" VALUES(23848,'Leslie','Leslie, Arkansas',28943,4);
INSERT INTO "django_geo_db_city" VALUES(23849,'Marble Falls','Marble Falls, Arkansas',28944,4);
INSERT INTO "django_geo_db_city" VALUES(23850,'Marshall','Marshall, Arkansas',28945,4);
INSERT INTO "django_geo_db_city" VALUES(23851,'Midway','Midway, Arkansas',28946,4);
INSERT INTO "django_geo_db_city" VALUES(23852,'Mountain Home','Mountain Home, Arkansas',28947,4);
INSERT INTO "django_geo_db_city" VALUES(23853,'Mount Judea','Mount Judea, Arkansas',28949,4);
INSERT INTO "django_geo_db_city" VALUES(23854,'Timbo','Timbo, Arkansas',28950,4);
INSERT INTO "django_geo_db_city" VALUES(23855,'Norfork','Norfork, Arkansas',28951,4);
INSERT INTO "django_geo_db_city" VALUES(23856,'Oak Grove','Oak Grove, Arkansas',28952,4);
INSERT INTO "django_geo_db_city" VALUES(23857,'Oakland','Oakland, Arkansas',28953,4);
INSERT INTO "django_geo_db_city" VALUES(23858,'Omaha','Omaha, Arkansas',28954,4);
INSERT INTO "django_geo_db_city" VALUES(23859,'Onia','Onia, Arkansas',28955,4);
INSERT INTO "django_geo_db_city" VALUES(23860,'Parthenon','Parthenon, Arkansas',28956,4);
INSERT INTO "django_geo_db_city" VALUES(23861,'Peel','Peel, Arkansas',28957,4);
INSERT INTO "django_geo_db_city" VALUES(23862,'Pindall','Pindall, Arkansas',28958,4);
INSERT INTO "django_geo_db_city" VALUES(23863,'Ponca','Ponca, Arkansas',28959,4);
INSERT INTO "django_geo_db_city" VALUES(23864,'Pyatt','Pyatt, Arkansas',28960,4);
INSERT INTO "django_geo_db_city" VALUES(23865,'Saint Joe','Saint Joe, Arkansas',28961,4);
INSERT INTO "django_geo_db_city" VALUES(23866,'Summit','Summit, Arkansas',28962,4);
INSERT INTO "django_geo_db_city" VALUES(23867,'Tilly','Tilly, Arkansas',28963,4);
INSERT INTO "django_geo_db_city" VALUES(23868,'Valley Springs','Valley Springs, Arkansas',28965,4);
INSERT INTO "django_geo_db_city" VALUES(23869,'Vendor','Vendor, Arkansas',28966,4);
INSERT INTO "django_geo_db_city" VALUES(23870,'Western Grove','Western Grove, Arkansas',28967,4);
INSERT INTO "django_geo_db_city" VALUES(23871,'Witts Springs','Witts Springs, Arkansas',28968,4);
INSERT INTO "django_geo_db_city" VALUES(23872,'Yellville','Yellville, Arkansas',28969,4);
INSERT INTO "django_geo_db_city" VALUES(23873,'Fayetteville','Fayetteville, Arkansas',28970,4);
INSERT INTO "django_geo_db_city" VALUES(23874,'Avoca','Avoca, Arkansas',28974,4);
INSERT INTO "django_geo_db_city" VALUES(23875,'Bentonville','Bentonville, Arkansas',28975,4);
INSERT INTO "django_geo_db_city" VALUES(23876,'Bella Vista','Bella Vista, Arkansas',28976,4);
INSERT INTO "django_geo_db_city" VALUES(23877,'Canehill','Canehill, Arkansas',28979,4);
INSERT INTO "django_geo_db_city" VALUES(23878,'Cave Springs','Cave Springs, Arkansas',28980,4);
INSERT INTO "django_geo_db_city" VALUES(23879,'Centerton','Centerton, Arkansas',28981,4);
INSERT INTO "django_geo_db_city" VALUES(23880,'Combs','Combs, Arkansas',28982,4);
INSERT INTO "django_geo_db_city" VALUES(23881,'Decatur','Decatur, Arkansas',28983,4);
INSERT INTO "django_geo_db_city" VALUES(23882,'Elkins','Elkins, Arkansas',28984,4);
INSERT INTO "django_geo_db_city" VALUES(23883,'Elm Springs','Elm Springs, Arkansas',28985,4);
INSERT INTO "django_geo_db_city" VALUES(23884,'Evansville','Evansville, Arkansas',28986,4);
INSERT INTO "django_geo_db_city" VALUES(23885,'Farmington','Farmington, Arkansas',28987,4);
INSERT INTO "django_geo_db_city" VALUES(23886,'Garfield','Garfield, Arkansas',28988,4);
INSERT INTO "django_geo_db_city" VALUES(23887,'Gateway','Gateway, Arkansas',28989,4);
INSERT INTO "django_geo_db_city" VALUES(23888,'Gentry','Gentry, Arkansas',28990,4);
INSERT INTO "django_geo_db_city" VALUES(23889,'Goshen','Goshen, Arkansas',28991,4);
INSERT INTO "django_geo_db_city" VALUES(23890,'Gravette','Gravette, Arkansas',28992,4);
INSERT INTO "django_geo_db_city" VALUES(23891,'Greenland','Greenland, Arkansas',28993,4);
INSERT INTO "django_geo_db_city" VALUES(23892,'Hindsville','Hindsville, Arkansas',28994,4);
INSERT INTO "django_geo_db_city" VALUES(23893,'Hiwasse','Hiwasse, Arkansas',28995,4);
INSERT INTO "django_geo_db_city" VALUES(23894,'Huntsville','Huntsville, Arkansas',28996,4);
INSERT INTO "django_geo_db_city" VALUES(23895,'Johnson','Johnson, Arkansas',28971,4);
INSERT INTO "django_geo_db_city" VALUES(23896,'Kingston','Kingston, Arkansas',28997,4);
INSERT INTO "django_geo_db_city" VALUES(23897,'Lincoln','Lincoln, Arkansas',28998,4);
INSERT INTO "django_geo_db_city" VALUES(23898,'Lowell','Lowell, Arkansas',28999,4);
INSERT INTO "django_geo_db_city" VALUES(23899,'Maysville','Maysville, Arkansas',29000,4);
INSERT INTO "django_geo_db_city" VALUES(23900,'Morrow','Morrow, Arkansas',29001,4);
INSERT INTO "django_geo_db_city" VALUES(23901,'Pea Ridge','Pea Ridge, Arkansas',29002,4);
INSERT INTO "django_geo_db_city" VALUES(23902,'Pettigrew','Pettigrew, Arkansas',29003,4);
INSERT INTO "django_geo_db_city" VALUES(23903,'Prairie Grove','Prairie Grove, Arkansas',29004,4);
INSERT INTO "django_geo_db_city" VALUES(23904,'Rogers','Rogers, Arkansas',29005,4);
INSERT INTO "django_geo_db_city" VALUES(23905,'Saint Paul','Saint Paul, Arkansas',29008,4);
INSERT INTO "django_geo_db_city" VALUES(23906,'Siloam Springs','Siloam Springs, Arkansas',29009,4);
INSERT INTO "django_geo_db_city" VALUES(23907,'Springdale','Springdale, Arkansas',29010,4);
INSERT INTO "django_geo_db_city" VALUES(23908,'Sulphur Springs','Sulphur Springs, Arkansas',29013,4);
INSERT INTO "django_geo_db_city" VALUES(23909,'Summers','Summers, Arkansas',29014,4);
INSERT INTO "django_geo_db_city" VALUES(23910,'Tontitown','Tontitown, Arkansas',29015,4);
INSERT INTO "django_geo_db_city" VALUES(23911,'Wesley','Wesley, Arkansas',29016,4);
INSERT INTO "django_geo_db_city" VALUES(23912,'West Fork','West Fork, Arkansas',29017,4);
INSERT INTO "django_geo_db_city" VALUES(23913,'Witter','Witter, Arkansas',29018,4);
INSERT INTO "django_geo_db_city" VALUES(23914,'Russellville','Russellville, Arkansas',29019,4);
INSERT INTO "django_geo_db_city" VALUES(23915,'Alix','Alix, Arkansas',29023,4);
INSERT INTO "django_geo_db_city" VALUES(23916,'Altus','Altus, Arkansas',29024,4);
INSERT INTO "django_geo_db_city" VALUES(23917,'Atkins','Atkins, Arkansas',29026,4);
INSERT INTO "django_geo_db_city" VALUES(23918,'Belleville','Belleville, Arkansas',29027,4);
INSERT INTO "django_geo_db_city" VALUES(23919,'Blue Mountain','Blue Mountain, Arkansas',29028,4);
INSERT INTO "django_geo_db_city" VALUES(23920,'Bluffton','Bluffton, Arkansas',29029,4);
INSERT INTO "django_geo_db_city" VALUES(23921,'Briggsville','Briggsville, Arkansas',29030,4);
INSERT INTO "django_geo_db_city" VALUES(23922,'Centerville','Centerville, Arkansas',29031,4);
INSERT INTO "django_geo_db_city" VALUES(23923,'Clarksville','Clarksville, Arkansas',29032,4);
INSERT INTO "django_geo_db_city" VALUES(23924,'Coal Hill','Coal Hill, Arkansas',29033,4);
INSERT INTO "django_geo_db_city" VALUES(23925,'Danville','Danville, Arkansas',29034,4);
INSERT INTO "django_geo_db_city" VALUES(23926,'Dardanelle','Dardanelle, Arkansas',29035,4);
INSERT INTO "django_geo_db_city" VALUES(23927,'Delaware','Delaware, Arkansas',29036,4);
INSERT INTO "django_geo_db_city" VALUES(23928,'Dover','Dover, Arkansas',29037,4);
INSERT INTO "django_geo_db_city" VALUES(23929,'Gravelly','Gravelly, Arkansas',29038,4);
INSERT INTO "django_geo_db_city" VALUES(23930,'Hagarville','Hagarville, Arkansas',29039,4);
INSERT INTO "django_geo_db_city" VALUES(23931,'Hartman','Hartman, Arkansas',29040,4);
INSERT INTO "django_geo_db_city" VALUES(23932,'Harvey','Harvey, Arkansas',29041,4);
INSERT INTO "django_geo_db_city" VALUES(23933,'Havana','Havana, Arkansas',29042,4);
INSERT INTO "django_geo_db_city" VALUES(23934,'Hector','Hector, Arkansas',29043,4);
INSERT INTO "django_geo_db_city" VALUES(23935,'Knoxville','Knoxville, Arkansas',29044,4);
INSERT INTO "django_geo_db_city" VALUES(23936,'Lamar','Lamar, Arkansas',29045,4);
INSERT INTO "django_geo_db_city" VALUES(23937,'London','London, Arkansas',29046,4);
INSERT INTO "django_geo_db_city" VALUES(23938,'New Blaine','New Blaine, Arkansas',29047,4);
INSERT INTO "django_geo_db_city" VALUES(23939,'Oark','Oark, Arkansas',29048,4);
INSERT INTO "django_geo_db_city" VALUES(23940,'Ola','Ola, Arkansas',29049,4);
INSERT INTO "django_geo_db_city" VALUES(23941,'Ozone','Ozone, Arkansas',29050,4);
INSERT INTO "django_geo_db_city" VALUES(23942,'Paris','Paris, Arkansas',29051,4);
INSERT INTO "django_geo_db_city" VALUES(23943,'Pelsor','Pelsor, Arkansas',29052,4);
INSERT INTO "django_geo_db_city" VALUES(23944,'Plainview','Plainview, Arkansas',29053,4);
INSERT INTO "django_geo_db_city" VALUES(23945,'Pottsville','Pottsville, Arkansas',29054,4);
INSERT INTO "django_geo_db_city" VALUES(23946,'Rover','Rover, Arkansas',29055,4);
INSERT INTO "django_geo_db_city" VALUES(23947,'Scranton','Scranton, Arkansas',29056,4);
INSERT INTO "django_geo_db_city" VALUES(23948,'Subiaco','Subiaco, Arkansas',29057,4);
INSERT INTO "django_geo_db_city" VALUES(23949,'Fort Smith','Fort Smith, Arkansas',29058,4);
INSERT INTO "django_geo_db_city" VALUES(23950,'Alma','Alma, Arkansas',29065,4);
INSERT INTO "django_geo_db_city" VALUES(23951,'Barling','Barling, Arkansas',29066,4);
INSERT INTO "django_geo_db_city" VALUES(23952,'Bates','Bates, Arkansas',29067,4);
INSERT INTO "django_geo_db_city" VALUES(23953,'Boles','Boles, Arkansas',29068,4);
INSERT INTO "django_geo_db_city" VALUES(23954,'Booneville','Booneville, Arkansas',29069,4);
INSERT INTO "django_geo_db_city" VALUES(23955,'Branch','Branch, Arkansas',29070,4);
INSERT INTO "django_geo_db_city" VALUES(23956,'Cecil','Cecil, Arkansas',29071,4);
INSERT INTO "django_geo_db_city" VALUES(23957,'Cedarville','Cedarville, Arkansas',29072,4);
INSERT INTO "django_geo_db_city" VALUES(23958,'Charleston','Charleston, Arkansas',29073,4);
INSERT INTO "django_geo_db_city" VALUES(23959,'Chester','Chester, Arkansas',29074,4);
INSERT INTO "django_geo_db_city" VALUES(23960,'Dyer','Dyer, Arkansas',29075,4);
INSERT INTO "django_geo_db_city" VALUES(23961,'Greenwood','Greenwood, Arkansas',29076,4);
INSERT INTO "django_geo_db_city" VALUES(23962,'Hackett','Hackett, Arkansas',29077,4);
INSERT INTO "django_geo_db_city" VALUES(23963,'Hartford','Hartford, Arkansas',29078,4);
INSERT INTO "django_geo_db_city" VALUES(23964,'Huntington','Huntington, Arkansas',29079,4);
INSERT INTO "django_geo_db_city" VALUES(23965,'Lavaca','Lavaca, Arkansas',29080,4);
INSERT INTO "django_geo_db_city" VALUES(23966,'Magazine','Magazine, Arkansas',29081,4);
INSERT INTO "django_geo_db_city" VALUES(23967,'Mansfield','Mansfield, Arkansas',29082,4);
INSERT INTO "django_geo_db_city" VALUES(23968,'Midland','Midland, Arkansas',29083,4);
INSERT INTO "django_geo_db_city" VALUES(23969,'Mountainburg','Mountainburg, Arkansas',29084,4);
INSERT INTO "django_geo_db_city" VALUES(23970,'Mulberry','Mulberry, Arkansas',29085,4);
INSERT INTO "django_geo_db_city" VALUES(23971,'Natural Dam','Natural Dam, Arkansas',29086,4);
INSERT INTO "django_geo_db_city" VALUES(23972,'Ozark','Ozark, Arkansas',29087,4);
INSERT INTO "django_geo_db_city" VALUES(23973,'Parks','Parks, Arkansas',29088,4);
INSERT INTO "django_geo_db_city" VALUES(23974,'Ratcliff','Ratcliff, Arkansas',29089,4);
INSERT INTO "django_geo_db_city" VALUES(23975,'Rudy','Rudy, Arkansas',29090,4);
INSERT INTO "django_geo_db_city" VALUES(23976,'Uniontown','Uniontown, Arkansas',29091,4);
INSERT INTO "django_geo_db_city" VALUES(23977,'Van Buren','Van Buren, Arkansas',29092,4);
INSERT INTO "django_geo_db_city" VALUES(23978,'Waldron','Waldron, Arkansas',29094,4);
INSERT INTO "django_geo_db_city" VALUES(23979,'Winslow','Winslow, Arkansas',29095,4);
INSERT INTO "django_geo_db_city" VALUES(23980,'Albert','Albert, Oklahoma',29096,36);
INSERT INTO "django_geo_db_city" VALUES(23981,'Alex','Alex, Oklahoma',29097,36);
INSERT INTO "django_geo_db_city" VALUES(23982,'Edmond','Edmond, Oklahoma',29098,36);
INSERT INTO "django_geo_db_city" VALUES(23983,'Amber','Amber, Oklahoma',29099,36);
INSERT INTO "django_geo_db_city" VALUES(23984,'Anadarko','Anadarko, Oklahoma',29100,36);
INSERT INTO "django_geo_db_city" VALUES(23985,'Apache','Apache, Oklahoma',29101,36);
INSERT INTO "django_geo_db_city" VALUES(23986,'Arcadia','Arcadia, Oklahoma',29102,36);
INSERT INTO "django_geo_db_city" VALUES(23987,'Bethany','Bethany, Oklahoma',29103,36);
INSERT INTO "django_geo_db_city" VALUES(23988,'Binger','Binger, Oklahoma',29104,36);
INSERT INTO "django_geo_db_city" VALUES(23989,'Blanchard','Blanchard, Oklahoma',29105,36);
INSERT INTO "django_geo_db_city" VALUES(23990,'Bradley','Bradley, Oklahoma',29106,36);
INSERT INTO "django_geo_db_city" VALUES(23991,'Bray','Bray, Oklahoma',29107,36);
INSERT INTO "django_geo_db_city" VALUES(23992,'Calumet','Calumet, Oklahoma',29109,36);
INSERT INTO "django_geo_db_city" VALUES(23993,'Carnegie','Carnegie, Oklahoma',29110,36);
INSERT INTO "django_geo_db_city" VALUES(23994,'Cashion','Cashion, Oklahoma',29111,36);
INSERT INTO "django_geo_db_city" VALUES(23995,'Cement','Cement, Oklahoma',29112,36);
INSERT INTO "django_geo_db_city" VALUES(23996,'Chickasha','Chickasha, Oklahoma',29113,36);
INSERT INTO "django_geo_db_city" VALUES(23997,'Norman','Norman, Oklahoma',29114,36);
INSERT INTO "django_geo_db_city" VALUES(23998,'Choctaw','Choctaw, Oklahoma',29115,36);
INSERT INTO "django_geo_db_city" VALUES(23999,'Colony','Colony, Oklahoma',29116,36);
INSERT INTO "django_geo_db_city" VALUES(24000,'Concho','Concho, Oklahoma',29117,36);
INSERT INTO "django_geo_db_city" VALUES(24001,'Corn','Corn, Oklahoma',29119,36);
INSERT INTO "django_geo_db_city" VALUES(24002,'Coyle','Coyle, Oklahoma',29121,36);
INSERT INTO "django_geo_db_city" VALUES(24003,'Crescent','Crescent, Oklahoma',29122,36);
INSERT INTO "django_geo_db_city" VALUES(24004,'Cyril','Cyril, Oklahoma',29123,36);
INSERT INTO "django_geo_db_city" VALUES(24005,'Davis','Davis, Oklahoma',29124,36);
INSERT INTO "django_geo_db_city" VALUES(24006,'Dibble','Dibble, Oklahoma',29125,36);
INSERT INTO "django_geo_db_city" VALUES(24007,'Dougherty','Dougherty, Oklahoma',29126,36);
INSERT INTO "django_geo_db_city" VALUES(24008,'Eakly','Eakly, Oklahoma',29127,36);
INSERT INTO "django_geo_db_city" VALUES(24009,'El Reno','El Reno, Oklahoma',29129,36);
INSERT INTO "django_geo_db_city" VALUES(24010,'Fort Cobb','Fort Cobb, Oklahoma',29130,36);
INSERT INTO "django_geo_db_city" VALUES(24011,'Geary','Geary, Oklahoma',29131,36);
INSERT INTO "django_geo_db_city" VALUES(24012,'Gotebo','Gotebo, Oklahoma',29132,36);
INSERT INTO "django_geo_db_city" VALUES(24013,'Gracemont','Gracemont, Oklahoma',29133,36);
INSERT INTO "django_geo_db_city" VALUES(24014,'Greenfield','Greenfield, Oklahoma',29134,36);
INSERT INTO "django_geo_db_city" VALUES(24015,'Guthrie','Guthrie, Oklahoma',29135,36);
INSERT INTO "django_geo_db_city" VALUES(24016,'Harrah','Harrah, Oklahoma',29136,36);
INSERT INTO "django_geo_db_city" VALUES(24017,'Hinton','Hinton, Oklahoma',29137,36);
INSERT INTO "django_geo_db_city" VALUES(24018,'Hydro','Hydro, Oklahoma',29138,36);
INSERT INTO "django_geo_db_city" VALUES(24019,'Jones','Jones, Oklahoma',29139,36);
INSERT INTO "django_geo_db_city" VALUES(24020,'Langston','Langston, Oklahoma',29140,36);
INSERT INTO "django_geo_db_city" VALUES(24021,'Lexington','Lexington, Oklahoma',29141,36);
INSERT INTO "django_geo_db_city" VALUES(24022,'Lindsay','Lindsay, Oklahoma',29142,36);
INSERT INTO "django_geo_db_city" VALUES(24023,'Lookeba','Lookeba, Oklahoma',29143,36);
INSERT INTO "django_geo_db_city" VALUES(24024,'Luther','Luther, Oklahoma',29144,36);
INSERT INTO "django_geo_db_city" VALUES(24025,'Marlow','Marlow, Oklahoma',29145,36);
INSERT INTO "django_geo_db_city" VALUES(24026,'Marshall','Marshall, Oklahoma',29146,36);
INSERT INTO "django_geo_db_city" VALUES(24027,'Maysville','Maysville, Oklahoma',29147,36);
INSERT INTO "django_geo_db_city" VALUES(24028,'Meridian','Meridian, Oklahoma',29148,36);
INSERT INTO "django_geo_db_city" VALUES(24029,'Minco','Minco, Oklahoma',29149,36);
INSERT INTO "django_geo_db_city" VALUES(24030,'Morrison','Morrison, Oklahoma',29150,36);
INSERT INTO "django_geo_db_city" VALUES(24031,'Mountain View','Mountain View, Oklahoma',29151,36);
INSERT INTO "django_geo_db_city" VALUES(24032,'Mulhall','Mulhall, Oklahoma',29152,36);
INSERT INTO "django_geo_db_city" VALUES(24033,'Mustang','Mustang, Oklahoma',29153,36);
INSERT INTO "django_geo_db_city" VALUES(24034,'Newcastle','Newcastle, Oklahoma',29154,36);
INSERT INTO "django_geo_db_city" VALUES(24035,'Nicoma Park','Nicoma Park, Oklahoma',29155,36);
INSERT INTO "django_geo_db_city" VALUES(24036,'Ninnekah','Ninnekah, Oklahoma',29156,36);
INSERT INTO "django_geo_db_city" VALUES(24037,'Noble','Noble, Oklahoma',29157,36);
INSERT INTO "django_geo_db_city" VALUES(24038,'Orlando','Orlando, Oklahoma',29162,36);
INSERT INTO "django_geo_db_city" VALUES(24039,'Paoli','Paoli, Oklahoma',29163,36);
INSERT INTO "django_geo_db_city" VALUES(24040,'Pauls Valley','Pauls Valley, Oklahoma',29164,36);
INSERT INTO "django_geo_db_city" VALUES(24041,'Perry','Perry, Oklahoma',29165,36);
INSERT INTO "django_geo_db_city" VALUES(24042,'Piedmont','Piedmont, Oklahoma',29166,36);
INSERT INTO "django_geo_db_city" VALUES(24043,'Pocasset','Pocasset, Oklahoma',29167,36);
INSERT INTO "django_geo_db_city" VALUES(24044,'Purcell','Purcell, Oklahoma',29168,36);
INSERT INTO "django_geo_db_city" VALUES(24045,'Rush Springs','Rush Springs, Oklahoma',29169,36);
INSERT INTO "django_geo_db_city" VALUES(24046,'Spencer','Spencer, Oklahoma',29171,36);
INSERT INTO "django_geo_db_city" VALUES(24047,'Yukon','Yukon, Oklahoma',29172,36);
INSERT INTO "django_geo_db_city" VALUES(24048,'Sulphur','Sulphur, Oklahoma',29173,36);
INSERT INTO "django_geo_db_city" VALUES(24049,'Tuttle','Tuttle, Oklahoma',29174,36);
INSERT INTO "django_geo_db_city" VALUES(24050,'Union City','Union City, Oklahoma',29175,36);
INSERT INTO "django_geo_db_city" VALUES(24051,'Verden','Verden, Oklahoma',29176,36);
INSERT INTO "django_geo_db_city" VALUES(24052,'Washington','Washington, Oklahoma',29177,36);
INSERT INTO "django_geo_db_city" VALUES(24053,'Washita','Washita, Oklahoma',29096,36);
INSERT INTO "django_geo_db_city" VALUES(24054,'Wayne','Wayne, Oklahoma',29178,36);
INSERT INTO "django_geo_db_city" VALUES(24055,'Weatherford','Weatherford, Oklahoma',29179,36);
INSERT INTO "django_geo_db_city" VALUES(24056,'Wheatland','Wheatland, Oklahoma',29180,36);
INSERT INTO "django_geo_db_city" VALUES(24057,'Wynnewood','Wynnewood, Oklahoma',29181,36);
INSERT INTO "django_geo_db_city" VALUES(24058,'Oklahoma City','Oklahoma City, Oklahoma',29183,36);
INSERT INTO "django_geo_db_city" VALUES(24059,'Austin','Austin, Texas',29234,51);
INSERT INTO "django_geo_db_city" VALUES(24060,'Sterling','Sterling, Oklahoma',29235,36);
INSERT INTO "django_geo_db_city" VALUES(24061,'Ames','Ames, Oklahoma',29236,36);
INSERT INTO "django_geo_db_city" VALUES(24062,'Ardmore','Ardmore, Oklahoma',29237,36);
INSERT INTO "django_geo_db_city" VALUES(24063,'Countyline','Countyline, Oklahoma',29239,36);
INSERT INTO "django_geo_db_city" VALUES(24064,'Burneyville','Burneyville, Oklahoma',29240,36);
INSERT INTO "django_geo_db_city" VALUES(24065,'Coleman','Coleman, Oklahoma',29241,36);
INSERT INTO "django_geo_db_city" VALUES(24066,'Elmore City','Elmore City, Oklahoma',29242,36);
INSERT INTO "django_geo_db_city" VALUES(24067,'Foster','Foster, Oklahoma',29243,36);
INSERT INTO "django_geo_db_city" VALUES(24068,'Fox','Fox, Oklahoma',29244,36);
INSERT INTO "django_geo_db_city" VALUES(24069,'Gene Autry','Gene Autry, Oklahoma',29245,36);
INSERT INTO "django_geo_db_city" VALUES(24070,'Graham','Graham, Oklahoma',29246,36);
INSERT INTO "django_geo_db_city" VALUES(24071,'Healdton','Healdton, Oklahoma',29247,36);
INSERT INTO "django_geo_db_city" VALUES(24072,'Kingston','Kingston, Oklahoma',29248,36);
INSERT INTO "django_geo_db_city" VALUES(24073,'Lebanon','Lebanon, Oklahoma',29249,36);
INSERT INTO "django_geo_db_city" VALUES(24074,'Leon','Leon, Oklahoma',29250,36);
INSERT INTO "django_geo_db_city" VALUES(24075,'Loco','Loco, Oklahoma',29251,36);
INSERT INTO "django_geo_db_city" VALUES(24076,'Lone Grove','Lone Grove, Oklahoma',29252,36);
INSERT INTO "django_geo_db_city" VALUES(24077,'Hennepin','Hennepin, Oklahoma',29253,36);
INSERT INTO "django_geo_db_city" VALUES(24078,'Ravia','Ravia, Oklahoma',29254,36);
INSERT INTO "django_geo_db_city" VALUES(24079,'Madill','Madill, Oklahoma',29255,36);
INSERT INTO "django_geo_db_city" VALUES(24080,'Mannsville','Mannsville, Oklahoma',29256,36);
INSERT INTO "django_geo_db_city" VALUES(24081,'Marietta','Marietta, Oklahoma',29257,36);
INSERT INTO "django_geo_db_city" VALUES(24082,'Mead','Mead, Oklahoma',29258,36);
INSERT INTO "django_geo_db_city" VALUES(24083,'Milburn','Milburn, Oklahoma',29259,36);
INSERT INTO "django_geo_db_city" VALUES(24084,'Overbrook','Overbrook, Oklahoma',29260,36);
INSERT INTO "django_geo_db_city" VALUES(24085,'Ringling','Ringling, Oklahoma',29262,36);
INSERT INTO "django_geo_db_city" VALUES(24086,'Springer','Springer, Oklahoma',29263,36);
INSERT INTO "django_geo_db_city" VALUES(24087,'Thackerville','Thackerville, Oklahoma',29264,36);
INSERT INTO "django_geo_db_city" VALUES(24088,'Tishomingo','Tishomingo, Oklahoma',29265,36);
INSERT INTO "django_geo_db_city" VALUES(24089,'Wapanucka','Wapanucka, Oklahoma',29266,36);
INSERT INTO "django_geo_db_city" VALUES(24090,'Wilson','Wilson, Oklahoma',29267,36);
INSERT INTO "django_geo_db_city" VALUES(24091,'Pernell','Pernell, Oklahoma',29268,36);
INSERT INTO "django_geo_db_city" VALUES(24092,'Ratliff City','Ratliff City, Oklahoma',29269,36);
INSERT INTO "django_geo_db_city" VALUES(24093,'Tatums','Tatums, Oklahoma',29270,36);
INSERT INTO "django_geo_db_city" VALUES(24094,'Tussy','Tussy, Oklahoma',29271,36);
INSERT INTO "django_geo_db_city" VALUES(24095,'Velma','Velma, Oklahoma',29272,36);
INSERT INTO "django_geo_db_city" VALUES(24096,'Lawton','Lawton, Oklahoma',29273,36);
INSERT INTO "django_geo_db_city" VALUES(24097,'Fort Sill','Fort Sill, Oklahoma',29275,36);
INSERT INTO "django_geo_db_city" VALUES(24098,'Addington','Addington, Oklahoma',29278,36);
INSERT INTO "django_geo_db_city" VALUES(24099,'Altus','Altus, Oklahoma',29279,36);
INSERT INTO "django_geo_db_city" VALUES(24100,'Altus AFB','Altus AFB, Oklahoma',29281,36);
INSERT INTO "django_geo_db_city" VALUES(24101,'Blair','Blair, Oklahoma',29282,36);
INSERT INTO "django_geo_db_city" VALUES(24102,'Cache','Cache, Oklahoma',29283,36);
INSERT INTO "django_geo_db_city" VALUES(24103,'Chattanooga','Chattanooga, Oklahoma',29284,36);
INSERT INTO "django_geo_db_city" VALUES(24104,'Comanche','Comanche, Oklahoma',29285,36);
INSERT INTO "django_geo_db_city" VALUES(24105,'Davidson','Davidson, Oklahoma',29286,36);
INSERT INTO "django_geo_db_city" VALUES(24106,'Devol','Devol, Oklahoma',29287,36);
INSERT INTO "django_geo_db_city" VALUES(24107,'Duke','Duke, Oklahoma',29288,36);
INSERT INTO "django_geo_db_city" VALUES(24108,'Duncan','Duncan, Oklahoma',29289,36);
INSERT INTO "django_geo_db_city" VALUES(24109,'Eldorado','Eldorado, Oklahoma',29291,36);
INSERT INTO "django_geo_db_city" VALUES(24110,'Elgin','Elgin, Oklahoma',29292,36);
INSERT INTO "django_geo_db_city" VALUES(24111,'Elmer','Elmer, Oklahoma',29293,36);
INSERT INTO "django_geo_db_city" VALUES(24112,'Faxon','Faxon, Oklahoma',29294,36);
INSERT INTO "django_geo_db_city" VALUES(24113,'Fletcher','Fletcher, Oklahoma',29295,36);
INSERT INTO "django_geo_db_city" VALUES(24114,'Frederick','Frederick, Oklahoma',29296,36);
INSERT INTO "django_geo_db_city" VALUES(24115,'Geronimo','Geronimo, Oklahoma',29297,36);
INSERT INTO "django_geo_db_city" VALUES(24116,'Gould','Gould, Oklahoma',29298,36);
INSERT INTO "django_geo_db_city" VALUES(24117,'Grandfield','Grandfield, Oklahoma',29299,36);
INSERT INTO "django_geo_db_city" VALUES(24118,'Granite','Granite, Oklahoma',29300,36);
INSERT INTO "django_geo_db_city" VALUES(24119,'Hastings','Hastings, Oklahoma',29301,36);
INSERT INTO "django_geo_db_city" VALUES(24120,'Headrick','Headrick, Oklahoma',29302,36);
INSERT INTO "django_geo_db_city" VALUES(24121,'Hollis','Hollis, Oklahoma',29303,36);
INSERT INTO "django_geo_db_city" VALUES(24122,'Hollister','Hollister, Oklahoma',29304,36);
INSERT INTO "django_geo_db_city" VALUES(24123,'Indiahoma','Indiahoma, Oklahoma',29305,36);
INSERT INTO "django_geo_db_city" VALUES(24124,'Loveland','Loveland, Oklahoma',29306,36);
INSERT INTO "django_geo_db_city" VALUES(24125,'Mangum','Mangum, Oklahoma',29307,36);
INSERT INTO "django_geo_db_city" VALUES(24126,'Manitou','Manitou, Oklahoma',29308,36);
INSERT INTO "django_geo_db_city" VALUES(24127,'Martha','Martha, Oklahoma',29309,36);
INSERT INTO "django_geo_db_city" VALUES(24128,'Medicine Park','Medicine Park, Oklahoma',29310,36);
INSERT INTO "django_geo_db_city" VALUES(24129,'Meers','Meers, Oklahoma',29274,36);
INSERT INTO "django_geo_db_city" VALUES(24130,'Mountain Park','Mountain Park, Oklahoma',29311,36);
INSERT INTO "django_geo_db_city" VALUES(24131,'Olustee','Olustee, Oklahoma',29312,36);
INSERT INTO "django_geo_db_city" VALUES(24132,'Oscar','Oscar, Oklahoma',29313,36);
INSERT INTO "django_geo_db_city" VALUES(24133,'Randlett','Randlett, Oklahoma',29314,36);
INSERT INTO "django_geo_db_city" VALUES(24134,'Roosevelt','Roosevelt, Oklahoma',29315,36);
INSERT INTO "django_geo_db_city" VALUES(24135,'Ryan','Ryan, Oklahoma',29316,36);
INSERT INTO "django_geo_db_city" VALUES(24136,'Snyder','Snyder, Oklahoma',29317,36);
INSERT INTO "django_geo_db_city" VALUES(24137,'Temple','Temple, Oklahoma',29319,36);
INSERT INTO "django_geo_db_city" VALUES(24138,'Terral','Terral, Oklahoma',29320,36);
INSERT INTO "django_geo_db_city" VALUES(24139,'Tipton','Tipton, Oklahoma',29321,36);
INSERT INTO "django_geo_db_city" VALUES(24140,'Vinson','Vinson, Oklahoma',29322,36);
INSERT INTO "django_geo_db_city" VALUES(24141,'Walters','Walters, Oklahoma',29323,36);
INSERT INTO "django_geo_db_city" VALUES(24142,'Waurika','Waurika, Oklahoma',29324,36);
INSERT INTO "django_geo_db_city" VALUES(24143,'Clinton','Clinton, Oklahoma',29325,36);
INSERT INTO "django_geo_db_city" VALUES(24144,'Arapaho','Arapaho, Oklahoma',29326,36);
INSERT INTO "django_geo_db_city" VALUES(24145,'Bessie','Bessie, Oklahoma',29327,36);
INSERT INTO "django_geo_db_city" VALUES(24146,'Burns Flat','Burns Flat, Oklahoma',29328,36);
INSERT INTO "django_geo_db_city" VALUES(24147,'Butler','Butler, Oklahoma',29329,36);
INSERT INTO "django_geo_db_city" VALUES(24148,'Canute','Canute, Oklahoma',29330,36);
INSERT INTO "django_geo_db_city" VALUES(24149,'Carter','Carter, Oklahoma',29331,36);
INSERT INTO "django_geo_db_city" VALUES(24150,'Cheyenne','Cheyenne, Oklahoma',29332,36);
INSERT INTO "django_geo_db_city" VALUES(24151,'Cordell','Cordell, Oklahoma',29333,36);
INSERT INTO "django_geo_db_city" VALUES(24152,'Crawford','Crawford, Oklahoma',29334,36);
INSERT INTO "django_geo_db_city" VALUES(24153,'Custer City','Custer City, Oklahoma',29335,36);
INSERT INTO "django_geo_db_city" VALUES(24154,'Dill City','Dill City, Oklahoma',29336,36);
INSERT INTO "django_geo_db_city" VALUES(24155,'Durham','Durham, Oklahoma',29337,36);
INSERT INTO "django_geo_db_city" VALUES(24156,'Elk City','Elk City, Oklahoma',29338,36);
INSERT INTO "django_geo_db_city" VALUES(24157,'Erick','Erick, Oklahoma',29339,36);
INSERT INTO "django_geo_db_city" VALUES(24158,'Fay','Fay, Oklahoma',29340,36);
INSERT INTO "django_geo_db_city" VALUES(24159,'Foss','Foss, Oklahoma',29341,36);
INSERT INTO "django_geo_db_city" VALUES(24160,'Hammon','Hammon, Oklahoma',29343,36);
INSERT INTO "django_geo_db_city" VALUES(24161,'Hobart','Hobart, Oklahoma',29344,36);
INSERT INTO "django_geo_db_city" VALUES(24162,'Leedey','Leedey, Oklahoma',29345,36);
INSERT INTO "django_geo_db_city" VALUES(24163,'Lone Wolf','Lone Wolf, Oklahoma',29346,36);
INSERT INTO "django_geo_db_city" VALUES(24164,'Mayfield','Mayfield, Oklahoma',29342,36);
INSERT INTO "django_geo_db_city" VALUES(24165,'Oakwood','Oakwood, Oklahoma',29347,36);
INSERT INTO "django_geo_db_city" VALUES(24166,'Putnam','Putnam, Oklahoma',29348,36);
INSERT INTO "django_geo_db_city" VALUES(24167,'Reydon','Reydon, Oklahoma',29349,36);
INSERT INTO "django_geo_db_city" VALUES(24168,'Rocky','Rocky, Oklahoma',29350,36);
INSERT INTO "django_geo_db_city" VALUES(24169,'Sayre','Sayre, Oklahoma',29351,36);
INSERT INTO "django_geo_db_city" VALUES(24170,'Seiling','Seiling, Oklahoma',29352,36);
INSERT INTO "django_geo_db_city" VALUES(24171,'Sentinel','Sentinel, Oklahoma',29353,36);
INSERT INTO "django_geo_db_city" VALUES(24172,'Sweetwater','Sweetwater, Oklahoma',29354,36);
INSERT INTO "django_geo_db_city" VALUES(24173,'Taloga','Taloga, Oklahoma',29355,36);
INSERT INTO "django_geo_db_city" VALUES(24174,'Texola','Texola, Oklahoma',29356,36);
INSERT INTO "django_geo_db_city" VALUES(24175,'Thomas','Thomas, Oklahoma',29357,36);
INSERT INTO "django_geo_db_city" VALUES(24176,'Willow','Willow, Oklahoma',29358,36);
INSERT INTO "django_geo_db_city" VALUES(24177,'Enid','Enid, Oklahoma',29359,36);
INSERT INTO "django_geo_db_city" VALUES(24178,'Aline','Aline, Oklahoma',29362,36);
INSERT INTO "django_geo_db_city" VALUES(24179,'Alva','Alva, Oklahoma',29363,36);
INSERT INTO "django_geo_db_city" VALUES(24180,'Amorita','Amorita, Oklahoma',29365,36);
INSERT INTO "django_geo_db_city" VALUES(24181,'Bison','Bison, Oklahoma',29366,36);
INSERT INTO "django_geo_db_city" VALUES(24182,'Burlington','Burlington, Oklahoma',29367,36);
INSERT INTO "django_geo_db_city" VALUES(24183,'Canton','Canton, Oklahoma',29368,36);
INSERT INTO "django_geo_db_city" VALUES(24184,'Carmen','Carmen, Oklahoma',29369,36);
INSERT INTO "django_geo_db_city" VALUES(24185,'Carrier','Carrier, Oklahoma',29370,36);
INSERT INTO "django_geo_db_city" VALUES(24186,'Cherokee','Cherokee, Oklahoma',29371,36);
INSERT INTO "django_geo_db_city" VALUES(24187,'Cleo Springs','Cleo Springs, Oklahoma',29372,36);
INSERT INTO "django_geo_db_city" VALUES(24188,'Covington','Covington, Oklahoma',29373,36);
INSERT INTO "django_geo_db_city" VALUES(24189,'Dacoma','Dacoma, Oklahoma',29374,36);
INSERT INTO "django_geo_db_city" VALUES(24190,'Douglas','Douglas, Oklahoma',29375,36);
INSERT INTO "django_geo_db_city" VALUES(24191,'Dover','Dover, Oklahoma',29376,36);
INSERT INTO "django_geo_db_city" VALUES(24192,'Drummond','Drummond, Oklahoma',29377,36);
INSERT INTO "django_geo_db_city" VALUES(24193,'Fairmont','Fairmont, Oklahoma',29378,36);
INSERT INTO "django_geo_db_city" VALUES(24194,'Fairview','Fairview, Oklahoma',29379,36);
INSERT INTO "django_geo_db_city" VALUES(24195,'Garber','Garber, Oklahoma',29380,36);
INSERT INTO "django_geo_db_city" VALUES(24196,'Goltry','Goltry, Oklahoma',29381,36);
INSERT INTO "django_geo_db_city" VALUES(24197,'Helena','Helena, Oklahoma',29382,36);
INSERT INTO "django_geo_db_city" VALUES(24198,'Hennessey','Hennessey, Oklahoma',29383,36);
INSERT INTO "django_geo_db_city" VALUES(24199,'Hillsdale','Hillsdale, Oklahoma',29384,36);
INSERT INTO "django_geo_db_city" VALUES(24200,'Hitchcock','Hitchcock, Oklahoma',29385,36);
INSERT INTO "django_geo_db_city" VALUES(24201,'Hopeton','Hopeton, Oklahoma',29386,36);
INSERT INTO "django_geo_db_city" VALUES(24202,'Isabella','Isabella, Oklahoma',29387,36);
INSERT INTO "django_geo_db_city" VALUES(24203,'Jet','Jet, Oklahoma',29388,36);
INSERT INTO "django_geo_db_city" VALUES(24204,'Kingfisher','Kingfisher, Oklahoma',29389,36);
INSERT INTO "django_geo_db_city" VALUES(24205,'Kremlin','Kremlin, Oklahoma',29390,36);
INSERT INTO "django_geo_db_city" VALUES(24206,'Lahoma','Lahoma, Oklahoma',29391,36);
INSERT INTO "django_geo_db_city" VALUES(24207,'Longdale','Longdale, Oklahoma',29392,36);
INSERT INTO "django_geo_db_city" VALUES(24208,'Loyal','Loyal, Oklahoma',29393,36);
INSERT INTO "django_geo_db_city" VALUES(24209,'Lucien','Lucien, Oklahoma',29394,36);
INSERT INTO "django_geo_db_city" VALUES(24210,'Manchester','Manchester, Oklahoma',29395,36);
INSERT INTO "django_geo_db_city" VALUES(24211,'Medford','Medford, Oklahoma',29396,36);
INSERT INTO "django_geo_db_city" VALUES(24212,'Meno','Meno, Oklahoma',29397,36);
INSERT INTO "django_geo_db_city" VALUES(24213,'Nash','Nash, Oklahoma',29398,36);
INSERT INTO "django_geo_db_city" VALUES(24214,'Okarche','Okarche, Oklahoma',29399,36);
INSERT INTO "django_geo_db_city" VALUES(24215,'Okeene','Okeene, Oklahoma',29400,36);
INSERT INTO "django_geo_db_city" VALUES(24216,'Omega','Omega, Oklahoma',29401,36);
INSERT INTO "django_geo_db_city" VALUES(24217,'Pond Creek','Pond Creek, Oklahoma',29402,36);
INSERT INTO "django_geo_db_city" VALUES(24218,'Ringwood','Ringwood, Oklahoma',29403,36);
INSERT INTO "django_geo_db_city" VALUES(24219,'Southard','Southard, Oklahoma',29404,36);
INSERT INTO "django_geo_db_city" VALUES(24220,'Wakita','Wakita, Oklahoma',29405,36);
INSERT INTO "django_geo_db_city" VALUES(24221,'Watonga','Watonga, Oklahoma',29406,36);
INSERT INTO "django_geo_db_city" VALUES(24222,'Waukomis','Waukomis, Oklahoma',29407,36);
INSERT INTO "django_geo_db_city" VALUES(24223,'Woodward','Woodward, Oklahoma',29408,36);
INSERT INTO "django_geo_db_city" VALUES(24224,'Arnett','Arnett, Oklahoma',29410,36);
INSERT INTO "django_geo_db_city" VALUES(24225,'Buffalo','Buffalo, Oklahoma',29411,36);
INSERT INTO "django_geo_db_city" VALUES(24226,'Camargo','Camargo, Oklahoma',29412,36);
INSERT INTO "django_geo_db_city" VALUES(24227,'Chester','Chester, Oklahoma',29413,36);
INSERT INTO "django_geo_db_city" VALUES(24228,'Fargo','Fargo, Oklahoma',29414,36);
INSERT INTO "django_geo_db_city" VALUES(24229,'Fort Supply','Fort Supply, Oklahoma',29415,36);
INSERT INTO "django_geo_db_city" VALUES(24230,'Freedom','Freedom, Oklahoma',29416,36);
INSERT INTO "django_geo_db_city" VALUES(24231,'Gage','Gage, Oklahoma',29417,36);
INSERT INTO "django_geo_db_city" VALUES(24232,'Gate','Gate, Oklahoma',29418,36);
INSERT INTO "django_geo_db_city" VALUES(24233,'Knowles','Knowles, Oklahoma',29419,36);
INSERT INTO "django_geo_db_city" VALUES(24234,'Laverne','Laverne, Oklahoma',29420,36);
INSERT INTO "django_geo_db_city" VALUES(24235,'May','May, Oklahoma',29421,36);
INSERT INTO "django_geo_db_city" VALUES(24236,'Mooreland','Mooreland, Oklahoma',29422,36);
INSERT INTO "django_geo_db_city" VALUES(24237,'Mutual','Mutual, Oklahoma',29423,36);
INSERT INTO "django_geo_db_city" VALUES(24238,'Rosston','Rosston, Oklahoma',29424,36);
INSERT INTO "django_geo_db_city" VALUES(24239,'Sharon','Sharon, Oklahoma',29425,36);
INSERT INTO "django_geo_db_city" VALUES(24240,'Shattuck','Shattuck, Oklahoma',29426,36);
INSERT INTO "django_geo_db_city" VALUES(24241,'Vici','Vici, Oklahoma',29427,36);
INSERT INTO "django_geo_db_city" VALUES(24242,'Waynoka','Waynoka, Oklahoma',29428,36);
INSERT INTO "django_geo_db_city" VALUES(24243,'Adams','Adams, Oklahoma',29429,36);
INSERT INTO "django_geo_db_city" VALUES(24244,'Balko','Balko, Oklahoma',29430,36);
INSERT INTO "django_geo_db_city" VALUES(24245,'Beaver','Beaver, Oklahoma',29431,36);
INSERT INTO "django_geo_db_city" VALUES(24246,'Boise City','Boise City, Oklahoma',29432,36);
INSERT INTO "django_geo_db_city" VALUES(24247,'Felt','Felt, Oklahoma',29433,36);
INSERT INTO "django_geo_db_city" VALUES(24248,'Forgan','Forgan, Oklahoma',29434,36);
INSERT INTO "django_geo_db_city" VALUES(24249,'Goodwell','Goodwell, Oklahoma',29435,36);
INSERT INTO "django_geo_db_city" VALUES(24250,'Guymon','Guymon, Oklahoma',29436,36);
INSERT INTO "django_geo_db_city" VALUES(24251,'Hardesty','Hardesty, Oklahoma',29437,36);
INSERT INTO "django_geo_db_city" VALUES(24252,'Hooker','Hooker, Oklahoma',29438,36);
INSERT INTO "django_geo_db_city" VALUES(24253,'Kenton','Kenton, Oklahoma',29439,36);
INSERT INTO "django_geo_db_city" VALUES(24254,'Keyes','Keyes, Oklahoma',29440,36);
INSERT INTO "django_geo_db_city" VALUES(24255,'Texhoma','Texhoma, Oklahoma',29441,36);
INSERT INTO "django_geo_db_city" VALUES(24256,'Turpin','Turpin, Oklahoma',29442,36);
INSERT INTO "django_geo_db_city" VALUES(24257,'Tyrone','Tyrone, Oklahoma',29443,36);
INSERT INTO "django_geo_db_city" VALUES(24258,'Avant','Avant, Oklahoma',29444,36);
INSERT INTO "django_geo_db_city" VALUES(24259,'Barnsdall','Barnsdall, Oklahoma',29445,36);
INSERT INTO "django_geo_db_city" VALUES(24260,'Bartlesville','Bartlesville, Oklahoma',29446,36);
INSERT INTO "django_geo_db_city" VALUES(24261,'Bixby','Bixby, Oklahoma',29449,36);
INSERT INTO "django_geo_db_city" VALUES(24262,'Bowring','Bowring, Oklahoma',29450,36);
INSERT INTO "django_geo_db_city" VALUES(24263,'Bristow','Bristow, Oklahoma',29451,36);
INSERT INTO "django_geo_db_city" VALUES(24264,'Broken Arrow','Broken Arrow, Oklahoma',29452,36);
INSERT INTO "django_geo_db_city" VALUES(24265,'Catoosa','Catoosa, Oklahoma',29456,36);
INSERT INTO "django_geo_db_city" VALUES(24266,'Chelsea','Chelsea, Oklahoma',29457,36);
INSERT INTO "django_geo_db_city" VALUES(24267,'Claremore','Claremore, Oklahoma',29458,36);
INSERT INTO "django_geo_db_city" VALUES(24268,'Cleveland','Cleveland, Oklahoma',29460,36);
INSERT INTO "django_geo_db_city" VALUES(24269,'Collinsville','Collinsville, Oklahoma',29461,36);
INSERT INTO "django_geo_db_city" VALUES(24270,'Copan','Copan, Oklahoma',29462,36);
INSERT INTO "django_geo_db_city" VALUES(24271,'Cushing','Cushing, Oklahoma',29463,36);
INSERT INTO "django_geo_db_city" VALUES(24272,'Davenport','Davenport, Oklahoma',29464,36);
INSERT INTO "django_geo_db_city" VALUES(24273,'Delaware','Delaware, Oklahoma',29465,36);
INSERT INTO "django_geo_db_city" VALUES(24274,'Depew','Depew, Oklahoma',29466,36);
INSERT INTO "django_geo_db_city" VALUES(24275,'Dewey','Dewey, Oklahoma',29467,36);
INSERT INTO "django_geo_db_city" VALUES(24276,'Drumright','Drumright, Oklahoma',29468,36);
INSERT INTO "django_geo_db_city" VALUES(24277,'Foyil','Foyil, Oklahoma',29469,36);
INSERT INTO "django_geo_db_city" VALUES(24278,'Glencoe','Glencoe, Oklahoma',29470,36);
INSERT INTO "django_geo_db_city" VALUES(24279,'Glenpool','Glenpool, Oklahoma',29471,36);
INSERT INTO "django_geo_db_city" VALUES(24280,'Hallett','Hallett, Oklahoma',29472,36);
INSERT INTO "django_geo_db_city" VALUES(24281,'Hominy','Hominy, Oklahoma',29473,36);
INSERT INTO "django_geo_db_city" VALUES(24282,'Inola','Inola, Oklahoma',29474,36);
INSERT INTO "django_geo_db_city" VALUES(24283,'Jenks','Jenks, Oklahoma',29475,36);
INSERT INTO "django_geo_db_city" VALUES(24284,'Jennings','Jennings, Oklahoma',29476,36);
INSERT INTO "django_geo_db_city" VALUES(24285,'Kellyville','Kellyville, Oklahoma',29477,36);
INSERT INTO "django_geo_db_city" VALUES(24286,'Kiefer','Kiefer, Oklahoma',29478,36);
INSERT INTO "django_geo_db_city" VALUES(24287,'Lenapah','Lenapah, Oklahoma',29479,36);
INSERT INTO "django_geo_db_city" VALUES(24288,'Leonard','Leonard, Oklahoma',29480,36);
INSERT INTO "django_geo_db_city" VALUES(24289,'Mannford','Mannford, Oklahoma',29481,36);
INSERT INTO "django_geo_db_city" VALUES(24290,'Maramec','Maramec, Oklahoma',29482,36);
INSERT INTO "django_geo_db_city" VALUES(24291,'Milfay','Milfay, Oklahoma',29483,36);
INSERT INTO "django_geo_db_city" VALUES(24292,'Mounds','Mounds, Oklahoma',29484,36);
INSERT INTO "django_geo_db_city" VALUES(24293,'Nowata','Nowata, Oklahoma',29485,36);
INSERT INTO "django_geo_db_city" VALUES(24294,'Oakhurst','Oakhurst, Oklahoma',29486,36);
INSERT INTO "django_geo_db_city" VALUES(24295,'Ochelata','Ochelata, Oklahoma',29487,36);
INSERT INTO "django_geo_db_city" VALUES(24296,'Oilton','Oilton, Oklahoma',29488,36);
INSERT INTO "django_geo_db_city" VALUES(24297,'Oologah','Oologah, Oklahoma',29489,36);
INSERT INTO "django_geo_db_city" VALUES(24298,'Osage','Osage, Oklahoma',29490,36);
INSERT INTO "django_geo_db_city" VALUES(24299,'Owasso','Owasso, Oklahoma',29491,36);
INSERT INTO "django_geo_db_city" VALUES(24300,'Pawhuska','Pawhuska, Oklahoma',29492,36);
INSERT INTO "django_geo_db_city" VALUES(24301,'Pawnee','Pawnee, Oklahoma',29493,36);
INSERT INTO "django_geo_db_city" VALUES(24302,'Perkins','Perkins, Oklahoma',29494,36);
INSERT INTO "django_geo_db_city" VALUES(24303,'Prue','Prue, Oklahoma',29495,36);
INSERT INTO "django_geo_db_city" VALUES(24304,'Ramona','Ramona, Oklahoma',29496,36);
INSERT INTO "django_geo_db_city" VALUES(24305,'Ripley','Ripley, Oklahoma',29497,36);
INSERT INTO "django_geo_db_city" VALUES(24306,'Sand Springs','Sand Springs, Oklahoma',29498,36);
INSERT INTO "django_geo_db_city" VALUES(24307,'McCord','McCord, Oklahoma',29499,36);
INSERT INTO "django_geo_db_city" VALUES(24308,'Sapulpa','Sapulpa, Oklahoma',29500,36);
INSERT INTO "django_geo_db_city" VALUES(24309,'Shamrock','Shamrock, Oklahoma',29502,36);
INSERT INTO "django_geo_db_city" VALUES(24310,'Skiatook','Skiatook, Oklahoma',29503,36);
INSERT INTO "django_geo_db_city" VALUES(24311,'Slick','Slick, Oklahoma',29504,36);
INSERT INTO "django_geo_db_city" VALUES(24312,'S Coffeyville','S Coffeyville, Oklahoma',29505,36);
INSERT INTO "django_geo_db_city" VALUES(24313,'Sperry','Sperry, Oklahoma',29506,36);
INSERT INTO "django_geo_db_city" VALUES(24314,'Stillwater','Stillwater, Oklahoma',29507,36);
INSERT INTO "django_geo_db_city" VALUES(24315,'Stroud','Stroud, Oklahoma',29511,36);
INSERT INTO "django_geo_db_city" VALUES(24316,'Talala','Talala, Oklahoma',29512,36);
INSERT INTO "django_geo_db_city" VALUES(24317,'Terlton','Terlton, Oklahoma',29513,36);
INSERT INTO "django_geo_db_city" VALUES(24318,'Vera','Vera, Oklahoma',29514,36);
INSERT INTO "django_geo_db_city" VALUES(24319,'Wann','Wann, Oklahoma',29515,36);
INSERT INTO "django_geo_db_city" VALUES(24320,'Wynona','Wynona, Oklahoma',29516,36);
INSERT INTO "django_geo_db_city" VALUES(24321,'Yale','Yale, Oklahoma',29517,36);
INSERT INTO "django_geo_db_city" VALUES(24322,'Tulsa','Tulsa, Oklahoma',29518,36);
INSERT INTO "django_geo_db_city" VALUES(24323,'Vinita','Vinita, Oklahoma',29553,36);
INSERT INTO "django_geo_db_city" VALUES(24324,'Colcord','Colcord, Oklahoma',29554,36);
INSERT INTO "django_geo_db_city" VALUES(24325,'Adair','Adair, Oklahoma',29555,36);
INSERT INTO "django_geo_db_city" VALUES(24326,'Afton','Afton, Oklahoma',29556,36);
INSERT INTO "django_geo_db_city" VALUES(24327,'Big Cabin','Big Cabin, Oklahoma',29557,36);
INSERT INTO "django_geo_db_city" VALUES(24328,'Bluejacket','Bluejacket, Oklahoma',29558,36);
INSERT INTO "django_geo_db_city" VALUES(24329,'Dodge','Dodge, Oklahoma',29559,36);
INSERT INTO "django_geo_db_city" VALUES(24330,'Cardin','Cardin, Oklahoma',29560,36);
INSERT INTO "django_geo_db_city" VALUES(24331,'Jay','Jay, Oklahoma',29561,36);
INSERT INTO "django_geo_db_city" VALUES(24332,'Chouteau','Chouteau, Oklahoma',29562,36);
INSERT INTO "django_geo_db_city" VALUES(24333,'Commerce','Commerce, Oklahoma',29564,36);
INSERT INTO "django_geo_db_city" VALUES(24334,'Disney','Disney, Oklahoma',29565,36);
INSERT INTO "django_geo_db_city" VALUES(24335,'Eucha','Eucha, Oklahoma',29566,36);
INSERT INTO "django_geo_db_city" VALUES(24336,'Fairland','Fairland, Oklahoma',29567,36);
INSERT INTO "django_geo_db_city" VALUES(24337,'Grove','Grove, Oklahoma',29568,36);
INSERT INTO "django_geo_db_city" VALUES(24338,'Kansas','Kansas, Oklahoma',29571,36);
INSERT INTO "django_geo_db_city" VALUES(24339,'Ketchum','Ketchum, Oklahoma',29572,36);
INSERT INTO "django_geo_db_city" VALUES(24340,'Langley','Langley, Oklahoma',29573,36);
INSERT INTO "django_geo_db_city" VALUES(24341,'Locust Grove','Locust Grove, Oklahoma',29574,36);
INSERT INTO "django_geo_db_city" VALUES(24342,'Mazie','Mazie, Oklahoma',29575,36);
INSERT INTO "django_geo_db_city" VALUES(24343,'Miami','Miami, Oklahoma',29576,36);
INSERT INTO "django_geo_db_city" VALUES(24344,'North Miami','North Miami, Oklahoma',29578,36);
INSERT INTO "django_geo_db_city" VALUES(24345,'Oaks','Oaks, Oklahoma',29579,36);
INSERT INTO "django_geo_db_city" VALUES(24346,'Picher','Picher, Oklahoma',29580,36);
INSERT INTO "django_geo_db_city" VALUES(24347,'Pryor','Pryor, Oklahoma',29581,36);
INSERT INTO "django_geo_db_city" VALUES(24348,'Quapaw','Quapaw, Oklahoma',29582,36);
INSERT INTO "django_geo_db_city" VALUES(24349,'Rose','Rose, Oklahoma',29583,36);
INSERT INTO "django_geo_db_city" VALUES(24350,'Salina','Salina, Oklahoma',29584,36);
INSERT INTO "django_geo_db_city" VALUES(24351,'Spavinaw','Spavinaw, Oklahoma',29585,36);
INSERT INTO "django_geo_db_city" VALUES(24352,'Strang','Strang, Oklahoma',29586,36);
INSERT INTO "django_geo_db_city" VALUES(24353,'Twin Oaks','Twin Oaks, Oklahoma',29587,36);
INSERT INTO "django_geo_db_city" VALUES(24354,'Welch','Welch, Oklahoma',29588,36);
INSERT INTO "django_geo_db_city" VALUES(24355,'Wyandotte','Wyandotte, Oklahoma',29589,36);
INSERT INTO "django_geo_db_city" VALUES(24356,'Muskogee','Muskogee, Oklahoma',29591,36);
INSERT INTO "django_geo_db_city" VALUES(24357,'Beggs','Beggs, Oklahoma',29594,36);
INSERT INTO "django_geo_db_city" VALUES(24358,'Boynton','Boynton, Oklahoma',29595,36);
INSERT INTO "django_geo_db_city" VALUES(24359,'Braggs','Braggs, Oklahoma',29596,36);
INSERT INTO "django_geo_db_city" VALUES(24360,'Canadian','Canadian, Oklahoma',29597,36);
INSERT INTO "django_geo_db_city" VALUES(24361,'Checotah','Checotah, Oklahoma',29598,36);
INSERT INTO "django_geo_db_city" VALUES(24362,'Cookson','Cookson, Oklahoma',29599,36);
INSERT INTO "django_geo_db_city" VALUES(24363,'Council Hill','Council Hill, Oklahoma',29600,36);
INSERT INTO "django_geo_db_city" VALUES(24364,'Coweta','Coweta, Oklahoma',29601,36);
INSERT INTO "django_geo_db_city" VALUES(24365,'Crowder','Crowder, Oklahoma',29602,36);
INSERT INTO "django_geo_db_city" VALUES(24366,'Dewar','Dewar, Oklahoma',29603,36);
INSERT INTO "django_geo_db_city" VALUES(24367,'Eufaula','Eufaula, Oklahoma',29604,36);
INSERT INTO "django_geo_db_city" VALUES(24368,'Fort Gibson','Fort Gibson, Oklahoma',29605,36);
INSERT INTO "django_geo_db_city" VALUES(24369,'Gore','Gore, Oklahoma',29606,36);
INSERT INTO "django_geo_db_city" VALUES(24370,'Haskell','Haskell, Oklahoma',29607,36);
INSERT INTO "django_geo_db_city" VALUES(24371,'Henryetta','Henryetta, Oklahoma',29608,36);
INSERT INTO "django_geo_db_city" VALUES(24372,'Hitchita','Hitchita, Oklahoma',29609,36);
INSERT INTO "django_geo_db_city" VALUES(24373,'Hoyt','Hoyt, Oklahoma',29610,36);
INSERT INTO "django_geo_db_city" VALUES(24374,'Hulbert','Hulbert, Oklahoma',29611,36);
INSERT INTO "django_geo_db_city" VALUES(24375,'Indianola','Indianola, Oklahoma',29612,36);
INSERT INTO "django_geo_db_city" VALUES(24376,'Moodys','Moodys, Oklahoma',29613,36);
INSERT INTO "django_geo_db_city" VALUES(24377,'Morris','Morris, Oklahoma',29614,36);
INSERT INTO "django_geo_db_city" VALUES(24378,'Okay','Okay, Oklahoma',29615,36);
INSERT INTO "django_geo_db_city" VALUES(24379,'Okmulgee','Okmulgee, Oklahoma',29616,36);
INSERT INTO "django_geo_db_city" VALUES(24380,'Oktaha','Oktaha, Oklahoma',29617,36);
INSERT INTO "django_geo_db_city" VALUES(24381,'Park Hill','Park Hill, Oklahoma',29618,36);
INSERT INTO "django_geo_db_city" VALUES(24382,'Peggs','Peggs, Oklahoma',29619,36);
INSERT INTO "django_geo_db_city" VALUES(24383,'Porter','Porter, Oklahoma',29620,36);
INSERT INTO "django_geo_db_city" VALUES(24384,'Porum','Porum, Oklahoma',29621,36);
INSERT INTO "django_geo_db_city" VALUES(24385,'Preston','Preston, Oklahoma',29622,36);
INSERT INTO "django_geo_db_city" VALUES(24386,'Proctor','Proctor, Oklahoma',29623,36);
INSERT INTO "django_geo_db_city" VALUES(24387,'Redbird','Redbird, Oklahoma',29624,36);
INSERT INTO "django_geo_db_city" VALUES(24388,'Rentiesville','Rentiesville, Oklahoma',29625,36);
INSERT INTO "django_geo_db_city" VALUES(24389,'Schulter','Schulter, Oklahoma',29626,36);
INSERT INTO "django_geo_db_city" VALUES(24390,'Stidham','Stidham, Oklahoma',29627,36);
INSERT INTO "django_geo_db_city" VALUES(24391,'Stigler','Stigler, Oklahoma',29628,36);
INSERT INTO "django_geo_db_city" VALUES(24392,'Taft','Taft, Oklahoma',29629,36);
INSERT INTO "django_geo_db_city" VALUES(24393,'Tahlequah','Tahlequah, Oklahoma',29630,36);
INSERT INTO "django_geo_db_city" VALUES(24394,'Tullahassee','Tullahassee, Oklahoma',29624,36);
INSERT INTO "django_geo_db_city" VALUES(24395,'Wagoner','Wagoner, Oklahoma',29632,36);
INSERT INTO "django_geo_db_city" VALUES(24396,'Wainwright','Wainwright, Oklahoma',29633,36);
INSERT INTO "django_geo_db_city" VALUES(24397,'Warner','Warner, Oklahoma',29634,36);
INSERT INTO "django_geo_db_city" VALUES(24398,'Webbers Falls','Webbers Falls, Oklahoma',29635,36);
INSERT INTO "django_geo_db_city" VALUES(24399,'Welling','Welling, Oklahoma',29636,36);
INSERT INTO "django_geo_db_city" VALUES(24400,'Whitefield','Whitefield, Oklahoma',29637,36);
INSERT INTO "django_geo_db_city" VALUES(24401,'Mcalester','Mcalester, Oklahoma',29638,36);
INSERT INTO "django_geo_db_city" VALUES(24402,'Ada','Ada, Oklahoma',29640,36);
INSERT INTO "django_geo_db_city" VALUES(24403,'Albion','Albion, Oklahoma',29641,36);
INSERT INTO "django_geo_db_city" VALUES(24404,'Alderson','Alderson, Oklahoma',29642,36);
INSERT INTO "django_geo_db_city" VALUES(24405,'Antlers','Antlers, Oklahoma',29643,36);
INSERT INTO "django_geo_db_city" VALUES(24406,'Atoka','Atoka, Oklahoma',29644,36);
INSERT INTO "django_geo_db_city" VALUES(24407,'Blanco','Blanco, Oklahoma',29645,36);
INSERT INTO "django_geo_db_city" VALUES(24408,'Blocker','Blocker, Oklahoma',29639,36);
INSERT INTO "django_geo_db_city" VALUES(24409,'Bromide','Bromide, Oklahoma',29646,36);
INSERT INTO "django_geo_db_city" VALUES(24410,'Calvin','Calvin, Oklahoma',29647,36);
INSERT INTO "django_geo_db_city" VALUES(24411,'Caney','Caney, Oklahoma',29648,36);
INSERT INTO "django_geo_db_city" VALUES(24412,'Centrahoma','Centrahoma, Oklahoma',29649,36);
INSERT INTO "django_geo_db_city" VALUES(24413,'Clarita','Clarita, Oklahoma',29650,36);
INSERT INTO "django_geo_db_city" VALUES(24414,'Clayton','Clayton, Oklahoma',29651,36);
INSERT INTO "django_geo_db_city" VALUES(24415,'Coalgate','Coalgate, Oklahoma',29652,36);
INSERT INTO "django_geo_db_city" VALUES(24416,'Daisy','Daisy, Oklahoma',29653,36);
INSERT INTO "django_geo_db_city" VALUES(24417,'Finley','Finley, Oklahoma',29655,36);
INSERT INTO "django_geo_db_city" VALUES(24418,'Gowen','Gowen, Oklahoma',29656,36);
INSERT INTO "django_geo_db_city" VALUES(24419,'Haileyville','Haileyville, Oklahoma',29657,36);
INSERT INTO "django_geo_db_city" VALUES(24420,'Hartshorne','Hartshorne, Oklahoma',29658,36);
INSERT INTO "django_geo_db_city" VALUES(24421,'Honobia','Honobia, Oklahoma',29659,36);
INSERT INTO "django_geo_db_city" VALUES(24422,'Kinta','Kinta, Oklahoma',29660,36);
INSERT INTO "django_geo_db_city" VALUES(24423,'Kiowa','Kiowa, Oklahoma',29661,36);
INSERT INTO "django_geo_db_city" VALUES(24424,'Krebs','Krebs, Oklahoma',29662,36);
INSERT INTO "django_geo_db_city" VALUES(24425,'Lane','Lane, Oklahoma',29663,36);
INSERT INTO "django_geo_db_city" VALUES(24426,'Lehigh','Lehigh, Oklahoma',29664,36);
INSERT INTO "django_geo_db_city" VALUES(24427,'Moyers','Moyers, Oklahoma',29665,36);
INSERT INTO "django_geo_db_city" VALUES(24428,'Nashoba','Nashoba, Oklahoma',29666,36);
INSERT INTO "django_geo_db_city" VALUES(24429,'Panola','Panola, Oklahoma',29667,36);
INSERT INTO "django_geo_db_city" VALUES(24430,'Pittsburg','Pittsburg, Oklahoma',29668,36);
INSERT INTO "django_geo_db_city" VALUES(24431,'Quinton','Quinton, Oklahoma',29669,36);
INSERT INTO "django_geo_db_city" VALUES(24432,'Rattan','Rattan, Oklahoma',29670,36);
INSERT INTO "django_geo_db_city" VALUES(24433,'Red Oak','Red Oak, Oklahoma',29671,36);
INSERT INTO "django_geo_db_city" VALUES(24434,'Savanna','Savanna, Oklahoma',29672,36);
INSERT INTO "django_geo_db_city" VALUES(24435,'Snow','Snow, Oklahoma',29673,36);
INSERT INTO "django_geo_db_city" VALUES(24436,'Stringtown','Stringtown, Oklahoma',29674,36);
INSERT INTO "django_geo_db_city" VALUES(24437,'Stuart','Stuart, Oklahoma',29675,36);
INSERT INTO "django_geo_db_city" VALUES(24438,'Talihina','Talihina, Oklahoma',29676,36);
INSERT INTO "django_geo_db_city" VALUES(24439,'Tupelo','Tupelo, Oklahoma',29677,36);
INSERT INTO "django_geo_db_city" VALUES(24440,'Tuskahoma','Tuskahoma, Oklahoma',29678,36);
INSERT INTO "django_geo_db_city" VALUES(24441,'Wardville','Wardville, Oklahoma',29679,36);
INSERT INTO "django_geo_db_city" VALUES(24442,'Whitesboro','Whitesboro, Oklahoma',29680,36);
INSERT INTO "django_geo_db_city" VALUES(24443,'Wilburton','Wilburton, Oklahoma',29681,36);
INSERT INTO "django_geo_db_city" VALUES(24444,'Ponca City','Ponca City, Oklahoma',29682,36);
INSERT INTO "django_geo_db_city" VALUES(24445,'Billings','Billings, Oklahoma',29686,36);
INSERT INTO "django_geo_db_city" VALUES(24446,'Blackwell','Blackwell, Oklahoma',29687,36);
INSERT INTO "django_geo_db_city" VALUES(24447,'Braman','Braman, Oklahoma',29688,36);
INSERT INTO "django_geo_db_city" VALUES(24448,'Burbank','Burbank, Oklahoma',29689,36);
INSERT INTO "django_geo_db_city" VALUES(24449,'Deer Creek','Deer Creek, Oklahoma',29690,36);
INSERT INTO "django_geo_db_city" VALUES(24450,'Fairfax','Fairfax, Oklahoma',29691,36);
INSERT INTO "django_geo_db_city" VALUES(24451,'Hunter','Hunter, Oklahoma',29692,36);
INSERT INTO "django_geo_db_city" VALUES(24452,'Kaw City','Kaw City, Oklahoma',29693,36);
INSERT INTO "django_geo_db_city" VALUES(24453,'Lamont','Lamont, Oklahoma',29694,36);
INSERT INTO "django_geo_db_city" VALUES(24454,'Marland','Marland, Oklahoma',29695,36);
INSERT INTO "django_geo_db_city" VALUES(24455,'Nardin','Nardin, Oklahoma',29696,36);
INSERT INTO "django_geo_db_city" VALUES(24456,'Newkirk','Newkirk, Oklahoma',29697,36);
INSERT INTO "django_geo_db_city" VALUES(24457,'Ralston','Ralston, Oklahoma',29698,36);
INSERT INTO "django_geo_db_city" VALUES(24458,'Red Rock','Red Rock, Oklahoma',29699,36);
INSERT INTO "django_geo_db_city" VALUES(24459,'Shidler','Shidler, Oklahoma',29700,36);
INSERT INTO "django_geo_db_city" VALUES(24460,'Tonkawa','Tonkawa, Oklahoma',29701,36);
INSERT INTO "django_geo_db_city" VALUES(24461,'Durant','Durant, Oklahoma',29702,36);
INSERT INTO "django_geo_db_city" VALUES(24462,'Achille','Achille, Oklahoma',29704,36);
INSERT INTO "django_geo_db_city" VALUES(24463,'Albany','Albany, Oklahoma',29705,36);
INSERT INTO "django_geo_db_city" VALUES(24464,'Battiest','Battiest, Oklahoma',29706,36);
INSERT INTO "django_geo_db_city" VALUES(24465,'Bennington','Bennington, Oklahoma',29707,36);
INSERT INTO "django_geo_db_city" VALUES(24466,'Bethel','Bethel, Oklahoma',29708,36);
INSERT INTO "django_geo_db_city" VALUES(24467,'Bokchito','Bokchito, Oklahoma',29709,36);
INSERT INTO "django_geo_db_city" VALUES(24468,'Boswell','Boswell, Oklahoma',29710,36);
INSERT INTO "django_geo_db_city" VALUES(24469,'Broken Bow','Broken Bow, Oklahoma',29711,36);
INSERT INTO "django_geo_db_city" VALUES(24470,'Caddo','Caddo, Oklahoma',29712,36);
INSERT INTO "django_geo_db_city" VALUES(24471,'Calera','Calera, Oklahoma',29713,36);
INSERT INTO "django_geo_db_city" VALUES(24472,'Cartwright','Cartwright, Oklahoma',29714,36);
INSERT INTO "django_geo_db_city" VALUES(24473,'Colbert','Colbert, Oklahoma',29715,36);
INSERT INTO "django_geo_db_city" VALUES(24474,'Eagletown','Eagletown, Oklahoma',29716,36);
INSERT INTO "django_geo_db_city" VALUES(24475,'Fort Towson','Fort Towson, Oklahoma',29717,36);
INSERT INTO "django_geo_db_city" VALUES(24476,'Garvin','Garvin, Oklahoma',29718,36);
INSERT INTO "django_geo_db_city" VALUES(24477,'Golden','Golden, Oklahoma',29719,36);
INSERT INTO "django_geo_db_city" VALUES(24478,'Grant','Grant, Oklahoma',29720,36);
INSERT INTO "django_geo_db_city" VALUES(24479,'Haworth','Haworth, Oklahoma',29721,36);
INSERT INTO "django_geo_db_city" VALUES(24480,'Hendrix','Hendrix, Oklahoma',29722,36);
INSERT INTO "django_geo_db_city" VALUES(24481,'Hugo','Hugo, Oklahoma',29723,36);
INSERT INTO "django_geo_db_city" VALUES(24482,'Idabel','Idabel, Oklahoma',29724,36);
INSERT INTO "django_geo_db_city" VALUES(24483,'Kemp','Kemp, Oklahoma',29725,36);
INSERT INTO "django_geo_db_city" VALUES(24484,'Kenefic','Kenefic, Oklahoma',29726,36);
INSERT INTO "django_geo_db_city" VALUES(24485,'Millerton','Millerton, Oklahoma',29727,36);
INSERT INTO "django_geo_db_city" VALUES(24486,'Pickens','Pickens, Oklahoma',29728,36);
INSERT INTO "django_geo_db_city" VALUES(24487,'Platter','Platter, Oklahoma',29729,36);
INSERT INTO "django_geo_db_city" VALUES(24488,'Ringold','Ringold, Oklahoma',29730,36);
INSERT INTO "django_geo_db_city" VALUES(24489,'Rufe','Rufe, Oklahoma',29731,36);
INSERT INTO "django_geo_db_city" VALUES(24490,'Sawyer','Sawyer, Oklahoma',29732,36);
INSERT INTO "django_geo_db_city" VALUES(24491,'Soper','Soper, Oklahoma',29733,36);
INSERT INTO "django_geo_db_city" VALUES(24492,'Spencerville','Spencerville, Oklahoma',29734,36);
INSERT INTO "django_geo_db_city" VALUES(24493,'Swink','Swink, Oklahoma',29735,36);
INSERT INTO "django_geo_db_city" VALUES(24494,'Valliant','Valliant, Oklahoma',29736,36);
INSERT INTO "django_geo_db_city" VALUES(24495,'Wright City','Wright City, Oklahoma',29737,36);
INSERT INTO "django_geo_db_city" VALUES(24496,'Shawnee','Shawnee, Oklahoma',29738,36);
INSERT INTO "django_geo_db_city" VALUES(24497,'Seminole','Seminole, Oklahoma',29742,36);
INSERT INTO "django_geo_db_city" VALUES(24498,'Agra','Agra, Oklahoma',29745,36);
INSERT INTO "django_geo_db_city" VALUES(24499,'Allen','Allen, Oklahoma',29746,36);
INSERT INTO "django_geo_db_city" VALUES(24500,'Asher','Asher, Oklahoma',29747,36);
INSERT INTO "django_geo_db_city" VALUES(24501,'Atwood','Atwood, Oklahoma',29748,36);
INSERT INTO "django_geo_db_city" VALUES(24502,'Boley','Boley, Oklahoma',29749,36);
INSERT INTO "django_geo_db_city" VALUES(24503,'Bowlegs','Bowlegs, Oklahoma',29750,36);
INSERT INTO "django_geo_db_city" VALUES(24504,'Byars','Byars, Oklahoma',29751,36);
INSERT INTO "django_geo_db_city" VALUES(24505,'Carney','Carney, Oklahoma',29752,36);
INSERT INTO "django_geo_db_city" VALUES(24506,'Castle','Castle, Oklahoma',29753,36);
INSERT INTO "django_geo_db_city" VALUES(24507,'Chandler','Chandler, Oklahoma',29754,36);
INSERT INTO "django_geo_db_city" VALUES(24508,'Connerville','Connerville, Oklahoma',29755,36);
INSERT INTO "django_geo_db_city" VALUES(24509,'Cromwell','Cromwell, Oklahoma',29756,36);
INSERT INTO "django_geo_db_city" VALUES(24510,'Dustin','Dustin, Oklahoma',29757,36);
INSERT INTO "django_geo_db_city" VALUES(24511,'Earlsboro','Earlsboro, Oklahoma',29758,36);
INSERT INTO "django_geo_db_city" VALUES(24512,'Fittstown','Fittstown, Oklahoma',29759,36);
INSERT INTO "django_geo_db_city" VALUES(24513,'Fitzhugh','Fitzhugh, Oklahoma',29760,36);
INSERT INTO "django_geo_db_city" VALUES(24514,'Francis','Francis, Oklahoma',29761,36);
INSERT INTO "django_geo_db_city" VALUES(24515,'Hanna','Hanna, Oklahoma',29762,36);
INSERT INTO "django_geo_db_city" VALUES(24516,'Holdenville','Holdenville, Oklahoma',29763,36);
INSERT INTO "django_geo_db_city" VALUES(24517,'Konawa','Konawa, Oklahoma',29764,36);
INSERT INTO "django_geo_db_city" VALUES(24518,'Lamar','Lamar, Oklahoma',29765,36);
INSERT INTO "django_geo_db_city" VALUES(24519,'Mcloud','Mcloud, Oklahoma',29766,36);
INSERT INTO "django_geo_db_city" VALUES(24520,'Macomb','Macomb, Oklahoma',29767,36);
INSERT INTO "django_geo_db_city" VALUES(24521,'Wetumka','Wetumka, Oklahoma',29768,36);
INSERT INTO "django_geo_db_city" VALUES(24522,'Maud','Maud, Oklahoma',29769,36);
INSERT INTO "django_geo_db_city" VALUES(24523,'Meeker','Meeker, Oklahoma',29770,36);
INSERT INTO "django_geo_db_city" VALUES(24524,'Mill Creek','Mill Creek, Oklahoma',29771,36);
INSERT INTO "django_geo_db_city" VALUES(24525,'Newalla','Newalla, Oklahoma',29772,36);
INSERT INTO "django_geo_db_city" VALUES(24526,'Okemah','Okemah, Oklahoma',29773,36);
INSERT INTO "django_geo_db_city" VALUES(24527,'Paden','Paden, Oklahoma',29774,36);
INSERT INTO "django_geo_db_city" VALUES(24528,'Prague','Prague, Oklahoma',29775,36);
INSERT INTO "django_geo_db_city" VALUES(24529,'Roff','Roff, Oklahoma',29776,36);
INSERT INTO "django_geo_db_city" VALUES(24530,'Saint Louis','Saint Louis, Oklahoma',29777,36);
INSERT INTO "django_geo_db_city" VALUES(24531,'Sasakwa','Sasakwa, Oklahoma',29778,36);
INSERT INTO "django_geo_db_city" VALUES(24532,'Sparks','Sparks, Oklahoma',29780,36);
INSERT INTO "django_geo_db_city" VALUES(24533,'Stonewall','Stonewall, Oklahoma',29781,36);
INSERT INTO "django_geo_db_city" VALUES(24534,'Stratford','Stratford, Oklahoma',29782,36);
INSERT INTO "django_geo_db_city" VALUES(24535,'Tecumseh','Tecumseh, Oklahoma',29783,36);
INSERT INTO "django_geo_db_city" VALUES(24536,'Tryon','Tryon, Oklahoma',29784,36);
INSERT INTO "django_geo_db_city" VALUES(24537,'Wanette','Wanette, Oklahoma',29785,36);
INSERT INTO "django_geo_db_city" VALUES(24538,'Weleetka','Weleetka, Oklahoma',29786,36);
INSERT INTO "django_geo_db_city" VALUES(24539,'Wellston','Wellston, Oklahoma',29787,36);
INSERT INTO "django_geo_db_city" VALUES(24540,'Wewoka','Wewoka, Oklahoma',29789,36);
INSERT INTO "django_geo_db_city" VALUES(24541,'Arkoma','Arkoma, Oklahoma',29791,36);
INSERT INTO "django_geo_db_city" VALUES(24542,'Pocola','Pocola, Oklahoma',29792,36);
INSERT INTO "django_geo_db_city" VALUES(24543,'Bokoshe','Bokoshe, Oklahoma',29793,36);
INSERT INTO "django_geo_db_city" VALUES(24544,'Bunch','Bunch, Oklahoma',29794,36);
INSERT INTO "django_geo_db_city" VALUES(24545,'Cameron','Cameron, Oklahoma',29795,36);
INSERT INTO "django_geo_db_city" VALUES(24546,'Fanshawe','Fanshawe, Oklahoma',29796,36);
INSERT INTO "django_geo_db_city" VALUES(24547,'Gans','Gans, Oklahoma',29797,36);
INSERT INTO "django_geo_db_city" VALUES(24548,'Heavener','Heavener, Oklahoma',29798,36);
INSERT INTO "django_geo_db_city" VALUES(24549,'Hodgen','Hodgen, Oklahoma',29799,36);
INSERT INTO "django_geo_db_city" VALUES(24550,'Howe','Howe, Oklahoma',29800,36);
INSERT INTO "django_geo_db_city" VALUES(24551,'Keota','Keota, Oklahoma',29801,36);
INSERT INTO "django_geo_db_city" VALUES(24552,'Leflore','Leflore, Oklahoma',29802,36);
INSERT INTO "django_geo_db_city" VALUES(24553,'Lequire','Lequire, Oklahoma',29803,36);
INSERT INTO "django_geo_db_city" VALUES(24554,'Mccurtain','Mccurtain, Oklahoma',29804,36);
INSERT INTO "django_geo_db_city" VALUES(24555,'Marble City','Marble City, Oklahoma',29805,36);
INSERT INTO "django_geo_db_city" VALUES(24556,'Moffett','Moffett, Oklahoma',29806,36);
INSERT INTO "django_geo_db_city" VALUES(24557,'Monroe','Monroe, Oklahoma',29807,36);
INSERT INTO "django_geo_db_city" VALUES(24558,'Muldrow','Muldrow, Oklahoma',29808,36);
INSERT INTO "django_geo_db_city" VALUES(24559,'Muse','Muse, Oklahoma',29809,36);
INSERT INTO "django_geo_db_city" VALUES(24560,'Panama','Panama, Oklahoma',29810,36);
INSERT INTO "django_geo_db_city" VALUES(24561,'Poteau','Poteau, Oklahoma',29811,36);
INSERT INTO "django_geo_db_city" VALUES(24562,'Roland','Roland, Oklahoma',29812,36);
INSERT INTO "django_geo_db_city" VALUES(24563,'Sallisaw','Sallisaw, Oklahoma',29813,36);
INSERT INTO "django_geo_db_city" VALUES(24564,'Shady Point','Shady Point, Oklahoma',29814,36);
INSERT INTO "django_geo_db_city" VALUES(24565,'Smithville','Smithville, Oklahoma',29815,36);
INSERT INTO "django_geo_db_city" VALUES(24566,'Spiro','Spiro, Oklahoma',29816,36);
INSERT INTO "django_geo_db_city" VALUES(24567,'Stilwell','Stilwell, Oklahoma',29817,36);
INSERT INTO "django_geo_db_city" VALUES(24568,'Vian','Vian, Oklahoma',29818,36);
INSERT INTO "django_geo_db_city" VALUES(24569,'Watson','Watson, Oklahoma',29819,36);
INSERT INTO "django_geo_db_city" VALUES(24570,'Watts','Watts, Oklahoma',29820,36);
INSERT INTO "django_geo_db_city" VALUES(24571,'Westville','Westville, Oklahoma',29821,36);
INSERT INTO "django_geo_db_city" VALUES(24572,'Wister','Wister, Oklahoma',29822,36);
INSERT INTO "django_geo_db_city" VALUES(24573,'Addison','Addison, Texas',29824,51);
INSERT INTO "django_geo_db_city" VALUES(24574,'Allen','Allen, Texas',29825,51);
INSERT INTO "django_geo_db_city" VALUES(24575,'Carrollton','Carrollton, Texas',29826,51);
INSERT INTO "django_geo_db_city" VALUES(24576,'Celina','Celina, Texas',29829,51);
INSERT INTO "django_geo_db_city" VALUES(24577,'Irving','Irving, Texas',29831,51);
INSERT INTO "django_geo_db_city" VALUES(24578,'Coppell','Coppell, Texas',29833,51);
INSERT INTO "django_geo_db_city" VALUES(24579,'Denison','Denison, Texas',29834,51);
INSERT INTO "django_geo_db_city" VALUES(24580,'Flower Mound','Flower Mound, Texas',29836,51);
INSERT INTO "django_geo_db_city" VALUES(24581,'Plano','Plano, Texas',29837,51);
INSERT INTO "django_geo_db_city" VALUES(24582,'Lewisville','Lewisville, Texas',29828,51);
INSERT INTO "django_geo_db_city" VALUES(24583,'Rowlett','Rowlett, Texas',29842,51);
INSERT INTO "django_geo_db_city" VALUES(24584,'Rockwall','Rockwall, Texas',29843,51);
INSERT INTO "django_geo_db_city" VALUES(24585,'Frisco','Frisco, Texas',29844,51);
INSERT INTO "django_geo_db_city" VALUES(24586,'Garland','Garland, Texas',29848,51);
INSERT INTO "django_geo_db_city" VALUES(24587,'Grand Prairie','Grand Prairie, Texas',29855,51);
INSERT INTO "django_geo_db_city" VALUES(24588,'The Colony','The Colony, Texas',29858,51);
INSERT INTO "django_geo_db_city" VALUES(24589,'Gunter','Gunter, Texas',29860,51);
INSERT INTO "django_geo_db_city" VALUES(24590,'Lake Dallas','Lake Dallas, Texas',29866,51);
INSERT INTO "django_geo_db_city" VALUES(24591,'Little Elm','Little Elm, Texas',29869,51);
INSERT INTO "django_geo_db_city" VALUES(24592,'McKinney','McKinney, Texas',29870,51);
INSERT INTO "django_geo_db_city" VALUES(24593,'Pottsboro','Pottsboro, Texas',29875,51);
INSERT INTO "django_geo_db_city" VALUES(24594,'Prosper','Prosper, Texas',29877,51);
INSERT INTO "django_geo_db_city" VALUES(24595,'Richardson','Richardson, Texas',29878,51);
INSERT INTO "django_geo_db_city" VALUES(24596,'Sherman','Sherman, Texas',29885,51);
INSERT INTO "django_geo_db_city" VALUES(24597,'Weston','Weston, Texas',29890,51);
INSERT INTO "django_geo_db_city" VALUES(24598,'Wylie','Wylie, Texas',29891,51);
INSERT INTO "django_geo_db_city" VALUES(24599,'Bardwell','Bardwell, Texas',29893,51);
INSERT INTO "django_geo_db_city" VALUES(24600,'Barry','Barry, Texas',29894,51);
INSERT INTO "django_geo_db_city" VALUES(24601,'Canton','Canton, Texas',29895,51);
INSERT INTO "django_geo_db_city" VALUES(24602,'Cedar Hill','Cedar Hill, Texas',29896,51);
INSERT INTO "django_geo_db_city" VALUES(24603,'Chatfield','Chatfield, Texas',29897,51);
INSERT INTO "django_geo_db_city" VALUES(24604,'Angus','Angus, Texas',29898,51);
INSERT INTO "django_geo_db_city" VALUES(24605,'Corsicana','Corsicana, Texas',29899,51);
INSERT INTO "django_geo_db_city" VALUES(24606,'Crandall','Crandall, Texas',29900,51);
INSERT INTO "django_geo_db_city" VALUES(24607,'Desoto','Desoto, Texas',29901,51);
INSERT INTO "django_geo_db_city" VALUES(24608,'Duncanville','Duncanville, Texas',29902,51);
INSERT INTO "django_geo_db_city" VALUES(24609,'Edgewood','Edgewood, Texas',29903,51);
INSERT INTO "django_geo_db_city" VALUES(24610,'Elmo','Elmo, Texas',29904,51);
INSERT INTO "django_geo_db_city" VALUES(24611,'Ennis','Ennis, Texas',29905,51);
INSERT INTO "django_geo_db_city" VALUES(24612,'Copeville','Copeville, Texas',29907,51);
INSERT INTO "django_geo_db_city" VALUES(24613,'Eustace','Eustace, Texas',29908,51);
INSERT INTO "django_geo_db_city" VALUES(24614,'Ferris','Ferris, Texas',29909,51);
INSERT INTO "django_geo_db_city" VALUES(24615,'Forney','Forney, Texas',29910,51);
INSERT INTO "django_geo_db_city" VALUES(24616,'Fruitvale','Fruitvale, Texas',29911,51);
INSERT INTO "django_geo_db_city" VALUES(24617,'Fate','Fate, Texas',29912,51);
INSERT INTO "django_geo_db_city" VALUES(24618,'Lancaster','Lancaster, Texas',29913,51);
INSERT INTO "django_geo_db_city" VALUES(24619,'Caddo Mills','Caddo Mills, Texas',29914,51);
INSERT INTO "django_geo_db_city" VALUES(24620,'Grand Saline','Grand Saline, Texas',29916,51);
INSERT INTO "django_geo_db_city" VALUES(24621,'Hutchins','Hutchins, Texas',29917,51);
INSERT INTO "django_geo_db_city" VALUES(24622,'Kaufman','Kaufman, Texas',29918,51);
INSERT INTO "django_geo_db_city" VALUES(24623,'Kemp','Kemp, Texas',29919,51);
INSERT INTO "django_geo_db_city" VALUES(24624,'Kerens','Kerens, Texas',29920,51);
INSERT INTO "django_geo_db_city" VALUES(24625,'Mabank','Mabank, Texas',29922,51);
INSERT INTO "django_geo_db_city" VALUES(24626,'Malakoff','Malakoff, Texas',29923,51);
INSERT INTO "django_geo_db_city" VALUES(24627,'Mesquite','Mesquite, Texas',29924,51);
INSERT INTO "django_geo_db_city" VALUES(24628,'Palmer','Palmer, Texas',29927,51);
INSERT INTO "django_geo_db_city" VALUES(24629,'Powell','Powell, Texas',29928,51);
INSERT INTO "django_geo_db_city" VALUES(24630,'Red Oak','Red Oak, Texas',29929,51);
INSERT INTO "django_geo_db_city" VALUES(24631,'Rice','Rice, Texas',29930,51);
INSERT INTO "django_geo_db_city" VALUES(24632,'Gun Barrel City','Gun Barrel City, Texas',29931,51);
INSERT INTO "django_geo_db_city" VALUES(24633,'Rosser','Rosser, Texas',29932,51);
INSERT INTO "django_geo_db_city" VALUES(24634,'Scurry','Scurry, Texas',29933,51);
INSERT INTO "django_geo_db_city" VALUES(24635,'Seagoville','Seagoville, Texas',29934,51);
INSERT INTO "django_geo_db_city" VALUES(24636,'Terrell','Terrell, Texas',29935,51);
INSERT INTO "django_geo_db_city" VALUES(24637,'Trinidad','Trinidad, Texas',29937,51);
INSERT INTO "django_geo_db_city" VALUES(24638,'Josephine','Josephine, Texas',29938,51);
INSERT INTO "django_geo_db_city" VALUES(24639,'Waxahachie','Waxahachie, Texas',29939,51);
INSERT INTO "django_geo_db_city" VALUES(24640,'Lavon','Lavon, Texas',29940,51);
INSERT INTO "django_geo_db_city" VALUES(24641,'Wills Point','Wills Point, Texas',29943,51);
INSERT INTO "django_geo_db_city" VALUES(24642,'Wilmer','Wilmer, Texas',29944,51);
INSERT INTO "django_geo_db_city" VALUES(24643,'Nevada','Nevada, Texas',29945,51);
INSERT INTO "django_geo_db_city" VALUES(24644,'Sunnyvale','Sunnyvale, Texas',29948,51);
INSERT INTO "django_geo_db_city" VALUES(24645,'Royse City','Royse City, Texas',29950,51);
INSERT INTO "django_geo_db_city" VALUES(24646,'Dallas','Dallas, Texas',29951,51);
INSERT INTO "django_geo_db_city" VALUES(24647,'Greenville','Greenville, Texas',30003,51);
INSERT INTO "django_geo_db_city" VALUES(24648,'Princeton','Princeton, Texas',30007,51);
INSERT INTO "django_geo_db_city" VALUES(24649,'Anna','Anna, Texas',30008,51);
INSERT INTO "django_geo_db_city" VALUES(24650,'Alba','Alba, Texas',30010,51);
INSERT INTO "django_geo_db_city" VALUES(24651,'Arthur City','Arthur City, Texas',30011,51);
INSERT INTO "django_geo_db_city" VALUES(24652,'Bagwell','Bagwell, Texas',30012,51);
INSERT INTO "django_geo_db_city" VALUES(24653,'Bailey','Bailey, Texas',30013,51);
INSERT INTO "django_geo_db_city" VALUES(24654,'Bells','Bells, Texas',30014,51);
INSERT INTO "django_geo_db_city" VALUES(24655,'Ben Franklin','Ben Franklin, Texas',30015,51);
INSERT INTO "django_geo_db_city" VALUES(24656,'Blossom','Blossom, Texas',30016,51);
INSERT INTO "django_geo_db_city" VALUES(24657,'Bogata','Bogata, Texas',30017,51);
INSERT INTO "django_geo_db_city" VALUES(24658,'Bonham','Bonham, Texas',30018,51);
INSERT INTO "django_geo_db_city" VALUES(24659,'Brashear','Brashear, Texas',30019,51);
INSERT INTO "django_geo_db_city" VALUES(24660,'Brookston','Brookston, Texas',30020,51);
INSERT INTO "django_geo_db_city" VALUES(24661,'Campbell','Campbell, Texas',30021,51);
INSERT INTO "django_geo_db_city" VALUES(24662,'Celeste','Celeste, Texas',30022,51);
INSERT INTO "django_geo_db_city" VALUES(24663,'Blue Ridge','Blue Ridge, Texas',30023,51);
INSERT INTO "django_geo_db_city" VALUES(24664,'Chicota','Chicota, Texas',30024,51);
INSERT INTO "django_geo_db_city" VALUES(24665,'Clarksville','Clarksville, Texas',30025,51);
INSERT INTO "django_geo_db_city" VALUES(24666,'Commerce','Commerce, Texas',30026,51);
INSERT INTO "django_geo_db_city" VALUES(24667,'Como','Como, Texas',30028,51);
INSERT INTO "django_geo_db_city" VALUES(24668,'Cooper','Cooper, Texas',30029,51);
INSERT INTO "django_geo_db_city" VALUES(24669,'Cumby','Cumby, Texas',30030,51);
INSERT INTO "django_geo_db_city" VALUES(24670,'Cunningham','Cunningham, Texas',30031,51);
INSERT INTO "django_geo_db_city" VALUES(24671,'Deport','Deport, Texas',30032,51);
INSERT INTO "django_geo_db_city" VALUES(24672,'Detroit','Detroit, Texas',30033,51);
INSERT INTO "django_geo_db_city" VALUES(24673,'Dike','Dike, Texas',30034,51);
INSERT INTO "django_geo_db_city" VALUES(24674,'Dodd City','Dodd City, Texas',30035,51);
INSERT INTO "django_geo_db_city" VALUES(24675,'Ector','Ector, Texas',30036,51);
INSERT INTO "django_geo_db_city" VALUES(24676,'Emory','Emory, Texas',30037,51);
INSERT INTO "django_geo_db_city" VALUES(24677,'Enloe','Enloe, Texas',30038,51);
INSERT INTO "django_geo_db_city" VALUES(24678,'Farmersville','Farmersville, Texas',30039,51);
INSERT INTO "django_geo_db_city" VALUES(24679,'Gober','Gober, Texas',30040,51);
INSERT INTO "django_geo_db_city" VALUES(24680,'Golden','Golden, Texas',30041,51);
INSERT INTO "django_geo_db_city" VALUES(24681,'Honey Grove','Honey Grove, Texas',30042,51);
INSERT INTO "django_geo_db_city" VALUES(24682,'Ivanhoe','Ivanhoe, Texas',30043,51);
INSERT INTO "django_geo_db_city" VALUES(24683,'Klondike','Klondike, Texas',30044,51);
INSERT INTO "django_geo_db_city" VALUES(24684,'Ladonia','Ladonia, Texas',30045,51);
INSERT INTO "django_geo_db_city" VALUES(24685,'Lake Creek','Lake Creek, Texas',30046,51);
INSERT INTO "django_geo_db_city" VALUES(24686,'Leesburg','Leesburg, Texas',30047,51);
INSERT INTO "django_geo_db_city" VALUES(24687,'Leonard','Leonard, Texas',30048,51);
INSERT INTO "django_geo_db_city" VALUES(24688,'Lone Oak','Lone Oak, Texas',30049,51);
INSERT INTO "django_geo_db_city" VALUES(24689,'Melissa','Melissa, Texas',30050,51);
INSERT INTO "django_geo_db_city" VALUES(24690,'Mount Pleasant','Mount Pleasant, Texas',30051,51);
INSERT INTO "django_geo_db_city" VALUES(24691,'Mount Vernon','Mount Vernon, Texas',30053,51);
INSERT INTO "django_geo_db_city" VALUES(24692,'Merit','Merit, Texas',30054,51);
INSERT INTO "django_geo_db_city" VALUES(24693,'Howe','Howe, Texas',30055,51);
INSERT INTO "django_geo_db_city" VALUES(24694,'Paris','Paris, Texas',30056,51);
INSERT INTO "django_geo_db_city" VALUES(24695,'Pattonville','Pattonville, Texas',30059,51);
INSERT INTO "django_geo_db_city" VALUES(24696,'Pecan Gap','Pecan Gap, Texas',30060,51);
INSERT INTO "django_geo_db_city" VALUES(24697,'Petty','Petty, Texas',30061,51);
INSERT INTO "django_geo_db_city" VALUES(24698,'Pickton','Pickton, Texas',30062,51);
INSERT INTO "django_geo_db_city" VALUES(24699,'Point','Point, Texas',30063,51);
INSERT INTO "django_geo_db_city" VALUES(24700,'Powderly','Powderly, Texas',30064,51);
INSERT INTO "django_geo_db_city" VALUES(24701,'Quinlan','Quinlan, Texas',30065,51);
INSERT INTO "django_geo_db_city" VALUES(24702,'Randolph','Randolph, Texas',30066,51);
INSERT INTO "django_geo_db_city" VALUES(24703,'Ravenna','Ravenna, Texas',30067,51);
INSERT INTO "django_geo_db_city" VALUES(24704,'Roxton','Roxton, Texas',30068,51);
INSERT INTO "django_geo_db_city" VALUES(24705,'Saltillo','Saltillo, Texas',30069,51);
INSERT INTO "django_geo_db_city" VALUES(24706,'Savoy','Savoy, Texas',30070,51);
INSERT INTO "django_geo_db_city" VALUES(24707,'Scroggins','Scroggins, Texas',30071,51);
INSERT INTO "django_geo_db_city" VALUES(24708,'Sulphur Bluff','Sulphur Bluff, Texas',30072,51);
INSERT INTO "django_geo_db_city" VALUES(24709,'Sulphur Springs','Sulphur Springs, Texas',30073,51);
INSERT INTO "django_geo_db_city" VALUES(24710,'Westminster','Westminster, Texas',30075,51);
INSERT INTO "django_geo_db_city" VALUES(24711,'Sumner','Sumner, Texas',30076,51);
INSERT INTO "django_geo_db_city" VALUES(24712,'Talco','Talco, Texas',30077,51);
INSERT INTO "django_geo_db_city" VALUES(24713,'Telephone','Telephone, Texas',30078,51);
INSERT INTO "django_geo_db_city" VALUES(24714,'Tom Bean','Tom Bean, Texas',30079,51);
INSERT INTO "django_geo_db_city" VALUES(24715,'Trenton','Trenton, Texas',30080,51);
INSERT INTO "django_geo_db_city" VALUES(24716,'Whitewright','Whitewright, Texas',30081,51);
INSERT INTO "django_geo_db_city" VALUES(24717,'Windom','Windom, Texas',30082,51);
INSERT INTO "django_geo_db_city" VALUES(24718,'Winfield','Winfield, Texas',30083,51);
INSERT INTO "django_geo_db_city" VALUES(24719,'Winnsboro','Winnsboro, Texas',30084,51);
INSERT INTO "django_geo_db_city" VALUES(24720,'Van Alstyne','Van Alstyne, Texas',30085,51);
INSERT INTO "django_geo_db_city" VALUES(24721,'Wolfe City','Wolfe City, Texas',30086,51);
INSERT INTO "django_geo_db_city" VALUES(24722,'Yantis','Yantis, Texas',30087,51);
INSERT INTO "django_geo_db_city" VALUES(24723,'Texarkana','Texarkana, Texas',30089,51);
INSERT INTO "django_geo_db_city" VALUES(24724,'Annona','Annona, Texas',30095,51);
INSERT INTO "django_geo_db_city" VALUES(24725,'Atlanta','Atlanta, Texas',30096,51);
INSERT INTO "django_geo_db_city" VALUES(24726,'Avery','Avery, Texas',30097,51);
INSERT INTO "django_geo_db_city" VALUES(24727,'Bivins','Bivins, Texas',30098,51);
INSERT INTO "django_geo_db_city" VALUES(24728,'Bloomburg','Bloomburg, Texas',30099,51);
INSERT INTO "django_geo_db_city" VALUES(24729,'Cookville','Cookville, Texas',30100,51);
INSERT INTO "django_geo_db_city" VALUES(24730,'De Kalb','De Kalb, Texas',30101,51);
INSERT INTO "django_geo_db_city" VALUES(24731,'Douglassville','Douglassville, Texas',30102,51);
INSERT INTO "django_geo_db_city" VALUES(24732,'Hooks','Hooks, Texas',30103,51);
INSERT INTO "django_geo_db_city" VALUES(24733,'Kildare','Kildare, Texas',30104,51);
INSERT INTO "django_geo_db_city" VALUES(24734,'Linden','Linden, Texas',30105,51);
INSERT INTO "django_geo_db_city" VALUES(24735,'Lodi','Lodi, Texas',30106,51);
INSERT INTO "django_geo_db_city" VALUES(24736,'McLeod','McLeod, Texas',30107,51);
INSERT INTO "django_geo_db_city" VALUES(24737,'Marietta','Marietta, Texas',30108,51);
INSERT INTO "django_geo_db_city" VALUES(24738,'Maud','Maud, Texas',30109,51);
INSERT INTO "django_geo_db_city" VALUES(24739,'Naples','Naples, Texas',30110,51);
INSERT INTO "django_geo_db_city" VALUES(24740,'Nash','Nash, Texas',30111,51);
INSERT INTO "django_geo_db_city" VALUES(24741,'New Boston','New Boston, Texas',30112,51);
INSERT INTO "django_geo_db_city" VALUES(24742,'Omaha','Omaha, Texas',30113,51);
INSERT INTO "django_geo_db_city" VALUES(24743,'Queen City','Queen City, Texas',30114,51);
INSERT INTO "django_geo_db_city" VALUES(24744,'Redwater','Redwater, Texas',30115,51);
INSERT INTO "django_geo_db_city" VALUES(24745,'Simms','Simms, Texas',30116,51);
INSERT INTO "django_geo_db_city" VALUES(24746,'Longview','Longview, Texas',30117,51);
INSERT INTO "django_geo_db_city" VALUES(24747,'Avinger','Avinger, Texas',30125,51);
INSERT INTO "django_geo_db_city" VALUES(24748,'Beckville','Beckville, Texas',30126,51);
INSERT INTO "django_geo_db_city" VALUES(24749,'Carthage','Carthage, Texas',30127,51);
INSERT INTO "django_geo_db_city" VALUES(24750,'Cason','Cason, Texas',30128,51);
INSERT INTO "django_geo_db_city" VALUES(24751,'Clayton','Clayton, Texas',30129,51);
INSERT INTO "django_geo_db_city" VALUES(24752,'Daingerfield','Daingerfield, Texas',30130,51);
INSERT INTO "django_geo_db_city" VALUES(24753,'De Berry','De Berry, Texas',30131,51);
INSERT INTO "django_geo_db_city" VALUES(24754,'Diana','Diana, Texas',30132,51);
INSERT INTO "django_geo_db_city" VALUES(24755,'Easton','Easton, Texas',30133,51);
INSERT INTO "django_geo_db_city" VALUES(24756,'Elysian Fields','Elysian Fields, Texas',30134,51);
INSERT INTO "django_geo_db_city" VALUES(24757,'Gary','Gary, Texas',30135,51);
INSERT INTO "django_geo_db_city" VALUES(24758,'Gilmer','Gilmer, Texas',30136,51);
INSERT INTO "django_geo_db_city" VALUES(24759,'Gladewater','Gladewater, Texas',30138,51);
INSERT INTO "django_geo_db_city" VALUES(24760,'Hallsville','Hallsville, Texas',30139,51);
INSERT INTO "django_geo_db_city" VALUES(24761,'Harleton','Harleton, Texas',30140,51);
INSERT INTO "django_geo_db_city" VALUES(24762,'Henderson','Henderson, Texas',30141,51);
INSERT INTO "django_geo_db_city" VALUES(24763,'Hughes Springs','Hughes Springs, Texas',30144,51);
INSERT INTO "django_geo_db_city" VALUES(24764,'Jefferson','Jefferson, Texas',30145,51);
INSERT INTO "django_geo_db_city" VALUES(24765,'Joinerville','Joinerville, Texas',30146,51);
INSERT INTO "django_geo_db_city" VALUES(24766,'Jonesville','Jonesville, Texas',30147,51);
INSERT INTO "django_geo_db_city" VALUES(24767,'Judson','Judson, Texas',30123,51);
INSERT INTO "django_geo_db_city" VALUES(24768,'Karnack','Karnack, Texas',30148,51);
INSERT INTO "django_geo_db_city" VALUES(24769,'Kilgore','Kilgore, Texas',30149,51);
INSERT INTO "django_geo_db_city" VALUES(24770,'Laird Hill','Laird Hill, Texas',30151,51);
INSERT INTO "django_geo_db_city" VALUES(24771,'Laneville','Laneville, Texas',30152,51);
INSERT INTO "django_geo_db_city" VALUES(24772,'Lone Star','Lone Star, Texas',30153,51);
INSERT INTO "django_geo_db_city" VALUES(24773,'Long Branch','Long Branch, Texas',30154,51);
INSERT INTO "django_geo_db_city" VALUES(24774,'Marshall','Marshall, Texas',30155,51);
INSERT INTO "django_geo_db_city" VALUES(24775,'Minden','Minden, Texas',30158,51);
INSERT INTO "django_geo_db_city" VALUES(24776,'Mount Enterprise','Mount Enterprise, Texas',30159,51);
INSERT INTO "django_geo_db_city" VALUES(24777,'New London','New London, Texas',30160,51);
INSERT INTO "django_geo_db_city" VALUES(24778,'Ore City','Ore City, Texas',30161,51);
INSERT INTO "django_geo_db_city" VALUES(24779,'Overton','Overton, Texas',30162,51);
INSERT INTO "django_geo_db_city" VALUES(24780,'Panola','Panola, Texas',30163,51);
INSERT INTO "django_geo_db_city" VALUES(24781,'Pittsburg','Pittsburg, Texas',30164,51);
INSERT INTO "django_geo_db_city" VALUES(24782,'Price','Price, Texas',30165,51);
INSERT INTO "django_geo_db_city" VALUES(24783,'Scottsville','Scottsville, Texas',30166,51);
INSERT INTO "django_geo_db_city" VALUES(24784,'Selman City','Selman City, Texas',30167,51);
INSERT INTO "django_geo_db_city" VALUES(24785,'Tatum','Tatum, Texas',30168,51);
INSERT INTO "django_geo_db_city" VALUES(24786,'Waskom','Waskom, Texas',30169,51);
INSERT INTO "django_geo_db_city" VALUES(24787,'White Oak','White Oak, Texas',30170,51);
INSERT INTO "django_geo_db_city" VALUES(24788,'Woodlawn','Woodlawn, Texas',30171,51);
INSERT INTO "django_geo_db_city" VALUES(24789,'Tyler','Tyler, Texas',30172,51);
INSERT INTO "django_geo_db_city" VALUES(24790,'Arp','Arp, Texas',30184,51);
INSERT INTO "django_geo_db_city" VALUES(24791,'Athens','Athens, Texas',30185,51);
INSERT INTO "django_geo_db_city" VALUES(24792,'Winona','Winona, Texas',30186,51);
INSERT INTO "django_geo_db_city" VALUES(24793,'Ben Wheeler','Ben Wheeler, Texas',30187,51);
INSERT INTO "django_geo_db_city" VALUES(24794,'Big Sandy','Big Sandy, Texas',30188,51);
INSERT INTO "django_geo_db_city" VALUES(24795,'Brownsboro','Brownsboro, Texas',30189,51);
INSERT INTO "django_geo_db_city" VALUES(24796,'Bullard','Bullard, Texas',30190,51);
INSERT INTO "django_geo_db_city" VALUES(24797,'Chandler','Chandler, Texas',30191,51);
INSERT INTO "django_geo_db_city" VALUES(24798,'Cuney','Cuney, Texas',30192,51);
INSERT INTO "django_geo_db_city" VALUES(24799,'Cushing','Cushing, Texas',30193,51);
INSERT INTO "django_geo_db_city" VALUES(24800,'Flint','Flint, Texas',30194,51);
INSERT INTO "django_geo_db_city" VALUES(24801,'Frankston','Frankston, Texas',30195,51);
INSERT INTO "django_geo_db_city" VALUES(24802,'Gallatin','Gallatin, Texas',30196,51);
INSERT INTO "django_geo_db_city" VALUES(24803,'Hawkins','Hawkins, Texas',30197,51);
INSERT INTO "django_geo_db_city" VALUES(24804,'Jacksonville','Jacksonville, Texas',30198,51);
INSERT INTO "django_geo_db_city" VALUES(24805,'Larue','Larue, Texas',30199,51);
INSERT INTO "django_geo_db_city" VALUES(24806,'Lindale','Lindale, Texas',30200,51);
INSERT INTO "django_geo_db_city" VALUES(24807,'Maydelle','Maydelle, Texas',30201,51);
INSERT INTO "django_geo_db_city" VALUES(24808,'Mineola','Mineola, Texas',30202,51);
INSERT INTO "django_geo_db_city" VALUES(24809,'Murchison','Murchison, Texas',30203,51);
INSERT INTO "django_geo_db_city" VALUES(24810,'Neches','Neches, Texas',30204,51);
INSERT INTO "django_geo_db_city" VALUES(24811,'New Summerfield','New Summerfield, Texas',30205,51);
INSERT INTO "django_geo_db_city" VALUES(24812,'Poynor','Poynor, Texas',30206,51);
INSERT INTO "django_geo_db_city" VALUES(24813,'Quitman','Quitman, Texas',30207,51);
INSERT INTO "django_geo_db_city" VALUES(24814,'Reklaw','Reklaw, Texas',30208,51);
INSERT INTO "django_geo_db_city" VALUES(24815,'Rusk','Rusk, Texas',30209,51);
INSERT INTO "django_geo_db_city" VALUES(24816,'Sacul','Sacul, Texas',30210,51);
INSERT INTO "django_geo_db_city" VALUES(24817,'Troup','Troup, Texas',30211,51);
INSERT INTO "django_geo_db_city" VALUES(24818,'Van','Van, Texas',30212,51);
INSERT INTO "django_geo_db_city" VALUES(24819,'Whitehouse','Whitehouse, Texas',30213,51);
INSERT INTO "django_geo_db_city" VALUES(24820,'Palestine','Palestine, Texas',30215,51);
INSERT INTO "django_geo_db_city" VALUES(24821,'Alto','Alto, Texas',30219,51);
INSERT INTO "django_geo_db_city" VALUES(24822,'Buffalo','Buffalo, Texas',30220,51);
INSERT INTO "django_geo_db_city" VALUES(24823,'Cayuga','Cayuga, Texas',30204,51);
INSERT INTO "django_geo_db_city" VALUES(24824,'Centerville','Centerville, Texas',30221,51);
INSERT INTO "django_geo_db_city" VALUES(24825,'Centralia','Centralia, Texas',30222,51);
INSERT INTO "django_geo_db_city" VALUES(24826,'Crockett','Crockett, Texas',30223,51);
INSERT INTO "django_geo_db_city" VALUES(24827,'Donie','Donie, Texas',30224,51);
INSERT INTO "django_geo_db_city" VALUES(24828,'Elkhart','Elkhart, Texas',30225,51);
INSERT INTO "django_geo_db_city" VALUES(24829,'Fairfield','Fairfield, Texas',30226,51);
INSERT INTO "django_geo_db_city" VALUES(24830,'Grapeland','Grapeland, Texas',30227,51);
INSERT INTO "django_geo_db_city" VALUES(24831,'Groveton','Groveton, Texas',30228,51);
INSERT INTO "django_geo_db_city" VALUES(24832,'Jewett','Jewett, Texas',30229,51);
INSERT INTO "django_geo_db_city" VALUES(24833,'Kennard','Kennard, Texas',30230,51);
INSERT INTO "django_geo_db_city" VALUES(24834,'Kirvin','Kirvin, Texas',30231,51);
INSERT INTO "django_geo_db_city" VALUES(24835,'Latexo','Latexo, Texas',30232,51);
INSERT INTO "django_geo_db_city" VALUES(24836,'Leona','Leona, Texas',30233,51);
INSERT INTO "django_geo_db_city" VALUES(24837,'Lovelady','Lovelady, Texas',30234,51);
INSERT INTO "django_geo_db_city" VALUES(24838,'Midway','Midway, Texas',30235,51);
INSERT INTO "django_geo_db_city" VALUES(24839,'Montalba','Montalba, Texas',30236,51);
INSERT INTO "django_geo_db_city" VALUES(24840,'Oakwood','Oakwood, Texas',30237,51);
INSERT INTO "django_geo_db_city" VALUES(24841,'Pennington','Pennington, Texas',30238,51);
INSERT INTO "django_geo_db_city" VALUES(24842,'Ratcliff','Ratcliff, Texas',30239,51);
INSERT INTO "django_geo_db_city" VALUES(24843,'Streetman','Streetman, Texas',30240,51);
INSERT INTO "django_geo_db_city" VALUES(24844,'Teague','Teague, Texas',30241,51);
INSERT INTO "django_geo_db_city" VALUES(24845,'Tennessee Colony','Tennessee Colony, Texas',30242,51);
INSERT INTO "django_geo_db_city" VALUES(24846,'Trinity','Trinity, Texas',30243,51);
INSERT INTO "django_geo_db_city" VALUES(24847,'Woodlake','Woodlake, Texas',30222,51);
INSERT INTO "django_geo_db_city" VALUES(24848,'Lufkin','Lufkin, Texas',30245,51);
INSERT INTO "django_geo_db_city" VALUES(24849,'Apple Springs','Apple Springs, Texas',30251,51);
INSERT INTO "django_geo_db_city" VALUES(24850,'Bon Wier','Bon Wier, Texas',30252,51);
INSERT INTO "django_geo_db_city" VALUES(24851,'Broaddus','Broaddus, Texas',30253,51);
INSERT INTO "django_geo_db_city" VALUES(24852,'Bronson','Bronson, Texas',30254,51);
INSERT INTO "django_geo_db_city" VALUES(24853,'Brookeland','Brookeland, Texas',30255,51);
INSERT INTO "django_geo_db_city" VALUES(24854,'Burkeville','Burkeville, Texas',30256,51);
INSERT INTO "django_geo_db_city" VALUES(24855,'Call','Call, Texas',30257,51);
INSERT INTO "django_geo_db_city" VALUES(24856,'Camden','Camden, Texas',30258,51);
INSERT INTO "django_geo_db_city" VALUES(24857,'Center','Center, Texas',30259,51);
INSERT INTO "django_geo_db_city" VALUES(24858,'Chester','Chester, Texas',30260,51);
INSERT INTO "django_geo_db_city" VALUES(24859,'Chireno','Chireno, Texas',30261,51);
INSERT INTO "django_geo_db_city" VALUES(24860,'Colmesneil','Colmesneil, Texas',30262,51);
INSERT INTO "django_geo_db_city" VALUES(24861,'Corrigan','Corrigan, Texas',30263,51);
INSERT INTO "django_geo_db_city" VALUES(24862,'Diboll','Diboll, Texas',30264,51);
INSERT INTO "django_geo_db_city" VALUES(24863,'Doucette','Doucette, Texas',30265,51);
INSERT INTO "django_geo_db_city" VALUES(24864,'Douglass','Douglass, Texas',30266,51);
INSERT INTO "django_geo_db_city" VALUES(24865,'Etoile','Etoile, Texas',30267,51);
INSERT INTO "django_geo_db_city" VALUES(24866,'Garrison','Garrison, Texas',30268,51);
INSERT INTO "django_geo_db_city" VALUES(24867,'Geneva','Geneva, Texas',30269,51);
INSERT INTO "django_geo_db_city" VALUES(24868,'Hemphill','Hemphill, Texas',30270,51);
INSERT INTO "django_geo_db_city" VALUES(24869,'Huntington','Huntington, Texas',30271,51);
INSERT INTO "django_geo_db_city" VALUES(24870,'Jasper','Jasper, Texas',30272,51);
INSERT INTO "django_geo_db_city" VALUES(24871,'Joaquin','Joaquin, Texas',30273,51);
INSERT INTO "django_geo_db_city" VALUES(24872,'Kirbyville','Kirbyville, Texas',30274,51);
INSERT INTO "django_geo_db_city" VALUES(24873,'Timpson','Timpson, Texas',30275,51);
INSERT INTO "django_geo_db_city" VALUES(24874,'Martinsville','Martinsville, Texas',30276,51);
INSERT INTO "django_geo_db_city" VALUES(24875,'Milam','Milam, Texas',30277,51);
INSERT INTO "django_geo_db_city" VALUES(24876,'Moscow','Moscow, Texas',30278,51);
INSERT INTO "django_geo_db_city" VALUES(24877,'Nacogdoches','Nacogdoches, Texas',30279,51);
INSERT INTO "django_geo_db_city" VALUES(24878,'Newton','Newton, Texas',30284,51);
INSERT INTO "django_geo_db_city" VALUES(24879,'Pineland','Pineland, Texas',30285,51);
INSERT INTO "django_geo_db_city" VALUES(24880,'Pollok','Pollok, Texas',30286,51);
INSERT INTO "django_geo_db_city" VALUES(24881,'San Augustine','San Augustine, Texas',30287,51);
INSERT INTO "django_geo_db_city" VALUES(24882,'Shelbyville','Shelbyville, Texas',30288,51);
INSERT INTO "django_geo_db_city" VALUES(24883,'Tenaha','Tenaha, Texas',30289,51);
INSERT INTO "django_geo_db_city" VALUES(24884,'Wells','Wells, Texas',30291,51);
INSERT INTO "django_geo_db_city" VALUES(24885,'Wiergate','Wiergate, Texas',30292,51);
INSERT INTO "django_geo_db_city" VALUES(24886,'Woden','Woden, Texas',30293,51);
INSERT INTO "django_geo_db_city" VALUES(24887,'Woodville','Woodville, Texas',30294,51);
INSERT INTO "django_geo_db_city" VALUES(24888,'Zavalla','Zavalla, Texas',30295,51);
INSERT INTO "django_geo_db_city" VALUES(24889,'Arlington','Arlington, Texas',30297,51);
INSERT INTO "django_geo_db_city" VALUES(24890,'Aledo','Aledo, Texas',30302,51);
INSERT INTO "django_geo_db_city" VALUES(24891,'Alvarado','Alvarado, Texas',30303,51);
INSERT INTO "django_geo_db_city" VALUES(24892,'Azle','Azle, Texas',30313,51);
INSERT INTO "django_geo_db_city" VALUES(24893,'Bedford','Bedford, Texas',30314,51);
INSERT INTO "django_geo_db_city" VALUES(24894,'Boyd','Boyd, Texas',30316,51);
INSERT INTO "django_geo_db_city" VALUES(24895,'Burleson','Burleson, Texas',30318,51);
INSERT INTO "django_geo_db_city" VALUES(24896,'Cleburne','Cleburne, Texas',30319,51);
INSERT INTO "django_geo_db_city" VALUES(24897,'Colleyville','Colleyville, Texas',30321,51);
INSERT INTO "django_geo_db_city" VALUES(24898,'Cresson','Cresson, Texas',30322,51);
INSERT INTO "django_geo_db_city" VALUES(24899,'Crowley','Crowley, Texas',30323,51);
INSERT INTO "django_geo_db_city" VALUES(24900,'Euless','Euless, Texas',30324,51);
INSERT INTO "django_geo_db_city" VALUES(24901,'Forreston','Forreston, Texas',30326,51);
INSERT INTO "django_geo_db_city" VALUES(24902,'Glen Rose','Glen Rose, Texas',30327,51);
INSERT INTO "django_geo_db_city" VALUES(24903,'Godley','Godley, Texas',30328,51);
INSERT INTO "django_geo_db_city" VALUES(24904,'Granbury','Granbury, Texas',30329,51);
INSERT INTO "django_geo_db_city" VALUES(24905,'Grandview','Grandview, Texas',30331,51);
INSERT INTO "django_geo_db_city" VALUES(24906,'Grapevine','Grapevine, Texas',30332,51);
INSERT INTO "django_geo_db_city" VALUES(24907,'Haslet','Haslet, Texas',30333,51);
INSERT INTO "django_geo_db_city" VALUES(24908,'Hurst','Hurst, Texas',30334,51);
INSERT INTO "django_geo_db_city" VALUES(24909,'Itasca','Itasca, Texas',30336,51);
INSERT INTO "django_geo_db_city" VALUES(24910,'Joshua','Joshua, Texas',30337,51);
INSERT INTO "django_geo_db_city" VALUES(24911,'Keene','Keene, Texas',30338,51);
INSERT INTO "django_geo_db_city" VALUES(24912,'Kennedale','Kennedale, Texas',30339,51);
INSERT INTO "django_geo_db_city" VALUES(24913,'Lillian','Lillian, Texas',30340,51);
INSERT INTO "django_geo_db_city" VALUES(24914,'Mansfield','Mansfield, Texas',30341,51);
INSERT INTO "django_geo_db_city" VALUES(24915,'Maypearl','Maypearl, Texas',30342,51);
INSERT INTO "django_geo_db_city" VALUES(24916,'Midlothian','Midlothian, Texas',30343,51);
INSERT INTO "django_geo_db_city" VALUES(24917,'Millsap','Millsap, Texas',30344,51);
INSERT INTO "django_geo_db_city" VALUES(24918,'Mineral Wells','Mineral Wells, Texas',30345,51);
INSERT INTO "django_geo_db_city" VALUES(24919,'Nemo','Nemo, Texas',30347,51);
INSERT INTO "django_geo_db_city" VALUES(24920,'Newark','Newark, Texas',30348,51);
INSERT INTO "django_geo_db_city" VALUES(24921,'Paradise','Paradise, Texas',30349,51);
INSERT INTO "django_geo_db_city" VALUES(24922,'Rainbow','Rainbow, Texas',30350,51);
INSERT INTO "django_geo_db_city" VALUES(24923,'Rhome','Rhome, Texas',30351,51);
INSERT INTO "django_geo_db_city" VALUES(24924,'Springtown','Springtown, Texas',30352,51);
INSERT INTO "django_geo_db_city" VALUES(24925,'Venus','Venus, Texas',30353,51);
INSERT INTO "django_geo_db_city" VALUES(24926,'Weatherford','Weatherford, Texas',30354,51);
INSERT INTO "django_geo_db_city" VALUES(24927,'Southlake','Southlake, Texas',30358,51);
INSERT INTO "django_geo_db_city" VALUES(24928,'Rio Vista','Rio Vista, Texas',30359,51);
INSERT INTO "django_geo_db_city" VALUES(24929,'Fort Worth','Fort Worth, Texas',30300,51);
INSERT INTO "django_geo_db_city" VALUES(24930,'Haltom City','Haltom City, Texas',30376,51);
INSERT INTO "django_geo_db_city" VALUES(24931,'Naval Air Station/ Jrb','Naval Air Station/ Jrb, Texas',30382,51);
INSERT INTO "django_geo_db_city" VALUES(24932,'North Richland Hills','North Richland Hills, Texas',30395,51);
INSERT INTO "django_geo_db_city" VALUES(24933,'Denton','Denton, Texas',30396,51);
INSERT INTO "django_geo_db_city" VALUES(24934,'Corinth','Corinth, Texas',30404,51);
INSERT INTO "django_geo_db_city" VALUES(24935,'Alvord','Alvord, Texas',30405,51);
INSERT INTO "django_geo_db_city" VALUES(24936,'Argyle','Argyle, Texas',30406,51);
INSERT INTO "django_geo_db_city" VALUES(24937,'Aubrey','Aubrey, Texas',30407,51);
INSERT INTO "django_geo_db_city" VALUES(24938,'Bellevue','Bellevue, Texas',30408,51);
INSERT INTO "django_geo_db_city" VALUES(24939,'Bowie','Bowie, Texas',30409,51);
INSERT INTO "django_geo_db_city" VALUES(24940,'Collinsville','Collinsville, Texas',30410,51);
INSERT INTO "django_geo_db_city" VALUES(24941,'Decatur','Decatur, Texas',30411,51);
INSERT INTO "django_geo_db_city" VALUES(24942,'Era','Era, Texas',30412,51);
INSERT INTO "django_geo_db_city" VALUES(24943,'Forestburg','Forestburg, Texas',30413,51);
INSERT INTO "django_geo_db_city" VALUES(24944,'Gainesville','Gainesville, Texas',30414,51);
INSERT INTO "django_geo_db_city" VALUES(24945,'Keller','Keller, Texas',30300,51);
INSERT INTO "django_geo_db_city" VALUES(24946,'Gordonville','Gordonville, Texas',30416,51);
INSERT INTO "django_geo_db_city" VALUES(24947,'Greenwood','Greenwood, Texas',30417,51);
INSERT INTO "django_geo_db_city" VALUES(24948,'Justin','Justin, Texas',30418,51);
INSERT INTO "django_geo_db_city" VALUES(24949,'Krum','Krum, Texas',30420,51);
INSERT INTO "django_geo_db_city" VALUES(24950,'Lindsay','Lindsay, Texas',30421,51);
INSERT INTO "django_geo_db_city" VALUES(24951,'Montague','Montague, Texas',30422,51);
INSERT INTO "django_geo_db_city" VALUES(24952,'Muenster','Muenster, Texas',30423,51);
INSERT INTO "django_geo_db_city" VALUES(24953,'Myra','Myra, Texas',30424,51);
INSERT INTO "django_geo_db_city" VALUES(24954,'Nocona','Nocona, Texas',30425,51);
INSERT INTO "django_geo_db_city" VALUES(24955,'Pilot Point','Pilot Point, Texas',30426,51);
INSERT INTO "django_geo_db_city" VALUES(24956,'Ponder','Ponder, Texas',30427,51);
INSERT INTO "django_geo_db_city" VALUES(24957,'Ringgold','Ringgold, Texas',30428,51);
INSERT INTO "django_geo_db_city" VALUES(24958,'Roanoke','Roanoke, Texas',30429,51);
INSERT INTO "django_geo_db_city" VALUES(24959,'Rosston','Rosston, Texas',30430,51);
INSERT INTO "django_geo_db_city" VALUES(24960,'Sadler','Sadler, Texas',30431,51);
INSERT INTO "django_geo_db_city" VALUES(24961,'Saint Jo','Saint Jo, Texas',30432,51);
INSERT INTO "django_geo_db_city" VALUES(24962,'Sanger','Sanger, Texas',30433,51);
INSERT INTO "django_geo_db_city" VALUES(24963,'Slidell','Slidell, Texas',30434,51);
INSERT INTO "django_geo_db_city" VALUES(24964,'Southmayd','Southmayd, Texas',30435,51);
INSERT INTO "django_geo_db_city" VALUES(24965,'Sunset','Sunset, Texas',30436,51);
INSERT INTO "django_geo_db_city" VALUES(24966,'Tioga','Tioga, Texas',30437,51);
INSERT INTO "django_geo_db_city" VALUES(24967,'Valley View','Valley View, Texas',30438,51);
INSERT INTO "django_geo_db_city" VALUES(24968,'Whitesboro','Whitesboro, Texas',30439,51);
INSERT INTO "django_geo_db_city" VALUES(24969,'Wichita Falls','Wichita Falls, Texas',30440,51);
INSERT INTO "django_geo_db_city" VALUES(24970,'Sheppard AFB','Sheppard AFB, Texas',30450,51);
INSERT INTO "django_geo_db_city" VALUES(24971,'Archer City','Archer City, Texas',30452,51);
INSERT INTO "django_geo_db_city" VALUES(24972,'Bluegrove','Bluegrove, Texas',30453,51);
INSERT INTO "django_geo_db_city" VALUES(24973,'Burkburnett','Burkburnett, Texas',30454,51);
INSERT INTO "django_geo_db_city" VALUES(24974,'Byers','Byers, Texas',30456,51);
INSERT INTO "django_geo_db_city" VALUES(24975,'Electra','Electra, Texas',30457,51);
INSERT INTO "django_geo_db_city" VALUES(24976,'Goree','Goree, Texas',30458,51);
INSERT INTO "django_geo_db_city" VALUES(24977,'Harrold','Harrold, Texas',30459,51);
INSERT INTO "django_geo_db_city" VALUES(24978,'Henrietta','Henrietta, Texas',30460,51);
INSERT INTO "django_geo_db_city" VALUES(24979,'Holliday','Holliday, Texas',30461,51);
INSERT INTO "django_geo_db_city" VALUES(24980,'Iowa Park','Iowa Park, Texas',30462,51);
INSERT INTO "django_geo_db_city" VALUES(24981,'Kamay','Kamay, Texas',30463,51);
INSERT INTO "django_geo_db_city" VALUES(24982,'Megargel','Megargel, Texas',30464,51);
INSERT INTO "django_geo_db_city" VALUES(24983,'Munday','Munday, Texas',30465,51);
INSERT INTO "django_geo_db_city" VALUES(24984,'Newcastle','Newcastle, Texas',30466,51);
INSERT INTO "django_geo_db_city" VALUES(24985,'Oklaunion','Oklaunion, Texas',30467,51);
INSERT INTO "django_geo_db_city" VALUES(24986,'Olney','Olney, Texas',30468,51);
INSERT INTO "django_geo_db_city" VALUES(24987,'Petrolia','Petrolia, Texas',30469,51);
INSERT INTO "django_geo_db_city" VALUES(24988,'Scotland','Scotland, Texas',30470,51);
INSERT INTO "django_geo_db_city" VALUES(24989,'Seymour','Seymour, Texas',30471,51);
INSERT INTO "django_geo_db_city" VALUES(24990,'Vernon','Vernon, Texas',30472,51);
INSERT INTO "django_geo_db_city" VALUES(24991,'Weinert','Weinert, Texas',30474,51);
INSERT INTO "django_geo_db_city" VALUES(24992,'Windthorst','Windthorst, Texas',30475,51);
INSERT INTO "django_geo_db_city" VALUES(24993,'Stephenville','Stephenville, Texas',30476,51);
INSERT INTO "django_geo_db_city" VALUES(24994,'Albany','Albany, Texas',30478,51);
INSERT INTO "django_geo_db_city" VALUES(24995,'Breckenridge','Breckenridge, Texas',30479,51);
INSERT INTO "django_geo_db_city" VALUES(24996,'Bridgeport','Bridgeport, Texas',30480,51);
INSERT INTO "django_geo_db_city" VALUES(24997,'Bryson','Bryson, Texas',30481,51);
INSERT INTO "django_geo_db_city" VALUES(24998,'Caddo','Caddo, Texas',30482,51);
INSERT INTO "django_geo_db_city" VALUES(24999,'Chico','Chico, Texas',30484,51);
INSERT INTO "django_geo_db_city" VALUES(25000,'Blanket','Blanket, Texas',30485,51);
INSERT INTO "django_geo_db_city" VALUES(25001,'Bluff Dale','Bluff Dale, Texas',30486,51);
INSERT INTO "django_geo_db_city" VALUES(25002,'Carbon','Carbon, Texas',30487,51);
INSERT INTO "django_geo_db_city" VALUES(25003,'Carlton','Carlton, Texas',30488,51);
INSERT INTO "django_geo_db_city" VALUES(25004,'Cisco','Cisco, Texas',30489,51);
INSERT INTO "django_geo_db_city" VALUES(25005,'Dennis','Dennis, Texas',30490,51);
INSERT INTO "django_geo_db_city" VALUES(25006,'Comanche','Comanche, Texas',30491,51);
INSERT INTO "django_geo_db_city" VALUES(25007,'Cross Plains','Cross Plains, Texas',30492,51);
INSERT INTO "django_geo_db_city" VALUES(25008,'De Leon','De Leon, Texas',30493,51);
INSERT INTO "django_geo_db_city" VALUES(25009,'Desdemona','Desdemona, Texas',30494,51);
INSERT INTO "django_geo_db_city" VALUES(25010,'Dublin','Dublin, Texas',30495,51);
INSERT INTO "django_geo_db_city" VALUES(25011,'Eastland','Eastland, Texas',30496,51);
INSERT INTO "django_geo_db_city" VALUES(25012,'Graford','Graford, Texas',30497,51);
INSERT INTO "django_geo_db_city" VALUES(25013,'Graham','Graham, Texas',30498,51);
INSERT INTO "django_geo_db_city" VALUES(25014,'Energy','Energy, Texas',30499,51);
INSERT INTO "django_geo_db_city" VALUES(25015,'Gordon','Gordon, Texas',30500,51);
INSERT INTO "django_geo_db_city" VALUES(25016,'Gorman','Gorman, Texas',30501,51);
INSERT INTO "django_geo_db_city" VALUES(25017,'Gustine','Gustine, Texas',30502,51);
INSERT INTO "django_geo_db_city" VALUES(25018,'Hico','Hico, Texas',30503,51);
INSERT INTO "django_geo_db_city" VALUES(25019,'Jacksboro','Jacksboro, Texas',30504,51);
INSERT INTO "django_geo_db_city" VALUES(25020,'Jermyn','Jermyn, Texas',30505,51);
INSERT INTO "django_geo_db_city" VALUES(25021,'Loving','Loving, Texas',30506,51);
INSERT INTO "django_geo_db_city" VALUES(25022,'Lingleville','Lingleville, Texas',30507,51);
INSERT INTO "django_geo_db_city" VALUES(25023,'Lipan','Lipan, Texas',30508,51);
INSERT INTO "django_geo_db_city" VALUES(25024,'Mingus','Mingus, Texas',30509,51);
INSERT INTO "django_geo_db_city" VALUES(25025,'Moran','Moran, Texas',30510,51);
INSERT INTO "django_geo_db_city" VALUES(25026,'Morgan Mill','Morgan Mill, Texas',30477,51);
INSERT INTO "django_geo_db_city" VALUES(25027,'Olden','Olden, Texas',30511,51);
INSERT INTO "django_geo_db_city" VALUES(25028,'Paluxy','Paluxy, Texas',30512,51);
INSERT INTO "django_geo_db_city" VALUES(25029,'Proctor','Proctor, Texas',30513,51);
INSERT INTO "django_geo_db_city" VALUES(25030,'Putnam','Putnam, Texas',30514,51);
INSERT INTO "django_geo_db_city" VALUES(25031,'Ranger','Ranger, Texas',30515,51);
INSERT INTO "django_geo_db_city" VALUES(25032,'Rising Star','Rising Star, Texas',30516,51);
INSERT INTO "django_geo_db_city" VALUES(25033,'Santo','Santo, Texas',30517,51);
INSERT INTO "django_geo_db_city" VALUES(25034,'Sidney','Sidney, Texas',30518,51);
INSERT INTO "django_geo_db_city" VALUES(25035,'Strawn','Strawn, Texas',30519,51);
INSERT INTO "django_geo_db_city" VALUES(25036,'Tolar','Tolar, Texas',30520,51);
INSERT INTO "django_geo_db_city" VALUES(25037,'South Bend','South Bend, Texas',30521,51);
INSERT INTO "django_geo_db_city" VALUES(25038,'Throckmorton','Throckmorton, Texas',30522,51);
INSERT INTO "django_geo_db_city" VALUES(25039,'Palo Pinto','Palo Pinto, Texas',30523,51);
INSERT INTO "django_geo_db_city" VALUES(25040,'Peaster','Peaster, Texas',30524,51);
INSERT INTO "django_geo_db_city" VALUES(25041,'Perrin','Perrin, Texas',30525,51);
INSERT INTO "django_geo_db_city" VALUES(25042,'Poolville','Poolville, Texas',30526,51);
INSERT INTO "django_geo_db_city" VALUES(25043,'Whitt','Whitt, Texas',30527,51);
INSERT INTO "django_geo_db_city" VALUES(25044,'Woodson','Woodson, Texas',30528,51);
INSERT INTO "django_geo_db_city" VALUES(25045,'Temple','Temple, Texas',30529,51);
INSERT INTO "django_geo_db_city" VALUES(25046,'Bartlett','Bartlett, Texas',30534,51);
INSERT INTO "django_geo_db_city" VALUES(25047,'Belton','Belton, Texas',30535,51);
INSERT INTO "django_geo_db_city" VALUES(25048,'Buckholts','Buckholts, Texas',30536,51);
INSERT INTO "django_geo_db_city" VALUES(25049,'Burlington','Burlington, Texas',30537,51);
INSERT INTO "django_geo_db_city" VALUES(25050,'Cameron','Cameron, Texas',30538,51);
INSERT INTO "django_geo_db_city" VALUES(25051,'Copperas Cove','Copperas Cove, Texas',30539,51);
INSERT INTO "django_geo_db_city" VALUES(25052,'Davilla','Davilla, Texas',30540,51);
INSERT INTO "django_geo_db_city" VALUES(25053,'Eddy','Eddy, Texas',30541,51);
INSERT INTO "django_geo_db_city" VALUES(25054,'Evant','Evant, Texas',30542,51);
INSERT INTO "django_geo_db_city" VALUES(25055,'Flat','Flat, Texas',30543,51);
INSERT INTO "django_geo_db_city" VALUES(25056,'Florence','Florence, Texas',30544,51);
INSERT INTO "django_geo_db_city" VALUES(25057,'Gatesville','Gatesville, Texas',30545,51);
INSERT INTO "django_geo_db_city" VALUES(25058,'Granger','Granger, Texas',30546,51);
INSERT INTO "django_geo_db_city" VALUES(25059,'Hamilton','Hamilton, Texas',30547,51);
INSERT INTO "django_geo_db_city" VALUES(25060,'Heidenheimer','Heidenheimer, Texas',30548,51);
INSERT INTO "django_geo_db_city" VALUES(25061,'Holland','Holland, Texas',30549,51);
INSERT INTO "django_geo_db_city" VALUES(25062,'Jarrell','Jarrell, Texas',30550,51);
INSERT INTO "django_geo_db_city" VALUES(25063,'Jonesboro','Jonesboro, Texas',30551,51);
INSERT INTO "django_geo_db_city" VALUES(25064,'Kempner','Kempner, Texas',30552,51);
INSERT INTO "django_geo_db_city" VALUES(25065,'Killeen','Killeen, Texas',30553,51);
INSERT INTO "django_geo_db_city" VALUES(25066,'Harker Heights','Harker Heights, Texas',30558,51);
INSERT INTO "django_geo_db_city" VALUES(25067,'Lampasas','Lampasas, Texas',30560,51);
INSERT INTO "django_geo_db_city" VALUES(25068,'Leon Junction','Leon Junction, Texas',30561,51);
INSERT INTO "django_geo_db_city" VALUES(25069,'Little River','Little River, Texas',30562,51);
INSERT INTO "django_geo_db_city" VALUES(25070,'Maysfield','Maysfield, Texas',30563,51);
INSERT INTO "django_geo_db_city" VALUES(25071,'Milano','Milano, Texas',30564,51);
INSERT INTO "django_geo_db_city" VALUES(25072,'Moody','Moody, Texas',30565,51);
INSERT INTO "django_geo_db_city" VALUES(25073,'Mound','Mound, Texas',30566,51);
INSERT INTO "django_geo_db_city" VALUES(25074,'Nolanville','Nolanville, Texas',30567,51);
INSERT INTO "django_geo_db_city" VALUES(25075,'Oglesby','Oglesby, Texas',30568,51);
INSERT INTO "django_geo_db_city" VALUES(25076,'Pendleton','Pendleton, Texas',30533,51);
INSERT INTO "django_geo_db_city" VALUES(25077,'Pottsville','Pottsville, Texas',30569,51);
INSERT INTO "django_geo_db_city" VALUES(25078,'Purmela','Purmela, Texas',30570,51);
INSERT INTO "django_geo_db_city" VALUES(25079,'Rockdale','Rockdale, Texas',30571,51);
INSERT INTO "django_geo_db_city" VALUES(25080,'Rogers','Rogers, Texas',30572,51);
INSERT INTO "django_geo_db_city" VALUES(25081,'Rosebud','Rosebud, Texas',30573,51);
INSERT INTO "django_geo_db_city" VALUES(25082,'Salado','Salado, Texas',30574,51);
INSERT INTO "django_geo_db_city" VALUES(25083,'Schwertner','Schwertner, Texas',30575,51);
INSERT INTO "django_geo_db_city" VALUES(25084,'Taylor','Taylor, Texas',30576,51);
INSERT INTO "django_geo_db_city" VALUES(25085,'Thorndale','Thorndale, Texas',30578,51);
INSERT INTO "django_geo_db_city" VALUES(25086,'Thrall','Thrall, Texas',30579,51);
INSERT INTO "django_geo_db_city" VALUES(25087,'Troy','Troy, Texas',30580,51);
INSERT INTO "django_geo_db_city" VALUES(25088,'Milford','Milford, Texas',30583,51);
INSERT INTO "django_geo_db_city" VALUES(25089,'Richland','Richland, Texas',30584,51);
INSERT INTO "django_geo_db_city" VALUES(25090,'Abbott','Abbott, Texas',30585,51);
INSERT INTO "django_geo_db_city" VALUES(25091,'Aquilla','Aquilla, Texas',30586,51);
INSERT INTO "django_geo_db_city" VALUES(25092,'Avalon','Avalon, Texas',30587,51);
INSERT INTO "django_geo_db_city" VALUES(25093,'Axtell','Axtell, Texas',30588,51);
INSERT INTO "django_geo_db_city" VALUES(25094,'Blooming Grove','Blooming Grove, Texas',30589,51);
INSERT INTO "django_geo_db_city" VALUES(25095,'Blum','Blum, Texas',30590,51);
INSERT INTO "django_geo_db_city" VALUES(25096,'Brandon','Brandon, Texas',30591,51);
INSERT INTO "django_geo_db_city" VALUES(25097,'Bremond','Bremond, Texas',30592,51);
INSERT INTO "django_geo_db_city" VALUES(25098,'Bruceville','Bruceville, Texas',30593,51);
INSERT INTO "django_geo_db_city" VALUES(25099,'Bynum','Bynum, Texas',30594,51);
INSERT INTO "django_geo_db_city" VALUES(25100,'Chilton','Chilton, Texas',30595,51);
INSERT INTO "django_geo_db_city" VALUES(25101,'China Spring','China Spring, Texas',30596,51);
INSERT INTO "django_geo_db_city" VALUES(25102,'Clifton','Clifton, Texas',30597,51);
INSERT INTO "django_geo_db_city" VALUES(25103,'Coolidge','Coolidge, Texas',30598,51);
INSERT INTO "django_geo_db_city" VALUES(25104,'Covington','Covington, Texas',30599,51);
INSERT INTO "django_geo_db_city" VALUES(25105,'Cranfills Gap','Cranfills Gap, Texas',30600,51);
INSERT INTO "django_geo_db_city" VALUES(25106,'Crawford','Crawford, Texas',30601,51);
INSERT INTO "django_geo_db_city" VALUES(25107,'Dawson','Dawson, Texas',30602,51);
INSERT INTO "django_geo_db_city" VALUES(25108,'Elm Mott','Elm Mott, Texas',30603,51);
INSERT INTO "django_geo_db_city" VALUES(25109,'Frost','Frost, Texas',30604,51);
INSERT INTO "django_geo_db_city" VALUES(25110,'Groesbeck','Groesbeck, Texas',30605,51);
INSERT INTO "django_geo_db_city" VALUES(25111,'Hewitt','Hewitt, Texas',30606,51);
INSERT INTO "django_geo_db_city" VALUES(25112,'Laguna Park','Laguna Park, Texas',30607,51);
INSERT INTO "django_geo_db_city" VALUES(25113,'Hillsboro','Hillsboro, Texas',30608,51);
INSERT INTO "django_geo_db_city" VALUES(25114,'Hubbard','Hubbard, Texas',30609,51);
INSERT INTO "django_geo_db_city" VALUES(25115,'Iredell','Iredell, Texas',30610,51);
INSERT INTO "django_geo_db_city" VALUES(25116,'Irene','Irene, Texas',30611,51);
INSERT INTO "django_geo_db_city" VALUES(25117,'Italy','Italy, Texas',30612,51);
INSERT INTO "django_geo_db_city" VALUES(25118,'Kopperl','Kopperl, Texas',30613,51);
INSERT INTO "django_geo_db_city" VALUES(25119,'Kosse','Kosse, Texas',30614,51);
INSERT INTO "django_geo_db_city" VALUES(25120,'Leroy','Leroy, Texas',30615,51);
INSERT INTO "django_geo_db_city" VALUES(25121,'Lorena','Lorena, Texas',30616,51);
INSERT INTO "django_geo_db_city" VALUES(25122,'Lott','Lott, Texas',30617,51);
INSERT INTO "django_geo_db_city" VALUES(25123,'McGregor','McGregor, Texas',30618,51);
INSERT INTO "django_geo_db_city" VALUES(25124,'Malone','Malone, Texas',30619,51);
INSERT INTO "django_geo_db_city" VALUES(25125,'Marlin','Marlin, Texas',30620,51);
INSERT INTO "django_geo_db_city" VALUES(25126,'Mart','Mart, Texas',30621,51);
INSERT INTO "django_geo_db_city" VALUES(25127,'Meridian','Meridian, Texas',30622,51);
INSERT INTO "django_geo_db_city" VALUES(25128,'Mertens','Mertens, Texas',30623,51);
INSERT INTO "django_geo_db_city" VALUES(25129,'Mexia','Mexia, Texas',30624,51);
INSERT INTO "django_geo_db_city" VALUES(25130,'Morgan','Morgan, Texas',30626,51);
INSERT INTO "django_geo_db_city" VALUES(25131,'Mount Calm','Mount Calm, Texas',30627,51);
INSERT INTO "django_geo_db_city" VALUES(25132,'Otto','Otto, Texas',30628,51);
INSERT INTO "django_geo_db_city" VALUES(25133,'Penelope','Penelope, Texas',30629,51);
INSERT INTO "django_geo_db_city" VALUES(25134,'Perry','Perry, Texas',30630,51);
INSERT INTO "django_geo_db_city" VALUES(25135,'Prairie Hill','Prairie Hill, Texas',30631,51);
INSERT INTO "django_geo_db_city" VALUES(25136,'Purdon','Purdon, Texas',30632,51);
INSERT INTO "django_geo_db_city" VALUES(25137,'Reagan','Reagan, Texas',30633,51);
INSERT INTO "django_geo_db_city" VALUES(25138,'Riesel','Riesel, Texas',30635,51);
INSERT INTO "django_geo_db_city" VALUES(25139,'Ross','Ross, Texas',30637,51);
INSERT INTO "django_geo_db_city" VALUES(25140,'Satin','Satin, Texas',30638,51);
INSERT INTO "django_geo_db_city" VALUES(25141,'Tehuacana','Tehuacana, Texas',30639,51);
INSERT INTO "django_geo_db_city" VALUES(25142,'Thornton','Thornton, Texas',30640,51);
INSERT INTO "django_geo_db_city" VALUES(25143,'Valley Mills','Valley Mills, Texas',30641,51);
INSERT INTO "django_geo_db_city" VALUES(25144,'Walnut Springs','Walnut Springs, Texas',30642,51);
INSERT INTO "django_geo_db_city" VALUES(25145,'West','West, Texas',30643,51);
INSERT INTO "django_geo_db_city" VALUES(25146,'Whitney','Whitney, Texas',30644,51);
INSERT INTO "django_geo_db_city" VALUES(25147,'Wortham','Wortham, Texas',30645,51);
INSERT INTO "django_geo_db_city" VALUES(25148,'Waco','Waco, Texas',30646,51);
INSERT INTO "django_geo_db_city" VALUES(25149,'Woodway','Woodway, Texas',30655,51);
INSERT INTO "django_geo_db_city" VALUES(25150,'Brownwood','Brownwood, Texas',30658,51);
INSERT INTO "django_geo_db_city" VALUES(25151,'Early','Early, Texas',30659,51);
INSERT INTO "django_geo_db_city" VALUES(25152,'Art','Art, Texas',30662,51);
INSERT INTO "django_geo_db_city" VALUES(25153,'Ballinger','Ballinger, Texas',30663,51);
INSERT INTO "django_geo_db_city" VALUES(25154,'Bangs','Bangs, Texas',30664,51);
INSERT INTO "django_geo_db_city" VALUES(25155,'Bend','Bend, Texas',30665,51);
INSERT INTO "django_geo_db_city" VALUES(25156,'Brady','Brady, Texas',30666,51);
INSERT INTO "django_geo_db_city" VALUES(25157,'Brookesmith','Brookesmith, Texas',30667,51);
INSERT INTO "django_geo_db_city" VALUES(25158,'Burkett','Burkett, Texas',30668,51);
INSERT INTO "django_geo_db_city" VALUES(25159,'Castell','Castell, Texas',30669,51);
INSERT INTO "django_geo_db_city" VALUES(25160,'Cherokee','Cherokee, Texas',30670,51);
INSERT INTO "django_geo_db_city" VALUES(25161,'Coleman','Coleman, Texas',30671,51);
INSERT INTO "django_geo_db_city" VALUES(25162,'Doole','Doole, Texas',30672,51);
INSERT INTO "django_geo_db_city" VALUES(25163,'Eden','Eden, Texas',30673,51);
INSERT INTO "django_geo_db_city" VALUES(25164,'Fort McKavett','Fort McKavett, Texas',30674,51);
INSERT INTO "django_geo_db_city" VALUES(25165,'Fredonia','Fredonia, Texas',30675,51);
INSERT INTO "django_geo_db_city" VALUES(25166,'Goldthwaite','Goldthwaite, Texas',30676,51);
INSERT INTO "django_geo_db_city" VALUES(25167,'Gouldbusk','Gouldbusk, Texas',30677,51);
INSERT INTO "django_geo_db_city" VALUES(25168,'Hext','Hext, Texas',30678,51);
INSERT INTO "django_geo_db_city" VALUES(25169,'Junction','Junction, Texas',30679,51);
INSERT INTO "django_geo_db_city" VALUES(25170,'Lohn','Lohn, Texas',30680,51);
INSERT INTO "django_geo_db_city" VALUES(25171,'Lometa','Lometa, Texas',30681,51);
INSERT INTO "django_geo_db_city" VALUES(25172,'London','London, Texas',30682,51);
INSERT INTO "django_geo_db_city" VALUES(25173,'Lowake','Lowake, Texas',30683,51);
INSERT INTO "django_geo_db_city" VALUES(25174,'Mason','Mason, Texas',30684,51);
INSERT INTO "django_geo_db_city" VALUES(25175,'May','May, Texas',30685,51);
INSERT INTO "django_geo_db_city" VALUES(25176,'Melvin','Melvin, Texas',30686,51);
INSERT INTO "django_geo_db_city" VALUES(25177,'Menard','Menard, Texas',30687,51);
INSERT INTO "django_geo_db_city" VALUES(25178,'Miles','Miles, Texas',30688,51);
INSERT INTO "django_geo_db_city" VALUES(25179,'Millersview','Millersview, Texas',30689,51);
INSERT INTO "django_geo_db_city" VALUES(25180,'Mullin','Mullin, Texas',30690,51);
INSERT INTO "django_geo_db_city" VALUES(25181,'Norton','Norton, Texas',30691,51);
INSERT INTO "django_geo_db_city" VALUES(25182,'Paint Rock','Paint Rock, Texas',30692,51);
INSERT INTO "django_geo_db_city" VALUES(25183,'Pear Valley','Pear Valley, Texas',30672,51);
INSERT INTO "django_geo_db_city" VALUES(25184,'Pontotoc','Pontotoc, Texas',30693,51);
INSERT INTO "django_geo_db_city" VALUES(25185,'Priddy','Priddy, Texas',30694,51);
INSERT INTO "django_geo_db_city" VALUES(25186,'Richland Springs','Richland Springs, Texas',30695,51);
INSERT INTO "django_geo_db_city" VALUES(25187,'Rochelle','Rochelle, Texas',30696,51);
INSERT INTO "django_geo_db_city" VALUES(25188,'Rockwood','Rockwood, Texas',30697,51);
INSERT INTO "django_geo_db_city" VALUES(25189,'Roosevelt','Roosevelt, Texas',30698,51);
INSERT INTO "django_geo_db_city" VALUES(25190,'Rowena','Rowena, Texas',30699,51);
INSERT INTO "django_geo_db_city" VALUES(25191,'San Saba','San Saba, Texas',30700,51);
INSERT INTO "django_geo_db_city" VALUES(25192,'Santa Anna','Santa Anna, Texas',30701,51);
INSERT INTO "django_geo_db_city" VALUES(25193,'Star','Star, Texas',30702,51);
INSERT INTO "django_geo_db_city" VALUES(25194,'Talpa','Talpa, Texas',30703,51);
INSERT INTO "django_geo_db_city" VALUES(25195,'Telegraph','Telegraph, Texas',30704,51);
INSERT INTO "django_geo_db_city" VALUES(25196,'Valera','Valera, Texas',30705,51);
INSERT INTO "django_geo_db_city" VALUES(25197,'Valley Spring','Valley Spring, Texas',30706,51);
INSERT INTO "django_geo_db_city" VALUES(25198,'Veribest','Veribest, Texas',30707,51);
INSERT INTO "django_geo_db_city" VALUES(25199,'Voca','Voca, Texas',30708,51);
INSERT INTO "django_geo_db_city" VALUES(25200,'Voss','Voss, Texas',30709,51);
INSERT INTO "django_geo_db_city" VALUES(25201,'Zephyr','Zephyr, Texas',30710,51);
INSERT INTO "django_geo_db_city" VALUES(25202,'San Angelo','San Angelo, Texas',30711,51);
INSERT INTO "django_geo_db_city" VALUES(25203,'Goodfellow AFB','Goodfellow AFB, Texas',30712,51);
INSERT INTO "django_geo_db_city" VALUES(25204,'Barnhart','Barnhart, Texas',30717,51);
INSERT INTO "django_geo_db_city" VALUES(25205,'Big Lake','Big Lake, Texas',30718,51);
INSERT INTO "django_geo_db_city" VALUES(25206,'Bronte','Bronte, Texas',30719,51);
INSERT INTO "django_geo_db_city" VALUES(25207,'Carlsbad','Carlsbad, Texas',30720,51);
INSERT INTO "django_geo_db_city" VALUES(25208,'Christoval','Christoval, Texas',30721,51);
INSERT INTO "django_geo_db_city" VALUES(25209,'Eldorado','Eldorado, Texas',30722,51);
INSERT INTO "django_geo_db_city" VALUES(25210,'Eola','Eola, Texas',30723,51);
INSERT INTO "django_geo_db_city" VALUES(25211,'Knickerbocker','Knickerbocker, Texas',30724,51);
INSERT INTO "django_geo_db_city" VALUES(25212,'Mereta','Mereta, Texas',30725,51);
INSERT INTO "django_geo_db_city" VALUES(25213,'Mertzon','Mertzon, Texas',30726,51);
INSERT INTO "django_geo_db_city" VALUES(25214,'Ozona','Ozona, Texas',30727,51);
INSERT INTO "django_geo_db_city" VALUES(25215,'Robert Lee','Robert Lee, Texas',30728,51);
INSERT INTO "django_geo_db_city" VALUES(25216,'Silver','Silver, Texas',30729,51);
INSERT INTO "django_geo_db_city" VALUES(25217,'Sonora','Sonora, Texas',30730,51);
INSERT INTO "django_geo_db_city" VALUES(25218,'Sterling City','Sterling City, Texas',30731,51);
INSERT INTO "django_geo_db_city" VALUES(25219,'Tennyson','Tennyson, Texas',30732,51);
INSERT INTO "django_geo_db_city" VALUES(25220,'Vancourt','Vancourt, Texas',30733,51);
INSERT INTO "django_geo_db_city" VALUES(25221,'Wall','Wall, Texas',30734,51);
INSERT INTO "django_geo_db_city" VALUES(25222,'Water Valley','Water Valley, Texas',30735,51);
INSERT INTO "django_geo_db_city" VALUES(25223,'Houston','Houston, Texas',30736,51);
INSERT INTO "django_geo_db_city" VALUES(25224,'Conroe','Conroe, Texas',30838,51);
INSERT INTO "django_geo_db_city" VALUES(25225,'North Houston','North Houston, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25226,'Montgomery','Montgomery, Texas',30844,51);
INSERT INTO "django_geo_db_city" VALUES(25227,'Willis','Willis, Texas',30845,51);
INSERT INTO "django_geo_db_city" VALUES(25228,'Huntsville','Huntsville, Texas',30846,51);
INSERT INTO "django_geo_db_city" VALUES(25229,'Humble','Humble, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25230,'Ace','Ace, Texas',30847,51);
INSERT INTO "django_geo_db_city" VALUES(25231,'Cleveland','Cleveland, Texas',30848,51);
INSERT INTO "django_geo_db_city" VALUES(25232,'Coldspring','Coldspring, Texas',30850,51);
INSERT INTO "django_geo_db_city" VALUES(25233,'Dallardsville','Dallardsville, Texas',30851,51);
INSERT INTO "django_geo_db_city" VALUES(25234,'Dobbin','Dobbin, Texas',30852,51);
INSERT INTO "django_geo_db_city" VALUES(25235,'Dodge','Dodge, Texas',30853,51);
INSERT INTO "django_geo_db_city" VALUES(25236,'Goodrich','Goodrich, Texas',30854,51);
INSERT INTO "django_geo_db_city" VALUES(25237,'Huffman','Huffman, Texas',30855,51);
INSERT INTO "django_geo_db_city" VALUES(25238,'Hufsmith','Hufsmith, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25239,'Leggett','Leggett, Texas',30863,51);
INSERT INTO "django_geo_db_city" VALUES(25240,'Livingston','Livingston, Texas',30864,51);
INSERT INTO "django_geo_db_city" VALUES(25241,'Magnolia','Magnolia, Texas',30865,51);
INSERT INTO "django_geo_db_city" VALUES(25242,'New Caney','New Caney, Texas',30869,51);
INSERT INTO "django_geo_db_city" VALUES(25243,'New Waverly','New Waverly, Texas',30870,51);
INSERT INTO "django_geo_db_city" VALUES(25244,'Oakhurst','Oakhurst, Texas',30871,51);
INSERT INTO "django_geo_db_city" VALUES(25245,'Onalaska','Onalaska, Texas',30872,51);
INSERT INTO "django_geo_db_city" VALUES(25246,'Pinehurst','Pinehurst, Texas',30873,51);
INSERT INTO "django_geo_db_city" VALUES(25247,'Plantersville','Plantersville, Texas',30874,51);
INSERT INTO "django_geo_db_city" VALUES(25248,'Pointblank','Pointblank, Texas',30875,51);
INSERT INTO "django_geo_db_city" VALUES(25249,'Porter','Porter, Texas',30876,51);
INSERT INTO "django_geo_db_city" VALUES(25250,'Riverside','Riverside, Texas',30877,51);
INSERT INTO "django_geo_db_city" VALUES(25251,'Romayor','Romayor, Texas',30878,51);
INSERT INTO "django_geo_db_city" VALUES(25252,'Rye','Rye, Texas',30879,51);
INSERT INTO "django_geo_db_city" VALUES(25253,'Shepherd','Shepherd, Texas',30880,51);
INSERT INTO "django_geo_db_city" VALUES(25254,'Splendora','Splendora, Texas',30881,51);
INSERT INTO "django_geo_db_city" VALUES(25255,'Spring','Spring, Texas',30882,51);
INSERT INTO "django_geo_db_city" VALUES(25256,'Thicket','Thicket, Texas',30883,51);
INSERT INTO "django_geo_db_city" VALUES(25257,'Tomball','Tomball, Texas',30884,51);
INSERT INTO "django_geo_db_city" VALUES(25258,'Votaw','Votaw, Texas',30885,51);
INSERT INTO "django_geo_db_city" VALUES(25259,'Bellaire','Bellaire, Texas',30899,51);
INSERT INTO "django_geo_db_city" VALUES(25260,'Bay City','Bay City, Texas',30900,51);
INSERT INTO "django_geo_db_city" VALUES(25261,'Richmond','Richmond, Texas',30901,51);
INSERT INTO "django_geo_db_city" VALUES(25262,'Cypress','Cypress, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25263,'Alief','Alief, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25264,'Altair','Altair, Texas',30902,51);
INSERT INTO "django_geo_db_city" VALUES(25265,'Barker','Barker, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25266,'Cedar Lane','Cedar Lane, Texas',30904,51);
INSERT INTO "django_geo_db_city" VALUES(25267,'Beasley','Beasley, Texas',30905,51);
INSERT INTO "django_geo_db_city" VALUES(25268,'Bellville','Bellville, Texas',30906,51);
INSERT INTO "django_geo_db_city" VALUES(25269,'Blessing','Blessing, Texas',30907,51);
INSERT INTO "django_geo_db_city" VALUES(25270,'Boling','Boling, Texas',30908,51);
INSERT INTO "django_geo_db_city" VALUES(25271,'Brazoria','Brazoria, Texas',30909,51);
INSERT INTO "django_geo_db_city" VALUES(25272,'Brookshire','Brookshire, Texas',30910,51);
INSERT INTO "django_geo_db_city" VALUES(25273,'Chappell Hill','Chappell Hill, Texas',30911,51);
INSERT INTO "django_geo_db_city" VALUES(25274,'Collegeport','Collegeport, Texas',30912,51);
INSERT INTO "django_geo_db_city" VALUES(25275,'Damon','Damon, Texas',30914,51);
INSERT INTO "django_geo_db_city" VALUES(25276,'Danciger','Danciger, Texas',30915,51);
INSERT INTO "django_geo_db_city" VALUES(25277,'Danevang','Danevang, Texas',30916,51);
INSERT INTO "django_geo_db_city" VALUES(25278,'Eagle Lake','Eagle Lake, Texas',30918,51);
INSERT INTO "django_geo_db_city" VALUES(25279,'East Bernard','East Bernard, Texas',30919,51);
INSERT INTO "django_geo_db_city" VALUES(25280,'Egypt','Egypt, Texas',30920,51);
INSERT INTO "django_geo_db_city" VALUES(25281,'El Campo','El Campo, Texas',30921,51);
INSERT INTO "django_geo_db_city" VALUES(25282,'San Leon','San Leon, Texas',30922,51);
INSERT INTO "django_geo_db_city" VALUES(25283,'Elmaton','Elmaton, Texas',30923,51);
INSERT INTO "django_geo_db_city" VALUES(25284,'Fulshear','Fulshear, Texas',30924,51);
INSERT INTO "django_geo_db_city" VALUES(25285,'Garwood','Garwood, Texas',30925,51);
INSERT INTO "django_geo_db_city" VALUES(25286,'Glen Flora','Glen Flora, Texas',30926,51);
INSERT INTO "django_geo_db_city" VALUES(25287,'Guy','Guy, Texas',30927,51);
INSERT INTO "django_geo_db_city" VALUES(25288,'Hempstead','Hempstead, Texas',30928,51);
INSERT INTO "django_geo_db_city" VALUES(25289,'Prairie View','Prairie View, Texas',30929,51);
INSERT INTO "django_geo_db_city" VALUES(25290,'Hockley','Hockley, Texas',30930,51);
INSERT INTO "django_geo_db_city" VALUES(25291,'Hungerford','Hungerford, Texas',30931,51);
INSERT INTO "django_geo_db_city" VALUES(25292,'Katy','Katy, Texas',30932,51);
INSERT INTO "django_geo_db_city" VALUES(25293,'Kendleton','Kendleton, Texas',30934,51);
INSERT INTO "django_geo_db_city" VALUES(25294,'Kenney','Kenney, Texas',30935,51);
INSERT INTO "django_geo_db_city" VALUES(25295,'Lane City','Lane City, Texas',30936,51);
INSERT INTO "django_geo_db_city" VALUES(25296,'Lissie','Lissie, Texas',30937,51);
INSERT INTO "django_geo_db_city" VALUES(25297,'Louise','Louise, Texas',30938,51);
INSERT INTO "django_geo_db_city" VALUES(25298,'Markham','Markham, Texas',30939,51);
INSERT INTO "django_geo_db_city" VALUES(25299,'Matagorda','Matagorda, Texas',30940,51);
INSERT INTO "django_geo_db_city" VALUES(25300,'Midfield','Midfield, Texas',30941,51);
INSERT INTO "django_geo_db_city" VALUES(25301,'Missouri City','Missouri City, Texas',30942,51);
INSERT INTO "django_geo_db_city" VALUES(25302,'Nada','Nada, Texas',30943,51);
INSERT INTO "django_geo_db_city" VALUES(25303,'Needville','Needville, Texas',30944,51);
INSERT INTO "django_geo_db_city" VALUES(25304,'Newgulf','Newgulf, Texas',30945,51);
INSERT INTO "django_geo_db_city" VALUES(25305,'Old Ocean','Old Ocean, Texas',30946,51);
INSERT INTO "django_geo_db_city" VALUES(25306,'Orchard','Orchard, Texas',30947,51);
INSERT INTO "django_geo_db_city" VALUES(25307,'Palacios','Palacios, Texas',30948,51);
INSERT INTO "django_geo_db_city" VALUES(25308,'Pattison','Pattison, Texas',30949,51);
INSERT INTO "django_geo_db_city" VALUES(25309,'Pierce','Pierce, Texas',30950,51);
INSERT INTO "django_geo_db_city" VALUES(25310,'Pledger','Pledger, Texas',30951,51);
INSERT INTO "django_geo_db_city" VALUES(25311,'Rock Island','Rock Island, Texas',30953,51);
INSERT INTO "django_geo_db_city" VALUES(25312,'Rosenberg','Rosenberg, Texas',30954,51);
INSERT INTO "django_geo_db_city" VALUES(25313,'San Felipe','San Felipe, Texas',30955,51);
INSERT INTO "django_geo_db_city" VALUES(25314,'Sealy','Sealy, Texas',30956,51);
INSERT INTO "django_geo_db_city" VALUES(25315,'Sheridan','Sheridan, Texas',30957,51);
INSERT INTO "django_geo_db_city" VALUES(25316,'Simonton','Simonton, Texas',30958,51);
INSERT INTO "django_geo_db_city" VALUES(25317,'Stafford','Stafford, Texas',30959,51);
INSERT INTO "django_geo_db_city" VALUES(25318,'Sugar Land','Sugar Land, Texas',30960,51);
INSERT INTO "django_geo_db_city" VALUES(25319,'Sweeny','Sweeny, Texas',30962,51);
INSERT INTO "django_geo_db_city" VALUES(25320,'Thompsons','Thompsons, Texas',30963,51);
INSERT INTO "django_geo_db_city" VALUES(25321,'Van Vleck','Van Vleck, Texas',30964,51);
INSERT INTO "django_geo_db_city" VALUES(25322,'Wadsworth','Wadsworth, Texas',30965,51);
INSERT INTO "django_geo_db_city" VALUES(25323,'Waller','Waller, Texas',30966,51);
INSERT INTO "django_geo_db_city" VALUES(25324,'Wallis','Wallis, Texas',30967,51);
INSERT INTO "django_geo_db_city" VALUES(25325,'West Columbia','West Columbia, Texas',30968,51);
INSERT INTO "django_geo_db_city" VALUES(25326,'Wharton','Wharton, Texas',30970,51);
INSERT INTO "django_geo_db_city" VALUES(25327,'Pasadena','Pasadena, Texas',30833,51);
INSERT INTO "django_geo_db_city" VALUES(25328,'Santa Fe','Santa Fe, Texas',30981,51);
INSERT INTO "django_geo_db_city" VALUES(25329,'Alvin','Alvin, Texas',30982,51);
INSERT INTO "django_geo_db_city" VALUES(25330,'Anahuac','Anahuac, Texas',30984,51);
INSERT INTO "django_geo_db_city" VALUES(25331,'Angleton','Angleton, Texas',30985,51);
INSERT INTO "django_geo_db_city" VALUES(25332,'Bacliff','Bacliff, Texas',30988,51);
INSERT INTO "django_geo_db_city" VALUES(25333,'Batson','Batson, Texas',30989,51);
INSERT INTO "django_geo_db_city" VALUES(25334,'Baytown','Baytown, Texas',30990,51);
INSERT INTO "django_geo_db_city" VALUES(25335,'Channelview','Channelview, Texas',30992,51);
INSERT INTO "django_geo_db_city" VALUES(25336,'Clute','Clute, Texas',30993,51);
INSERT INTO "django_geo_db_city" VALUES(25337,'Crosby','Crosby, Texas',30994,51);
INSERT INTO "django_geo_db_city" VALUES(25338,'Daisetta','Daisetta, Texas',30995,51);
INSERT INTO "django_geo_db_city" VALUES(25339,'Danbury','Danbury, Texas',30996,51);
INSERT INTO "django_geo_db_city" VALUES(25340,'Dayton','Dayton, Texas',30997,51);
INSERT INTO "django_geo_db_city" VALUES(25341,'Deer Park','Deer Park, Texas',30998,51);
INSERT INTO "django_geo_db_city" VALUES(25342,'Dickinson','Dickinson, Texas',30999,51);
INSERT INTO "django_geo_db_city" VALUES(25343,'Devers','Devers, Texas',31000,51);
INSERT INTO "django_geo_db_city" VALUES(25344,'Freeport','Freeport, Texas',31002,51);
INSERT INTO "django_geo_db_city" VALUES(25345,'Fresno','Fresno, Texas',31003,51);
INSERT INTO "django_geo_db_city" VALUES(25346,'Friendswood','Friendswood, Texas',31004,51);
INSERT INTO "django_geo_db_city" VALUES(25347,'Galena Park','Galena Park, Texas',31005,51);
INSERT INTO "django_geo_db_city" VALUES(25348,'Galveston','Galveston, Texas',31007,51);
INSERT INTO "django_geo_db_city" VALUES(25349,'Hankamer','Hankamer, Texas',31012,51);
INSERT INTO "django_geo_db_city" VALUES(25350,'Hardin','Hardin, Texas',31013,51);
INSERT INTO "django_geo_db_city" VALUES(25351,'Highlands','Highlands, Texas',31014,51);
INSERT INTO "django_geo_db_city" VALUES(25352,'Hitchcock','Hitchcock, Texas',31015,51);
INSERT INTO "django_geo_db_city" VALUES(25353,'Hull','Hull, Texas',31016,51);
INSERT INTO "django_geo_db_city" VALUES(25354,'Kemah','Kemah, Texas',31017,51);
INSERT INTO "django_geo_db_city" VALUES(25355,'Lake Jackson','Lake Jackson, Texas',31018,51);
INSERT INTO "django_geo_db_city" VALUES(25356,'League City','League City, Texas',31019,51);
INSERT INTO "django_geo_db_city" VALUES(25357,'La Marque','La Marque, Texas',31020,51);
INSERT INTO "django_geo_db_city" VALUES(25358,'La Porte','La Porte, Texas',31021,51);
INSERT INTO "django_geo_db_city" VALUES(25359,'Liberty','Liberty, Texas',31024,51);
INSERT INTO "django_geo_db_city" VALUES(25360,'Liverpool','Liverpool, Texas',31025,51);
INSERT INTO "django_geo_db_city" VALUES(25361,'Manvel','Manvel, Texas',31026,51);
INSERT INTO "django_geo_db_city" VALUES(25362,'Mont Belvieu','Mont Belvieu, Texas',31027,51);
INSERT INTO "django_geo_db_city" VALUES(25363,'Pearland','Pearland, Texas',31028,51);
INSERT INTO "django_geo_db_city" VALUES(25364,'Raywood','Raywood, Texas',31029,51);
INSERT INTO "django_geo_db_city" VALUES(25365,'Rosharon','Rosharon, Texas',31030,51);
INSERT INTO "django_geo_db_city" VALUES(25366,'Saratoga','Saratoga, Texas',31032,51);
INSERT INTO "django_geo_db_city" VALUES(25367,'Seabrook','Seabrook, Texas',31033,51);
INSERT INTO "django_geo_db_city" VALUES(25368,'South Houston','South Houston, Texas',31034,51);
INSERT INTO "django_geo_db_city" VALUES(25369,'Texas City','Texas City, Texas',31036,51);
INSERT INTO "django_geo_db_city" VALUES(25370,'Wallisville','Wallisville, Texas',31039,51);
INSERT INTO "django_geo_db_city" VALUES(25371,'Webster','Webster, Texas',31040,51);
INSERT INTO "django_geo_db_city" VALUES(25372,'Bridge City','Bridge City, Texas',31041,51);
INSERT INTO "django_geo_db_city" VALUES(25373,'Buna','Buna, Texas',31042,51);
INSERT INTO "django_geo_db_city" VALUES(25374,'China','China, Texas',31043,51);
INSERT INTO "django_geo_db_city" VALUES(25375,'Deweyville','Deweyville, Texas',31044,51);
INSERT INTO "django_geo_db_city" VALUES(25376,'Evadale','Evadale, Texas',31045,51);
INSERT INTO "django_geo_db_city" VALUES(25377,'Fred','Fred, Texas',31046,51);
INSERT INTO "django_geo_db_city" VALUES(25378,'Gilchrist','Gilchrist, Texas',31047,51);
INSERT INTO "django_geo_db_city" VALUES(25379,'Groves','Groves, Texas',31048,51);
INSERT INTO "django_geo_db_city" VALUES(25380,'Hamshire','Hamshire, Texas',31049,51);
INSERT INTO "django_geo_db_city" VALUES(25381,'High Island','High Island, Texas',31050,51);
INSERT INTO "django_geo_db_city" VALUES(25382,'Hillister','Hillister, Texas',31051,51);
INSERT INTO "django_geo_db_city" VALUES(25383,'Kountze','Kountze, Texas',31052,51);
INSERT INTO "django_geo_db_city" VALUES(25384,'Mauriceville','Mauriceville, Texas',31053,51);
INSERT INTO "django_geo_db_city" VALUES(25385,'Nederland','Nederland, Texas',31054,51);
INSERT INTO "django_geo_db_city" VALUES(25386,'Nome','Nome, Texas',31055,51);
INSERT INTO "django_geo_db_city" VALUES(25387,'Orange','Orange, Texas',31056,51);
INSERT INTO "django_geo_db_city" VALUES(25388,'Brenham','Brenham, Texas',31059,51);
INSERT INTO "django_geo_db_city" VALUES(25389,'Orangefield','Orangefield, Texas',31060,51);
INSERT INTO "django_geo_db_city" VALUES(25390,'Port Arthur','Port Arthur, Texas',31061,51);
INSERT INTO "django_geo_db_city" VALUES(25391,'Port Bolivar','Port Bolivar, Texas',31065,51);
INSERT INTO "django_geo_db_city" VALUES(25392,'Port Neches','Port Neches, Texas',31066,51);
INSERT INTO "django_geo_db_city" VALUES(25393,'Sabine Pass','Sabine Pass, Texas',31067,51);
INSERT INTO "django_geo_db_city" VALUES(25394,'Silsbee','Silsbee, Texas',31068,51);
INSERT INTO "django_geo_db_city" VALUES(25395,'Lumberton','Lumberton, Texas',31069,51);
INSERT INTO "django_geo_db_city" VALUES(25396,'Sour Lake','Sour Lake, Texas',31070,51);
INSERT INTO "django_geo_db_city" VALUES(25397,'Spurger','Spurger, Texas',31071,51);
INSERT INTO "django_geo_db_city" VALUES(25398,'Stowell','Stowell, Texas',31072,51);
INSERT INTO "django_geo_db_city" VALUES(25399,'Vidor','Vidor, Texas',31073,51);
INSERT INTO "django_geo_db_city" VALUES(25400,'Village Mills','Village Mills, Texas',31074,51);
INSERT INTO "django_geo_db_city" VALUES(25401,'Warren','Warren, Texas',31075,51);
INSERT INTO "django_geo_db_city" VALUES(25402,'Winnie','Winnie, Texas',31076,51);
INSERT INTO "django_geo_db_city" VALUES(25403,'Beaumont','Beaumont, Texas',31077,51);
INSERT INTO "django_geo_db_city" VALUES(25404,'Voth','Voth, Texas',31085,51);
INSERT INTO "django_geo_db_city" VALUES(25405,'Bryan','Bryan, Texas',31089,51);
INSERT INTO "django_geo_db_city" VALUES(25406,'Anderson','Anderson, Texas',31095,51);
INSERT INTO "django_geo_db_city" VALUES(25407,'Bedias','Bedias, Texas',31096,51);
INSERT INTO "django_geo_db_city" VALUES(25408,'Burton','Burton, Texas',31099,51);
INSERT INTO "django_geo_db_city" VALUES(25409,'Caldwell','Caldwell, Texas',31100,51);
INSERT INTO "django_geo_db_city" VALUES(25410,'Calvert','Calvert, Texas',31101,51);
INSERT INTO "django_geo_db_city" VALUES(25411,'Chriesman','Chriesman, Texas',31102,51);
INSERT INTO "django_geo_db_city" VALUES(25412,'Clay','Clay, Texas',31103,51);
INSERT INTO "django_geo_db_city" VALUES(25413,'College Station','College Station, Texas',31104,51);
INSERT INTO "django_geo_db_city" VALUES(25414,'Concord','Concord, Texas',31107,51);
INSERT INTO "django_geo_db_city" VALUES(25415,'Deanville','Deanville, Texas',31102,51);
INSERT INTO "django_geo_db_city" VALUES(25416,'Dime Box','Dime Box, Texas',31108,51);
INSERT INTO "django_geo_db_city" VALUES(25417,'Flynn','Flynn, Texas',31109,51);
INSERT INTO "django_geo_db_city" VALUES(25418,'Franklin','Franklin, Texas',31110,51);
INSERT INTO "django_geo_db_city" VALUES(25419,'Gause','Gause, Texas',31111,51);
INSERT INTO "django_geo_db_city" VALUES(25420,'Hearne','Hearne, Texas',31112,51);
INSERT INTO "django_geo_db_city" VALUES(25421,'Iola','Iola, Texas',31113,51);
INSERT INTO "django_geo_db_city" VALUES(25422,'Kurten','Kurten, Texas',31092,51);
INSERT INTO "django_geo_db_city" VALUES(25423,'Lyons','Lyons, Texas',31114,51);
INSERT INTO "django_geo_db_city" VALUES(25424,'Madisonville','Madisonville, Texas',31115,51);
INSERT INTO "django_geo_db_city" VALUES(25425,'Marquez','Marquez, Texas',31116,51);
INSERT INTO "django_geo_db_city" VALUES(25426,'Millican','Millican, Texas',31117,51);
INSERT INTO "django_geo_db_city" VALUES(25427,'Mumford','Mumford, Texas',31118,51);
INSERT INTO "django_geo_db_city" VALUES(25428,'Navasota','Navasota, Texas',31119,51);
INSERT INTO "django_geo_db_city" VALUES(25429,'New Baden','New Baden, Texas',31120,51);
INSERT INTO "django_geo_db_city" VALUES(25430,'Normangee','Normangee, Texas',31121,51);
INSERT INTO "django_geo_db_city" VALUES(25431,'North Zulch','North Zulch, Texas',31122,51);
INSERT INTO "django_geo_db_city" VALUES(25432,'Richards','Richards, Texas',31123,51);
INSERT INTO "django_geo_db_city" VALUES(25433,'Roans Prairie','Roans Prairie, Texas',31125,51);
INSERT INTO "django_geo_db_city" VALUES(25434,'Shiro','Shiro, Texas',31126,51);
INSERT INTO "django_geo_db_city" VALUES(25435,'Snook','Snook, Texas',31127,51);
INSERT INTO "django_geo_db_city" VALUES(25436,'Somerville','Somerville, Texas',31128,51);
INSERT INTO "django_geo_db_city" VALUES(25437,'Washington','Washington, Texas',31129,51);
INSERT INTO "django_geo_db_city" VALUES(25438,'Wellborn','Wellborn, Texas',31092,51);
INSERT INTO "django_geo_db_city" VALUES(25439,'Wheelock','Wheelock, Texas',31130,51);
INSERT INTO "django_geo_db_city" VALUES(25440,'Sienna Plantation','Sienna Plantation, Texas',31131,51);
INSERT INTO "django_geo_db_city" VALUES(25441,'Victoria','Victoria, Texas',31132,51);
INSERT INTO "django_geo_db_city" VALUES(25442,'Austwell','Austwell, Texas',31137,51);
INSERT INTO "django_geo_db_city" VALUES(25443,'Bloomington','Bloomington, Texas',31138,51);
INSERT INTO "django_geo_db_city" VALUES(25444,'Cuero','Cuero, Texas',31139,51);
INSERT INTO "django_geo_db_city" VALUES(25445,'Edna','Edna, Texas',31140,51);
INSERT INTO "django_geo_db_city" VALUES(25446,'Fannin','Fannin, Texas',31141,51);
INSERT INTO "django_geo_db_city" VALUES(25447,'Francitas','Francitas, Texas',31142,51);
INSERT INTO "django_geo_db_city" VALUES(25448,'Ganado','Ganado, Texas',31143,51);
INSERT INTO "django_geo_db_city" VALUES(25449,'Goliad','Goliad, Texas',31144,51);
INSERT INTO "django_geo_db_city" VALUES(25450,'Hallettsville','Hallettsville, Texas',31145,51);
INSERT INTO "django_geo_db_city" VALUES(25451,'Hochheim','Hochheim, Texas',31147,51);
INSERT INTO "django_geo_db_city" VALUES(25452,'Inez','Inez, Texas',31148,51);
INSERT INTO "django_geo_db_city" VALUES(25453,'La Salle','La Salle, Texas',31149,51);
INSERT INTO "django_geo_db_city" VALUES(25454,'La Ward','La Ward, Texas',31150,51);
INSERT INTO "django_geo_db_city" VALUES(25455,'Lolita','Lolita, Texas',31151,51);
INSERT INTO "django_geo_db_city" VALUES(25456,'Long Mott','Long Mott, Texas',31152,51);
INSERT INTO "django_geo_db_city" VALUES(25457,'Mcfaddin','Mcfaddin, Texas',31153,51);
INSERT INTO "django_geo_db_city" VALUES(25458,'Meyersville','Meyersville, Texas',31154,51);
INSERT INTO "django_geo_db_city" VALUES(25459,'Moulton','Moulton, Texas',31155,51);
INSERT INTO "django_geo_db_city" VALUES(25460,'Nursery','Nursery, Texas',31156,51);
INSERT INTO "django_geo_db_city" VALUES(25461,'Placedo','Placedo, Texas',31157,51);
INSERT INTO "django_geo_db_city" VALUES(25462,'Point Comfort','Point Comfort, Texas',31158,51);
INSERT INTO "django_geo_db_city" VALUES(25463,'Port Lavaca','Port Lavaca, Texas',31159,51);
INSERT INTO "django_geo_db_city" VALUES(25464,'Port O Connor','Port O Connor, Texas',31160,51);
INSERT INTO "django_geo_db_city" VALUES(25465,'Seadrift','Seadrift, Texas',31161,51);
INSERT INTO "django_geo_db_city" VALUES(25466,'Shiner','Shiner, Texas',31162,51);
INSERT INTO "django_geo_db_city" VALUES(25467,'Speaks','Speaks, Texas',31163,51);
INSERT INTO "django_geo_db_city" VALUES(25468,'Sublime','Sublime, Texas',31164,51);
INSERT INTO "django_geo_db_city" VALUES(25469,'Sweet Home','Sweet Home, Texas',31163,51);
INSERT INTO "django_geo_db_city" VALUES(25470,'Telferner','Telferner, Texas',31165,51);
INSERT INTO "django_geo_db_city" VALUES(25471,'Thomaston','Thomaston, Texas',31166,51);
INSERT INTO "django_geo_db_city" VALUES(25472,'Tivoli','Tivoli, Texas',31167,51);
INSERT INTO "django_geo_db_city" VALUES(25473,'Vanderbilt','Vanderbilt, Texas',31168,51);
INSERT INTO "django_geo_db_city" VALUES(25474,'Weesatche','Weesatche, Texas',31169,51);
INSERT INTO "django_geo_db_city" VALUES(25475,'Westhoff','Westhoff, Texas',31170,51);
INSERT INTO "django_geo_db_city" VALUES(25476,'Yoakum','Yoakum, Texas',31171,51);
INSERT INTO "django_geo_db_city" VALUES(25477,'Artesia Wells','Artesia Wells, Texas',31173,51);
INSERT INTO "django_geo_db_city" VALUES(25478,'Atascosa','Atascosa, Texas',31174,51);
INSERT INTO "django_geo_db_city" VALUES(25479,'Bandera','Bandera, Texas',31175,51);
INSERT INTO "django_geo_db_city" VALUES(25480,'Bergheim','Bergheim, Texas',31176,51);
INSERT INTO "django_geo_db_city" VALUES(25481,'Bigfoot','Bigfoot, Texas',31177,51);
INSERT INTO "django_geo_db_city" VALUES(25482,'Boerne','Boerne, Texas',31178,51);
INSERT INTO "django_geo_db_city" VALUES(25483,'Calliham','Calliham, Texas',31179,51);
INSERT INTO "django_geo_db_city" VALUES(25484,'Campbellton','Campbellton, Texas',31180,51);
INSERT INTO "django_geo_db_city" VALUES(25485,'Castroville','Castroville, Texas',31181,51);
INSERT INTO "django_geo_db_city" VALUES(25486,'Center Point','Center Point, Texas',31182,51);
INSERT INTO "django_geo_db_city" VALUES(25487,'Charlotte','Charlotte, Texas',31183,51);
INSERT INTO "django_geo_db_city" VALUES(25488,'Christine','Christine, Texas',31184,51);
INSERT INTO "django_geo_db_city" VALUES(25489,'Comfort','Comfort, Texas',31185,51);
INSERT INTO "django_geo_db_city" VALUES(25490,'Cotulla','Cotulla, Texas',31186,51);
INSERT INTO "django_geo_db_city" VALUES(25491,'Devine','Devine, Texas',31188,51);
INSERT INTO "django_geo_db_city" VALUES(25492,'Dilley','Dilley, Texas',31189,51);
INSERT INTO "django_geo_db_city" VALUES(25493,'Encinal','Encinal, Texas',31190,51);
INSERT INTO "django_geo_db_city" VALUES(25494,'Fowlerton','Fowlerton, Texas',31191,51);
INSERT INTO "django_geo_db_city" VALUES(25495,'George West','George West, Texas',31192,51);
INSERT INTO "django_geo_db_city" VALUES(25496,'Helotes','Helotes, Texas',31193,51);
INSERT INTO "django_geo_db_city" VALUES(25497,'Hunt','Hunt, Texas',31194,51);
INSERT INTO "django_geo_db_city" VALUES(25498,'Ingram','Ingram, Texas',31195,51);
INSERT INTO "django_geo_db_city" VALUES(25499,'Jourdanton','Jourdanton, Texas',31196,51);
INSERT INTO "django_geo_db_city" VALUES(25500,'Kendalia','Kendalia, Texas',31197,51);
INSERT INTO "django_geo_db_city" VALUES(25501,'Kerrville','Kerrville, Texas',31198,51);
INSERT INTO "django_geo_db_city" VALUES(25502,'La Coste','La Coste, Texas',31200,51);
INSERT INTO "django_geo_db_city" VALUES(25503,'Laredo','Laredo, Texas',31201,51);
INSERT INTO "django_geo_db_city" VALUES(25504,'Leming','Leming, Texas',31210,51);
INSERT INTO "django_geo_db_city" VALUES(25505,'Lytle','Lytle, Texas',31211,51);
INSERT INTO "django_geo_db_city" VALUES(25506,'McCoy','McCoy, Texas',31212,51);
INSERT INTO "django_geo_db_city" VALUES(25507,'Macdona','Macdona, Texas',31213,51);
INSERT INTO "django_geo_db_city" VALUES(25508,'Medina','Medina, Texas',31214,51);
INSERT INTO "django_geo_db_city" VALUES(25509,'Mico','Mico, Texas',31215,51);
INSERT INTO "django_geo_db_city" VALUES(25510,'Moore','Moore, Texas',31216,51);
INSERT INTO "django_geo_db_city" VALUES(25511,'Mountain Home','Mountain Home, Texas',31217,51);
INSERT INTO "django_geo_db_city" VALUES(25512,'Natalia','Natalia, Texas',31218,51);
INSERT INTO "django_geo_db_city" VALUES(25513,'Oakville','Oakville, Texas',31219,51);
INSERT INTO "django_geo_db_city" VALUES(25514,'Pearsall','Pearsall, Texas',31220,51);
INSERT INTO "django_geo_db_city" VALUES(25515,'Peggy','Peggy, Texas',31221,51);
INSERT INTO "django_geo_db_city" VALUES(25516,'Pipe Creek','Pipe Creek, Texas',31222,51);
INSERT INTO "django_geo_db_city" VALUES(25517,'Pleasanton','Pleasanton, Texas',31223,51);
INSERT INTO "django_geo_db_city" VALUES(25518,'Poteet','Poteet, Texas',31224,51);
INSERT INTO "django_geo_db_city" VALUES(25519,'Rio Medina','Rio Medina, Texas',31225,51);
INSERT INTO "django_geo_db_city" VALUES(25520,'San Ygnacio','San Ygnacio, Texas',31226,51);
INSERT INTO "django_geo_db_city" VALUES(25521,'Somerset','Somerset, Texas',31227,51);
INSERT INTO "django_geo_db_city" VALUES(25522,'Spring Branch','Spring Branch, Texas',31228,51);
INSERT INTO "django_geo_db_city" VALUES(25523,'Three Rivers','Three Rivers, Texas',31229,51);
INSERT INTO "django_geo_db_city" VALUES(25524,'Tilden','Tilden, Texas',31230,51);
INSERT INTO "django_geo_db_city" VALUES(25525,'Von Ormy','Von Ormy, Texas',31231,51);
INSERT INTO "django_geo_db_city" VALUES(25526,'Waring','Waring, Texas',31232,51);
INSERT INTO "django_geo_db_city" VALUES(25527,'Whitsett','Whitsett, Texas',31233,51);
INSERT INTO "django_geo_db_city" VALUES(25528,'Zapata','Zapata, Texas',31234,51);
INSERT INTO "django_geo_db_city" VALUES(25529,'Adkins','Adkins, Texas',31237,51);
INSERT INTO "django_geo_db_city" VALUES(25530,'Beeville','Beeville, Texas',31238,51);
INSERT INTO "django_geo_db_city" VALUES(25531,'Berclair','Berclair, Texas',31240,51);
INSERT INTO "django_geo_db_city" VALUES(25532,'Cibolo','Cibolo, Texas',31241,51);
INSERT INTO "django_geo_db_city" VALUES(25533,'Converse','Converse, Texas',31242,51);
INSERT INTO "django_geo_db_city" VALUES(25534,'Ecleto','Ecleto, Texas',31243,51);
INSERT INTO "django_geo_db_city" VALUES(25535,'Elmendorf','Elmendorf, Texas',31244,51);
INSERT INTO "django_geo_db_city" VALUES(25536,'Falls City','Falls City, Texas',31245,51);
INSERT INTO "django_geo_db_city" VALUES(25537,'Floresville','Floresville, Texas',31246,51);
INSERT INTO "django_geo_db_city" VALUES(25538,'Geronimo','Geronimo, Texas',31247,51);
INSERT INTO "django_geo_db_city" VALUES(25539,'Gillett','Gillett, Texas',31248,51);
INSERT INTO "django_geo_db_city" VALUES(25540,'Hobson','Hobson, Texas',31249,51);
INSERT INTO "django_geo_db_city" VALUES(25541,'Karnes City','Karnes City, Texas',31250,51);
INSERT INTO "django_geo_db_city" VALUES(25542,'Kenedy','Kenedy, Texas',31251,51);
INSERT INTO "django_geo_db_city" VALUES(25543,'La Vernia','La Vernia, Texas',31252,51);
INSERT INTO "django_geo_db_city" VALUES(25544,'Leesville','Leesville, Texas',31253,51);
INSERT INTO "django_geo_db_city" VALUES(25545,'McQueeney','McQueeney, Texas',31254,51);
INSERT INTO "django_geo_db_city" VALUES(25546,'Marion','Marion, Texas',31255,51);
INSERT INTO "django_geo_db_city" VALUES(25547,'Mineral','Mineral, Texas',31256,51);
INSERT INTO "django_geo_db_city" VALUES(25548,'San Antonio','San Antonio, Texas',31257,51);
INSERT INTO "django_geo_db_city" VALUES(25549,'New Braunfels','New Braunfels, Texas',31258,51);
INSERT INTO "django_geo_db_city" VALUES(25550,'Canyon Lake','Canyon Lake, Texas',31261,51);
INSERT INTO "django_geo_db_city" VALUES(25551,'Nixon','Nixon, Texas',31265,51);
INSERT INTO "django_geo_db_city" VALUES(25552,'Nordheim','Nordheim, Texas',31266,51);
INSERT INTO "django_geo_db_city" VALUES(25553,'Normanna','Normanna, Texas',31267,51);
INSERT INTO "django_geo_db_city" VALUES(25554,'Pandora','Pandora, Texas',31268,51);
INSERT INTO "django_geo_db_city" VALUES(25555,'Panna Maria','Panna Maria, Texas',31269,51);
INSERT INTO "django_geo_db_city" VALUES(25556,'Pawnee','Pawnee, Texas',31270,51);
INSERT INTO "django_geo_db_city" VALUES(25557,'Pettus','Pettus, Texas',31271,51);
INSERT INTO "django_geo_db_city" VALUES(25558,'Poth','Poth, Texas',31272,51);
INSERT INTO "django_geo_db_city" VALUES(25559,'Universal City','Universal City, Texas',31273,51);
INSERT INTO "django_geo_db_city" VALUES(25560,'Runge','Runge, Texas',31275,51);
INSERT INTO "django_geo_db_city" VALUES(25561,'Saint Hedwig','Saint Hedwig, Texas',31276,51);
INSERT INTO "django_geo_db_city" VALUES(25562,'Schertz','Schertz, Texas',31277,51);
INSERT INTO "django_geo_db_city" VALUES(25563,'Seguin','Seguin, Texas',31278,51);
INSERT INTO "django_geo_db_city" VALUES(25564,'Smiley','Smiley, Texas',31280,51);
INSERT INTO "django_geo_db_city" VALUES(25565,'Stockdale','Stockdale, Texas',31281,51);
INSERT INTO "django_geo_db_city" VALUES(25566,'Sutherland Springs','Sutherland Springs, Texas',31282,51);
INSERT INTO "django_geo_db_city" VALUES(25567,'Tuleta','Tuleta, Texas',31283,51);
INSERT INTO "django_geo_db_city" VALUES(25568,'Bulverde','Bulverde, Texas',31284,51);
INSERT INTO "django_geo_db_city" VALUES(25569,'Yorktown','Yorktown, Texas',31285,51);
INSERT INTO "django_geo_db_city" VALUES(25570,'McAllen','McAllen, Texas',31348,51);
INSERT INTO "django_geo_db_city" VALUES(25571,'Agua Dulce','Agua Dulce, Texas',31349,51);
INSERT INTO "django_geo_db_city" VALUES(25572,'Alice','Alice, Texas',31350,51);
INSERT INTO "django_geo_db_city" VALUES(25573,'Aransas Pass','Aransas Pass, Texas',31353,51);
INSERT INTO "django_geo_db_city" VALUES(25574,'Rancho Alegre','Rancho Alegre, Texas',31355,51);
INSERT INTO "django_geo_db_city" VALUES(25575,'Armstrong','Armstrong, Texas',31356,51);
INSERT INTO "django_geo_db_city" VALUES(25576,'Banquete','Banquete, Texas',31357,51);
INSERT INTO "django_geo_db_city" VALUES(25577,'Bayside','Bayside, Texas',31358,51);
INSERT INTO "django_geo_db_city" VALUES(25578,'Benavides','Benavides, Texas',31359,51);
INSERT INTO "django_geo_db_city" VALUES(25579,'Ben Bolt','Ben Bolt, Texas',31352,51);
INSERT INTO "django_geo_db_city" VALUES(25580,'Bishop','Bishop, Texas',31360,51);
INSERT INTO "django_geo_db_city" VALUES(25581,'Bruni','Bruni, Texas',31361,51);
INSERT INTO "django_geo_db_city" VALUES(25582,'Chapman Ranch','Chapman Ranch, Texas',31362,51);
INSERT INTO "django_geo_db_city" VALUES(25583,'Concepcion','Concepcion, Texas',31363,51);
INSERT INTO "django_geo_db_city" VALUES(25584,'Dinero','Dinero, Texas',31219,51);
INSERT INTO "django_geo_db_city" VALUES(25585,'Driscoll','Driscoll, Texas',31364,51);
INSERT INTO "django_geo_db_city" VALUES(25586,'Edroy','Edroy, Texas',31365,51);
INSERT INTO "django_geo_db_city" VALUES(25587,'Encino','Encino, Texas',31366,51);
INSERT INTO "django_geo_db_city" VALUES(25588,'Falfurrias','Falfurrias, Texas',31367,51);
INSERT INTO "django_geo_db_city" VALUES(25589,'Freer','Freer, Texas',31368,51);
INSERT INTO "django_geo_db_city" VALUES(25590,'Fulton','Fulton, Texas',31369,51);
INSERT INTO "django_geo_db_city" VALUES(25591,'Gregory','Gregory, Texas',31370,51);
INSERT INTO "django_geo_db_city" VALUES(25592,'Guerra','Guerra, Texas',31371,51);
INSERT INTO "django_geo_db_city" VALUES(25593,'Hebbronville','Hebbronville, Texas',31372,51);
INSERT INTO "django_geo_db_city" VALUES(25594,'Ingleside','Ingleside, Texas',31373,51);
INSERT INTO "django_geo_db_city" VALUES(25595,'Kingsville','Kingsville, Texas',31374,51);
INSERT INTO "django_geo_db_city" VALUES(25596,'Mathis','Mathis, Texas',31376,51);
INSERT INTO "django_geo_db_city" VALUES(25597,'Mirando City','Mirando City, Texas',31377,51);
INSERT INTO "django_geo_db_city" VALUES(25598,'Odem','Odem, Texas',31378,51);
INSERT INTO "django_geo_db_city" VALUES(25599,'Oilton','Oilton, Texas',31379,51);
INSERT INTO "django_geo_db_city" VALUES(25600,'Orange Grove','Orange Grove, Texas',31380,51);
INSERT INTO "django_geo_db_city" VALUES(25601,'Port Aransas','Port Aransas, Texas',31381,51);
INSERT INTO "django_geo_db_city" VALUES(25602,'Portland','Portland, Texas',31382,51);
INSERT INTO "django_geo_db_city" VALUES(25603,'Premont','Premont, Texas',31383,51);
INSERT INTO "django_geo_db_city" VALUES(25604,'Realitos','Realitos, Texas',31384,51);
INSERT INTO "django_geo_db_city" VALUES(25605,'Refugio','Refugio, Texas',31385,51);
INSERT INTO "django_geo_db_city" VALUES(25606,'Riviera','Riviera, Texas',31386,51);
INSERT INTO "django_geo_db_city" VALUES(25607,'Robstown','Robstown, Texas',31387,51);
INSERT INTO "django_geo_db_city" VALUES(25608,'Rockport','Rockport, Texas',31388,51);
INSERT INTO "django_geo_db_city" VALUES(25609,'Sandia','Sandia, Texas',31390,51);
INSERT INTO "django_geo_db_city" VALUES(25610,'San Diego','San Diego, Texas',31391,51);
INSERT INTO "django_geo_db_city" VALUES(25611,'Sarita','Sarita, Texas',31392,51);
INSERT INTO "django_geo_db_city" VALUES(25612,'Sinton','Sinton, Texas',31393,51);
INSERT INTO "django_geo_db_city" VALUES(25613,'Skidmore','Skidmore, Texas',31394,51);
INSERT INTO "django_geo_db_city" VALUES(25614,'Taft','Taft, Texas',31395,51);
INSERT INTO "django_geo_db_city" VALUES(25615,'Tynan','Tynan, Texas',31396,51);
INSERT INTO "django_geo_db_city" VALUES(25616,'Woodsboro','Woodsboro, Texas',31397,51);
INSERT INTO "django_geo_db_city" VALUES(25617,'Corpus Christi','Corpus Christi, Texas',31398,51);
INSERT INTO "django_geo_db_city" VALUES(25618,'Mcallen','Mcallen, Texas',31419,51);
INSERT INTO "django_geo_db_city" VALUES(25619,'Mission','Mission, Texas',31424,51);
INSERT INTO "django_geo_db_city" VALUES(25620,'Alamo','Alamo, Texas',31425,51);
INSERT INTO "django_geo_db_city" VALUES(25621,'Brownsville','Brownsville, Texas',31426,51);
INSERT INTO "django_geo_db_city" VALUES(25622,'Combes','Combes, Texas',31431,51);
INSERT INTO "django_geo_db_city" VALUES(25623,'Delmita','Delmita, Texas',31432,51);
INSERT INTO "django_geo_db_city" VALUES(25624,'Donna','Donna, Texas',31433,51);
INSERT INTO "django_geo_db_city" VALUES(25625,'Edcouch','Edcouch, Texas',31434,51);
INSERT INTO "django_geo_db_city" VALUES(25626,'Edinburg','Edinburg, Texas',31435,51);
INSERT INTO "django_geo_db_city" VALUES(25627,'Elsa','Elsa, Texas',31438,51);
INSERT INTO "django_geo_db_city" VALUES(25628,'Falcon Heights','Falcon Heights, Texas',31439,51);
INSERT INTO "django_geo_db_city" VALUES(25629,'Garciasville','Garciasville, Texas',31440,51);
INSERT INTO "django_geo_db_city" VALUES(25630,'Grulla','Grulla, Texas',31441,51);
INSERT INTO "django_geo_db_city" VALUES(25631,'Hargill','Hargill, Texas',31442,51);
INSERT INTO "django_geo_db_city" VALUES(25632,'Harlingen','Harlingen, Texas',31443,51);
INSERT INTO "django_geo_db_city" VALUES(25633,'Hidalgo','Hidalgo, Texas',31448,51);
INSERT INTO "django_geo_db_city" VALUES(25634,'La Blanca','La Blanca, Texas',31449,51);
INSERT INTO "django_geo_db_city" VALUES(25635,'La Feria','La Feria, Texas',31450,51);
INSERT INTO "django_geo_db_city" VALUES(25636,'La Joya','La Joya, Texas',31451,51);
INSERT INTO "django_geo_db_city" VALUES(25637,'Lasara','Lasara, Texas',31452,51);
INSERT INTO "django_geo_db_city" VALUES(25638,'La Villa','La Villa, Texas',31453,51);
INSERT INTO "django_geo_db_city" VALUES(25639,'Linn','Linn, Texas',31454,51);
INSERT INTO "django_geo_db_city" VALUES(25640,'Lopeno','Lopeno, Texas',31455,51);
INSERT INTO "django_geo_db_city" VALUES(25641,'Los Ebanos','Los Ebanos, Texas',31456,51);
INSERT INTO "django_geo_db_city" VALUES(25642,'Los Fresnos','Los Fresnos, Texas',31457,51);
INSERT INTO "django_geo_db_city" VALUES(25643,'Los Indios','Los Indios, Texas',31458,51);
INSERT INTO "django_geo_db_city" VALUES(25644,'Lozano','Lozano, Texas',31459,51);
INSERT INTO "django_geo_db_city" VALUES(25645,'Lyford','Lyford, Texas',31460,51);
INSERT INTO "django_geo_db_city" VALUES(25646,'Mercedes','Mercedes, Texas',31461,51);
INSERT INTO "django_geo_db_city" VALUES(25647,'Sebastian','Sebastian, Texas',31464,51);
INSERT INTO "django_geo_db_city" VALUES(25648,'Olmito','Olmito, Texas',31465,51);
INSERT INTO "django_geo_db_city" VALUES(25649,'Penitas','Penitas, Texas',31466,51);
INSERT INTO "django_geo_db_city" VALUES(25650,'Pharr','Pharr, Texas',31467,51);
INSERT INTO "django_geo_db_city" VALUES(25651,'Port Isabel','Port Isabel, Texas',31468,51);
INSERT INTO "django_geo_db_city" VALUES(25652,'Progreso','Progreso, Texas',31469,51);
INSERT INTO "django_geo_db_city" VALUES(25653,'Raymondville','Raymondville, Texas',31470,51);
INSERT INTO "django_geo_db_city" VALUES(25654,'Rio Grande City','Rio Grande City, Texas',31471,51);
INSERT INTO "django_geo_db_city" VALUES(25655,'Rio Hondo','Rio Hondo, Texas',31472,51);
INSERT INTO "django_geo_db_city" VALUES(25656,'Roma','Roma, Texas',31473,51);
INSERT INTO "django_geo_db_city" VALUES(25657,'Salineno','Salineno, Texas',31474,51);
INSERT INTO "django_geo_db_city" VALUES(25658,'San Benito','San Benito, Texas',31475,51);
INSERT INTO "django_geo_db_city" VALUES(25659,'La Victoria','La Victoria, Texas',31476,51);
INSERT INTO "django_geo_db_city" VALUES(25660,'San Isidro','San Isidro, Texas',31477,51);
INSERT INTO "django_geo_db_city" VALUES(25661,'San Juan','San Juan, Texas',31478,51);
INSERT INTO "django_geo_db_city" VALUES(25662,'San Perlita','San Perlita, Texas',31479,51);
INSERT INTO "django_geo_db_city" VALUES(25663,'Santa Elena','Santa Elena, Texas',31480,51);
INSERT INTO "django_geo_db_city" VALUES(25664,'Santa Maria','Santa Maria, Texas',31481,51);
INSERT INTO "django_geo_db_city" VALUES(25665,'Santa Rosa','Santa Rosa, Texas',31482,51);
INSERT INTO "django_geo_db_city" VALUES(25666,'Sullivan City','Sullivan City, Texas',31484,51);
INSERT INTO "django_geo_db_city" VALUES(25667,'Weslaco','Weslaco, Texas',31485,51);
INSERT INTO "django_geo_db_city" VALUES(25668,'South Padre Island','South Padre Island, Texas',31486,51);
INSERT INTO "django_geo_db_city" VALUES(25669,'Port Mansfield','Port Mansfield, Texas',31487,51);
INSERT INTO "django_geo_db_city" VALUES(25670,'Bastrop','Bastrop, Texas',31488,51);
INSERT INTO "django_geo_db_city" VALUES(25671,'Bebe','Bebe, Texas',31489,51);
INSERT INTO "django_geo_db_city" VALUES(25672,'Belmont','Belmont, Texas',31489,51);
INSERT INTO "django_geo_db_city" VALUES(25673,'Bertram','Bertram, Texas',31490,51);
INSERT INTO "django_geo_db_city" VALUES(25674,'Blanco','Blanco, Texas',31491,51);
INSERT INTO "django_geo_db_city" VALUES(25675,'Bluffton','Bluffton, Texas',31492,51);
INSERT INTO "django_geo_db_city" VALUES(25676,'Briggs','Briggs, Texas',31493,51);
INSERT INTO "django_geo_db_city" VALUES(25677,'Buchanan Dam','Buchanan Dam, Texas',31494,51);
INSERT INTO "django_geo_db_city" VALUES(25678,'Buda','Buda, Texas',31495,51);
INSERT INTO "django_geo_db_city" VALUES(25679,'Burnet','Burnet, Texas',31496,51);
INSERT INTO "django_geo_db_city" VALUES(25680,'Cedar Creek','Cedar Creek, Texas',31497,51);
INSERT INTO "django_geo_db_city" VALUES(25681,'Cedar Park','Cedar Park, Texas',31498,51);
INSERT INTO "django_geo_db_city" VALUES(25682,'Cost','Cost, Texas',31499,51);
INSERT INTO "django_geo_db_city" VALUES(25683,'Coupland','Coupland, Texas',31500,51);
INSERT INTO "django_geo_db_city" VALUES(25684,'Dale','Dale, Texas',31501,51);
INSERT INTO "django_geo_db_city" VALUES(25685,'Del Valle','Del Valle, Texas',31502,51);
INSERT INTO "django_geo_db_city" VALUES(25686,'Doss','Doss, Texas',31503,51);
INSERT INTO "django_geo_db_city" VALUES(25687,'Driftwood','Driftwood, Texas',31504,51);
INSERT INTO "django_geo_db_city" VALUES(25688,'Dripping Springs','Dripping Springs, Texas',31505,51);
INSERT INTO "django_geo_db_city" VALUES(25689,'Elgin','Elgin, Texas',31506,51);
INSERT INTO "django_geo_db_city" VALUES(25690,'Fentress','Fentress, Texas',31507,51);
INSERT INTO "django_geo_db_city" VALUES(25691,'Fischer','Fischer, Texas',31508,51);
INSERT INTO "django_geo_db_city" VALUES(25692,'Fredericksburg','Fredericksburg, Texas',31509,51);
INSERT INTO "django_geo_db_city" VALUES(25693,'Georgetown','Georgetown, Texas',31510,51);
INSERT INTO "django_geo_db_city" VALUES(25694,'Gonzales','Gonzales, Texas',31513,51);
INSERT INTO "django_geo_db_city" VALUES(25695,'Harper','Harper, Texas',31515,51);
INSERT INTO "django_geo_db_city" VALUES(25696,'Harwood','Harwood, Texas',31516,51);
INSERT INTO "django_geo_db_city" VALUES(25697,'Hutto','Hutto, Texas',31517,51);
INSERT INTO "django_geo_db_city" VALUES(25698,'Hye','Hye, Texas',31518,51);
INSERT INTO "django_geo_db_city" VALUES(25699,'Johnson City','Johnson City, Texas',31519,51);
INSERT INTO "django_geo_db_city" VALUES(25700,'Kingsbury','Kingsbury, Texas',31520,51);
INSERT INTO "django_geo_db_city" VALUES(25701,'Kingsland','Kingsland, Texas',31521,51);
INSERT INTO "django_geo_db_city" VALUES(25702,'Kyle','Kyle, Texas',31522,51);
INSERT INTO "django_geo_db_city" VALUES(25703,'Leander','Leander, Texas',31523,51);
INSERT INTO "django_geo_db_city" VALUES(25704,'Liberty Hill','Liberty Hill, Texas',31524,51);
INSERT INTO "django_geo_db_city" VALUES(25705,'Llano','Llano, Texas',31525,51);
INSERT INTO "django_geo_db_city" VALUES(25706,'Lockhart','Lockhart, Texas',31526,51);
INSERT INTO "django_geo_db_city" VALUES(25707,'Luling','Luling, Texas',31528,51);
INSERT INTO "django_geo_db_city" VALUES(25708,'McDade','McDade, Texas',31529,51);
INSERT INTO "django_geo_db_city" VALUES(25709,'McNeil','McNeil, Texas',29234,51);
INSERT INTO "django_geo_db_city" VALUES(25710,'Manchaca','Manchaca, Texas',31530,51);
INSERT INTO "django_geo_db_city" VALUES(25711,'Manor','Manor, Texas',31531,51);
INSERT INTO "django_geo_db_city" VALUES(25712,'Marble Falls','Marble Falls, Texas',31532,51);
INSERT INTO "django_geo_db_city" VALUES(25713,'Martindale','Martindale, Texas',31533,51);
INSERT INTO "django_geo_db_city" VALUES(25714,'Maxwell','Maxwell, Texas',31534,51);
INSERT INTO "django_geo_db_city" VALUES(25715,'Ottine','Ottine, Texas',31536,51);
INSERT INTO "django_geo_db_city" VALUES(25716,'Paige','Paige, Texas',31537,51);
INSERT INTO "django_geo_db_city" VALUES(25717,'Pflugerville','Pflugerville, Texas',31538,51);
INSERT INTO "django_geo_db_city" VALUES(25718,'Prairie Lea','Prairie Lea, Texas',31539,51);
INSERT INTO "django_geo_db_city" VALUES(25719,'Red Rock','Red Rock, Texas',31540,51);
INSERT INTO "django_geo_db_city" VALUES(25720,'Round Mountain','Round Mountain, Texas',31541,51);
INSERT INTO "django_geo_db_city" VALUES(25721,'Round Rock','Round Rock, Texas',31542,51);
INSERT INTO "django_geo_db_city" VALUES(25722,'Sandy','Sandy, Texas',31543,51);
INSERT INTO "django_geo_db_city" VALUES(25723,'San Marcos','San Marcos, Texas',31544,51);
INSERT INTO "django_geo_db_city" VALUES(25724,'Spicewood','Spicewood, Texas',31546,51);
INSERT INTO "django_geo_db_city" VALUES(25725,'Staples','Staples, Texas',31547,51);
INSERT INTO "django_geo_db_city" VALUES(25726,'Stonewall','Stonewall, Texas',31548,51);
INSERT INTO "django_geo_db_city" VALUES(25727,'Tow','Tow, Texas',31549,51);
INSERT INTO "django_geo_db_city" VALUES(25728,'Walburg','Walburg, Texas',31550,51);
INSERT INTO "django_geo_db_city" VALUES(25729,'Weir','Weir, Texas',31551,51);
INSERT INTO "django_geo_db_city" VALUES(25730,'Willow City','Willow City, Texas',31552,51);
INSERT INTO "django_geo_db_city" VALUES(25731,'Wimberley','Wimberley, Texas',31553,51);
INSERT INTO "django_geo_db_city" VALUES(25732,'Wrightsboro','Wrightsboro, Texas',31489,51);
INSERT INTO "django_geo_db_city" VALUES(25733,'Uvalde','Uvalde, Texas',31608,51);
INSERT INTO "django_geo_db_city" VALUES(25734,'Asherton','Asherton, Texas',31610,51);
INSERT INTO "django_geo_db_city" VALUES(25735,'Barksdale','Barksdale, Texas',31611,51);
INSERT INTO "django_geo_db_city" VALUES(25736,'Batesville','Batesville, Texas',31612,51);
INSERT INTO "django_geo_db_city" VALUES(25737,'Big Wells','Big Wells, Texas',31613,51);
INSERT INTO "django_geo_db_city" VALUES(25738,'Brackettville','Brackettville, Texas',31614,51);
INSERT INTO "django_geo_db_city" VALUES(25739,'Camp Wood','Camp Wood, Texas',31615,51);
INSERT INTO "django_geo_db_city" VALUES(25740,'Carrizo Springs','Carrizo Springs, Texas',31616,51);
INSERT INTO "django_geo_db_city" VALUES(25741,'Catarina','Catarina, Texas',31618,51);
INSERT INTO "django_geo_db_city" VALUES(25742,'Comstock','Comstock, Texas',31619,51);
INSERT INTO "django_geo_db_city" VALUES(25743,'Concan','Concan, Texas',31620,51);
INSERT INTO "django_geo_db_city" VALUES(25744,'Crystal City','Crystal City, Texas',31621,51);
INSERT INTO "django_geo_db_city" VALUES(25745,'Del Rio','Del Rio, Texas',31622,51);
INSERT INTO "django_geo_db_city" VALUES(25746,'Laughlin A F B','Laughlin A F B, Texas',31625,51);
INSERT INTO "django_geo_db_city" VALUES(25747,'D Hanis','D Hanis, Texas',31627,51);
INSERT INTO "django_geo_db_city" VALUES(25748,'Dryden','Dryden, Texas',31628,51);
INSERT INTO "django_geo_db_city" VALUES(25749,'Eagle Pass','Eagle Pass, Texas',31629,51);
INSERT INTO "django_geo_db_city" VALUES(25750,'El Indio','El Indio, Texas',31631,51);
INSERT INTO "django_geo_db_city" VALUES(25751,'Hondo','Hondo, Texas',31632,51);
INSERT INTO "django_geo_db_city" VALUES(25752,'Knippa','Knippa, Texas',31633,51);
INSERT INTO "django_geo_db_city" VALUES(25753,'Langtry','Langtry, Texas',31626,51);
INSERT INTO "django_geo_db_city" VALUES(25754,'La Pryor','La Pryor, Texas',31634,51);
INSERT INTO "django_geo_db_city" VALUES(25755,'Leakey','Leakey, Texas',31635,51);
INSERT INTO "django_geo_db_city" VALUES(25756,'Quemado','Quemado, Texas',31636,51);
INSERT INTO "django_geo_db_city" VALUES(25757,'Rio Frio','Rio Frio, Texas',31637,51);
INSERT INTO "django_geo_db_city" VALUES(25758,'Rocksprings','Rocksprings, Texas',31638,51);
INSERT INTO "django_geo_db_city" VALUES(25759,'Sabinal','Sabinal, Texas',31639,51);
INSERT INTO "django_geo_db_city" VALUES(25760,'Tarpley','Tarpley, Texas',31640,51);
INSERT INTO "django_geo_db_city" VALUES(25761,'Utopia','Utopia, Texas',31641,51);
INSERT INTO "django_geo_db_city" VALUES(25762,'Vanderpool','Vanderpool, Texas',31642,51);
INSERT INTO "django_geo_db_city" VALUES(25763,'Yancey','Yancey, Texas',31643,51);
INSERT INTO "django_geo_db_city" VALUES(25764,'Bleiblerville','Bleiblerville, Texas',30935,51);
INSERT INTO "django_geo_db_city" VALUES(25765,'Carmine','Carmine, Texas',31644,51);
INSERT INTO "django_geo_db_city" VALUES(25766,'Cat Spring','Cat Spring, Texas',31645,51);
INSERT INTO "django_geo_db_city" VALUES(25767,'Columbus','Columbus, Texas',31646,51);
INSERT INTO "django_geo_db_city" VALUES(25768,'Alleyton','Alleyton, Texas',31647,51);
INSERT INTO "django_geo_db_city" VALUES(25769,'Ellinger','Ellinger, Texas',31648,51);
INSERT INTO "django_geo_db_city" VALUES(25770,'Fayetteville','Fayetteville, Texas',31649,51);
INSERT INTO "django_geo_db_city" VALUES(25771,'Flatonia','Flatonia, Texas',31650,51);
INSERT INTO "django_geo_db_city" VALUES(25772,'Giddings','Giddings, Texas',31651,51);
INSERT INTO "django_geo_db_city" VALUES(25773,'Glidden','Glidden, Texas',31652,51);
INSERT INTO "django_geo_db_city" VALUES(25774,'Industry','Industry, Texas',31653,51);
INSERT INTO "django_geo_db_city" VALUES(25775,'La Grange','La Grange, Texas',31654,51);
INSERT INTO "django_geo_db_city" VALUES(25776,'Ledbetter','Ledbetter, Texas',31655,51);
INSERT INTO "django_geo_db_city" VALUES(25777,'Lexington','Lexington, Texas',31656,51);
INSERT INTO "django_geo_db_city" VALUES(25778,'Lincoln','Lincoln, Texas',31657,51);
INSERT INTO "django_geo_db_city" VALUES(25779,'Muldoon','Muldoon, Texas',31658,51);
INSERT INTO "django_geo_db_city" VALUES(25780,'New Ulm','New Ulm, Texas',31659,51);
INSERT INTO "django_geo_db_city" VALUES(25781,'Oakland','Oakland, Texas',30943,51);
INSERT INTO "django_geo_db_city" VALUES(25782,'Plum','Plum, Texas',31660,51);
INSERT INTO "django_geo_db_city" VALUES(25783,'Rosanky','Rosanky, Texas',31661,51);
INSERT INTO "django_geo_db_city" VALUES(25784,'Round Top','Round Top, Texas',31662,51);
INSERT INTO "django_geo_db_city" VALUES(25785,'Schulenburg','Schulenburg, Texas',31663,51);
INSERT INTO "django_geo_db_city" VALUES(25786,'Smithville','Smithville, Texas',31664,51);
INSERT INTO "django_geo_db_city" VALUES(25787,'Waelder','Waelder, Texas',31665,51);
INSERT INTO "django_geo_db_city" VALUES(25788,'Warda','Warda, Texas',31666,51);
INSERT INTO "django_geo_db_city" VALUES(25789,'Weimar','Weimar, Texas',31668,51);
INSERT INTO "django_geo_db_city" VALUES(25790,'West Point','West Point, Texas',31669,51);
INSERT INTO "django_geo_db_city" VALUES(25791,'Adrian','Adrian, Texas',31671,51);
INSERT INTO "django_geo_db_city" VALUES(25792,'Alanreed','Alanreed, Texas',31672,51);
INSERT INTO "django_geo_db_city" VALUES(25793,'Allison','Allison, Texas',31673,51);
INSERT INTO "django_geo_db_city" VALUES(25794,'Booker','Booker, Texas',31674,51);
INSERT INTO "django_geo_db_city" VALUES(25795,'Borger','Borger, Texas',31675,51);
INSERT INTO "django_geo_db_city" VALUES(25796,'Bovina','Bovina, Texas',31677,51);
INSERT INTO "django_geo_db_city" VALUES(25797,'Boys Ranch','Boys Ranch, Texas',31678,51);
INSERT INTO "django_geo_db_city" VALUES(25798,'Briscoe','Briscoe, Texas',31679,51);
INSERT INTO "django_geo_db_city" VALUES(25799,'Bushland','Bushland, Texas',31680,51);
INSERT INTO "django_geo_db_city" VALUES(25800,'Cactus','Cactus, Texas',31681,51);
INSERT INTO "django_geo_db_city" VALUES(25801,'Canadian','Canadian, Texas',31682,51);
INSERT INTO "django_geo_db_city" VALUES(25802,'Canyon','Canyon, Texas',31683,51);
INSERT INTO "django_geo_db_city" VALUES(25803,'Channing','Channing, Texas',31685,51);
INSERT INTO "django_geo_db_city" VALUES(25804,'Claude','Claude, Texas',31686,51);
INSERT INTO "django_geo_db_city" VALUES(25805,'Cotton Center','Cotton Center, Texas',31687,51);
INSERT INTO "django_geo_db_city" VALUES(25806,'Dalhart','Dalhart, Texas',31688,51);
INSERT INTO "django_geo_db_city" VALUES(25807,'Darrouzett','Darrouzett, Texas',31689,51);
INSERT INTO "django_geo_db_city" VALUES(25808,'Dawn','Dawn, Texas',31690,51);
INSERT INTO "django_geo_db_city" VALUES(25809,'Dimmitt','Dimmitt, Texas',31691,51);
INSERT INTO "django_geo_db_city" VALUES(25810,'Dumas','Dumas, Texas',31692,51);
INSERT INTO "django_geo_db_city" VALUES(25811,'Earth','Earth, Texas',31693,51);
INSERT INTO "django_geo_db_city" VALUES(25812,'Edmonson','Edmonson, Texas',31694,51);
INSERT INTO "django_geo_db_city" VALUES(25813,'Farnsworth','Farnsworth, Texas',31695,51);
INSERT INTO "django_geo_db_city" VALUES(25814,'Follett','Follett, Texas',31696,51);
INSERT INTO "django_geo_db_city" VALUES(25815,'Friona','Friona, Texas',31697,51);
INSERT INTO "django_geo_db_city" VALUES(25816,'Fritch','Fritch, Texas',31698,51);
INSERT INTO "django_geo_db_city" VALUES(25817,'Groom','Groom, Texas',31699,51);
INSERT INTO "django_geo_db_city" VALUES(25818,'Gruver','Gruver, Texas',31700,51);
INSERT INTO "django_geo_db_city" VALUES(25819,'Hale Center','Hale Center, Texas',31701,51);
INSERT INTO "django_geo_db_city" VALUES(25820,'Happy','Happy, Texas',31702,51);
INSERT INTO "django_geo_db_city" VALUES(25821,'Hart','Hart, Texas',31703,51);
INSERT INTO "django_geo_db_city" VALUES(25822,'Hartley','Hartley, Texas',31704,51);
INSERT INTO "django_geo_db_city" VALUES(25823,'Hereford','Hereford, Texas',31705,51);
INSERT INTO "django_geo_db_city" VALUES(25824,'Higgins','Higgins, Texas',31706,51);
INSERT INTO "django_geo_db_city" VALUES(25825,'Kerrick','Kerrick, Oklahoma',31707,36);
INSERT INTO "django_geo_db_city" VALUES(25826,'Kress','Kress, Texas',31708,51);
INSERT INTO "django_geo_db_city" VALUES(25827,'Lazbuddie','Lazbuddie, Texas',31709,51);
INSERT INTO "django_geo_db_city" VALUES(25828,'Lefors','Lefors, Texas',31710,51);
INSERT INTO "django_geo_db_city" VALUES(25829,'Lipscomb','Lipscomb, Texas',31711,51);
INSERT INTO "django_geo_db_city" VALUES(25830,'Mclean','Mclean, Texas',31712,51);
INSERT INTO "django_geo_db_city" VALUES(25831,'Masterson','Masterson, Texas',31713,51);
INSERT INTO "django_geo_db_city" VALUES(25832,'Miami','Miami, Texas',31714,51);
INSERT INTO "django_geo_db_city" VALUES(25833,'Mobeetie','Mobeetie, Texas',31715,51);
INSERT INTO "django_geo_db_city" VALUES(25834,'Morse','Morse, Texas',31716,51);
INSERT INTO "django_geo_db_city" VALUES(25835,'Nazareth','Nazareth, Texas',31717,51);
INSERT INTO "django_geo_db_city" VALUES(25836,'Olton','Olton, Texas',31718,51);
INSERT INTO "django_geo_db_city" VALUES(25837,'Pampa','Pampa, Texas',31719,51);
INSERT INTO "django_geo_db_city" VALUES(25838,'Panhandle','Panhandle, Texas',31721,51);
INSERT INTO "django_geo_db_city" VALUES(25839,'Perryton','Perryton, Texas',31722,51);
INSERT INTO "django_geo_db_city" VALUES(25840,'Plainview','Plainview, Texas',31723,51);
INSERT INTO "django_geo_db_city" VALUES(25841,'Samnorwood','Samnorwood, Texas',31725,51);
INSERT INTO "django_geo_db_city" VALUES(25842,'Sanford','Sanford, Texas',31726,51);
INSERT INTO "django_geo_db_city" VALUES(25843,'Shamrock','Shamrock, Texas',31727,51);
INSERT INTO "django_geo_db_city" VALUES(25844,'Skellytown','Skellytown, Texas',31728,51);
INSERT INTO "django_geo_db_city" VALUES(25845,'Spearman','Spearman, Texas',31729,51);
INSERT INTO "django_geo_db_city" VALUES(25846,'Springlake','Springlake, Texas',31730,51);
INSERT INTO "django_geo_db_city" VALUES(25847,'Stinnett','Stinnett, Texas',31731,51);
INSERT INTO "django_geo_db_city" VALUES(25848,'Stratford','Stratford, Texas',31732,51);
INSERT INTO "django_geo_db_city" VALUES(25849,'Summerfield','Summerfield, Texas',31733,51);
INSERT INTO "django_geo_db_city" VALUES(25850,'Sunray','Sunray, Texas',31734,51);
INSERT INTO "django_geo_db_city" VALUES(25851,'Texline','Texline, Texas',31735,51);
INSERT INTO "django_geo_db_city" VALUES(25852,'Tulia','Tulia, Texas',31736,51);
INSERT INTO "django_geo_db_city" VALUES(25853,'Umbarger','Umbarger, Texas',31737,51);
INSERT INTO "django_geo_db_city" VALUES(25854,'Vega','Vega, Texas',31738,51);
INSERT INTO "django_geo_db_city" VALUES(25855,'Waka','Waka, Texas',31739,51);
INSERT INTO "django_geo_db_city" VALUES(25856,'Wayside','Wayside, Texas',31740,51);
INSERT INTO "django_geo_db_city" VALUES(25857,'Wellington','Wellington, Texas',31741,51);
INSERT INTO "django_geo_db_city" VALUES(25858,'Wheeler','Wheeler, Texas',31742,51);
INSERT INTO "django_geo_db_city" VALUES(25859,'White Deer','White Deer, Texas',31743,51);
INSERT INTO "django_geo_db_city" VALUES(25860,'Wildorado','Wildorado, Texas',31744,51);
INSERT INTO "django_geo_db_city" VALUES(25861,'Amarillo','Amarillo, Texas',31745,51);
INSERT INTO "django_geo_db_city" VALUES(25862,'Childress','Childress, Texas',31765,51);
INSERT INTO "django_geo_db_city" VALUES(25863,'Afton','Afton, Texas',31766,51);
INSERT INTO "django_geo_db_city" VALUES(25864,'Aiken','Aiken, Texas',31767,51);
INSERT INTO "django_geo_db_city" VALUES(25865,'Carey','Carey, Texas',31768,51);
INSERT INTO "django_geo_db_city" VALUES(25866,'Cee Vee','Cee Vee, Texas',31769,51);
INSERT INTO "django_geo_db_city" VALUES(25867,'Chalk','Chalk, Texas',31770,51);
INSERT INTO "django_geo_db_city" VALUES(25868,'Chillicothe','Chillicothe, Texas',31771,51);
INSERT INTO "django_geo_db_city" VALUES(25869,'Clarendon','Clarendon, Texas',31772,51);
INSERT INTO "django_geo_db_city" VALUES(25870,'Crowell','Crowell, Texas',31773,51);
INSERT INTO "django_geo_db_city" VALUES(25871,'Dickens','Dickens, Texas',31774,51);
INSERT INTO "django_geo_db_city" VALUES(25872,'Dodson','Dodson, Texas',31775,51);
INSERT INTO "django_geo_db_city" VALUES(25873,'Dougherty','Dougherty, Texas',31776,51);
INSERT INTO "django_geo_db_city" VALUES(25874,'Dumont','Dumont, Texas',31777,51);
INSERT INTO "django_geo_db_city" VALUES(25875,'Estelline','Estelline, Texas',31778,51);
INSERT INTO "django_geo_db_city" VALUES(25876,'Flomot','Flomot, Texas',31779,51);
INSERT INTO "django_geo_db_city" VALUES(25877,'Floydada','Floydada, Texas',31780,51);
INSERT INTO "django_geo_db_city" VALUES(25878,'Guthrie','Guthrie, Texas',31781,51);
INSERT INTO "django_geo_db_city" VALUES(25879,'Hedley','Hedley, Texas',31782,51);
INSERT INTO "django_geo_db_city" VALUES(25880,'Kirkland','Kirkland, Texas',31768,51);
INSERT INTO "django_geo_db_city" VALUES(25881,'Lakeview','Lakeview, Texas',31783,51);
INSERT INTO "django_geo_db_city" VALUES(25882,'Lelia Lake','Lelia Lake, Texas',31784,51);
INSERT INTO "django_geo_db_city" VALUES(25883,'Lockney','Lockney, Texas',31785,51);
INSERT INTO "django_geo_db_city" VALUES(25884,'Mcadoo','Mcadoo, Texas',31786,51);
INSERT INTO "django_geo_db_city" VALUES(25885,'Matador','Matador, Texas',31787,51);
INSERT INTO "django_geo_db_city" VALUES(25886,'Memphis','Memphis, Texas',31788,51);
INSERT INTO "django_geo_db_city" VALUES(25887,'Odell','Odell, Texas',31789,51);
INSERT INTO "django_geo_db_city" VALUES(25888,'Paducah','Paducah, Texas',31790,51);
INSERT INTO "django_geo_db_city" VALUES(25889,'Petersburg','Petersburg, Texas',31791,51);
INSERT INTO "django_geo_db_city" VALUES(25890,'Quail','Quail, Texas',31792,51);
INSERT INTO "django_geo_db_city" VALUES(25891,'Quanah','Quanah, Texas',31793,51);
INSERT INTO "django_geo_db_city" VALUES(25892,'Quitaque','Quitaque, Texas',31794,51);
INSERT INTO "django_geo_db_city" VALUES(25893,'Roaring Springs','Roaring Springs, Texas',31795,51);
INSERT INTO "django_geo_db_city" VALUES(25894,'Silverton','Silverton, Texas',31796,51);
INSERT INTO "django_geo_db_city" VALUES(25895,'South Plains','South Plains, Texas',31767,51);
INSERT INTO "django_geo_db_city" VALUES(25896,'Tell','Tell, Texas',31797,51);
INSERT INTO "django_geo_db_city" VALUES(25897,'Turkey','Turkey, Texas',31798,51);
INSERT INTO "django_geo_db_city" VALUES(25898,'Abernathy','Abernathy, Texas',31800,51);
INSERT INTO "django_geo_db_city" VALUES(25899,'Amherst','Amherst, Texas',31801,51);
INSERT INTO "django_geo_db_city" VALUES(25900,'Anton','Anton, Texas',31802,51);
INSERT INTO "django_geo_db_city" VALUES(25901,'Bledsoe','Bledsoe, Texas',31803,51);
INSERT INTO "django_geo_db_city" VALUES(25902,'Brownfield','Brownfield, Texas',31804,51);
INSERT INTO "django_geo_db_city" VALUES(25903,'Bula','Bula, Texas',31805,51);
INSERT INTO "django_geo_db_city" VALUES(25904,'Sudan','Sudan, Texas',31806,51);
INSERT INTO "django_geo_db_city" VALUES(25905,'Crosbyton','Crosbyton, Texas',31807,51);
INSERT INTO "django_geo_db_city" VALUES(25906,'Denver City','Denver City, Texas',31808,51);
INSERT INTO "django_geo_db_city" VALUES(25907,'Enochs','Enochs, Texas',31809,51);
INSERT INTO "django_geo_db_city" VALUES(25908,'Farwell','Farwell, Texas',31810,51);
INSERT INTO "django_geo_db_city" VALUES(25909,'Fieldton','Fieldton, Texas',31811,51);
INSERT INTO "django_geo_db_city" VALUES(25910,'Idalou','Idalou, Texas',31812,51);
INSERT INTO "django_geo_db_city" VALUES(25911,'Justiceburg','Justiceburg, Texas',31813,51);
INSERT INTO "django_geo_db_city" VALUES(25912,'Lamesa','Lamesa, Texas',31814,51);
INSERT INTO "django_geo_db_city" VALUES(25913,'Levelland','Levelland, Texas',31815,51);
INSERT INTO "django_geo_db_city" VALUES(25914,'Littlefield','Littlefield, Texas',31817,51);
INSERT INTO "django_geo_db_city" VALUES(25915,'Loop','Loop, Texas',31818,51);
INSERT INTO "django_geo_db_city" VALUES(25916,'Lorenzo','Lorenzo, Texas',31819,51);
INSERT INTO "django_geo_db_city" VALUES(25917,'Maple','Maple, Texas',31820,51);
INSERT INTO "django_geo_db_city" VALUES(25918,'Meadow','Meadow, Texas',31821,51);
INSERT INTO "django_geo_db_city" VALUES(25919,'Morton','Morton, Texas',31822,51);
INSERT INTO "django_geo_db_city" VALUES(25920,'Muleshoe','Muleshoe, Texas',31823,51);
INSERT INTO "django_geo_db_city" VALUES(25921,'New Deal','New Deal, Texas',31824,51);
INSERT INTO "django_geo_db_city" VALUES(25922,'Odonnell','Odonnell, Texas',31825,51);
INSERT INTO "django_geo_db_city" VALUES(25923,'Pep','Pep, Texas',31826,51);
INSERT INTO "django_geo_db_city" VALUES(25924,'Plains','Plains, Texas',31827,51);
INSERT INTO "django_geo_db_city" VALUES(25925,'Post','Post, Texas',31828,51);
INSERT INTO "django_geo_db_city" VALUES(25926,'Ralls','Ralls, Texas',31829,51);
INSERT INTO "django_geo_db_city" VALUES(25927,'Ropesville','Ropesville, Texas',31830,51);
INSERT INTO "django_geo_db_city" VALUES(25928,'Seagraves','Seagraves, Texas',31831,51);
INSERT INTO "django_geo_db_city" VALUES(25929,'Seminole','Seminole, Texas',31832,51);
INSERT INTO "django_geo_db_city" VALUES(25930,'Shallowater','Shallowater, Texas',31833,51);
INSERT INTO "django_geo_db_city" VALUES(25931,'Slaton','Slaton, Texas',31834,51);
INSERT INTO "django_geo_db_city" VALUES(25932,'Ransom Canyon','Ransom Canyon, Texas',31835,51);
INSERT INTO "django_geo_db_city" VALUES(25933,'Smyer','Smyer, Texas',31836,51);
INSERT INTO "django_geo_db_city" VALUES(25934,'Spade','Spade, Texas',31838,51);
INSERT INTO "django_geo_db_city" VALUES(25935,'Spur','Spur, Texas',31839,51);
INSERT INTO "django_geo_db_city" VALUES(25936,'Sundown','Sundown, Texas',31841,51);
INSERT INTO "django_geo_db_city" VALUES(25937,'Tahoka','Tahoka, Texas',31842,51);
INSERT INTO "django_geo_db_city" VALUES(25938,'Tokio','Tokio, Texas',31843,51);
INSERT INTO "django_geo_db_city" VALUES(25939,'Welch','Welch, Texas',31844,51);
INSERT INTO "django_geo_db_city" VALUES(25940,'Wellman','Wellman, Texas',31845,51);
INSERT INTO "django_geo_db_city" VALUES(25941,'Whiteface','Whiteface, Texas',31846,51);
INSERT INTO "django_geo_db_city" VALUES(25942,'Whitharral','Whitharral, Texas',31847,51);
INSERT INTO "django_geo_db_city" VALUES(25943,'Wilson','Wilson, Texas',31848,51);
INSERT INTO "django_geo_db_city" VALUES(25944,'Wolfforth','Wolfforth, Texas',31849,51);
INSERT INTO "django_geo_db_city" VALUES(25945,'New Home','New Home, Texas',31850,51);
INSERT INTO "django_geo_db_city" VALUES(25946,'Lubbock','Lubbock, Texas',31851,51);
INSERT INTO "django_geo_db_city" VALUES(25947,'Anson','Anson, Texas',31870,51);
INSERT INTO "django_geo_db_city" VALUES(25948,'Aspermont','Aspermont, Texas',31871,51);
INSERT INTO "django_geo_db_city" VALUES(25949,'Avoca','Avoca, Texas',31872,51);
INSERT INTO "django_geo_db_city" VALUES(25950,'Baird','Baird, Texas',31873,51);
INSERT INTO "django_geo_db_city" VALUES(25951,'Benjamin','Benjamin, Texas',31874,51);
INSERT INTO "django_geo_db_city" VALUES(25952,'Blackwell','Blackwell, Texas',31875,51);
INSERT INTO "django_geo_db_city" VALUES(25953,'Buffalo Gap','Buffalo Gap, Texas',31876,51);
INSERT INTO "django_geo_db_city" VALUES(25954,'Clyde','Clyde, Texas',31877,51);
INSERT INTO "django_geo_db_city" VALUES(25955,'Coahoma','Coahoma, Texas',31878,51);
INSERT INTO "django_geo_db_city" VALUES(25956,'Colorado City','Colorado City, Texas',31879,51);
INSERT INTO "django_geo_db_city" VALUES(25957,'Dunn','Dunn, Texas',31880,51);
INSERT INTO "django_geo_db_city" VALUES(25958,'Fluvanna','Fluvanna, Texas',31881,51);
INSERT INTO "django_geo_db_city" VALUES(25959,'Girard','Girard, Texas',31882,51);
INSERT INTO "django_geo_db_city" VALUES(25960,'Goldsboro','Goldsboro, Texas',31883,51);
INSERT INTO "django_geo_db_city" VALUES(25961,'Hamlin','Hamlin, Texas',31884,51);
INSERT INTO "django_geo_db_city" VALUES(25962,'Haskell','Haskell, Texas',31885,51);
INSERT INTO "django_geo_db_city" VALUES(25963,'Hawley','Hawley, Texas',31886,51);
INSERT INTO "django_geo_db_city" VALUES(25964,'Hermleigh','Hermleigh, Texas',31887,51);
INSERT INTO "django_geo_db_city" VALUES(25965,'Ira','Ira, Texas',31888,51);
INSERT INTO "django_geo_db_city" VALUES(25966,'Jayton','Jayton, Texas',31889,51);
INSERT INTO "django_geo_db_city" VALUES(25967,'Knox City','Knox City, Texas',31890,51);
INSERT INTO "django_geo_db_city" VALUES(25968,'Lawn','Lawn, Texas',31891,51);
INSERT INTO "django_geo_db_city" VALUES(25969,'Loraine','Loraine, Texas',31892,51);
INSERT INTO "django_geo_db_city" VALUES(25970,'Lueders','Lueders, Texas',31893,51);
INSERT INTO "django_geo_db_city" VALUES(25971,'McCaulley','McCaulley, Texas',31894,51);
INSERT INTO "django_geo_db_city" VALUES(25972,'Maryneal','Maryneal, Texas',31895,51);
INSERT INTO "django_geo_db_city" VALUES(25973,'Merkel','Merkel, Texas',31896,51);
INSERT INTO "django_geo_db_city" VALUES(25974,'Nolan','Nolan, Texas',31897,51);
INSERT INTO "django_geo_db_city" VALUES(25975,'Novice','Novice, Texas',31898,51);
INSERT INTO "django_geo_db_city" VALUES(25976,'O Brien','O Brien, Texas',31899,51);
INSERT INTO "django_geo_db_city" VALUES(25977,'Old Glory','Old Glory, Texas',31900,51);
INSERT INTO "django_geo_db_city" VALUES(25978,'Ovalo','Ovalo, Texas',31901,51);
INSERT INTO "django_geo_db_city" VALUES(25979,'Roby','Roby, Texas',31902,51);
INSERT INTO "django_geo_db_city" VALUES(25980,'Rochester','Rochester, Texas',31903,51);
INSERT INTO "django_geo_db_city" VALUES(25981,'Roscoe','Roscoe, Texas',31904,51);
INSERT INTO "django_geo_db_city" VALUES(25982,'Rotan','Rotan, Texas',31905,51);
INSERT INTO "django_geo_db_city" VALUES(25983,'Rule','Rule, Texas',31906,51);
INSERT INTO "django_geo_db_city" VALUES(25984,'Snyder','Snyder, Texas',31908,51);
INSERT INTO "django_geo_db_city" VALUES(25985,'Stamford','Stamford, Texas',31909,51);
INSERT INTO "django_geo_db_city" VALUES(25986,'Sweetwater','Sweetwater, Texas',31911,51);
INSERT INTO "django_geo_db_city" VALUES(25987,'Sylvester','Sylvester, Texas',31912,51);
INSERT INTO "django_geo_db_city" VALUES(25988,'Trent','Trent, Texas',31913,51);
INSERT INTO "django_geo_db_city" VALUES(25989,'Tuscola','Tuscola, Texas',31914,51);
INSERT INTO "django_geo_db_city" VALUES(25990,'Tye','Tye, Texas',31915,51);
INSERT INTO "django_geo_db_city" VALUES(25991,'Westbrook','Westbrook, Texas',31916,51);
INSERT INTO "django_geo_db_city" VALUES(25992,'Wingate','Wingate, Texas',31917,51);
INSERT INTO "django_geo_db_city" VALUES(25993,'Winters','Winters, Texas',31918,51);
INSERT INTO "django_geo_db_city" VALUES(25994,'Abilene','Abilene, Texas',31920,51);
INSERT INTO "django_geo_db_city" VALUES(25995,'Dyess AFB','Dyess AFB, Texas',31926,51);
INSERT INTO "django_geo_db_city" VALUES(25996,'Midland','Midland, Texas',31931,51);
INSERT INTO "django_geo_db_city" VALUES(25997,'Ackerly','Ackerly, Texas',31938,51);
INSERT INTO "django_geo_db_city" VALUES(25998,'Andrews','Andrews, Texas',31939,51);
INSERT INTO "django_geo_db_city" VALUES(25999,'Balmorhea','Balmorhea, Texas',31940,51);
INSERT INTO "django_geo_db_city" VALUES(26000,'Barstow','Barstow, Texas',31941,51);
INSERT INTO "django_geo_db_city" VALUES(26001,'Big Spring','Big Spring, Texas',31942,51);
INSERT INTO "django_geo_db_city" VALUES(26002,'Coyanosa','Coyanosa, Texas',31944,51);
INSERT INTO "django_geo_db_city" VALUES(26003,'Crane','Crane, Texas',31945,51);
INSERT INTO "django_geo_db_city" VALUES(26004,'Forsan','Forsan, Texas',31946,51);
INSERT INTO "django_geo_db_city" VALUES(26005,'Fort Davis','Fort Davis, Texas',31947,51);
INSERT INTO "django_geo_db_city" VALUES(26006,'Fort Stockton','Fort Stockton, Texas',31948,51);
INSERT INTO "django_geo_db_city" VALUES(26007,'Gail','Gail, Texas',31949,51);
INSERT INTO "django_geo_db_city" VALUES(26008,'Garden City','Garden City, Texas',31950,51);
INSERT INTO "django_geo_db_city" VALUES(26009,'Girvin','Girvin, Texas',31951,51);
INSERT INTO "django_geo_db_city" VALUES(26010,'Goldsmith','Goldsmith, Texas',31952,51);
INSERT INTO "django_geo_db_city" VALUES(26011,'Grandfalls','Grandfalls, Texas',31953,51);
INSERT INTO "django_geo_db_city" VALUES(26012,'Imperial','Imperial, Texas',31954,51);
INSERT INTO "django_geo_db_city" VALUES(26013,'Iraan','Iraan, Texas',31955,51);
INSERT INTO "django_geo_db_city" VALUES(26014,'Kermit','Kermit, Texas',31956,51);
INSERT INTO "django_geo_db_city" VALUES(26015,'Knott','Knott, Texas',31957,51);
INSERT INTO "django_geo_db_city" VALUES(26016,'Lenorah','Lenorah, Texas',31958,51);
INSERT INTO "django_geo_db_city" VALUES(26017,'McCamey','McCamey, Texas',31959,51);
INSERT INTO "django_geo_db_city" VALUES(26018,'Mentone','Mentone, Texas',31960,51);
INSERT INTO "django_geo_db_city" VALUES(26019,'Midkiff','Midkiff, Texas',31961,51);
INSERT INTO "django_geo_db_city" VALUES(26020,'Monahans','Monahans, Texas',31962,51);
INSERT INTO "django_geo_db_city" VALUES(26021,'Wickett','Wickett, Texas',31963,51);
INSERT INTO "django_geo_db_city" VALUES(26022,'Gardendale','Gardendale, Texas',31964,51);
INSERT INTO "django_geo_db_city" VALUES(26023,'Notrees','Notrees, Texas',31965,51);
INSERT INTO "django_geo_db_city" VALUES(26024,'Odessa','Odessa, Texas',31966,51);
INSERT INTO "django_geo_db_city" VALUES(26025,'Orla','Orla, Texas',31975,51);
INSERT INTO "django_geo_db_city" VALUES(26026,'Pecos','Pecos, Texas',31976,51);
INSERT INTO "django_geo_db_city" VALUES(26027,'Penwell','Penwell, Texas',31977,51);
INSERT INTO "django_geo_db_city" VALUES(26028,'Pyote','Pyote, Texas',31978,51);
INSERT INTO "django_geo_db_city" VALUES(26029,'Rankin','Rankin, Texas',31979,51);
INSERT INTO "django_geo_db_city" VALUES(26030,'Royalty','Royalty, Texas',31980,51);
INSERT INTO "django_geo_db_city" VALUES(26031,'Saragosa','Saragosa, Texas',31981,51);
INSERT INTO "django_geo_db_city" VALUES(26032,'Sheffield','Sheffield, Texas',31982,51);
INSERT INTO "django_geo_db_city" VALUES(26033,'Stanton','Stanton, Texas',31983,51);
INSERT INTO "django_geo_db_city" VALUES(26034,'Tarzan','Tarzan, Texas',31984,51);
INSERT INTO "django_geo_db_city" VALUES(26035,'Toyah','Toyah, Texas',31985,51);
INSERT INTO "django_geo_db_city" VALUES(26036,'Toyahvale','Toyahvale, Texas',31975,51);
INSERT INTO "django_geo_db_city" VALUES(26037,'Wink','Wink, Texas',31987,51);
INSERT INTO "django_geo_db_city" VALUES(26038,'Anthony','Anthony, Texas',31988,51);
INSERT INTO "django_geo_db_city" VALUES(26039,'Alpine','Alpine, Texas',31989,51);
INSERT INTO "django_geo_db_city" VALUES(26040,'Big Bend National Park','Big Bend National Park, Texas',31992,51);
INSERT INTO "django_geo_db_city" VALUES(26041,'Canutillo','Canutillo, Texas',31993,51);
INSERT INTO "django_geo_db_city" VALUES(26042,'Clint','Clint, Texas',31994,51);
INSERT INTO "django_geo_db_city" VALUES(26043,'Dell City','Dell City, Texas',31995,51);
INSERT INTO "django_geo_db_city" VALUES(26044,'Fabens','Fabens, Texas',31996,51);
INSERT INTO "django_geo_db_city" VALUES(26045,'Fort Hancock','Fort Hancock, Texas',31997,51);
INSERT INTO "django_geo_db_city" VALUES(26046,'Sierra Blanca','Sierra Blanca, Texas',31998,51);
INSERT INTO "django_geo_db_city" VALUES(26047,'Marathon','Marathon, Texas',31999,51);
INSERT INTO "django_geo_db_city" VALUES(26048,'Marfa','Marfa, Texas',32000,51);
INSERT INTO "django_geo_db_city" VALUES(26049,'Presidio','Presidio, Texas',32001,51);
INSERT INTO "django_geo_db_city" VALUES(26050,'Redford','Redford, Texas',32002,51);
INSERT INTO "django_geo_db_city" VALUES(26051,'Salt Flat','Salt Flat, Texas',32003,51);
INSERT INTO "django_geo_db_city" VALUES(26052,'Sanderson','Sanderson, Texas',32004,51);
INSERT INTO "django_geo_db_city" VALUES(26053,'San Elizario','San Elizario, Texas',32005,51);
INSERT INTO "django_geo_db_city" VALUES(26054,'Shafter','Shafter, Texas',32006,51);
INSERT INTO "django_geo_db_city" VALUES(26055,'Terlingua','Terlingua, Texas',32008,51);
INSERT INTO "django_geo_db_city" VALUES(26056,'Tornillo','Tornillo, Texas',32009,51);
INSERT INTO "django_geo_db_city" VALUES(26057,'Valentine','Valentine, Texas',32010,51);
INSERT INTO "django_geo_db_city" VALUES(26058,'Van Horn','Van Horn, Texas',32011,51);
INSERT INTO "django_geo_db_city" VALUES(26059,'El Paso','El Paso, Texas',32014,51);
INSERT INTO "django_geo_db_city" VALUES(26060,'El Paso','El Paso, New Mexico',32029,31);
INSERT INTO "django_geo_db_city" VALUES(26061,'Aurora','Aurora, Colorado',32042,7);
INSERT INTO "django_geo_db_city" VALUES(26062,'Arvada','Arvada, Colorado',32043,7);
INSERT INTO "django_geo_db_city" VALUES(26063,'Broomfield','Broomfield, Colorado',32059,7);
INSERT INTO "django_geo_db_city" VALUES(26064,'Commerce City','Commerce City, Colorado',32061,7);
INSERT INTO "django_geo_db_city" VALUES(26065,'Dupont','Dupont, Colorado',32062,7);
INSERT INTO "django_geo_db_city" VALUES(26066,'Eldorado Springs','Eldorado Springs, Colorado',32063,7);
INSERT INTO "django_geo_db_city" VALUES(26067,'Lafayette','Lafayette, Colorado',32064,7);
INSERT INTO "django_geo_db_city" VALUES(26068,'Louisville','Louisville, Colorado',32065,7);
INSERT INTO "django_geo_db_city" VALUES(26069,'Westminster','Westminster, Colorado',32067,7);
INSERT INTO "django_geo_db_city" VALUES(26070,'Wheat Ridge','Wheat Ridge, Colorado',32069,7);
INSERT INTO "django_geo_db_city" VALUES(26071,'Agate','Agate, Colorado',32074,7);
INSERT INTO "django_geo_db_city" VALUES(26072,'Bennett','Bennett, Colorado',32075,7);
INSERT INTO "django_geo_db_city" VALUES(26073,'Byers','Byers, Colorado',32076,7);
INSERT INTO "django_geo_db_city" VALUES(26074,'Castle Rock','Castle Rock, Colorado',32077,7);
INSERT INTO "django_geo_db_city" VALUES(26075,'Deer Trail','Deer Trail, Colorado',32078,7);
INSERT INTO "django_geo_db_city" VALUES(26076,'Elbert','Elbert, Colorado',32079,7);
INSERT INTO "django_geo_db_city" VALUES(26077,'Elizabeth','Elizabeth, Colorado',32080,7);
INSERT INTO "django_geo_db_city" VALUES(26078,'Englewood','Englewood, Colorado',32083,7);
INSERT INTO "django_geo_db_city" VALUES(26079,'Franktown','Franktown, Colorado',32087,7);
INSERT INTO "django_geo_db_city" VALUES(26080,'Kiowa','Kiowa, Colorado',32088,7);
INSERT INTO "django_geo_db_city" VALUES(26081,'Larkspur','Larkspur, Colorado',32089,7);
INSERT INTO "django_geo_db_city" VALUES(26082,'Littleton','Littleton, Colorado',32090,7);
INSERT INTO "django_geo_db_city" VALUES(26083,'Lone Tree','Lone Tree, Colorado',32100,7);
INSERT INTO "django_geo_db_city" VALUES(26084,'Louviers','Louviers, Colorado',32101,7);
INSERT INTO "django_geo_db_city" VALUES(26085,'Monument','Monument, Colorado',32102,7);
INSERT INTO "django_geo_db_city" VALUES(26086,'Palmer Lake','Palmer Lake, Colorado',32103,7);
INSERT INTO "django_geo_db_city" VALUES(26087,'Parker','Parker, Colorado',32104,7);
INSERT INTO "django_geo_db_city" VALUES(26088,'Sedalia','Sedalia, Colorado',32105,7);
INSERT INTO "django_geo_db_city" VALUES(26089,'Strasburg','Strasburg, Colorado',32106,7);
INSERT INTO "django_geo_db_city" VALUES(26090,'Watkins','Watkins, Colorado',32107,7);
INSERT INTO "django_geo_db_city" VALUES(26091,'Denver','Denver, Colorado',32110,7);
INSERT INTO "django_geo_db_city" VALUES(26092,'Sherrelwood','Sherrelwood, Colorado',32164,7);
INSERT INTO "django_geo_db_city" VALUES(26093,'Boulder','Boulder, Colorado',32165,7);
INSERT INTO "django_geo_db_city" VALUES(26094,'Golden','Golden, Colorado',32172,7);
INSERT INTO "django_geo_db_city" VALUES(26095,'Alma','Alma, Colorado',32174,7);
INSERT INTO "django_geo_db_city" VALUES(26096,'Bailey','Bailey, Colorado',32175,7);
INSERT INTO "django_geo_db_city" VALUES(26097,'Black Hawk','Black Hawk, Colorado',32176,7);
INSERT INTO "django_geo_db_city" VALUES(26098,'Bond','Bond, Colorado',32177,7);
INSERT INTO "django_geo_db_city" VALUES(26099,'Breckenridge','Breckenridge, Colorado',32178,7);
INSERT INTO "django_geo_db_city" VALUES(26100,'Buffalo Creek','Buffalo Creek, Colorado',32179,7);
INSERT INTO "django_geo_db_city" VALUES(26101,'Burns','Burns, Colorado',32180,7);
INSERT INTO "django_geo_db_city" VALUES(26102,'Central City','Central City, Colorado',32181,7);
INSERT INTO "django_geo_db_city" VALUES(26103,'Clark','Clark, Colorado',32182,7);
INSERT INTO "django_geo_db_city" VALUES(26104,'Climax','Climax, Colorado',32183,7);
INSERT INTO "django_geo_db_city" VALUES(26105,'Coalmont','Coalmont, Colorado',32184,7);
INSERT INTO "django_geo_db_city" VALUES(26106,'Como','Como, Colorado',32185,7);
INSERT INTO "django_geo_db_city" VALUES(26107,'Conifer','Conifer, Colorado',32186,7);
INSERT INTO "django_geo_db_city" VALUES(26108,'Cowdrey','Cowdrey, Colorado',32187,7);
INSERT INTO "django_geo_db_city" VALUES(26109,'Dillon','Dillon, Colorado',32188,7);
INSERT INTO "django_geo_db_city" VALUES(26110,'Dumont','Dumont, Colorado',32189,7);
INSERT INTO "django_geo_db_city" VALUES(26111,'Evergreen','Evergreen, Colorado',32043,7);
INSERT INTO "django_geo_db_city" VALUES(26112,'Empire','Empire, Colorado',32190,7);
INSERT INTO "django_geo_db_city" VALUES(26113,'Fairplay','Fairplay, Colorado',32192,7);
INSERT INTO "django_geo_db_city" VALUES(26114,'Fraser','Fraser, Colorado',32193,7);
INSERT INTO "django_geo_db_city" VALUES(26115,'Frisco','Frisco, Colorado',32194,7);
INSERT INTO "django_geo_db_city" VALUES(26116,'Georgetown','Georgetown, Colorado',32195,7);
INSERT INTO "django_geo_db_city" VALUES(26117,'Granby','Granby, Colorado',32196,7);
INSERT INTO "django_geo_db_city" VALUES(26118,'Grand Lake','Grand Lake, Colorado',32197,7);
INSERT INTO "django_geo_db_city" VALUES(26119,'Grant','Grant, Colorado',32198,7);
INSERT INTO "django_geo_db_city" VALUES(26120,'Hartsel','Hartsel, Colorado',32199,7);
INSERT INTO "django_geo_db_city" VALUES(26121,'Hot Sulphur Springs','Hot Sulphur Springs, Colorado',32200,7);
INSERT INTO "django_geo_db_city" VALUES(26122,'Idaho Springs','Idaho Springs, Colorado',32201,7);
INSERT INTO "django_geo_db_city" VALUES(26123,'Idledale','Idledale, Colorado',32202,7);
INSERT INTO "django_geo_db_city" VALUES(26124,'Indian Hills','Indian Hills, Colorado',32203,7);
INSERT INTO "django_geo_db_city" VALUES(26125,'Jamestown','Jamestown, Colorado',32204,7);
INSERT INTO "django_geo_db_city" VALUES(26126,'Jefferson','Jefferson, Colorado',32205,7);
INSERT INTO "django_geo_db_city" VALUES(26127,'Kittredge','Kittredge, Colorado',32206,7);
INSERT INTO "django_geo_db_city" VALUES(26128,'Kremmling','Kremmling, Colorado',32207,7);
INSERT INTO "django_geo_db_city" VALUES(26129,'Leadville','Leadville, Colorado',32208,7);
INSERT INTO "django_geo_db_city" VALUES(26130,'McCoy','McCoy, Colorado',32209,7);
INSERT INTO "django_geo_db_city" VALUES(26131,'Morrison','Morrison, Colorado',32210,7);
INSERT INTO "django_geo_db_city" VALUES(26132,'Nederland','Nederland, Colorado',32211,7);
INSERT INTO "django_geo_db_city" VALUES(26133,'Oak Creek','Oak Creek, Colorado',32212,7);
INSERT INTO "django_geo_db_city" VALUES(26134,'Parshall','Parshall, Colorado',32213,7);
INSERT INTO "django_geo_db_city" VALUES(26135,'Phippsburg','Phippsburg, Colorado',32214,7);
INSERT INTO "django_geo_db_city" VALUES(26136,'Pine','Pine, Colorado',32215,7);
INSERT INTO "django_geo_db_city" VALUES(26137,'Pinecliffe','Pinecliffe, Colorado',32216,7);
INSERT INTO "django_geo_db_city" VALUES(26138,'Rand','Rand, Colorado',32217,7);
INSERT INTO "django_geo_db_city" VALUES(26139,'Rollinsville','Rollinsville, Colorado',32218,7);
INSERT INTO "django_geo_db_city" VALUES(26140,'Shawnee','Shawnee, Colorado',32219,7);
INSERT INTO "django_geo_db_city" VALUES(26141,'Silver Plume','Silver Plume, Colorado',32220,7);
INSERT INTO "django_geo_db_city" VALUES(26142,'Steamboat Springs','Steamboat Springs, Colorado',32221,7);
INSERT INTO "django_geo_db_city" VALUES(26143,'Tabernash','Tabernash, Colorado',32222,7);
INSERT INTO "django_geo_db_city" VALUES(26144,'Toponas','Toponas, Colorado',32223,7);
INSERT INTO "django_geo_db_city" VALUES(26145,'Walden','Walden, Colorado',32224,7);
INSERT INTO "django_geo_db_city" VALUES(26146,'Ward','Ward, Colorado',32225,7);
INSERT INTO "django_geo_db_city" VALUES(26147,'Winter Park','Winter Park, Colorado',32226,7);
INSERT INTO "django_geo_db_city" VALUES(26148,'Yampa','Yampa, Colorado',32227,7);
INSERT INTO "django_geo_db_city" VALUES(26149,'Silverthorne','Silverthorne, Colorado',32230,7);
INSERT INTO "django_geo_db_city" VALUES(26150,'Longmont','Longmont, Colorado',32232,7);
INSERT INTO "django_geo_db_city" VALUES(26151,'Colorado Springs','Colorado Springs, Colorado',32235,7);
INSERT INTO "django_geo_db_city" VALUES(26152,'Allenspark','Allenspark, Colorado',32236,7);
INSERT INTO "django_geo_db_city" VALUES(26153,'Estes Park','Estes Park, Colorado',32237,7);
INSERT INTO "django_geo_db_city" VALUES(26154,'Bellvue','Bellvue, Colorado',32238,7);
INSERT INTO "django_geo_db_city" VALUES(26155,'Berthoud','Berthoud, Colorado',32239,7);
INSERT INTO "django_geo_db_city" VALUES(26156,'Dacono','Dacono, Colorado',32240,7);
INSERT INTO "django_geo_db_city" VALUES(26157,'Drake','Drake, Colorado',32241,7);
INSERT INTO "django_geo_db_city" VALUES(26158,'Erie','Erie, Colorado',32242,7);
INSERT INTO "django_geo_db_city" VALUES(26159,'Firestone','Firestone, Colorado',32244,7);
INSERT INTO "django_geo_db_city" VALUES(26160,'Fort Collins','Fort Collins, Colorado',32245,7);
INSERT INTO "django_geo_db_city" VALUES(26161,'Frederick','Frederick, Colorado',32253,7);
INSERT INTO "django_geo_db_city" VALUES(26162,'Glen Haven','Glen Haven, Colorado',32254,7);
INSERT INTO "django_geo_db_city" VALUES(26163,'Hygiene','Hygiene, Colorado',32255,7);
INSERT INTO "django_geo_db_city" VALUES(26164,'Johnstown','Johnstown, Colorado',32256,7);
INSERT INTO "django_geo_db_city" VALUES(26165,'Laporte','Laporte, Colorado',32257,7);
INSERT INTO "django_geo_db_city" VALUES(26166,'Livermore','Livermore, Colorado',32258,7);
INSERT INTO "django_geo_db_city" VALUES(26167,'Loveland','Loveland, Colorado',32259,7);
INSERT INTO "django_geo_db_city" VALUES(26168,'Lyons','Lyons, Colorado',32262,7);
INSERT INTO "django_geo_db_city" VALUES(26169,'Masonville','Masonville, Colorado',32263,7);
INSERT INTO "django_geo_db_city" VALUES(26170,'Mead','Mead, Colorado',32264,7);
INSERT INTO "django_geo_db_city" VALUES(26171,'Milliken','Milliken, Colorado',32265,7);
INSERT INTO "django_geo_db_city" VALUES(26172,'Niwot','Niwot, Colorado',32266,7);
INSERT INTO "django_geo_db_city" VALUES(26173,'Red Feather Lakes','Red Feather Lakes, Colorado',32267,7);
INSERT INTO "django_geo_db_city" VALUES(26174,'Severance','Severance, Colorado',32268,7);
INSERT INTO "django_geo_db_city" VALUES(26175,'Timnath','Timnath, Colorado',32269,7);
INSERT INTO "django_geo_db_city" VALUES(26176,'Wellington','Wellington, Colorado',32270,7);
INSERT INTO "django_geo_db_city" VALUES(26177,'Windsor','Windsor, Colorado',32271,7);
INSERT INTO "django_geo_db_city" VALUES(26178,'Brighton','Brighton, Colorado',32273,7);
INSERT INTO "django_geo_db_city" VALUES(26179,'Thornton','Thornton, Colorado',32274,7);
INSERT INTO "django_geo_db_city" VALUES(26180,'Lochbuie','Lochbuie, Colorado',32275,7);
INSERT INTO "django_geo_db_city" VALUES(26181,'Ault','Ault, Colorado',32276,7);
INSERT INTO "django_geo_db_city" VALUES(26182,'Briggsdale','Briggsdale, Colorado',32277,7);
INSERT INTO "django_geo_db_city" VALUES(26183,'Carr','Carr, Colorado',32278,7);
INSERT INTO "django_geo_db_city" VALUES(26184,'Eastlake','Eastlake, Colorado',32070,7);
INSERT INTO "django_geo_db_city" VALUES(26185,'Eaton','Eaton, Colorado',32279,7);
INSERT INTO "django_geo_db_city" VALUES(26186,'Evans','Evans, Colorado',32280,7);
INSERT INTO "django_geo_db_city" VALUES(26187,'Fort Lupton','Fort Lupton, Colorado',32281,7);
INSERT INTO "django_geo_db_city" VALUES(26188,'Galeton','Galeton, Colorado',32282,7);
INSERT INTO "django_geo_db_city" VALUES(26189,'Gilcrest','Gilcrest, Colorado',32283,7);
INSERT INTO "django_geo_db_city" VALUES(26190,'Gill','Gill, Colorado',32284,7);
INSERT INTO "django_geo_db_city" VALUES(26191,'Greeley','Greeley, Colorado',32285,7);
INSERT INTO "django_geo_db_city" VALUES(26192,'Henderson','Henderson, Colorado',32291,7);
INSERT INTO "django_geo_db_city" VALUES(26193,'Hudson','Hudson, Colorado',32292,7);
INSERT INTO "django_geo_db_city" VALUES(26194,'Keenesburg','Keenesburg, Colorado',32293,7);
INSERT INTO "django_geo_db_city" VALUES(26195,'Kersey','Kersey, Colorado',32294,7);
INSERT INTO "django_geo_db_city" VALUES(26196,'La Salle','La Salle, Colorado',32295,7);
INSERT INTO "django_geo_db_city" VALUES(26197,'Lucerne','Lucerne, Colorado',32296,7);
INSERT INTO "django_geo_db_city" VALUES(26198,'Nunn','Nunn, Colorado',32297,7);
INSERT INTO "django_geo_db_city" VALUES(26199,'Orchard','Orchard, Colorado',32298,7);
INSERT INTO "django_geo_db_city" VALUES(26200,'Pierce','Pierce, Colorado',32299,7);
INSERT INTO "django_geo_db_city" VALUES(26201,'Platteville','Platteville, Colorado',32300,7);
INSERT INTO "django_geo_db_city" VALUES(26202,'Roggen','Roggen, Colorado',32301,7);
INSERT INTO "django_geo_db_city" VALUES(26203,'Weldona','Weldona, Colorado',32302,7);
INSERT INTO "django_geo_db_city" VALUES(26204,'Wiggins','Wiggins, Colorado',32303,7);
INSERT INTO "django_geo_db_city" VALUES(26205,'Fort Morgan','Fort Morgan, Colorado',32304,7);
INSERT INTO "django_geo_db_city" VALUES(26206,'Log Lane Village','Log Lane Village, Colorado',32305,7);
INSERT INTO "django_geo_db_city" VALUES(26207,'Akron','Akron, Colorado',32306,7);
INSERT INTO "django_geo_db_city" VALUES(26208,'Amherst','Amherst, Colorado',32307,7);
INSERT INTO "django_geo_db_city" VALUES(26209,'Atwood','Atwood, Colorado',32308,7);
INSERT INTO "django_geo_db_city" VALUES(26210,'Brush','Brush, Colorado',32309,7);
INSERT INTO "django_geo_db_city" VALUES(26211,'Crook','Crook, Colorado',32310,7);
INSERT INTO "django_geo_db_city" VALUES(26212,'Eckley','Eckley, Colorado',32311,7);
INSERT INTO "django_geo_db_city" VALUES(26213,'Fleming','Fleming, Colorado',32312,7);
INSERT INTO "django_geo_db_city" VALUES(26214,'Grover','Grover, Colorado',32313,7);
INSERT INTO "django_geo_db_city" VALUES(26215,'Haxtun','Haxtun, Colorado',32314,7);
INSERT INTO "django_geo_db_city" VALUES(26216,'Hereford','Hereford, Colorado',32315,7);
INSERT INTO "django_geo_db_city" VALUES(26217,'Hillrose','Hillrose, Colorado',32316,7);
INSERT INTO "django_geo_db_city" VALUES(26218,'Holyoke','Holyoke, Colorado',32317,7);
INSERT INTO "django_geo_db_city" VALUES(26219,'Idalia','Idalia, Colorado',32318,7);
INSERT INTO "django_geo_db_city" VALUES(26220,'Iliff','Iliff, Colorado',32319,7);
INSERT INTO "django_geo_db_city" VALUES(26221,'Julesburg','Julesburg, Colorado',32320,7);
INSERT INTO "django_geo_db_city" VALUES(26222,'Lindon','Lindon, Colorado',32321,7);
INSERT INTO "django_geo_db_city" VALUES(26223,'Merino','Merino, Colorado',32322,7);
INSERT INTO "django_geo_db_city" VALUES(26224,'New Raymer','New Raymer, Colorado',32323,7);
INSERT INTO "django_geo_db_city" VALUES(26225,'Otis','Otis, Colorado',32324,7);
INSERT INTO "django_geo_db_city" VALUES(26226,'Ovid','Ovid, Colorado',32325,7);
INSERT INTO "django_geo_db_city" VALUES(26227,'Padroni','Padroni, Colorado',32326,7);
INSERT INTO "django_geo_db_city" VALUES(26228,'Paoli','Paoli, Colorado',32327,7);
INSERT INTO "django_geo_db_city" VALUES(26229,'Peetz','Peetz, Colorado',32328,7);
INSERT INTO "django_geo_db_city" VALUES(26230,'Sedgwick','Sedgwick, Colorado',32329,7);
INSERT INTO "django_geo_db_city" VALUES(26231,'Snyder','Snyder, Colorado',32330,7);
INSERT INTO "django_geo_db_city" VALUES(26232,'Sterling','Sterling, Colorado',32331,7);
INSERT INTO "django_geo_db_city" VALUES(26233,'Stoneham','Stoneham, Colorado',32332,7);
INSERT INTO "django_geo_db_city" VALUES(26234,'Vernon','Vernon, Colorado',32333,7);
INSERT INTO "django_geo_db_city" VALUES(26235,'Woodrow','Woodrow, Colorado',32334,7);
INSERT INTO "django_geo_db_city" VALUES(26236,'Wray','Wray, Colorado',32335,7);
INSERT INTO "django_geo_db_city" VALUES(26237,'Yuma','Yuma, Colorado',32336,7);
INSERT INTO "django_geo_db_city" VALUES(26238,'Anton','Anton, Colorado',32337,7);
INSERT INTO "django_geo_db_city" VALUES(26239,'Arapahoe','Arapahoe, Colorado',32338,7);
INSERT INTO "django_geo_db_city" VALUES(26240,'Arriba','Arriba, Colorado',32339,7);
INSERT INTO "django_geo_db_city" VALUES(26241,'Bethune','Bethune, Colorado',32340,7);
INSERT INTO "django_geo_db_city" VALUES(26242,'Burlington','Burlington, Colorado',32341,7);
INSERT INTO "django_geo_db_city" VALUES(26243,'Calhan','Calhan, Colorado',32342,7);
INSERT INTO "django_geo_db_city" VALUES(26244,'Cascade','Cascade, Colorado',32343,7);
INSERT INTO "django_geo_db_city" VALUES(26245,'Cheyenne Wells','Cheyenne Wells, Colorado',32344,7);
INSERT INTO "django_geo_db_city" VALUES(26246,'Cope','Cope, Colorado',32345,7);
INSERT INTO "django_geo_db_city" VALUES(26247,'Cripple Creek','Cripple Creek, Colorado',32346,7);
INSERT INTO "django_geo_db_city" VALUES(26248,'Divide','Divide, Colorado',32347,7);
INSERT INTO "django_geo_db_city" VALUES(26249,'Flagler','Flagler, Colorado',32348,7);
INSERT INTO "django_geo_db_city" VALUES(26250,'Florissant','Florissant, Colorado',32349,7);
INSERT INTO "django_geo_db_city" VALUES(26251,'Fountain','Fountain, Colorado',32350,7);
INSERT INTO "django_geo_db_city" VALUES(26252,'Genoa','Genoa, Colorado',32351,7);
INSERT INTO "django_geo_db_city" VALUES(26253,'Green Mountain Falls','Green Mountain Falls, Colorado',32352,7);
INSERT INTO "django_geo_db_city" VALUES(26254,'Guffey','Guffey, Colorado',32353,7);
INSERT INTO "django_geo_db_city" VALUES(26255,'Hugo','Hugo, Colorado',32354,7);
INSERT INTO "django_geo_db_city" VALUES(26256,'Joes','Joes, Colorado',32355,7);
INSERT INTO "django_geo_db_city" VALUES(26257,'Karval','Karval, Colorado',32356,7);
INSERT INTO "django_geo_db_city" VALUES(26258,'Kirk','Kirk, Colorado',32357,7);
INSERT INTO "django_geo_db_city" VALUES(26259,'Kit Carson','Kit Carson, Colorado',32358,7);
INSERT INTO "django_geo_db_city" VALUES(26260,'Limon','Limon, Colorado',32359,7);
INSERT INTO "django_geo_db_city" VALUES(26261,'Lake George','Lake George, Colorado',32360,7);
INSERT INTO "django_geo_db_city" VALUES(26262,'Manitou Springs','Manitou Springs, Colorado',32362,7);
INSERT INTO "django_geo_db_city" VALUES(26263,'Matheson','Matheson, Colorado',32363,7);
INSERT INTO "django_geo_db_city" VALUES(26264,'Peyton','Peyton, Colorado',32364,7);
INSERT INTO "django_geo_db_city" VALUES(26265,'Ramah','Ramah, Colorado',32365,7);
INSERT INTO "django_geo_db_city" VALUES(26266,'Rush','Rush, Colorado',32366,7);
INSERT INTO "django_geo_db_city" VALUES(26267,'Seibert','Seibert, Colorado',32367,7);
INSERT INTO "django_geo_db_city" VALUES(26268,'Simla','Simla, Colorado',32368,7);
INSERT INTO "django_geo_db_city" VALUES(26269,'Stratton','Stratton, Colorado',32369,7);
INSERT INTO "django_geo_db_city" VALUES(26270,'U S A F Academy','U S A F Academy, Colorado',32370,7);
INSERT INTO "django_geo_db_city" VALUES(26271,'Victor','Victor, Colorado',32372,7);
INSERT INTO "django_geo_db_city" VALUES(26272,'Vona','Vona, Colorado',32373,7);
INSERT INTO "django_geo_db_city" VALUES(26273,'Wild Horse','Wild Horse, Colorado',32374,7);
INSERT INTO "django_geo_db_city" VALUES(26274,'Woodland Park','Woodland Park, Colorado',32375,7);
INSERT INTO "django_geo_db_city" VALUES(26275,'Yoder','Yoder, Colorado',32376,7);
INSERT INTO "django_geo_db_city" VALUES(26276,'Pueblo','Pueblo, Colorado',32407,7);
INSERT INTO "django_geo_db_city" VALUES(26277,'Colorado City','Colorado City, Colorado',32415,7);
INSERT INTO "django_geo_db_city" VALUES(26278,'Aguilar','Aguilar, Colorado',32416,7);
INSERT INTO "django_geo_db_city" VALUES(26279,'Arlington','Arlington, Colorado',32417,7);
INSERT INTO "django_geo_db_city" VALUES(26280,'Avondale','Avondale, Colorado',32418,7);
INSERT INTO "django_geo_db_city" VALUES(26281,'Beulah','Beulah, Colorado',32419,7);
INSERT INTO "django_geo_db_city" VALUES(26282,'Boncarbo','Boncarbo, Colorado',32420,7);
INSERT INTO "django_geo_db_city" VALUES(26283,'Boone','Boone, Colorado',32421,7);
INSERT INTO "django_geo_db_city" VALUES(26284,'Branson','Branson, Colorado',32422,7);
INSERT INTO "django_geo_db_city" VALUES(26285,'Campo','Campo, Colorado',32423,7);
INSERT INTO "django_geo_db_city" VALUES(26286,'Cheraw','Cheraw, Colorado',32424,7);
INSERT INTO "django_geo_db_city" VALUES(26287,'Crowley','Crowley, Colorado',32425,7);
INSERT INTO "django_geo_db_city" VALUES(26288,'Eads','Eads, Colorado',32427,7);
INSERT INTO "django_geo_db_city" VALUES(26289,'Fort Lyon','Fort Lyon, Colorado',32428,7);
INSERT INTO "django_geo_db_city" VALUES(26290,'Fowler','Fowler, Colorado',32429,7);
INSERT INTO "django_geo_db_city" VALUES(26291,'Gardner','Gardner, Colorado',32430,7);
INSERT INTO "django_geo_db_city" VALUES(26292,'Granada','Granada, Colorado',32431,7);
INSERT INTO "django_geo_db_city" VALUES(26293,'Gulnare','Gulnare, Colorado',32432,7);
INSERT INTO "django_geo_db_city" VALUES(26294,'Hartman','Hartman, Colorado',32433,7);
INSERT INTO "django_geo_db_city" VALUES(26295,'Hasty','Hasty, Colorado',32434,7);
INSERT INTO "django_geo_db_city" VALUES(26296,'Haswell','Haswell, Colorado',32435,7);
INSERT INTO "django_geo_db_city" VALUES(26297,'Hoehne','Hoehne, Colorado',32436,7);
INSERT INTO "django_geo_db_city" VALUES(26298,'Holly','Holly, Colorado',32437,7);
INSERT INTO "django_geo_db_city" VALUES(26299,'Kim','Kim, Colorado',32438,7);
INSERT INTO "django_geo_db_city" VALUES(26300,'La Junta','La Junta, Colorado',32439,7);
INSERT INTO "django_geo_db_city" VALUES(26301,'Lamar','Lamar, Colorado',32440,7);
INSERT INTO "django_geo_db_city" VALUES(26302,'Las Animas','Las Animas, Colorado',32441,7);
INSERT INTO "django_geo_db_city" VALUES(26303,'La Veta','La Veta, Colorado',32442,7);
INSERT INTO "django_geo_db_city" VALUES(26304,'McClave','McClave, Colorado',32443,7);
INSERT INTO "django_geo_db_city" VALUES(26305,'Manzanola','Manzanola, Colorado',32444,7);
INSERT INTO "django_geo_db_city" VALUES(26306,'Model','Model, Colorado',32445,7);
INSERT INTO "django_geo_db_city" VALUES(26307,'Olney Springs','Olney Springs, Colorado',32446,7);
INSERT INTO "django_geo_db_city" VALUES(26308,'Ordway','Ordway, Colorado',32447,7);
INSERT INTO "django_geo_db_city" VALUES(26309,'Pritchett','Pritchett, Colorado',32448,7);
INSERT INTO "django_geo_db_city" VALUES(26310,'Red Wing','Red Wing, Colorado',32449,7);
INSERT INTO "django_geo_db_city" VALUES(26311,'Rocky Ford','Rocky Ford, Colorado',32450,7);
INSERT INTO "django_geo_db_city" VALUES(26312,'Rye','Rye, Colorado',32451,7);
INSERT INTO "django_geo_db_city" VALUES(26313,'Sheridan Lake','Sheridan Lake, Colorado',32452,7);
INSERT INTO "django_geo_db_city" VALUES(26314,'Springfield','Springfield, Colorado',32453,7);
INSERT INTO "django_geo_db_city" VALUES(26315,'Starkville','Starkville, Colorado',32454,7);
INSERT INTO "django_geo_db_city" VALUES(26316,'Sugar City','Sugar City, Colorado',32455,7);
INSERT INTO "django_geo_db_city" VALUES(26317,'Swink','Swink, Colorado',32456,7);
INSERT INTO "django_geo_db_city" VALUES(26318,'Trinchera','Trinchera, Colorado',32458,7);
INSERT INTO "django_geo_db_city" VALUES(26319,'Trinidad','Trinidad, Colorado',32459,7);
INSERT INTO "django_geo_db_city" VALUES(26320,'Two Buttes','Two Buttes, Colorado',32460,7);
INSERT INTO "django_geo_db_city" VALUES(26321,'Vilas','Vilas, Colorado',32461,7);
INSERT INTO "django_geo_db_city" VALUES(26322,'Walsenburg','Walsenburg, Colorado',32462,7);
INSERT INTO "django_geo_db_city" VALUES(26323,'Walsh','Walsh, Colorado',32463,7);
INSERT INTO "django_geo_db_city" VALUES(26324,'Weston','Weston, Colorado',32464,7);
INSERT INTO "django_geo_db_city" VALUES(26325,'Wiley','Wiley, Colorado',32465,7);
INSERT INTO "django_geo_db_city" VALUES(26326,'Alamosa','Alamosa, Colorado',32466,7);
INSERT INTO "django_geo_db_city" VALUES(26327,'Antonito','Antonito, Colorado',32468,7);
INSERT INTO "django_geo_db_city" VALUES(26328,'Arboles','Arboles, Colorado',32469,7);
INSERT INTO "django_geo_db_city" VALUES(26329,'Bayfield','Bayfield, Colorado',32470,7);
INSERT INTO "django_geo_db_city" VALUES(26330,'Blanca','Blanca, Colorado',32471,7);
INSERT INTO "django_geo_db_city" VALUES(26331,'Capulin','Capulin, Colorado',32472,7);
INSERT INTO "django_geo_db_city" VALUES(26332,'Center','Center, Colorado',32473,7);
INSERT INTO "django_geo_db_city" VALUES(26333,'Chama','Chama, Colorado',32474,7);
INSERT INTO "django_geo_db_city" VALUES(26334,'Chimney Rock','Chimney Rock, Colorado',32475,7);
INSERT INTO "django_geo_db_city" VALUES(26335,'Chromo','Chromo, Colorado',32476,7);
INSERT INTO "django_geo_db_city" VALUES(26336,'Conejos','Conejos, Colorado',32477,7);
INSERT INTO "django_geo_db_city" VALUES(26337,'Creede','Creede, Colorado',32478,7);
INSERT INTO "django_geo_db_city" VALUES(26338,'Crestone','Crestone, Colorado',32479,7);
INSERT INTO "django_geo_db_city" VALUES(26339,'Del Norte','Del Norte, Colorado',32480,7);
INSERT INTO "django_geo_db_city" VALUES(26340,'Fort Garland','Fort Garland, Colorado',32481,7);
INSERT INTO "django_geo_db_city" VALUES(26341,'Garcia','Garcia, Colorado',32482,7);
INSERT INTO "django_geo_db_city" VALUES(26342,'Homelake','Homelake, Colorado',32483,7);
INSERT INTO "django_geo_db_city" VALUES(26343,'Hooper','Hooper, Colorado',32484,7);
INSERT INTO "django_geo_db_city" VALUES(26344,'Ignacio','Ignacio, Colorado',32485,7);
INSERT INTO "django_geo_db_city" VALUES(26345,'Jaroso','Jaroso, Colorado',32486,7);
INSERT INTO "django_geo_db_city" VALUES(26346,'La Jara','La Jara, Colorado',32487,7);
INSERT INTO "django_geo_db_city" VALUES(26347,'Manassa','Manassa, Colorado',32488,7);
INSERT INTO "django_geo_db_city" VALUES(26348,'Moffat','Moffat, Colorado',32489,7);
INSERT INTO "django_geo_db_city" VALUES(26349,'Monte Vista','Monte Vista, Colorado',32490,7);
INSERT INTO "django_geo_db_city" VALUES(26350,'Mosca','Mosca, Colorado',32491,7);
INSERT INTO "django_geo_db_city" VALUES(26351,'Pagosa Springs','Pagosa Springs, Colorado',32492,7);
INSERT INTO "django_geo_db_city" VALUES(26352,'Romeo','Romeo, Colorado',32493,7);
INSERT INTO "django_geo_db_city" VALUES(26353,'Saguache','Saguache, Colorado',32494,7);
INSERT INTO "django_geo_db_city" VALUES(26354,'Sanford','Sanford, Colorado',32495,7);
INSERT INTO "django_geo_db_city" VALUES(26355,'San Luis','San Luis, Colorado',32496,7);
INSERT INTO "django_geo_db_city" VALUES(26356,'San Pablo','San Pablo, Colorado',32497,7);
INSERT INTO "django_geo_db_city" VALUES(26357,'South Fork','South Fork, Colorado',32498,7);
INSERT INTO "django_geo_db_city" VALUES(26358,'Villa Grove','Villa Grove, Colorado',32499,7);
INSERT INTO "django_geo_db_city" VALUES(26359,'Salida','Salida, Colorado',32501,7);
INSERT INTO "django_geo_db_city" VALUES(26360,'Almont','Almont, Colorado',32502,7);
INSERT INTO "django_geo_db_city" VALUES(26361,'Buena Vista','Buena Vista, Colorado',32503,7);
INSERT INTO "django_geo_db_city" VALUES(26362,'Canon City','Canon City, Colorado',32504,7);
INSERT INTO "django_geo_db_city" VALUES(26363,'Cimarron','Cimarron, Colorado',32506,7);
INSERT INTO "django_geo_db_city" VALUES(26364,'Coal Creek','Coal Creek, Colorado',32507,7);
INSERT INTO "django_geo_db_city" VALUES(26365,'Coaldale','Coaldale, Colorado',32508,7);
INSERT INTO "django_geo_db_city" VALUES(26366,'Cotopaxi','Cotopaxi, Colorado',32509,7);
INSERT INTO "django_geo_db_city" VALUES(26367,'Crested Butte','Crested Butte, Colorado',32510,7);
INSERT INTO "django_geo_db_city" VALUES(26368,'Florence','Florence, Colorado',32512,7);
INSERT INTO "django_geo_db_city" VALUES(26369,'Monarch','Monarch, Colorado',32513,7);
INSERT INTO "django_geo_db_city" VALUES(26370,'Granite','Granite, Colorado',32514,7);
INSERT INTO "django_geo_db_city" VALUES(26371,'Gunnison','Gunnison, Colorado',32515,7);
INSERT INTO "django_geo_db_city" VALUES(26372,'Hillside','Hillside, Colorado',32517,7);
INSERT INTO "django_geo_db_city" VALUES(26373,'Howard','Howard, Colorado',32518,7);
INSERT INTO "django_geo_db_city" VALUES(26374,'Lake City','Lake City, Colorado',32519,7);
INSERT INTO "django_geo_db_city" VALUES(26375,'Nathrop','Nathrop, Colorado',32520,7);
INSERT INTO "django_geo_db_city" VALUES(26376,'Ohio City','Ohio City, Colorado',32521,7);
INSERT INTO "django_geo_db_city" VALUES(26377,'Parlin','Parlin, Colorado',32522,7);
INSERT INTO "django_geo_db_city" VALUES(26378,'Penrose','Penrose, Colorado',32523,7);
INSERT INTO "django_geo_db_city" VALUES(26379,'Pitkin','Pitkin, Colorado',32524,7);
INSERT INTO "django_geo_db_city" VALUES(26380,'Poncha Springs','Poncha Springs, Colorado',32525,7);
INSERT INTO "django_geo_db_city" VALUES(26381,'Powderhorn','Powderhorn, Colorado',32526,7);
INSERT INTO "django_geo_db_city" VALUES(26382,'Rockvale','Rockvale, Colorado',32527,7);
INSERT INTO "django_geo_db_city" VALUES(26383,'Sargents','Sargents, Colorado',32529,7);
INSERT INTO "django_geo_db_city" VALUES(26384,'Twin Lakes','Twin Lakes, Colorado',32530,7);
INSERT INTO "django_geo_db_city" VALUES(26385,'Westcliffe','Westcliffe, Colorado',32531,7);
INSERT INTO "django_geo_db_city" VALUES(26386,'Wetmore','Wetmore, Colorado',32532,7);
INSERT INTO "django_geo_db_city" VALUES(26387,'Basalt','Basalt, Colorado',32533,7);
INSERT INTO "django_geo_db_city" VALUES(26388,'Durango','Durango, Colorado',32535,7);
INSERT INTO "django_geo_db_city" VALUES(26389,'Cahone','Cahone, Colorado',32539,7);
INSERT INTO "django_geo_db_city" VALUES(26390,'Cortez','Cortez, Colorado',32540,7);
INSERT INTO "django_geo_db_city" VALUES(26391,'Dolores','Dolores, Colorado',32541,7);
INSERT INTO "django_geo_db_city" VALUES(26392,'Dove Creek','Dove Creek, Colorado',32542,7);
INSERT INTO "django_geo_db_city" VALUES(26393,'Egnar','Egnar, Colorado',32543,7);
INSERT INTO "django_geo_db_city" VALUES(26394,'Hesperus','Hesperus, Colorado',32544,7);
INSERT INTO "django_geo_db_city" VALUES(26395,'Lewis','Lewis, Colorado',32545,7);
INSERT INTO "django_geo_db_city" VALUES(26396,'Mancos','Mancos, Colorado',32546,7);
INSERT INTO "django_geo_db_city" VALUES(26397,'Marvel','Marvel, Colorado',32547,7);
INSERT INTO "django_geo_db_city" VALUES(26398,'Mesa Verde National Park','Mesa Verde National Park, Colorado',32548,7);
INSERT INTO "django_geo_db_city" VALUES(26399,'Pleasant View','Pleasant View, Colorado',32549,7);
INSERT INTO "django_geo_db_city" VALUES(26400,'Rico','Rico, Colorado',32550,7);
INSERT INTO "django_geo_db_city" VALUES(26401,'Towaoc','Towaoc, Colorado',32551,7);
INSERT INTO "django_geo_db_city" VALUES(26402,'Yellow Jacket','Yellow Jacket, Colorado',32552,7);
INSERT INTO "django_geo_db_city" VALUES(26403,'Montrose','Montrose, Colorado',32553,7);
INSERT INTO "django_geo_db_city" VALUES(26404,'Austin','Austin, Colorado',32555,7);
INSERT INTO "django_geo_db_city" VALUES(26405,'Bedrock','Bedrock, Colorado',32556,7);
INSERT INTO "django_geo_db_city" VALUES(26406,'Cedaredge','Cedaredge, Colorado',32557,7);
INSERT INTO "django_geo_db_city" VALUES(26407,'Cory','Cory, Colorado',32558,7);
INSERT INTO "django_geo_db_city" VALUES(26408,'Crawford','Crawford, Colorado',32559,7);
INSERT INTO "django_geo_db_city" VALUES(26409,'Delta','Delta, Colorado',32560,7);
INSERT INTO "django_geo_db_city" VALUES(26410,'Eckert','Eckert, Colorado',32561,7);
INSERT INTO "django_geo_db_city" VALUES(26411,'Hotchkiss','Hotchkiss, Colorado',32562,7);
INSERT INTO "django_geo_db_city" VALUES(26412,'Lazear','Lazear, Colorado',32563,7);
INSERT INTO "django_geo_db_city" VALUES(26413,'Maher','Maher, Colorado',32564,7);
INSERT INTO "django_geo_db_city" VALUES(26414,'Naturita','Naturita, Colorado',32565,7);
INSERT INTO "django_geo_db_city" VALUES(26415,'Norwood','Norwood, Colorado',32566,7);
INSERT INTO "django_geo_db_city" VALUES(26416,'Nucla','Nucla, Colorado',32567,7);
INSERT INTO "django_geo_db_city" VALUES(26417,'Olathe','Olathe, Colorado',32568,7);
INSERT INTO "django_geo_db_city" VALUES(26418,'Ophir','Ophir, Colorado',32569,7);
INSERT INTO "django_geo_db_city" VALUES(26419,'Ouray','Ouray, Colorado',32570,7);
INSERT INTO "django_geo_db_city" VALUES(26420,'Paonia','Paonia, Colorado',32571,7);
INSERT INTO "django_geo_db_city" VALUES(26421,'Paradox','Paradox, Colorado',32572,7);
INSERT INTO "django_geo_db_city" VALUES(26422,'Placerville','Placerville, Colorado',32573,7);
INSERT INTO "django_geo_db_city" VALUES(26423,'Redvale','Redvale, Colorado',32574,7);
INSERT INTO "django_geo_db_city" VALUES(26424,'Ridgway','Ridgway, Colorado',32575,7);
INSERT INTO "django_geo_db_city" VALUES(26425,'Silverton','Silverton, Colorado',32576,7);
INSERT INTO "django_geo_db_city" VALUES(26426,'Somerset','Somerset, Colorado',32577,7);
INSERT INTO "django_geo_db_city" VALUES(26427,'Telluride','Telluride, Colorado',32578,7);
INSERT INTO "django_geo_db_city" VALUES(26428,'Grand Junction','Grand Junction, Colorado',32579,7);
INSERT INTO "django_geo_db_city" VALUES(26429,'Snowmass Village','Snowmass Village, Colorado',32585,7);
INSERT INTO "django_geo_db_city" VALUES(26430,'Clifton','Clifton, Colorado',32586,7);
INSERT INTO "django_geo_db_city" VALUES(26431,'Fruita','Fruita, Colorado',32587,7);
INSERT INTO "django_geo_db_city" VALUES(26432,'Gateway','Gateway, Colorado',32588,7);
INSERT INTO "django_geo_db_city" VALUES(26433,'Glade Park','Glade Park, Colorado',32589,7);
INSERT INTO "django_geo_db_city" VALUES(26434,'Loma','Loma, Colorado',32590,7);
INSERT INTO "django_geo_db_city" VALUES(26435,'Mack','Mack, Colorado',32591,7);
INSERT INTO "django_geo_db_city" VALUES(26436,'Palisade','Palisade, Colorado',32592,7);
INSERT INTO "django_geo_db_city" VALUES(26437,'Whitewater','Whitewater, Colorado',32593,7);
INSERT INTO "django_geo_db_city" VALUES(26438,'Glenwood Springs','Glenwood Springs, Colorado',32594,7);
INSERT INTO "django_geo_db_city" VALUES(26439,'Dinosaur','Dinosaur, Colorado',32596,7);
INSERT INTO "django_geo_db_city" VALUES(26440,'Aspen','Aspen, Colorado',32597,7);
INSERT INTO "django_geo_db_city" VALUES(26441,'Avon','Avon, Colorado',32601,7);
INSERT INTO "django_geo_db_city" VALUES(26442,'Carbondale','Carbondale, Colorado',32603,7);
INSERT INTO "django_geo_db_city" VALUES(26443,'Collbran','Collbran, Colorado',32604,7);
INSERT INTO "django_geo_db_city" VALUES(26444,'Craig','Craig, Colorado',32605,7);
INSERT INTO "django_geo_db_city" VALUES(26445,'El Jebel','El Jebel, Colorado',32607,7);
INSERT INTO "django_geo_db_city" VALUES(26446,'De Beque','De Beque, Colorado',32608,7);
INSERT INTO "django_geo_db_city" VALUES(26447,'Eagle','Eagle, Colorado',32609,7);
INSERT INTO "django_geo_db_city" VALUES(26448,'Edwards','Edwards, Colorado',32610,7);
INSERT INTO "django_geo_db_city" VALUES(26449,'Parachute','Parachute, Colorado',32612,7);
INSERT INTO "django_geo_db_city" VALUES(26450,'Battlement Mesa','Battlement Mesa, Colorado',32613,7);
INSERT INTO "django_geo_db_city" VALUES(26451,'Gypsum','Gypsum, Colorado',32614,7);
INSERT INTO "django_geo_db_city" VALUES(26452,'Hamilton','Hamilton, Colorado',32615,7);
INSERT INTO "django_geo_db_city" VALUES(26453,'Hayden','Hayden, Colorado',32616,7);
INSERT INTO "django_geo_db_city" VALUES(26454,'Maybell','Maybell, Colorado',32617,7);
INSERT INTO "django_geo_db_city" VALUES(26455,'Meeker','Meeker, Colorado',32618,7);
INSERT INTO "django_geo_db_city" VALUES(26456,'Meredith','Meredith, Colorado',32619,7);
INSERT INTO "django_geo_db_city" VALUES(26457,'Mesa','Mesa, Colorado',32620,7);
INSERT INTO "django_geo_db_city" VALUES(26458,'Minturn','Minturn, Colorado',32621,7);
INSERT INTO "django_geo_db_city" VALUES(26459,'Molina','Molina, Colorado',32622,7);
INSERT INTO "django_geo_db_city" VALUES(26460,'New Castle','New Castle, Colorado',32623,7);
INSERT INTO "django_geo_db_city" VALUES(26461,'Rangely','Rangely, Colorado',32624,7);
INSERT INTO "django_geo_db_city" VALUES(26462,'Red Cliff','Red Cliff, Colorado',32625,7);
INSERT INTO "django_geo_db_city" VALUES(26463,'Rifle','Rifle, Colorado',32626,7);
INSERT INTO "django_geo_db_city" VALUES(26464,'Silt','Silt, Colorado',32627,7);
INSERT INTO "django_geo_db_city" VALUES(26465,'Slater','Slater, Colorado',32628,7);
INSERT INTO "django_geo_db_city" VALUES(26466,'Snowmass','Snowmass, Colorado',32629,7);
INSERT INTO "django_geo_db_city" VALUES(26467,'Wolcott','Wolcott, Colorado',32630,7);
INSERT INTO "django_geo_db_city" VALUES(26468,'Woody Creek','Woody Creek, Colorado',32631,7);
INSERT INTO "django_geo_db_city" VALUES(26469,'Vail','Vail, Colorado',32632,7);
INSERT INTO "django_geo_db_city" VALUES(26470,'Cheyenne','Cheyenne, Wyoming',32634,59);
INSERT INTO "django_geo_db_city" VALUES(26471,'Fe Warren AFB','Fe Warren AFB, Wyoming',32637,59);
INSERT INTO "django_geo_db_city" VALUES(26472,'Albin','Albin, Wyoming',32640,59);
INSERT INTO "django_geo_db_city" VALUES(26473,'Bosler','Bosler, Wyoming',32641,59);
INSERT INTO "django_geo_db_city" VALUES(26474,'Buford','Buford, Wyoming',32642,59);
INSERT INTO "django_geo_db_city" VALUES(26475,'Burns','Burns, Wyoming',32643,59);
INSERT INTO "django_geo_db_city" VALUES(26476,'Carpenter','Carpenter, Wyoming',32644,59);
INSERT INTO "django_geo_db_city" VALUES(26477,'Centennial','Centennial, Wyoming',32645,59);
INSERT INTO "django_geo_db_city" VALUES(26478,'Garrett','Garrett, Wyoming',32646,59);
INSERT INTO "django_geo_db_city" VALUES(26479,'Granite Canon','Granite Canon, Wyoming',32647,59);
INSERT INTO "django_geo_db_city" VALUES(26480,'Hillsdale','Hillsdale, Wyoming',32648,59);
INSERT INTO "django_geo_db_city" VALUES(26481,'Horse Creek','Horse Creek, Wyoming',32649,59);
INSERT INTO "django_geo_db_city" VALUES(26482,'Jelm','Jelm, Colorado',32650,7);
INSERT INTO "django_geo_db_city" VALUES(26483,'Laramie','Laramie, Wyoming',32651,59);
INSERT INTO "django_geo_db_city" VALUES(26484,'Meriden','Meriden, Wyoming',32655,59);
INSERT INTO "django_geo_db_city" VALUES(26485,'Pine Bluffs','Pine Bluffs, Nebraska',32656,27);
INSERT INTO "django_geo_db_city" VALUES(26486,'Rock River','Rock River, Wyoming',32657,59);
INSERT INTO "django_geo_db_city" VALUES(26487,'Tie Siding','Tie Siding, Wyoming',32658,59);
INSERT INTO "django_geo_db_city" VALUES(26488,'Yellowstone National Park','Yellowstone National Park, Wyoming',32659,59);
INSERT INTO "django_geo_db_city" VALUES(26489,'Wheatland','Wheatland, Wyoming',32660,59);
INSERT INTO "django_geo_db_city" VALUES(26490,'Chugwater','Chugwater, Wyoming',32661,59);
INSERT INTO "django_geo_db_city" VALUES(26491,'Fort Laramie','Fort Laramie, Wyoming',32662,59);
INSERT INTO "django_geo_db_city" VALUES(26492,'Glendo','Glendo, Wyoming',32663,59);
INSERT INTO "django_geo_db_city" VALUES(26493,'Guernsey','Guernsey, Wyoming',32664,59);
INSERT INTO "django_geo_db_city" VALUES(26494,'Hartville','Hartville, Wyoming',32665,59);
INSERT INTO "django_geo_db_city" VALUES(26495,'Hawk Springs','Hawk Springs, Wyoming',32666,59);
INSERT INTO "django_geo_db_city" VALUES(26496,'Huntley','Huntley, Wyoming',32667,59);
INSERT INTO "django_geo_db_city" VALUES(26497,'Jay Em','Jay Em, Wyoming',32668,59);
INSERT INTO "django_geo_db_city" VALUES(26498,'Lagrange','Lagrange, Wyoming',32669,59);
INSERT INTO "django_geo_db_city" VALUES(26499,'Lance Creek','Lance Creek, Wyoming',32670,59);
INSERT INTO "django_geo_db_city" VALUES(26500,'Lingle','Lingle, Wyoming',32671,59);
INSERT INTO "django_geo_db_city" VALUES(26501,'Lost Springs','Lost Springs, Wyoming',32672,59);
INSERT INTO "django_geo_db_city" VALUES(26502,'Lusk','Lusk, Wyoming',32673,59);
INSERT INTO "django_geo_db_city" VALUES(26503,'Manville','Manville, Wyoming',32675,59);
INSERT INTO "django_geo_db_city" VALUES(26504,'Shawnee','Shawnee, Wyoming',32676,59);
INSERT INTO "django_geo_db_city" VALUES(26505,'Torrington','Torrington, Wyoming',32677,59);
INSERT INTO "django_geo_db_city" VALUES(26506,'Van Tassell','Van Tassell, Wyoming',32678,59);
INSERT INTO "django_geo_db_city" VALUES(26507,'Veteran','Veteran, Wyoming',32679,59);
INSERT INTO "django_geo_db_city" VALUES(26508,'Yoder','Yoder, Wyoming',32680,59);
INSERT INTO "django_geo_db_city" VALUES(26509,'Rawlins','Rawlins, Wyoming',32681,59);
INSERT INTO "django_geo_db_city" VALUES(26510,'Jeffrey City','Jeffrey City, Wyoming',32682,59);
INSERT INTO "django_geo_db_city" VALUES(26511,'Baggs','Baggs, Wyoming',32683,59);
INSERT INTO "django_geo_db_city" VALUES(26512,'Bairoil','Bairoil, Wyoming',32684,59);
INSERT INTO "django_geo_db_city" VALUES(26513,'Dixon','Dixon, Wyoming',32685,59);
INSERT INTO "django_geo_db_city" VALUES(26514,'Elk Mountain','Elk Mountain, Wyoming',32686,59);
INSERT INTO "django_geo_db_city" VALUES(26515,'Encampment','Encampment, Wyoming',32687,59);
INSERT INTO "django_geo_db_city" VALUES(26516,'Hanna','Hanna, Wyoming',32688,59);
INSERT INTO "django_geo_db_city" VALUES(26517,'Medicine Bow','Medicine Bow, Wyoming',32689,59);
INSERT INTO "django_geo_db_city" VALUES(26518,'Saratoga','Saratoga, Wyoming',32690,59);
INSERT INTO "django_geo_db_city" VALUES(26519,'Savery','Savery, Wyoming',32691,59);
INSERT INTO "django_geo_db_city" VALUES(26520,'Sinclair','Sinclair, Wyoming',32692,59);
INSERT INTO "django_geo_db_city" VALUES(26521,'Walcott','Walcott, Wyoming',32693,59);
INSERT INTO "django_geo_db_city" VALUES(26522,'Wamsutter','Wamsutter, Wyoming',32694,59);
INSERT INTO "django_geo_db_city" VALUES(26523,'Worland','Worland, Wyoming',32696,59);
INSERT INTO "django_geo_db_city" VALUES(26524,'Basin','Basin, Wyoming',32697,59);
INSERT INTO "django_geo_db_city" VALUES(26525,'Burlington','Burlington, Wyoming',32698,59);
INSERT INTO "django_geo_db_city" VALUES(26526,'Byron','Byron, Wyoming',32699,59);
INSERT INTO "django_geo_db_city" VALUES(26527,'Cody','Cody, Wyoming',32700,59);
INSERT INTO "django_geo_db_city" VALUES(26528,'Cowley','Cowley, Wyoming',32701,59);
INSERT INTO "django_geo_db_city" VALUES(26529,'Deaver','Deaver, Wyoming',32702,59);
INSERT INTO "django_geo_db_city" VALUES(26530,'Emblem','Emblem, Wyoming',32703,59);
INSERT INTO "django_geo_db_city" VALUES(26531,'Frannie','Frannie, Wyoming',32704,59);
INSERT INTO "django_geo_db_city" VALUES(26532,'Greybull','Greybull, Wyoming',32705,59);
INSERT INTO "django_geo_db_city" VALUES(26533,'Hamilton Dome','Hamilton Dome, Wyoming',32706,59);
INSERT INTO "django_geo_db_city" VALUES(26534,'Hyattville','Hyattville, Wyoming',32707,59);
INSERT INTO "django_geo_db_city" VALUES(26535,'Kirby','Kirby, Wyoming',32708,59);
INSERT INTO "django_geo_db_city" VALUES(26536,'Lovell','Lovell, Wyoming',32709,59);
INSERT INTO "django_geo_db_city" VALUES(26537,'Manderson','Manderson, Wyoming',32710,59);
INSERT INTO "django_geo_db_city" VALUES(26538,'Meeteetse','Meeteetse, Wyoming',32711,59);
INSERT INTO "django_geo_db_city" VALUES(26539,'Otto','Otto, Wyoming',32712,59);
INSERT INTO "django_geo_db_city" VALUES(26540,'Powell','Powell, Wyoming',32713,59);
INSERT INTO "django_geo_db_city" VALUES(26541,'Ralston','Ralston, Wyoming',32714,59);
INSERT INTO "django_geo_db_city" VALUES(26542,'Shell','Shell, Wyoming',32715,59);
INSERT INTO "django_geo_db_city" VALUES(26543,'Ten Sleep','Ten Sleep, Wyoming',32716,59);
INSERT INTO "django_geo_db_city" VALUES(26544,'Thermopolis','Thermopolis, Wyoming',32717,59);
INSERT INTO "django_geo_db_city" VALUES(26545,'Wapiti','Wapiti, Wyoming',32718,59);
INSERT INTO "django_geo_db_city" VALUES(26546,'Riverton','Riverton, Wyoming',32719,59);
INSERT INTO "django_geo_db_city" VALUES(26547,'Vista West','Vista West, Wyoming',32720,59);
INSERT INTO "django_geo_db_city" VALUES(26548,'Arapahoe','Arapahoe, Wyoming',32721,59);
INSERT INTO "django_geo_db_city" VALUES(26549,'Crowheart','Crowheart, Wyoming',32722,59);
INSERT INTO "django_geo_db_city" VALUES(26550,'Dubois','Dubois, Wyoming',32723,59);
INSERT INTO "django_geo_db_city" VALUES(26551,'Fort Washakie','Fort Washakie, Wyoming',32724,59);
INSERT INTO "django_geo_db_city" VALUES(26552,'Hudson','Hudson, Wyoming',32725,59);
INSERT INTO "django_geo_db_city" VALUES(26553,'Kinnear','Kinnear, Wyoming',32726,59);
INSERT INTO "django_geo_db_city" VALUES(26554,'Lander','Lander, Wyoming',32727,59);
INSERT INTO "django_geo_db_city" VALUES(26555,'Pavillion','Pavillion, Wyoming',32728,59);
INSERT INTO "django_geo_db_city" VALUES(26556,'Saint Stephens','Saint Stephens, Wyoming',32729,59);
INSERT INTO "django_geo_db_city" VALUES(26557,'Casper','Casper, Wyoming',32730,59);
INSERT INTO "django_geo_db_city" VALUES(26558,'Shirley Basin','Shirley Basin, Wyoming',32735,59);
INSERT INTO "django_geo_db_city" VALUES(26559,'Alcova','Alcova, Wyoming',32736,59);
INSERT INTO "django_geo_db_city" VALUES(26560,'Arminto','Arminto, Wyoming',32733,59);
INSERT INTO "django_geo_db_city" VALUES(26561,'Bill','Bill, Wyoming',32737,59);
INSERT INTO "django_geo_db_city" VALUES(26562,'Douglas','Douglas, Wyoming',32738,59);
INSERT INTO "django_geo_db_city" VALUES(26563,'Edgerton','Edgerton, Wyoming',32739,59);
INSERT INTO "django_geo_db_city" VALUES(26564,'Evansville','Evansville, Wyoming',32740,59);
INSERT INTO "django_geo_db_city" VALUES(26565,'Glenrock','Glenrock, Wyoming',32741,59);
INSERT INTO "django_geo_db_city" VALUES(26566,'Hiland','Hiland, Wyoming',32733,59);
INSERT INTO "django_geo_db_city" VALUES(26567,'Kaycee','Kaycee, Wyoming',32742,59);
INSERT INTO "django_geo_db_city" VALUES(26568,'Linch','Linch, Wyoming',32743,59);
INSERT INTO "django_geo_db_city" VALUES(26569,'Lysite','Lysite, Wyoming',32744,59);
INSERT INTO "django_geo_db_city" VALUES(26570,'Midwest','Midwest, Wyoming',32745,59);
INSERT INTO "django_geo_db_city" VALUES(26571,'Mills','Mills, Wyoming',32746,59);
INSERT INTO "django_geo_db_city" VALUES(26572,'Natrona','Natrona, Wyoming',32733,59);
INSERT INTO "django_geo_db_city" VALUES(26573,'Powder River','Powder River, Wyoming',32733,59);
INSERT INTO "django_geo_db_city" VALUES(26574,'Shoshoni','Shoshoni, Wyoming',32747,59);
INSERT INTO "django_geo_db_city" VALUES(26575,'Newcastle','Newcastle, Wyoming',32748,59);
INSERT INTO "django_geo_db_city" VALUES(26576,'Aladdin','Aladdin, Wyoming',32750,59);
INSERT INTO "django_geo_db_city" VALUES(26577,'Alva','Alva, Wyoming',32751,59);
INSERT INTO "django_geo_db_city" VALUES(26578,'Beulah','Beulah, Wyoming',32752,59);
INSERT INTO "django_geo_db_city" VALUES(26579,'Carlile','Carlile, Wyoming',32753,59);
INSERT INTO "django_geo_db_city" VALUES(26580,'Devils Tower','Devils Tower, Wyoming',32754,59);
INSERT INTO "django_geo_db_city" VALUES(26581,'Four Corners','Four Corners, Wyoming',32755,59);
INSERT INTO "django_geo_db_city" VALUES(26582,'Gillette','Gillette, Wyoming',32756,59);
INSERT INTO "django_geo_db_city" VALUES(26583,'Hulett','Hulett, Wyoming',32759,59);
INSERT INTO "django_geo_db_city" VALUES(26584,'Moorcroft','Moorcroft, Wyoming',32760,59);
INSERT INTO "django_geo_db_city" VALUES(26585,'Osage','Osage, Wyoming',32761,59);
INSERT INTO "django_geo_db_city" VALUES(26586,'Recluse','Recluse, Wyoming',32762,59);
INSERT INTO "django_geo_db_city" VALUES(26587,'Rozet','Rozet, Wyoming',32763,59);
INSERT INTO "django_geo_db_city" VALUES(26588,'Sundance','Sundance, Wyoming',32764,59);
INSERT INTO "django_geo_db_city" VALUES(26589,'Upton','Upton, Wyoming',32765,59);
INSERT INTO "django_geo_db_city" VALUES(26590,'Weston','Weston, Wyoming',32766,59);
INSERT INTO "django_geo_db_city" VALUES(26591,'Wright','Wright, Wyoming',32767,59);
INSERT INTO "django_geo_db_city" VALUES(26592,'Sheridan','Sheridan, Wyoming',32769,59);
INSERT INTO "django_geo_db_city" VALUES(26593,'Arvada','Arvada, Wyoming',32770,59);
INSERT INTO "django_geo_db_city" VALUES(26594,'Banner','Banner, Wyoming',32771,59);
INSERT INTO "django_geo_db_city" VALUES(26595,'Big Horn','Big Horn, Wyoming',32772,59);
INSERT INTO "django_geo_db_city" VALUES(26596,'Buffalo','Buffalo, Wyoming',32773,59);
INSERT INTO "django_geo_db_city" VALUES(26597,'Clearmont','Clearmont, Wyoming',32774,59);
INSERT INTO "django_geo_db_city" VALUES(26598,'Dayton','Dayton, Wyoming',32775,59);
INSERT INTO "django_geo_db_city" VALUES(26599,'Leiter','Leiter, Wyoming',32776,59);
INSERT INTO "django_geo_db_city" VALUES(26600,'Parkman','Parkman, Wyoming',32777,59);
INSERT INTO "django_geo_db_city" VALUES(26601,'Ranchester','Ranchester, Wyoming',32778,59);
INSERT INTO "django_geo_db_city" VALUES(26602,'Saddlestring','Saddlestring, Wyoming',32779,59);
INSERT INTO "django_geo_db_city" VALUES(26603,'Story','Story, Wyoming',32780,59);
INSERT INTO "django_geo_db_city" VALUES(26604,'Wolf','Wolf, Wyoming',32781,59);
INSERT INTO "django_geo_db_city" VALUES(26605,'Wyarno','Wyarno, Wyoming',32782,59);
INSERT INTO "django_geo_db_city" VALUES(26606,'Rock Springs','Rock Springs, Wyoming',32783,59);
INSERT INTO "django_geo_db_city" VALUES(26607,'Bondurant','Bondurant, Wyoming',32785,59);
INSERT INTO "django_geo_db_city" VALUES(26608,'Boulder','Boulder, Wyoming',32786,59);
INSERT INTO "django_geo_db_city" VALUES(26609,'Cora','Cora, Wyoming',32787,59);
INSERT INTO "django_geo_db_city" VALUES(26610,'Little America','Little America, Wyoming',32788,59);
INSERT INTO "django_geo_db_city" VALUES(26611,'Evanston','Evanston, Wyoming',32789,59);
INSERT INTO "django_geo_db_city" VALUES(26612,'Farson','Farson, Wyoming',32791,59);
INSERT INTO "django_geo_db_city" VALUES(26613,'Fort Bridger','Fort Bridger, Wyoming',32792,59);
INSERT INTO "django_geo_db_city" VALUES(26614,'Granger','Granger, Wyoming',32793,59);
INSERT INTO "django_geo_db_city" VALUES(26615,'Green River','Green River, Wyoming',32794,59);
INSERT INTO "django_geo_db_city" VALUES(26616,'Lontetree','Lontetree, Wyoming',32795,59);
INSERT INTO "django_geo_db_city" VALUES(26617,'Lyman','Lyman, Wyoming',32796,59);
INSERT INTO "django_geo_db_city" VALUES(26618,'McKinnon','McKinnon, Wyoming',32797,59);
INSERT INTO "django_geo_db_city" VALUES(26619,'Mountain View','Mountain View, Wyoming',32798,59);
INSERT INTO "django_geo_db_city" VALUES(26620,'Pinedale','Pinedale, Wyoming',32799,59);
INSERT INTO "django_geo_db_city" VALUES(26621,'Point Of Rocks','Point Of Rocks, Wyoming',32800,59);
INSERT INTO "django_geo_db_city" VALUES(26622,'Reliance','Reliance, Wyoming',32801,59);
INSERT INTO "django_geo_db_city" VALUES(26623,'Robertson','Robertson, Wyoming',32802,59);
INSERT INTO "django_geo_db_city" VALUES(26624,'Superior','Superior, Wyoming',32803,59);
INSERT INTO "django_geo_db_city" VALUES(26625,'Jackson','Jackson, Wyoming',32804,59);
INSERT INTO "django_geo_db_city" VALUES(26626,'Kelly','Kelly, Wyoming',32806,59);
INSERT INTO "django_geo_db_city" VALUES(26627,'Moose','Moose, Wyoming',32807,59);
INSERT INTO "django_geo_db_city" VALUES(26628,'Moran','Moran, Wyoming',32808,59);
INSERT INTO "django_geo_db_city" VALUES(26629,'Wilson','Wilson, Wyoming',32809,59);
INSERT INTO "django_geo_db_city" VALUES(26630,'Teton Village','Teton Village, Wyoming',32810,59);
INSERT INTO "django_geo_db_city" VALUES(26631,'Kemmerer','Kemmerer, Wyoming',32811,59);
INSERT INTO "django_geo_db_city" VALUES(26632,'Afton','Afton, Wyoming',32812,59);
INSERT INTO "django_geo_db_city" VALUES(26633,'Auburn','Auburn, Wyoming',32813,59);
INSERT INTO "django_geo_db_city" VALUES(26634,'Bedford','Bedford, Wyoming',32814,59);
INSERT INTO "django_geo_db_city" VALUES(26635,'Big Piney','Big Piney, Wyoming',32815,59);
INSERT INTO "django_geo_db_city" VALUES(26636,'Cokeville','Cokeville, Wyoming',32816,59);
INSERT INTO "django_geo_db_city" VALUES(26637,'Daniel','Daniel, Wyoming',32817,59);
INSERT INTO "django_geo_db_city" VALUES(26638,'Diamondville','Diamondville, Wyoming',32818,59);
INSERT INTO "django_geo_db_city" VALUES(26639,'Etna','Etna, Wyoming',32819,59);
INSERT INTO "django_geo_db_city" VALUES(26640,'Fairview','Fairview, Wyoming',32820,59);
INSERT INTO "django_geo_db_city" VALUES(26641,'Freedom','Freedom, Idaho',32821,16);
INSERT INTO "django_geo_db_city" VALUES(26642,'Frontier','Frontier, Wyoming',32822,59);
INSERT INTO "django_geo_db_city" VALUES(26643,'Grover','Grover, Wyoming',32823,59);
INSERT INTO "django_geo_db_city" VALUES(26644,'La Barge','La Barge, Wyoming',32824,59);
INSERT INTO "django_geo_db_city" VALUES(26645,'Opal','Opal, Wyoming',32825,59);
INSERT INTO "django_geo_db_city" VALUES(26646,'Smoot','Smoot, Wyoming',32826,59);
INSERT INTO "django_geo_db_city" VALUES(26647,'Thayne','Thayne, Wyoming',32827,59);
INSERT INTO "django_geo_db_city" VALUES(26648,'Alpine','Alpine, Wyoming',32828,59);
INSERT INTO "django_geo_db_city" VALUES(26649,'Pocatello','Pocatello, Idaho',32829,16);
INSERT INTO "django_geo_db_city" VALUES(26650,'Fort Hall','Fort Hall, Idaho',32831,16);
INSERT INTO "django_geo_db_city" VALUES(26651,'Aberdeen','Aberdeen, Idaho',32835,16);
INSERT INTO "django_geo_db_city" VALUES(26652,'American Falls','American Falls, Idaho',32836,16);
INSERT INTO "django_geo_db_city" VALUES(26653,'Arbon','Arbon, Idaho',32837,16);
INSERT INTO "django_geo_db_city" VALUES(26654,'Arco','Arco, Idaho',32838,16);
INSERT INTO "django_geo_db_city" VALUES(26655,'Arimo','Arimo, Idaho',32839,16);
INSERT INTO "django_geo_db_city" VALUES(26656,'Atomic City','Atomic City, Idaho',32840,16);
INSERT INTO "django_geo_db_city" VALUES(26657,'Bancroft','Bancroft, Idaho',32841,16);
INSERT INTO "django_geo_db_city" VALUES(26658,'Basalt','Basalt, Idaho',32842,16);
INSERT INTO "django_geo_db_city" VALUES(26659,'Bern','Bern, Idaho',32843,16);
INSERT INTO "django_geo_db_city" VALUES(26660,'Blackfoot','Blackfoot, Idaho',32844,16);
INSERT INTO "django_geo_db_city" VALUES(26661,'Bloomington','Bloomington, Idaho',32845,16);
INSERT INTO "django_geo_db_city" VALUES(26662,'Challis','Challis, Idaho',32846,16);
INSERT INTO "django_geo_db_city" VALUES(26663,'Clayton','Clayton, Idaho',32847,16);
INSERT INTO "django_geo_db_city" VALUES(26664,'Clifton','Clifton, Idaho',32848,16);
INSERT INTO "django_geo_db_city" VALUES(26665,'Cobalt','Cobalt, Idaho',32849,16);
INSERT INTO "django_geo_db_city" VALUES(26666,'Conda','Conda, Idaho',32850,16);
INSERT INTO "django_geo_db_city" VALUES(26667,'Dayton','Dayton, Idaho',32851,16);
INSERT INTO "django_geo_db_city" VALUES(26668,'Dingle','Dingle, Idaho',32852,16);
INSERT INTO "django_geo_db_city" VALUES(26669,'Downey','Downey, Idaho',32853,16);
INSERT INTO "django_geo_db_city" VALUES(26670,'Ellis','Ellis, Idaho',32854,16);
INSERT INTO "django_geo_db_city" VALUES(26671,'Firth','Firth, Idaho',32855,16);
INSERT INTO "django_geo_db_city" VALUES(26672,'Franklin','Franklin, Idaho',32856,16);
INSERT INTO "django_geo_db_city" VALUES(26673,'Geneva','Geneva, Idaho',32857,16);
INSERT INTO "django_geo_db_city" VALUES(26674,'Georgetown','Georgetown, Idaho',32858,16);
INSERT INTO "django_geo_db_city" VALUES(26675,'Grace','Grace, Idaho',32859,16);
INSERT INTO "django_geo_db_city" VALUES(26676,'Holbrook','Holbrook, Idaho',32860,16);
INSERT INTO "django_geo_db_city" VALUES(26677,'Howe','Howe, Idaho',32861,16);
INSERT INTO "django_geo_db_city" VALUES(26678,'Inkom','Inkom, Idaho',32862,16);
INSERT INTO "django_geo_db_city" VALUES(26679,'Lava Hot Springs','Lava Hot Springs, Idaho',32863,16);
INSERT INTO "django_geo_db_city" VALUES(26680,'McCammon','McCammon, Idaho',32864,16);
INSERT INTO "django_geo_db_city" VALUES(26681,'Mackay','Mackay, Idaho',32865,16);
INSERT INTO "django_geo_db_city" VALUES(26682,'Malad City','Malad City, Idaho',32866,16);
INSERT INTO "django_geo_db_city" VALUES(26683,'May','May, Idaho',32867,16);
INSERT INTO "django_geo_db_city" VALUES(26684,'Montpelier','Montpelier, Idaho',32868,16);
INSERT INTO "django_geo_db_city" VALUES(26685,'Moore','Moore, Idaho',32869,16);
INSERT INTO "django_geo_db_city" VALUES(26686,'Moreland','Moreland, Idaho',32870,16);
INSERT INTO "django_geo_db_city" VALUES(26687,'Paris','Paris, Idaho',32871,16);
INSERT INTO "django_geo_db_city" VALUES(26688,'Pingree','Pingree, Idaho',32872,16);
INSERT INTO "django_geo_db_city" VALUES(26689,'Preston','Preston, Idaho',32873,16);
INSERT INTO "django_geo_db_city" VALUES(26690,'Rockland','Rockland, Idaho',32874,16);
INSERT INTO "django_geo_db_city" VALUES(26691,'Saint Charles','Saint Charles, Idaho',32875,16);
INSERT INTO "django_geo_db_city" VALUES(26692,'Shelley','Shelley, Idaho',32876,16);
INSERT INTO "django_geo_db_city" VALUES(26693,'Soda Springs','Soda Springs, Idaho',32877,16);
INSERT INTO "django_geo_db_city" VALUES(26694,'Springfield','Springfield, Idaho',32878,16);
INSERT INTO "django_geo_db_city" VALUES(26695,'Stanley','Stanley, Idaho',32879,16);
INSERT INTO "django_geo_db_city" VALUES(26696,'Swanlake','Swanlake, Idaho',32880,16);
INSERT INTO "django_geo_db_city" VALUES(26697,'Thatcher','Thatcher, Idaho',32881,16);
INSERT INTO "django_geo_db_city" VALUES(26698,'Wayan','Wayan, Idaho',32882,16);
INSERT INTO "django_geo_db_city" VALUES(26699,'Weston','Weston, Idaho',32883,16);
INSERT INTO "django_geo_db_city" VALUES(26700,'Fish Haven','Fish Haven, Idaho',32884,16);
INSERT INTO "django_geo_db_city" VALUES(26701,'Twin Falls','Twin Falls, Idaho',32885,16);
INSERT INTO "django_geo_db_city" VALUES(26702,'Rogerson','Rogerson, Idaho',32886,16);
INSERT INTO "django_geo_db_city" VALUES(26703,'Albion','Albion, Idaho',32888,16);
INSERT INTO "django_geo_db_city" VALUES(26704,'Almo','Almo, Idaho',32889,16);
INSERT INTO "django_geo_db_city" VALUES(26705,'Bellevue','Bellevue, Idaho',32890,16);
INSERT INTO "django_geo_db_city" VALUES(26706,'Bliss','Bliss, Idaho',32891,16);
INSERT INTO "django_geo_db_city" VALUES(26707,'Buhl','Buhl, Idaho',32892,16);
INSERT INTO "django_geo_db_city" VALUES(26708,'Burley','Burley, Idaho',32893,16);
INSERT INTO "django_geo_db_city" VALUES(26709,'Carey','Carey, Idaho',32894,16);
INSERT INTO "django_geo_db_city" VALUES(26710,'Castleford','Castleford, Idaho',32895,16);
INSERT INTO "django_geo_db_city" VALUES(26711,'Corral','Corral, Idaho',32896,16);
INSERT INTO "django_geo_db_city" VALUES(26712,'Declo','Declo, Idaho',32897,16);
INSERT INTO "django_geo_db_city" VALUES(26713,'Dietrich','Dietrich, Idaho',32898,16);
INSERT INTO "django_geo_db_city" VALUES(26714,'Eden','Eden, Idaho',32899,16);
INSERT INTO "django_geo_db_city" VALUES(26715,'Fairfield','Fairfield, Idaho',32900,16);
INSERT INTO "django_geo_db_city" VALUES(26716,'Filer','Filer, Idaho',32901,16);
INSERT INTO "django_geo_db_city" VALUES(26717,'Gooding','Gooding, Idaho',32902,16);
INSERT INTO "django_geo_db_city" VALUES(26718,'Hagerman','Hagerman, Idaho',32903,16);
INSERT INTO "django_geo_db_city" VALUES(26719,'Hailey','Hailey, Idaho',32904,16);
INSERT INTO "django_geo_db_city" VALUES(26720,'Hansen','Hansen, Idaho',32905,16);
INSERT INTO "django_geo_db_city" VALUES(26721,'Hazelton','Hazelton, Idaho',32906,16);
INSERT INTO "django_geo_db_city" VALUES(26722,'Heyburn','Heyburn, Idaho',32907,16);
INSERT INTO "django_geo_db_city" VALUES(26723,'Hill City','Hill City, Idaho',32908,16);
INSERT INTO "django_geo_db_city" VALUES(26724,'Jerome','Jerome, Idaho',32909,16);
INSERT INTO "django_geo_db_city" VALUES(26725,'Ketchum','Ketchum, Idaho',32910,16);
INSERT INTO "django_geo_db_city" VALUES(26726,'Kimberly','Kimberly, Idaho',32911,16);
INSERT INTO "django_geo_db_city" VALUES(26727,'Malta','Malta, Idaho',32912,16);
INSERT INTO "django_geo_db_city" VALUES(26728,'Minidoka','Minidoka, Idaho',32913,16);
INSERT INTO "django_geo_db_city" VALUES(26729,'Murtaugh','Murtaugh, Idaho',32914,16);
INSERT INTO "django_geo_db_city" VALUES(26730,'Oakley','Oakley, Idaho',32915,16);
INSERT INTO "django_geo_db_city" VALUES(26731,'Paul','Paul, Idaho',32916,16);
INSERT INTO "django_geo_db_city" VALUES(26732,'Picabo','Picabo, Idaho',32917,16);
INSERT INTO "django_geo_db_city" VALUES(26733,'Richfield','Richfield, Idaho',32918,16);
INSERT INTO "django_geo_db_city" VALUES(26734,'Rupert','Rupert, Idaho',32919,16);
INSERT INTO "django_geo_db_city" VALUES(26735,'Shoshone','Shoshone, Idaho',32920,16);
INSERT INTO "django_geo_db_city" VALUES(26736,'Sun Valley','Sun Valley, Idaho',32921,16);
INSERT INTO "django_geo_db_city" VALUES(26737,'Wendell','Wendell, Idaho',32923,16);
INSERT INTO "django_geo_db_city" VALUES(26738,'Idaho Falls','Idaho Falls, Idaho',32924,16);
INSERT INTO "django_geo_db_city" VALUES(26739,'Ashton','Ashton, Idaho',32930,16);
INSERT INTO "django_geo_db_city" VALUES(26740,'Chester','Chester, Idaho',32931,16);
INSERT INTO "django_geo_db_city" VALUES(26741,'Driggs','Driggs, Idaho',32932,16);
INSERT INTO "django_geo_db_city" VALUES(26742,'Dubois','Dubois, Idaho',32933,16);
INSERT INTO "django_geo_db_city" VALUES(26743,'Felt','Felt, Idaho',32934,16);
INSERT INTO "django_geo_db_city" VALUES(26744,'Hamer','Hamer, Idaho',32935,16);
INSERT INTO "django_geo_db_city" VALUES(26745,'Iona','Iona, Idaho',32936,16);
INSERT INTO "django_geo_db_city" VALUES(26746,'Irwin','Irwin, Idaho',32937,16);
INSERT INTO "django_geo_db_city" VALUES(26747,'Island Park','Island Park, Idaho',32938,16);
INSERT INTO "django_geo_db_city" VALUES(26748,'Lewisville','Lewisville, Idaho',32939,16);
INSERT INTO "django_geo_db_city" VALUES(26749,'Macks Inn','Macks Inn, Idaho',32940,16);
INSERT INTO "django_geo_db_city" VALUES(26750,'Menan','Menan, Idaho',32941,16);
INSERT INTO "django_geo_db_city" VALUES(26751,'Monteview','Monteview, Idaho',32942,16);
INSERT INTO "django_geo_db_city" VALUES(26752,'Newdale','Newdale, Idaho',32943,16);
INSERT INTO "django_geo_db_city" VALUES(26753,'Parker','Parker, Idaho',32944,16);
INSERT INTO "django_geo_db_city" VALUES(26754,'Rexburg','Rexburg, Idaho',32945,16);
INSERT INTO "django_geo_db_city" VALUES(26755,'Rigby','Rigby, Idaho',32947,16);
INSERT INTO "django_geo_db_city" VALUES(26756,'Ririe','Ririe, Idaho',32948,16);
INSERT INTO "django_geo_db_city" VALUES(26757,'Roberts','Roberts, Idaho',32949,16);
INSERT INTO "django_geo_db_city" VALUES(26758,'Saint Anthony','Saint Anthony, Idaho',32950,16);
INSERT INTO "django_geo_db_city" VALUES(26759,'Spencer','Spencer, Idaho',32951,16);
INSERT INTO "django_geo_db_city" VALUES(26760,'Squirrel','Squirrel, Idaho',32944,16);
INSERT INTO "django_geo_db_city" VALUES(26761,'Sugar City','Sugar City, Idaho',32952,16);
INSERT INTO "django_geo_db_city" VALUES(26762,'Swan Valley','Swan Valley, Idaho',32953,16);
INSERT INTO "django_geo_db_city" VALUES(26763,'Terreton','Terreton, Idaho',32954,16);
INSERT INTO "django_geo_db_city" VALUES(26764,'Teton','Teton, Idaho',32955,16);
INSERT INTO "django_geo_db_city" VALUES(26765,'Tetonia','Tetonia, Idaho',32956,16);
INSERT INTO "django_geo_db_city" VALUES(26766,'Ucon','Ucon, Idaho',32957,16);
INSERT INTO "django_geo_db_city" VALUES(26767,'Victor','Victor, Idaho',32958,16);
INSERT INTO "django_geo_db_city" VALUES(26768,'Carmen','Carmen, Idaho',32959,16);
INSERT INTO "django_geo_db_city" VALUES(26769,'Gibbonsville','Gibbonsville, Idaho',32960,16);
INSERT INTO "django_geo_db_city" VALUES(26770,'Leadore','Leadore, Idaho',32961,16);
INSERT INTO "django_geo_db_city" VALUES(26771,'Lemhi','Lemhi, Idaho',32962,16);
INSERT INTO "django_geo_db_city" VALUES(26772,'North Fork','North Fork, Idaho',32963,16);
INSERT INTO "django_geo_db_city" VALUES(26773,'Salmon','Salmon, Idaho',32964,16);
INSERT INTO "django_geo_db_city" VALUES(26774,'Tendoy','Tendoy, Idaho',32965,16);
INSERT INTO "django_geo_db_city" VALUES(26775,'Shoup','Shoup, Idaho',32966,16);
INSERT INTO "django_geo_db_city" VALUES(26776,'Lewiston','Lewiston, Idaho',32967,16);
INSERT INTO "django_geo_db_city" VALUES(26777,'Ahsahka','Ahsahka, Idaho',32968,16);
INSERT INTO "django_geo_db_city" VALUES(26778,'Cottonwood','Cottonwood, Idaho',32969,16);
INSERT INTO "django_geo_db_city" VALUES(26779,'Craigmont','Craigmont, Idaho',32970,16);
INSERT INTO "django_geo_db_city" VALUES(26780,'Culdesac','Culdesac, Idaho',32971,16);
INSERT INTO "django_geo_db_city" VALUES(26781,'Elk City','Elk City, Idaho',32972,16);
INSERT INTO "django_geo_db_city" VALUES(26782,'Ferdinand','Ferdinand, Idaho',32973,16);
INSERT INTO "django_geo_db_city" VALUES(26783,'Grangeville','Grangeville, Idaho',32974,16);
INSERT INTO "django_geo_db_city" VALUES(26784,'Fenn','Fenn, Idaho',32975,16);
INSERT INTO "django_geo_db_city" VALUES(26785,'Greencreek','Greencreek, Idaho',32976,16);
INSERT INTO "django_geo_db_city" VALUES(26786,'Juliaetta','Juliaetta, Idaho',32978,16);
INSERT INTO "django_geo_db_city" VALUES(26787,'Kamiah','Kamiah, Idaho',32979,16);
INSERT INTO "django_geo_db_city" VALUES(26788,'Kendrick','Kendrick, Idaho',32980,16);
INSERT INTO "django_geo_db_city" VALUES(26789,'Kooskia','Kooskia, Idaho',32981,16);
INSERT INTO "django_geo_db_city" VALUES(26790,'Lapwai','Lapwai, Idaho',32982,16);
INSERT INTO "django_geo_db_city" VALUES(26791,'Lenore','Lenore, Idaho',32983,16);
INSERT INTO "django_geo_db_city" VALUES(26792,'Lucile','Lucile, Idaho',32984,16);
INSERT INTO "django_geo_db_city" VALUES(26793,'Nezperce','Nezperce, Idaho',32985,16);
INSERT INTO "django_geo_db_city" VALUES(26794,'Orofino','Orofino, Idaho',32986,16);
INSERT INTO "django_geo_db_city" VALUES(26795,'Peck','Peck, Idaho',32987,16);
INSERT INTO "django_geo_db_city" VALUES(26796,'Pierce','Pierce, Idaho',32988,16);
INSERT INTO "django_geo_db_city" VALUES(26797,'Pollock','Pollock, Idaho',32989,16);
INSERT INTO "django_geo_db_city" VALUES(26798,'Reubens','Reubens, Idaho',32990,16);
INSERT INTO "django_geo_db_city" VALUES(26799,'Riggins','Riggins, Idaho',32991,16);
INSERT INTO "django_geo_db_city" VALUES(26800,'Spalding','Spalding, Idaho',32992,16);
INSERT INTO "django_geo_db_city" VALUES(26801,'Stites','Stites, Idaho',32993,16);
INSERT INTO "django_geo_db_city" VALUES(26802,'Weippe','Weippe, Idaho',32994,16);
INSERT INTO "django_geo_db_city" VALUES(26803,'White Bird','White Bird, Idaho',32995,16);
INSERT INTO "django_geo_db_city" VALUES(26804,'Winchester','Winchester, Idaho',32996,16);
INSERT INTO "django_geo_db_city" VALUES(26805,'Atlanta','Atlanta, Idaho',32997,16);
INSERT INTO "django_geo_db_city" VALUES(26806,'Banks','Banks, Idaho',32998,16);
INSERT INTO "django_geo_db_city" VALUES(26807,'Bruneau','Bruneau, Idaho',32999,16);
INSERT INTO "django_geo_db_city" VALUES(26808,'Caldwell','Caldwell, Idaho',33000,16);
INSERT INTO "django_geo_db_city" VALUES(26809,'Cambridge','Cambridge, Idaho',33003,16);
INSERT INTO "django_geo_db_city" VALUES(26810,'Cascade','Cascade, Idaho',33004,16);
INSERT INTO "django_geo_db_city" VALUES(26811,'Council','Council, Idaho',33005,16);
INSERT INTO "django_geo_db_city" VALUES(26812,'Donnelly','Donnelly, Idaho',33006,16);
INSERT INTO "django_geo_db_city" VALUES(26813,'Eagle','Eagle, Idaho',33007,16);
INSERT INTO "django_geo_db_city" VALUES(26814,'Emmett','Emmett, Idaho',33008,16);
INSERT INTO "django_geo_db_city" VALUES(26815,'Fruitland','Fruitland, Idaho',33009,16);
INSERT INTO "django_geo_db_city" VALUES(26816,'Fruitvale','Fruitvale, Idaho',33010,16);
INSERT INTO "django_geo_db_city" VALUES(26817,'Garden Valley','Garden Valley, Idaho',33011,16);
INSERT INTO "django_geo_db_city" VALUES(26818,'Glenns Ferry','Glenns Ferry, Idaho',33012,16);
INSERT INTO "django_geo_db_city" VALUES(26819,'Grand View','Grand View, Idaho',33013,16);
INSERT INTO "django_geo_db_city" VALUES(26820,'Greenleaf','Greenleaf, Idaho',33014,16);
INSERT INTO "django_geo_db_city" VALUES(26821,'Hammett','Hammett, Idaho',33015,16);
INSERT INTO "django_geo_db_city" VALUES(26822,'Homedale','Homedale, Idaho',33016,16);
INSERT INTO "django_geo_db_city" VALUES(26823,'Horseshoe Bend','Horseshoe Bend, Idaho',33017,16);
INSERT INTO "django_geo_db_city" VALUES(26824,'Huston','Huston, Idaho',33018,16);
INSERT INTO "django_geo_db_city" VALUES(26825,'Idaho City','Idaho City, Idaho',33019,16);
INSERT INTO "django_geo_db_city" VALUES(26826,'Indian Valley','Indian Valley, Idaho',33020,16);
INSERT INTO "django_geo_db_city" VALUES(26827,'King Hill','King Hill, Idaho',33021,16);
INSERT INTO "django_geo_db_city" VALUES(26828,'Kuna','Kuna, Idaho',33022,16);
INSERT INTO "django_geo_db_city" VALUES(26829,'Lake Fork','Lake Fork, Idaho',33023,16);
INSERT INTO "django_geo_db_city" VALUES(26830,'Letha','Letha, Idaho',33024,16);
INSERT INTO "django_geo_db_city" VALUES(26831,'Lowman','Lowman, Idaho',33025,16);
INSERT INTO "django_geo_db_city" VALUES(26832,'McCall','McCall, Idaho',33026,16);
INSERT INTO "django_geo_db_city" VALUES(26833,'Marsing','Marsing, Idaho',33027,16);
INSERT INTO "django_geo_db_city" VALUES(26834,'Melba','Melba, Idaho',33028,16);
INSERT INTO "django_geo_db_city" VALUES(26835,'Meridian','Meridian, Idaho',33029,16);
INSERT INTO "django_geo_db_city" VALUES(26836,'Mesa','Mesa, Idaho',33030,16);
INSERT INTO "django_geo_db_city" VALUES(26837,'Middleton','Middleton, Idaho',33031,16);
INSERT INTO "django_geo_db_city" VALUES(26838,'Midvale','Midvale, Idaho',33032,16);
INSERT INTO "django_geo_db_city" VALUES(26839,'Mountain Home','Mountain Home, Idaho',33033,16);
INSERT INTO "django_geo_db_city" VALUES(26840,'Mountain Home A F B','Mountain Home A F B, Idaho',33034,16);
INSERT INTO "django_geo_db_city" VALUES(26841,'Murphy','Murphy, Idaho',33035,16);
INSERT INTO "django_geo_db_city" VALUES(26842,'Nampa','Nampa, Idaho',33036,16);
INSERT INTO "django_geo_db_city" VALUES(26843,'New Meadows','New Meadows, Idaho',33039,16);
INSERT INTO "django_geo_db_city" VALUES(26844,'New Plymouth','New Plymouth, Idaho',33040,16);
INSERT INTO "django_geo_db_city" VALUES(26845,'Notus','Notus, Idaho',33041,16);
INSERT INTO "django_geo_db_city" VALUES(26846,'Ola','Ola, Idaho',33042,16);
INSERT INTO "django_geo_db_city" VALUES(26847,'Parma','Parma, Idaho',33043,16);
INSERT INTO "django_geo_db_city" VALUES(26848,'Payette','Payette, Idaho',33044,16);
INSERT INTO "django_geo_db_city" VALUES(26849,'Placerville','Placerville, Idaho',33045,16);
INSERT INTO "django_geo_db_city" VALUES(26850,'Star','Star, Idaho',33046,16);
INSERT INTO "django_geo_db_city" VALUES(26851,'Sweet','Sweet, Idaho',33047,16);
INSERT INTO "django_geo_db_city" VALUES(26852,'Warren','Warren, Idaho',33048,16);
INSERT INTO "django_geo_db_city" VALUES(26853,'Weiser','Weiser, Idaho',33049,16);
INSERT INTO "django_geo_db_city" VALUES(26854,'Wilder','Wilder, Idaho',33050,16);
INSERT INTO "django_geo_db_city" VALUES(26855,'Yellow Pine','Yellow Pine, Idaho',33051,16);
INSERT INTO "django_geo_db_city" VALUES(26856,'Boise','Boise, Idaho',33055,16);
INSERT INTO "django_geo_db_city" VALUES(26857,'Athol','Athol, Idaho',33069,16);
INSERT INTO "django_geo_db_city" VALUES(26858,'Avery','Avery, Idaho',33070,16);
INSERT INTO "django_geo_db_city" VALUES(26859,'Bayview','Bayview, Idaho',33071,16);
INSERT INTO "django_geo_db_city" VALUES(26860,'Blanchard','Blanchard, Idaho',33072,16);
INSERT INTO "django_geo_db_city" VALUES(26861,'Bonners Ferry','Bonners Ferry, Idaho',33073,16);
INSERT INTO "django_geo_db_city" VALUES(26862,'Bovill','Bovill, Idaho',33074,16);
INSERT INTO "django_geo_db_city" VALUES(26863,'Calder','Calder, Idaho',33075,16);
INSERT INTO "django_geo_db_city" VALUES(26864,'Careywood','Careywood, Idaho',33076,16);
INSERT INTO "django_geo_db_city" VALUES(26865,'Cataldo','Cataldo, Idaho',33077,16);
INSERT INTO "django_geo_db_city" VALUES(26866,'Clark Fork','Clark Fork, Idaho',33078,16);
INSERT INTO "django_geo_db_city" VALUES(26867,'Clarkia','Clarkia, Idaho',33079,16);
INSERT INTO "django_geo_db_city" VALUES(26868,'Cocolalla','Cocolalla, Idaho',33080,16);
INSERT INTO "django_geo_db_city" VALUES(26869,'Coeur D Alene','Coeur D Alene, Idaho',33081,16);
INSERT INTO "django_geo_db_city" VALUES(26870,'Coolin','Coolin, Idaho',33084,16);
INSERT INTO "django_geo_db_city" VALUES(26871,'Oldtown','Oldtown, Idaho',33085,16);
INSERT INTO "django_geo_db_city" VALUES(26872,'Deary','Deary, Idaho',33086,16);
INSERT INTO "django_geo_db_city" VALUES(26873,'Desmet','Desmet, Idaho',33087,16);
INSERT INTO "django_geo_db_city" VALUES(26874,'Dover','Dover, Idaho',33088,16);
INSERT INTO "django_geo_db_city" VALUES(26875,'Eastport','Eastport, Idaho',33089,16);
INSERT INTO "django_geo_db_city" VALUES(26876,'Elk River','Elk River, Idaho',33090,16);
INSERT INTO "django_geo_db_city" VALUES(26877,'Fernwood','Fernwood, Idaho',33091,16);
INSERT INTO "django_geo_db_city" VALUES(26878,'Genesee','Genesee, Idaho',33092,16);
INSERT INTO "django_geo_db_city" VALUES(26879,'Harrison','Harrison, Idaho',33093,16);
INSERT INTO "django_geo_db_city" VALUES(26880,'Harvard','Harvard, Idaho',33094,16);
INSERT INTO "django_geo_db_city" VALUES(26881,'Hayden','Hayden, Idaho',33095,16);
INSERT INTO "django_geo_db_city" VALUES(26882,'Hope','Hope, Idaho',33096,16);
INSERT INTO "django_geo_db_city" VALUES(26883,'Kellogg','Kellogg, Idaho',33097,16);
INSERT INTO "django_geo_db_city" VALUES(26884,'Kingston','Kingston, Idaho',33098,16);
INSERT INTO "django_geo_db_city" VALUES(26885,'Kootenai','Kootenai, Idaho',33099,16);
INSERT INTO "django_geo_db_city" VALUES(26886,'Laclede','Laclede, Idaho',33100,16);
INSERT INTO "django_geo_db_city" VALUES(26887,'Medimont','Medimont, Idaho',33101,16);
INSERT INTO "django_geo_db_city" VALUES(26888,'Moscow','Moscow, Idaho',33102,16);
INSERT INTO "django_geo_db_city" VALUES(26889,'Moyie Springs','Moyie Springs, Idaho',33104,16);
INSERT INTO "django_geo_db_city" VALUES(26890,'Mullan','Mullan, Idaho',33105,16);
INSERT INTO "django_geo_db_city" VALUES(26891,'Naples','Naples, Idaho',33106,16);
INSERT INTO "django_geo_db_city" VALUES(26892,'Nordman','Nordman, Idaho',33107,16);
INSERT INTO "django_geo_db_city" VALUES(26893,'Osburn','Osburn, Idaho',33108,16);
INSERT INTO "django_geo_db_city" VALUES(26894,'Pinehurst','Pinehurst, Idaho',33109,16);
INSERT INTO "django_geo_db_city" VALUES(26895,'Plummer','Plummer, Idaho',33110,16);
INSERT INTO "django_geo_db_city" VALUES(26896,'Ponderay','Ponderay, Idaho',33111,16);
INSERT INTO "django_geo_db_city" VALUES(26897,'Porthill','Porthill, Idaho',33112,16);
INSERT INTO "django_geo_db_city" VALUES(26898,'Post Falls','Post Falls, Idaho',33113,16);
INSERT INTO "django_geo_db_city" VALUES(26899,'Potlatch','Potlatch, Idaho',33114,16);
INSERT INTO "django_geo_db_city" VALUES(26900,'Priest River','Priest River, Idaho',33115,16);
INSERT INTO "django_geo_db_city" VALUES(26901,'Princeton','Princeton, Idaho',33116,16);
INSERT INTO "django_geo_db_city" VALUES(26902,'Rathdrum','Rathdrum, Idaho',33117,16);
INSERT INTO "django_geo_db_city" VALUES(26903,'Sagle','Sagle, Idaho',33118,16);
INSERT INTO "django_geo_db_city" VALUES(26904,'Saint Maries','Saint Maries, Idaho',33119,16);
INSERT INTO "django_geo_db_city" VALUES(26905,'Samuels','Samuels, Idaho',33088,16);
INSERT INTO "django_geo_db_city" VALUES(26906,'Sandpoint','Sandpoint, Idaho',33120,16);
INSERT INTO "django_geo_db_city" VALUES(26907,'Colburn','Colburn, Idaho',33121,16);
INSERT INTO "django_geo_db_city" VALUES(26908,'Santa','Santa, Idaho',33122,16);
INSERT INTO "django_geo_db_city" VALUES(26909,'Silverton','Silverton, Idaho',33123,16);
INSERT INTO "django_geo_db_city" VALUES(26910,'Smelterville','Smelterville, Idaho',33124,16);
INSERT INTO "django_geo_db_city" VALUES(26911,'Spirit Lake','Spirit Lake, Idaho',33125,16);
INSERT INTO "django_geo_db_city" VALUES(26912,'Tensed','Tensed, Idaho',33126,16);
INSERT INTO "django_geo_db_city" VALUES(26913,'Troy','Troy, Idaho',33127,16);
INSERT INTO "django_geo_db_city" VALUES(26914,'Viola','Viola, Idaho',33128,16);
INSERT INTO "django_geo_db_city" VALUES(26915,'Wallace','Wallace, Idaho',33129,16);
INSERT INTO "django_geo_db_city" VALUES(26916,'Murray','Murray, Idaho',33130,16);
INSERT INTO "django_geo_db_city" VALUES(26917,'Worley','Worley, Idaho',33131,16);
INSERT INTO "django_geo_db_city" VALUES(26918,'Altamont','Altamont, Utah',33132,52);
INSERT INTO "django_geo_db_city" VALUES(26919,'Altonah','Altonah, Utah',33133,52);
INSERT INTO "django_geo_db_city" VALUES(26920,'American Fork','American Fork, Utah',33134,52);
INSERT INTO "django_geo_db_city" VALUES(26921,'Alpine','Alpine, Utah',33135,52);
INSERT INTO "django_geo_db_city" VALUES(26922,'Bingham Canyon','Bingham Canyon, Utah',33136,52);
INSERT INTO "django_geo_db_city" VALUES(26923,'Bluebell','Bluebell, Utah',33137,52);
INSERT INTO "django_geo_db_city" VALUES(26924,'Bonanza','Bonanza, Utah',33138,52);
INSERT INTO "django_geo_db_city" VALUES(26925,'Bountiful','Bountiful, Utah',33139,52);
INSERT INTO "django_geo_db_city" VALUES(26926,'Cedar Valley','Cedar Valley, Utah',33141,52);
INSERT INTO "django_geo_db_city" VALUES(26927,'Centerville','Centerville, Utah',33142,52);
INSERT INTO "django_geo_db_city" VALUES(26928,'Clearfield','Clearfield, Utah',33143,52);
INSERT INTO "django_geo_db_city" VALUES(26929,'Coalville','Coalville, Utah',33145,52);
INSERT INTO "django_geo_db_city" VALUES(26930,'Croydon','Croydon, Utah',33146,52);
INSERT INTO "django_geo_db_city" VALUES(26931,'Draper','Draper, Utah',33147,52);
INSERT INTO "django_geo_db_city" VALUES(26932,'Duchesne','Duchesne, Utah',33148,52);
INSERT INTO "django_geo_db_city" VALUES(26933,'Dugway','Dugway, Utah',33149,52);
INSERT INTO "django_geo_db_city" VALUES(26934,'Dutch John','Dutch John, Utah',33150,52);
INSERT INTO "django_geo_db_city" VALUES(26935,'Echo','Echo, Utah',33151,52);
INSERT INTO "django_geo_db_city" VALUES(26936,'Farmington','Farmington, Utah',33152,52);
INSERT INTO "django_geo_db_city" VALUES(26937,'Fort Duchesne','Fort Duchesne, Utah',33153,52);
INSERT INTO "django_geo_db_city" VALUES(26938,'Fruitland','Fruitland, Utah',33154,52);
INSERT INTO "django_geo_db_city" VALUES(26939,'Garden City','Garden City, Utah',33155,52);
INSERT INTO "django_geo_db_city" VALUES(26940,'Grantsville','Grantsville, Utah',33156,52);
INSERT INTO "django_geo_db_city" VALUES(26941,'Gusher','Gusher, Utah',33157,52);
INSERT INTO "django_geo_db_city" VALUES(26942,'Hanna','Hanna, Utah',33158,52);
INSERT INTO "django_geo_db_city" VALUES(26943,'Heber City','Heber City, Utah',33159,52);
INSERT INTO "django_geo_db_city" VALUES(26944,'Henefer','Henefer, Utah',33160,52);
INSERT INTO "django_geo_db_city" VALUES(26945,'Ibapah','Ibapah, Utah',33161,52);
INSERT INTO "django_geo_db_city" VALUES(26946,'Jensen','Jensen, Utah',33162,52);
INSERT INTO "django_geo_db_city" VALUES(26947,'Kamas','Kamas, Utah',33163,52);
INSERT INTO "django_geo_db_city" VALUES(26948,'Kaysville','Kaysville, Utah',33164,52);
INSERT INTO "django_geo_db_city" VALUES(26949,'Laketown','Laketown, Utah',33165,52);
INSERT INTO "django_geo_db_city" VALUES(26950,'Lapoint','Lapoint, Utah',33166,52);
INSERT INTO "django_geo_db_city" VALUES(26951,'Layton','Layton, Utah',33167,52);
INSERT INTO "django_geo_db_city" VALUES(26952,'Lindon','Lindon, Utah',33169,52);
INSERT INTO "django_geo_db_city" VALUES(26953,'Lehi','Lehi, Utah',33170,52);
INSERT INTO "django_geo_db_city" VALUES(26954,'Magna','Magna, Utah',33171,52);
INSERT INTO "django_geo_db_city" VALUES(26955,'Manila','Manila, Utah',33172,52);
INSERT INTO "django_geo_db_city" VALUES(26956,'Midvale','Midvale, Utah',33173,52);
INSERT INTO "django_geo_db_city" VALUES(26957,'Midway','Midway, Utah',33174,52);
INSERT INTO "django_geo_db_city" VALUES(26958,'Morgan','Morgan, Utah',33175,52);
INSERT INTO "django_geo_db_city" VALUES(26959,'Mountain Home','Mountain Home, Utah',33176,52);
INSERT INTO "django_geo_db_city" VALUES(26960,'Myton','Myton, Utah',33177,52);
INSERT INTO "django_geo_db_city" VALUES(26961,'Neola','Neola, Utah',33178,52);
INSERT INTO "django_geo_db_city" VALUES(26962,'North Salt Lake','North Salt Lake, Utah',33179,52);
INSERT INTO "django_geo_db_city" VALUES(26963,'Oakley','Oakley, Utah',33180,52);
INSERT INTO "django_geo_db_city" VALUES(26964,'Hill AFB','Hill AFB, Utah',33181,52);
INSERT INTO "django_geo_db_city" VALUES(26965,'Orem','Orem, Utah',33182,52);
INSERT INTO "django_geo_db_city" VALUES(26966,'Park City','Park City, Utah',33185,52);
INSERT INTO "django_geo_db_city" VALUES(26967,'Peoa','Peoa, Utah',33186,52);
INSERT INTO "django_geo_db_city" VALUES(26968,'Pleasant Grove','Pleasant Grove, Utah',33187,52);
INSERT INTO "django_geo_db_city" VALUES(26969,'Randlett','Randlett, Utah',33188,52);
INSERT INTO "django_geo_db_city" VALUES(26970,'Randolph','Randolph, Utah',33189,52);
INSERT INTO "django_geo_db_city" VALUES(26971,'Riverton','Riverton, Utah',33190,52);
INSERT INTO "django_geo_db_city" VALUES(26972,'Roosevelt','Roosevelt, Utah',33191,52);
INSERT INTO "django_geo_db_city" VALUES(26973,'Roy','Roy, Utah',33192,52);
INSERT INTO "django_geo_db_city" VALUES(26974,'Rush Valley','Rush Valley, Utah',33194,52);
INSERT INTO "django_geo_db_city" VALUES(26975,'Sandy','Sandy, Utah',33195,52);
INSERT INTO "django_geo_db_city" VALUES(26976,'Stockton','Stockton, Utah',33196,52);
INSERT INTO "django_geo_db_city" VALUES(26977,'Tabiona','Tabiona, Utah',33197,52);
INSERT INTO "django_geo_db_city" VALUES(26978,'Talmage','Talmage, Utah',33198,52);
INSERT INTO "django_geo_db_city" VALUES(26979,'Tooele','Tooele, Utah',33199,52);
INSERT INTO "django_geo_db_city" VALUES(26980,'Syracuse','Syracuse, Utah',33200,52);
INSERT INTO "django_geo_db_city" VALUES(26981,'Tridell','Tridell, Utah',33201,52);
INSERT INTO "django_geo_db_city" VALUES(26982,'Vernal','Vernal, Utah',33202,52);
INSERT INTO "django_geo_db_city" VALUES(26983,'Vernon','Vernon, Utah',33203,52);
INSERT INTO "django_geo_db_city" VALUES(26984,'Wallsburg','Wallsburg, Utah',33204,52);
INSERT INTO "django_geo_db_city" VALUES(26985,'Wendover','Wendover, Utah',33205,52);
INSERT INTO "django_geo_db_city" VALUES(26986,'West Jordan','West Jordan, Utah',33206,52);
INSERT INTO "django_geo_db_city" VALUES(26987,'Whiterocks','Whiterocks, Utah',33207,52);
INSERT INTO "django_geo_db_city" VALUES(26988,'Woodruff','Woodruff, Utah',33208,52);
INSERT INTO "django_geo_db_city" VALUES(26989,'Woods Cross','Woods Cross, Utah',33209,52);
INSERT INTO "django_geo_db_city" VALUES(26990,'South Jordan','South Jordan, Utah',33215,52);
INSERT INTO "django_geo_db_city" VALUES(26991,'Salt Lake City','Salt Lake City, Utah',33218,52);
INSERT INTO "django_geo_db_city" VALUES(26992,'Ogden','Ogden, Utah',33253,52);
INSERT INTO "django_geo_db_city" VALUES(26993,'Green River','Green River, Utah',33255,52);
INSERT INTO "django_geo_db_city" VALUES(26994,'Bear River City','Bear River City, Utah',33256,52);
INSERT INTO "django_geo_db_city" VALUES(26995,'Brigham City','Brigham City, Utah',33257,52);
INSERT INTO "django_geo_db_city" VALUES(26996,'Cache Junction','Cache Junction, Utah',33258,52);
INSERT INTO "django_geo_db_city" VALUES(26997,'Clarkston','Clarkston, Utah',33259,52);
INSERT INTO "django_geo_db_city" VALUES(26998,'Collinston','Collinston, Utah',33260,52);
INSERT INTO "django_geo_db_city" VALUES(26999,'Corinne','Corinne, Utah',33261,52);
INSERT INTO "django_geo_db_city" VALUES(27000,'Cornish','Cornish, Utah',33262,52);
INSERT INTO "django_geo_db_city" VALUES(27001,'Deweyville','Deweyville, Utah',33263,52);
INSERT INTO "django_geo_db_city" VALUES(27002,'Eden','Eden, Utah',33264,52);
INSERT INTO "django_geo_db_city" VALUES(27003,'Fielding','Fielding, Utah',33265,52);
INSERT INTO "django_geo_db_city" VALUES(27004,'Garland','Garland, Utah',33266,52);
INSERT INTO "django_geo_db_city" VALUES(27005,'Grouse Creek','Grouse Creek, Utah',33267,52);
INSERT INTO "django_geo_db_city" VALUES(27006,'Honeyville','Honeyville, Utah',33268,52);
INSERT INTO "django_geo_db_city" VALUES(27007,'Hooper','Hooper, Utah',33269,52);
INSERT INTO "django_geo_db_city" VALUES(27008,'Howell','Howell, Utah',33270,52);
INSERT INTO "django_geo_db_city" VALUES(27009,'Huntsville','Huntsville, Utah',33271,52);
INSERT INTO "django_geo_db_city" VALUES(27010,'Hyde Park','Hyde Park, Utah',33272,52);
INSERT INTO "django_geo_db_city" VALUES(27011,'Hyrum','Hyrum, Utah',33273,52);
INSERT INTO "django_geo_db_city" VALUES(27012,'Lewiston','Lewiston, Utah',33274,52);
INSERT INTO "django_geo_db_city" VALUES(27013,'Logan','Logan, Utah',33275,52);
INSERT INTO "django_geo_db_city" VALUES(27014,'Mantua','Mantua, Utah',33278,52);
INSERT INTO "django_geo_db_city" VALUES(27015,'Mendon','Mendon, Utah',33279,52);
INSERT INTO "django_geo_db_city" VALUES(27016,'Millville','Millville, Utah',33280,52);
INSERT INTO "django_geo_db_city" VALUES(27017,'Newton','Newton, Utah',33281,52);
INSERT INTO "django_geo_db_city" VALUES(27018,'Paradise','Paradise, Utah',33282,52);
INSERT INTO "django_geo_db_city" VALUES(27019,'Park Valley','Park Valley, Utah',33283,52);
INSERT INTO "django_geo_db_city" VALUES(27020,'Plymouth','Plymouth, Utah',33284,52);
INSERT INTO "django_geo_db_city" VALUES(27021,'Portage','Portage, Utah',33285,52);
INSERT INTO "django_geo_db_city" VALUES(27022,'Providence','Providence, Utah',33286,52);
INSERT INTO "django_geo_db_city" VALUES(27023,'Richmond','Richmond, Utah',33287,52);
INSERT INTO "django_geo_db_city" VALUES(27024,'Riverside','Riverside, Utah',33288,52);
INSERT INTO "django_geo_db_city" VALUES(27025,'Smithfield','Smithfield, Utah',33289,52);
INSERT INTO "django_geo_db_city" VALUES(27026,'Snowville','Snowville, Utah',33290,52);
INSERT INTO "django_geo_db_city" VALUES(27027,'Tremonton','Tremonton, Utah',33291,52);
INSERT INTO "django_geo_db_city" VALUES(27028,'Trenton','Trenton, Utah',33292,52);
INSERT INTO "django_geo_db_city" VALUES(27029,'Wellsville','Wellsville, Utah',33293,52);
INSERT INTO "django_geo_db_city" VALUES(27030,'Willard','Willard, Utah',33294,52);
INSERT INTO "django_geo_db_city" VALUES(27031,'South Willard','South Willard, Utah',33296,52);
INSERT INTO "django_geo_db_city" VALUES(27032,'Price','Price, Utah',33304,52);
INSERT INTO "django_geo_db_city" VALUES(27033,'Aneth','Aneth, Utah',33305,52);
INSERT INTO "django_geo_db_city" VALUES(27034,'Blanding','Blanding, Utah',33306,52);
INSERT INTO "django_geo_db_city" VALUES(27035,'Bluff','Bluff, Utah',33307,52);
INSERT INTO "django_geo_db_city" VALUES(27036,'Castle Dale','Castle Dale, Utah',33308,52);
INSERT INTO "django_geo_db_city" VALUES(27037,'Cisco','Cisco, Utah',33309,52);
INSERT INTO "django_geo_db_city" VALUES(27038,'Clawson','Clawson, Utah',33310,52);
INSERT INTO "django_geo_db_city" VALUES(27039,'Cleveland','Cleveland, Utah',33311,52);
INSERT INTO "django_geo_db_city" VALUES(27040,'East Carbon','East Carbon, Utah',33312,52);
INSERT INTO "django_geo_db_city" VALUES(27041,'Elmo','Elmo, Utah',33313,52);
INSERT INTO "django_geo_db_city" VALUES(27042,'Emery','Emery, Utah',33314,52);
INSERT INTO "django_geo_db_city" VALUES(27043,'Ferron','Ferron, Utah',33315,52);
INSERT INTO "django_geo_db_city" VALUES(27044,'Helper','Helper, Utah',33317,52);
INSERT INTO "django_geo_db_city" VALUES(27045,'Hiawatha','Hiawatha, Utah',33318,52);
INSERT INTO "django_geo_db_city" VALUES(27046,'Huntington','Huntington, Utah',33319,52);
INSERT INTO "django_geo_db_city" VALUES(27047,'Kenilworth','Kenilworth, Utah',33320,52);
INSERT INTO "django_geo_db_city" VALUES(27048,'La Sal','La Sal, Utah',33321,52);
INSERT INTO "django_geo_db_city" VALUES(27049,'Mexican Hat','Mexican Hat, Utah',33322,52);
INSERT INTO "django_geo_db_city" VALUES(27050,'Moab','Moab, Utah',33323,52);
INSERT INTO "django_geo_db_city" VALUES(27051,'Lake Powell','Lake Powell, Utah',33324,52);
INSERT INTO "django_geo_db_city" VALUES(27052,'Montezuma Creek','Montezuma Creek, Utah',33325,52);
INSERT INTO "django_geo_db_city" VALUES(27053,'Monticello','Monticello, Utah',33326,52);
INSERT INTO "django_geo_db_city" VALUES(27054,'Monument Valley','Monument Valley, Arizona',33327,3);
INSERT INTO "django_geo_db_city" VALUES(27055,'Orangeville','Orangeville, Utah',33328,52);
INSERT INTO "django_geo_db_city" VALUES(27056,'Sunnyside','Sunnyside, Utah',33329,52);
INSERT INTO "django_geo_db_city" VALUES(27057,'Thompson','Thompson, Utah',33330,52);
INSERT INTO "django_geo_db_city" VALUES(27058,'Wellington','Wellington, Utah',33331,52);
INSERT INTO "django_geo_db_city" VALUES(27059,'Provo','Provo, Utah',33332,52);
INSERT INTO "django_geo_db_city" VALUES(27060,'Aurora','Aurora, Utah',33337,52);
INSERT INTO "django_geo_db_city" VALUES(27061,'Axtell','Axtell, Utah',33338,52);
INSERT INTO "django_geo_db_city" VALUES(27062,'Centerfield','Centerfield, Utah',33339,52);
INSERT INTO "django_geo_db_city" VALUES(27063,'Chester','Chester, Utah',33340,52);
INSERT INTO "django_geo_db_city" VALUES(27064,'Delta','Delta, Utah',33341,52);
INSERT INTO "django_geo_db_city" VALUES(27065,'Elberta','Elberta, Utah',33342,52);
INSERT INTO "django_geo_db_city" VALUES(27066,'Ephraim','Ephraim, Utah',33343,52);
INSERT INTO "django_geo_db_city" VALUES(27067,'Eureka','Eureka, Utah',33344,52);
INSERT INTO "django_geo_db_city" VALUES(27068,'Fairview','Fairview, Utah',33345,52);
INSERT INTO "django_geo_db_city" VALUES(27069,'Fayette','Fayette, Utah',33346,52);
INSERT INTO "django_geo_db_city" VALUES(27070,'Fillmore','Fillmore, Utah',33347,52);
INSERT INTO "django_geo_db_city" VALUES(27071,'Fountain Green','Fountain Green, Utah',33348,52);
INSERT INTO "django_geo_db_city" VALUES(27072,'Goshen','Goshen, Utah',33349,52);
INSERT INTO "django_geo_db_city" VALUES(27073,'Gunnison','Gunnison, Utah',33350,52);
INSERT INTO "django_geo_db_city" VALUES(27074,'Hinckley','Hinckley, Utah',33351,52);
INSERT INTO "django_geo_db_city" VALUES(27075,'Holden','Holden, Utah',33352,52);
INSERT INTO "django_geo_db_city" VALUES(27076,'Kanosh','Kanosh, Utah',33353,52);
INSERT INTO "django_geo_db_city" VALUES(27077,'Leamington','Leamington, Utah',33354,52);
INSERT INTO "django_geo_db_city" VALUES(27078,'Levan','Levan, Utah',33355,52);
INSERT INTO "django_geo_db_city" VALUES(27079,'Lynndyl','Lynndyl, Utah',33356,52);
INSERT INTO "django_geo_db_city" VALUES(27080,'Manti','Manti, Utah',33357,52);
INSERT INTO "django_geo_db_city" VALUES(27081,'Mayfield','Mayfield, Utah',33358,52);
INSERT INTO "django_geo_db_city" VALUES(27082,'Meadow','Meadow, Utah',33359,52);
INSERT INTO "django_geo_db_city" VALUES(27083,'Mona','Mona, Utah',33360,52);
INSERT INTO "django_geo_db_city" VALUES(27084,'Moroni','Moroni, Utah',33361,52);
INSERT INTO "django_geo_db_city" VALUES(27085,'Mount Pleasant','Mount Pleasant, Utah',33362,52);
INSERT INTO "django_geo_db_city" VALUES(27086,'Nephi','Nephi, Utah',33363,52);
INSERT INTO "django_geo_db_city" VALUES(27087,'Oak City','Oak City, Utah',33364,52);
INSERT INTO "django_geo_db_city" VALUES(27088,'Oasis','Oasis, Utah',33365,52);
INSERT INTO "django_geo_db_city" VALUES(27089,'Payson','Payson, Utah',33366,52);
INSERT INTO "django_geo_db_city" VALUES(27090,'Redmond','Redmond, Utah',33367,52);
INSERT INTO "django_geo_db_city" VALUES(27091,'Salem','Salem, Utah',33368,52);
INSERT INTO "django_geo_db_city" VALUES(27092,'Salina','Salina, Utah',33369,52);
INSERT INTO "django_geo_db_city" VALUES(27093,'Santaquin','Santaquin, Utah',33370,52);
INSERT INTO "django_geo_db_city" VALUES(27094,'Scipio','Scipio, Utah',33371,52);
INSERT INTO "django_geo_db_city" VALUES(27095,'Sigurd','Sigurd, Utah',33372,52);
INSERT INTO "django_geo_db_city" VALUES(27096,'Spanish Fork','Spanish Fork, Utah',33373,52);
INSERT INTO "django_geo_db_city" VALUES(27097,'Spring City','Spring City, Utah',33374,52);
INSERT INTO "django_geo_db_city" VALUES(27098,'Springville','Springville, Utah',33375,52);
INSERT INTO "django_geo_db_city" VALUES(27099,'Mapleton','Mapleton, Utah',33376,52);
INSERT INTO "django_geo_db_city" VALUES(27100,'Sterling','Sterling, Utah',33377,52);
INSERT INTO "django_geo_db_city" VALUES(27101,'Wales','Wales, Utah',33378,52);
INSERT INTO "django_geo_db_city" VALUES(27102,'Richfield','Richfield, Utah',33379,52);
INSERT INTO "django_geo_db_city" VALUES(27103,'Alton','Alton, Utah',33380,52);
INSERT INTO "django_geo_db_city" VALUES(27104,'Annabella','Annabella, Utah',33381,52);
INSERT INTO "django_geo_db_city" VALUES(27105,'Antimony','Antimony, Utah',33382,52);
INSERT INTO "django_geo_db_city" VALUES(27106,'Beaver','Beaver, Utah',33383,52);
INSERT INTO "django_geo_db_city" VALUES(27107,'Beryl','Beryl, Utah',33384,52);
INSERT INTO "django_geo_db_city" VALUES(27108,'Bicknell','Bicknell, Utah',33385,52);
INSERT INTO "django_geo_db_city" VALUES(27109,'Boulder','Boulder, Utah',33386,52);
INSERT INTO "django_geo_db_city" VALUES(27110,'Bryce Canyon','Bryce Canyon, Utah',33387,52);
INSERT INTO "django_geo_db_city" VALUES(27111,'Cannonville','Cannonville, Utah',33388,52);
INSERT INTO "django_geo_db_city" VALUES(27112,'Brian Head','Brian Head, Utah',33389,52);
INSERT INTO "django_geo_db_city" VALUES(27113,'Cedar City','Cedar City, Utah',33390,52);
INSERT INTO "django_geo_db_city" VALUES(27114,'Central','Central, Utah',33392,52);
INSERT INTO "django_geo_db_city" VALUES(27115,'Circleville','Circleville, Utah',33393,52);
INSERT INTO "django_geo_db_city" VALUES(27116,'Elsinore','Elsinore, Utah',33394,52);
INSERT INTO "django_geo_db_city" VALUES(27117,'Enterprise','Enterprise, Utah',33395,52);
INSERT INTO "django_geo_db_city" VALUES(27118,'Escalante','Escalante, Utah',33396,52);
INSERT INTO "django_geo_db_city" VALUES(27119,'Garrison','Garrison, Utah',33397,52);
INSERT INTO "django_geo_db_city" VALUES(27120,'Glendale','Glendale, Utah',33398,52);
INSERT INTO "django_geo_db_city" VALUES(27121,'Glenwood','Glenwood, Utah',33399,52);
INSERT INTO "django_geo_db_city" VALUES(27122,'Greenville','Greenville, Utah',33400,52);
INSERT INTO "django_geo_db_city" VALUES(27123,'Greenwich','Greenwich, Utah',33401,52);
INSERT INTO "django_geo_db_city" VALUES(27124,'Gunlock','Gunlock, Utah',33402,52);
INSERT INTO "django_geo_db_city" VALUES(27125,'Hanksville','Hanksville, Utah',33403,52);
INSERT INTO "django_geo_db_city" VALUES(27126,'Hatch','Hatch, Utah',33404,52);
INSERT INTO "django_geo_db_city" VALUES(27127,'Henrieville','Henrieville, Utah',33405,52);
INSERT INTO "django_geo_db_city" VALUES(27128,'Hurricane','Hurricane, Utah',33406,52);
INSERT INTO "django_geo_db_city" VALUES(27129,'Ivins','Ivins, Utah',33407,52);
INSERT INTO "django_geo_db_city" VALUES(27130,'Joseph','Joseph, Utah',33408,52);
INSERT INTO "django_geo_db_city" VALUES(27131,'Junction','Junction, Utah',33409,52);
INSERT INTO "django_geo_db_city" VALUES(27132,'Kanab','Kanab, Utah',33410,52);
INSERT INTO "django_geo_db_city" VALUES(27133,'Kanarraville','Kanarraville, Utah',33411,52);
INSERT INTO "django_geo_db_city" VALUES(27134,'Kingston','Kingston, Utah',33412,52);
INSERT INTO "django_geo_db_city" VALUES(27135,'Koosharem','Koosharem, Utah',33413,52);
INSERT INTO "django_geo_db_city" VALUES(27136,'La Verkin','La Verkin, Utah',33414,52);
INSERT INTO "django_geo_db_city" VALUES(27137,'Leeds','Leeds, Utah',33415,52);
INSERT INTO "django_geo_db_city" VALUES(27138,'Loa','Loa, Utah',33416,52);
INSERT INTO "django_geo_db_city" VALUES(27139,'Lyman','Lyman, Utah',33417,52);
INSERT INTO "django_geo_db_city" VALUES(27140,'Marysvale','Marysvale, Utah',33418,52);
INSERT INTO "django_geo_db_city" VALUES(27141,'Milford','Milford, Utah',33419,52);
INSERT INTO "django_geo_db_city" VALUES(27142,'Minersville','Minersville, Utah',33420,52);
INSERT INTO "django_geo_db_city" VALUES(27143,'Modena','Modena, Utah',33421,52);
INSERT INTO "django_geo_db_city" VALUES(27144,'Monroe','Monroe, Utah',33422,52);
INSERT INTO "django_geo_db_city" VALUES(27145,'Mount Carmel','Mount Carmel, Utah',33423,52);
INSERT INTO "django_geo_db_city" VALUES(27146,'Newcastle','Newcastle, Utah',33424,52);
INSERT INTO "django_geo_db_city" VALUES(27147,'New Harmony','New Harmony, Utah',33425,52);
INSERT INTO "django_geo_db_city" VALUES(27148,'Orderville','Orderville, Utah',33426,52);
INSERT INTO "django_geo_db_city" VALUES(27149,'Panguitch','Panguitch, Utah',33427,52);
INSERT INTO "django_geo_db_city" VALUES(27150,'Paragonah','Paragonah, Utah',33428,52);
INSERT INTO "django_geo_db_city" VALUES(27151,'Parowan','Parowan, Utah',33429,52);
INSERT INTO "django_geo_db_city" VALUES(27152,'Duck Creek Village','Duck Creek Village, Utah',33430,52);
INSERT INTO "django_geo_db_city" VALUES(27153,'Rockville','Rockville, Utah',33431,52);
INSERT INTO "django_geo_db_city" VALUES(27154,'Bryce','Bryce, Utah',33432,52);
INSERT INTO "django_geo_db_city" VALUES(27155,'Santa Clara','Santa Clara, Utah',33433,52);
INSERT INTO "django_geo_db_city" VALUES(27156,'Sevier','Sevier, Utah',33434,52);
INSERT INTO "django_geo_db_city" VALUES(27157,'Springdale','Springdale, Utah',33435,52);
INSERT INTO "django_geo_db_city" VALUES(27158,'Saint George','Saint George, Utah',33436,52);
INSERT INTO "django_geo_db_city" VALUES(27159,'Summit','Summit, Utah',33438,52);
INSERT INTO "django_geo_db_city" VALUES(27160,'Teasdale','Teasdale, Utah',33439,52);
INSERT INTO "django_geo_db_city" VALUES(27161,'Toquerville','Toquerville, Utah',33440,52);
INSERT INTO "django_geo_db_city" VALUES(27162,'Torrey','Torrey, Utah',33441,52);
INSERT INTO "django_geo_db_city" VALUES(27163,'Tropic','Tropic, Utah',33442,52);
INSERT INTO "django_geo_db_city" VALUES(27164,'Virgin','Virgin, Utah',33443,52);
INSERT INTO "django_geo_db_city" VALUES(27165,'Washington','Washington, Utah',33444,52);
INSERT INTO "django_geo_db_city" VALUES(27166,'Pine Valley','Pine Valley, Utah',33445,52);
INSERT INTO "django_geo_db_city" VALUES(27167,'Veyo','Veyo, Utah',33446,52);
INSERT INTO "django_geo_db_city" VALUES(27168,'Dammeron Valley','Dammeron Valley, Utah',33447,52);
INSERT INTO "django_geo_db_city" VALUES(27169,'Hildale','Hildale, Utah',33448,52);
INSERT INTO "django_geo_db_city" VALUES(27170,'Clinton','Clinton, Utah',33452,52);
INSERT INTO "django_geo_db_city" VALUES(27171,'Phoenix','Phoenix, Arizona',33454,3);
INSERT INTO "django_geo_db_city" VALUES(27172,'Anthem','Anthem, Arizona',33497,3);
INSERT INTO "django_geo_db_city" VALUES(27173,'New River','New River, Arizona',33498,3);
INSERT INTO "django_geo_db_city" VALUES(27174,'Mesa','Mesa, Arizona',33500,3);
INSERT INTO "django_geo_db_city" VALUES(27175,'Apache Junction','Apache Junction, Arizona',33515,3);
INSERT INTO "django_geo_db_city" VALUES(27176,'Gold Camp','Gold Camp, Arizona',33516,3);
INSERT INTO "django_geo_db_city" VALUES(27177,'Bapchule','Bapchule, Arizona',33519,3);
INSERT INTO "django_geo_db_city" VALUES(27178,'Casa Grande','Casa Grande, Arizona',33520,3);
INSERT INTO "django_geo_db_city" VALUES(27179,'Arizona City','Arizona City, Arizona',33521,3);
INSERT INTO "django_geo_db_city" VALUES(27180,'Chandler','Chandler, Arizona',33522,3);
INSERT INTO "django_geo_db_city" VALUES(27181,'Chandler Heights','Chandler Heights, Arizona',33525,3);
INSERT INTO "django_geo_db_city" VALUES(27182,'Coolidge','Coolidge, Arizona',33526,3);
INSERT INTO "django_geo_db_city" VALUES(27183,'Eloy','Eloy, Arizona',33528,3);
INSERT INTO "django_geo_db_city" VALUES(27184,'Florence','Florence, Arizona',33529,3);
INSERT INTO "django_geo_db_city" VALUES(27185,'Gilbert','Gilbert, Arizona',33530,3);
INSERT INTO "django_geo_db_city" VALUES(27186,'Hayden','Hayden, Arizona',33532,3);
INSERT INTO "django_geo_db_city" VALUES(27187,'Higley','Higley, Arizona',33533,3);
INSERT INTO "django_geo_db_city" VALUES(27188,'Kearny','Kearny, Arizona',33534,3);
INSERT INTO "django_geo_db_city" VALUES(27189,'Maricopa','Maricopa, Arizona',33535,3);
INSERT INTO "django_geo_db_city" VALUES(27190,'Picacho','Picacho, Arizona',33537,3);
INSERT INTO "django_geo_db_city" VALUES(27191,'Queen Creek','Queen Creek, Arizona',33538,3);
INSERT INTO "django_geo_db_city" VALUES(27192,'Red Rock','Red Rock, Arizona',33540,3);
INSERT INTO "django_geo_db_city" VALUES(27193,'Sacaton','Sacaton, Arizona',33541,3);
INSERT INTO "django_geo_db_city" VALUES(27194,'Scottsdale','Scottsdale, Arizona',33544,3);
INSERT INTO "django_geo_db_city" VALUES(27195,'Paradise Valley','Paradise Valley, Arizona',33547,3);
INSERT INTO "django_geo_db_city" VALUES(27196,'Rio Verde','Rio Verde, Arizona',33556,3);
INSERT INTO "django_geo_db_city" VALUES(27197,'Fort Mcdowell','Fort Mcdowell, Arizona',33557,3);
INSERT INTO "django_geo_db_city" VALUES(27198,'Fountain Hills','Fountain Hills, Arizona',33558,3);
INSERT INTO "django_geo_db_city" VALUES(27199,'Stanfield','Stanfield, Arizona',33559,3);
INSERT INTO "django_geo_db_city" VALUES(27200,'Superior','Superior, Arizona',33560,3);
INSERT INTO "django_geo_db_city" VALUES(27201,'Tempe','Tempe, Arizona',33562,3);
INSERT INTO "django_geo_db_city" VALUES(27202,'Tortilla Flat','Tortilla Flat, Arizona',33455,3);
INSERT INTO "django_geo_db_city" VALUES(27203,'Valley Farms','Valley Farms, Arizona',33570,3);
INSERT INTO "django_geo_db_city" VALUES(27204,'Winkelman','Winkelman, Arizona',33571,3);
INSERT INTO "django_geo_db_city" VALUES(27205,'Glendale','Glendale, Arizona',33574,3);
INSERT INTO "django_geo_db_city" VALUES(27206,'Luke AFB','Luke AFB, Arizona',33582,3);
INSERT INTO "django_geo_db_city" VALUES(27207,'Carefree','Carefree, Arizona',33584,3);
INSERT INTO "django_geo_db_city" VALUES(27208,'Aguila','Aguila, Arizona',33585,3);
INSERT INTO "django_geo_db_city" VALUES(27209,'Ajo','Ajo, Arizona',33586,3);
INSERT INTO "django_geo_db_city" VALUES(27210,'Arlington','Arlington, Arizona',33587,3);
INSERT INTO "django_geo_db_city" VALUES(27211,'Avondale','Avondale, Arizona',33588,3);
INSERT INTO "django_geo_db_city" VALUES(27212,'Black Canyon City','Black Canyon City, Arizona',33589,3);
INSERT INTO "django_geo_db_city" VALUES(27213,'Bouse','Bouse, Arizona',33590,3);
INSERT INTO "django_geo_db_city" VALUES(27214,'Buckeye','Buckeye, Arizona',33591,3);
INSERT INTO "django_geo_db_city" VALUES(27215,'Cave Creek','Cave Creek, Arizona',33455,3);
INSERT INTO "django_geo_db_city" VALUES(27216,'Cibola','Cibola, Arizona',33592,3);
INSERT INTO "django_geo_db_city" VALUES(27217,'Cashion','Cashion, Arizona',33593,3);
INSERT INTO "django_geo_db_city" VALUES(27218,'Wickenburg','Wickenburg, Arizona',33594,3);
INSERT INTO "django_geo_db_city" VALUES(27219,'Congress','Congress, Arizona',33596,3);
INSERT INTO "django_geo_db_city" VALUES(27220,'Dateland','Dateland, Arizona',33597,3);
INSERT INTO "django_geo_db_city" VALUES(27221,'Ehrenberg','Ehrenberg, Arizona',33598,3);
INSERT INTO "django_geo_db_city" VALUES(27222,'El Mirage','El Mirage, Arizona',33599,3);
INSERT INTO "django_geo_db_city" VALUES(27223,'Gadsden','Gadsden, Arizona',33600,3);
INSERT INTO "django_geo_db_city" VALUES(27224,'Gila Bend','Gila Bend, Arizona',33601,3);
INSERT INTO "django_geo_db_city" VALUES(27225,'Goodyear','Goodyear, Arizona',33602,3);
INSERT INTO "django_geo_db_city" VALUES(27226,'Laveen','Laveen, Arizona',33603,3);
INSERT INTO "django_geo_db_city" VALUES(27227,'Litchfield Park','Litchfield Park, Arizona',33604,3);
INSERT INTO "django_geo_db_city" VALUES(27228,'Lukeville','Lukeville, Arizona',33605,3);
INSERT INTO "django_geo_db_city" VALUES(27229,'Morristown','Morristown, Arizona',33606,3);
INSERT INTO "django_geo_db_city" VALUES(27230,'Palo Verde','Palo Verde, Arizona',33455,3);
INSERT INTO "django_geo_db_city" VALUES(27231,'Parker','Parker, Arizona',33607,3);
INSERT INTO "django_geo_db_city" VALUES(27232,'Peoria','Peoria, Arizona',33608,3);
INSERT INTO "django_geo_db_city" VALUES(27233,'Quartzsite','Quartzsite, Arizona',33609,3);
INSERT INTO "django_geo_db_city" VALUES(27234,'Roll','Roll, Arizona',33610,3);
INSERT INTO "django_geo_db_city" VALUES(27235,'Salome','Salome, Arizona',33611,3);
INSERT INTO "django_geo_db_city" VALUES(27236,'San Luis','San Luis, Arizona',33612,3);
INSERT INTO "django_geo_db_city" VALUES(27237,'Somerton','Somerton, Arizona',33613,3);
INSERT INTO "django_geo_db_city" VALUES(27238,'Sun City','Sun City, Arizona',33614,3);
INSERT INTO "django_geo_db_city" VALUES(27239,'Tacna','Tacna, Arizona',33615,3);
INSERT INTO "django_geo_db_city" VALUES(27240,'Tolleson','Tolleson, Arizona',33616,3);
INSERT INTO "django_geo_db_city" VALUES(27241,'Tonopah','Tonopah, Arizona',33617,3);
INSERT INTO "django_geo_db_city" VALUES(27242,'Waddell','Waddell, Arizona',33618,3);
INSERT INTO "django_geo_db_city" VALUES(27243,'Wellton','Wellton, Arizona',33619,3);
INSERT INTO "django_geo_db_city" VALUES(27244,'Wenden','Wenden, Arizona',33620,3);
INSERT INTO "django_geo_db_city" VALUES(27245,'Wikieup','Wikieup, Arizona',33622,3);
INSERT INTO "django_geo_db_city" VALUES(27246,'Wittmann','Wittmann, Arizona',33623,3);
INSERT INTO "django_geo_db_city" VALUES(27247,'Yarnell','Yarnell, Arizona',33624,3);
INSERT INTO "django_geo_db_city" VALUES(27248,'Youngtown','Youngtown, Arizona',33625,3);
INSERT INTO "django_geo_db_city" VALUES(27249,'Yuma','Yuma, Arizona',33626,3);
INSERT INTO "django_geo_db_city" VALUES(27250,'Poston','Poston, Arizona',33631,3);
INSERT INTO "django_geo_db_city" VALUES(27251,'Surprise','Surprise, Arizona',33633,3);
INSERT INTO "django_geo_db_city" VALUES(27252,'Sun City West','Sun City West, Arizona',33634,3);
INSERT INTO "django_geo_db_city" VALUES(27253,'Globe','Globe, Arizona',33642,3);
INSERT INTO "django_geo_db_city" VALUES(27254,'Thatcher','Thatcher, Arizona',33644,3);
INSERT INTO "django_geo_db_city" VALUES(27255,'Bylas','Bylas, Arizona',33645,3);
INSERT INTO "django_geo_db_city" VALUES(27256,'Central','Central, Arizona',33646,3);
INSERT INTO "django_geo_db_city" VALUES(27257,'Claypool','Claypool, Arizona',33647,3);
INSERT INTO "django_geo_db_city" VALUES(27258,'Clifton','Clifton, Arizona',33648,3);
INSERT INTO "django_geo_db_city" VALUES(27259,'Duncan','Duncan, Arizona',33649,3);
INSERT INTO "django_geo_db_city" VALUES(27260,'Eden','Eden, Arizona',33650,3);
INSERT INTO "django_geo_db_city" VALUES(27261,'Fort Thomas','Fort Thomas, Arizona',33651,3);
INSERT INTO "django_geo_db_city" VALUES(27262,'Miami','Miami, Arizona',33652,3);
INSERT INTO "django_geo_db_city" VALUES(27263,'Morenci','Morenci, Arizona',33653,3);
INSERT INTO "django_geo_db_city" VALUES(27264,'Payson','Payson, Arizona',33654,3);
INSERT INTO "django_geo_db_city" VALUES(27265,'Peridot','Peridot, Arizona',33655,3);
INSERT INTO "django_geo_db_city" VALUES(27266,'Pima','Pima, Arizona',33656,3);
INSERT INTO "django_geo_db_city" VALUES(27267,'Pine','Pine, Arizona',33657,3);
INSERT INTO "django_geo_db_city" VALUES(27268,'Roosevelt','Roosevelt, Arizona',33658,3);
INSERT INTO "django_geo_db_city" VALUES(27269,'Safford','Safford, Arizona',33659,3);
INSERT INTO "django_geo_db_city" VALUES(27270,'San Carlos','San Carlos, Arizona',33662,3);
INSERT INTO "django_geo_db_city" VALUES(27271,'Solomon','Solomon, Arizona',33663,3);
INSERT INTO "django_geo_db_city" VALUES(27272,'Tonto Basin','Tonto Basin, Arizona',33665,3);
INSERT INTO "django_geo_db_city" VALUES(27273,'Young','Young, Arizona',33666,3);
INSERT INTO "django_geo_db_city" VALUES(27274,'Arivaca','Arivaca, Arizona',33667,3);
INSERT INTO "django_geo_db_city" VALUES(27275,'Benson','Benson, Arizona',33668,3);
INSERT INTO "django_geo_db_city" VALUES(27276,'Bisbee','Bisbee, Arizona',33669,3);
INSERT INTO "django_geo_db_city" VALUES(27277,'Bowie','Bowie, Arizona',33670,3);
INSERT INTO "django_geo_db_city" VALUES(27278,'Cochise','Cochise, Arizona',33671,3);
INSERT INTO "django_geo_db_city" VALUES(27279,'Douglas','Douglas, Arizona',33672,3);
INSERT INTO "django_geo_db_city" VALUES(27280,'Dragoon','Dragoon, Arizona',33674,3);
INSERT INTO "django_geo_db_city" VALUES(27281,'Elfrida','Elfrida, Arizona',33675,3);
INSERT INTO "django_geo_db_city" VALUES(27282,'Elgin','Elgin, Arizona',33676,3);
INSERT INTO "django_geo_db_city" VALUES(27283,'Fort Huachuca','Fort Huachuca, Arizona',33677,3);
INSERT INTO "django_geo_db_city" VALUES(27284,'Green Valley','Green Valley, Arizona',33678,3);
INSERT INTO "django_geo_db_city" VALUES(27285,'Hereford','Hereford, Arizona',33679,3);
INSERT INTO "django_geo_db_city" VALUES(27286,'Huachuca City','Huachuca City, Arizona',33680,3);
INSERT INTO "django_geo_db_city" VALUES(27287,'McNeal','McNeal, Arizona',33681,3);
INSERT INTO "django_geo_db_city" VALUES(27288,'Mammoth','Mammoth, Arizona',33682,3);
INSERT INTO "django_geo_db_city" VALUES(27289,'Mount Lemmon','Mount Lemmon, Arizona',33683,3);
INSERT INTO "django_geo_db_city" VALUES(27290,'Naco','Naco, Arizona',33684,3);
INSERT INTO "django_geo_db_city" VALUES(27291,'Nogales','Nogales, Arizona',33685,3);
INSERT INTO "django_geo_db_city" VALUES(27292,'Oracle','Oracle, Arizona',33687,3);
INSERT INTO "django_geo_db_city" VALUES(27293,'Patagonia','Patagonia, Arizona',33688,3);
INSERT INTO "django_geo_db_city" VALUES(27294,'Pearce','Pearce, Arizona',33689,3);
INSERT INTO "django_geo_db_city" VALUES(27295,'Pirtleville','Pirtleville, Arizona',33690,3);
INSERT INTO "django_geo_db_city" VALUES(27296,'Pomerene','Pomerene, Arizona',33691,3);
INSERT INTO "django_geo_db_city" VALUES(27297,'Sahuarita','Sahuarita, Arizona',33693,3);
INSERT INTO "django_geo_db_city" VALUES(27298,'Saint David','Saint David, Arizona',33694,3);
INSERT INTO "django_geo_db_city" VALUES(27299,'San Manuel','San Manuel, Arizona',33695,3);
INSERT INTO "django_geo_db_city" VALUES(27300,'San Simon','San Simon, Arizona',33696,3);
INSERT INTO "django_geo_db_city" VALUES(27301,'Sasabe','Sasabe, Arizona',33697,3);
INSERT INTO "django_geo_db_city" VALUES(27302,'Sells','Sells, Arizona',33698,3);
INSERT INTO "django_geo_db_city" VALUES(27303,'Sierra Vista','Sierra Vista, Arizona',33699,3);
INSERT INTO "django_geo_db_city" VALUES(27304,'Sonoita','Sonoita, Arizona',33701,3);
INSERT INTO "django_geo_db_city" VALUES(27305,'Tombstone','Tombstone, Arizona',33702,3);
INSERT INTO "django_geo_db_city" VALUES(27306,'Topawa','Topawa, Arizona',33703,3);
INSERT INTO "django_geo_db_city" VALUES(27307,'Tumacacori','Tumacacori, Arizona',33704,3);
INSERT INTO "django_geo_db_city" VALUES(27308,'Vail','Vail, Arizona',33705,3);
INSERT INTO "django_geo_db_city" VALUES(27309,'Willcox','Willcox, Arizona',33706,3);
INSERT INTO "django_geo_db_city" VALUES(27310,'Amado','Amado, Arizona',33708,3);
INSERT INTO "django_geo_db_city" VALUES(27311,'Tubac','Tubac, Arizona',33709,3);
INSERT INTO "django_geo_db_city" VALUES(27312,'Rio Rico','Rio Rico, Arizona',33710,3);
INSERT INTO "django_geo_db_city" VALUES(27313,'Cortaro','Cortaro, Arizona',33712,3);
INSERT INTO "django_geo_db_city" VALUES(27314,'Marana','Marana, Arizona',33713,3);
INSERT INTO "django_geo_db_city" VALUES(27315,'Rillito','Rillito, Arizona',33714,3);
INSERT INTO "django_geo_db_city" VALUES(27316,'Tucson','Tucson, Arizona',33716,3);
INSERT INTO "django_geo_db_city" VALUES(27317,'Catalina','Catalina, Arizona',33605,3);
INSERT INTO "django_geo_db_city" VALUES(27318,'Show Low','Show Low, Arizona',33755,3);
INSERT INTO "django_geo_db_city" VALUES(27319,'Cibecue','Cibecue, Arizona',33757,3);
INSERT INTO "django_geo_db_city" VALUES(27320,'White Mountain Lake','White Mountain Lake, Arizona',33758,3);
INSERT INTO "django_geo_db_city" VALUES(27321,'Alpine','Alpine, Arizona',33759,3);
INSERT INTO "django_geo_db_city" VALUES(27322,'Blue','Blue, Arizona',33760,3);
INSERT INTO "django_geo_db_city" VALUES(27323,'Clay Springs','Clay Springs, Arizona',33761,3);
INSERT INTO "django_geo_db_city" VALUES(27324,'Concho','Concho, Arizona',33762,3);
INSERT INTO "django_geo_db_city" VALUES(27325,'Eagar','Eagar, Arizona',33763,3);
INSERT INTO "django_geo_db_city" VALUES(27326,'Fort Apache','Fort Apache, Arizona',33764,3);
INSERT INTO "django_geo_db_city" VALUES(27327,'Greer','Greer, Arizona',33765,3);
INSERT INTO "django_geo_db_city" VALUES(27328,'Heber','Heber, Arizona',33766,3);
INSERT INTO "django_geo_db_city" VALUES(27329,'Lakeside','Lakeside, Arizona',33767,3);
INSERT INTO "django_geo_db_city" VALUES(27330,'Mcnary','Mcnary, Arizona',33768,3);
INSERT INTO "django_geo_db_city" VALUES(27331,'Forest Lakes','Forest Lakes, Arizona',33769,3);
INSERT INTO "django_geo_db_city" VALUES(27332,'Nutrioso','Nutrioso, Arizona',33770,3);
INSERT INTO "django_geo_db_city" VALUES(27333,'Overgaard','Overgaard, Arizona',33771,3);
INSERT INTO "django_geo_db_city" VALUES(27334,'Pinedale','Pinedale, Arizona',33772,3);
INSERT INTO "django_geo_db_city" VALUES(27335,'Pinetop','Pinetop, Arizona',33773,3);
INSERT INTO "django_geo_db_city" VALUES(27336,'Saint Johns','Saint Johns, Arizona',33774,3);
INSERT INTO "django_geo_db_city" VALUES(27337,'Snowflake','Snowflake, Arizona',33775,3);
INSERT INTO "django_geo_db_city" VALUES(27338,'Springerville','Springerville, Arizona',33776,3);
INSERT INTO "django_geo_db_city" VALUES(27339,'Taylor','Taylor, Arizona',33777,3);
INSERT INTO "django_geo_db_city" VALUES(27340,'Vernon','Vernon, Arizona',33778,3);
INSERT INTO "django_geo_db_city" VALUES(27341,'Whiteriver','Whiteriver, Arizona',33779,3);
INSERT INTO "django_geo_db_city" VALUES(27342,'Woodruff','Woodruff, Arizona',33780,3);
INSERT INTO "django_geo_db_city" VALUES(27343,'Flagstaff','Flagstaff, Arizona',33781,3);
INSERT INTO "django_geo_db_city" VALUES(27344,'Bellemont','Bellemont, Arizona',33784,3);
INSERT INTO "django_geo_db_city" VALUES(27345,'Gray Mountain','Gray Mountain, Arizona',33785,3);
INSERT INTO "django_geo_db_city" VALUES(27346,'Munds Park','Munds Park, Arizona',33786,3);
INSERT INTO "django_geo_db_city" VALUES(27347,'Parks','Parks, Arizona',33787,3);
INSERT INTO "django_geo_db_city" VALUES(27348,'Cameron','Cameron, Arizona',33788,3);
INSERT INTO "django_geo_db_city" VALUES(27349,'Colorado City','Colorado City, Arizona',33789,3);
INSERT INTO "django_geo_db_city" VALUES(27350,'Fredonia','Fredonia, Arizona',33790,3);
INSERT INTO "django_geo_db_city" VALUES(27351,'Grand Canyon','Grand Canyon, Arizona',33791,3);
INSERT INTO "django_geo_db_city" VALUES(27352,'Happy Jack','Happy Jack, Arizona',33792,3);
INSERT INTO "django_geo_db_city" VALUES(27353,'Holbrook','Holbrook, Arizona',33793,3);
INSERT INTO "django_geo_db_city" VALUES(27354,'Petrified Forest Natl Pk','Petrified Forest Natl Pk, Arizona',33794,3);
INSERT INTO "django_geo_db_city" VALUES(27355,'Sun Valley','Sun Valley, Arizona',33795,3);
INSERT INTO "django_geo_db_city" VALUES(27356,'Hotevilla','Hotevilla, Arizona',33796,3);
INSERT INTO "django_geo_db_city" VALUES(27357,'Indian Wells','Indian Wells, Arizona',33797,3);
INSERT INTO "django_geo_db_city" VALUES(27358,'Joseph City','Joseph City, Arizona',33798,3);
INSERT INTO "django_geo_db_city" VALUES(27359,'Kayenta','Kayenta, Arizona',33799,3);
INSERT INTO "django_geo_db_city" VALUES(27360,'Keams Canyon','Keams Canyon, Arizona',33800,3);
INSERT INTO "django_geo_db_city" VALUES(27361,'Leupp','Leupp, Arizona',33801,3);
INSERT INTO "django_geo_db_city" VALUES(27362,'Marble Canyon','Marble Canyon, Arizona',33802,3);
INSERT INTO "django_geo_db_city" VALUES(27363,'Mormon Lake','Mormon Lake, Arizona',33803,3);
INSERT INTO "django_geo_db_city" VALUES(27364,'Kykotsmovi Village','Kykotsmovi Village, Arizona',33804,3);
INSERT INTO "django_geo_db_city" VALUES(27365,'Page','Page, Arizona',33805,3);
INSERT INTO "django_geo_db_city" VALUES(27366,'Polacca','Polacca, Arizona',33806,3);
INSERT INTO "django_geo_db_city" VALUES(27367,'Second Mesa','Second Mesa, Arizona',33807,3);
INSERT INTO "django_geo_db_city" VALUES(27368,'Tonalea','Tonalea, Arizona',33808,3);
INSERT INTO "django_geo_db_city" VALUES(27369,'Tuba City','Tuba City, Arizona',33809,3);
INSERT INTO "django_geo_db_city" VALUES(27370,'Williams','Williams, Arizona',33810,3);
INSERT INTO "django_geo_db_city" VALUES(27371,'Winslow','Winslow, Arizona',33811,3);
INSERT INTO "django_geo_db_city" VALUES(27372,'North Rim','North Rim, Arizona',33812,3);
INSERT INTO "django_geo_db_city" VALUES(27373,'Kaibito','Kaibito, Arizona',33813,3);
INSERT INTO "django_geo_db_city" VALUES(27374,'Shonto','Shonto, Arizona',33814,3);
INSERT INTO "django_geo_db_city" VALUES(27375,'Bagdad','Bagdad, Arizona',33815,3);
INSERT INTO "django_geo_db_city" VALUES(27376,'Prescott','Prescott, Arizona',33816,3);
INSERT INTO "django_geo_db_city" VALUES(27377,'Prescott Valley','Prescott Valley, Arizona',33821,3);
INSERT INTO "django_geo_db_city" VALUES(27378,'Ash Fork','Ash Fork, Arizona',33824,3);
INSERT INTO "django_geo_db_city" VALUES(27379,'Camp Verde','Camp Verde, Arizona',33826,3);
INSERT INTO "django_geo_db_city" VALUES(27380,'Chino Valley','Chino Valley, Arizona',33827,3);
INSERT INTO "django_geo_db_city" VALUES(27381,'Clarkdale','Clarkdale, Arizona',33828,3);
INSERT INTO "django_geo_db_city" VALUES(27382,'Cornville','Cornville, Arizona',33829,3);
INSERT INTO "django_geo_db_city" VALUES(27383,'Cottonwood','Cottonwood, Arizona',33830,3);
INSERT INTO "django_geo_db_city" VALUES(27384,'Dewey','Dewey, Arizona',33831,3);
INSERT INTO "django_geo_db_city" VALUES(27385,'Humboldt','Humboldt, Arizona',33832,3);
INSERT INTO "django_geo_db_city" VALUES(27386,'Iron Springs','Iron Springs, Arizona',33822,3);
INSERT INTO "django_geo_db_city" VALUES(27387,'Jerome','Jerome, Arizona',33833,3);
INSERT INTO "django_geo_db_city" VALUES(27388,'Kirkland','Kirkland, Arizona',33834,3);
INSERT INTO "django_geo_db_city" VALUES(27389,'Mayer','Mayer, Arizona',33835,3);
INSERT INTO "django_geo_db_city" VALUES(27390,'Paulden','Paulden, Arizona',33836,3);
INSERT INTO "django_geo_db_city" VALUES(27391,'Rimrock','Rimrock, Arizona',33837,3);
INSERT INTO "django_geo_db_city" VALUES(27392,'Sedona','Sedona, Arizona',33838,3);
INSERT INTO "django_geo_db_city" VALUES(27393,'Seligman','Seligman, Arizona',33839,3);
INSERT INTO "django_geo_db_city" VALUES(27394,'Skull Valley','Skull Valley, Arizona',33840,3);
INSERT INTO "django_geo_db_city" VALUES(27395,'Lake Montezuma','Lake Montezuma, Arizona',33843,3);
INSERT INTO "django_geo_db_city" VALUES(27396,'Crown King','Crown King, Arizona',33844,3);
INSERT INTO "django_geo_db_city" VALUES(27397,'Kingman','Kingman, Arizona',33849,3);
INSERT INTO "django_geo_db_city" VALUES(27398,'Lake Havasu City','Lake Havasu City, Arizona',33851,3);
INSERT INTO "django_geo_db_city" VALUES(27399,'Hackberry','Hackberry, Arizona',33853,3);
INSERT INTO "django_geo_db_city" VALUES(27400,'Hualapai','Hualapai, Arizona',33855,3);
INSERT INTO "django_geo_db_city" VALUES(27401,'Golden Valley','Golden Valley, Arizona',33856,3);
INSERT INTO "django_geo_db_city" VALUES(27402,'Bullhead City','Bullhead City, Arizona',33857,3);
INSERT INTO "django_geo_db_city" VALUES(27403,'Fort Mohave','Fort Mohave, Arizona',33858,3);
INSERT INTO "django_geo_db_city" VALUES(27404,'Chloride','Chloride, Arizona',33862,3);
INSERT INTO "django_geo_db_city" VALUES(27405,'Littlefield','Littlefield, Arizona',33863,3);
INSERT INTO "django_geo_db_city" VALUES(27406,'Oatman','Oatman, Arizona',33864,3);
INSERT INTO "django_geo_db_city" VALUES(27407,'Peach Springs','Peach Springs, Arizona',33865,3);
INSERT INTO "django_geo_db_city" VALUES(27408,'Supai','Supai, Arizona',33866,3);
INSERT INTO "django_geo_db_city" VALUES(27409,'Topock','Topock, Arizona',33867,3);
INSERT INTO "django_geo_db_city" VALUES(27410,'Valentine','Valentine, Arizona',33868,3);
INSERT INTO "django_geo_db_city" VALUES(27411,'Yucca','Yucca, Arizona',33869,3);
INSERT INTO "django_geo_db_city" VALUES(27412,'Mohave Valley','Mohave Valley, Arizona',33871,3);
INSERT INTO "django_geo_db_city" VALUES(27413,'Dolan Springs','Dolan Springs, Arizona',33872,3);
INSERT INTO "django_geo_db_city" VALUES(27414,'Temple Bar Marina','Temple Bar Marina, Arizona',33874,3);
INSERT INTO "django_geo_db_city" VALUES(27415,'Meadview','Meadview, Arizona',33875,3);
INSERT INTO "django_geo_db_city" VALUES(27416,'Willow Beach','Willow Beach, Arizona',33853,3);
INSERT INTO "django_geo_db_city" VALUES(27417,'Chambers','Chambers, Arizona',33877,3);
INSERT INTO "django_geo_db_city" VALUES(27418,'Chinle','Chinle, Arizona',33878,3);
INSERT INTO "django_geo_db_city" VALUES(27419,'Fort Defiance','Fort Defiance, Arizona',33879,3);
INSERT INTO "django_geo_db_city" VALUES(27420,'Ganado','Ganado, Arizona',33880,3);
INSERT INTO "django_geo_db_city" VALUES(27421,'Houck','Houck, Arizona',33881,3);
INSERT INTO "django_geo_db_city" VALUES(27422,'Lukachukai','Lukachukai, Arizona',33882,3);
INSERT INTO "django_geo_db_city" VALUES(27423,'Lupton','Lupton, Arizona',33883,3);
INSERT INTO "django_geo_db_city" VALUES(27424,'Pinon','Pinon, Arizona',33884,3);
INSERT INTO "django_geo_db_city" VALUES(27425,'Saint Michaels','Saint Michaels, Arizona',33885,3);
INSERT INTO "django_geo_db_city" VALUES(27426,'Sanders','Sanders, Arizona',33886,3);
INSERT INTO "django_geo_db_city" VALUES(27427,'Teec Nos Pos','Teec Nos Pos, Arizona',33887,3);
INSERT INTO "django_geo_db_city" VALUES(27428,'Window Rock','Window Rock, Arizona',33888,3);
INSERT INTO "django_geo_db_city" VALUES(27429,'Blue Gap','Blue Gap, Arizona',33889,3);
INSERT INTO "django_geo_db_city" VALUES(27430,'Dennehotso','Dennehotso, Arizona',33890,3);
INSERT INTO "django_geo_db_city" VALUES(27431,'Many Farms','Many Farms, Arizona',33891,3);
INSERT INTO "django_geo_db_city" VALUES(27432,'Nazlini','Nazlini, Arizona',33892,3);
INSERT INTO "django_geo_db_city" VALUES(27433,'Red Valley','Red Valley, Arizona',33893,3);
INSERT INTO "django_geo_db_city" VALUES(27434,'Rock Point','Rock Point, Arizona',33894,3);
INSERT INTO "django_geo_db_city" VALUES(27435,'Round Rock','Round Rock, Arizona',33895,3);
INSERT INTO "django_geo_db_city" VALUES(27436,'Sawmill','Sawmill, Arizona',33896,3);
INSERT INTO "django_geo_db_city" VALUES(27437,'Big Park','Big Park, Arizona',33897,3);
INSERT INTO "django_geo_db_city" VALUES(27438,'Tsaile','Tsaile, Arizona',33898,3);
INSERT INTO "django_geo_db_city" VALUES(27439,'Algodones','Algodones, New Mexico',33900,31);
INSERT INTO "django_geo_db_city" VALUES(27440,'Belen','Belen, New Mexico',33901,31);
INSERT INTO "django_geo_db_city" VALUES(27441,'Bernalillo','Bernalillo, New Mexico',33902,31);
INSERT INTO "django_geo_db_city" VALUES(27442,'Bluewater','Bluewater, New Mexico',33903,31);
INSERT INTO "django_geo_db_city" VALUES(27443,'Bosque','Bosque, New Mexico',33904,31);
INSERT INTO "django_geo_db_city" VALUES(27444,'Casa Blanca','Casa Blanca, New Mexico',33905,31);
INSERT INTO "django_geo_db_city" VALUES(27445,'Cedar Crest','Cedar Crest, New Mexico',33906,31);
INSERT INTO "django_geo_db_city" VALUES(27446,'Cedarvale','Cedarvale, New Mexico',33907,31);
INSERT INTO "django_geo_db_city" VALUES(27447,'Cerrillos','Cerrillos, New Mexico',33908,31);
INSERT INTO "django_geo_db_city" VALUES(27448,'Claunch','Claunch, New Mexico',33909,31);
INSERT INTO "django_geo_db_city" VALUES(27449,'Coyote','Coyote, New Mexico',33910,31);
INSERT INTO "django_geo_db_city" VALUES(27450,'Cuba','Cuba, New Mexico',33911,31);
INSERT INTO "django_geo_db_city" VALUES(27451,'Cubero','Cubero, New Mexico',33912,31);
INSERT INTO "django_geo_db_city" VALUES(27452,'Edgewood','Edgewood, New Mexico',33913,31);
INSERT INTO "django_geo_db_city" VALUES(27453,'Estancia','Estancia, New Mexico',33914,31);
INSERT INTO "django_geo_db_city" VALUES(27454,'Gallina','Gallina, New Mexico',33915,31);
INSERT INTO "django_geo_db_city" VALUES(27455,'Counselor','Counselor, New Mexico',33916,31);
INSERT INTO "django_geo_db_city" VALUES(27456,'Grants','Grants, New Mexico',33917,31);
INSERT INTO "django_geo_db_city" VALUES(27457,'Milan','Milan, New Mexico',33918,31);
INSERT INTO "django_geo_db_city" VALUES(27458,'Isleta','Isleta, New Mexico',33919,31);
INSERT INTO "django_geo_db_city" VALUES(27459,'Jarales','Jarales, New Mexico',33920,31);
INSERT INTO "django_geo_db_city" VALUES(27460,'Jemez Pueblo','Jemez Pueblo, New Mexico',33921,31);
INSERT INTO "django_geo_db_city" VALUES(27461,'Jemez Springs','Jemez Springs, New Mexico',33922,31);
INSERT INTO "django_geo_db_city" VALUES(27462,'Laguna','Laguna, New Mexico',33923,31);
INSERT INTO "django_geo_db_city" VALUES(27463,'La Jara','La Jara, New Mexico',33924,31);
INSERT INTO "django_geo_db_city" VALUES(27464,'La Joya','La Joya, New Mexico',33925,31);
INSERT INTO "django_geo_db_city" VALUES(27465,'Lindrith','Lindrith, New Mexico',33926,31);
INSERT INTO "django_geo_db_city" VALUES(27466,'Los Lunas','Los Lunas, New Mexico',33927,31);
INSERT INTO "django_geo_db_city" VALUES(27467,'McIntosh','McIntosh, New Mexico',33928,31);
INSERT INTO "django_geo_db_city" VALUES(27468,'Pueblo Of Acoma','Pueblo Of Acoma, New Mexico',33929,31);
INSERT INTO "django_geo_db_city" VALUES(27469,'Moriarty','Moriarty, New Mexico',33930,31);
INSERT INTO "django_geo_db_city" VALUES(27470,'Mountainair','Mountainair, New Mexico',33931,31);
INSERT INTO "django_geo_db_city" VALUES(27471,'Nageezi','Nageezi, New Mexico',33932,31);
INSERT INTO "django_geo_db_city" VALUES(27472,'New Laguna','New Laguna, New Mexico',33933,31);
INSERT INTO "django_geo_db_city" VALUES(27473,'Paguate','Paguate, New Mexico',33934,31);
INSERT INTO "django_geo_db_city" VALUES(27474,'Pena Blanca','Pena Blanca, New Mexico',33935,31);
INSERT INTO "django_geo_db_city" VALUES(27475,'Peralta','Peralta, New Mexico',33936,31);
INSERT INTO "django_geo_db_city" VALUES(27476,'Placitas','Placitas, New Mexico',33937,31);
INSERT INTO "django_geo_db_city" VALUES(27477,'Ponderosa','Ponderosa, New Mexico',33938,31);
INSERT INTO "django_geo_db_city" VALUES(27478,'Prewitt','Prewitt, New Mexico',33939,31);
INSERT INTO "django_geo_db_city" VALUES(27479,'Regina','Regina, New Mexico',33940,31);
INSERT INTO "django_geo_db_city" VALUES(27480,'Sandia Park','Sandia Park, New Mexico',33941,31);
INSERT INTO "django_geo_db_city" VALUES(27481,'Corrales','Corrales, New Mexico',33942,31);
INSERT INTO "django_geo_db_city" VALUES(27482,'San Fidel','San Fidel, New Mexico',33943,31);
INSERT INTO "django_geo_db_city" VALUES(27483,'San Rafael','San Rafael, New Mexico',33944,31);
INSERT INTO "django_geo_db_city" VALUES(27484,'Santo Domingo Pueblo','Santo Domingo Pueblo, New Mexico',33945,31);
INSERT INTO "django_geo_db_city" VALUES(27485,'San Ysidro','San Ysidro, New Mexico',33946,31);
INSERT INTO "django_geo_db_city" VALUES(27486,'Stanley','Stanley, New Mexico',33947,31);
INSERT INTO "django_geo_db_city" VALUES(27487,'Tajique','Tajique, New Mexico',33907,31);
INSERT INTO "django_geo_db_city" VALUES(27488,'Tijeras','Tijeras, New Mexico',33948,31);
INSERT INTO "django_geo_db_city" VALUES(27489,'Tome','Tome, New Mexico',33949,31);
INSERT INTO "django_geo_db_city" VALUES(27490,'Torreon','Torreon, New Mexico',33950,31);
INSERT INTO "django_geo_db_city" VALUES(27491,'Veguita','Veguita, New Mexico',33951,31);
INSERT INTO "django_geo_db_city" VALUES(27492,'Willard','Willard, New Mexico',33952,31);
INSERT INTO "django_geo_db_city" VALUES(27493,'Youngsville','Youngsville, New Mexico',33953,31);
INSERT INTO "django_geo_db_city" VALUES(27494,'Bosque Farms','Bosque Farms, New Mexico',33954,31);
INSERT INTO "django_geo_db_city" VALUES(27495,'Clines Corners','Clines Corners, New Mexico',33955,31);
INSERT INTO "django_geo_db_city" VALUES(27496,'Cochiti Pueblo','Cochiti Pueblo, New Mexico',33956,31);
INSERT INTO "django_geo_db_city" VALUES(27497,'Cochiti Lake','Cochiti Lake, New Mexico',33957,31);
INSERT INTO "django_geo_db_city" VALUES(27498,'Albuquerque','Albuquerque, New Mexico',33958,31);
INSERT INTO "django_geo_db_city" VALUES(27499,'Kirtland AFB','Kirtland AFB, New Mexico',33974,31);
INSERT INTO "django_geo_db_city" VALUES(27500,'Rio Rancho','Rio Rancho, New Mexico',33980,31);
INSERT INTO "django_geo_db_city" VALUES(27501,'Gallup','Gallup, New Mexico',33983,31);
INSERT INTO "django_geo_db_city" VALUES(27502,'Brimhall','Brimhall, New Mexico',33986,31);
INSERT INTO "django_geo_db_city" VALUES(27503,'Church Rock','Church Rock, New Mexico',33987,31);
INSERT INTO "django_geo_db_city" VALUES(27504,'Continental Divide','Continental Divide, New Mexico',33988,31);
INSERT INTO "django_geo_db_city" VALUES(27505,'Crownpoint','Crownpoint, New Mexico',33989,31);
INSERT INTO "django_geo_db_city" VALUES(27506,'Fence Lake','Fence Lake, New Mexico',33990,31);
INSERT INTO "django_geo_db_city" VALUES(27507,'Fort Wingate','Fort Wingate, New Mexico',33991,31);
INSERT INTO "django_geo_db_city" VALUES(27508,'Gamerco','Gamerco, New Mexico',33992,31);
INSERT INTO "django_geo_db_city" VALUES(27509,'Mentmore','Mentmore, New Mexico',33993,31);
INSERT INTO "django_geo_db_city" VALUES(27510,'Mexican Springs','Mexican Springs, New Mexico',33994,31);
INSERT INTO "django_geo_db_city" VALUES(27511,'Ramah','Ramah, New Mexico',33995,31);
INSERT INTO "django_geo_db_city" VALUES(27512,'Rehoboth','Rehoboth, New Mexico',33996,31);
INSERT INTO "django_geo_db_city" VALUES(27513,'Thoreau','Thoreau, New Mexico',33997,31);
INSERT INTO "django_geo_db_city" VALUES(27514,'Tohatchi','Tohatchi, New Mexico',33998,31);
INSERT INTO "django_geo_db_city" VALUES(27515,'Vanderwagen','Vanderwagen, New Mexico',33999,31);
INSERT INTO "django_geo_db_city" VALUES(27516,'Zuni','Zuni, New Mexico',34000,31);
INSERT INTO "django_geo_db_city" VALUES(27517,'Navajo','Navajo, Arizona',34001,3);
INSERT INTO "django_geo_db_city" VALUES(27518,'Jamestown','Jamestown, New Mexico',34002,31);
INSERT INTO "django_geo_db_city" VALUES(27519,'Pinehill','Pinehill, New Mexico',34003,31);
INSERT INTO "django_geo_db_city" VALUES(27520,'Sheep Springs','Sheep Springs, New Mexico',34004,31);
INSERT INTO "django_geo_db_city" VALUES(27521,'Smith Lake','Smith Lake, New Mexico',33984,31);
INSERT INTO "django_geo_db_city" VALUES(27522,'Yatahey','Yatahey, New Mexico',34005,31);
INSERT INTO "django_geo_db_city" VALUES(27523,'Navajo','Navajo, New Mexico',34006,31);
INSERT INTO "django_geo_db_city" VALUES(27524,'Farmington','Farmington, New Mexico',34007,31);
INSERT INTO "django_geo_db_city" VALUES(27525,'Aztec','Aztec, New Mexico',34009,31);
INSERT INTO "django_geo_db_city" VALUES(27526,'Blanco','Blanco, New Mexico',34010,31);
INSERT INTO "django_geo_db_city" VALUES(27527,'Bloomfield','Bloomfield, New Mexico',34011,31);
INSERT INTO "django_geo_db_city" VALUES(27528,'Flora Vista','Flora Vista, New Mexico',34012,31);
INSERT INTO "django_geo_db_city" VALUES(27529,'Fruitland','Fruitland, New Mexico',34013,31);
INSERT INTO "django_geo_db_city" VALUES(27530,'Kirtland','Kirtland, New Mexico',34014,31);
INSERT INTO "django_geo_db_city" VALUES(27531,'La Plata','La Plata, New Mexico',34015,31);
INSERT INTO "django_geo_db_city" VALUES(27532,'Navajo Dam','Navajo Dam, New Mexico',34016,31);
INSERT INTO "django_geo_db_city" VALUES(27533,'Shiprock','Shiprock, New Mexico',34017,31);
INSERT INTO "django_geo_db_city" VALUES(27534,'Waterflow','Waterflow, New Mexico',34018,31);
INSERT INTO "django_geo_db_city" VALUES(27535,'Newcomb','Newcomb, New Mexico',34019,31);
INSERT INTO "django_geo_db_city" VALUES(27536,'Sanostee','Sanostee, New Mexico',34020,31);
INSERT INTO "django_geo_db_city" VALUES(27537,'Santa Fe','Santa Fe, New Mexico',34022,31);
INSERT INTO "django_geo_db_city" VALUES(27538,'Abiquiu','Abiquiu, New Mexico',34030,31);
INSERT INTO "django_geo_db_city" VALUES(27539,'Alcalde','Alcalde, New Mexico',34031,31);
INSERT INTO "django_geo_db_city" VALUES(27540,'Amalia','Amalia, New Mexico',34032,31);
INSERT INTO "django_geo_db_city" VALUES(27541,'Arroyo Hondo','Arroyo Hondo, New Mexico',34033,31);
INSERT INTO "django_geo_db_city" VALUES(27542,'Arroyo Seco','Arroyo Seco, New Mexico',34034,31);
INSERT INTO "django_geo_db_city" VALUES(27543,'Canjilon','Canjilon, New Mexico',34035,31);
INSERT INTO "django_geo_db_city" VALUES(27544,'Canones','Canones, New Mexico',34036,31);
INSERT INTO "django_geo_db_city" VALUES(27545,'Carson','Carson, New Mexico',34037,31);
INSERT INTO "django_geo_db_city" VALUES(27546,'Cebolla','Cebolla, New Mexico',34038,31);
INSERT INTO "django_geo_db_city" VALUES(27547,'Cerro','Cerro, New Mexico',34039,31);
INSERT INTO "django_geo_db_city" VALUES(27548,'Chama','Chama, New Mexico',34040,31);
INSERT INTO "django_geo_db_city" VALUES(27549,'Chamisal','Chamisal, New Mexico',34041,31);
INSERT INTO "django_geo_db_city" VALUES(27550,'Chimayo','Chimayo, New Mexico',34042,31);
INSERT INTO "django_geo_db_city" VALUES(27551,'Cordova','Cordova, New Mexico',34043,31);
INSERT INTO "django_geo_db_city" VALUES(27552,'Costilla','Costilla, New Mexico',34044,31);
INSERT INTO "django_geo_db_city" VALUES(27553,'Taos Ski Valley','Taos Ski Valley, New Mexico',34045,31);
INSERT INTO "django_geo_db_city" VALUES(27554,'Dixon','Dixon, New Mexico',34046,31);
INSERT INTO "django_geo_db_city" VALUES(27555,'Dulce','Dulce, New Mexico',34047,31);
INSERT INTO "django_geo_db_city" VALUES(27556,'El Prado','El Prado, New Mexico',34048,31);
INSERT INTO "django_geo_db_city" VALUES(27557,'El Rito','El Rito, New Mexico',34049,31);
INSERT INTO "django_geo_db_city" VALUES(27558,'Embudo','Embudo, New Mexico',34050,31);
INSERT INTO "django_geo_db_city" VALUES(27559,'Espanola','Espanola, New Mexico',34051,31);
INSERT INTO "django_geo_db_city" VALUES(27560,'Glorieta','Glorieta, New Mexico',34053,31);
INSERT INTO "django_geo_db_city" VALUES(27561,'Hernandez','Hernandez, New Mexico',34054,31);
INSERT INTO "django_geo_db_city" VALUES(27562,'Ilfeld','Ilfeld, New Mexico',34055,31);
INSERT INTO "django_geo_db_city" VALUES(27563,'La Madera','La Madera, New Mexico',34056,31);
INSERT INTO "django_geo_db_city" VALUES(27564,'Lamy','Lamy, New Mexico',34057,31);
INSERT INTO "django_geo_db_city" VALUES(27565,'Llano','Llano, New Mexico',34058,31);
INSERT INTO "django_geo_db_city" VALUES(27566,'Los Alamos','Los Alamos, New Mexico',34059,31);
INSERT INTO "django_geo_db_city" VALUES(27567,'Medanales','Medanales, New Mexico',34061,31);
INSERT INTO "django_geo_db_city" VALUES(27568,'Ojo Caliente','Ojo Caliente, New Mexico',34062,31);
INSERT INTO "django_geo_db_city" VALUES(27569,'Los Ojos','Los Ojos, New Mexico',34063,31);
INSERT INTO "django_geo_db_city" VALUES(27570,'Pecos','Pecos, New Mexico',34064,31);
INSERT INTO "django_geo_db_city" VALUES(27571,'Penasco','Penasco, New Mexico',34065,31);
INSERT INTO "django_geo_db_city" VALUES(27572,'Petaca','Petaca, New Mexico',34066,31);
INSERT INTO "django_geo_db_city" VALUES(27573,'Questa','Questa, New Mexico',34067,31);
INSERT INTO "django_geo_db_city" VALUES(27574,'Ranchos De Taos','Ranchos De Taos, New Mexico',34068,31);
INSERT INTO "django_geo_db_city" VALUES(27575,'Red River','Red River, New Mexico',34069,31);
INSERT INTO "django_geo_db_city" VALUES(27576,'Ribera','Ribera, New Mexico',34070,31);
INSERT INTO "django_geo_db_city" VALUES(27577,'Rowe','Rowe, New Mexico',34071,31);
INSERT INTO "django_geo_db_city" VALUES(27578,'San Cristobal','San Cristobal, New Mexico',34072,31);
INSERT INTO "django_geo_db_city" VALUES(27579,'San Jose','San Jose, New Mexico',34073,31);
INSERT INTO "django_geo_db_city" VALUES(27580,'San Juan Pueblo','San Juan Pueblo, New Mexico',34074,31);
INSERT INTO "django_geo_db_city" VALUES(27581,'Santa Cruz','Santa Cruz, New Mexico',34075,31);
INSERT INTO "django_geo_db_city" VALUES(27582,'Serafina','Serafina, New Mexico',34076,31);
INSERT INTO "django_geo_db_city" VALUES(27583,'Taos','Taos, New Mexico',34077,31);
INSERT INTO "django_geo_db_city" VALUES(27584,'Tererro','Tererro, New Mexico',34078,31);
INSERT INTO "django_geo_db_city" VALUES(27585,'Tesuque','Tesuque, New Mexico',34079,31);
INSERT INTO "django_geo_db_city" VALUES(27586,'Tierra Amarilla','Tierra Amarilla, New Mexico',34080,31);
INSERT INTO "django_geo_db_city" VALUES(27587,'Trampas','Trampas, New Mexico',34081,31);
INSERT INTO "django_geo_db_city" VALUES(27588,'Tres Piedras','Tres Piedras, New Mexico',34082,31);
INSERT INTO "django_geo_db_city" VALUES(27589,'Truchas','Truchas, New Mexico',34083,31);
INSERT INTO "django_geo_db_city" VALUES(27590,'Vadito','Vadito, New Mexico',34084,31);
INSERT INTO "django_geo_db_city" VALUES(27591,'Valdez','Valdez, New Mexico',34085,31);
INSERT INTO "django_geo_db_city" VALUES(27592,'Vallecitos','Vallecitos, New Mexico',34086,31);
INSERT INTO "django_geo_db_city" VALUES(27593,'Velarde','Velarde, New Mexico',34087,31);
INSERT INTO "django_geo_db_city" VALUES(27594,'Villanueva','Villanueva, New Mexico',34088,31);
INSERT INTO "django_geo_db_city" VALUES(27595,'Las Vegas','Las Vegas, New Mexico',34090,31);
INSERT INTO "django_geo_db_city" VALUES(27596,'Angel Fire','Angel Fire, New Mexico',34091,31);
INSERT INTO "django_geo_db_city" VALUES(27597,'Anton Chico','Anton Chico, New Mexico',34092,31);
INSERT INTO "django_geo_db_city" VALUES(27598,'Buena Vista','Buena Vista, New Mexico',34093,31);
INSERT INTO "django_geo_db_city" VALUES(27599,'Chacon','Chacon, New Mexico',34094,31);
INSERT INTO "django_geo_db_city" VALUES(27600,'Cimarron','Cimarron, New Mexico',34095,31);
INSERT INTO "django_geo_db_city" VALUES(27601,'Cleveland','Cleveland, New Mexico',34096,31);
INSERT INTO "django_geo_db_city" VALUES(27602,'Eagle Nest','Eagle Nest, New Mexico',34097,31);
INSERT INTO "django_geo_db_city" VALUES(27603,'Guadalupita','Guadalupita, New Mexico',34098,31);
INSERT INTO "django_geo_db_city" VALUES(27604,'Holman','Holman, New Mexico',34099,31);
INSERT INTO "django_geo_db_city" VALUES(27605,'La Loma','La Loma, New Mexico',34100,31);
INSERT INTO "django_geo_db_city" VALUES(27606,'Maxwell','Maxwell, New Mexico',34101,31);
INSERT INTO "django_geo_db_city" VALUES(27607,'Miami','Miami, New Mexico',34102,31);
INSERT INTO "django_geo_db_city" VALUES(27608,'Mills','Mills, New Mexico',34103,31);
INSERT INTO "django_geo_db_city" VALUES(27609,'Montezuma','Montezuma, New Mexico',34104,31);
INSERT INTO "django_geo_db_city" VALUES(27610,'Mora','Mora, New Mexico',34105,31);
INSERT INTO "django_geo_db_city" VALUES(27611,'Mosquero','Mosquero, New Mexico',34106,31);
INSERT INTO "django_geo_db_city" VALUES(27612,'Ocate','Ocate, New Mexico',34107,31);
INSERT INTO "django_geo_db_city" VALUES(27613,'Ojo Feliz','Ojo Feliz, New Mexico',34108,31);
INSERT INTO "django_geo_db_city" VALUES(27614,'Rainsville','Rainsville, New Mexico',34109,31);
INSERT INTO "django_geo_db_city" VALUES(27615,'Raton','Raton, New Mexico',34110,31);
INSERT INTO "django_geo_db_city" VALUES(27616,'Rociada','Rociada, New Mexico',34111,31);
INSERT INTO "django_geo_db_city" VALUES(27617,'Roy','Roy, New Mexico',34112,31);
INSERT INTO "django_geo_db_city" VALUES(27618,'Sapello','Sapello, New Mexico',34113,31);
INSERT INTO "django_geo_db_city" VALUES(27619,'Solano','Solano, New Mexico',34114,31);
INSERT INTO "django_geo_db_city" VALUES(27620,'Springer','Springer, New Mexico',34115,31);
INSERT INTO "django_geo_db_city" VALUES(27621,'Ute Park','Ute Park, New Mexico',34116,31);
INSERT INTO "django_geo_db_city" VALUES(27622,'Valmora','Valmora, New Mexico',34117,31);
INSERT INTO "django_geo_db_city" VALUES(27623,'Wagon Mound','Wagon Mound, New Mexico',34118,31);
INSERT INTO "django_geo_db_city" VALUES(27624,'Watrous','Watrous, New Mexico',34119,31);
INSERT INTO "django_geo_db_city" VALUES(27625,'Socorro','Socorro, New Mexico',34120,31);
INSERT INTO "django_geo_db_city" VALUES(27626,'Aragon','Aragon, New Mexico',34121,31);
INSERT INTO "django_geo_db_city" VALUES(27627,'Datil','Datil, New Mexico',34122,31);
INSERT INTO "django_geo_db_city" VALUES(27628,'Lemitar','Lemitar, New Mexico',34123,31);
INSERT INTO "django_geo_db_city" VALUES(27629,'Luna','Luna, New Mexico',34124,31);
INSERT INTO "django_geo_db_city" VALUES(27630,'Magdalena','Magdalena, New Mexico',34125,31);
INSERT INTO "django_geo_db_city" VALUES(27631,'Pie Town','Pie Town, New Mexico',34126,31);
INSERT INTO "django_geo_db_city" VALUES(27632,'Polvadera','Polvadera, New Mexico',34127,31);
INSERT INTO "django_geo_db_city" VALUES(27633,'Quemado','Quemado, New Mexico',34128,31);
INSERT INTO "django_geo_db_city" VALUES(27634,'Reserve','Reserve, New Mexico',34129,31);
INSERT INTO "django_geo_db_city" VALUES(27635,'San Acacia','San Acacia, New Mexico',34130,31);
INSERT INTO "django_geo_db_city" VALUES(27636,'San Antonio','San Antonio, New Mexico',34131,31);
INSERT INTO "django_geo_db_city" VALUES(27637,'Truth Or Consequences','Truth Or Consequences, New Mexico',34132,31);
INSERT INTO "django_geo_db_city" VALUES(27638,'Truth or Consequences','Truth or Consequences, New Mexico',34133,31);
INSERT INTO "django_geo_db_city" VALUES(27639,'Arrey','Arrey, New Mexico',34134,31);
INSERT INTO "django_geo_db_city" VALUES(27640,'Caballo','Caballo, New Mexico',34135,31);
INSERT INTO "django_geo_db_city" VALUES(27641,'Derry','Derry, New Mexico',34136,31);
INSERT INTO "django_geo_db_city" VALUES(27642,'Elephant Butte','Elephant Butte, New Mexico',34137,31);
INSERT INTO "django_geo_db_city" VALUES(27643,'Garfield','Garfield, New Mexico',34138,31);
INSERT INTO "django_geo_db_city" VALUES(27644,'Hatch','Hatch, New Mexico',34139,31);
INSERT INTO "django_geo_db_city" VALUES(27645,'Monticello','Monticello, New Mexico',34140,31);
INSERT INTO "django_geo_db_city" VALUES(27646,'Rincon','Rincon, New Mexico',34141,31);
INSERT INTO "django_geo_db_city" VALUES(27647,'Salem','Salem, New Mexico',34142,31);
INSERT INTO "django_geo_db_city" VALUES(27648,'Williamsburg','Williamsburg, New Mexico',34143,31);
INSERT INTO "django_geo_db_city" VALUES(27649,'Winston','Winston, New Mexico',34144,31);
INSERT INTO "django_geo_db_city" VALUES(27650,'Las Cruces','Las Cruces, New Mexico',34146,31);
INSERT INTO "django_geo_db_city" VALUES(27651,'White Sands Missile Range','White Sands Missile Range, New Mexico',34147,31);
INSERT INTO "django_geo_db_city" VALUES(27652,'Santa Teresa','Santa Teresa, New Mexico',34153,31);
INSERT INTO "django_geo_db_city" VALUES(27653,'Playas','Playas, New Mexico',34154,31);
INSERT INTO "django_geo_db_city" VALUES(27654,'Sunland Park','Sunland Park, New Mexico',34157,31);
INSERT INTO "django_geo_db_city" VALUES(27655,'Animas','Animas, New Mexico',34158,31);
INSERT INTO "django_geo_db_city" VALUES(27656,'Anthony','Anthony, New Mexico',34159,31);
INSERT INTO "django_geo_db_city" VALUES(27657,'Arenas Valley','Arenas Valley, New Mexico',34160,31);
INSERT INTO "django_geo_db_city" VALUES(27658,'Bayard','Bayard, New Mexico',34161,31);
INSERT INTO "django_geo_db_city" VALUES(27659,'Berino','Berino, New Mexico',34162,31);
INSERT INTO "django_geo_db_city" VALUES(27660,'Buckhorn','Buckhorn, New Mexico',34163,31);
INSERT INTO "django_geo_db_city" VALUES(27661,'Santa Clara','Santa Clara, New Mexico',34164,31);
INSERT INTO "django_geo_db_city" VALUES(27662,'Chamberino','Chamberino, New Mexico',34165,31);
INSERT INTO "django_geo_db_city" VALUES(27663,'Cliff','Cliff, New Mexico',34166,31);
INSERT INTO "django_geo_db_city" VALUES(27664,'Columbus','Columbus, New Mexico',34167,31);
INSERT INTO "django_geo_db_city" VALUES(27665,'Deming','Deming, New Mexico',34168,31);
INSERT INTO "django_geo_db_city" VALUES(27666,'Dona Ana','Dona Ana, New Mexico',34170,31);
INSERT INTO "django_geo_db_city" VALUES(27667,'Fairacres','Fairacres, New Mexico',34171,31);
INSERT INTO "django_geo_db_city" VALUES(27668,'Faywood','Faywood, New Mexico',34172,31);
INSERT INTO "django_geo_db_city" VALUES(27669,'Fort Bayard','Fort Bayard, New Mexico',34173,31);
INSERT INTO "django_geo_db_city" VALUES(27670,'Gila','Gila, New Mexico',34174,31);
INSERT INTO "django_geo_db_city" VALUES(27671,'Glenwood','Glenwood, New Mexico',34175,31);
INSERT INTO "django_geo_db_city" VALUES(27672,'Hachita','Hachita, New Mexico',34176,31);
INSERT INTO "django_geo_db_city" VALUES(27673,'Hanover','Hanover, New Mexico',34177,31);
INSERT INTO "django_geo_db_city" VALUES(27674,'Hillsboro','Hillsboro, New Mexico',34178,31);
INSERT INTO "django_geo_db_city" VALUES(27675,'Hurley','Hurley, New Mexico',34179,31);
INSERT INTO "django_geo_db_city" VALUES(27676,'La Mesa','La Mesa, New Mexico',34180,31);
INSERT INTO "django_geo_db_city" VALUES(27677,'Lordsburg','Lordsburg, New Mexico',34181,31);
INSERT INTO "django_geo_db_city" VALUES(27678,'Mesilla','Mesilla, New Mexico',34182,31);
INSERT INTO "django_geo_db_city" VALUES(27679,'Mesilla Park','Mesilla Park, New Mexico',34183,31);
INSERT INTO "django_geo_db_city" VALUES(27680,'Mesquite','Mesquite, New Mexico',34184,31);
INSERT INTO "django_geo_db_city" VALUES(27681,'Mimbres','Mimbres, New Mexico',34185,31);
INSERT INTO "django_geo_db_city" VALUES(27682,'Mule Creek','Mule Creek, New Mexico',34186,31);
INSERT INTO "django_geo_db_city" VALUES(27683,'Organ','Organ, New Mexico',34187,31);
INSERT INTO "django_geo_db_city" VALUES(27684,'Pinos Altos','Pinos Altos, New Mexico',34188,31);
INSERT INTO "django_geo_db_city" VALUES(27685,'Radium Springs','Radium Springs, New Mexico',34189,31);
INSERT INTO "django_geo_db_city" VALUES(27686,'Redrock','Redrock, New Mexico',34190,31);
INSERT INTO "django_geo_db_city" VALUES(27687,'Rodeo','Rodeo, New Mexico',34191,31);
INSERT INTO "django_geo_db_city" VALUES(27688,'San Miguel','San Miguel, New Mexico',34192,31);
INSERT INTO "django_geo_db_city" VALUES(27689,'Silver City','Silver City, New Mexico',34193,31);
INSERT INTO "django_geo_db_city" VALUES(27690,'Tyrone','Tyrone, New Mexico',34196,31);
INSERT INTO "django_geo_db_city" VALUES(27691,'Vado','Vado, New Mexico',34197,31);
INSERT INTO "django_geo_db_city" VALUES(27692,'Chaparral','Chaparral, New Mexico',34198,31);
INSERT INTO "django_geo_db_city" VALUES(27693,'Grady','Grady, New Mexico',34200,31);
INSERT INTO "django_geo_db_city" VALUES(27694,'Clovis','Clovis, New Mexico',34201,31);
INSERT INTO "django_geo_db_city" VALUES(27695,'Cannon AFB','Cannon AFB, New Mexico',34203,31);
INSERT INTO "django_geo_db_city" VALUES(27696,'Broadview','Broadview, New Mexico',34204,31);
INSERT INTO "django_geo_db_city" VALUES(27697,'Causey','Causey, New Mexico',34205,31);
INSERT INTO "django_geo_db_city" VALUES(27698,'Crossroads','Crossroads, New Mexico',34206,31);
INSERT INTO "django_geo_db_city" VALUES(27699,'Dora','Dora, New Mexico',34207,31);
INSERT INTO "django_geo_db_city" VALUES(27700,'Elida','Elida, New Mexico',34208,31);
INSERT INTO "django_geo_db_city" VALUES(27701,'Floyd','Floyd, New Mexico',34209,31);
INSERT INTO "django_geo_db_city" VALUES(27702,'Fort Sumner','Fort Sumner, New Mexico',34210,31);
INSERT INTO "django_geo_db_city" VALUES(27703,'House','House, New Mexico',34212,31);
INSERT INTO "django_geo_db_city" VALUES(27704,'Kenna','Kenna, New Mexico',34213,31);
INSERT INTO "django_geo_db_city" VALUES(27705,'Lingo','Lingo, New Mexico',34214,31);
INSERT INTO "django_geo_db_city" VALUES(27706,'Melrose','Melrose, New Mexico',34215,31);
INSERT INTO "django_geo_db_city" VALUES(27707,'Milnesand','Milnesand, New Mexico',34216,31);
INSERT INTO "django_geo_db_city" VALUES(27708,'Pep','Pep, New Mexico',34217,31);
INSERT INTO "django_geo_db_city" VALUES(27709,'Portales','Portales, New Mexico',34218,31);
INSERT INTO "django_geo_db_city" VALUES(27710,'Rogers','Rogers, New Mexico',34219,31);
INSERT INTO "django_geo_db_city" VALUES(27711,'Saint Vrain','Saint Vrain, New Mexico',34220,31);
INSERT INTO "django_geo_db_city" VALUES(27712,'Taiban','Taiban, New Mexico',34221,31);
INSERT INTO "django_geo_db_city" VALUES(27713,'Texico','Texico, New Mexico',34222,31);
INSERT INTO "django_geo_db_city" VALUES(27714,'Yeso','Yeso, New Mexico',34223,31);
INSERT INTO "django_geo_db_city" VALUES(27715,'Roswell','Roswell, New Mexico',34224,31);
INSERT INTO "django_geo_db_city" VALUES(27716,'Artesia','Artesia, New Mexico',34227,31);
INSERT INTO "django_geo_db_city" VALUES(27717,'Caprock','Caprock, New Mexico',34229,31);
INSERT INTO "django_geo_db_city" VALUES(27718,'Carlsbad','Carlsbad, New Mexico',34230,31);
INSERT INTO "django_geo_db_city" VALUES(27719,'Dexter','Dexter, New Mexico',34232,31);
INSERT INTO "django_geo_db_city" VALUES(27720,'Eunice','Eunice, New Mexico',34233,31);
INSERT INTO "django_geo_db_city" VALUES(27721,'Hagerman','Hagerman, New Mexico',34234,31);
INSERT INTO "django_geo_db_city" VALUES(27722,'Hobbs','Hobbs, New Mexico',34235,31);
INSERT INTO "django_geo_db_city" VALUES(27723,'Hope','Hope, New Mexico',34239,31);
INSERT INTO "django_geo_db_city" VALUES(27724,'Jal','Jal, New Mexico',34240,31);
INSERT INTO "django_geo_db_city" VALUES(27725,'Lake Arthur','Lake Arthur, New Mexico',34241,31);
INSERT INTO "django_geo_db_city" VALUES(27726,'Lakewood','Lakewood, New Mexico',34242,31);
INSERT INTO "django_geo_db_city" VALUES(27727,'Loco Hills','Loco Hills, New Mexico',34243,31);
INSERT INTO "django_geo_db_city" VALUES(27728,'Loving','Loving, New Mexico',34244,31);
INSERT INTO "django_geo_db_city" VALUES(27729,'Lovington','Lovington, New Mexico',34245,31);
INSERT INTO "django_geo_db_city" VALUES(27730,'McDonald','McDonald, New Mexico',34246,31);
INSERT INTO "django_geo_db_city" VALUES(27731,'Malaga','Malaga, New Mexico',34247,31);
INSERT INTO "django_geo_db_city" VALUES(27732,'Maljamar','Maljamar, New Mexico',34248,31);
INSERT INTO "django_geo_db_city" VALUES(27733,'Monument','Monument, New Mexico',34249,31);
INSERT INTO "django_geo_db_city" VALUES(27734,'Tatum','Tatum, New Mexico',34250,31);
INSERT INTO "django_geo_db_city" VALUES(27735,'Whites City','Whites City, New Mexico',34251,31);
INSERT INTO "django_geo_db_city" VALUES(27736,'Carrizozo','Carrizozo, New Mexico',34252,31);
INSERT INTO "django_geo_db_city" VALUES(27737,'Alamogordo','Alamogordo, New Mexico',34253,31);
INSERT INTO "django_geo_db_city" VALUES(27738,'Alto','Alto, New Mexico',34255,31);
INSERT INTO "django_geo_db_city" VALUES(27739,'Bent','Bent, New Mexico',34256,31);
INSERT INTO "django_geo_db_city" VALUES(27740,'Boles Acres','Boles Acres, New Mexico',34257,31);
INSERT INTO "django_geo_db_city" VALUES(27741,'Capitan','Capitan, New Mexico',34258,31);
INSERT INTO "django_geo_db_city" VALUES(27742,'Cloudcroft','Cloudcroft, New Mexico',34259,31);
INSERT INTO "django_geo_db_city" VALUES(27743,'Corona','Corona, New Mexico',34260,31);
INSERT INTO "django_geo_db_city" VALUES(27744,'Encino','Encino, New Mexico',34261,31);
INSERT INTO "django_geo_db_city" VALUES(27745,'Fort Stanton','Fort Stanton, New Mexico',34262,31);
INSERT INTO "django_geo_db_city" VALUES(27746,'Glencoe','Glencoe, New Mexico',34263,31);
INSERT INTO "django_geo_db_city" VALUES(27747,'High Rolls Mountain Park','High Rolls Mountain Park, New Mexico',34264,31);
INSERT INTO "django_geo_db_city" VALUES(27748,'Holloman Air Force Base','Holloman Air Force Base, New Mexico',34265,31);
INSERT INTO "django_geo_db_city" VALUES(27749,'La Luz','La Luz, New Mexico',34266,31);
INSERT INTO "django_geo_db_city" VALUES(27750,'Hondo','Hondo, New Mexico',34267,31);
INSERT INTO "django_geo_db_city" VALUES(27751,'Lincoln','Lincoln, New Mexico',34269,31);
INSERT INTO "django_geo_db_city" VALUES(27752,'Mayhill','Mayhill, New Mexico',34270,31);
INSERT INTO "django_geo_db_city" VALUES(27753,'Mescalero','Mescalero, New Mexico',34271,31);
INSERT INTO "django_geo_db_city" VALUES(27754,'Nogal','Nogal, New Mexico',34272,31);
INSERT INTO "django_geo_db_city" VALUES(27755,'Orogrande','Orogrande, New Mexico',34273,31);
INSERT INTO "django_geo_db_city" VALUES(27756,'Picacho','Picacho, New Mexico',34274,31);
INSERT INTO "django_geo_db_city" VALUES(27757,'Pinon','Pinon, New Mexico',34275,31);
INSERT INTO "django_geo_db_city" VALUES(27758,'Ruidoso','Ruidoso, New Mexico',34276,31);
INSERT INTO "django_geo_db_city" VALUES(27759,'Ruidoso Downs','Ruidoso Downs, New Mexico',34277,31);
INSERT INTO "django_geo_db_city" VALUES(27760,'Sacramento','Sacramento, New Mexico',34278,31);
INSERT INTO "django_geo_db_city" VALUES(27761,'San Patricio','San Patricio, New Mexico',34279,31);
INSERT INTO "django_geo_db_city" VALUES(27762,'Sunspot','Sunspot, New Mexico',34280,31);
INSERT INTO "django_geo_db_city" VALUES(27763,'Timberon','Timberon, New Mexico',34281,31);
INSERT INTO "django_geo_db_city" VALUES(27764,'Tinnie','Tinnie, New Mexico',34282,31);
INSERT INTO "django_geo_db_city" VALUES(27765,'Tularosa','Tularosa, New Mexico',34283,31);
INSERT INTO "django_geo_db_city" VALUES(27766,'Vaughn','Vaughn, New Mexico',34284,31);
INSERT INTO "django_geo_db_city" VALUES(27767,'Weed','Weed, New Mexico',34285,31);
INSERT INTO "django_geo_db_city" VALUES(27768,'Tucumcari','Tucumcari, New Mexico',34287,31);
INSERT INTO "django_geo_db_city" VALUES(27769,'Amistad','Amistad, New Mexico',34288,31);
INSERT INTO "django_geo_db_city" VALUES(27770,'Bard','Bard, New Mexico',34289,31);
INSERT INTO "django_geo_db_city" VALUES(27771,'Capulin','Capulin, New Mexico',34290,31);
INSERT INTO "django_geo_db_city" VALUES(27772,'Clayton','Clayton, New Mexico',34291,31);
INSERT INTO "django_geo_db_city" VALUES(27773,'Conchas Dam','Conchas Dam, New Mexico',34292,31);
INSERT INTO "django_geo_db_city" VALUES(27774,'Cuervo','Cuervo, New Mexico',34293,31);
INSERT INTO "django_geo_db_city" VALUES(27775,'Des Moines','Des Moines, New Mexico',34294,31);
INSERT INTO "django_geo_db_city" VALUES(27776,'Folsom','Folsom, New Mexico',34295,31);
INSERT INTO "django_geo_db_city" VALUES(27777,'Garita','Garita, New Mexico',34296,31);
INSERT INTO "django_geo_db_city" VALUES(27778,'Gladstone','Gladstone, New Mexico',34297,31);
INSERT INTO "django_geo_db_city" VALUES(27779,'Grenville','Grenville, New Mexico',34298,31);
INSERT INTO "django_geo_db_city" VALUES(27780,'Logan','Logan, New Mexico',34299,31);
INSERT INTO "django_geo_db_city" VALUES(27781,'McAlister','McAlister, New Mexico',34300,31);
INSERT INTO "django_geo_db_city" VALUES(27782,'Mount Dora','Mount Dora, New Mexico',34301,31);
INSERT INTO "django_geo_db_city" VALUES(27783,'Nara Visa','Nara Visa, New Mexico',34302,31);
INSERT INTO "django_geo_db_city" VALUES(27784,'Newkirk','Newkirk, New Mexico',34303,31);
INSERT INTO "django_geo_db_city" VALUES(27785,'Quay','Quay, New Mexico',34304,31);
INSERT INTO "django_geo_db_city" VALUES(27786,'San Jon','San Jon, New Mexico',34305,31);
INSERT INTO "django_geo_db_city" VALUES(27787,'Santa Rosa','Santa Rosa, New Mexico',34306,31);
INSERT INTO "django_geo_db_city" VALUES(27788,'Sedan','Sedan, New Mexico',34307,31);
INSERT INTO "django_geo_db_city" VALUES(27789,'Seneca','Seneca, New Mexico',34308,31);
INSERT INTO "django_geo_db_city" VALUES(27790,'Trementina','Trementina, New Mexico',34055,31);
INSERT INTO "django_geo_db_city" VALUES(27791,'Bell Ranch','Bell Ranch, New Mexico',34055,31);
INSERT INTO "django_geo_db_city" VALUES(27792,'The Lakes','The Lakes, Nevada',34310,28);
INSERT INTO "django_geo_db_city" VALUES(27793,'Alamo','Alamo, Nevada',34312,28);
INSERT INTO "django_geo_db_city" VALUES(27794,'Beatty','Beatty, Nevada',34313,28);
INSERT INTO "django_geo_db_city" VALUES(27795,'Blue Diamond','Blue Diamond, Nevada',34314,28);
INSERT INTO "django_geo_db_city" VALUES(27796,'Boulder City','Boulder City, Nevada',34315,28);
INSERT INTO "django_geo_db_city" VALUES(27797,'Bunkerville','Bunkerville, Nevada',34316,28);
INSERT INTO "django_geo_db_city" VALUES(27798,'Caliente','Caliente, Nevada',34317,28);
INSERT INTO "django_geo_db_city" VALUES(27799,'Henderson','Henderson, Nevada',34311,28);
INSERT INTO "django_geo_db_city" VALUES(27800,'Dyer','Dyer, Nevada',34318,28);
INSERT INTO "django_geo_db_city" VALUES(27801,'Goldfield','Goldfield, Nevada',34321,28);
INSERT INTO "django_geo_db_city" VALUES(27802,'Hiko','Hiko, Nevada',34324,28);
INSERT INTO "django_geo_db_city" VALUES(27803,'Indian Springs','Indian Springs, Nevada',34325,28);
INSERT INTO "django_geo_db_city" VALUES(27804,'Jean','Jean, Nevada',34326,28);
INSERT INTO "django_geo_db_city" VALUES(27805,'Amargosa Valley','Amargosa Valley, Nevada',34327,28);
INSERT INTO "django_geo_db_city" VALUES(27806,'Logandale','Logandale, Nevada',34328,28);
INSERT INTO "django_geo_db_city" VALUES(27807,'Manhattan','Manhattan, Nevada',34329,28);
INSERT INTO "django_geo_db_city" VALUES(27808,'Mercury','Mercury, Nevada',34330,28);
INSERT INTO "django_geo_db_city" VALUES(27809,'Mesquite','Mesquite, Arizona',34331,3);
INSERT INTO "django_geo_db_city" VALUES(27810,'Moapa','Moapa, Nevada',34332,28);
INSERT INTO "django_geo_db_city" VALUES(27811,'Mesquite','Mesquite, Nevada',34333,28);
INSERT INTO "django_geo_db_city" VALUES(27812,'Laughlin','Laughlin, Nevada',34334,28);
INSERT INTO "django_geo_db_city" VALUES(27813,'North Las Vegas','North Las Vegas, Nevada',34336,28);
INSERT INTO "django_geo_db_city" VALUES(27814,'Cal Nev Ari','Cal Nev Ari, Nevada',34340,28);
INSERT INTO "django_geo_db_city" VALUES(27815,'Overton','Overton, Nevada',34341,28);
INSERT INTO "django_geo_db_city" VALUES(27816,'Pahrump','Pahrump, Nevada',34342,28);
INSERT INTO "django_geo_db_city" VALUES(27817,'Panaca','Panaca, Nevada',34343,28);
INSERT INTO "django_geo_db_city" VALUES(27818,'Pioche','Pioche, Nevada',34344,28);
INSERT INTO "django_geo_db_city" VALUES(27819,'Round Mountain','Round Mountain, Nevada',34330,28);
INSERT INTO "django_geo_db_city" VALUES(27820,'Searchlight','Searchlight, Nevada',34345,28);
INSERT INTO "django_geo_db_city" VALUES(27821,'Silverpeak','Silverpeak, Nevada',34346,28);
INSERT INTO "django_geo_db_city" VALUES(27822,'Tonopah','Tonopah, Nevada',34348,28);
INSERT INTO "django_geo_db_city" VALUES(27823,'Las Vegas','Las Vegas, Nevada',34356,28);
INSERT INTO "django_geo_db_city" VALUES(27824,'Summerlin South','Summerlin South, Nevada',34385,28);
INSERT INTO "django_geo_db_city" VALUES(27825,'Nellis AFB','Nellis AFB, Nevada',34397,28);
INSERT INTO "django_geo_db_city" VALUES(27826,'Ely','Ely, Nevada',34398,28);
INSERT INTO "django_geo_db_city" VALUES(27827,'Austin','Austin, Nevada',34399,28);
INSERT INTO "django_geo_db_city" VALUES(27828,'Baker','Baker, Nevada',34400,28);
INSERT INTO "django_geo_db_city" VALUES(27829,'Duckwater','Duckwater, Nevada',34401,28);
INSERT INTO "django_geo_db_city" VALUES(27830,'Eureka','Eureka, Nevada',34403,28);
INSERT INTO "django_geo_db_city" VALUES(27831,'Lund','Lund, Nevada',34404,28);
INSERT INTO "django_geo_db_city" VALUES(27832,'McGill','McGill, Nevada',34405,28);
INSERT INTO "django_geo_db_city" VALUES(27833,'Ruth','Ruth, Nevada',34406,28);
INSERT INTO "django_geo_db_city" VALUES(27834,'Crystal Bay','Crystal Bay, Nevada',34407,28);
INSERT INTO "django_geo_db_city" VALUES(27835,'Dayton','Dayton, Nevada',34408,28);
INSERT INTO "django_geo_db_city" VALUES(27836,'Denio','Denio, Nevada',34409,28);
INSERT INTO "django_geo_db_city" VALUES(27837,'Empire','Empire, Nevada',34410,28);
INSERT INTO "django_geo_db_city" VALUES(27838,'Fallon','Fallon, Nevada',34411,28);
INSERT INTO "django_geo_db_city" VALUES(27839,'Fernley','Fernley, Nevada',34413,28);
INSERT INTO "django_geo_db_city" VALUES(27840,'Gabbs','Gabbs, Nevada',34414,28);
INSERT INTO "django_geo_db_city" VALUES(27841,'Gardnerville','Gardnerville, Nevada',34415,28);
INSERT INTO "django_geo_db_city" VALUES(27842,'Genoa','Genoa, Nevada',34416,28);
INSERT INTO "django_geo_db_city" VALUES(27843,'Gerlach','Gerlach, Nevada',34417,28);
INSERT INTO "django_geo_db_city" VALUES(27844,'Glenbrook','Glenbrook, Nevada',34418,28);
INSERT INTO "django_geo_db_city" VALUES(27845,'Golconda','Golconda, Nevada',34419,28);
INSERT INTO "django_geo_db_city" VALUES(27846,'Hawthorne','Hawthorne, Nevada',34420,28);
INSERT INTO "django_geo_db_city" VALUES(27847,'Imlay','Imlay, Nevada',34421,28);
INSERT INTO "django_geo_db_city" VALUES(27848,'Lovelock','Lovelock, Nevada',34422,28);
INSERT INTO "django_geo_db_city" VALUES(27849,'Luning','Luning, Nevada',34423,28);
INSERT INTO "django_geo_db_city" VALUES(27850,'McDermitt','McDermitt, Nevada',34424,28);
INSERT INTO "django_geo_db_city" VALUES(27851,'Mina','Mina, Nevada',34425,28);
INSERT INTO "django_geo_db_city" VALUES(27852,'Minden','Minden, Nevada',34426,28);
INSERT INTO "django_geo_db_city" VALUES(27853,'Nixon','Nixon, Nevada',34427,28);
INSERT INTO "django_geo_db_city" VALUES(27854,'Orovada','Orovada, Nevada',34428,28);
INSERT INTO "django_geo_db_city" VALUES(27855,'Paradise Valley','Paradise Valley, Nevada',34429,28);
INSERT INTO "django_geo_db_city" VALUES(27856,'Schurz','Schurz, Nevada',34430,28);
INSERT INTO "django_geo_db_city" VALUES(27857,'Silver City','Silver City, Nevada',34431,28);
INSERT INTO "django_geo_db_city" VALUES(27858,'Silver Springs','Silver Springs, Nevada',34432,28);
INSERT INTO "django_geo_db_city" VALUES(27859,'Smith','Smith, Nevada',34433,28);
INSERT INTO "django_geo_db_city" VALUES(27860,'Sparks','Sparks, Nevada',34434,28);
INSERT INTO "django_geo_db_city" VALUES(27861,'Sun Valley','Sun Valley, Nevada',34436,28);
INSERT INTO "django_geo_db_city" VALUES(27862,'Valmy','Valmy, Nevada',34439,28);
INSERT INTO "django_geo_db_city" VALUES(27863,'Verdi','Verdi, California',34440,6);
INSERT INTO "django_geo_db_city" VALUES(27864,'Virginia City','Virginia City, Nevada',34441,28);
INSERT INTO "django_geo_db_city" VALUES(27865,'Wadsworth','Wadsworth, Nevada',34442,28);
INSERT INTO "django_geo_db_city" VALUES(27866,'Wellington','Wellington, Nevada',34443,28);
INSERT INTO "django_geo_db_city" VALUES(27867,'Winnemucca','Winnemucca, Nevada',34444,28);
INSERT INTO "django_geo_db_city" VALUES(27868,'Yerington','Yerington, Nevada',34446,28);
INSERT INTO "django_geo_db_city" VALUES(27869,'Zephyr Cove','Zephyr Cove, Nevada',34447,28);
INSERT INTO "django_geo_db_city" VALUES(27870,'Stateline','Stateline, Nevada',34448,28);
INSERT INTO "django_geo_db_city" VALUES(27871,'Incline Village','Incline Village, Nevada',34449,28);
INSERT INTO "django_geo_db_city" VALUES(27872,'Gardnerville Ranchos','Gardnerville Ranchos, Nevada',34452,28);
INSERT INTO "django_geo_db_city" VALUES(27873,'Reno','Reno, Nevada',34454,28);
INSERT INTO "django_geo_db_city" VALUES(27874,'Carson City','Carson City, Nevada',34468,28);
INSERT INTO "django_geo_db_city" VALUES(27875,'Washoe Valley','Washoe Valley, Nevada',34471,28);
INSERT INTO "django_geo_db_city" VALUES(27876,'Kingsbury','Kingsbury, Nevada',34475,28);
INSERT INTO "django_geo_db_city" VALUES(27877,'Elko','Elko, Nevada',34476,28);
INSERT INTO "django_geo_db_city" VALUES(27878,'Spring Creek','Spring Creek, Nevada',34479,28);
INSERT INTO "django_geo_db_city" VALUES(27879,'Battle Mountain','Battle Mountain, Nevada',34480,28);
INSERT INTO "django_geo_db_city" VALUES(27880,'Crescent Valley','Crescent Valley, Nevada',34481,28);
INSERT INTO "django_geo_db_city" VALUES(27881,'Carlin','Carlin, Nevada',34482,28);
INSERT INTO "django_geo_db_city" VALUES(27882,'Deeth','Deeth, Nevada',34483,28);
INSERT INTO "django_geo_db_city" VALUES(27883,'Halleck','Halleck, Nevada',34484,28);
INSERT INTO "django_geo_db_city" VALUES(27884,'Jackpot','Jackpot, Nevada',34485,28);
INSERT INTO "django_geo_db_city" VALUES(27885,'Jarbidge','Jarbidge, Nevada',34486,28);
INSERT INTO "django_geo_db_city" VALUES(27886,'Lamoille','Lamoille, Nevada',34487,28);
INSERT INTO "django_geo_db_city" VALUES(27887,'Montello','Montello, Nevada',34488,28);
INSERT INTO "django_geo_db_city" VALUES(27888,'Mountain City','Mountain City, Nevada',34489,28);
INSERT INTO "django_geo_db_city" VALUES(27889,'Owyhee','Owyhee, Nevada',34490,28);
INSERT INTO "django_geo_db_city" VALUES(27890,'Ruby Valley','Ruby Valley, Nevada',34491,28);
INSERT INTO "django_geo_db_city" VALUES(27891,'Tuscarora','Tuscarora, Nevada',34492,28);
INSERT INTO "django_geo_db_city" VALUES(27892,'Wells','Wells, Nevada',34493,28);
INSERT INTO "django_geo_db_city" VALUES(27893,'West Wendover','West Wendover, Nevada',34494,28);
INSERT INTO "django_geo_db_city" VALUES(27894,'Gerlach-Empire','Gerlach-Empire, Nevada',34495,28);
INSERT INTO "django_geo_db_city" VALUES(27895,'Los Angeles','Los Angeles, California',34496,6);
INSERT INTO "django_geo_db_city" VALUES(27896,'West Hollywood','West Hollywood, California',34556,6);
INSERT INTO "django_geo_db_city" VALUES(27897,'Bell','Bell, California',34559,6);
INSERT INTO "django_geo_db_city" VALUES(27898,'Bell Gardens','Bell Gardens, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27899,'Inglewood','Inglewood, California',34560,6);
INSERT INTO "django_geo_db_city" VALUES(27900,'Beverly Hills','Beverly Hills, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27901,'Compton','Compton, California',34564,6);
INSERT INTO "django_geo_db_city" VALUES(27902,'Culver City','Culver City, California',34567,6);
INSERT INTO "django_geo_db_city" VALUES(27903,'Downey','Downey, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27904,'El Segundo','El Segundo, California',34572,6);
INSERT INTO "django_geo_db_city" VALUES(27905,'Gardena','Gardena, California',34573,6);
INSERT INTO "django_geo_db_city" VALUES(27906,'Hawthorne','Hawthorne, California',34576,6);
INSERT INTO "django_geo_db_city" VALUES(27907,'Hermosa Beach','Hermosa Beach, California',34577,6);
INSERT INTO "django_geo_db_city" VALUES(27908,'Huntington Park','Huntington Park, California',34578,6);
INSERT INTO "django_geo_db_city" VALUES(27909,'Lawndale','Lawndale, California',34579,6);
INSERT INTO "django_geo_db_city" VALUES(27910,'Lynwood','Lynwood, California',34581,6);
INSERT INTO "django_geo_db_city" VALUES(27911,'Malibu','Malibu, California',34582,6);
INSERT INTO "django_geo_db_city" VALUES(27912,'Manhattan Beach','Manhattan Beach, California',34584,6);
INSERT INTO "django_geo_db_city" VALUES(27913,'Maywood','Maywood, California',34585,6);
INSERT INTO "django_geo_db_city" VALUES(27914,'Pacific Palisades','Pacific Palisades, California',34586,6);
INSERT INTO "django_geo_db_city" VALUES(27915,'Palos Verdes Peninsula','Palos Verdes Peninsula, California',34587,6);
INSERT INTO "django_geo_db_city" VALUES(27916,'Rancho Palos Verdes','Rancho Palos Verdes, California',34588,6);
INSERT INTO "django_geo_db_city" VALUES(27917,'Redondo Beach','Redondo Beach, California',34589,6);
INSERT INTO "django_geo_db_city" VALUES(27918,'South Gate','South Gate, California',34592,6);
INSERT INTO "django_geo_db_city" VALUES(27919,'Topanga','Topanga, California',34593,6);
INSERT INTO "django_geo_db_city" VALUES(27920,'Venice','Venice, California',34594,6);
INSERT INTO "django_geo_db_city" VALUES(27921,'Marina Del Rey','Marina Del Rey, California',34595,6);
INSERT INTO "django_geo_db_city" VALUES(27922,'Playa Del Rey','Playa Del Rey, California',34596,6);
INSERT INTO "django_geo_db_city" VALUES(27923,'Santa Monica','Santa Monica, California',34602,6);
INSERT INTO "django_geo_db_city" VALUES(27924,'Torrance','Torrance, California',34608,6);
INSERT INTO "django_geo_db_city" VALUES(27925,'Whittier','Whittier, California',34613,6);
INSERT INTO "django_geo_db_city" VALUES(27926,'Buena Park','Buena Park, California',34619,6);
INSERT INTO "django_geo_db_city" VALUES(27927,'La Palma','La Palma, California',34622,6);
INSERT INTO "django_geo_db_city" VALUES(27928,'Cypress','Cypress, California',34623,6);
INSERT INTO "django_geo_db_city" VALUES(27929,'La Habra','La Habra, California',34624,6);
INSERT INTO "django_geo_db_city" VALUES(27930,'La Mirada','La Mirada, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27931,'Montebello','Montebello, California',34627,6);
INSERT INTO "django_geo_db_city" VALUES(27932,'Norwalk','Norwalk, California',34628,6);
INSERT INTO "django_geo_db_city" VALUES(27933,'Pico Rivera','Pico Rivera, California',34629,6);
INSERT INTO "django_geo_db_city" VALUES(27934,'Santa Fe Springs','Santa Fe Springs, California',34630,6);
INSERT INTO "django_geo_db_city" VALUES(27935,'Stanton','Stanton, California',34631,6);
INSERT INTO "django_geo_db_city" VALUES(27936,'Artesia','Artesia, California',34632,6);
INSERT INTO "django_geo_db_city" VALUES(27937,'Cerritos','Cerritos, California',34633,6);
INSERT INTO "django_geo_db_city" VALUES(27938,'Avalon','Avalon, California',34634,6);
INSERT INTO "django_geo_db_city" VALUES(27939,'Bellflower','Bellflower, California',34635,6);
INSERT INTO "django_geo_db_city" VALUES(27940,'Harbor City','Harbor City, California',34636,6);
INSERT INTO "django_geo_db_city" VALUES(27941,'Lakewood','Lakewood, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27942,'Hawaiian Gardens','Hawaiian Gardens, California',34641,6);
INSERT INTO "django_geo_db_city" VALUES(27943,'Lomita','Lomita, California',34642,6);
INSERT INTO "django_geo_db_city" VALUES(27944,'Los Alamitos','Los Alamitos, California',34643,6);
INSERT INTO "django_geo_db_city" VALUES(27945,'Paramount','Paramount, California',34644,6);
INSERT INTO "django_geo_db_city" VALUES(27946,'San Pedro','San Pedro, California',34645,6);
INSERT INTO "django_geo_db_city" VALUES(27947,'Seal Beach','Seal Beach, California',34647,6);
INSERT INTO "django_geo_db_city" VALUES(27948,'Sunset Beach','Sunset Beach, California',34648,6);
INSERT INTO "django_geo_db_city" VALUES(27949,'Surfside','Surfside, California',34649,6);
INSERT INTO "django_geo_db_city" VALUES(27950,'Wilmington','Wilmington, California',34650,6);
INSERT INTO "django_geo_db_city" VALUES(27951,'Carson','Carson, California',34651,6);
INSERT INTO "django_geo_db_city" VALUES(27952,'Long Beach','Long Beach, California',34654,6);
INSERT INTO "django_geo_db_city" VALUES(27953,'Altadena','Altadena, California',34673,6);
INSERT INTO "django_geo_db_city" VALUES(27954,'Arcadia','Arcadia, California',34674,6);
INSERT INTO "django_geo_db_city" VALUES(27955,'Duarte','Duarte, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27956,'La Canada Flintridge','La Canada Flintridge, California',34677,6);
INSERT INTO "django_geo_db_city" VALUES(27957,'Monrovia','Monrovia, California',34678,6);
INSERT INTO "django_geo_db_city" VALUES(27958,'Montrose','Montrose, California',34679,6);
INSERT INTO "django_geo_db_city" VALUES(27959,'Mount Wilson','Mount Wilson, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27960,'Sierra Madre','Sierra Madre, California',34680,6);
INSERT INTO "django_geo_db_city" VALUES(27961,'South Pasadena','South Pasadena, California',34681,6);
INSERT INTO "django_geo_db_city" VALUES(27962,'Sunland','Sunland, California',34682,6);
INSERT INTO "django_geo_db_city" VALUES(27963,'Tujunga','Tujunga, California',34683,6);
INSERT INTO "django_geo_db_city" VALUES(27964,'Verdugo City','Verdugo City, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27965,'Pasadena','Pasadena, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27966,'San Marino','San Marino, California',34690,6);
INSERT INTO "django_geo_db_city" VALUES(27967,'Glendale','Glendale, California',34691,6);
INSERT INTO "django_geo_db_city" VALUES(27968,'La Crescenta','La Crescenta, California',34699,6);
INSERT INTO "django_geo_db_city" VALUES(27969,'Agoura Hills','Agoura Hills, California',34700,6);
INSERT INTO "django_geo_db_city" VALUES(27970,'Calabasas','Calabasas, California',34701,6);
INSERT INTO "django_geo_db_city" VALUES(27971,'Canoga Park','Canoga Park, California',34702,6);
INSERT INTO "django_geo_db_city" VALUES(27972,'Winnetka','Winnetka, California',34704,6);
INSERT INTO "django_geo_db_city" VALUES(27973,'West Hills','West Hills, California',34705,6);
INSERT INTO "django_geo_db_city" VALUES(27974,'Castaic','Castaic, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27975,'Chatsworth','Chatsworth, California',34706,6);
INSERT INTO "django_geo_db_city" VALUES(27976,'Encino','Encino, California',34707,6);
INSERT INTO "django_geo_db_city" VALUES(27977,'Newbury Park','Newbury Park, California',34708,6);
INSERT INTO "django_geo_db_city" VALUES(27978,'Newhall','Newhall, California',34710,6);
INSERT INTO "django_geo_db_city" VALUES(27979,'Northridge','Northridge, California',34711,6);
INSERT INTO "django_geo_db_city" VALUES(27980,'Pacoima','Pacoima, California',34714,6);
INSERT INTO "django_geo_db_city" VALUES(27981,'Reseda','Reseda, California',34715,6);
INSERT INTO "django_geo_db_city" VALUES(27982,'San Fernando','San Fernando, California',34716,6);
INSERT INTO "django_geo_db_city" VALUES(27983,'Sylmar','Sylmar, California',34717,6);
INSERT INTO "django_geo_db_city" VALUES(27984,'North Hills','North Hills, California',34718,6);
INSERT INTO "django_geo_db_city" VALUES(27985,'Granada Hills','Granada Hills, California',34719,6);
INSERT INTO "django_geo_db_city" VALUES(27986,'Mission Hills','Mission Hills, California',34720,6);
INSERT INTO "django_geo_db_city" VALUES(27987,'Santa Clarita','Santa Clarita, California',34721,6);
INSERT INTO "django_geo_db_city" VALUES(27988,'Canyon Country','Canyon Country, California',34722,6);
INSERT INTO "django_geo_db_city" VALUES(27989,'Sun Valley','Sun Valley, California',34723,6);
INSERT INTO "django_geo_db_city" VALUES(27990,'Valencia','Valencia, California',34724,6);
INSERT INTO "django_geo_db_city" VALUES(27991,'Tarzana','Tarzana, California',34726,6);
INSERT INTO "django_geo_db_city" VALUES(27992,'Thousand Oaks','Thousand Oaks, California',34708,6);
INSERT INTO "django_geo_db_city" VALUES(27993,'Westlake Village','Westlake Village, California',34708,6);
INSERT INTO "django_geo_db_city" VALUES(27994,'Woodland Hills','Woodland Hills, California',34730,6);
INSERT INTO "django_geo_db_city" VALUES(27995,'Oak Park','Oak Park, California',34732,6);
INSERT INTO "django_geo_db_city" VALUES(27996,'Stevenson Ranch','Stevenson Ranch, California',34733,6);
INSERT INTO "django_geo_db_city" VALUES(27997,'Van Nuys','Van Nuys, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(27998,'Panorama City','Panorama City, California',34738,6);
INSERT INTO "django_geo_db_city" VALUES(27999,'Sherman Oaks','Sherman Oaks, California',34739,6);
INSERT INTO "django_geo_db_city" VALUES(28000,'Burbank','Burbank, California',34745,6);
INSERT INTO "django_geo_db_city" VALUES(28001,'North Hollywood','North Hollywood, California',34750,6);
INSERT INTO "django_geo_db_city" VALUES(28002,'Studio City','Studio City, California',34752,6);
INSERT INTO "django_geo_db_city" VALUES(28003,'Valley Village','Valley Village, California',34755,6);
INSERT INTO "django_geo_db_city" VALUES(28004,'Universal City','Universal City, California',34756,6);
INSERT INTO "django_geo_db_city" VALUES(28005,'Toluca Lake','Toluca Lake, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(28006,'Alta Loma','Alta Loma, California',34758,6);
INSERT INTO "django_geo_db_city" VALUES(28007,'Azusa','Azusa, California',34759,6);
INSERT INTO "django_geo_db_city" VALUES(28008,'Baldwin Park','Baldwin Park, California',34760,6);
INSERT INTO "django_geo_db_city" VALUES(28009,'Chino','Chino, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28010,'Chino Hills','Chino Hills, California',34762,6);
INSERT INTO "django_geo_db_city" VALUES(28011,'Claremont','Claremont, California',34764,6);
INSERT INTO "django_geo_db_city" VALUES(28012,'City Of Industry','City Of Industry, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(28013,'Corona','Corona, California',34765,6);
INSERT INTO "django_geo_db_city" VALUES(28014,'Covina','Covina, California',34767,6);
INSERT INTO "django_geo_db_city" VALUES(28015,'Rancho Cucamonga','Rancho Cucamonga, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28016,'El Monte','El Monte, California',34771,6);
INSERT INTO "django_geo_db_city" VALUES(28017,'South El Monte','South El Monte, California',34773,6);
INSERT INTO "django_geo_db_city" VALUES(28018,'Glendora','Glendora, California',34776,6);
INSERT INTO "django_geo_db_city" VALUES(28019,'Guasti','Guasti, California',34778,6);
INSERT INTO "django_geo_db_city" VALUES(28020,'La Puente','La Puente, California',34779,6);
INSERT INTO "django_geo_db_city" VALUES(28021,'Hacienda Heights','Hacienda Heights, California',34780,6);
INSERT INTO "django_geo_db_city" VALUES(28022,'Rowland Heights','Rowland Heights, California',34782,6);
INSERT INTO "django_geo_db_city" VALUES(28023,'La Verne','La Verne, California',34783,6);
INSERT INTO "django_geo_db_city" VALUES(28024,'Mira Loma','Mira Loma, California',34784,6);
INSERT INTO "django_geo_db_city" VALUES(28025,'Monterey Park','Monterey Park, California',34785,6);
INSERT INTO "django_geo_db_city" VALUES(28026,'Ontario','Ontario, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28027,'Mt Baldy','Mt Baldy, California',34787,6);
INSERT INTO "django_geo_db_city" VALUES(28028,'Norco','Norco, California',34765,6);
INSERT INTO "django_geo_db_city" VALUES(28029,'Montclair','Montclair, California',34790,6);
INSERT INTO "django_geo_db_city" VALUES(28030,'Diamond Bar','Diamond Bar, California',34792,6);
INSERT INTO "django_geo_db_city" VALUES(28031,'Pomona','Pomona, California',34793,6);
INSERT INTO "django_geo_db_city" VALUES(28032,'Rosemead','Rosemead, California',34796,6);
INSERT INTO "django_geo_db_city" VALUES(28033,'San Dimas','San Dimas, California',34797,6);
INSERT INTO "django_geo_db_city" VALUES(28034,'San Gabriel','San Gabriel, California',34798,6);
INSERT INTO "django_geo_db_city" VALUES(28035,'Temple City','Temple City, California',34800,6);
INSERT INTO "django_geo_db_city" VALUES(28036,'Upland','Upland, California',34801,6);
INSERT INTO "django_geo_db_city" VALUES(28037,'Walnut','Walnut, California',34504,6);
INSERT INTO "django_geo_db_city" VALUES(28038,'West Covina','West Covina, California',34804,6);
INSERT INTO "django_geo_db_city" VALUES(28039,'Alhambra','Alhambra, California',34807,6);
INSERT INTO "django_geo_db_city" VALUES(28040,'Alpine','Alpine, California',34809,6);
INSERT INTO "django_geo_db_city" VALUES(28041,'Bonita','Bonita, California',34810,6);
INSERT INTO "django_geo_db_city" VALUES(28042,'Boulevard','Boulevard, California',34812,6);
INSERT INTO "django_geo_db_city" VALUES(28043,'Campo','Campo, California',34813,6);
INSERT INTO "django_geo_db_city" VALUES(28044,'Chula Vista','Chula Vista, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28045,'Descanso','Descanso, California',34819,6);
INSERT INTO "django_geo_db_city" VALUES(28046,'Dulzura','Dulzura, California',34820,6);
INSERT INTO "django_geo_db_city" VALUES(28047,'La Presa','La Presa, California',34821,6);
INSERT INTO "django_geo_db_city" VALUES(28048,'Guatay','Guatay, California',34822,6);
INSERT INTO "django_geo_db_city" VALUES(28049,'Imperial Beach','Imperial Beach, California',34823,6);
INSERT INTO "django_geo_db_city" VALUES(28050,'Jacumba','Jacumba, California',34824,6);
INSERT INTO "django_geo_db_city" VALUES(28051,'Jamul','Jamul, California',34825,6);
INSERT INTO "django_geo_db_city" VALUES(28052,'La Mesa','La Mesa, California',34826,6);
INSERT INTO "django_geo_db_city" VALUES(28053,'Lemon Grove','Lemon Grove, California',34828,6);
INSERT INTO "django_geo_db_city" VALUES(28054,'Lincoln Acres','Lincoln Acres, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28055,'Mount Laguna','Mount Laguna, California',34829,6);
INSERT INTO "django_geo_db_city" VALUES(28056,'National City','National City, California',34830,6);
INSERT INTO "django_geo_db_city" VALUES(28057,'Pine Valley','Pine Valley, California',34831,6);
INSERT INTO "django_geo_db_city" VALUES(28058,'Potrero','Potrero, California',34832,6);
INSERT INTO "django_geo_db_city" VALUES(28059,'Spring Valley','Spring Valley, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28060,'Tecate','Tecate, California',34835,6);
INSERT INTO "django_geo_db_city" VALUES(28061,'Carlsbad','Carlsbad, California',34836,6);
INSERT INTO "django_geo_db_city" VALUES(28062,'Bonsall','Bonsall, California',34837,6);
INSERT INTO "django_geo_db_city" VALUES(28063,'Borrego Springs','Borrego Springs, California',34838,6);
INSERT INTO "django_geo_db_city" VALUES(28064,'Cardiff By The Sea','Cardiff By The Sea, California',34839,6);
INSERT INTO "django_geo_db_city" VALUES(28065,'Del Mar','Del Mar, California',34842,6);
INSERT INTO "django_geo_db_city" VALUES(28066,'El Cajon','El Cajon, California',34843,6);
INSERT INTO "django_geo_db_city" VALUES(28067,'Encinitas','Encinitas, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28068,'Escondido','Escondido, California',34847,6);
INSERT INTO "django_geo_db_city" VALUES(28069,'Fallbrook','Fallbrook, California',34850,6);
INSERT INTO "django_geo_db_city" VALUES(28070,'Adelanto','Adelanto, California',34852,6);
INSERT INTO "django_geo_db_city" VALUES(28071,'Julian','Julian, California',34853,6);
INSERT INTO "django_geo_db_city" VALUES(28072,'La Jolla','La Jolla, California',34854,6);
INSERT INTO "django_geo_db_city" VALUES(28073,'Lakeside','Lakeside, California',34855,6);
INSERT INTO "django_geo_db_city" VALUES(28074,'Oceanside','Oceanside, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28075,'Camp Pendleton','Camp Pendleton, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28076,'Pala','Pala, California',34859,6);
INSERT INTO "django_geo_db_city" VALUES(28077,'Palomar Mountain','Palomar Mountain, California',34860,6);
INSERT INTO "django_geo_db_city" VALUES(28078,'Pauma Valley','Pauma Valley, California',34861,6);
INSERT INTO "django_geo_db_city" VALUES(28079,'Poway','Poway, California',34862,6);
INSERT INTO "django_geo_db_city" VALUES(28080,'Ramona','Ramona, California',34863,6);
INSERT INTO "django_geo_db_city" VALUES(28081,'Ranchita','Ranchita, California',34864,6);
INSERT INTO "django_geo_db_city" VALUES(28082,'Rancho Santa Fe','Rancho Santa Fe, California',34865,6);
INSERT INTO "django_geo_db_city" VALUES(28083,'San Luis Rey','San Luis Rey, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28084,'San Marcos','San Marcos, California',34866,6);
INSERT INTO "django_geo_db_city" VALUES(28085,'Santa Ysabel','Santa Ysabel, California',34867,6);
INSERT INTO "django_geo_db_city" VALUES(28086,'Santee','Santee, California',34868,6);
INSERT INTO "django_geo_db_city" VALUES(28087,'Solana Beach','Solana Beach, California',34869,6);
INSERT INTO "django_geo_db_city" VALUES(28088,'Valley Center','Valley Center, California',34871,6);
INSERT INTO "django_geo_db_city" VALUES(28089,'Vista','Vista, California',34872,6);
INSERT INTO "django_geo_db_city" VALUES(28090,'Warner Springs','Warner Springs, California',34874,6);
INSERT INTO "django_geo_db_city" VALUES(28091,'San Diego','San Diego, California',34876,6);
INSERT INTO "django_geo_db_city" VALUES(28092,'Coronado','Coronado, California',34892,6);
INSERT INTO "django_geo_db_city" VALUES(28093,'San Ysidro','San Ysidro, California',34811,6);
INSERT INTO "django_geo_db_city" VALUES(28094,'Indio','Indio, California',34920,6);
INSERT INTO "django_geo_db_city" VALUES(28095,'Indian Wells','Indian Wells, California',34922,6);
INSERT INTO "django_geo_db_city" VALUES(28096,'Palm Desert','Palm Desert, California',34923,6);
INSERT INTO "django_geo_db_city" VALUES(28097,'Banning','Banning, California',34924,6);
INSERT INTO "django_geo_db_city" VALUES(28098,'Bard','Bard, California',34925,6);
INSERT INTO "django_geo_db_city" VALUES(28099,'Beaumont','Beaumont, California',34926,6);
INSERT INTO "django_geo_db_city" VALUES(28100,'Blythe','Blythe, California',34927,6);
INSERT INTO "django_geo_db_city" VALUES(28101,'Brawley','Brawley, California',34929,6);
INSERT INTO "django_geo_db_city" VALUES(28102,'Cabazon','Cabazon, California',34930,6);
INSERT INTO "django_geo_db_city" VALUES(28103,'Calexico','Calexico, California',34931,6);
INSERT INTO "django_geo_db_city" VALUES(28104,'Calipatria','Calipatria, California',34933,6);
INSERT INTO "django_geo_db_city" VALUES(28105,'Cathedral City','Cathedral City, California',34934,6);
INSERT INTO "django_geo_db_city" VALUES(28106,'Coachella','Coachella, California',34935,6);
INSERT INTO "django_geo_db_city" VALUES(28107,'Desert Center','Desert Center, California',34936,6);
INSERT INTO "django_geo_db_city" VALUES(28108,'Desert Hot Springs','Desert Hot Springs, California',34937,6);
INSERT INTO "django_geo_db_city" VALUES(28109,'Earp','Earp, California',34939,6);
INSERT INTO "django_geo_db_city" VALUES(28110,'El Centro','El Centro, California',34940,6);
INSERT INTO "django_geo_db_city" VALUES(28111,'Heber','Heber, California',34942,6);
INSERT INTO "django_geo_db_city" VALUES(28112,'Holtville','Holtville, California',34943,6);
INSERT INTO "django_geo_db_city" VALUES(28113,'Imperial','Imperial, California',34944,6);
INSERT INTO "django_geo_db_city" VALUES(28114,'Joshua Tree','Joshua Tree, California',34945,6);
INSERT INTO "django_geo_db_city" VALUES(28115,'La Quinta','La Quinta, California',34946,6);
INSERT INTO "django_geo_db_city" VALUES(28116,'Mecca','Mecca, California',34947,6);
INSERT INTO "django_geo_db_city" VALUES(28117,'Morongo Valley','Morongo Valley, California',34948,6);
INSERT INTO "django_geo_db_city" VALUES(28118,'Niland','Niland, California',34949,6);
INSERT INTO "django_geo_db_city" VALUES(28119,'North Palm Springs','North Palm Springs, California',34950,6);
INSERT INTO "django_geo_db_city" VALUES(28120,'Ocotillo','Ocotillo, California',34951,6);
INSERT INTO "django_geo_db_city" VALUES(28121,'Palm Springs','Palm Springs, California',34954,6);
INSERT INTO "django_geo_db_city" VALUES(28122,'Palo Verde','Palo Verde, California',34957,6);
INSERT INTO "django_geo_db_city" VALUES(28123,'Parker Dam','Parker Dam, California',34958,6);
INSERT INTO "django_geo_db_city" VALUES(28124,'Pioneertown','Pioneertown, California',34959,6);
INSERT INTO "django_geo_db_city" VALUES(28125,'Rancho Mirage','Rancho Mirage, California',34960,6);
INSERT INTO "django_geo_db_city" VALUES(28126,'Seeley','Seeley, California',34962,6);
INSERT INTO "django_geo_db_city" VALUES(28127,'Thermal','Thermal, California',34963,6);
INSERT INTO "django_geo_db_city" VALUES(28128,'Salton City','Salton City, California',34964,6);
INSERT INTO "django_geo_db_city" VALUES(28129,'Thousand Palms','Thousand Palms, California',34965,6);
INSERT INTO "django_geo_db_city" VALUES(28130,'Twentynine Palms','Twentynine Palms, California',34966,6);
INSERT INTO "django_geo_db_city" VALUES(28131,'Vidal','Vidal, California',34968,6);
INSERT INTO "django_geo_db_city" VALUES(28132,'Westmorland','Westmorland, California',34969,6);
INSERT INTO "django_geo_db_city" VALUES(28133,'White Water','White Water, California',34970,6);
INSERT INTO "django_geo_db_city" VALUES(28134,'Winterhaven','Winterhaven, California',34971,6);
INSERT INTO "django_geo_db_city" VALUES(28135,'Yucca Valley','Yucca Valley, California',34972,6);
INSERT INTO "django_geo_db_city" VALUES(28136,'Landers','Landers, California',34973,6);
INSERT INTO "django_geo_db_city" VALUES(28137,'Amboy','Amboy, California',34976,6);
INSERT INTO "django_geo_db_city" VALUES(28138,'Angelus Oaks','Angelus Oaks, California',34977,6);
INSERT INTO "django_geo_db_city" VALUES(28139,'Apple Valley','Apple Valley, California',34978,6);
INSERT INTO "django_geo_db_city" VALUES(28140,'Baker','Baker, California',34980,6);
INSERT INTO "django_geo_db_city" VALUES(28141,'Fort Irwin','Fort Irwin, California',34981,6);
INSERT INTO "django_geo_db_city" VALUES(28142,'Barstow','Barstow, California',34982,6);
INSERT INTO "django_geo_db_city" VALUES(28143,'Grand Terrace','Grand Terrace, California',34984,6);
INSERT INTO "django_geo_db_city" VALUES(28144,'Big Bear City','Big Bear City, California',34985,6);
INSERT INTO "django_geo_db_city" VALUES(28145,'Big Bear Lake','Big Bear Lake, California',34986,6);
INSERT INTO "django_geo_db_city" VALUES(28146,'Bloomington','Bloomington, California',34987,6);
INSERT INTO "django_geo_db_city" VALUES(28147,'Blue Jay','Blue Jay, California',34988,6);
INSERT INTO "django_geo_db_city" VALUES(28148,'Bryn Mawr','Bryn Mawr, California',34989,6);
INSERT INTO "django_geo_db_city" VALUES(28149,'Calimesa','Calimesa, California',34990,6);
INSERT INTO "django_geo_db_city" VALUES(28150,'Cedar Glen','Cedar Glen, California',34991,6);
INSERT INTO "django_geo_db_city" VALUES(28151,'Cedarpines Park','Cedarpines Park, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28152,'Cima','Cima, California',34992,6);
INSERT INTO "django_geo_db_city" VALUES(28153,'Colton','Colton, California',34993,6);
INSERT INTO "django_geo_db_city" VALUES(28154,'Crestline','Crestline, California',34994,6);
INSERT INTO "django_geo_db_city" VALUES(28155,'Crest Park','Crest Park, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28156,'Daggett','Daggett, California',34995,6);
INSERT INTO "django_geo_db_city" VALUES(28157,'Death Valley','Death Valley, California',34996,6);
INSERT INTO "django_geo_db_city" VALUES(28158,'Phelan','Phelan, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28159,'Essex','Essex, California',34997,6);
INSERT INTO "django_geo_db_city" VALUES(28160,'Fawnskin','Fawnskin, California',34998,6);
INSERT INTO "django_geo_db_city" VALUES(28161,'Fontana','Fontana, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28162,'Ludlow','Ludlow, California',35002,6);
INSERT INTO "django_geo_db_city" VALUES(28163,'Forest Falls','Forest Falls, California',35003,6);
INSERT INTO "django_geo_db_city" VALUES(28164,'Hesperia','Hesperia, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28165,'Green Valley Lake','Green Valley Lake, California',35004,6);
INSERT INTO "django_geo_db_city" VALUES(28166,'Helendale','Helendale, California',35005,6);
INSERT INTO "django_geo_db_city" VALUES(28167,'Highland','Highland, California',35007,6);
INSERT INTO "django_geo_db_city" VALUES(28168,'Hinkley','Hinkley, California',35008,6);
INSERT INTO "django_geo_db_city" VALUES(28169,'Loma Linda','Loma Linda, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28170,'Lake Arrowhead','Lake Arrowhead, California',35009,6);
INSERT INTO "django_geo_db_city" VALUES(28171,'Lucerne Valley','Lucerne Valley, California',35011,6);
INSERT INTO "django_geo_db_city" VALUES(28172,'Lytle Creek','Lytle Creek, California',35012,6);
INSERT INTO "django_geo_db_city" VALUES(28173,'Mentone','Mentone, California',35013,6);
INSERT INTO "django_geo_db_city" VALUES(28174,'Needles','Needles, California',35014,6);
INSERT INTO "django_geo_db_city" VALUES(28175,'Nipton','Nipton, California',35015,6);
INSERT INTO "django_geo_db_city" VALUES(28176,'Newberry Springs','Newberry Springs, California',35016,6);
INSERT INTO "django_geo_db_city" VALUES(28177,'Mountain Pass','Mountain Pass, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28178,'Oro Grande','Oro Grande, California',35017,6);
INSERT INTO "django_geo_db_city" VALUES(28179,'Patton','Patton, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28180,'Pinon Hills','Pinon Hills, California',35019,6);
INSERT INTO "django_geo_db_city" VALUES(28181,'Redlands','Redlands, California',35020,6);
INSERT INTO "django_geo_db_city" VALUES(28182,'Rialto','Rialto, California',35022,6);
INSERT INTO "django_geo_db_city" VALUES(28183,'Rimforest','Rimforest, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28184,'Running Springs','Running Springs, California',35024,6);
INSERT INTO "django_geo_db_city" VALUES(28185,'Shoshone','Shoshone, California',35025,6);
INSERT INTO "django_geo_db_city" VALUES(28186,'Skyforest','Skyforest, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28187,'Sugarloaf','Sugarloaf, California',35026,6);
INSERT INTO "django_geo_db_city" VALUES(28188,'Tecopa','Tecopa, California',35027,6);
INSERT INTO "django_geo_db_city" VALUES(28189,'Twin Peaks','Twin Peaks, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28190,'Victorville','Victorville, California',35028,6);
INSERT INTO "django_geo_db_city" VALUES(28191,'Winchester','Winchester, California',35030,6);
INSERT INTO "django_geo_db_city" VALUES(28192,'Wrightwood','Wrightwood, California',35031,6);
INSERT INTO "django_geo_db_city" VALUES(28193,'Yermo','Yermo, California',35032,6);
INSERT INTO "django_geo_db_city" VALUES(28194,'Yucaipa','Yucaipa, California',35033,6);
INSERT INTO "django_geo_db_city" VALUES(28195,'San Bernardino','San Bernardino, California',35034,6);
INSERT INTO "django_geo_db_city" VALUES(28196,'Riverside','Riverside, California',35043,6);
INSERT INTO "django_geo_db_city" VALUES(28197,'March Air Force Base','March Air Force Base, California',35051,6);
INSERT INTO "django_geo_db_city" VALUES(28198,'Lake Elsinore','Lake Elsinore, California',35052,6);
INSERT INTO "django_geo_db_city" VALUES(28199,'Aguanga','Aguanga, California',35054,6);
INSERT INTO "django_geo_db_city" VALUES(28200,'Anza','Anza, California',35055,6);
INSERT INTO "django_geo_db_city" VALUES(28201,'Hemet','Hemet, California',35056,6);
INSERT INTO "django_geo_db_city" VALUES(28202,'Homeland','Homeland, California',35059,6);
INSERT INTO "django_geo_db_city" VALUES(28203,'Idyllwild','Idyllwild, California',35060,6);
INSERT INTO "django_geo_db_city" VALUES(28204,'Moreno Valley','Moreno Valley, California',35061,6);
INSERT INTO "django_geo_db_city" VALUES(28205,'Mountain Center','Mountain Center, California',35066,6);
INSERT INTO "django_geo_db_city" VALUES(28206,'Murrieta','Murrieta, California',35067,6);
INSERT INTO "django_geo_db_city" VALUES(28207,'Nuevo','Nuevo, California',35069,6);
INSERT INTO "django_geo_db_city" VALUES(28208,'Perris','Perris, California',35070,6);
INSERT INTO "django_geo_db_city" VALUES(28209,'San Jacinto','San Jacinto, California',34765,6);
INSERT INTO "django_geo_db_city" VALUES(28210,'Menifee','Menifee, California',35074,6);
INSERT INTO "django_geo_db_city" VALUES(28211,'Sun City','Sun City, California',35075,6);
INSERT INTO "django_geo_db_city" VALUES(28212,'Temecula','Temecula, California',34765,6);
INSERT INTO "django_geo_db_city" VALUES(28213,'Wildomar','Wildomar, California',35081,6);
INSERT INTO "django_geo_db_city" VALUES(28214,'Irvine','Irvine, California',35083,6);
INSERT INTO "django_geo_db_city" VALUES(28215,'Huntington Beach','Huntington Beach, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28216,'Laguna Niguel','Laguna Niguel, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28217,'Foothill Ranch','Foothill Ranch, California',35087,6);
INSERT INTO "django_geo_db_city" VALUES(28218,'Capistrano Beach','Capistrano Beach, California',35094,6);
INSERT INTO "django_geo_db_city" VALUES(28219,'Corona Del Mar','Corona Del Mar, California',35095,6);
INSERT INTO "django_geo_db_city" VALUES(28220,'Costa Mesa','Costa Mesa, California',35096,6);
INSERT INTO "django_geo_db_city" VALUES(28221,'Dana Point','Dana Point, California',35098,6);
INSERT INTO "django_geo_db_city" VALUES(28222,'Lake Forest','Lake Forest, California',35099,6);
INSERT INTO "django_geo_db_city" VALUES(28223,'Laguna Hills','Laguna Hills, California',35100,6);
INSERT INTO "django_geo_db_city" VALUES(28224,'East Irvine','East Irvine, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28225,'Laguna Beach','Laguna Beach, California',35105,6);
INSERT INTO "django_geo_db_city" VALUES(28226,'Midway City','Midway City, California',35108,6);
INSERT INTO "django_geo_db_city" VALUES(28227,'Aliso Viejo','Aliso Viejo, California',35109,6);
INSERT INTO "django_geo_db_city" VALUES(28228,'Newport Coast','Newport Coast, California',35110,6);
INSERT INTO "django_geo_db_city" VALUES(28229,'Newport Beach','Newport Beach, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28230,'Placentia','Placentia, California',35116,6);
INSERT INTO "django_geo_db_city" VALUES(28231,'San Clemente','San Clemente, California',35117,6);
INSERT INTO "django_geo_db_city" VALUES(28232,'San Juan Capistrano','San Juan Capistrano, California',35120,6);
INSERT INTO "django_geo_db_city" VALUES(28233,'Silverado','Silverado, California',35121,6);
INSERT INTO "django_geo_db_city" VALUES(28234,'Trabuco Canyon','Trabuco Canyon, California',35123,6);
INSERT INTO "django_geo_db_city" VALUES(28235,'Garden Grove','Garden Grove, California',35125,6);
INSERT INTO "django_geo_db_city" VALUES(28236,'Westminster','Westminster, California',35126,6);
INSERT INTO "django_geo_db_city" VALUES(28237,'Rancho Santa Margarita','Rancho Santa Margarita, California',35127,6);
INSERT INTO "django_geo_db_city" VALUES(28238,'Mission Viejo','Mission Viejo, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28239,'Ladera Ranch','Ladera Ranch, California',35131,6);
INSERT INTO "django_geo_db_city" VALUES(28240,'Santa Ana','Santa Ana, California',35132,6);
INSERT INTO "django_geo_db_city" VALUES(28241,'Fountain Valley','Fountain Valley, California',35138,6);
INSERT INTO "django_geo_db_city" VALUES(28242,'Tustin','Tustin, California',35140,6);
INSERT INTO "django_geo_db_city" VALUES(28243,'Anaheim','Anaheim, California',35142,6);
INSERT INTO "django_geo_db_city" VALUES(28244,'Atwood','Atwood, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28245,'Brea','Brea, California',35149,6);
INSERT INTO "django_geo_db_city" VALUES(28246,'Fullerton','Fullerton, California',35151,6);
INSERT INTO "django_geo_db_city" VALUES(28247,'Orange','Orange, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28248,'Villa Park','Villa Park, California',35161,6);
INSERT INTO "django_geo_db_city" VALUES(28249,'Yorba Linda','Yorba Linda, California',34621,6);
INSERT INTO "django_geo_db_city" VALUES(28250,'Ventura','Ventura, California',35175,6);
INSERT INTO "django_geo_db_city" VALUES(28251,'Camarillo','Camarillo, California',35179,6);
INSERT INTO "django_geo_db_city" VALUES(28252,'Carpinteria','Carpinteria, California',35181,6);
INSERT INTO "django_geo_db_city" VALUES(28253,'Fillmore','Fillmore, California',35183,6);
INSERT INTO "django_geo_db_city" VALUES(28254,'Moorpark','Moorpark, California',34708,6);
INSERT INTO "django_geo_db_city" VALUES(28255,'Oak View','Oak View, California',35185,6);
INSERT INTO "django_geo_db_city" VALUES(28256,'Ojai','Ojai, California',35186,6);
INSERT INTO "django_geo_db_city" VALUES(28257,'Oxnard','Oxnard, California',35187,6);
INSERT INTO "django_geo_db_city" VALUES(28258,'Piru','Piru, California',35191,6);
INSERT INTO "django_geo_db_city" VALUES(28259,'Port Hueneme','Port Hueneme, California',35192,6);
INSERT INTO "django_geo_db_city" VALUES(28260,'Point Mugu Nawc','Point Mugu Nawc, California',35193,6);
INSERT INTO "django_geo_db_city" VALUES(28261,'Port Hueneme Cbc Base','Port Hueneme Cbc Base, California',35194,6);
INSERT INTO "django_geo_db_city" VALUES(28262,'Santa Paula','Santa Paula, California',35195,6);
INSERT INTO "django_geo_db_city" VALUES(28263,'Simi Valley','Simi Valley, California',34708,6);
INSERT INTO "django_geo_db_city" VALUES(28264,'Brandeis','Brandeis, California',35197,6);
INSERT INTO "django_geo_db_city" VALUES(28265,'Somis','Somis, California',35199,6);
INSERT INTO "django_geo_db_city" VALUES(28266,'Summerland','Summerland, California',35200,6);
INSERT INTO "django_geo_db_city" VALUES(28267,'Santa Barbara','Santa Barbara, California',35201,6);
INSERT INTO "django_geo_db_city" VALUES(28268,'Goleta','Goleta, California',35182,6);
INSERT INTO "django_geo_db_city" VALUES(28269,'Alpaugh','Alpaugh, California',35211,6);
INSERT INTO "django_geo_db_city" VALUES(28270,'Armona','Armona, California',35212,6);
INSERT INTO "django_geo_db_city" VALUES(28271,'Arvin','Arvin, California',35213,6);
INSERT INTO "django_geo_db_city" VALUES(28272,'Avenal','Avenal, California',35214,6);
INSERT INTO "django_geo_db_city" VALUES(28273,'Bodfish','Bodfish, California',35215,6);
INSERT INTO "django_geo_db_city" VALUES(28274,'Buttonwillow','Buttonwillow, California',35216,6);
INSERT INTO "django_geo_db_city" VALUES(28275,'California Hot Springs','California Hot Springs, California',35217,6);
INSERT INTO "django_geo_db_city" VALUES(28276,'Camp Nelson','Camp Nelson, California',35218,6);
INSERT INTO "django_geo_db_city" VALUES(28277,'Coalinga','Coalinga, California',35219,6);
INSERT INTO "django_geo_db_city" VALUES(28278,'Corcoran','Corcoran, California',35220,6);
INSERT INTO "django_geo_db_city" VALUES(28279,'Delano','Delano, California',35221,6);
INSERT INTO "django_geo_db_city" VALUES(28280,'Earlimart','Earlimart, California',35223,6);
INSERT INTO "django_geo_db_city" VALUES(28281,'Ducor','Ducor, California',35224,6);
INSERT INTO "django_geo_db_city" VALUES(28282,'Edison','Edison, California',35226,6);
INSERT INTO "django_geo_db_city" VALUES(28283,'Exeter','Exeter, California',35227,6);
INSERT INTO "django_geo_db_city" VALUES(28284,'Frazier Park','Frazier Park, California',35228,6);
INSERT INTO "django_geo_db_city" VALUES(28285,'Farmersville','Farmersville, California',35229,6);
INSERT INTO "django_geo_db_city" VALUES(28286,'Fellows','Fellows, California',35230,6);
INSERT INTO "django_geo_db_city" VALUES(28287,'Glennville','Glennville, California',35232,6);
INSERT INTO "django_geo_db_city" VALUES(28288,'Goshen','Goshen, California',35233,6);
INSERT INTO "django_geo_db_city" VALUES(28289,'Hanford','Hanford, California',35234,6);
INSERT INTO "django_geo_db_city" VALUES(28290,'Huron','Huron, California',35236,6);
INSERT INTO "django_geo_db_city" VALUES(28291,'Ivanhoe','Ivanhoe, California',35237,6);
INSERT INTO "django_geo_db_city" VALUES(28292,'Kaweah','Kaweah, California',35238,6);
INSERT INTO "django_geo_db_city" VALUES(28293,'Kernville','Kernville, California',35239,6);
INSERT INTO "django_geo_db_city" VALUES(28294,'Kettleman City','Kettleman City, California',35240,6);
INSERT INTO "django_geo_db_city" VALUES(28295,'Lake Isabella','Lake Isabella, California',35241,6);
INSERT INTO "django_geo_db_city" VALUES(28296,'Lamont','Lamont, California',35242,6);
INSERT INTO "django_geo_db_city" VALUES(28297,'Laton','Laton, California',35243,6);
INSERT INTO "django_geo_db_city" VALUES(28298,'Lebec','Lebec, California',35244,6);
INSERT INTO "django_geo_db_city" VALUES(28299,'Lemon Cove','Lemon Cove, California',35245,6);
INSERT INTO "django_geo_db_city" VALUES(28300,'Lemoore','Lemoore, California',35246,6);
INSERT INTO "django_geo_db_city" VALUES(28301,'Lindsay','Lindsay, California',35247,6);
INSERT INTO "django_geo_db_city" VALUES(28302,'Lost Hills','Lost Hills, California',35248,6);
INSERT INTO "django_geo_db_city" VALUES(28303,'McFarland','McFarland, California',35249,6);
INSERT INTO "django_geo_db_city" VALUES(28304,'McKittrick','McKittrick, California',35250,6);
INSERT INTO "django_geo_db_city" VALUES(28305,'Maricopa','Maricopa, California',35251,6);
INSERT INTO "django_geo_db_city" VALUES(28306,'New Cuyama','New Cuyama, California',35252,6);
INSERT INTO "django_geo_db_city" VALUES(28307,'Onyx','Onyx, California',35253,6);
INSERT INTO "django_geo_db_city" VALUES(28308,'Pixley','Pixley, California',35254,6);
INSERT INTO "django_geo_db_city" VALUES(28309,'Porterville','Porterville, California',35255,6);
INSERT INTO "django_geo_db_city" VALUES(28310,'Posey','Posey, California',35257,6);
INSERT INTO "django_geo_db_city" VALUES(28311,'Richgrove','Richgrove, California',35258,6);
INSERT INTO "django_geo_db_city" VALUES(28312,'Sequoia National Park','Sequoia National Park, California',35259,6);
INSERT INTO "django_geo_db_city" VALUES(28313,'Shafter','Shafter, California',35260,6);
INSERT INTO "django_geo_db_city" VALUES(28314,'Springville','Springville, California',35261,6);
INSERT INTO "django_geo_db_city" VALUES(28315,'Stratford','Stratford, California',35262,6);
INSERT INTO "django_geo_db_city" VALUES(28316,'Strathmore','Strathmore, California',35263,6);
INSERT INTO "django_geo_db_city" VALUES(28317,'Taft','Taft, California',35264,6);
INSERT INTO "django_geo_db_city" VALUES(28318,'Terra Bella','Terra Bella, California',35265,6);
INSERT INTO "django_geo_db_city" VALUES(28319,'Three Rivers','Three Rivers, California',35266,6);
INSERT INTO "django_geo_db_city" VALUES(28320,'Tipton','Tipton, California',35267,6);
INSERT INTO "django_geo_db_city" VALUES(28321,'Tulare','Tulare, California',35268,6);
INSERT INTO "django_geo_db_city" VALUES(28322,'Tupman','Tupman, California',35270,6);
INSERT INTO "django_geo_db_city" VALUES(28323,'Visalia','Visalia, California',35271,6);
INSERT INTO "django_geo_db_city" VALUES(28324,'Wasco','Wasco, California',35274,6);
INSERT INTO "django_geo_db_city" VALUES(28325,'Waukena','Waukena, California',35275,6);
INSERT INTO "django_geo_db_city" VALUES(28326,'Weldon','Weldon, California',35276,6);
INSERT INTO "django_geo_db_city" VALUES(28327,'Wofford Heights','Wofford Heights, California',35277,6);
INSERT INTO "django_geo_db_city" VALUES(28328,'Woodlake','Woodlake, California',35278,6);
INSERT INTO "django_geo_db_city" VALUES(28329,'Woody','Woody, California',35279,6);
INSERT INTO "django_geo_db_city" VALUES(28330,'Bakersfield','Bakersfield, California',35282,6);
INSERT INTO "django_geo_db_city" VALUES(28331,'Lake of the Woods','Lake of the Woods, California',35293,6);
INSERT INTO "django_geo_db_city" VALUES(28332,'San Luis Obispo','San Luis Obispo, California',35294,6);
INSERT INTO "django_geo_db_city" VALUES(28333,'Los Osos','Los Osos, California',35295,6);
INSERT INTO "django_geo_db_city" VALUES(28334,'Arroyo Grande','Arroyo Grande, California',35299,6);
INSERT INTO "django_geo_db_city" VALUES(28335,'Atascadero','Atascadero, California',35300,6);
INSERT INTO "django_geo_db_city" VALUES(28336,'Avila Beach','Avila Beach, California',35302,6);
INSERT INTO "django_geo_db_city" VALUES(28337,'Bradley','Bradley, California',35303,6);
INSERT INTO "django_geo_db_city" VALUES(28338,'Buellton','Buellton, California',35304,6);
INSERT INTO "django_geo_db_city" VALUES(28339,'Cambria','Cambria, California',35305,6);
INSERT INTO "django_geo_db_city" VALUES(28340,'Casmalia','Casmalia, California',35306,6);
INSERT INTO "django_geo_db_city" VALUES(28341,'Cayucos','Cayucos, California',35307,6);
INSERT INTO "django_geo_db_city" VALUES(28342,'Creston','Creston, California',35308,6);
INSERT INTO "django_geo_db_city" VALUES(28343,'Grover Beach','Grover Beach, California',35309,6);
INSERT INTO "django_geo_db_city" VALUES(28344,'Guadalupe','Guadalupe, California',35310,6);
INSERT INTO "django_geo_db_city" VALUES(28345,'Harmony','Harmony, California',35311,6);
INSERT INTO "django_geo_db_city" VALUES(28346,'Lompoc','Lompoc, California',35312,6);
INSERT INTO "django_geo_db_city" VALUES(28347,'Los Alamos','Los Alamos, California',35314,6);
INSERT INTO "django_geo_db_city" VALUES(28348,'Los Olivos','Los Olivos, California',35315,6);
INSERT INTO "django_geo_db_city" VALUES(28349,'Morro Bay','Morro Bay, California',35316,6);
INSERT INTO "django_geo_db_city" VALUES(28350,'Nipomo','Nipomo, California',35317,6);
INSERT INTO "django_geo_db_city" VALUES(28351,'Oceano','Oceano, California',35318,6);
INSERT INTO "django_geo_db_city" VALUES(28352,'Paso Robles','Paso Robles, California',35319,6);
INSERT INTO "django_geo_db_city" VALUES(28353,'Pismo Beach','Pismo Beach, California',35296,6);
INSERT INTO "django_geo_db_city" VALUES(28354,'San Ardo','San Ardo, California',35322,6);
INSERT INTO "django_geo_db_city" VALUES(28355,'San Miguel','San Miguel, California',35323,6);
INSERT INTO "django_geo_db_city" VALUES(28356,'San Simeon','San Simeon, California',35324,6);
INSERT INTO "django_geo_db_city" VALUES(28357,'Santa Margarita','Santa Margarita, California',35325,6);
INSERT INTO "django_geo_db_city" VALUES(28358,'Santa Maria','Santa Maria, California',35326,6);
INSERT INTO "django_geo_db_city" VALUES(28359,'Santa Ynez','Santa Ynez, California',35331,6);
INSERT INTO "django_geo_db_city" VALUES(28360,'Shandon','Shandon, California',35332,6);
INSERT INTO "django_geo_db_city" VALUES(28361,'Solvang','Solvang, California',35333,6);
INSERT INTO "django_geo_db_city" VALUES(28362,'Templeton','Templeton, California',35335,6);
INSERT INTO "django_geo_db_city" VALUES(28363,'Mojave','Mojave, California',35337,6);
INSERT INTO "django_geo_db_city" VALUES(28364,'California City','California City, California',35339,6);
INSERT INTO "django_geo_db_city" VALUES(28365,'Acton','Acton, California',35341,6);
INSERT INTO "django_geo_db_city" VALUES(28366,'Benton','Benton, California',35342,6);
INSERT INTO "django_geo_db_city" VALUES(28367,'Big Pine','Big Pine, California',35343,6);
INSERT INTO "django_geo_db_city" VALUES(28368,'Bishop','Bishop, California',35344,6);
INSERT INTO "django_geo_db_city" VALUES(28369,'Boron','Boron, California',35346,6);
INSERT INTO "django_geo_db_city" VALUES(28370,'Bridgeport','Bridgeport, California',35347,6);
INSERT INTO "django_geo_db_city" VALUES(28371,'Caliente','Caliente, California',35348,6);
INSERT INTO "django_geo_db_city" VALUES(28372,'Cantil','Cantil, California',35349,6);
INSERT INTO "django_geo_db_city" VALUES(28373,'Darwin','Darwin, California',35350,6);
INSERT INTO "django_geo_db_city" VALUES(28374,'Edwards','Edwards, California',35351,6);
INSERT INTO "django_geo_db_city" VALUES(28375,'Independence','Independence, California',35352,6);
INSERT INTO "django_geo_db_city" VALUES(28376,'Inyokern','Inyokern, California',35353,6);
INSERT INTO "django_geo_db_city" VALUES(28377,'Johannesburg','Johannesburg, California',35354,6);
INSERT INTO "django_geo_db_city" VALUES(28378,'June Lake','June Lake, California',35355,6);
INSERT INTO "django_geo_db_city" VALUES(28379,'Keeler','Keeler, California',35356,6);
INSERT INTO "django_geo_db_city" VALUES(28380,'Keene','Keene, California',35357,6);
INSERT INTO "django_geo_db_city" VALUES(28381,'Lake Hughes','Lake Hughes, California',35358,6);
INSERT INTO "django_geo_db_city" VALUES(28382,'Lancaster','Lancaster, California',35359,6);
INSERT INTO "django_geo_db_city" VALUES(28383,'Lee Vining','Lee Vining, California',35363,6);
INSERT INTO "django_geo_db_city" VALUES(28384,'Little Lake','Little Lake, California',35345,6);
INSERT INTO "django_geo_db_city" VALUES(28385,'Littlerock','Littlerock, California',35364,6);
INSERT INTO "django_geo_db_city" VALUES(28386,'Llano','Llano, California',35365,6);
INSERT INTO "django_geo_db_city" VALUES(28387,'Lone Pine','Lone Pine, California',35366,6);
INSERT INTO "django_geo_db_city" VALUES(28388,'Mammoth Lakes','Mammoth Lakes, California',35367,6);
INSERT INTO "django_geo_db_city" VALUES(28389,'Olancha','Olancha, California',35368,6);
INSERT INTO "django_geo_db_city" VALUES(28390,'Palmdale','Palmdale, California',35369,6);
INSERT INTO "django_geo_db_city" VALUES(28391,'Pearblossom','Pearblossom, California',35372,6);
INSERT INTO "django_geo_db_city" VALUES(28392,'Randsburg','Randsburg, California',35373,6);
INSERT INTO "django_geo_db_city" VALUES(28393,'Ridgecrest','Ridgecrest, California',35374,6);
INSERT INTO "django_geo_db_city" VALUES(28394,'Red Mountain','Red Mountain, California',34761,6);
INSERT INTO "django_geo_db_city" VALUES(28395,'Rosamond','Rosamond, California',35375,6);
INSERT INTO "django_geo_db_city" VALUES(28396,'Tehachapi','Tehachapi, California',35376,6);
INSERT INTO "django_geo_db_city" VALUES(28397,'Trona','Trona, California',35377,6);
INSERT INTO "django_geo_db_city" VALUES(28398,'Valyermo','Valyermo, California',35378,6);
INSERT INTO "django_geo_db_city" VALUES(28399,'Ahwahnee','Ahwahnee, California',35381,6);
INSERT INTO "django_geo_db_city" VALUES(28400,'Auberry','Auberry, California',35382,6);
INSERT INTO "django_geo_db_city" VALUES(28401,'Badger','Badger, California',35383,6);
INSERT INTO "django_geo_db_city" VALUES(28402,'Bass Lake','Bass Lake, California',35384,6);
INSERT INTO "django_geo_db_city" VALUES(28403,'Big Creek','Big Creek, California',35385,6);
INSERT INTO "django_geo_db_city" VALUES(28404,'Biola','Biola, California',35386,6);
INSERT INTO "django_geo_db_city" VALUES(28405,'Burrel','Burrel, California',35387,6);
INSERT INTO "django_geo_db_city" VALUES(28406,'Cantua Creek','Cantua Creek, California',35388,6);
INSERT INTO "django_geo_db_city" VALUES(28407,'Caruthers','Caruthers, California',35389,6);
INSERT INTO "django_geo_db_city" VALUES(28408,'Chowchilla','Chowchilla, California',35390,6);
INSERT INTO "django_geo_db_city" VALUES(28409,'Clovis','Clovis, California',35391,6);
INSERT INTO "django_geo_db_city" VALUES(28410,'Coarsegold','Coarsegold, California',35394,6);
INSERT INTO "django_geo_db_city" VALUES(28411,'Cutler','Cutler, California',35395,6);
INSERT INTO "django_geo_db_city" VALUES(28412,'Del Rey','Del Rey, California',35396,6);
INSERT INTO "django_geo_db_city" VALUES(28413,'Dinuba','Dinuba, California',35397,6);
INSERT INTO "django_geo_db_city" VALUES(28414,'Dos Palos','Dos Palos, California',35398,6);
INSERT INTO "django_geo_db_city" VALUES(28415,'Dunlap','Dunlap, California',35399,6);
INSERT INTO "django_geo_db_city" VALUES(28416,'Firebaugh','Firebaugh, California',35400,6);
INSERT INTO "django_geo_db_city" VALUES(28417,'Fish Camp','Fish Camp, California',35401,6);
INSERT INTO "django_geo_db_city" VALUES(28418,'Five Points','Five Points, California',35402,6);
INSERT INTO "django_geo_db_city" VALUES(28419,'Fowler','Fowler, California',35403,6);
INSERT INTO "django_geo_db_city" VALUES(28420,'Friant','Friant, California',35404,6);
INSERT INTO "django_geo_db_city" VALUES(28421,'Helm','Helm, California',35405,6);
INSERT INTO "django_geo_db_city" VALUES(28422,'Hume','Hume, California',35406,6);
INSERT INTO "django_geo_db_city" VALUES(28423,'Kerman','Kerman, California',35407,6);
INSERT INTO "django_geo_db_city" VALUES(28424,'Kingsburg','Kingsburg, California',35408,6);
INSERT INTO "django_geo_db_city" VALUES(28425,'Kings Canyon National Pk','Kings Canyon National Pk, California',35409,6);
INSERT INTO "django_geo_db_city" VALUES(28426,'Lakeshore','Lakeshore, California',35410,6);
INSERT INTO "django_geo_db_city" VALUES(28427,'Los Banos','Los Banos, California',35411,6);
INSERT INTO "django_geo_db_city" VALUES(28428,'Madera','Madera, California',35412,6);
INSERT INTO "django_geo_db_city" VALUES(28429,'Mendota','Mendota, California',35415,6);
INSERT INTO "django_geo_db_city" VALUES(28430,'Miramonte','Miramonte, California',35416,6);
INSERT INTO "django_geo_db_city" VALUES(28431,'Mono Hot Springs','Mono Hot Springs, California',35417,6);
INSERT INTO "django_geo_db_city" VALUES(28432,'North Fork','North Fork, California',35418,6);
INSERT INTO "django_geo_db_city" VALUES(28433,'Oakhurst','Oakhurst, California',35419,6);
INSERT INTO "django_geo_db_city" VALUES(28434,'O Neals','O Neals, California',35420,6);
INSERT INTO "django_geo_db_city" VALUES(28435,'Orange Cove','Orange Cove, California',35421,6);
INSERT INTO "django_geo_db_city" VALUES(28436,'Orosi','Orosi, California',35422,6);
INSERT INTO "django_geo_db_city" VALUES(28437,'Parlier','Parlier, California',35423,6);
INSERT INTO "django_geo_db_city" VALUES(28438,'Piedra','Piedra, California',35424,6);
INSERT INTO "django_geo_db_city" VALUES(28439,'Fresno','Fresno, California',35425,6);
INSERT INTO "django_geo_db_city" VALUES(28440,'Prather','Prather, California',35426,6);
INSERT INTO "django_geo_db_city" VALUES(28441,'Raisin','Raisin, California',35427,6);
INSERT INTO "django_geo_db_city" VALUES(28442,'Raymond','Raymond, California',35428,6);
INSERT INTO "django_geo_db_city" VALUES(28443,'Reedley','Reedley, California',35429,6);
INSERT INTO "django_geo_db_city" VALUES(28444,'Riverdale','Riverdale, California',35430,6);
INSERT INTO "django_geo_db_city" VALUES(28445,'Sanger','Sanger, California',35431,6);
INSERT INTO "django_geo_db_city" VALUES(28446,'San Joaquin','San Joaquin, California',35432,6);
INSERT INTO "django_geo_db_city" VALUES(28447,'Santa Rita Park','Santa Rita Park, California',35433,6);
INSERT INTO "django_geo_db_city" VALUES(28448,'Selma','Selma, California',35434,6);
INSERT INTO "django_geo_db_city" VALUES(28449,'Shaver Lake','Shaver Lake, California',35435,6);
INSERT INTO "django_geo_db_city" VALUES(28450,'South Dos Palos','South Dos Palos, California',35436,6);
INSERT INTO "django_geo_db_city" VALUES(28451,'Sultana','Sultana, California',35437,6);
INSERT INTO "django_geo_db_city" VALUES(28452,'Tollhouse','Tollhouse, California',35438,6);
INSERT INTO "django_geo_db_city" VALUES(28453,'Tranquillity','Tranquillity, California',35439,6);
INSERT INTO "django_geo_db_city" VALUES(28454,'Wishon','Wishon, California',35440,6);
INSERT INTO "django_geo_db_city" VALUES(28455,'Yettem','Yettem, California',35441,6);
INSERT INTO "django_geo_db_city" VALUES(28456,'Traver','Traver, California',35442,6);
INSERT INTO "django_geo_db_city" VALUES(28457,'Squaw Valley','Squaw Valley, California',35443,6);
INSERT INTO "django_geo_db_city" VALUES(28458,'Salinas','Salinas, California',35461,6);
INSERT INTO "django_geo_db_city" VALUES(28459,'Big Sur','Big Sur, California',35467,6);
INSERT INTO "django_geo_db_city" VALUES(28460,'Carmel','Carmel, California',35468,6);
INSERT INTO "django_geo_db_city" VALUES(28461,'Carmel Valley','Carmel Valley, California',35471,6);
INSERT INTO "django_geo_db_city" VALUES(28462,'Chualar','Chualar, California',35472,6);
INSERT INTO "django_geo_db_city" VALUES(28463,'Gonzales','Gonzales, California',35473,6);
INSERT INTO "django_geo_db_city" VALUES(28464,'Greenfield','Greenfield, California',35474,6);
INSERT INTO "django_geo_db_city" VALUES(28465,'Jolon','Jolon, California',35475,6);
INSERT INTO "django_geo_db_city" VALUES(28466,'King City','King City, California',35476,6);
INSERT INTO "django_geo_db_city" VALUES(28467,'Lockwood','Lockwood, California',35477,6);
INSERT INTO "django_geo_db_city" VALUES(28468,'Marina','Marina, California',35478,6);
INSERT INTO "django_geo_db_city" VALUES(28469,'Monterey','Monterey, California',35479,6);
INSERT INTO "django_geo_db_city" VALUES(28470,'Pacific Grove','Pacific Grove, California',35481,6);
INSERT INTO "django_geo_db_city" VALUES(28471,'Pebble Beach','Pebble Beach, California',35482,6);
INSERT INTO "django_geo_db_city" VALUES(28472,'San Lucas','San Lucas, California',35483,6);
INSERT INTO "django_geo_db_city" VALUES(28473,'Seaside','Seaside, California',35484,6);
INSERT INTO "django_geo_db_city" VALUES(28474,'Soledad','Soledad, California',35485,6);
INSERT INTO "django_geo_db_city" VALUES(28475,'Spreckels','Spreckels, California',35486,6);
INSERT INTO "django_geo_db_city" VALUES(28476,'Belmont','Belmont, California',35487,6);
INSERT INTO "django_geo_db_city" VALUES(28477,'Brisbane','Brisbane, California',35489,6);
INSERT INTO "django_geo_db_city" VALUES(28478,'Burlingame','Burlingame, California',35490,6);
INSERT INTO "django_geo_db_city" VALUES(28479,'Daly City','Daly City, California',35491,6);
INSERT INTO "django_geo_db_city" VALUES(28480,'El Granada','El Granada, California',35493,6);
INSERT INTO "django_geo_db_city" VALUES(28481,'Half Moon Bay','Half Moon Bay, California',35494,6);
INSERT INTO "django_geo_db_city" VALUES(28482,'La Honda','La Honda, California',35495,6);
INSERT INTO "django_geo_db_city" VALUES(28483,'Loma Mar','Loma Mar, California',35496,6);
INSERT INTO "django_geo_db_city" VALUES(28484,'Los Altos','Los Altos, California',35497,6);
INSERT INTO "django_geo_db_city" VALUES(28485,'Menlo Park','Menlo Park, California',35500,6);
INSERT INTO "django_geo_db_city" VALUES(28486,'Atherton','Atherton, California',35501,6);
INSERT INTO "django_geo_db_city" VALUES(28487,'Portola Valley','Portola Valley, California',35502,6);
INSERT INTO "django_geo_db_city" VALUES(28488,'Millbrae','Millbrae, California',35503,6);
INSERT INTO "django_geo_db_city" VALUES(28489,'Mountain View','Mountain View, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28490,'Montara','Montara, California',35504,6);
INSERT INTO "django_geo_db_city" VALUES(28491,'Moss Beach','Moss Beach, California',35505,6);
INSERT INTO "django_geo_db_city" VALUES(28492,'Pacifica','Pacifica, California',35509,6);
INSERT INTO "django_geo_db_city" VALUES(28493,'Redwood City','Redwood City, California',35488,6);
INSERT INTO "django_geo_db_city" VALUES(28494,'Pescadero','Pescadero, California',35510,6);
INSERT INTO "django_geo_db_city" VALUES(28495,'San Bruno','San Bruno, California',35515,6);
INSERT INTO "django_geo_db_city" VALUES(28496,'San Carlos','San Carlos, California',35516,6);
INSERT INTO "django_geo_db_city" VALUES(28497,'San Gregorio','San Gregorio, California',35517,6);
INSERT INTO "django_geo_db_city" VALUES(28498,'South San Francisco','South San Francisco, California',35518,6);
INSERT INTO "django_geo_db_city" VALUES(28499,'Sunnyvale','Sunnyvale, California',35519,6);
INSERT INTO "django_geo_db_city" VALUES(28500,'San Francisco','San Francisco, California',35523,6);
INSERT INTO "django_geo_db_city" VALUES(28501,'Sacramento','Sacramento, California',35552,6);
INSERT INTO "django_geo_db_city" VALUES(28502,'Palo Alto','Palo Alto, California',35554,6);
INSERT INTO "django_geo_db_city" VALUES(28503,'Stanford','Stanford, California',35557,6);
INSERT INTO "django_geo_db_city" VALUES(28504,'San Mateo','San Mateo, California',35559,6);
INSERT INTO "django_geo_db_city" VALUES(28505,'Foster City','Foster City, California',35563,6);
INSERT INTO "django_geo_db_city" VALUES(28506,'Alameda','Alameda, California',35565,6);
INSERT INTO "django_geo_db_city" VALUES(28507,'American Canyon','American Canyon, California',35567,6);
INSERT INTO "django_geo_db_city" VALUES(28508,'Danville','Danville, California',35568,6);
INSERT INTO "django_geo_db_city" VALUES(28509,'Alamo','Alamo, California',35569,6);
INSERT INTO "django_geo_db_city" VALUES(28510,'Angwin','Angwin, California',35570,6);
INSERT INTO "django_geo_db_city" VALUES(28511,'Antioch','Antioch, California',35571,6);
INSERT INTO "django_geo_db_city" VALUES(28512,'Benicia','Benicia, California',35572,6);
INSERT INTO "django_geo_db_city" VALUES(28513,'Bethel Island','Bethel Island, California',35573,6);
INSERT INTO "django_geo_db_city" VALUES(28514,'Birds Landing','Birds Landing, California',35574,6);
INSERT INTO "django_geo_db_city" VALUES(28515,'Brentwood','Brentwood, California',35575,6);
INSERT INTO "django_geo_db_city" VALUES(28516,'Byron','Byron, California',35576,6);
INSERT INTO "django_geo_db_city" VALUES(28517,'Calistoga','Calistoga, California',35577,6);
INSERT INTO "django_geo_db_city" VALUES(28518,'Canyon','Canyon, California',35578,6);
INSERT INTO "django_geo_db_city" VALUES(28519,'Clayton','Clayton, California',35579,6);
INSERT INTO "django_geo_db_city" VALUES(28520,'Concord','Concord, California',35580,6);
INSERT INTO "django_geo_db_city" VALUES(28521,'Pleasant Hill','Pleasant Hill, California',35584,6);
INSERT INTO "django_geo_db_city" VALUES(28522,'Crockett','Crockett, California',35585,6);
INSERT INTO "django_geo_db_city" VALUES(28523,'Diablo','Diablo, California',35588,6);
INSERT INTO "django_geo_db_city" VALUES(28524,'El Cerrito','El Cerrito, California',35589,6);
INSERT INTO "django_geo_db_city" VALUES(28525,'Fairfield','Fairfield, California',35591,6);
INSERT INTO "django_geo_db_city" VALUES(28526,'Travis AFB','Travis AFB, California',35593,6);
INSERT INTO "django_geo_db_city" VALUES(28527,'Fremont','Fremont, California',35594,6);
INSERT INTO "django_geo_db_city" VALUES(28528,'Hayward','Hayward, California',35595,6);
INSERT INTO "django_geo_db_city" VALUES(28529,'Castro Valley','Castro Valley, California',35602,6);
INSERT INTO "django_geo_db_city" VALUES(28530,'Hercules','Hercules, California',35603,6);
INSERT INTO "django_geo_db_city" VALUES(28531,'Knightsen','Knightsen, California',35604,6);
INSERT INTO "django_geo_db_city" VALUES(28532,'Lafayette','Lafayette, California',35605,6);
INSERT INTO "django_geo_db_city" VALUES(28533,'Livermore','Livermore, California',35606,6);
INSERT INTO "django_geo_db_city" VALUES(28534,'Martinez','Martinez, California',35608,6);
INSERT INTO "django_geo_db_city" VALUES(28535,'Moraga','Moraga, California',35610,6);
INSERT INTO "django_geo_db_city" VALUES(28536,'Napa','Napa, California',35611,6);
INSERT INTO "django_geo_db_city" VALUES(28537,'Newark','Newark, California',35613,6);
INSERT INTO "django_geo_db_city" VALUES(28538,'Oakley','Oakley, California',35614,6);
INSERT INTO "django_geo_db_city" VALUES(28539,'Oakville','Oakville, California',35615,6);
INSERT INTO "django_geo_db_city" VALUES(28540,'Orinda','Orinda, California',35616,6);
INSERT INTO "django_geo_db_city" VALUES(28541,'Pinole','Pinole, California',35617,6);
INSERT INTO "django_geo_db_city" VALUES(28542,'Pittsburg','Pittsburg, California',35618,6);
INSERT INTO "django_geo_db_city" VALUES(28543,'Pleasanton','Pleasanton, California',35619,6);
INSERT INTO "django_geo_db_city" VALUES(28544,'Pope Valley','Pope Valley, California',35620,6);
INSERT INTO "django_geo_db_city" VALUES(28545,'Dublin','Dublin, California',35621,6);
INSERT INTO "django_geo_db_city" VALUES(28546,'Port Costa','Port Costa, California',35622,6);
INSERT INTO "django_geo_db_city" VALUES(28547,'Rio Vista','Rio Vista, California',35623,6);
INSERT INTO "django_geo_db_city" VALUES(28548,'Rodeo','Rodeo, California',35624,6);
INSERT INTO "django_geo_db_city" VALUES(28549,'Rutherford','Rutherford, California',35625,6);
INSERT INTO "django_geo_db_city" VALUES(28550,'Saint Helena','Saint Helena, California',35626,6);
INSERT INTO "django_geo_db_city" VALUES(28551,'Deer Park','Deer Park, California',35627,6);
INSERT INTO "django_geo_db_city" VALUES(28552,'San Leandro','San Leandro, California',35628,6);
INSERT INTO "django_geo_db_city" VALUES(28553,'San Lorenzo','San Lorenzo, California',35631,6);
INSERT INTO "django_geo_db_city" VALUES(28554,'San Ramon','San Ramon, California',35633,6);
INSERT INTO "django_geo_db_city" VALUES(28555,'Suisun City','Suisun City, California',35634,6);
INSERT INTO "django_geo_db_city" VALUES(28556,'Sunol','Sunol, California',35635,6);
INSERT INTO "django_geo_db_city" VALUES(28557,'Union City','Union City, California',35636,6);
INSERT INTO "django_geo_db_city" VALUES(28558,'Vallejo','Vallejo, California',35638,6);
INSERT INTO "django_geo_db_city" VALUES(28559,'Walnut Creek','Walnut Creek, California',35642,6);
INSERT INTO "django_geo_db_city" VALUES(28560,'Yountville','Yountville, California',35645,6);
INSERT INTO "django_geo_db_city" VALUES(28561,'Oakland','Oakland, California',35646,6);
INSERT INTO "django_geo_db_city" VALUES(28562,'Emeryville','Emeryville, California',35652,6);
INSERT INTO "django_geo_db_city" VALUES(28563,'Piedmont','Piedmont, California',35595,6);
INSERT INTO "django_geo_db_city" VALUES(28564,'Berkeley','Berkeley, California',35666,6);
INSERT INTO "django_geo_db_city" VALUES(28565,'Albany','Albany, California',35671,6);
INSERT INTO "django_geo_db_city" VALUES(28566,'Richmond','Richmond, California',35677,6);
INSERT INTO "django_geo_db_city" VALUES(28567,'El Sobrante','El Sobrante, California',35678,6);
INSERT INTO "django_geo_db_city" VALUES(28568,'San Pablo','San Pablo, California',35681,6);
INSERT INTO "django_geo_db_city" VALUES(28569,'San Rafael','San Rafael, California',35682,6);
INSERT INTO "django_geo_db_city" VALUES(28570,'Greenbrae','Greenbrae, California',35684,6);
INSERT INTO "django_geo_db_city" VALUES(28571,'Kentfield','Kentfield, California',35685,6);
INSERT INTO "django_geo_db_city" VALUES(28572,'Belvedere Tiburon','Belvedere Tiburon, California',35687,6);
INSERT INTO "django_geo_db_city" VALUES(28573,'Bodega','Bodega, California',35688,6);
INSERT INTO "django_geo_db_city" VALUES(28574,'Bodega Bay','Bodega Bay, California',35689,6);
INSERT INTO "django_geo_db_city" VALUES(28575,'Bolinas','Bolinas, California',35690,6);
INSERT INTO "django_geo_db_city" VALUES(28576,'Corte Madera','Corte Madera, California',35691,6);
INSERT INTO "django_geo_db_city" VALUES(28577,'Cotati','Cotati, California',35692,6);
INSERT INTO "django_geo_db_city" VALUES(28578,'Rohnert Park','Rohnert Park, California',35692,6);
INSERT INTO "django_geo_db_city" VALUES(28579,'Dillon Beach','Dillon Beach, California',35694,6);
INSERT INTO "django_geo_db_city" VALUES(28580,'Fairfax','Fairfax, California',35695,6);
INSERT INTO "django_geo_db_city" VALUES(28581,'Forest Knolls','Forest Knolls, California',35697,6);
INSERT INTO "django_geo_db_city" VALUES(28582,'Inverness','Inverness, California',35698,6);
INSERT INTO "django_geo_db_city" VALUES(28583,'Lagunitas','Lagunitas, California',35699,6);
INSERT INTO "django_geo_db_city" VALUES(28584,'Larkspur','Larkspur, California',35700,6);
INSERT INTO "django_geo_db_city" VALUES(28585,'Marshall','Marshall, California',35701,6);
INSERT INTO "django_geo_db_city" VALUES(28586,'Mill Valley','Mill Valley, California',35702,6);
INSERT INTO "django_geo_db_city" VALUES(28587,'Novato','Novato, California',35703,6);
INSERT INTO "django_geo_db_city" VALUES(28588,'Nicasio','Nicasio, California',35704,6);
INSERT INTO "django_geo_db_city" VALUES(28589,'Olema','Olema, California',35708,6);
INSERT INTO "django_geo_db_city" VALUES(28590,'Penngrove','Penngrove, California',35709,6);
INSERT INTO "django_geo_db_city" VALUES(28591,'Petaluma','Petaluma, California',35710,6);
INSERT INTO "django_geo_db_city" VALUES(28592,'Point Reyes Station','Point Reyes Station, California',35712,6);
INSERT INTO "django_geo_db_city" VALUES(28593,'Ross','Ross, California',35713,6);
INSERT INTO "django_geo_db_city" VALUES(28594,'San Anselmo','San Anselmo, California',35714,6);
INSERT INTO "django_geo_db_city" VALUES(28595,'San Geronimo','San Geronimo, California',35715,6);
INSERT INTO "django_geo_db_city" VALUES(28596,'San Quentin','San Quentin, California',35716,6);
INSERT INTO "django_geo_db_city" VALUES(28597,'Sausalito','Sausalito, California',35717,6);
INSERT INTO "django_geo_db_city" VALUES(28598,'Stinson Beach','Stinson Beach, California',35718,6);
INSERT INTO "django_geo_db_city" VALUES(28599,'Tomales','Tomales, California',35719,6);
INSERT INTO "django_geo_db_city" VALUES(28600,'Valley Ford','Valley Ford, California',35720,6);
INSERT INTO "django_geo_db_city" VALUES(28601,'Woodacre','Woodacre, California',35721,6);
INSERT INTO "django_geo_db_city" VALUES(28602,'Aptos','Aptos, California',35725,6);
INSERT INTO "django_geo_db_city" VALUES(28603,'Alviso','Alviso, California',35726,6);
INSERT INTO "django_geo_db_city" VALUES(28604,'Aromas','Aromas, California',35728,6);
INSERT INTO "django_geo_db_city" VALUES(28605,'Ben Lomond','Ben Lomond, California',35729,6);
INSERT INTO "django_geo_db_city" VALUES(28606,'Boulder Creek','Boulder Creek, California',35730,6);
INSERT INTO "django_geo_db_city" VALUES(28607,'Brookdale','Brookdale, California',35731,6);
INSERT INTO "django_geo_db_city" VALUES(28608,'Campbell','Campbell, California',35732,6);
INSERT INTO "django_geo_db_city" VALUES(28609,'Capitola','Capitola, California',35733,6);
INSERT INTO "django_geo_db_city" VALUES(28610,'Castroville','Castroville, California',35734,6);
INSERT INTO "django_geo_db_city" VALUES(28611,'Coyote','Coyote, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28612,'Cupertino','Cupertino, California',35735,6);
INSERT INTO "django_geo_db_city" VALUES(28613,'Davenport','Davenport, California',35736,6);
INSERT INTO "django_geo_db_city" VALUES(28614,'Felton','Felton, California',35737,6);
INSERT INTO "django_geo_db_city" VALUES(28615,'Freedom','Freedom, California',35738,6);
INSERT INTO "django_geo_db_city" VALUES(28616,'Gilroy','Gilroy, California',35739,6);
INSERT INTO "django_geo_db_city" VALUES(28617,'Hollister','Hollister, California',35742,6);
INSERT INTO "django_geo_db_city" VALUES(28618,'Holy City','Holy City, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28619,'Los Gatos','Los Gatos, California',35744,6);
INSERT INTO "django_geo_db_city" VALUES(28620,'Milpitas','Milpitas, California',35747,6);
INSERT INTO "django_geo_db_city" VALUES(28621,'Morgan Hill','Morgan Hill, California',35749,6);
INSERT INTO "django_geo_db_city" VALUES(28622,'Moss Landing','Moss Landing, California',35751,6);
INSERT INTO "django_geo_db_city" VALUES(28623,'Mount Hermon','Mount Hermon, California',35752,6);
INSERT INTO "django_geo_db_city" VALUES(28624,'New Almaden','New Almaden, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28625,'Paicines','Paicines, California',35753,6);
INSERT INTO "django_geo_db_city" VALUES(28626,'Redwood Estates','Redwood Estates, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28627,'San Juan Bautista','San Juan Bautista, California',35754,6);
INSERT INTO "django_geo_db_city" VALUES(28628,'San Martin','San Martin, California',35755,6);
INSERT INTO "django_geo_db_city" VALUES(28629,'Santa Clara','Santa Clara, California',35756,6);
INSERT INTO "django_geo_db_city" VALUES(28630,'Santa Cruz','Santa Cruz, California',35759,6);
INSERT INTO "django_geo_db_city" VALUES(28631,'Scotts Valley','Scotts Valley, California',35765,6);
INSERT INTO "django_geo_db_city" VALUES(28632,'Saratoga','Saratoga, California',35766,6);
INSERT INTO "django_geo_db_city" VALUES(28633,'Soquel','Soquel, California',35767,6);
INSERT INTO "django_geo_db_city" VALUES(28634,'Tres Pinos','Tres Pinos, California',35768,6);
INSERT INTO "django_geo_db_city" VALUES(28635,'Watsonville','Watsonville, California',35769,6);
INSERT INTO "django_geo_db_city" VALUES(28636,'San Jose','San Jose, California',35498,6);
INSERT INTO "django_geo_db_city" VALUES(28637,'Mount Hamilton','Mount Hamilton, California',35797,6);
INSERT INTO "django_geo_db_city" VALUES(28638,'Stockton','Stockton, California',35802,6);
INSERT INTO "django_geo_db_city" VALUES(28639,'Acampo','Acampo, California',35817,6);
INSERT INTO "django_geo_db_city" VALUES(28640,'Altaville','Altaville, California',35818,6);
INSERT INTO "django_geo_db_city" VALUES(28641,'Angels Camp','Angels Camp, California',35819,6);
INSERT INTO "django_geo_db_city" VALUES(28642,'Arnold','Arnold, California',35820,6);
INSERT INTO "django_geo_db_city" VALUES(28643,'Avery','Avery, California',35821,6);
INSERT INTO "django_geo_db_city" VALUES(28644,'Burson','Burson, California',35822,6);
INSERT INTO "django_geo_db_city" VALUES(28645,'Campo Seco','Campo Seco, California',35823,6);
INSERT INTO "django_geo_db_city" VALUES(28646,'Clements','Clements, California',35824,6);
INSERT INTO "django_geo_db_city" VALUES(28647,'Copperopolis','Copperopolis, California',35825,6);
INSERT INTO "django_geo_db_city" VALUES(28648,'Douglas Flat','Douglas Flat, California',35826,6);
INSERT INTO "django_geo_db_city" VALUES(28649,'Farmington','Farmington, California',35827,6);
INSERT INTO "django_geo_db_city" VALUES(28650,'French Camp','French Camp, California',35828,6);
INSERT INTO "django_geo_db_city" VALUES(28651,'Glencoe','Glencoe, California',35829,6);
INSERT INTO "django_geo_db_city" VALUES(28652,'Hathaway Pines','Hathaway Pines, California',35830,6);
INSERT INTO "django_geo_db_city" VALUES(28653,'Holt','Holt, California',35809,6);
INSERT INTO "django_geo_db_city" VALUES(28654,'Linden','Linden, California',35831,6);
INSERT INTO "django_geo_db_city" VALUES(28655,'Lockeford','Lockeford, California',35832,6);
INSERT INTO "django_geo_db_city" VALUES(28656,'Lodi','Lodi, California',35833,6);
INSERT INTO "django_geo_db_city" VALUES(28657,'Mokelumne Hill','Mokelumne Hill, California',35835,6);
INSERT INTO "django_geo_db_city" VALUES(28658,'Mountain Ranch','Mountain Ranch, California',35836,6);
INSERT INTO "django_geo_db_city" VALUES(28659,'Murphys','Murphys, California',35837,6);
INSERT INTO "django_geo_db_city" VALUES(28660,'Rail Road Flat','Rail Road Flat, California',35838,6);
INSERT INTO "django_geo_db_city" VALUES(28661,'San Andreas','San Andreas, California',35839,6);
INSERT INTO "django_geo_db_city" VALUES(28662,'Sheep Ranch','Sheep Ranch, California',35840,6);
INSERT INTO "django_geo_db_city" VALUES(28663,'Vallecito','Vallecito, California',35841,6);
INSERT INTO "django_geo_db_city" VALUES(28664,'Valley Springs','Valley Springs, California',35842,6);
INSERT INTO "django_geo_db_city" VALUES(28665,'Victor','Victor, California',35843,6);
INSERT INTO "django_geo_db_city" VALUES(28666,'Wallace','Wallace, California',35844,6);
INSERT INTO "django_geo_db_city" VALUES(28667,'West Point','West Point, California',35845,6);
INSERT INTO "django_geo_db_city" VALUES(28668,'Wilseyville','Wilseyville, California',35846,6);
INSERT INTO "django_geo_db_city" VALUES(28669,'Woodbridge','Woodbridge, California',35847,6);
INSERT INTO "django_geo_db_city" VALUES(28670,'Lyoth','Lyoth, California',35809,6);
INSERT INTO "django_geo_db_city" VALUES(28671,'Atwater','Atwater, California',35849,6);
INSERT INTO "django_geo_db_city" VALUES(28672,'Ballico','Ballico, California',35850,6);
INSERT INTO "django_geo_db_city" VALUES(28673,'Banta','Banta, California',35809,6);
INSERT INTO "django_geo_db_city" VALUES(28674,'Big Oak Flat','Big Oak Flat, California',35851,6);
INSERT INTO "django_geo_db_city" VALUES(28675,'Catheys Valley','Catheys Valley, California',35852,6);
INSERT INTO "django_geo_db_city" VALUES(28676,'Ceres','Ceres, California',35853,6);
INSERT INTO "django_geo_db_city" VALUES(28677,'Chinese Camp','Chinese Camp, California',35854,6);
INSERT INTO "django_geo_db_city" VALUES(28678,'Columbia','Columbia, California',35855,6);
INSERT INTO "django_geo_db_city" VALUES(28679,'Coulterville','Coulterville, California',35856,6);
INSERT INTO "django_geo_db_city" VALUES(28680,'Cressey','Cressey, California',35857,6);
INSERT INTO "django_geo_db_city" VALUES(28681,'Crows Landing','Crows Landing, California',35858,6);
INSERT INTO "django_geo_db_city" VALUES(28682,'Dardanelle','Dardanelle, California',35859,6);
INSERT INTO "django_geo_db_city" VALUES(28683,'Delhi','Delhi, California',35860,6);
INSERT INTO "django_geo_db_city" VALUES(28684,'Denair','Denair, California',35861,6);
INSERT INTO "django_geo_db_city" VALUES(28685,'El Nido','El Nido, California',35862,6);
INSERT INTO "django_geo_db_city" VALUES(28686,'El Portal','El Portal, California',35863,6);
INSERT INTO "django_geo_db_city" VALUES(28687,'Empire','Empire, California',35864,6);
INSERT INTO "django_geo_db_city" VALUES(28688,'Escalon','Escalon, California',35865,6);
INSERT INTO "django_geo_db_city" VALUES(28689,'Groveland','Groveland, California',35866,6);
INSERT INTO "django_geo_db_city" VALUES(28690,'Gustine','Gustine, California',35867,6);
INSERT INTO "django_geo_db_city" VALUES(28691,'Hickman','Hickman, California',35868,6);
INSERT INTO "django_geo_db_city" VALUES(28692,'Hilmar','Hilmar, California',35869,6);
INSERT INTO "django_geo_db_city" VALUES(28693,'Hornitos','Hornitos, California',35870,6);
INSERT INTO "django_geo_db_city" VALUES(28694,'Hughson','Hughson, California',35871,6);
INSERT INTO "django_geo_db_city" VALUES(28695,'Jamestown','Jamestown, California',35872,6);
INSERT INTO "django_geo_db_city" VALUES(28696,'Keyes','Keyes, California',35873,6);
INSERT INTO "django_geo_db_city" VALUES(28697,'La Grange','La Grange, California',35874,6);
INSERT INTO "django_geo_db_city" VALUES(28698,'Lathrop','Lathrop, California',35875,6);
INSERT INTO "django_geo_db_city" VALUES(28699,'Le Grand','Le Grand, California',35876,6);
INSERT INTO "django_geo_db_city" VALUES(28700,'Livingston','Livingston, California',35877,6);
INSERT INTO "django_geo_db_city" VALUES(28701,'Long Barn','Long Barn, California',35878,6);
INSERT INTO "django_geo_db_city" VALUES(28702,'Manteca','Manteca, California',35879,6);
INSERT INTO "django_geo_db_city" VALUES(28703,'Mariposa','Mariposa, California',35881,6);
INSERT INTO "django_geo_db_city" VALUES(28704,'Merced','Merced, California',35882,6);
INSERT INTO "django_geo_db_city" VALUES(28705,'Midpines','Midpines, California',35885,6);
INSERT INTO "django_geo_db_city" VALUES(28706,'Mi Wuk Village','Mi Wuk Village, California',35886,6);
INSERT INTO "django_geo_db_city" VALUES(28707,'Moccasin','Moccasin, California',35887,6);
INSERT INTO "django_geo_db_city" VALUES(28708,'Modesto','Modesto, California',35889,6);
INSERT INTO "django_geo_db_city" VALUES(28709,'Newman','Newman, California',35897,6);
INSERT INTO "django_geo_db_city" VALUES(28710,'Oakdale','Oakdale, California',35898,6);
INSERT INTO "django_geo_db_city" VALUES(28711,'Patterson','Patterson, California',35899,6);
INSERT INTO "django_geo_db_city" VALUES(28712,'Pinecrest','Pinecrest, California',35900,6);
INSERT INTO "django_geo_db_city" VALUES(28713,'Planada','Planada, California',35901,6);
INSERT INTO "django_geo_db_city" VALUES(28714,'Ripon','Ripon, California',35902,6);
INSERT INTO "django_geo_db_city" VALUES(28715,'Riverbank','Riverbank, California',35903,6);
INSERT INTO "django_geo_db_city" VALUES(28716,'Salida','Salida, California',35904,6);
INSERT INTO "django_geo_db_city" VALUES(28717,'Snelling','Snelling, California',35905,6);
INSERT INTO "django_geo_db_city" VALUES(28718,'Sonora','Sonora, California',35906,6);
INSERT INTO "django_geo_db_city" VALUES(28719,'Soulsbyville','Soulsbyville, California',35907,6);
INSERT INTO "django_geo_db_city" VALUES(28720,'Standard','Standard, California',35908,6);
INSERT INTO "django_geo_db_city" VALUES(28721,'Stevinson','Stevinson, California',35909,6);
INSERT INTO "django_geo_db_city" VALUES(28722,'Strawberry','Strawberry, California',35910,6);
INSERT INTO "django_geo_db_city" VALUES(28723,'Tracy','Tracy, California',35911,6);
INSERT INTO "django_geo_db_city" VALUES(28724,'Tuolumne','Tuolumne, California',35913,6);
INSERT INTO "django_geo_db_city" VALUES(28725,'Turlock','Turlock, California',35914,6);
INSERT INTO "django_geo_db_city" VALUES(28726,'Twain Harte','Twain Harte, California',35916,6);
INSERT INTO "django_geo_db_city" VALUES(28727,'Vernalis','Vernalis, California',35917,6);
INSERT INTO "django_geo_db_city" VALUES(28728,'Waterford','Waterford, California',35918,6);
INSERT INTO "django_geo_db_city" VALUES(28729,'Westley','Westley, California',35919,6);
INSERT INTO "django_geo_db_city" VALUES(28730,'Winton','Winton, California',35920,6);
INSERT INTO "django_geo_db_city" VALUES(28731,'Yosemite National Park','Yosemite National Park, California',35921,6);
INSERT INTO "django_geo_db_city" VALUES(28732,'Santa Rosa','Santa Rosa, California',35922,6);
INSERT INTO "django_geo_db_city" VALUES(28733,'Albion','Albion, California',35930,6);
INSERT INTO "django_geo_db_city" VALUES(28734,'Annapolis','Annapolis, California',35931,6);
INSERT INTO "django_geo_db_city" VALUES(28735,'Boonville','Boonville, California',35932,6);
INSERT INTO "django_geo_db_city" VALUES(28736,'Boyes Hot Springs','Boyes Hot Springs, California',35692,6);
INSERT INTO "django_geo_db_city" VALUES(28737,'Branscomb','Branscomb, California',35933,6);
INSERT INTO "django_geo_db_city" VALUES(28738,'Calpella','Calpella, California',35934,6);
INSERT INTO "django_geo_db_city" VALUES(28739,'Camp Meeker','Camp Meeker, California',35935,6);
INSERT INTO "django_geo_db_city" VALUES(28740,'Caspar','Caspar, California',35936,6);
INSERT INTO "django_geo_db_city" VALUES(28741,'Cazadero','Cazadero, California',35937,6);
INSERT INTO "django_geo_db_city" VALUES(28742,'Clearlake','Clearlake, California',35938,6);
INSERT INTO "django_geo_db_city" VALUES(28743,'Clearlake Oaks','Clearlake Oaks, California',35939,6);
INSERT INTO "django_geo_db_city" VALUES(28744,'Clearlake Park','Clearlake Park, California',35940,6);
INSERT INTO "django_geo_db_city" VALUES(28745,'Cloverdale','Cloverdale, California',35941,6);
INSERT INTO "django_geo_db_city" VALUES(28746,'Cobb','Cobb, California',35942,6);
INSERT INTO "django_geo_db_city" VALUES(28747,'Comptche','Comptche, California',35943,6);
INSERT INTO "django_geo_db_city" VALUES(28748,'Covelo','Covelo, California',35944,6);
INSERT INTO "django_geo_db_city" VALUES(28749,'Dos Rios','Dos Rios, California',35945,6);
INSERT INTO "django_geo_db_city" VALUES(28750,'Duncans Mills','Duncans Mills, California',35946,6);
INSERT INTO "django_geo_db_city" VALUES(28751,'Eldridge','Eldridge, California',35947,6);
INSERT INTO "django_geo_db_city" VALUES(28752,'Elk','Elk, California',35948,6);
INSERT INTO "django_geo_db_city" VALUES(28753,'El Verano','El Verano, California',35949,6);
INSERT INTO "django_geo_db_city" VALUES(28754,'Finley','Finley, California',35950,6);
INSERT INTO "django_geo_db_city" VALUES(28755,'Forestville','Forestville, California',35951,6);
INSERT INTO "django_geo_db_city" VALUES(28756,'Fort Bragg','Fort Bragg, California',35952,6);
INSERT INTO "django_geo_db_city" VALUES(28757,'Fulton','Fulton, California',35953,6);
INSERT INTO "django_geo_db_city" VALUES(28758,'Geyserville','Geyserville, California',35954,6);
INSERT INTO "django_geo_db_city" VALUES(28759,'Glen Ellen','Glen Ellen, California',35955,6);
INSERT INTO "django_geo_db_city" VALUES(28760,'Glenhaven','Glenhaven, California',35956,6);
INSERT INTO "django_geo_db_city" VALUES(28761,'Graton','Graton, California',35957,6);
INSERT INTO "django_geo_db_city" VALUES(28762,'Gualala','Gualala, California',35958,6);
INSERT INTO "django_geo_db_city" VALUES(28763,'Guerneville','Guerneville, California',35959,6);
INSERT INTO "django_geo_db_city" VALUES(28764,'Healdsburg','Healdsburg, California',35960,6);
INSERT INTO "django_geo_db_city" VALUES(28765,'Hopland','Hopland, California',35961,6);
INSERT INTO "django_geo_db_city" VALUES(28766,'Jenner','Jenner, California',35962,6);
INSERT INTO "django_geo_db_city" VALUES(28767,'Kelseyville','Kelseyville, California',35963,6);
INSERT INTO "django_geo_db_city" VALUES(28768,'Kenwood','Kenwood, California',35964,6);
INSERT INTO "django_geo_db_city" VALUES(28769,'Lakeport','Lakeport, California',35965,6);
INSERT INTO "django_geo_db_city" VALUES(28770,'Laytonville','Laytonville, California',35966,6);
INSERT INTO "django_geo_db_city" VALUES(28771,'Littleriver','Littleriver, California',35967,6);
INSERT INTO "django_geo_db_city" VALUES(28772,'Lower Lake','Lower Lake, California',35968,6);
INSERT INTO "django_geo_db_city" VALUES(28773,'Lucerne','Lucerne, California',35969,6);
INSERT INTO "django_geo_db_city" VALUES(28774,'Manchester','Manchester, California',35970,6);
INSERT INTO "django_geo_db_city" VALUES(28775,'Mendocino','Mendocino, California',35971,6);
INSERT INTO "django_geo_db_city" VALUES(28776,'Middletown','Middletown, California',35972,6);
INSERT INTO "django_geo_db_city" VALUES(28777,'Monte Rio','Monte Rio, California',35973,6);
INSERT INTO "django_geo_db_city" VALUES(28778,'Navarro','Navarro, California',35974,6);
INSERT INTO "django_geo_db_city" VALUES(28779,'Nice','Nice, California',35975,6);
INSERT INTO "django_geo_db_city" VALUES(28780,'Occidental','Occidental, California',35976,6);
INSERT INTO "django_geo_db_city" VALUES(28781,'Philo','Philo, California',35977,6);
INSERT INTO "django_geo_db_city" VALUES(28782,'Point Arena','Point Arena, California',35978,6);
INSERT INTO "django_geo_db_city" VALUES(28783,'Potter Valley','Potter Valley, California',35979,6);
INSERT INTO "django_geo_db_city" VALUES(28784,'Redwood Valley','Redwood Valley, California',35980,6);
INSERT INTO "django_geo_db_city" VALUES(28785,'Rio Nido','Rio Nido, California',35981,6);
INSERT INTO "django_geo_db_city" VALUES(28786,'Sebastopol','Sebastopol, California',35982,6);
INSERT INTO "django_geo_db_city" VALUES(28787,'Sonoma','Sonoma, California',35984,6);
INSERT INTO "django_geo_db_city" VALUES(28788,'Stewarts Point','Stewarts Point, California',35985,6);
INSERT INTO "django_geo_db_city" VALUES(28789,'Talmage','Talmage, California',35986,6);
INSERT INTO "django_geo_db_city" VALUES(28790,'Ukiah','Ukiah, California',35987,6);
INSERT INTO "django_geo_db_city" VALUES(28791,'Upper Lake','Upper Lake, California',35988,6);
INSERT INTO "django_geo_db_city" VALUES(28792,'Villa Grande','Villa Grande, California',35989,6);
INSERT INTO "django_geo_db_city" VALUES(28793,'Vineburg','Vineburg, California',35692,6);
INSERT INTO "django_geo_db_city" VALUES(28794,'Westport','Westport, California',35990,6);
INSERT INTO "django_geo_db_city" VALUES(28795,'Willits','Willits, California',35991,6);
INSERT INTO "django_geo_db_city" VALUES(28796,'Windsor','Windsor, California',35992,6);
INSERT INTO "django_geo_db_city" VALUES(28797,'Witter Springs','Witter Springs, California',35993,6);
INSERT INTO "django_geo_db_city" VALUES(28798,'Yorkville','Yorkville, California',35994,6);
INSERT INTO "django_geo_db_city" VALUES(28799,'The Sea Ranch','The Sea Ranch, California',35995,6);
INSERT INTO "django_geo_db_city" VALUES(28800,'Eureka','Eureka, California',35996,6);
INSERT INTO "django_geo_db_city" VALUES(28801,'Alderpoint','Alderpoint, California',35999,6);
INSERT INTO "django_geo_db_city" VALUES(28802,'Blocksburg','Blocksburg, California',36000,6);
INSERT INTO "django_geo_db_city" VALUES(28803,'Diamond Springs','Diamond Springs, California',36001,6);
INSERT INTO "django_geo_db_city" VALUES(28804,'Arcata','Arcata, California',36002,6);
INSERT INTO "django_geo_db_city" VALUES(28805,'Mckinleyville','Mckinleyville, California',36003,6);
INSERT INTO "django_geo_db_city" VALUES(28806,'Bayside','Bayside, California',36006,6);
INSERT INTO "django_geo_db_city" VALUES(28807,'Blue Lake','Blue Lake, California',36007,6);
INSERT INTO "django_geo_db_city" VALUES(28808,'Bridgeville','Bridgeville, California',36008,6);
INSERT INTO "django_geo_db_city" VALUES(28809,'Burnt Ranch','Burnt Ranch, California',36009,6);
INSERT INTO "django_geo_db_city" VALUES(28810,'Carlotta','Carlotta, California',36010,6);
INSERT INTO "django_geo_db_city" VALUES(28811,'Crescent City','Crescent City, California',36011,6);
INSERT INTO "django_geo_db_city" VALUES(28812,'Cutten','Cutten, California',36013,6);
INSERT INTO "django_geo_db_city" VALUES(28813,'Ferndale','Ferndale, California',36014,6);
INSERT INTO "django_geo_db_city" VALUES(28814,'Fields Landing','Fields Landing, California',36015,6);
INSERT INTO "django_geo_db_city" VALUES(28815,'Fort Dick','Fort Dick, California',36016,6);
INSERT INTO "django_geo_db_city" VALUES(28816,'Fortuna','Fortuna, California',36017,6);
INSERT INTO "django_geo_db_city" VALUES(28817,'Garberville','Garberville, California',36018,6);
INSERT INTO "django_geo_db_city" VALUES(28818,'Gasquet','Gasquet, California',36019,6);
INSERT INTO "django_geo_db_city" VALUES(28819,'Honeydew','Honeydew, California',36020,6);
INSERT INTO "django_geo_db_city" VALUES(28820,'Hoopa','Hoopa, California',36021,6);
INSERT INTO "django_geo_db_city" VALUES(28821,'Hydesville','Hydesville, California',36022,6);
INSERT INTO "django_geo_db_city" VALUES(28822,'Klamath','Klamath, California',36023,6);
INSERT INTO "django_geo_db_city" VALUES(28823,'Kneeland','Kneeland, California',36024,6);
INSERT INTO "django_geo_db_city" VALUES(28824,'Korbel','Korbel, California',36025,6);
INSERT INTO "django_geo_db_city" VALUES(28825,'Loleta','Loleta, California',36026,6);
INSERT INTO "django_geo_db_city" VALUES(28826,'Mad River','Mad River, California',36027,6);
INSERT INTO "django_geo_db_city" VALUES(28827,'Miranda','Miranda, California',36028,6);
INSERT INTO "django_geo_db_city" VALUES(28828,'Myers Flat','Myers Flat, California',36029,6);
INSERT INTO "django_geo_db_city" VALUES(28829,'Orick','Orick, California',36030,6);
INSERT INTO "django_geo_db_city" VALUES(28830,'Orleans','Orleans, California',36031,6);
INSERT INTO "django_geo_db_city" VALUES(28831,'Petrolia','Petrolia, California',36032,6);
INSERT INTO "django_geo_db_city" VALUES(28832,'Phillipsville','Phillipsville, California',36033,6);
INSERT INTO "django_geo_db_city" VALUES(28833,'Redway','Redway, California',36034,6);
INSERT INTO "django_geo_db_city" VALUES(28834,'Rio Dell','Rio Dell, California',36035,6);
INSERT INTO "django_geo_db_city" VALUES(28835,'Salyer','Salyer, California',36036,6);
INSERT INTO "django_geo_db_city" VALUES(28836,'Samoa','Samoa, California',36037,6);
INSERT INTO "django_geo_db_city" VALUES(28837,'Scotia','Scotia, California',36038,6);
INSERT INTO "django_geo_db_city" VALUES(28838,'Smith River','Smith River, California',36039,6);
INSERT INTO "django_geo_db_city" VALUES(28839,'Somes Bar','Somes Bar, California',36040,6);
INSERT INTO "django_geo_db_city" VALUES(28840,'Redcrest','Redcrest, California',36041,6);
INSERT INTO "django_geo_db_city" VALUES(28841,'Trinidad','Trinidad, California',36042,6);
INSERT INTO "django_geo_db_city" VALUES(28842,'Weott','Weott, California',36043,6);
INSERT INTO "django_geo_db_city" VALUES(28843,'Willow Creek','Willow Creek, California',36044,6);
INSERT INTO "django_geo_db_city" VALUES(28844,'Leggett','Leggett, California',36045,6);
INSERT INTO "django_geo_db_city" VALUES(28845,'Piercy','Piercy, California',36046,6);
INSERT INTO "django_geo_db_city" VALUES(28846,'Whitethorn','Whitethorn, California',36047,6);
INSERT INTO "django_geo_db_city" VALUES(28847,'Zenia','Zenia, California',36049,6);
INSERT INTO "django_geo_db_city" VALUES(28848,'Amador City','Amador City, California',36050,6);
INSERT INTO "django_geo_db_city" VALUES(28849,'Auburn','Auburn, California',36051,6);
INSERT INTO "django_geo_db_city" VALUES(28850,'West Sacramento','West Sacramento, California',36054,6);
INSERT INTO "django_geo_db_city" VALUES(28851,'Brooks','Brooks, California',36055,6);
INSERT INTO "django_geo_db_city" VALUES(28852,'Capay','Capay, California',36056,6);
INSERT INTO "django_geo_db_city" VALUES(28853,'Carmichael','Carmichael, California',36057,6);
INSERT INTO "django_geo_db_city" VALUES(28854,'Citrus Heights','Citrus Heights, California',36059,6);
INSERT INTO "django_geo_db_city" VALUES(28855,'Clarksburg','Clarksburg, California',36060,6);
INSERT INTO "django_geo_db_city" VALUES(28856,'Coloma','Coloma, California',36061,6);
INSERT INTO "django_geo_db_city" VALUES(28857,'Cool','Cool, California',36062,6);
INSERT INTO "django_geo_db_city" VALUES(28858,'Courtland','Courtland, California',36063,6);
INSERT INTO "django_geo_db_city" VALUES(28859,'Davis','Davis, California',36064,6);
INSERT INTO "django_geo_db_city" VALUES(28860,'El Macero','El Macero, California',36066,6);
INSERT INTO "django_geo_db_city" VALUES(28861,'Dixon','Dixon, California',36068,6);
INSERT INTO "django_geo_db_city" VALUES(28862,'El Dorado','El Dorado, California',36070,6);
INSERT INTO "django_geo_db_city" VALUES(28863,'Elk Grove','Elk Grove, California',36071,6);
INSERT INTO "django_geo_db_city" VALUES(28864,'Elmira','Elmira, California',36072,6);
INSERT INTO "django_geo_db_city" VALUES(28865,'Elverta','Elverta, California',36073,6);
INSERT INTO "django_geo_db_city" VALUES(28866,'Esparto','Esparto, California',36074,6);
INSERT INTO "django_geo_db_city" VALUES(28867,'Fair Oaks','Fair Oaks, California',36075,6);
INSERT INTO "django_geo_db_city" VALUES(28868,'Fiddletown','Fiddletown, California',36076,6);
INSERT INTO "django_geo_db_city" VALUES(28869,'Folsom','Folsom, California',36077,6);
INSERT INTO "django_geo_db_city" VALUES(28870,'Foresthill','Foresthill, California',36078,6);
INSERT INTO "django_geo_db_city" VALUES(28871,'Galt','Galt, California',36079,6);
INSERT INTO "django_geo_db_city" VALUES(28872,'Garden Valley','Garden Valley, California',36080,6);
INSERT INTO "django_geo_db_city" VALUES(28873,'Georgetown','Georgetown, California',36081,6);
INSERT INTO "django_geo_db_city" VALUES(28874,'Greenwood','Greenwood, California',36082,6);
INSERT INTO "django_geo_db_city" VALUES(28875,'Grizzly Flats','Grizzly Flats, California',36083,6);
INSERT INTO "django_geo_db_city" VALUES(28876,'Guinda','Guinda, California',36084,6);
INSERT INTO "django_geo_db_city" VALUES(28877,'Herald','Herald, California',36085,6);
INSERT INTO "django_geo_db_city" VALUES(28878,'Hood','Hood, California',36086,6);
INSERT INTO "django_geo_db_city" VALUES(28879,'Ione','Ione, California',36087,6);
INSERT INTO "django_geo_db_city" VALUES(28880,'Isleton','Isleton, California',36088,6);
INSERT INTO "django_geo_db_city" VALUES(28881,'Jackson','Jackson, California',36089,6);
INSERT INTO "django_geo_db_city" VALUES(28882,'Kit Carson','Kit Carson, California',36090,6);
INSERT INTO "django_geo_db_city" VALUES(28883,'Knights Landing','Knights Landing, California',36091,6);
INSERT INTO "django_geo_db_city" VALUES(28884,'Kirkwood','Kirkwood, California',36092,6);
INSERT INTO "django_geo_db_city" VALUES(28885,'Lincoln','Lincoln, California',36093,6);
INSERT INTO "django_geo_db_city" VALUES(28886,'Loomis','Loomis, California',36094,6);
INSERT INTO "django_geo_db_city" VALUES(28887,'Lotus','Lotus, California',36095,6);
INSERT INTO "django_geo_db_city" VALUES(28888,'Mcclellan AFB','Mcclellan AFB, California',36096,6);
INSERT INTO "django_geo_db_city" VALUES(28889,'Madison','Madison, California',36097,6);
INSERT INTO "django_geo_db_city" VALUES(28890,'Martell','Martell, California',36090,6);
INSERT INTO "django_geo_db_city" VALUES(28891,'Mather','Mather, California',36098,6);
INSERT INTO "django_geo_db_city" VALUES(28892,'Mount Aukum','Mount Aukum, California',36099,6);
INSERT INTO "django_geo_db_city" VALUES(28893,'Newcastle','Newcastle, California',36100,6);
INSERT INTO "django_geo_db_city" VALUES(28894,'Nicolaus','Nicolaus, California',36101,6);
INSERT INTO "django_geo_db_city" VALUES(28895,'North Highlands','North Highlands, California',36102,6);
INSERT INTO "django_geo_db_city" VALUES(28896,'Roseville','Roseville, California',36103,6);
INSERT INTO "django_geo_db_city" VALUES(28897,'Orangevale','Orangevale, California',36104,6);
INSERT INTO "django_geo_db_city" VALUES(28898,'Penryn','Penryn, California',36105,6);
INSERT INTO "django_geo_db_city" VALUES(28899,'Pilot Hill','Pilot Hill, California',36106,6);
INSERT INTO "django_geo_db_city" VALUES(28900,'Pine Grove','Pine Grove, California',36107,6);
INSERT INTO "django_geo_db_city" VALUES(28901,'Pioneer','Pioneer, California',36108,6);
INSERT INTO "django_geo_db_city" VALUES(28902,'Placerville','Placerville, California',36109,6);
INSERT INTO "django_geo_db_city" VALUES(28903,'Pleasant Grove','Pleasant Grove, California',36110,6);
INSERT INTO "django_geo_db_city" VALUES(28904,'Plymouth','Plymouth, California',36111,6);
INSERT INTO "django_geo_db_city" VALUES(28905,'Rancho Cordova','Rancho Cordova, California',36112,6);
INSERT INTO "django_geo_db_city" VALUES(28906,'Represa','Represa, California',35553,6);
INSERT INTO "django_geo_db_city" VALUES(28907,'Rescue','Rescue, California',36113,6);
INSERT INTO "django_geo_db_city" VALUES(28908,'Rio Linda','Rio Linda, California',36114,6);
INSERT INTO "django_geo_db_city" VALUES(28909,'Rio Oso','Rio Oso, California',36115,6);
INSERT INTO "django_geo_db_city" VALUES(28910,'River Pines','River Pines, California',36116,6);
INSERT INTO "django_geo_db_city" VALUES(28911,'Robbins','Robbins, California',36117,6);
INSERT INTO "django_geo_db_city" VALUES(28912,'Rocklin','Rocklin, California',36118,6);
INSERT INTO "django_geo_db_city" VALUES(28913,'Rumsey','Rumsey, California',36120,6);
INSERT INTO "django_geo_db_city" VALUES(28914,'Ryde','Ryde, California',36121,6);
INSERT INTO "django_geo_db_city" VALUES(28915,'Sheridan','Sheridan, California',36122,6);
INSERT INTO "django_geo_db_city" VALUES(28916,'Shingle Springs','Shingle Springs, California',36123,6);
INSERT INTO "django_geo_db_city" VALUES(28917,'Sloughhouse','Sloughhouse, California',36124,6);
INSERT INTO "django_geo_db_city" VALUES(28918,'Somerset','Somerset, California',36125,6);
INSERT INTO "django_geo_db_city" VALUES(28919,'Sutter Creek','Sutter Creek, California',36126,6);
INSERT INTO "django_geo_db_city" VALUES(28920,'Thornton','Thornton, California',36127,6);
INSERT INTO "django_geo_db_city" VALUES(28921,'Vacaville','Vacaville, California',36128,6);
INSERT INTO "django_geo_db_city" VALUES(28922,'Volcano','Volcano, California',36130,6);
INSERT INTO "django_geo_db_city" VALUES(28923,'Walnut Grove','Walnut Grove, California',36131,6);
INSERT INTO "django_geo_db_city" VALUES(28924,'Wheatland','Wheatland, California',36133,6);
INSERT INTO "django_geo_db_city" VALUES(28925,'Wilton','Wilton, California',36134,6);
INSERT INTO "django_geo_db_city" VALUES(28926,'Winters','Winters, California',36135,6);
INSERT INTO "django_geo_db_city" VALUES(28927,'Woodland','Woodland, California',36136,6);
INSERT INTO "django_geo_db_city" VALUES(28928,'Yolo','Yolo, California',36138,6);
INSERT INTO "django_geo_db_city" VALUES(28929,'Zamora','Zamora, California',36139,6);
INSERT INTO "django_geo_db_city" VALUES(28930,'Drytown','Drytown, California',36140,6);
INSERT INTO "django_geo_db_city" VALUES(28931,'Alta','Alta, California',36141,6);
INSERT INTO "django_geo_db_city" VALUES(28932,'Applegate','Applegate, California',36142,6);
INSERT INTO "django_geo_db_city" VALUES(28933,'Camino','Camino, California',36143,6);
INSERT INTO "django_geo_db_city" VALUES(28934,'Chicago Park','Chicago Park, California',36144,6);
INSERT INTO "django_geo_db_city" VALUES(28935,'Colfax','Colfax, California',36145,6);
INSERT INTO "django_geo_db_city" VALUES(28936,'Dutch Flat','Dutch Flat, California',36146,6);
INSERT INTO "django_geo_db_city" VALUES(28937,'Emigrant Gap','Emigrant Gap, California',36147,6);
INSERT INTO "django_geo_db_city" VALUES(28938,'Gold Run','Gold Run, California',36148,6);
INSERT INTO "django_geo_db_city" VALUES(28939,'Kyburz','Kyburz, California',36149,6);
INSERT INTO "django_geo_db_city" VALUES(28940,'Echo Lake','Echo Lake, California',36150,6);
INSERT INTO "django_geo_db_city" VALUES(28941,'Meadow Vista','Meadow Vista, California',36151,6);
INSERT INTO "django_geo_db_city" VALUES(28942,'Norden','Norden, California',36152,6);
INSERT INTO "django_geo_db_city" VALUES(28943,'Pollock Pines','Pollock Pines, California',36153,6);
INSERT INTO "django_geo_db_city" VALUES(28944,'Soda Springs','Soda Springs, California',36154,6);
INSERT INTO "django_geo_db_city" VALUES(28945,'Twin Bridges','Twin Bridges, California',36155,6);
INSERT INTO "django_geo_db_city" VALUES(28946,'Weimar','Weimar, California',36156,6);
INSERT INTO "django_geo_db_city" VALUES(28947,'Granite Bay','Granite Bay, California',36158,6);
INSERT INTO "django_geo_db_city" VALUES(28948,'El Dorado Hills','El Dorado Hills, California',36162,6);
INSERT INTO "django_geo_db_city" VALUES(28949,'Spring Garden','Spring Garden, California',36164,6);
INSERT INTO "django_geo_db_city" VALUES(28950,'Antelope','Antelope, California',36193,6);
INSERT INTO "django_geo_db_city" VALUES(28951,'Marysville','Marysville, California',36195,6);
INSERT INTO "django_geo_db_city" VALUES(28952,'Beale AFB','Beale AFB, California',36196,6);
INSERT INTO "django_geo_db_city" VALUES(28953,'Alleghany','Alleghany, California',36197,6);
INSERT INTO "django_geo_db_city" VALUES(28954,'Arbuckle','Arbuckle, California',36198,6);
INSERT INTO "django_geo_db_city" VALUES(28955,'Artois','Artois, California',36199,6);
INSERT INTO "django_geo_db_city" VALUES(28956,'Bangor','Bangor, California',36200,6);
INSERT INTO "django_geo_db_city" VALUES(28957,'Belden','Belden, California',36201,6);
INSERT INTO "django_geo_db_city" VALUES(28958,'Berry Creek','Berry Creek, California',36202,6);
INSERT INTO "django_geo_db_city" VALUES(28959,'Biggs','Biggs, California',36203,6);
INSERT INTO "django_geo_db_city" VALUES(28960,'Browns Valley','Browns Valley, California',36204,6);
INSERT INTO "django_geo_db_city" VALUES(28961,'Brownsville','Brownsville, California',36205,6);
INSERT INTO "django_geo_db_city" VALUES(28962,'Butte City','Butte City, California',36206,6);
INSERT INTO "django_geo_db_city" VALUES(28963,'Camptonville','Camptonville, California',36207,6);
INSERT INTO "django_geo_db_city" VALUES(28964,'Canyondam','Canyondam, California',36208,6);
INSERT INTO "django_geo_db_city" VALUES(28965,'Cedar Ridge','Cedar Ridge, California',36152,6);
INSERT INTO "django_geo_db_city" VALUES(28966,'Challenge','Challenge, California',36209,6);
INSERT INTO "django_geo_db_city" VALUES(28967,'Chico','Chico, California',36210,6);
INSERT INTO "django_geo_db_city" VALUES(28968,'Clipper Mills','Clipper Mills, California',36214,6);
INSERT INTO "django_geo_db_city" VALUES(28969,'College City','College City, California',36215,6);
INSERT INTO "django_geo_db_city" VALUES(28970,'Colusa','Colusa, California',36216,6);
INSERT INTO "django_geo_db_city" VALUES(28971,'Crescent Mills','Crescent Mills, California',36217,6);
INSERT INTO "django_geo_db_city" VALUES(28972,'Dobbins','Dobbins, California',36218,6);
INSERT INTO "django_geo_db_city" VALUES(28973,'Downieville','Downieville, California',36219,6);
INSERT INTO "django_geo_db_city" VALUES(28974,'Dunnigan','Dunnigan, California',36220,6);
INSERT INTO "django_geo_db_city" VALUES(28975,'Durham','Durham, California',36221,6);
INSERT INTO "django_geo_db_city" VALUES(28976,'Elk Creek','Elk Creek, California',36222,6);
INSERT INTO "django_geo_db_city" VALUES(28977,'Feather Falls','Feather Falls, California',36223,6);
INSERT INTO "django_geo_db_city" VALUES(28978,'Forbestown','Forbestown, California',36224,6);
INSERT INTO "django_geo_db_city" VALUES(28979,'Forest Ranch','Forest Ranch, California',36225,6);
INSERT INTO "django_geo_db_city" VALUES(28980,'Glenn','Glenn, California',36226,6);
INSERT INTO "django_geo_db_city" VALUES(28981,'Goodyears Bar','Goodyears Bar, California',36227,6);
INSERT INTO "django_geo_db_city" VALUES(28982,'Grass Valley','Grass Valley, California',36228,6);
INSERT INTO "django_geo_db_city" VALUES(28983,'Penn Valley','Penn Valley, California',36229,6);
INSERT INTO "django_geo_db_city" VALUES(28984,'Greenville','Greenville, California',36230,6);
INSERT INTO "django_geo_db_city" VALUES(28985,'Gridley','Gridley, California',36231,6);
INSERT INTO "django_geo_db_city" VALUES(28986,'Grimes','Grimes, California',36233,6);
INSERT INTO "django_geo_db_city" VALUES(28987,'Hamilton City','Hamilton City, California',36234,6);
INSERT INTO "django_geo_db_city" VALUES(28988,'Live Oak','Live Oak, California',36235,6);
INSERT INTO "django_geo_db_city" VALUES(28989,'Magalia','Magalia, California',36236,6);
INSERT INTO "django_geo_db_city" VALUES(28990,'Maxwell','Maxwell, California',36237,6);
INSERT INTO "django_geo_db_city" VALUES(28991,'Meadow Valley','Meadow Valley, California',36238,6);
INSERT INTO "django_geo_db_city" VALUES(28992,'Meridian','Meridian, California',36239,6);
INSERT INTO "django_geo_db_city" VALUES(28993,'Nelson','Nelson, California',36240,6);
INSERT INTO "django_geo_db_city" VALUES(28994,'Nevada City','Nevada City, California',36241,6);
INSERT INTO "django_geo_db_city" VALUES(28995,'North San Juan','North San Juan, California',36242,6);
INSERT INTO "django_geo_db_city" VALUES(28996,'Olivehurst','Olivehurst, California',36243,6);
INSERT INTO "django_geo_db_city" VALUES(28997,'Oregon House','Oregon House, California',36244,6);
INSERT INTO "django_geo_db_city" VALUES(28998,'Orland','Orland, California',36245,6);
INSERT INTO "django_geo_db_city" VALUES(28999,'Oroville','Oroville, California',36246,6);
INSERT INTO "django_geo_db_city" VALUES(29000,'Paradise','Paradise, California',36248,6);
INSERT INTO "django_geo_db_city" VALUES(29001,'Palermo','Palermo, California',36249,6);
INSERT INTO "django_geo_db_city" VALUES(29002,'Princeton','Princeton, California',36251,6);
INSERT INTO "django_geo_db_city" VALUES(29003,'Quincy','Quincy, California',36252,6);
INSERT INTO "django_geo_db_city" VALUES(29004,'Rackerby','Rackerby, California',36253,6);
INSERT INTO "django_geo_db_city" VALUES(29005,'Richvale','Richvale, California',36255,6);
INSERT INTO "django_geo_db_city" VALUES(29006,'Rough And Ready','Rough And Ready, California',36256,6);
INSERT INTO "django_geo_db_city" VALUES(29007,'Smartville','Smartville, California',36257,6);
INSERT INTO "django_geo_db_city" VALUES(29008,'Stirling City','Stirling City, California',36258,6);
INSERT INTO "django_geo_db_city" VALUES(29009,'Stonyford','Stonyford, California',36259,6);
INSERT INTO "django_geo_db_city" VALUES(29010,'Storrie','Storrie, California',36260,6);
INSERT INTO "django_geo_db_city" VALUES(29011,'Strawberry Valley','Strawberry Valley, California',36261,6);
INSERT INTO "django_geo_db_city" VALUES(29012,'Sutter','Sutter, California',36262,6);
INSERT INTO "django_geo_db_city" VALUES(29013,'Taylorsville','Taylorsville, California',36263,6);
INSERT INTO "django_geo_db_city" VALUES(29014,'Twain','Twain, California',36264,6);
INSERT INTO "django_geo_db_city" VALUES(29015,'Washington','Washington, California',36265,6);
INSERT INTO "django_geo_db_city" VALUES(29016,'Williams','Williams, California',36266,6);
INSERT INTO "django_geo_db_city" VALUES(29017,'Willows','Willows, California',36267,6);
INSERT INTO "django_geo_db_city" VALUES(29018,'Yuba City','Yuba City, California',36268,6);
INSERT INTO "django_geo_db_city" VALUES(29019,'Redding','Redding, California',36271,6);
INSERT INTO "django_geo_db_city" VALUES(29020,'Adin','Adin, California',36274,6);
INSERT INTO "django_geo_db_city" VALUES(29021,'Anderson','Anderson, California',36275,6);
INSERT INTO "django_geo_db_city" VALUES(29022,'Bella Vista','Bella Vista, California',36276,6);
INSERT INTO "django_geo_db_city" VALUES(29023,'Bieber','Bieber, California',36277,6);
INSERT INTO "django_geo_db_city" VALUES(29024,'Big Bar','Big Bar, California',36278,6);
INSERT INTO "django_geo_db_city" VALUES(29025,'Big Bend','Big Bend, California',36279,6);
INSERT INTO "django_geo_db_city" VALUES(29026,'Burney','Burney, California',36280,6);
INSERT INTO "django_geo_db_city" VALUES(29027,'Callahan','Callahan, California',36281,6);
INSERT INTO "django_geo_db_city" VALUES(29028,'Canby','Canby, California',36282,6);
INSERT INTO "django_geo_db_city" VALUES(29029,'Cassel','Cassel, California',36283,6);
INSERT INTO "django_geo_db_city" VALUES(29030,'Castella','Castella, California',36284,6);
INSERT INTO "django_geo_db_city" VALUES(29031,'Shasta Lake','Shasta Lake, California',36285,6);
INSERT INTO "django_geo_db_city" VALUES(29032,'Chester','Chester, California',36286,6);
INSERT INTO "django_geo_db_city" VALUES(29033,'Corning','Corning, California',36287,6);
INSERT INTO "django_geo_db_city" VALUES(29034,'Cottonwood','Cottonwood, California',36288,6);
INSERT INTO "django_geo_db_city" VALUES(29035,'Dorris','Dorris, California',36289,6);
INSERT INTO "django_geo_db_city" VALUES(29036,'Douglas City','Douglas City, California',36290,6);
INSERT INTO "django_geo_db_city" VALUES(29037,'Dunsmuir','Dunsmuir, California',36291,6);
INSERT INTO "django_geo_db_city" VALUES(29038,'Etna','Etna, California',36292,6);
INSERT INTO "django_geo_db_city" VALUES(29039,'Fall River Mills','Fall River Mills, California',36293,6);
INSERT INTO "django_geo_db_city" VALUES(29040,'Flournoy','Flournoy, California',36294,6);
INSERT INTO "django_geo_db_city" VALUES(29041,'Forks Of Salmon','Forks Of Salmon, California',36295,6);
INSERT INTO "django_geo_db_city" VALUES(29042,'Fort Jones','Fort Jones, California',36296,6);
INSERT INTO "django_geo_db_city" VALUES(29043,'French Gulch','French Gulch, California',36297,6);
INSERT INTO "django_geo_db_city" VALUES(29044,'Gazelle','Gazelle, California',36298,6);
INSERT INTO "django_geo_db_city" VALUES(29045,'Gerber','Gerber, California',36299,6);
INSERT INTO "django_geo_db_city" VALUES(29046,'Greenview','Greenview, California',36300,6);
INSERT INTO "django_geo_db_city" VALUES(29047,'Grenada','Grenada, California',36301,6);
INSERT INTO "django_geo_db_city" VALUES(29048,'Happy Camp','Happy Camp, California',36302,6);
INSERT INTO "django_geo_db_city" VALUES(29049,'Hat Creek','Hat Creek, California',36303,6);
INSERT INTO "django_geo_db_city" VALUES(29050,'Hayfork','Hayfork, California',36304,6);
INSERT INTO "django_geo_db_city" VALUES(29051,'Hornbrook','Hornbrook, California',36305,6);
INSERT INTO "django_geo_db_city" VALUES(29052,'Hyampom','Hyampom, California',36306,6);
INSERT INTO "django_geo_db_city" VALUES(29053,'Igo','Igo, California',36307,6);
INSERT INTO "django_geo_db_city" VALUES(29054,'Junction City','Junction City, California',36308,6);
INSERT INTO "django_geo_db_city" VALUES(29055,'Klamath River','Klamath River, California',36310,6);
INSERT INTO "django_geo_db_city" VALUES(29056,'Lakehead','Lakehead, California',36311,6);
INSERT INTO "django_geo_db_city" VALUES(29057,'Lewiston','Lewiston, California',36312,6);
INSERT INTO "django_geo_db_city" VALUES(29058,'Mcarthur','Mcarthur, California',36313,6);
INSERT INTO "django_geo_db_city" VALUES(29059,'Lookout','Lookout, California',36314,6);
INSERT INTO "django_geo_db_city" VALUES(29060,'Los Molinos','Los Molinos, California',36315,6);
INSERT INTO "django_geo_db_city" VALUES(29061,'Mccloud','Mccloud, California',36317,6);
INSERT INTO "django_geo_db_city" VALUES(29062,'Macdoel','Macdoel, California',36318,6);
INSERT INTO "django_geo_db_city" VALUES(29063,'Manton','Manton, California',36319,6);
INSERT INTO "django_geo_db_city" VALUES(29064,'Mill Creek','Mill Creek, California',36320,6);
INSERT INTO "django_geo_db_city" VALUES(29065,'Millville','Millville, California',36321,6);
INSERT INTO "django_geo_db_city" VALUES(29066,'Mineral','Mineral, California',36322,6);
INSERT INTO "django_geo_db_city" VALUES(29067,'Montague','Montague, California',36323,6);
INSERT INTO "django_geo_db_city" VALUES(29068,'Montgomery Creek','Montgomery Creek, California',36324,6);
INSERT INTO "django_geo_db_city" VALUES(29069,'Mount Shasta','Mount Shasta, California',36325,6);
INSERT INTO "django_geo_db_city" VALUES(29070,'Nubieber','Nubieber, California',36326,6);
INSERT INTO "django_geo_db_city" VALUES(29071,'Oak Run','Oak Run, California',36327,6);
INSERT INTO "django_geo_db_city" VALUES(29072,'Obrien','Obrien, California',36328,6);
INSERT INTO "django_geo_db_city" VALUES(29073,'Old Station','Old Station, California',36329,6);
INSERT INTO "django_geo_db_city" VALUES(29074,'Palo Cedro','Palo Cedro, California',36330,6);
INSERT INTO "django_geo_db_city" VALUES(29075,'Paskenta','Paskenta, California',36331,6);
INSERT INTO "django_geo_db_city" VALUES(29076,'Paynes Creek','Paynes Creek, California',36332,6);
INSERT INTO "django_geo_db_city" VALUES(29077,'Platina','Platina, California',36333,6);
INSERT INTO "django_geo_db_city" VALUES(29078,'Proberta','Proberta, California',36334,6);
INSERT INTO "django_geo_db_city" VALUES(29079,'Red Bluff','Red Bluff, California',36336,6);
INSERT INTO "django_geo_db_city" VALUES(29080,'Round Mountain','Round Mountain, California',36337,6);
INSERT INTO "django_geo_db_city" VALUES(29081,'Scott Bar','Scott Bar, California',36338,6);
INSERT INTO "django_geo_db_city" VALUES(29082,'Seiad Valley','Seiad Valley, California',36339,6);
INSERT INTO "django_geo_db_city" VALUES(29083,'Shasta','Shasta, California',36340,6);
INSERT INTO "django_geo_db_city" VALUES(29084,'Shingletown','Shingletown, California',36341,6);
INSERT INTO "django_geo_db_city" VALUES(29085,'Tehama','Tehama, California',36343,6);
INSERT INTO "django_geo_db_city" VALUES(29086,'Trinity Center','Trinity Center, California',36344,6);
INSERT INTO "django_geo_db_city" VALUES(29087,'Vina','Vina, California',36345,6);
INSERT INTO "django_geo_db_city" VALUES(29088,'Weaverville','Weaverville, California',36346,6);
INSERT INTO "django_geo_db_city" VALUES(29089,'Weed','Weed, California',36347,6);
INSERT INTO "django_geo_db_city" VALUES(29090,'Whiskeytown','Whiskeytown, California',36348,6);
INSERT INTO "django_geo_db_city" VALUES(29091,'Whitmore','Whitmore, California',36349,6);
INSERT INTO "django_geo_db_city" VALUES(29092,'Yreka','Yreka, California',36350,6);
INSERT INTO "django_geo_db_city" VALUES(29093,'Alturas','Alturas, California',36352,6);
INSERT INTO "django_geo_db_city" VALUES(29094,'Blairsden-Graeagle','Blairsden-Graeagle, California',36353,6);
INSERT INTO "django_geo_db_city" VALUES(29095,'Cedarville','Cedarville, California',36354,6);
INSERT INTO "django_geo_db_city" VALUES(29096,'Chilcoot','Chilcoot, California',36355,6);
INSERT INTO "django_geo_db_city" VALUES(29097,'Clio','Clio, California',36356,6);
INSERT INTO "django_geo_db_city" VALUES(29098,'Coleville','Coleville, California',36357,6);
INSERT INTO "django_geo_db_city" VALUES(29099,'Davis Creek','Davis Creek, California',36358,6);
INSERT INTO "django_geo_db_city" VALUES(29100,'Doyle','Doyle, California',36359,6);
INSERT INTO "django_geo_db_city" VALUES(29101,'Eagleville','Eagleville, California',36360,6);
INSERT INTO "django_geo_db_city" VALUES(29102,'Floriston','Floriston, California',36361,6);
INSERT INTO "django_geo_db_city" VALUES(29103,'Fort Bidwell','Fort Bidwell, California',36362,6);
INSERT INTO "django_geo_db_city" VALUES(29104,'Herlong','Herlong, California',36363,6);
INSERT INTO "django_geo_db_city" VALUES(29105,'Janesville','Janesville, California',36364,6);
INSERT INTO "django_geo_db_city" VALUES(29106,'Lake City','Lake City, California',36365,6);
INSERT INTO "django_geo_db_city" VALUES(29107,'Likely','Likely, California',36366,6);
INSERT INTO "django_geo_db_city" VALUES(29108,'Litchfield','Litchfield, California',36367,6);
INSERT INTO "django_geo_db_city" VALUES(29109,'Loyalton','Loyalton, California',36368,6);
INSERT INTO "django_geo_db_city" VALUES(29110,'Madeline','Madeline, California',36369,6);
INSERT INTO "django_geo_db_city" VALUES(29111,'Markleeville','Markleeville, California',36370,6);
INSERT INTO "django_geo_db_city" VALUES(29112,'Milford','Milford, California',36371,6);
INSERT INTO "django_geo_db_city" VALUES(29113,'Portola','Portola, California',36372,6);
INSERT INTO "django_geo_db_city" VALUES(29114,'Ravendale','Ravendale, California',36373,6);
INSERT INTO "django_geo_db_city" VALUES(29115,'Calpine','Calpine, California',36374,6);
INSERT INTO "django_geo_db_city" VALUES(29116,'Sierra City','Sierra City, California',36375,6);
INSERT INTO "django_geo_db_city" VALUES(29117,'Sierraville','Sierraville, California',36376,6);
INSERT INTO "django_geo_db_city" VALUES(29118,'Susanville','Susanville, California',36313,6);
INSERT INTO "django_geo_db_city" VALUES(29119,'Standish','Standish, California',36377,6);
INSERT INTO "django_geo_db_city" VALUES(29120,'Beckwourth','Beckwourth, California',36378,6);
INSERT INTO "django_geo_db_city" VALUES(29121,'Termo','Termo, California',36380,6);
INSERT INTO "django_geo_db_city" VALUES(29122,'Topaz','Topaz, California',36381,6);
INSERT INTO "django_geo_db_city" VALUES(29123,'Tulelake','Tulelake, California',36382,6);
INSERT INTO "django_geo_db_city" VALUES(29124,'Vinton','Vinton, California',36383,6);
INSERT INTO "django_geo_db_city" VALUES(29125,'Wendel','Wendel, California',36384,6);
INSERT INTO "django_geo_db_city" VALUES(29126,'Westwood','Westwood, California',36385,6);
INSERT INTO "django_geo_db_city" VALUES(29127,'Carnelian Bay','Carnelian Bay, California',36386,6);
INSERT INTO "django_geo_db_city" VALUES(29128,'Homewood','Homewood, California',36387,6);
INSERT INTO "django_geo_db_city" VALUES(29129,'Tahoma','Tahoma, California',36388,6);
INSERT INTO "django_geo_db_city" VALUES(29130,'Kings Beach','Kings Beach, California',36389,6);
INSERT INTO "django_geo_db_city" VALUES(29131,'Tahoe City','Tahoe City, California',36390,6);
INSERT INTO "django_geo_db_city" VALUES(29132,'Olympic Valley','Olympic Valley, California',36391,6);
INSERT INTO "django_geo_db_city" VALUES(29133,'Tahoe Vista','Tahoe Vista, California',36392,6);
INSERT INTO "django_geo_db_city" VALUES(29134,'South Lake Tahoe','South Lake Tahoe, California',36393,6);
INSERT INTO "django_geo_db_city" VALUES(29135,'Truckee','Truckee, California',36401,6);
INSERT INTO "django_geo_db_city" VALUES(29136,'Kawela Bay','Kawela Bay, Hawaii',36405,15);
INSERT INTO "django_geo_db_city" VALUES(29137,'Hawaiian Ocean View','Hawaiian Ocean View, Hawaii',36406,15);
INSERT INTO "django_geo_db_city" VALUES(29138,'Volcano','Volcano, Hawaii',36407,15);
INSERT INTO "django_geo_db_city" VALUES(29139,'Kaneohe','Kaneohe, Hawaii',36408,15);
INSERT INTO "django_geo_db_city" VALUES(29140,'Aiea','Aiea, Hawaii',36409,15);
INSERT INTO "django_geo_db_city" VALUES(29141,'Anahola','Anahola, Hawaii',36410,15);
INSERT INTO "django_geo_db_city" VALUES(29142,'Captain Cook','Captain Cook, Hawaii',36411,15);
INSERT INTO "django_geo_db_city" VALUES(29143,'Eleele','Eleele, Hawaii',36412,15);
INSERT INTO "django_geo_db_city" VALUES(29144,'Ewa Beach','Ewa Beach, Hawaii',36413,15);
INSERT INTO "django_geo_db_city" VALUES(29145,'Kapolei','Kapolei, Hawaii',36414,15);
INSERT INTO "django_geo_db_city" VALUES(29146,'Haiku','Haiku, Hawaii',36415,15);
INSERT INTO "django_geo_db_city" VALUES(29147,'Hakalau','Hakalau, Hawaii',36417,15);
INSERT INTO "django_geo_db_city" VALUES(29148,'Haleiwa','Haleiwa, Hawaii',36418,15);
INSERT INTO "django_geo_db_city" VALUES(29149,'Hana','Hana, Hawaii',36419,15);
INSERT INTO "django_geo_db_city" VALUES(29150,'Hanalei','Hanalei, Hawaii',36420,15);
INSERT INTO "django_geo_db_city" VALUES(29151,'Hanamaulu','Hanamaulu, Hawaii',36421,15);
INSERT INTO "django_geo_db_city" VALUES(29152,'Hanapepe','Hanapepe, Hawaii',36422,15);
INSERT INTO "django_geo_db_city" VALUES(29153,'Hauula','Hauula, Hawaii',36423,15);
INSERT INTO "django_geo_db_city" VALUES(29154,'Hawaii National Park','Hawaii National Park, Hawaii',36424,15);
INSERT INTO "django_geo_db_city" VALUES(29155,'Hawi','Hawi, Hawaii',36425,15);
INSERT INTO "django_geo_db_city" VALUES(29156,'Hilo','Hilo, Hawaii',36426,15);
INSERT INTO "django_geo_db_city" VALUES(29157,'Princeville','Princeville, Hawaii',36428,15);
INSERT INTO "django_geo_db_city" VALUES(29158,'Holualoa','Holualoa, Hawaii',36429,15);
INSERT INTO "django_geo_db_city" VALUES(29159,'Honaunau','Honaunau, Hawaii',36430,15);
INSERT INTO "django_geo_db_city" VALUES(29160,'Honokaa','Honokaa, Hawaii',36431,15);
INSERT INTO "django_geo_db_city" VALUES(29161,'Honomu','Honomu, Hawaii',36432,15);
INSERT INTO "django_geo_db_city" VALUES(29162,'Hoolehua','Hoolehua, Hawaii',36433,15);
INSERT INTO "django_geo_db_city" VALUES(29163,'Kaaawa','Kaaawa, Hawaii',36434,15);
INSERT INTO "django_geo_db_city" VALUES(29164,'Kahuku','Kahuku, Hawaii',36435,15);
INSERT INTO "django_geo_db_city" VALUES(29165,'Kahului','Kahului, Hawaii',36436,15);
INSERT INTO "django_geo_db_city" VALUES(29166,'Kailua','Kailua, Hawaii',36438,15);
INSERT INTO "django_geo_db_city" VALUES(29167,'Ocean View','Ocean View, Hawaii',36439,15);
INSERT INTO "django_geo_db_city" VALUES(29168,'Waikoloa','Waikoloa, Hawaii',36440,15);
INSERT INTO "django_geo_db_city" VALUES(29169,'Keauhou','Keauhou, Hawaii',36427,15);
INSERT INTO "django_geo_db_city" VALUES(29170,'Kailua Kona','Kailua Kona, Hawaii',36441,15);
INSERT INTO "django_geo_db_city" VALUES(29171,'Kalaheo','Kalaheo, Hawaii',36442,15);
INSERT INTO "django_geo_db_city" VALUES(29172,'Kalaupapa','Kalaupapa, Hawaii',36443,15);
INSERT INTO "django_geo_db_city" VALUES(29173,'Kamuela','Kamuela, Hawaii',36444,15);
INSERT INTO "django_geo_db_city" VALUES(29174,'Kapaa','Kapaa, Hawaii',36446,15);
INSERT INTO "django_geo_db_city" VALUES(29175,'Kaumakani','Kaumakani, Hawaii',36447,15);
INSERT INTO "django_geo_db_city" VALUES(29176,'Kaunakakai','Kaunakakai, Hawaii',36448,15);
INSERT INTO "django_geo_db_city" VALUES(29177,'Keaau','Keaau, Hawaii',36449,15);
INSERT INTO "django_geo_db_city" VALUES(29178,'Kealakekua','Kealakekua, Hawaii',36450,15);
INSERT INTO "django_geo_db_city" VALUES(29179,'Kealia','Kealia, Hawaii',36451,15);
INSERT INTO "django_geo_db_city" VALUES(29180,'Kekaha','Kekaha, Hawaii',36452,15);
INSERT INTO "django_geo_db_city" VALUES(29181,'Kihei','Kihei, Hawaii',36453,15);
INSERT INTO "django_geo_db_city" VALUES(29182,'Kilauea','Kilauea, Hawaii',36454,15);
INSERT INTO "django_geo_db_city" VALUES(29183,'Kapaau','Kapaau, Hawaii',36455,15);
INSERT INTO "django_geo_db_city" VALUES(29184,'Koloa','Koloa, Hawaii',36456,15);
INSERT INTO "django_geo_db_city" VALUES(29185,'Kualapuu','Kualapuu, Hawaii',36457,15);
INSERT INTO "django_geo_db_city" VALUES(29186,'Kunia','Kunia, Hawaii',36458,15);
INSERT INTO "django_geo_db_city" VALUES(29187,'Kurtistown','Kurtistown, Hawaii',36459,15);
INSERT INTO "django_geo_db_city" VALUES(29188,'Lahaina','Lahaina, Hawaii',36460,15);
INSERT INTO "django_geo_db_city" VALUES(29189,'Laie','Laie, Hawaii',36461,15);
INSERT INTO "django_geo_db_city" VALUES(29190,'Lanai City','Lanai City, Hawaii',36462,15);
INSERT INTO "django_geo_db_city" VALUES(29191,'Laupahoehoe','Laupahoehoe, Hawaii',36463,15);
INSERT INTO "django_geo_db_city" VALUES(29192,'Lawai','Lawai, Hawaii',36464,15);
INSERT INTO "django_geo_db_city" VALUES(29193,'Lihue','Lihue, Hawaii',36465,15);
INSERT INTO "django_geo_db_city" VALUES(29194,'Makawao','Makawao, Hawaii',36466,15);
INSERT INTO "django_geo_db_city" VALUES(29195,'Makaweli','Makaweli, Hawaii',36467,15);
INSERT INTO "django_geo_db_city" VALUES(29196,'Maunaloa','Maunaloa, Hawaii',36468,15);
INSERT INTO "django_geo_db_city" VALUES(29197,'Mountain View','Mountain View, Hawaii',36469,15);
INSERT INTO "django_geo_db_city" VALUES(29198,'Naalehu','Naalehu, Hawaii',36470,15);
INSERT INTO "django_geo_db_city" VALUES(29199,'Ninole','Ninole, Hawaii',36471,15);
INSERT INTO "django_geo_db_city" VALUES(29200,'Ookala','Ookala, Hawaii',36472,15);
INSERT INTO "django_geo_db_city" VALUES(29201,'Paauhau','Paauhau, Hawaii',36427,15);
INSERT INTO "django_geo_db_city" VALUES(29202,'Paauilo','Paauilo, Hawaii',36473,15);
INSERT INTO "django_geo_db_city" VALUES(29203,'Pahala','Pahala, Hawaii',36474,15);
INSERT INTO "django_geo_db_city" VALUES(29204,'Pahoa','Pahoa, Hawaii',36475,15);
INSERT INTO "django_geo_db_city" VALUES(29205,'Paia','Paia, Hawaii',36476,15);
INSERT INTO "django_geo_db_city" VALUES(29206,'Papaaloa','Papaaloa, Hawaii',36477,15);
INSERT INTO "django_geo_db_city" VALUES(29207,'Papaikou','Papaikou, Hawaii',36478,15);
INSERT INTO "django_geo_db_city" VALUES(29208,'Pearl City','Pearl City, Hawaii',36479,15);
INSERT INTO "django_geo_db_city" VALUES(29209,'Pepeekeo','Pepeekeo, Hawaii',36480,15);
INSERT INTO "django_geo_db_city" VALUES(29210,'Puunene','Puunene, Hawaii',36437,15);
INSERT INTO "django_geo_db_city" VALUES(29211,'Wahiawa','Wahiawa, Hawaii',36482,15);
INSERT INTO "django_geo_db_city" VALUES(29212,'Pukalani','Pukalani, Hawaii',36483,15);
INSERT INTO "django_geo_db_city" VALUES(29213,'Mililani','Mililani, Hawaii',36484,15);
INSERT INTO "django_geo_db_city" VALUES(29214,'Kula','Kula, Hawaii',36485,15);
INSERT INTO "django_geo_db_city" VALUES(29215,'Waialua','Waialua, Hawaii',36486,15);
INSERT INTO "django_geo_db_city" VALUES(29216,'Waianae','Waianae, Hawaii',36487,15);
INSERT INTO "django_geo_db_city" VALUES(29217,'Wailuku','Wailuku, Hawaii',36488,15);
INSERT INTO "django_geo_db_city" VALUES(29218,'Waimanalo','Waimanalo, Hawaii',36489,15);
INSERT INTO "django_geo_db_city" VALUES(29219,'Waimea','Waimea, Hawaii',36490,15);
INSERT INTO "django_geo_db_city" VALUES(29220,'Waipahu','Waipahu, Hawaii',36491,15);
INSERT INTO "django_geo_db_city" VALUES(29221,'Pago Pago','Pago Pago, American Samoa',239,5);
INSERT INTO "django_geo_db_city" VALUES(29222,'Honolulu','Honolulu, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29223,'Hickam AFB','Hickam AFB, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29224,'Wheeler Army Airfield','Wheeler Army Airfield, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29225,'Schofield Barracks','Schofield Barracks, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29226,'Fort Shafter','Fort Shafter, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29227,'Tripler Army Medical Ctr','Tripler Army Medical Ctr, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29228,'Pearl Harbor','Pearl Harbor, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29229,'Camp H M Smith','Camp H M Smith, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29230,'Barbers Point N A S','Barbers Point N A S, Hawaii',36504,15);
INSERT INTO "django_geo_db_city" VALUES(29231,'M C B H Kaneohe Bay','M C B H Kaneohe Bay, Hawaii',36505,15);
INSERT INTO "django_geo_db_city" VALUES(29232,'Wake Island','Wake Island, Hawaii',36492,15);
INSERT INTO "django_geo_db_city" VALUES(29233,'Antelope','Antelope, Oregon',36507,37);
INSERT INTO "django_geo_db_city" VALUES(29234,'Aurora','Aurora, Oregon',36508,37);
INSERT INTO "django_geo_db_city" VALUES(29235,'Beavercreek','Beavercreek, Oregon',36509,37);
INSERT INTO "django_geo_db_city" VALUES(29236,'Beaverton','Beaverton, Oregon',36510,37);
INSERT INTO "django_geo_db_city" VALUES(29237,'Boring','Boring, Oregon',36514,37);
INSERT INTO "django_geo_db_city" VALUES(29238,'Bridal Veil','Bridal Veil, Oregon',36515,37);
INSERT INTO "django_geo_db_city" VALUES(29239,'Brightwood','Brightwood, Oregon',36516,37);
INSERT INTO "django_geo_db_city" VALUES(29240,'Canby','Canby, Oregon',36517,37);
INSERT INTO "django_geo_db_city" VALUES(29241,'Cascade Locks','Cascade Locks, Oregon',36518,37);
INSERT INTO "django_geo_db_city" VALUES(29242,'Clackamas','Clackamas, Oregon',36519,37);
INSERT INTO "django_geo_db_city" VALUES(29243,'Clatskanie','Clatskanie, Oregon',36520,37);
INSERT INTO "django_geo_db_city" VALUES(29244,'Colton','Colton, Oregon',36521,37);
INSERT INTO "django_geo_db_city" VALUES(29245,'Columbia City','Columbia City, Oregon',36522,37);
INSERT INTO "django_geo_db_city" VALUES(29246,'Corbett','Corbett, Oregon',36523,37);
INSERT INTO "django_geo_db_city" VALUES(29247,'Donald','Donald, Oregon',36524,37);
INSERT INTO "django_geo_db_city" VALUES(29248,'Dufur','Dufur, Oregon',36525,37);
INSERT INTO "django_geo_db_city" VALUES(29249,'Eagle Creek','Eagle Creek, Oregon',36526,37);
INSERT INTO "django_geo_db_city" VALUES(29250,'Estacada','Estacada, Oregon',36527,37);
INSERT INTO "django_geo_db_city" VALUES(29251,'Fairview','Fairview, Oregon',36528,37);
INSERT INTO "django_geo_db_city" VALUES(29252,'Gervais','Gervais, Oregon',36529,37);
INSERT INTO "django_geo_db_city" VALUES(29253,'Gladstone','Gladstone, Oregon',36530,37);
INSERT INTO "django_geo_db_city" VALUES(29254,'Government Camp','Government Camp, Oregon',36531,37);
INSERT INTO "django_geo_db_city" VALUES(29255,'Grass Valley','Grass Valley, Oregon',36532,37);
INSERT INTO "django_geo_db_city" VALUES(29256,'Gresham','Gresham, Oregon',36533,37);
INSERT INTO "django_geo_db_city" VALUES(29257,'Hood River','Hood River, Oregon',36534,37);
INSERT INTO "django_geo_db_city" VALUES(29258,'Hubbard','Hubbard, Oregon',36535,37);
INSERT INTO "django_geo_db_city" VALUES(29259,'Kent','Kent, Oregon',36536,37);
INSERT INTO "django_geo_db_city" VALUES(29260,'Lake Oswego','Lake Oswego, Oregon',36537,37);
INSERT INTO "django_geo_db_city" VALUES(29261,'Marylhurst','Marylhurst, Oregon',36539,37);
INSERT INTO "django_geo_db_city" VALUES(29262,'Maupin','Maupin, Oregon',36540,37);
INSERT INTO "django_geo_db_city" VALUES(29263,'Molalla','Molalla, Oregon',36541,37);
INSERT INTO "django_geo_db_city" VALUES(29264,'Moro','Moro, Oregon',36542,37);
INSERT INTO "django_geo_db_city" VALUES(29265,'Mosier','Mosier, Oregon',36543,37);
INSERT INTO "django_geo_db_city" VALUES(29266,'Mount Hood Parkdale','Mount Hood Parkdale, Oregon',36544,37);
INSERT INTO "django_geo_db_city" VALUES(29267,'Mulino','Mulino, Oregon',36545,37);
INSERT INTO "django_geo_db_city" VALUES(29268,'Odell','Odell, Oregon',36546,37);
INSERT INTO "django_geo_db_city" VALUES(29269,'Oregon City','Oregon City, Oregon',36547,37);
INSERT INTO "django_geo_db_city" VALUES(29270,'Rainier','Rainier, Oregon',36548,37);
INSERT INTO "django_geo_db_city" VALUES(29271,'Rhododendron','Rhododendron, Oregon',36549,37);
INSERT INTO "django_geo_db_city" VALUES(29272,'Rufus','Rufus, Oregon',36550,37);
INSERT INTO "django_geo_db_city" VALUES(29273,'Saint Helens','Saint Helens, Oregon',36551,37);
INSERT INTO "django_geo_db_city" VALUES(29274,'Warren','Warren, Oregon',36552,37);
INSERT INTO "django_geo_db_city" VALUES(29275,'Deer Island','Deer Island, Oregon',36553,37);
INSERT INTO "django_geo_db_city" VALUES(29276,'Sandy','Sandy, Oregon',36554,37);
INSERT INTO "django_geo_db_city" VALUES(29277,'Scappoose','Scappoose, Oregon',36555,37);
INSERT INTO "django_geo_db_city" VALUES(29278,'Shaniko','Shaniko, Oregon',36556,37);
INSERT INTO "django_geo_db_city" VALUES(29279,'The Dalles','The Dalles, Oregon',36557,37);
INSERT INTO "django_geo_db_city" VALUES(29280,'Troutdale','Troutdale, Oregon',36558,37);
INSERT INTO "django_geo_db_city" VALUES(29281,'Tualatin','Tualatin, Oregon',36559,37);
INSERT INTO "django_geo_db_city" VALUES(29282,'Tygh Valley','Tygh Valley, Oregon',36560,37);
INSERT INTO "django_geo_db_city" VALUES(29283,'Vernonia','Vernonia, Oregon',36561,37);
INSERT INTO "django_geo_db_city" VALUES(29284,'Wasco','Wasco, Oregon',36562,37);
INSERT INTO "django_geo_db_city" VALUES(29285,'Welches','Welches, Oregon',36563,37);
INSERT INTO "django_geo_db_city" VALUES(29286,'West Linn','West Linn, Oregon',36564,37);
INSERT INTO "django_geo_db_city" VALUES(29287,'Wilsonville','Wilsonville, Oregon',36565,37);
INSERT INTO "django_geo_db_city" VALUES(29288,'Woodburn','Woodburn, Oregon',36566,37);
INSERT INTO "django_geo_db_city" VALUES(29289,'Amity','Amity, Oregon',36570,37);
INSERT INTO "django_geo_db_city" VALUES(29290,'Arch Cape','Arch Cape, Oregon',36571,37);
INSERT INTO "django_geo_db_city" VALUES(29291,'Astoria','Astoria, Oregon',36572,37);
INSERT INTO "django_geo_db_city" VALUES(29292,'Hillsboro','Hillsboro, Oregon',36573,37);
INSERT INTO "django_geo_db_city" VALUES(29293,'Banks','Banks, Oregon',36574,37);
INSERT INTO "django_geo_db_city" VALUES(29294,'Bay City','Bay City, Oregon',36575,37);
INSERT INTO "django_geo_db_city" VALUES(29295,'Beaver','Beaver, Oregon',36576,37);
INSERT INTO "django_geo_db_city" VALUES(29296,'Buxton','Buxton, Oregon',36577,37);
INSERT INTO "django_geo_db_city" VALUES(29297,'Cannon Beach','Cannon Beach, Oregon',36578,37);
INSERT INTO "django_geo_db_city" VALUES(29298,'Carlton','Carlton, Oregon',36579,37);
INSERT INTO "django_geo_db_city" VALUES(29299,'Cloverdale','Cloverdale, Oregon',36580,37);
INSERT INTO "django_geo_db_city" VALUES(29300,'Cornelius','Cornelius, Oregon',36581,37);
INSERT INTO "django_geo_db_city" VALUES(29301,'Dayton','Dayton, Oregon',36582,37);
INSERT INTO "django_geo_db_city" VALUES(29302,'Dundee','Dundee, Oregon',36583,37);
INSERT INTO "django_geo_db_city" VALUES(29303,'Forest Grove','Forest Grove, Oregon',36584,37);
INSERT INTO "django_geo_db_city" VALUES(29304,'Gales Creek','Gales Creek, Oregon',36585,37);
INSERT INTO "django_geo_db_city" VALUES(29305,'Garibaldi','Garibaldi, Oregon',36586,37);
INSERT INTO "django_geo_db_city" VALUES(29306,'Gaston','Gaston, Oregon',36587,37);
INSERT INTO "django_geo_db_city" VALUES(29307,'Hammond','Hammond, Oregon',36588,37);
INSERT INTO "django_geo_db_city" VALUES(29308,'Hebo','Hebo, Oregon',36589,37);
INSERT INTO "django_geo_db_city" VALUES(29309,'Manning','Manning, Oregon',36592,37);
INSERT INTO "django_geo_db_city" VALUES(29310,'Lafayette','Lafayette, Oregon',36593,37);
INSERT INTO "django_geo_db_city" VALUES(29311,'Mcminnville','Mcminnville, Oregon',36594,37);
INSERT INTO "django_geo_db_city" VALUES(29312,'Manzanita','Manzanita, Oregon',36595,37);
INSERT INTO "django_geo_db_city" VALUES(29313,'Nehalem','Nehalem, Oregon',36596,37);
INSERT INTO "django_geo_db_city" VALUES(29314,'Newberg','Newberg, Oregon',36597,37);
INSERT INTO "django_geo_db_city" VALUES(29315,'North Plains','North Plains, Oregon',36598,37);
INSERT INTO "django_geo_db_city" VALUES(29316,'Oceanside','Oceanside, Oregon',36599,37);
INSERT INTO "django_geo_db_city" VALUES(29317,'Pacific City','Pacific City, Oregon',36600,37);
INSERT INTO "django_geo_db_city" VALUES(29318,'Rockaway Beach','Rockaway Beach, Oregon',36601,37);
INSERT INTO "django_geo_db_city" VALUES(29319,'Saint Paul','Saint Paul, Oregon',36602,37);
INSERT INTO "django_geo_db_city" VALUES(29320,'Seaside','Seaside, Oregon',36603,37);
INSERT INTO "django_geo_db_city" VALUES(29321,'Sherwood','Sherwood, Oregon',36604,37);
INSERT INTO "django_geo_db_city" VALUES(29322,'Tillamook','Tillamook, Oregon',36605,37);
INSERT INTO "django_geo_db_city" VALUES(29323,'Netarts','Netarts, Oregon',36606,37);
INSERT INTO "django_geo_db_city" VALUES(29324,'Timber','Timber, Oregon',36607,37);
INSERT INTO "django_geo_db_city" VALUES(29325,'Tolovana Park','Tolovana Park, Oregon',36608,37);
INSERT INTO "django_geo_db_city" VALUES(29326,'Warrenton','Warrenton, Oregon',36609,37);
INSERT INTO "django_geo_db_city" VALUES(29327,'Wheeler','Wheeler, Oregon',36610,37);
INSERT INTO "django_geo_db_city" VALUES(29328,'Yamhill','Yamhill, Oregon',36611,37);
INSERT INTO "django_geo_db_city" VALUES(29329,'Neskowin','Neskowin, Oregon',36612,37);
INSERT INTO "django_geo_db_city" VALUES(29330,'Portland','Portland, Oregon',36614,37);
INSERT INTO "django_geo_db_city" VALUES(29331,'Raleigh Hills','Raleigh Hills, Oregon',36639,37);
INSERT INTO "django_geo_db_city" VALUES(29332,'Grants Pass','Grants Pass, Oregon',36650,37);
INSERT INTO "django_geo_db_city" VALUES(29333,'Chiloquin','Chiloquin, Oregon',36651,37);
INSERT INTO "django_geo_db_city" VALUES(29334,'Salem','Salem, Oregon',36654,37);
INSERT INTO "django_geo_db_city" VALUES(29335,'Keizer','Keizer, Oregon',36660,37);
INSERT INTO "django_geo_db_city" VALUES(29336,'Albany','Albany, Oregon',36666,37);
INSERT INTO "django_geo_db_city" VALUES(29337,'Alsea','Alsea, Oregon',36668,37);
INSERT INTO "django_geo_db_city" VALUES(29338,'Aumsville','Aumsville, Oregon',36669,37);
INSERT INTO "django_geo_db_city" VALUES(29339,'Blodgett','Blodgett, Oregon',36670,37);
INSERT INTO "django_geo_db_city" VALUES(29340,'Brownsville','Brownsville, Oregon',36671,37);
INSERT INTO "django_geo_db_city" VALUES(29341,'Cascadia','Cascadia, Oregon',36672,37);
INSERT INTO "django_geo_db_city" VALUES(29342,'Corvallis','Corvallis, Oregon',36673,37);
INSERT INTO "django_geo_db_city" VALUES(29343,'Crabtree','Crabtree, Oregon',36676,37);
INSERT INTO "django_geo_db_city" VALUES(29344,'Crawfordsville','Crawfordsville, Oregon',36677,37);
INSERT INTO "django_geo_db_city" VALUES(29345,'Dallas','Dallas, Oregon',36678,37);
INSERT INTO "django_geo_db_city" VALUES(29346,'Depoe Bay','Depoe Bay, Oregon',36680,37);
INSERT INTO "django_geo_db_city" VALUES(29347,'Detroit','Detroit, Oregon',36681,37);
INSERT INTO "django_geo_db_city" VALUES(29348,'Eddyville','Eddyville, Oregon',36682,37);
INSERT INTO "django_geo_db_city" VALUES(29349,'Falls City','Falls City, Oregon',36683,37);
INSERT INTO "django_geo_db_city" VALUES(29350,'Foster','Foster, Oregon',36684,37);
INSERT INTO "django_geo_db_city" VALUES(29351,'Gates','Gates, Oregon',36685,37);
INSERT INTO "django_geo_db_city" VALUES(29352,'Grand Ronde','Grand Ronde, Oregon',36686,37);
INSERT INTO "django_geo_db_city" VALUES(29353,'Halsey','Halsey, Oregon',36687,37);
INSERT INTO "django_geo_db_city" VALUES(29354,'Idanha','Idanha, Oregon',36688,37);
INSERT INTO "django_geo_db_city" VALUES(29355,'Independence','Independence, Oregon',36689,37);
INSERT INTO "django_geo_db_city" VALUES(29356,'Jefferson','Jefferson, Oregon',36690,37);
INSERT INTO "django_geo_db_city" VALUES(29357,'Lebanon','Lebanon, Oregon',36691,37);
INSERT INTO "django_geo_db_city" VALUES(29358,'Logsden','Logsden, Oregon',36692,37);
INSERT INTO "django_geo_db_city" VALUES(29359,'Lyons','Lyons, Oregon',36693,37);
INSERT INTO "django_geo_db_city" VALUES(29360,'Marion','Marion, Oregon',36660,37);
INSERT INTO "django_geo_db_city" VALUES(29361,'Mill City','Mill City, Oregon',36694,37);
INSERT INTO "django_geo_db_city" VALUES(29362,'Monmouth','Monmouth, Oregon',36695,37);
INSERT INTO "django_geo_db_city" VALUES(29363,'Mount Angel','Mount Angel, Oregon',36696,37);
INSERT INTO "django_geo_db_city" VALUES(29364,'Neotsu','Neotsu, Oregon',36697,37);
INSERT INTO "django_geo_db_city" VALUES(29365,'Newport','Newport, Oregon',36698,37);
INSERT INTO "django_geo_db_city" VALUES(29366,'South Beach','South Beach, Oregon',36699,37);
INSERT INTO "django_geo_db_city" VALUES(29367,'Lincoln City','Lincoln City, Oregon',36700,37);
INSERT INTO "django_geo_db_city" VALUES(29368,'Otis','Otis, Oregon',36701,37);
INSERT INTO "django_geo_db_city" VALUES(29369,'Otter Rock','Otter Rock, Oregon',36702,37);
INSERT INTO "django_geo_db_city" VALUES(29370,'Philomath','Philomath, Oregon',36703,37);
INSERT INTO "django_geo_db_city" VALUES(29371,'Rickreall','Rickreall, Oregon',36704,37);
INSERT INTO "django_geo_db_city" VALUES(29372,'Rose Lodge','Rose Lodge, Oregon',36705,37);
INSERT INTO "django_geo_db_city" VALUES(29373,'Saint Benedict','Saint Benedict, Oregon',36660,37);
INSERT INTO "django_geo_db_city" VALUES(29374,'Scio','Scio, Oregon',36706,37);
INSERT INTO "django_geo_db_city" VALUES(29375,'Scotts Mills','Scotts Mills, Oregon',36707,37);
INSERT INTO "django_geo_db_city" VALUES(29376,'Seal Rock','Seal Rock, Oregon',36708,37);
INSERT INTO "django_geo_db_city" VALUES(29377,'Shedd','Shedd, Oregon',36709,37);
INSERT INTO "django_geo_db_city" VALUES(29378,'Sheridan','Sheridan, Oregon',36710,37);
INSERT INTO "django_geo_db_city" VALUES(29379,'Siletz','Siletz, Oregon',36711,37);
INSERT INTO "django_geo_db_city" VALUES(29380,'Silverton','Silverton, Oregon',36712,37);
INSERT INTO "django_geo_db_city" VALUES(29381,'Stayton','Stayton, Oregon',36713,37);
INSERT INTO "django_geo_db_city" VALUES(29382,'Mehama','Mehama, Oregon',36714,37);
INSERT INTO "django_geo_db_city" VALUES(29383,'Sublimity','Sublimity, Oregon',36715,37);
INSERT INTO "django_geo_db_city" VALUES(29384,'Sweet Home','Sweet Home, Oregon',36716,37);
INSERT INTO "django_geo_db_city" VALUES(29385,'Gleneden Beach','Gleneden Beach, Oregon',36717,37);
INSERT INTO "django_geo_db_city" VALUES(29386,'Tangent','Tangent, Oregon',36718,37);
INSERT INTO "django_geo_db_city" VALUES(29387,'Tidewater','Tidewater, Oregon',36719,37);
INSERT INTO "django_geo_db_city" VALUES(29388,'Toledo','Toledo, Oregon',36720,37);
INSERT INTO "django_geo_db_city" VALUES(29389,'Turner','Turner, Oregon',36721,37);
INSERT INTO "django_geo_db_city" VALUES(29390,'Waldport','Waldport, Oregon',36722,37);
INSERT INTO "django_geo_db_city" VALUES(29391,'Willamina','Willamina, Oregon',36723,37);
INSERT INTO "django_geo_db_city" VALUES(29392,'Eugene','Eugene, Oregon',36724,37);
INSERT INTO "django_geo_db_city" VALUES(29393,'Agness','Agness, Oregon',36729,37);
INSERT INTO "django_geo_db_city" VALUES(29394,'Allegany','Allegany, Oregon',36730,37);
INSERT INTO "django_geo_db_city" VALUES(29395,'Alvadore','Alvadore, Oregon',36732,37);
INSERT INTO "django_geo_db_city" VALUES(29396,'Azalea','Azalea, Oregon',36733,37);
INSERT INTO "django_geo_db_city" VALUES(29397,'Bandon','Bandon, Oregon',36734,37);
INSERT INTO "django_geo_db_city" VALUES(29398,'Blachly','Blachly, Oregon',36735,37);
INSERT INTO "django_geo_db_city" VALUES(29399,'Blue River','Blue River, Oregon',36736,37);
INSERT INTO "django_geo_db_city" VALUES(29400,'Broadbent','Broadbent, Oregon',36737,37);
INSERT INTO "django_geo_db_city" VALUES(29401,'Brookings','Brookings, Oregon',36738,37);
INSERT INTO "django_geo_db_city" VALUES(29402,'Camas Valley','Camas Valley, Oregon',36739,37);
INSERT INTO "django_geo_db_city" VALUES(29403,'Canyonville','Canyonville, Oregon',36740,37);
INSERT INTO "django_geo_db_city" VALUES(29404,'Cheshire','Cheshire, Oregon',36741,37);
INSERT INTO "django_geo_db_city" VALUES(29405,'Coos Bay','Coos Bay, Oregon',36742,37);
INSERT INTO "django_geo_db_city" VALUES(29406,'Coquille','Coquille, Oregon',36743,37);
INSERT INTO "django_geo_db_city" VALUES(29407,'Cottage Grove','Cottage Grove, Oregon',36744,37);
INSERT INTO "django_geo_db_city" VALUES(29408,'Crescent Lake','Crescent Lake, Oregon',36745,37);
INSERT INTO "django_geo_db_city" VALUES(29409,'Creswell','Creswell, Oregon',36746,37);
INSERT INTO "django_geo_db_city" VALUES(29410,'Culp Creek','Culp Creek, Oregon',36747,37);
INSERT INTO "django_geo_db_city" VALUES(29411,'Curtin','Curtin, Oregon',36748,37);
INSERT INTO "django_geo_db_city" VALUES(29412,'Days Creek','Days Creek, Oregon',36749,37);
INSERT INTO "django_geo_db_city" VALUES(29413,'Deadwood','Deadwood, Oregon',36750,37);
INSERT INTO "django_geo_db_city" VALUES(29414,'Dexter','Dexter, Oregon',36751,37);
INSERT INTO "django_geo_db_city" VALUES(29415,'Dillard','Dillard, Oregon',36752,37);
INSERT INTO "django_geo_db_city" VALUES(29416,'Dorena','Dorena, Oregon',36753,37);
INSERT INTO "django_geo_db_city" VALUES(29417,'Drain','Drain, Oregon',36754,37);
INSERT INTO "django_geo_db_city" VALUES(29418,'Elkton','Elkton, Oregon',36755,37);
INSERT INTO "django_geo_db_city" VALUES(29419,'Elmira','Elmira, Oregon',36756,37);
INSERT INTO "django_geo_db_city" VALUES(29420,'Fall Creek','Fall Creek, Oregon',36757,37);
INSERT INTO "django_geo_db_city" VALUES(29421,'Florence','Florence, Oregon',36758,37);
INSERT INTO "django_geo_db_city" VALUES(29422,'Gardiner','Gardiner, Oregon',36760,37);
INSERT INTO "django_geo_db_city" VALUES(29423,'Glendale','Glendale, Oregon',36761,37);
INSERT INTO "django_geo_db_city" VALUES(29424,'Glide','Glide, Oregon',36762,37);
INSERT INTO "django_geo_db_city" VALUES(29425,'Gold Beach','Gold Beach, Oregon',36763,37);
INSERT INTO "django_geo_db_city" VALUES(29426,'Harrisburg','Harrisburg, Oregon',36764,37);
INSERT INTO "django_geo_db_city" VALUES(29427,'Idleyld Park','Idleyld Park, Oregon',36765,37);
INSERT INTO "django_geo_db_city" VALUES(29428,'Junction City','Junction City, Oregon',36766,37);
INSERT INTO "django_geo_db_city" VALUES(29429,'Lakeside','Lakeside, Oregon',36767,37);
INSERT INTO "django_geo_db_city" VALUES(29430,'Langlois','Langlois, Oregon',36768,37);
INSERT INTO "django_geo_db_city" VALUES(29431,'Lorane','Lorane, Oregon',36769,37);
INSERT INTO "django_geo_db_city" VALUES(29432,'Lowell','Lowell, Oregon',36770,37);
INSERT INTO "django_geo_db_city" VALUES(29433,'Mapleton','Mapleton, Oregon',36771,37);
INSERT INTO "django_geo_db_city" VALUES(29434,'Marcola','Marcola, Oregon',36772,37);
INSERT INTO "django_geo_db_city" VALUES(29435,'Pleasant Hill','Pleasant Hill, Oregon',36773,37);
INSERT INTO "django_geo_db_city" VALUES(29436,'Monroe','Monroe, Oregon',36774,37);
INSERT INTO "django_geo_db_city" VALUES(29437,'Myrtle Creek','Myrtle Creek, Oregon',36775,37);
INSERT INTO "django_geo_db_city" VALUES(29438,'Myrtle Point','Myrtle Point, Oregon',36776,37);
INSERT INTO "django_geo_db_city" VALUES(29439,'North Bend','North Bend, Oregon',36777,37);
INSERT INTO "django_geo_db_city" VALUES(29440,'Norway','Norway, Oregon',36778,37);
INSERT INTO "django_geo_db_city" VALUES(29441,'Noti','Noti, Oregon',36779,37);
INSERT INTO "django_geo_db_city" VALUES(29442,'Oakland','Oakland, Oregon',36780,37);
INSERT INTO "django_geo_db_city" VALUES(29443,'Oakridge','Oakridge, Oregon',36781,37);
INSERT INTO "django_geo_db_city" VALUES(29444,'Ophir','Ophir, Oregon',36782,37);
INSERT INTO "django_geo_db_city" VALUES(29445,'Port Orford','Port Orford, Oregon',36783,37);
INSERT INTO "django_geo_db_city" VALUES(29446,'Powers','Powers, Oregon',36784,37);
INSERT INTO "django_geo_db_city" VALUES(29447,'Reedsport','Reedsport, Oregon',36785,37);
INSERT INTO "django_geo_db_city" VALUES(29448,'Remote','Remote, Oregon',36778,37);
INSERT INTO "django_geo_db_city" VALUES(29449,'Riddle','Riddle, Oregon',36786,37);
INSERT INTO "django_geo_db_city" VALUES(29450,'Roseburg','Roseburg, Oregon',36787,37);
INSERT INTO "django_geo_db_city" VALUES(29451,'Saginaw','Saginaw, Oregon',36759,37);
INSERT INTO "django_geo_db_city" VALUES(29452,'Scottsburg','Scottsburg, Oregon',36788,37);
INSERT INTO "django_geo_db_city" VALUES(29453,'Sixes','Sixes, Oregon',36789,37);
INSERT INTO "django_geo_db_city" VALUES(29454,'Springfield','Springfield, Oregon',36790,37);
INSERT INTO "django_geo_db_city" VALUES(29455,'Sutherlin','Sutherlin, Oregon',36792,37);
INSERT INTO "django_geo_db_city" VALUES(29456,'Swisshome','Swisshome, Oregon',36793,37);
INSERT INTO "django_geo_db_city" VALUES(29457,'Tenmile','Tenmile, Oregon',36794,37);
INSERT INTO "django_geo_db_city" VALUES(29458,'Thurston','Thurston, Oregon',36759,37);
INSERT INTO "django_geo_db_city" VALUES(29459,'Tiller','Tiller, Oregon',36795,37);
INSERT INTO "django_geo_db_city" VALUES(29460,'Umpqua','Umpqua, Oregon',36796,37);
INSERT INTO "django_geo_db_city" VALUES(29461,'Veneta','Veneta, Oregon',36797,37);
INSERT INTO "django_geo_db_city" VALUES(29462,'Vida','Vida, Oregon',36798,37);
INSERT INTO "django_geo_db_city" VALUES(29463,'Walterville','Walterville, Oregon',36799,37);
INSERT INTO "django_geo_db_city" VALUES(29464,'Walton','Walton, Oregon',36800,37);
INSERT INTO "django_geo_db_city" VALUES(29465,'Wedderburn','Wedderburn, Oregon',36801,37);
INSERT INTO "django_geo_db_city" VALUES(29466,'Westfir','Westfir, Oregon',36802,37);
INSERT INTO "django_geo_db_city" VALUES(29467,'Westlake','Westlake, Oregon',36803,37);
INSERT INTO "django_geo_db_city" VALUES(29468,'Wilbur','Wilbur, Oregon',36804,37);
INSERT INTO "django_geo_db_city" VALUES(29469,'Winchester','Winchester, Oregon',36805,37);
INSERT INTO "django_geo_db_city" VALUES(29470,'Winston','Winston, Oregon',36806,37);
INSERT INTO "django_geo_db_city" VALUES(29471,'Wolf Creek','Wolf Creek, Oregon',36807,37);
INSERT INTO "django_geo_db_city" VALUES(29472,'Yachats','Yachats, Oregon',36808,37);
INSERT INTO "django_geo_db_city" VALUES(29473,'Yoncalla','Yoncalla, Oregon',36809,37);
INSERT INTO "django_geo_db_city" VALUES(29474,'Medford','Medford, Oregon',36810,37);
INSERT INTO "django_geo_db_city" VALUES(29475,'Central Point','Central Point, Oregon',36811,37);
INSERT INTO "django_geo_db_city" VALUES(29476,'White City','White City, Oregon',36812,37);
INSERT INTO "django_geo_db_city" VALUES(29477,'Ashland','Ashland, Oregon',36814,37);
INSERT INTO "django_geo_db_city" VALUES(29478,'Butte Falls','Butte Falls, Oregon',36815,37);
INSERT INTO "django_geo_db_city" VALUES(29479,'Cave Junction','Cave Junction, Oregon',36816,37);
INSERT INTO "django_geo_db_city" VALUES(29480,'Eagle Point','Eagle Point, Oregon',36817,37);
INSERT INTO "django_geo_db_city" VALUES(29481,'Gold Hill','Gold Hill, Oregon',36818,37);
INSERT INTO "django_geo_db_city" VALUES(29482,'Jacksonville','Jacksonville, Oregon',36822,37);
INSERT INTO "django_geo_db_city" VALUES(29483,'Kerby','Kerby, Oregon',36823,37);
INSERT INTO "django_geo_db_city" VALUES(29484,'Merlin','Merlin, Oregon',36824,37);
INSERT INTO "django_geo_db_city" VALUES(29485,'Murphy','Murphy, Oregon',36825,37);
INSERT INTO "django_geo_db_city" VALUES(29486,'O Brien','O Brien, Oregon',36826,37);
INSERT INTO "django_geo_db_city" VALUES(29487,'Phoenix','Phoenix, Oregon',36827,37);
INSERT INTO "django_geo_db_city" VALUES(29488,'Prospect','Prospect, Oregon',36828,37);
INSERT INTO "django_geo_db_city" VALUES(29489,'Rogue River','Rogue River, Oregon',36829,37);
INSERT INTO "django_geo_db_city" VALUES(29490,'Selma','Selma, Oregon',36830,37);
INSERT INTO "django_geo_db_city" VALUES(29491,'Shady Cove','Shady Cove, Oregon',36831,37);
INSERT INTO "django_geo_db_city" VALUES(29492,'Talent','Talent, Oregon',36832,37);
INSERT INTO "django_geo_db_city" VALUES(29493,'Trail','Trail, Oregon',36833,37);
INSERT INTO "django_geo_db_city" VALUES(29494,'Wilderville','Wilderville, Oregon',36834,37);
INSERT INTO "django_geo_db_city" VALUES(29495,'Williams','Williams, Oregon',36835,37);
INSERT INTO "django_geo_db_city" VALUES(29496,'Lostine','Lostine, Oregon',36837,37);
INSERT INTO "django_geo_db_city" VALUES(29497,'Klamath Falls','Klamath Falls, Oregon',36838,37);
INSERT INTO "django_geo_db_city" VALUES(29498,'Crater Lake','Crater Lake, Oregon',36841,37);
INSERT INTO "django_geo_db_city" VALUES(29499,'Adel','Adel, Oregon',36842,37);
INSERT INTO "django_geo_db_city" VALUES(29500,'Beatty','Beatty, Oregon',36843,37);
INSERT INTO "django_geo_db_city" VALUES(29501,'Bly','Bly, Oregon',36844,37);
INSERT INTO "django_geo_db_city" VALUES(29502,'Bonanza','Bonanza, Oregon',36845,37);
INSERT INTO "django_geo_db_city" VALUES(29503,'Dairy','Dairy, Oregon',36847,37);
INSERT INTO "django_geo_db_city" VALUES(29504,'Fort Klamath','Fort Klamath, Oregon',36848,37);
INSERT INTO "django_geo_db_city" VALUES(29505,'Keno','Keno, Oregon',36849,37);
INSERT INTO "django_geo_db_city" VALUES(29506,'Lakeview','Lakeview, Oregon',36850,37);
INSERT INTO "django_geo_db_city" VALUES(29507,'Malin','Malin, Oregon',36852,37);
INSERT INTO "django_geo_db_city" VALUES(29508,'Merrill','Merrill, Oregon',36853,37);
INSERT INTO "django_geo_db_city" VALUES(29509,'Midland','Midland, Oregon',36854,37);
INSERT INTO "django_geo_db_city" VALUES(29510,'New Pine Creek','New Pine Creek, California',36855,6);
INSERT INTO "django_geo_db_city" VALUES(29511,'Paisley','Paisley, Oregon',36856,37);
INSERT INTO "django_geo_db_city" VALUES(29512,'Plush','Plush, Oregon',36857,37);
INSERT INTO "django_geo_db_city" VALUES(29513,'Silver Lake','Silver Lake, Oregon',36858,37);
INSERT INTO "django_geo_db_city" VALUES(29514,'Sprague River','Sprague River, Oregon',36859,37);
INSERT INTO "django_geo_db_city" VALUES(29515,'Summer Lake','Summer Lake, Oregon',36860,37);
INSERT INTO "django_geo_db_city" VALUES(29516,'Christmas Valley','Christmas Valley, Oregon',36861,37);
INSERT INTO "django_geo_db_city" VALUES(29517,'Bend','Bend, Oregon',36862,37);
INSERT INTO "django_geo_db_city" VALUES(29518,'Fields','Fields, Oregon',36866,37);
INSERT INTO "django_geo_db_city" VALUES(29519,'Ashwood','Ashwood, Oregon',36867,37);
INSERT INTO "django_geo_db_city" VALUES(29520,'Brothers','Brothers, Oregon',36868,37);
INSERT INTO "django_geo_db_city" VALUES(29521,'Burns','Burns, Oregon',36869,37);
INSERT INTO "django_geo_db_city" VALUES(29522,'Princeton','Princeton, Oregon',36870,37);
INSERT INTO "django_geo_db_city" VALUES(29523,'Diamond','Diamond, Oregon',36871,37);
INSERT INTO "django_geo_db_city" VALUES(29524,'Camp Sherman','Camp Sherman, Oregon',36872,37);
INSERT INTO "django_geo_db_city" VALUES(29525,'Chemult','Chemult, Oregon',36873,37);
INSERT INTO "django_geo_db_city" VALUES(29526,'Crane','Crane, Oregon',36874,37);
INSERT INTO "django_geo_db_city" VALUES(29527,'Crescent','Crescent, Oregon',36875,37);
INSERT INTO "django_geo_db_city" VALUES(29528,'Culver','Culver, Oregon',36876,37);
INSERT INTO "django_geo_db_city" VALUES(29529,'Fort Rock','Fort Rock, Oregon',36877,37);
INSERT INTO "django_geo_db_city" VALUES(29530,'Frenchglen','Frenchglen, Oregon',36878,37);
INSERT INTO "django_geo_db_city" VALUES(29531,'Gilchrist','Gilchrist, Oregon',36879,37);
INSERT INTO "django_geo_db_city" VALUES(29532,'Hines','Hines, Oregon',36880,37);
INSERT INTO "django_geo_db_city" VALUES(29533,'La Pine','La Pine, Oregon',36881,37);
INSERT INTO "django_geo_db_city" VALUES(29534,'Lawen','Lawen, Oregon',36882,37);
INSERT INTO "django_geo_db_city" VALUES(29535,'Madras','Madras, Oregon',36883,37);
INSERT INTO "django_geo_db_city" VALUES(29536,'Mitchell','Mitchell, Oregon',36884,37);
INSERT INTO "django_geo_db_city" VALUES(29537,'Paulina','Paulina, Oregon',36885,37);
INSERT INTO "django_geo_db_city" VALUES(29538,'Post','Post, Oregon',36886,37);
INSERT INTO "django_geo_db_city" VALUES(29539,'Powell Butte','Powell Butte, Oregon',36887,37);
INSERT INTO "django_geo_db_city" VALUES(29540,'Prineville','Prineville, Oregon',36888,37);
INSERT INTO "django_geo_db_city" VALUES(29541,'Redmond','Redmond, Oregon',36889,37);
INSERT INTO "django_geo_db_city" VALUES(29542,'Riley','Riley, Oregon',36890,37);
INSERT INTO "django_geo_db_city" VALUES(29543,'Sisters','Sisters, Oregon',36891,37);
INSERT INTO "django_geo_db_city" VALUES(29544,'Terrebonne','Terrebonne, Oregon',36892,37);
INSERT INTO "django_geo_db_city" VALUES(29545,'Warm Springs','Warm Springs, Oregon',36893,37);
INSERT INTO "django_geo_db_city" VALUES(29546,'Roseburg North','Roseburg North, Oregon',36894,37);
INSERT INTO "django_geo_db_city" VALUES(29547,'Pendleton','Pendleton, Oregon',36895,37);
INSERT INTO "django_geo_db_city" VALUES(29548,'Adams','Adams, Oregon',36896,37);
INSERT INTO "django_geo_db_city" VALUES(29549,'Arlington','Arlington, Oregon',36897,37);
INSERT INTO "django_geo_db_city" VALUES(29550,'Athena','Athena, Oregon',36898,37);
INSERT INTO "django_geo_db_city" VALUES(29551,'Baker City','Baker City, Oregon',36899,37);
INSERT INTO "django_geo_db_city" VALUES(29552,'Bates','Bates, Oregon',36900,37);
INSERT INTO "django_geo_db_city" VALUES(29553,'Boardman','Boardman, Oregon',36901,37);
INSERT INTO "django_geo_db_city" VALUES(29554,'Bridgeport','Bridgeport, Oregon',36902,37);
INSERT INTO "django_geo_db_city" VALUES(29555,'Canyon City','Canyon City, Oregon',36903,37);
INSERT INTO "django_geo_db_city" VALUES(29556,'Cayuse','Cayuse, Oregon',36904,37);
INSERT INTO "django_geo_db_city" VALUES(29557,'Condon','Condon, Oregon',36905,37);
INSERT INTO "django_geo_db_city" VALUES(29558,'Cove','Cove, Oregon',36906,37);
INSERT INTO "django_geo_db_city" VALUES(29559,'Dayville','Dayville, Oregon',36907,37);
INSERT INTO "django_geo_db_city" VALUES(29560,'Echo','Echo, Oregon',36908,37);
INSERT INTO "django_geo_db_city" VALUES(29561,'Elgin','Elgin, Oregon',36909,37);
INSERT INTO "django_geo_db_city" VALUES(29562,'Enterprise','Enterprise, Oregon',36910,37);
INSERT INTO "django_geo_db_city" VALUES(29563,'Fossil','Fossil, Oregon',36911,37);
INSERT INTO "django_geo_db_city" VALUES(29564,'Fox','Fox, Oregon',36912,37);
INSERT INTO "django_geo_db_city" VALUES(29565,'Haines','Haines, Oregon',36913,37);
INSERT INTO "django_geo_db_city" VALUES(29566,'Halfway','Halfway, Oregon',36914,37);
INSERT INTO "django_geo_db_city" VALUES(29567,'Helix','Helix, Oregon',36915,37);
INSERT INTO "django_geo_db_city" VALUES(29568,'Heppner','Heppner, Oregon',36916,37);
INSERT INTO "django_geo_db_city" VALUES(29569,'Hereford','Hereford, Oregon',36917,37);
INSERT INTO "django_geo_db_city" VALUES(29570,'Hermiston','Hermiston, Oregon',36918,37);
INSERT INTO "django_geo_db_city" VALUES(29571,'Lexington','Lexington, Oregon',36919,37);
INSERT INTO "django_geo_db_city" VALUES(29572,'Oxbow','Oxbow, Oregon',36920,37);
INSERT INTO "django_geo_db_city" VALUES(29573,'Imbler','Imbler, Oregon',36921,37);
INSERT INTO "django_geo_db_city" VALUES(29574,'Imnaha','Imnaha, Oregon',36922,37);
INSERT INTO "django_geo_db_city" VALUES(29575,'Ione','Ione, Oregon',36923,37);
INSERT INTO "django_geo_db_city" VALUES(29576,'Irrigon','Irrigon, Oregon',36924,37);
INSERT INTO "django_geo_db_city" VALUES(29577,'John Day','John Day, Oregon',36925,37);
INSERT INTO "django_geo_db_city" VALUES(29578,'Joseph','Joseph, Oregon',36926,37);
INSERT INTO "django_geo_db_city" VALUES(29579,'Kimberly','Kimberly, Oregon',36927,37);
INSERT INTO "django_geo_db_city" VALUES(29580,'La Grande','La Grande, Oregon',36928,37);
INSERT INTO "django_geo_db_city" VALUES(29581,'Long Creek','Long Creek, Oregon',36929,37);
INSERT INTO "django_geo_db_city" VALUES(29582,'Meacham','Meacham, Oregon',36931,37);
INSERT INTO "django_geo_db_city" VALUES(29583,'Mikkalo','Mikkalo, Oregon',36932,37);
INSERT INTO "django_geo_db_city" VALUES(29584,'Milton Freewater','Milton Freewater, Oregon',36933,37);
INSERT INTO "django_geo_db_city" VALUES(29585,'Monument','Monument, Oregon',36934,37);
INSERT INTO "django_geo_db_city" VALUES(29586,'Mount Vernon','Mount Vernon, Oregon',36935,37);
INSERT INTO "django_geo_db_city" VALUES(29587,'North Powder','North Powder, Oregon',36936,37);
INSERT INTO "django_geo_db_city" VALUES(29588,'Pilot Rock','Pilot Rock, Oregon',36937,37);
INSERT INTO "django_geo_db_city" VALUES(29589,'Prairie City','Prairie City, Oregon',36938,37);
INSERT INTO "django_geo_db_city" VALUES(29590,'Richland','Richland, Oregon',36939,37);
INSERT INTO "django_geo_db_city" VALUES(29591,'Ritter','Ritter, Oregon',36940,37);
INSERT INTO "django_geo_db_city" VALUES(29592,'Seneca','Seneca, Oregon',36941,37);
INSERT INTO "django_geo_db_city" VALUES(29593,'Spray','Spray, Oregon',36942,37);
INSERT INTO "django_geo_db_city" VALUES(29594,'Stanfield','Stanfield, Oregon',36943,37);
INSERT INTO "django_geo_db_city" VALUES(29595,'Summerville','Summerville, Oregon',36944,37);
INSERT INTO "django_geo_db_city" VALUES(29596,'Sumpter','Sumpter, Oregon',36945,37);
INSERT INTO "django_geo_db_city" VALUES(29597,'Ukiah','Ukiah, Oregon',36946,37);
INSERT INTO "django_geo_db_city" VALUES(29598,'Umatilla','Umatilla, Oregon',36947,37);
INSERT INTO "django_geo_db_city" VALUES(29599,'Union','Union, Oregon',36948,37);
INSERT INTO "django_geo_db_city" VALUES(29600,'Unity','Unity, Oregon',36949,37);
INSERT INTO "django_geo_db_city" VALUES(29601,'Wallowa','Wallowa, Oregon',36950,37);
INSERT INTO "django_geo_db_city" VALUES(29602,'Weston','Weston, Oregon',36951,37);
INSERT INTO "django_geo_db_city" VALUES(29603,'Adrian','Adrian, Oregon',36952,37);
INSERT INTO "django_geo_db_city" VALUES(29604,'Arock','Arock, Oregon',36953,37);
INSERT INTO "django_geo_db_city" VALUES(29605,'Brogan','Brogan, Oregon',36954,37);
INSERT INTO "django_geo_db_city" VALUES(29606,'Drewsey','Drewsey, Oregon',36955,37);
INSERT INTO "django_geo_db_city" VALUES(29607,'Durkee','Durkee, Oregon',36956,37);
INSERT INTO "django_geo_db_city" VALUES(29608,'Harper','Harper, Oregon',36957,37);
INSERT INTO "django_geo_db_city" VALUES(29609,'Huntington','Huntington, Oregon',36958,37);
INSERT INTO "django_geo_db_city" VALUES(29610,'Ironside','Ironside, Oregon',36959,37);
INSERT INTO "django_geo_db_city" VALUES(29611,'Jamieson','Jamieson, Oregon',36960,37);
INSERT INTO "django_geo_db_city" VALUES(29612,'Jordan Valley','Jordan Valley, Idaho',36961,16);
INSERT INTO "django_geo_db_city" VALUES(29613,'Juntura','Juntura, Oregon',36962,37);
INSERT INTO "django_geo_db_city" VALUES(29614,'Nyssa','Nyssa, Idaho',36963,16);
INSERT INTO "django_geo_db_city" VALUES(29615,'Ontario','Ontario, Oregon',36964,37);
INSERT INTO "django_geo_db_city" VALUES(29616,'Riverside','Riverside, Oregon',36965,37);
INSERT INTO "django_geo_db_city" VALUES(29617,'Vale','Vale, Oregon',36966,37);
INSERT INTO "django_geo_db_city" VALUES(29618,'Westfall','Westfall, Oregon',36967,37);
INSERT INTO "django_geo_db_city" VALUES(29619,'Auburn','Auburn, Washington',36968,56);
INSERT INTO "django_geo_db_city" VALUES(29620,'Federal Way','Federal Way, Washington',36970,56);
INSERT INTO "django_geo_db_city" VALUES(29621,'Bellevue','Bellevue, Washington',36971,56);
INSERT INTO "django_geo_db_city" VALUES(29622,'Black Diamond','Black Diamond, Washington',36977,56);
INSERT INTO "django_geo_db_city" VALUES(29623,'Bothell','Bothell, Washington',36978,56);
INSERT INTO "django_geo_db_city" VALUES(29624,'Burton','Burton, Washington',36976,56);
INSERT INTO "django_geo_db_city" VALUES(29625,'Carnation','Carnation, Washington',36980,56);
INSERT INTO "django_geo_db_city" VALUES(29626,'Duvall','Duvall, Washington',36981,56);
INSERT INTO "django_geo_db_city" VALUES(29627,'Edmonds','Edmonds, Washington',36982,56);
INSERT INTO "django_geo_db_city" VALUES(29628,'Enumclaw','Enumclaw, Washington',36984,56);
INSERT INTO "django_geo_db_city" VALUES(29629,'Fall City','Fall City, Washington',36986,56);
INSERT INTO "django_geo_db_city" VALUES(29630,'Hobart','Hobart, Washington',36987,56);
INSERT INTO "django_geo_db_city" VALUES(29631,'Issaquah','Issaquah, Washington',36989,56);
INSERT INTO "django_geo_db_city" VALUES(29632,'Kenmore','Kenmore, Washington',36990,56);
INSERT INTO "django_geo_db_city" VALUES(29633,'Kent','Kent, Washington',36992,56);
INSERT INTO "django_geo_db_city" VALUES(29634,'Kirkland','Kirkland, Washington',36995,56);
INSERT INTO "django_geo_db_city" VALUES(29635,'Lynnwood','Lynnwood, Washington',36997,56);
INSERT INTO "django_geo_db_city" VALUES(29636,'Maple Valley','Maple Valley, Washington',36999,56);
INSERT INTO "django_geo_db_city" VALUES(29637,'Medina','Medina, Washington',37000,56);
INSERT INTO "django_geo_db_city" VALUES(29638,'Mercer Island','Mercer Island, Washington',37001,56);
INSERT INTO "django_geo_db_city" VALUES(29639,'Mountlake Terrace','Mountlake Terrace, Washington',37003,56);
INSERT INTO "django_geo_db_city" VALUES(29640,'North Bend','North Bend, Washington',37004,56);
INSERT INTO "django_geo_db_city" VALUES(29641,'Pacific','Pacific, Washington',37006,56);
INSERT INTO "django_geo_db_city" VALUES(29642,'Preston','Preston, Washington',37007,56);
INSERT INTO "django_geo_db_city" VALUES(29643,'Ravensdale','Ravensdale, Washington',37008,56);
INSERT INTO "django_geo_db_city" VALUES(29644,'Redmond','Redmond, Washington',37009,56);
INSERT INTO "django_geo_db_city" VALUES(29645,'Redondo','Redondo, Washington',36976,56);
INSERT INTO "django_geo_db_city" VALUES(29646,'Renton','Renton, Washington',37011,56);
INSERT INTO "django_geo_db_city" VALUES(29647,'Seattle','Seattle, Washington',36976,56);
INSERT INTO "django_geo_db_city" VALUES(29648,'Rollingbay','Rollingbay, Washington',37015,56);
INSERT INTO "django_geo_db_city" VALUES(29649,'Seahurst','Seahurst, Washington',36976,56);
INSERT INTO "django_geo_db_city" VALUES(29650,'Snoqualmie','Snoqualmie, Washington',37016,56);
INSERT INTO "django_geo_db_city" VALUES(29651,'Snoqualmie Pass','Snoqualmie Pass, Washington',37018,56);
INSERT INTO "django_geo_db_city" VALUES(29652,'Vashon','Vashon, Washington',37019,56);
INSERT INTO "django_geo_db_city" VALUES(29653,'Woodinville','Woodinville, Washington',37020,56);
INSERT INTO "django_geo_db_city" VALUES(29654,'Sammamish','Sammamish, Washington',37021,56);
INSERT INTO "django_geo_db_city" VALUES(29655,'Bainbridge Island','Bainbridge Island, Washington',37034,56);
INSERT INTO "django_geo_db_city" VALUES(29656,'Shoreline','Shoreline, Washington',37036,56);
INSERT INTO "django_geo_db_city" VALUES(29657,'Everett','Everett, Washington',37063,56);
INSERT INTO "django_geo_db_city" VALUES(29658,'Acme','Acme, Washington',37069,56);
INSERT INTO "django_geo_db_city" VALUES(29659,'Anacortes','Anacortes, Washington',37070,56);
INSERT INTO "django_geo_db_city" VALUES(29660,'Blakely Island','Blakely Island, Washington',37071,56);
INSERT INTO "django_geo_db_city" VALUES(29661,'Arlington','Arlington, Washington',37072,56);
INSERT INTO "django_geo_db_city" VALUES(29662,'Baring','Baring, Washington',37073,56);
INSERT INTO "django_geo_db_city" VALUES(29663,'Bellingham','Bellingham, Washington',37074,56);
INSERT INTO "django_geo_db_city" VALUES(29664,'Blaine','Blaine, Washington',37078,56);
INSERT INTO "django_geo_db_city" VALUES(29665,'Bow','Bow, Washington',37079,56);
INSERT INTO "django_geo_db_city" VALUES(29666,'Burlington','Burlington, Washington',37080,56);
INSERT INTO "django_geo_db_city" VALUES(29667,'Clearlake','Clearlake, Washington',37081,56);
INSERT INTO "django_geo_db_city" VALUES(29668,'Clinton','Clinton, Washington',37082,56);
INSERT INTO "django_geo_db_city" VALUES(29669,'Concrete','Concrete, Washington',37083,56);
INSERT INTO "django_geo_db_city" VALUES(29670,'Conway','Conway, Washington',37084,56);
INSERT INTO "django_geo_db_city" VALUES(29671,'Coupeville','Coupeville, Washington',37085,56);
INSERT INTO "django_geo_db_city" VALUES(29672,'Custer','Custer, Washington',37086,56);
INSERT INTO "django_geo_db_city" VALUES(29673,'Darrington','Darrington, Washington',37087,56);
INSERT INTO "django_geo_db_city" VALUES(29674,'Deer Harbor','Deer Harbor, Washington',37088,56);
INSERT INTO "django_geo_db_city" VALUES(29675,'Deming','Deming, Washington',37089,56);
INSERT INTO "django_geo_db_city" VALUES(29676,'Eastsound','Eastsound, Washington',37090,56);
INSERT INTO "django_geo_db_city" VALUES(29677,'Everson','Everson, Washington',37092,56);
INSERT INTO "django_geo_db_city" VALUES(29678,'Ferndale','Ferndale, Washington',37093,56);
INSERT INTO "django_geo_db_city" VALUES(29679,'Freeland','Freeland, Washington',37094,56);
INSERT INTO "django_geo_db_city" VALUES(29680,'Friday Harbor','Friday Harbor, Washington',37095,56);
INSERT INTO "django_geo_db_city" VALUES(29681,'Gold Bar','Gold Bar, Washington',37096,56);
INSERT INTO "django_geo_db_city" VALUES(29682,'Granite Falls','Granite Falls, Washington',37097,56);
INSERT INTO "django_geo_db_city" VALUES(29683,'Greenbank','Greenbank, Washington',37098,56);
INSERT INTO "django_geo_db_city" VALUES(29684,'Hamilton','Hamilton, Washington',37099,56);
INSERT INTO "django_geo_db_city" VALUES(29685,'Index','Index, Washington',37100,56);
INSERT INTO "django_geo_db_city" VALUES(29686,'La Conner','La Conner, Washington',37101,56);
INSERT INTO "django_geo_db_city" VALUES(29687,'Lake Stevens','Lake Stevens, Washington',37102,56);
INSERT INTO "django_geo_db_city" VALUES(29688,'North Lakewood','North Lakewood, Washington',37005,56);
INSERT INTO "django_geo_db_city" VALUES(29689,'Langley','Langley, Washington',37103,56);
INSERT INTO "django_geo_db_city" VALUES(29690,'Lopez Island','Lopez Island, Washington',37104,56);
INSERT INTO "django_geo_db_city" VALUES(29691,'Lummi Island','Lummi Island, Washington',37105,56);
INSERT INTO "django_geo_db_city" VALUES(29692,'Lyman','Lyman, Washington',37106,56);
INSERT INTO "django_geo_db_city" VALUES(29693,'Lynden','Lynden, Washington',37107,56);
INSERT INTO "django_geo_db_city" VALUES(29694,'Maple Falls','Maple Falls, Washington',37108,56);
INSERT INTO "django_geo_db_city" VALUES(29695,'Marblemount','Marblemount, Washington',37109,56);
INSERT INTO "django_geo_db_city" VALUES(29696,'Marysville','Marysville, Washington',37110,56);
INSERT INTO "django_geo_db_city" VALUES(29697,'Monroe','Monroe, Washington',37112,56);
INSERT INTO "django_geo_db_city" VALUES(29698,'Mount Vernon','Mount Vernon, Washington',37113,56);
INSERT INTO "django_geo_db_city" VALUES(29699,'Mukilteo','Mukilteo, Washington',37115,56);
INSERT INTO "django_geo_db_city" VALUES(29700,'Nooksack','Nooksack, Washington',37116,56);
INSERT INTO "django_geo_db_city" VALUES(29701,'Oak Harbor','Oak Harbor, Washington',37117,56);
INSERT INTO "django_geo_db_city" VALUES(29702,'Olga','Olga, Washington',37119,56);
INSERT INTO "django_geo_db_city" VALUES(29703,'Orcas','Orcas, Washington',37120,56);
INSERT INTO "django_geo_db_city" VALUES(29704,'Point Roberts','Point Roberts, Washington',37121,56);
INSERT INTO "django_geo_db_city" VALUES(29705,'Camano','Camano, Washington',37122,56);
INSERT INTO "django_geo_db_city" VALUES(29706,'Rockport','Rockport, Washington',37123,56);
INSERT INTO "django_geo_db_city" VALUES(29707,'Sedro Woolley','Sedro Woolley, Washington',37124,56);
INSERT INTO "django_geo_db_city" VALUES(29708,'Shaw Island','Shaw Island, Washington',37125,56);
INSERT INTO "django_geo_db_city" VALUES(29709,'Silvana','Silvana, Washington',37005,56);
INSERT INTO "django_geo_db_city" VALUES(29710,'Skykomish','Skykomish, Washington',37126,56);
INSERT INTO "django_geo_db_city" VALUES(29711,'Snohomish','Snohomish, Washington',37127,56);
INSERT INTO "django_geo_db_city" VALUES(29712,'Stanwood','Stanwood, Washington',37129,56);
INSERT INTO "django_geo_db_city" VALUES(29713,'Startup','Startup, Washington',37130,56);
INSERT INTO "django_geo_db_city" VALUES(29714,'Sultan','Sultan, Washington',37131,56);
INSERT INTO "django_geo_db_city" VALUES(29715,'Sumas','Sumas, Washington',37132,56);
INSERT INTO "django_geo_db_city" VALUES(29716,'Waldron','Waldron, Washington',37134,56);
INSERT INTO "django_geo_db_city" VALUES(29717,'Anderson Island','Anderson Island, Washington',37135,56);
INSERT INTO "django_geo_db_city" VALUES(29718,'Ashford','Ashford, Washington',37136,56);
INSERT INTO "django_geo_db_city" VALUES(29719,'Beaver','Beaver, Washington',37137,56);
INSERT INTO "django_geo_db_city" VALUES(29720,'Bremerton','Bremerton, Washington',37138,56);
INSERT INTO "django_geo_db_city" VALUES(29721,'Silverdale','Silverdale, Washington',37142,56);
INSERT INTO "django_geo_db_city" VALUES(29722,'Brinnon','Brinnon, Washington',37144,56);
INSERT INTO "django_geo_db_city" VALUES(29723,'Buckley','Buckley, Washington',37145,56);
INSERT INTO "django_geo_db_city" VALUES(29724,'Burley','Burley, Washington',37146,56);
INSERT INTO "django_geo_db_city" VALUES(29725,'Carbonado','Carbonado, Washington',37147,56);
INSERT INTO "django_geo_db_city" VALUES(29726,'Carlsborg','Carlsborg, Washington',37148,56);
INSERT INTO "django_geo_db_city" VALUES(29727,'Chimacum','Chimacum, Washington',37149,56);
INSERT INTO "django_geo_db_city" VALUES(29728,'Clallam Bay','Clallam Bay, Washington',37150,56);
INSERT INTO "django_geo_db_city" VALUES(29729,'Dupont','Dupont, Washington',37151,56);
INSERT INTO "django_geo_db_city" VALUES(29730,'Eatonville','Eatonville, Washington',37152,56);
INSERT INTO "django_geo_db_city" VALUES(29731,'Gig Harbor','Gig Harbor, Washington',37153,56);
INSERT INTO "django_geo_db_city" VALUES(29732,'Elbe','Elbe, Washington',37154,56);
INSERT INTO "django_geo_db_city" VALUES(29733,'Forks','Forks, Washington',37155,56);
INSERT INTO "django_geo_db_city" VALUES(29734,'Fox Island','Fox Island, Washington',37157,56);
INSERT INTO "django_geo_db_city" VALUES(29735,'Glenoma','Glenoma, Washington',37159,56);
INSERT INTO "django_geo_db_city" VALUES(29736,'Graham','Graham, Washington',37161,56);
INSERT INTO "django_geo_db_city" VALUES(29737,'Port Hadlock','Port Hadlock, Washington',37162,56);
INSERT INTO "django_geo_db_city" VALUES(29738,'Hansville','Hansville, Washington',37163,56);
INSERT INTO "django_geo_db_city" VALUES(29739,'Indianola','Indianola, Washington',37164,56);
INSERT INTO "django_geo_db_city" VALUES(29740,'Joyce','Joyce, Washington',37148,56);
INSERT INTO "django_geo_db_city" VALUES(29741,'Kapowsin','Kapowsin, Washington',37165,56);
INSERT INTO "django_geo_db_city" VALUES(29742,'Keyport','Keyport, Washington',37166,56);
INSERT INTO "django_geo_db_city" VALUES(29743,'Kingston','Kingston, Washington',37167,56);
INSERT INTO "django_geo_db_city" VALUES(29744,'La Grande','La Grande, Washington',37168,56);
INSERT INTO "django_geo_db_city" VALUES(29745,'Lakebay','Lakebay, Washington',37169,56);
INSERT INTO "django_geo_db_city" VALUES(29746,'La Push','La Push, Washington',37170,56);
INSERT INTO "django_geo_db_city" VALUES(29747,'Longbranch','Longbranch, Washington',37171,56);
INSERT INTO "django_geo_db_city" VALUES(29748,'Sumner','Sumner, Washington',37168,56);
INSERT INTO "django_geo_db_city" VALUES(29749,'Manchester','Manchester, Washington',37172,56);
INSERT INTO "django_geo_db_city" VALUES(29750,'Milton','Milton, Washington',37173,56);
INSERT INTO "django_geo_db_city" VALUES(29751,'Mineral','Mineral, Washington',37174,56);
INSERT INTO "django_geo_db_city" VALUES(29752,'Morton','Morton, Washington',37175,56);
INSERT INTO "django_geo_db_city" VALUES(29753,'Neah Bay','Neah Bay, Washington',37176,56);
INSERT INTO "django_geo_db_city" VALUES(29754,'Nordland','Nordland, Washington',37177,56);
INSERT INTO "django_geo_db_city" VALUES(29755,'Olalla','Olalla, Washington',37178,56);
INSERT INTO "django_geo_db_city" VALUES(29756,'Orting','Orting, Washington',37179,56);
INSERT INTO "django_geo_db_city" VALUES(29757,'Packwood','Packwood, Washington',37180,56);
INSERT INTO "django_geo_db_city" VALUES(29758,'Port Angeles','Port Angeles, Washington',37181,56);
INSERT INTO "django_geo_db_city" VALUES(29759,'Port Gamble','Port Gamble, Washington',37183,56);
INSERT INTO "django_geo_db_city" VALUES(29760,'Port Ludlow','Port Ludlow, Washington',37184,56);
INSERT INTO "django_geo_db_city" VALUES(29761,'Port Orchard','Port Orchard, Washington',37185,56);
INSERT INTO "django_geo_db_city" VALUES(29762,'Port Townsend','Port Townsend, Washington',37187,56);
INSERT INTO "django_geo_db_city" VALUES(29763,'Poulsbo','Poulsbo, Washington',37188,56);
INSERT INTO "django_geo_db_city" VALUES(29764,'Puyallup','Puyallup, Washington',37189,56);
INSERT INTO "django_geo_db_city" VALUES(29765,'Quilcene','Quilcene, Washington',37194,56);
INSERT INTO "django_geo_db_city" VALUES(29766,'Randle','Randle, Washington',37195,56);
INSERT INTO "django_geo_db_city" VALUES(29767,'Retsil','Retsil, Washington',37146,56);
INSERT INTO "django_geo_db_city" VALUES(29768,'Seabeck','Seabeck, Washington',37196,56);
INSERT INTO "django_geo_db_city" VALUES(29769,'Sekiu','Sekiu, Washington',37197,56);
INSERT INTO "django_geo_db_city" VALUES(29770,'Sequim','Sequim, Washington',37198,56);
INSERT INTO "django_geo_db_city" VALUES(29771,'South Colby','South Colby, Washington',37200,56);
INSERT INTO "django_geo_db_city" VALUES(29772,'South Prairie','South Prairie, Washington',37201,56);
INSERT INTO "django_geo_db_city" VALUES(29773,'Southworth','Southworth, Washington',37202,56);
INSERT INTO "django_geo_db_city" VALUES(29774,'Spanaway','Spanaway, Washington',37203,56);
INSERT INTO "django_geo_db_city" VALUES(29775,'Steilacoom','Steilacoom, Washington',37204,56);
INSERT INTO "django_geo_db_city" VALUES(29776,'Suquamish','Suquamish, Washington',37207,56);
INSERT INTO "django_geo_db_city" VALUES(29777,'Tracyton','Tracyton, Washington',37208,56);
INSERT INTO "django_geo_db_city" VALUES(29778,'Vaughn','Vaughn, Washington',37209,56);
INSERT INTO "django_geo_db_city" VALUES(29779,'Wauna','Wauna, Washington',37210,56);
INSERT INTO "django_geo_db_city" VALUES(29780,'Wilkeson','Wilkeson, Washington',37211,56);
INSERT INTO "django_geo_db_city" VALUES(29781,'Longmire','Longmire, Washington',37168,56);
INSERT INTO "django_geo_db_city" VALUES(29782,'Paradise Inn','Paradise Inn, Washington',37168,56);
INSERT INTO "django_geo_db_city" VALUES(29783,'Tacoma','Tacoma, Washington',37212,56);
INSERT INTO "django_geo_db_city" VALUES(29784,'Camp Murray','Camp Murray, Washington',37168,56);
INSERT INTO "django_geo_db_city" VALUES(29785,'Lakewood','Lakewood, Washington',37227,56);
INSERT INTO "django_geo_db_city" VALUES(29786,'Parkland','Parkland, Washington',37233,56);
INSERT INTO "django_geo_db_city" VALUES(29787,'University Place','University Place, Washington',37236,56);
INSERT INTO "django_geo_db_city" VALUES(29788,'Oakville','Oakville, Washington',37237,56);
INSERT INTO "django_geo_db_city" VALUES(29789,'Tumwater','Tumwater, Washington',37241,56);
INSERT INTO "django_geo_db_city" VALUES(29790,'Olympia','Olympia, Washington',37242,56);
INSERT INTO "django_geo_db_city" VALUES(29791,'Lacey','Lacey, Washington',37244,56);
INSERT INTO "django_geo_db_city" VALUES(29792,'Aberdeen','Aberdeen, Washington',37251,56);
INSERT INTO "django_geo_db_city" VALUES(29793,'Adna','Adna, Washington',37252,56);
INSERT INTO "django_geo_db_city" VALUES(29794,'Allyn','Allyn, Washington',37253,56);
INSERT INTO "django_geo_db_city" VALUES(29795,'Amanda Park','Amanda Park, Washington',37254,56);
INSERT INTO "django_geo_db_city" VALUES(29796,'Bay Center','Bay Center, Washington',37255,56);
INSERT INTO "django_geo_db_city" VALUES(29797,'Belfair','Belfair, Washington',37256,56);
INSERT INTO "django_geo_db_city" VALUES(29798,'Bucoda','Bucoda, Washington',37257,56);
INSERT INTO "django_geo_db_city" VALUES(29799,'Centralia','Centralia, Washington',37258,56);
INSERT INTO "django_geo_db_city" VALUES(29800,'Chehalis','Chehalis, Washington',37259,56);
INSERT INTO "django_geo_db_city" VALUES(29801,'Cinebar','Cinebar, Washington',37260,56);
INSERT INTO "django_geo_db_city" VALUES(29802,'Copalis Beach','Copalis Beach, Washington',37261,56);
INSERT INTO "django_geo_db_city" VALUES(29803,'Copalis Crossing','Copalis Crossing, Washington',37262,56);
INSERT INTO "django_geo_db_city" VALUES(29804,'Cosmopolis','Cosmopolis, Washington',37263,56);
INSERT INTO "django_geo_db_city" VALUES(29805,'Curtis','Curtis, Washington',37264,56);
INSERT INTO "django_geo_db_city" VALUES(29806,'Doty','Doty, Washington',37265,56);
INSERT INTO "django_geo_db_city" VALUES(29807,'East Olympia','East Olympia, Washington',37245,56);
INSERT INTO "django_geo_db_city" VALUES(29808,'Elma','Elma, Washington',37266,56);
INSERT INTO "django_geo_db_city" VALUES(29809,'Ethel','Ethel, Washington',37267,56);
INSERT INTO "django_geo_db_city" VALUES(29810,'Galvin','Galvin, Washington',37268,56);
INSERT INTO "django_geo_db_city" VALUES(29811,'Grapeview','Grapeview, Washington',37269,56);
INSERT INTO "django_geo_db_city" VALUES(29812,'Grayland','Grayland, Washington',37270,56);
INSERT INTO "django_geo_db_city" VALUES(29813,'Hoodsport','Hoodsport, Washington',37271,56);
INSERT INTO "django_geo_db_city" VALUES(29814,'Hoquiam','Hoquiam, Washington',37272,56);
INSERT INTO "django_geo_db_city" VALUES(29815,'Humptulips','Humptulips, Washington',37273,56);
INSERT INTO "django_geo_db_city" VALUES(29816,'Lebam','Lebam, Washington',37274,56);
INSERT INTO "django_geo_db_city" VALUES(29817,'Lilliwaup','Lilliwaup, Washington',37275,56);
INSERT INTO "django_geo_db_city" VALUES(29818,'Littlerock','Littlerock, Washington',37276,56);
INSERT INTO "django_geo_db_city" VALUES(29819,'Mccleary','Mccleary, Washington',37277,56);
INSERT INTO "django_geo_db_city" VALUES(29820,'Mckenna','Mckenna, Washington',37278,56);
INSERT INTO "django_geo_db_city" VALUES(29821,'Malone','Malone, Washington',37279,56);
INSERT INTO "django_geo_db_city" VALUES(29822,'Matlock','Matlock, Washington',37280,56);
INSERT INTO "django_geo_db_city" VALUES(29823,'Menlo','Menlo, Washington',37281,56);
INSERT INTO "django_geo_db_city" VALUES(29824,'Moclips','Moclips, Washington',37282,56);
INSERT INTO "django_geo_db_city" VALUES(29825,'Montesano','Montesano, Washington',37283,56);
INSERT INTO "django_geo_db_city" VALUES(29826,'Mossyrock','Mossyrock, Washington',37284,56);
INSERT INTO "django_geo_db_city" VALUES(29827,'Napavine','Napavine, Washington',37285,56);
INSERT INTO "django_geo_db_city" VALUES(29828,'Neilton','Neilton, Washington',37286,56);
INSERT INTO "django_geo_db_city" VALUES(29829,'Ocean Shores','Ocean Shores, Washington',37288,56);
INSERT INTO "django_geo_db_city" VALUES(29830,'Onalaska','Onalaska, Washington',37289,56);
INSERT INTO "django_geo_db_city" VALUES(29831,'Pacific Beach','Pacific Beach, Washington',37290,56);
INSERT INTO "django_geo_db_city" VALUES(29832,'Pe Ell','Pe Ell, Washington',37291,56);
INSERT INTO "django_geo_db_city" VALUES(29833,'Quinault','Quinault, Washington',37292,56);
INSERT INTO "django_geo_db_city" VALUES(29834,'Rainier','Rainier, Washington',37293,56);
INSERT INTO "django_geo_db_city" VALUES(29835,'Raymond','Raymond, Washington',37294,56);
INSERT INTO "django_geo_db_city" VALUES(29836,'Rochester','Rochester, Washington',37295,56);
INSERT INTO "django_geo_db_city" VALUES(29837,'Roy','Roy, Washington',37296,56);
INSERT INTO "django_geo_db_city" VALUES(29838,'Ryderwood','Ryderwood, Washington',37297,56);
INSERT INTO "django_geo_db_city" VALUES(29839,'Salkum','Salkum, Washington',37298,56);
INSERT INTO "django_geo_db_city" VALUES(29840,'Satsop','Satsop, Washington',37299,56);
INSERT INTO "django_geo_db_city" VALUES(29841,'Shelton','Shelton, Washington',37300,56);
INSERT INTO "django_geo_db_city" VALUES(29842,'Silver Creek','Silver Creek, Washington',37301,56);
INSERT INTO "django_geo_db_city" VALUES(29843,'South Bend','South Bend, Washington',37302,56);
INSERT INTO "django_geo_db_city" VALUES(29844,'Taholah','Taholah, Washington',37303,56);
INSERT INTO "django_geo_db_city" VALUES(29845,'Tahuya','Tahuya, Washington',37304,56);
INSERT INTO "django_geo_db_city" VALUES(29846,'Tenino','Tenino, Washington',37305,56);
INSERT INTO "django_geo_db_city" VALUES(29847,'Tokeland','Tokeland, Washington',37306,56);
INSERT INTO "django_geo_db_city" VALUES(29848,'Toledo','Toledo, Washington',37307,56);
INSERT INTO "django_geo_db_city" VALUES(29849,'Union','Union, Washington',37308,56);
INSERT INTO "django_geo_db_city" VALUES(29850,'Vader','Vader, Washington',37309,56);
INSERT INTO "django_geo_db_city" VALUES(29851,'Westport','Westport, Washington',37310,56);
INSERT INTO "django_geo_db_city" VALUES(29852,'Winlock','Winlock, Washington',37311,56);
INSERT INTO "django_geo_db_city" VALUES(29853,'Yelm','Yelm, Washington',37312,56);
INSERT INTO "django_geo_db_city" VALUES(29854,'Amboy','Amboy, Washington',37313,56);
INSERT INTO "django_geo_db_city" VALUES(29855,'Appleton','Appleton, Washington',37314,56);
INSERT INTO "django_geo_db_city" VALUES(29856,'Ariel','Ariel, Washington',37315,56);
INSERT INTO "django_geo_db_city" VALUES(29857,'Battle Ground','Battle Ground, Washington',37316,56);
INSERT INTO "django_geo_db_city" VALUES(29858,'Bingen','Bingen, Washington',37317,56);
INSERT INTO "django_geo_db_city" VALUES(29859,'Brush Prairie','Brush Prairie, Washington',37318,56);
INSERT INTO "django_geo_db_city" VALUES(29860,'Camas','Camas, Washington',37319,56);
INSERT INTO "django_geo_db_city" VALUES(29861,'Carrolls','Carrolls, Washington',37320,56);
INSERT INTO "django_geo_db_city" VALUES(29862,'Carson','Carson, Washington',37321,56);
INSERT INTO "django_geo_db_city" VALUES(29863,'Castle Rock','Castle Rock, Washington',37322,56);
INSERT INTO "django_geo_db_city" VALUES(29864,'Cathlamet','Cathlamet, Washington',37323,56);
INSERT INTO "django_geo_db_city" VALUES(29865,'Centerville','Centerville, Washington',37324,56);
INSERT INTO "django_geo_db_city" VALUES(29866,'Chinook','Chinook, Washington',37325,56);
INSERT INTO "django_geo_db_city" VALUES(29867,'Cougar','Cougar, Washington',37326,56);
INSERT INTO "django_geo_db_city" VALUES(29868,'Dallesport','Dallesport, Washington',37327,56);
INSERT INTO "django_geo_db_city" VALUES(29869,'Glenwood','Glenwood, Washington',37328,56);
INSERT INTO "django_geo_db_city" VALUES(29870,'Goldendale','Goldendale, Washington',37329,56);
INSERT INTO "django_geo_db_city" VALUES(29871,'Grays River','Grays River, Washington',37330,56);
INSERT INTO "django_geo_db_city" VALUES(29872,'Heisson','Heisson, Washington',37331,56);
INSERT INTO "django_geo_db_city" VALUES(29873,'Husum','Husum, Washington',37332,56);
INSERT INTO "django_geo_db_city" VALUES(29874,'Ilwaco','Ilwaco, Washington',37333,56);
INSERT INTO "django_geo_db_city" VALUES(29875,'Kalama','Kalama, Washington',37334,56);
INSERT INTO "django_geo_db_city" VALUES(29876,'Kelso','Kelso, Washington',37335,56);
INSERT INTO "django_geo_db_city" VALUES(29877,'Klickitat','Klickitat, Washington',37336,56);
INSERT INTO "django_geo_db_city" VALUES(29878,'La Center','La Center, Washington',37337,56);
INSERT INTO "django_geo_db_city" VALUES(29879,'Long Beach','Long Beach, Washington',37338,56);
INSERT INTO "django_geo_db_city" VALUES(29880,'Longview','Longview, Washington',37339,56);
INSERT INTO "django_geo_db_city" VALUES(29881,'Lyle','Lyle, Washington',37340,56);
INSERT INTO "django_geo_db_city" VALUES(29882,'Nahcotta','Nahcotta, Washington',37281,56);
INSERT INTO "django_geo_db_city" VALUES(29883,'Naselle','Naselle, Washington',37341,56);
INSERT INTO "django_geo_db_city" VALUES(29884,'North Bonneville','North Bonneville, Washington',37342,56);
INSERT INTO "django_geo_db_city" VALUES(29885,'Ocean Park','Ocean Park, Washington',37343,56);
INSERT INTO "django_geo_db_city" VALUES(29886,'Oysterville','Oysterville, Washington',37344,56);
INSERT INTO "django_geo_db_city" VALUES(29887,'Ridgefield','Ridgefield, Washington',37345,56);
INSERT INTO "django_geo_db_city" VALUES(29888,'Rosburg','Rosburg, Washington',37346,56);
INSERT INTO "django_geo_db_city" VALUES(29889,'Seaview','Seaview, Washington',37347,56);
INSERT INTO "django_geo_db_city" VALUES(29890,'Silverlake','Silverlake, Washington',37348,56);
INSERT INTO "django_geo_db_city" VALUES(29891,'Skamokawa','Skamokawa, Washington',37349,56);
INSERT INTO "django_geo_db_city" VALUES(29892,'Stevenson','Stevenson, Washington',37350,56);
INSERT INTO "django_geo_db_city" VALUES(29893,'Toutle','Toutle, Washington',37351,56);
INSERT INTO "django_geo_db_city" VALUES(29894,'Trout Lake','Trout Lake, Washington',37352,56);
INSERT INTO "django_geo_db_city" VALUES(29895,'Underwood','Underwood, Washington',37353,56);
INSERT INTO "django_geo_db_city" VALUES(29896,'Hazel Dell North','Hazel Dell North, Washington',37355,56);
INSERT INTO "django_geo_db_city" VALUES(29897,'Vancouver','Vancouver, Washington',37356,56);
INSERT INTO "django_geo_db_city" VALUES(29898,'Wahkiacus','Wahkiacus, Washington',37362,56);
INSERT INTO "django_geo_db_city" VALUES(29899,'Washougal','Washougal, Washington',37363,56);
INSERT INTO "django_geo_db_city" VALUES(29900,'White Salmon','White Salmon, Washington',37364,56);
INSERT INTO "django_geo_db_city" VALUES(29901,'Wishram','Wishram, Washington',37365,56);
INSERT INTO "django_geo_db_city" VALUES(29902,'Woodland','Woodland, Washington',37366,56);
INSERT INTO "django_geo_db_city" VALUES(29903,'Yacolt','Yacolt, Washington',37367,56);
INSERT INTO "django_geo_db_city" VALUES(29904,'Waller','Waller, Washington',37373,56);
INSERT INTO "django_geo_db_city" VALUES(29905,'Wenatchee','Wenatchee, Washington',37374,56);
INSERT INTO "django_geo_db_city" VALUES(29906,'East Wenatchee','East Wenatchee, Washington',37375,56);
INSERT INTO "django_geo_db_city" VALUES(29907,'Ardenvoir','Ardenvoir, Washington',37377,56);
INSERT INTO "django_geo_db_city" VALUES(29908,'Brewster','Brewster, Washington',37378,56);
INSERT INTO "django_geo_db_city" VALUES(29909,'Bridgeport','Bridgeport, Washington',37379,56);
INSERT INTO "django_geo_db_city" VALUES(29910,'Carlton','Carlton, Washington',37380,56);
INSERT INTO "django_geo_db_city" VALUES(29911,'Cashmere','Cashmere, Washington',37381,56);
INSERT INTO "django_geo_db_city" VALUES(29912,'Chelan','Chelan, Washington',37382,56);
INSERT INTO "django_geo_db_city" VALUES(29913,'Chelan Falls','Chelan Falls, Washington',37383,56);
INSERT INTO "django_geo_db_city" VALUES(29914,'Conconully','Conconully, Washington',37384,56);
INSERT INTO "django_geo_db_city" VALUES(29915,'Dryden','Dryden, Washington',37385,56);
INSERT INTO "django_geo_db_city" VALUES(29916,'Entiat','Entiat, Washington',37386,56);
INSERT INTO "django_geo_db_city" VALUES(29917,'Ephrata','Ephrata, Washington',37387,56);
INSERT INTO "django_geo_db_city" VALUES(29918,'George','George, Washington',37388,56);
INSERT INTO "django_geo_db_city" VALUES(29919,'Leavenworth','Leavenworth, Washington',37389,56);
INSERT INTO "django_geo_db_city" VALUES(29920,'Loomis','Loomis, Washington',37390,56);
INSERT INTO "django_geo_db_city" VALUES(29921,'Malaga','Malaga, Washington',37391,56);
INSERT INTO "django_geo_db_city" VALUES(29922,'Malott','Malott, Washington',37392,56);
INSERT INTO "django_geo_db_city" VALUES(29923,'Mansfield','Mansfield, Washington',37393,56);
INSERT INTO "django_geo_db_city" VALUES(29924,'Manson','Manson, Washington',37394,56);
INSERT INTO "django_geo_db_city" VALUES(29925,'Marlin','Marlin, Washington',37395,56);
INSERT INTO "django_geo_db_city" VALUES(29926,'Mazama','Mazama, Washington',37396,56);
INSERT INTO "django_geo_db_city" VALUES(29927,'Methow','Methow, Washington',37397,56);
INSERT INTO "django_geo_db_city" VALUES(29928,'Monitor','Monitor, Washington',37398,56);
INSERT INTO "django_geo_db_city" VALUES(29929,'Moses Lake','Moses Lake, Washington',37399,56);
INSERT INTO "django_geo_db_city" VALUES(29930,'Okanogan','Okanogan, Washington',37400,56);
INSERT INTO "django_geo_db_city" VALUES(29931,'Omak','Omak, Washington',37401,56);
INSERT INTO "django_geo_db_city" VALUES(29932,'Orondo','Orondo, Washington',37402,56);
INSERT INTO "django_geo_db_city" VALUES(29933,'Oroville','Oroville, Washington',37403,56);
INSERT INTO "django_geo_db_city" VALUES(29934,'Palisades','Palisades, Washington',37404,56);
INSERT INTO "django_geo_db_city" VALUES(29935,'Pateros','Pateros, Washington',37405,56);
INSERT INTO "django_geo_db_city" VALUES(29936,'Peshastin','Peshastin, Washington',37406,56);
INSERT INTO "django_geo_db_city" VALUES(29937,'Quincy','Quincy, Washington',37407,56);
INSERT INTO "django_geo_db_city" VALUES(29938,'Riverside','Riverside, Washington',37408,56);
INSERT INTO "django_geo_db_city" VALUES(29939,'Rock Island','Rock Island, Washington',37409,56);
INSERT INTO "django_geo_db_city" VALUES(29940,'Soap Lake','Soap Lake, Washington',37410,56);
INSERT INTO "django_geo_db_city" VALUES(29941,'Stehekin','Stehekin, Washington',37411,56);
INSERT INTO "django_geo_db_city" VALUES(29942,'Stratford','Stratford, Washington',37412,56);
INSERT INTO "django_geo_db_city" VALUES(29943,'Tonasket','Tonasket, Washington',37413,56);
INSERT INTO "django_geo_db_city" VALUES(29944,'Twisp','Twisp, Washington',37414,56);
INSERT INTO "django_geo_db_city" VALUES(29945,'Warden','Warden, Washington',37415,56);
INSERT INTO "django_geo_db_city" VALUES(29946,'Waterville','Waterville, Washington',37416,56);
INSERT INTO "django_geo_db_city" VALUES(29947,'Wauconda','Wauconda, Washington',37417,56);
INSERT INTO "django_geo_db_city" VALUES(29948,'Wilson Creek','Wilson Creek, Washington',37418,56);
INSERT INTO "django_geo_db_city" VALUES(29949,'Winthrop','Winthrop, Washington',37419,56);
INSERT INTO "django_geo_db_city" VALUES(29950,'Yakima','Yakima, Washington',37420,56);
INSERT INTO "django_geo_db_city" VALUES(29951,'Brownstown','Brownstown, Washington',37423,56);
INSERT INTO "django_geo_db_city" VALUES(29952,'Buena','Buena, Washington',37427,56);
INSERT INTO "django_geo_db_city" VALUES(29953,'Cle Elum','Cle Elum, Washington',37428,56);
INSERT INTO "django_geo_db_city" VALUES(29954,'Cowiche','Cowiche, Washington',37429,56);
INSERT INTO "django_geo_db_city" VALUES(29955,'Easton','Easton, Washington',37430,56);
INSERT INTO "django_geo_db_city" VALUES(29956,'Ellensburg','Ellensburg, Washington',37431,56);
INSERT INTO "django_geo_db_city" VALUES(29957,'Goose Prairie','Goose Prairie, Washington',37432,56);
INSERT INTO "django_geo_db_city" VALUES(29958,'Grandview','Grandview, Washington',37433,56);
INSERT INTO "django_geo_db_city" VALUES(29959,'Granger','Granger, Washington',37434,56);
INSERT INTO "django_geo_db_city" VALUES(29960,'Harrah','Harrah, Washington',37435,56);
INSERT INTO "django_geo_db_city" VALUES(29961,'Kittitas','Kittitas, Washington',37436,56);
INSERT INTO "django_geo_db_city" VALUES(29962,'Mabton','Mabton, Washington',37437,56);
INSERT INTO "django_geo_db_city" VALUES(29963,'Moxee','Moxee, Washington',37438,56);
INSERT INTO "django_geo_db_city" VALUES(29964,'Naches','Naches, Washington',37439,56);
INSERT INTO "django_geo_db_city" VALUES(29965,'Outlook','Outlook, Washington',37440,56);
INSERT INTO "django_geo_db_city" VALUES(29966,'Parker','Parker, Washington',37423,56);
INSERT INTO "django_geo_db_city" VALUES(29967,'Ronald','Ronald, Washington',37441,56);
INSERT INTO "django_geo_db_city" VALUES(29968,'Roslyn','Roslyn, Washington',37442,56);
INSERT INTO "django_geo_db_city" VALUES(29969,'Selah','Selah, Washington',37443,56);
INSERT INTO "django_geo_db_city" VALUES(29970,'South Cle Elum','South Cle Elum, Washington',37444,56);
INSERT INTO "django_geo_db_city" VALUES(29971,'Sunnyside','Sunnyside, Washington',37445,56);
INSERT INTO "django_geo_db_city" VALUES(29972,'Thorp','Thorp, Washington',37446,56);
INSERT INTO "django_geo_db_city" VALUES(29973,'Tieton','Tieton, Washington',37447,56);
INSERT INTO "django_geo_db_city" VALUES(29974,'Toppenish','Toppenish, Washington',37448,56);
INSERT INTO "django_geo_db_city" VALUES(29975,'Vantage','Vantage, Washington',37449,56);
INSERT INTO "django_geo_db_city" VALUES(29976,'Wapato','Wapato, Washington',37450,56);
INSERT INTO "django_geo_db_city" VALUES(29977,'White Swan','White Swan, Washington',37451,56);
INSERT INTO "django_geo_db_city" VALUES(29978,'Zillah','Zillah, Washington',37452,56);
INSERT INTO "django_geo_db_city" VALUES(29979,'Airway Heights','Airway Heights, Washington',37454,56);
INSERT INTO "django_geo_db_city" VALUES(29980,'Chattaroy','Chattaroy, Washington',37455,56);
INSERT INTO "django_geo_db_city" VALUES(29981,'Cheney','Cheney, Washington',37456,56);
INSERT INTO "django_geo_db_city" VALUES(29982,'Colbert','Colbert, Washington',37457,56);
INSERT INTO "django_geo_db_city" VALUES(29983,'Deer Park','Deer Park, Washington',37458,56);
INSERT INTO "django_geo_db_city" VALUES(29984,'Edwall','Edwall, Washington',37459,56);
INSERT INTO "django_geo_db_city" VALUES(29985,'Elk','Elk, Washington',37460,56);
INSERT INTO "django_geo_db_city" VALUES(29986,'Fairchild Air Force Base','Fairchild Air Force Base, Washington',37461,56);
INSERT INTO "django_geo_db_city" VALUES(29987,'Fairfield','Fairfield, Washington',37462,56);
INSERT INTO "django_geo_db_city" VALUES(29988,'Ford','Ford, Washington',37463,56);
INSERT INTO "django_geo_db_city" VALUES(29989,'Four Lakes','Four Lakes, Washington',37464,56);
INSERT INTO "django_geo_db_city" VALUES(29990,'Freeman','Freeman, Washington',37465,56);
INSERT INTO "django_geo_db_city" VALUES(29991,'Greenacres','Greenacres, Washington',37466,56);
INSERT INTO "django_geo_db_city" VALUES(29992,'Lamont','Lamont, Washington',37467,56);
INSERT INTO "django_geo_db_city" VALUES(29993,'Latah','Latah, Washington',37468,56);
INSERT INTO "django_geo_db_city" VALUES(29994,'Liberty Lake','Liberty Lake, Washington',37469,56);
INSERT INTO "django_geo_db_city" VALUES(29995,'Marshall','Marshall, Washington',37470,56);
INSERT INTO "django_geo_db_city" VALUES(29996,'Mead','Mead, Washington',37471,56);
INSERT INTO "django_geo_db_city" VALUES(29997,'Medical Lake','Medical Lake, Washington',37472,56);
INSERT INTO "django_geo_db_city" VALUES(29998,'Mica','Mica, Washington',37473,56);
INSERT INTO "django_geo_db_city" VALUES(29999,'Newman Lake','Newman Lake, Washington',37474,56);
INSERT INTO "django_geo_db_city" VALUES(30000,'Nine Mile Falls','Nine Mile Falls, Washington',37475,56);
INSERT INTO "django_geo_db_city" VALUES(30001,'Otis Orchards','Otis Orchards, Washington',37476,56);
INSERT INTO "django_geo_db_city" VALUES(30002,'Reardan','Reardan, Washington',37477,56);
INSERT INTO "django_geo_db_city" VALUES(30003,'Rockford','Rockford, Washington',37478,56);
INSERT INTO "django_geo_db_city" VALUES(30004,'Spangle','Spangle, Washington',37479,56);
INSERT INTO "django_geo_db_city" VALUES(30005,'Sprague','Sprague, Washington',37480,56);
INSERT INTO "django_geo_db_city" VALUES(30006,'Tekoa','Tekoa, Washington',37481,56);
INSERT INTO "django_geo_db_city" VALUES(30007,'Tumtum','Tumtum, Washington',37482,56);
INSERT INTO "django_geo_db_city" VALUES(30008,'Valleyford','Valleyford, Washington',37483,56);
INSERT INTO "django_geo_db_city" VALUES(30009,'Veradale','Veradale, Washington',37484,56);
INSERT INTO "django_geo_db_city" VALUES(30010,'Waverly','Waverly, Washington',37485,56);
INSERT INTO "django_geo_db_city" VALUES(30011,'Wellpinit','Wellpinit, Washington',37486,56);
INSERT INTO "django_geo_db_city" VALUES(30012,'Addy','Addy, Washington',37488,56);
INSERT INTO "django_geo_db_city" VALUES(30013,'Albion','Albion, Washington',37489,56);
INSERT INTO "django_geo_db_city" VALUES(30014,'Almira','Almira, Washington',37490,56);
INSERT INTO "django_geo_db_city" VALUES(30015,'Belmont','Belmont, Washington',37491,56);
INSERT INTO "django_geo_db_city" VALUES(30016,'Benge','Benge, Washington',37492,56);
INSERT INTO "django_geo_db_city" VALUES(30017,'Boyds','Boyds, Washington',37493,56);
INSERT INTO "django_geo_db_city" VALUES(30018,'Chewelah','Chewelah, Washington',37494,56);
INSERT INTO "django_geo_db_city" VALUES(30019,'Clayton','Clayton, Washington',37495,56);
INSERT INTO "django_geo_db_city" VALUES(30020,'Colfax','Colfax, Washington',37496,56);
INSERT INTO "django_geo_db_city" VALUES(30021,'Colton','Colton, Washington',37497,56);
INSERT INTO "django_geo_db_city" VALUES(30022,'Colville','Colville, Washington',37498,56);
INSERT INTO "django_geo_db_city" VALUES(30023,'Coulee City','Coulee City, Washington',37499,56);
INSERT INTO "django_geo_db_city" VALUES(30024,'Coulee Dam','Coulee Dam, Washington',37500,56);
INSERT INTO "django_geo_db_city" VALUES(30025,'Creston','Creston, Washington',37501,56);
INSERT INTO "django_geo_db_city" VALUES(30026,'Curlew','Curlew, Washington',37502,56);
INSERT INTO "django_geo_db_city" VALUES(30027,'Cusick','Cusick, Washington',37503,56);
INSERT INTO "django_geo_db_city" VALUES(30028,'Danville','Danville, Washington',37504,56);
INSERT INTO "django_geo_db_city" VALUES(30029,'Davenport','Davenport, Washington',37505,56);
INSERT INTO "django_geo_db_city" VALUES(30030,'Electric City','Electric City, Washington',37506,56);
INSERT INTO "django_geo_db_city" VALUES(30031,'Elmer City','Elmer City, Washington',37507,56);
INSERT INTO "django_geo_db_city" VALUES(30032,'Endicott','Endicott, Washington',37508,56);
INSERT INTO "django_geo_db_city" VALUES(30033,'Evans','Evans, Washington',37509,56);
INSERT INTO "django_geo_db_city" VALUES(30034,'Saint John','Saint John, Washington',37510,56);
INSERT INTO "django_geo_db_city" VALUES(30035,'Farmington','Farmington, Idaho',37511,16);
INSERT INTO "django_geo_db_city" VALUES(30036,'Fruitland','Fruitland, Washington',37512,56);
INSERT INTO "django_geo_db_city" VALUES(30037,'Garfield','Garfield, Washington',37513,56);
INSERT INTO "django_geo_db_city" VALUES(30038,'Gifford','Gifford, Washington',37514,56);
INSERT INTO "django_geo_db_city" VALUES(30039,'Grand Coulee','Grand Coulee, Washington',37515,56);
INSERT INTO "django_geo_db_city" VALUES(30040,'Harrington','Harrington, Washington',37516,56);
INSERT INTO "django_geo_db_city" VALUES(30041,'Hartline','Hartline, Washington',37517,56);
INSERT INTO "django_geo_db_city" VALUES(30042,'Hay','Hay, Washington',37518,56);
INSERT INTO "django_geo_db_city" VALUES(30043,'Hunters','Hunters, Washington',37519,56);
INSERT INTO "django_geo_db_city" VALUES(30044,'Inchelium','Inchelium, Washington',37520,56);
INSERT INTO "django_geo_db_city" VALUES(30045,'Ione','Ione, Washington',37521,56);
INSERT INTO "django_geo_db_city" VALUES(30046,'Keller','Keller, Washington',37522,56);
INSERT INTO "django_geo_db_city" VALUES(30047,'Kettle Falls','Kettle Falls, Washington',37523,56);
INSERT INTO "django_geo_db_city" VALUES(30048,'Lacrosse','Lacrosse, Washington',37524,56);
INSERT INTO "django_geo_db_city" VALUES(30049,'Lamona','Lamona, Washington',37525,56);
INSERT INTO "django_geo_db_city" VALUES(30050,'Laurier','Laurier, Washington',37526,56);
INSERT INTO "django_geo_db_city" VALUES(30051,'Lincoln','Lincoln, Washington',37525,56);
INSERT INTO "django_geo_db_city" VALUES(30052,'Loon Lake','Loon Lake, Washington',37527,56);
INSERT INTO "django_geo_db_city" VALUES(30053,'Malden','Malden, Washington',37528,56);
INSERT INTO "django_geo_db_city" VALUES(30054,'Malo','Malo, Washington',37529,56);
INSERT INTO "django_geo_db_city" VALUES(30055,'Marcus','Marcus, Washington',37530,56);
INSERT INTO "django_geo_db_city" VALUES(30056,'Metaline','Metaline, Washington',37531,56);
INSERT INTO "django_geo_db_city" VALUES(30057,'Metaline Falls','Metaline Falls, Washington',37532,56);
INSERT INTO "django_geo_db_city" VALUES(30058,'Mohler','Mohler, Washington',37533,56);
INSERT INTO "django_geo_db_city" VALUES(30059,'Nespelem','Nespelem, Washington',37534,56);
INSERT INTO "django_geo_db_city" VALUES(30060,'Newport','Newport, Washington',37535,56);
INSERT INTO "django_geo_db_city" VALUES(30061,'Northport','Northport, Washington',37536,56);
INSERT INTO "django_geo_db_city" VALUES(30062,'Oakesdale','Oakesdale, Washington',37537,56);
INSERT INTO "django_geo_db_city" VALUES(30063,'Odessa','Odessa, Washington',37538,56);
INSERT INTO "django_geo_db_city" VALUES(30064,'Orient','Orient, Washington',37539,56);
INSERT INTO "django_geo_db_city" VALUES(30065,'Palouse','Palouse, Washington',37540,56);
INSERT INTO "django_geo_db_city" VALUES(30066,'Pullman','Pullman, Washington',37541,56);
INSERT INTO "django_geo_db_city" VALUES(30067,'Republic','Republic, Washington',37542,56);
INSERT INTO "django_geo_db_city" VALUES(30068,'Rice','Rice, Washington',37543,56);
INSERT INTO "django_geo_db_city" VALUES(30069,'Ritzville','Ritzville, Washington',37544,56);
INSERT INTO "django_geo_db_city" VALUES(30070,'Rosalia','Rosalia, Washington',37545,56);
INSERT INTO "django_geo_db_city" VALUES(30071,'Springdale','Springdale, Washington',37547,56);
INSERT INTO "django_geo_db_city" VALUES(30072,'Steptoe','Steptoe, Washington',37510,56);
INSERT INTO "django_geo_db_city" VALUES(30073,'Thornton','Thornton, Washington',37548,56);
INSERT INTO "django_geo_db_city" VALUES(30074,'Uniontown','Uniontown, Washington',37549,56);
INSERT INTO "django_geo_db_city" VALUES(30075,'Usk','Usk, Washington',37550,56);
INSERT INTO "django_geo_db_city" VALUES(30076,'Valley','Valley, Washington',37551,56);
INSERT INTO "django_geo_db_city" VALUES(30077,'Wilbur','Wilbur, Washington',37552,56);
INSERT INTO "django_geo_db_city" VALUES(30078,'Spokane','Spokane, Washington',37553,56);
INSERT INTO "django_geo_db_city" VALUES(30079,'Pasco','Pasco, Washington',37569,56);
INSERT INTO "django_geo_db_city" VALUES(30080,'Mattawa','Mattawa, Washington',37571,56);
INSERT INTO "django_geo_db_city" VALUES(30081,'Desert Aire','Desert Aire, Washington',37572,56);
INSERT INTO "django_geo_db_city" VALUES(30082,'Benton City','Benton City, Washington',37573,56);
INSERT INTO "django_geo_db_city" VALUES(30083,'Beverly','Beverly, Washington',37574,56);
INSERT INTO "django_geo_db_city" VALUES(30084,'Bickleton','Bickleton, Washington',37575,56);
INSERT INTO "django_geo_db_city" VALUES(30085,'Burbank','Burbank, Washington',37576,56);
INSERT INTO "django_geo_db_city" VALUES(30086,'College Place','College Place, Washington',37577,56);
INSERT INTO "django_geo_db_city" VALUES(30087,'Connell','Connell, Washington',37578,56);
INSERT INTO "django_geo_db_city" VALUES(30088,'Cunningham','Cunningham, Washington',37579,56);
INSERT INTO "django_geo_db_city" VALUES(30089,'Dayton','Dayton, Washington',37580,56);
INSERT INTO "django_geo_db_city" VALUES(30090,'Dixie','Dixie, Washington',37581,56);
INSERT INTO "django_geo_db_city" VALUES(30091,'Eltopia','Eltopia, Washington',37582,56);
INSERT INTO "django_geo_db_city" VALUES(30092,'Hatton','Hatton, Washington',37583,56);
INSERT INTO "django_geo_db_city" VALUES(30093,'Hooper','Hooper, Washington',37510,56);
INSERT INTO "django_geo_db_city" VALUES(30094,'Kahlotus','Kahlotus, Washington',37584,56);
INSERT INTO "django_geo_db_city" VALUES(30095,'Kennewick','Kennewick, Washington',37585,56);
INSERT INTO "django_geo_db_city" VALUES(30096,'Lind','Lind, Washington',37588,56);
INSERT INTO "django_geo_db_city" VALUES(30097,'Mesa','Mesa, Washington',37589,56);
INSERT INTO "django_geo_db_city" VALUES(30098,'Othello','Othello, Washington',37590,56);
INSERT INTO "django_geo_db_city" VALUES(30099,'Paterson','Paterson, Washington',37591,56);
INSERT INTO "django_geo_db_city" VALUES(30100,'Plymouth','Plymouth, Washington',37592,56);
INSERT INTO "django_geo_db_city" VALUES(30101,'Pomeroy','Pomeroy, Washington',37593,56);
INSERT INTO "django_geo_db_city" VALUES(30102,'Prescott','Prescott, Washington',37594,56);
INSERT INTO "django_geo_db_city" VALUES(30103,'Prosser','Prosser, Washington',37596,56);
INSERT INTO "django_geo_db_city" VALUES(30104,'Richland','Richland, Washington',37597,56);
INSERT INTO "django_geo_db_city" VALUES(30105,'West Richland','West Richland, Washington',37598,56);
INSERT INTO "django_geo_db_city" VALUES(30106,'Roosevelt','Roosevelt, Washington',37599,56);
INSERT INTO "django_geo_db_city" VALUES(30107,'Royal City','Royal City, Washington',37600,56);
INSERT INTO "django_geo_db_city" VALUES(30108,'Starbuck','Starbuck, Washington',37601,56);
INSERT INTO "django_geo_db_city" VALUES(30109,'Touchet','Touchet, Washington',37602,56);
INSERT INTO "django_geo_db_city" VALUES(30110,'Waitsburg','Waitsburg, Washington',37603,56);
INSERT INTO "django_geo_db_city" VALUES(30111,'Walla Walla','Walla Walla, Oregon',37604,37);
INSERT INTO "django_geo_db_city" VALUES(30112,'Wallula','Wallula, Washington',37605,56);
INSERT INTO "django_geo_db_city" VALUES(30113,'Washtucna','Washtucna, Washington',37606,56);
INSERT INTO "django_geo_db_city" VALUES(30114,'Anatone','Anatone, Washington',37607,56);
INSERT INTO "django_geo_db_city" VALUES(30115,'Asotin','Asotin, Washington',37608,56);
INSERT INTO "django_geo_db_city" VALUES(30116,'Clarkston','Clarkston, Washington',37609,56);
INSERT INTO "django_geo_db_city" VALUES(30117,'Anchorage','Anchorage, Alaska',37610,2);
INSERT INTO "django_geo_db_city" VALUES(30118,'Fort Richardson','Fort Richardson, Alaska',37614,2);
INSERT INTO "django_geo_db_city" VALUES(30119,'Elmendorf AFB','Elmendorf AFB, Alaska',37615,2);
INSERT INTO "django_geo_db_city" VALUES(30120,'Indian','Indian, Alaska',37628,2);
INSERT INTO "django_geo_db_city" VALUES(30121,'Adak','Adak, Alaska',37629,2);
INSERT INTO "django_geo_db_city" VALUES(30122,'Atka','Atka, Alaska',37630,2);
INSERT INTO "django_geo_db_city" VALUES(30123,'Chignik Lake','Chignik Lake, Alaska',37631,2);
INSERT INTO "django_geo_db_city" VALUES(30124,'Port Heiden','Port Heiden, Alaska',37632,2);
INSERT INTO "django_geo_db_city" VALUES(30125,'Port Lions','Port Lions, Alaska',37633,2);
INSERT INTO "django_geo_db_city" VALUES(30126,'Akiachak','Akiachak, Alaska',37634,2);
INSERT INTO "django_geo_db_city" VALUES(30127,'Akiak','Akiak, Alaska',37635,2);
INSERT INTO "django_geo_db_city" VALUES(30128,'Akutan','Akutan, Alaska',37636,2);
INSERT INTO "django_geo_db_city" VALUES(30129,'Alakanuk','Alakanuk, Alaska',37637,2);
INSERT INTO "django_geo_db_city" VALUES(30130,'Aleknagik','Aleknagik, Alaska',37638,2);
INSERT INTO "django_geo_db_city" VALUES(30131,'Anchor Point','Anchor Point, Alaska',37639,2);
INSERT INTO "django_geo_db_city" VALUES(30132,'Aniak','Aniak, Alaska',37640,2);
INSERT INTO "django_geo_db_city" VALUES(30133,'Anvik','Anvik, Alaska',37641,2);
INSERT INTO "django_geo_db_city" VALUES(30134,'Bethel','Bethel, Alaska',37642,2);
INSERT INTO "django_geo_db_city" VALUES(30135,'Chefornak','Chefornak, Alaska',37643,2);
INSERT INTO "django_geo_db_city" VALUES(30136,'Chevak','Chevak, Alaska',37644,2);
INSERT INTO "django_geo_db_city" VALUES(30137,'Chignik','Chignik, Alaska',37645,2);
INSERT INTO "django_geo_db_city" VALUES(30138,'Chignik Lagoon','Chignik Lagoon, Alaska',37646,2);
INSERT INTO "django_geo_db_city" VALUES(30139,'Chitina','Chitina, Alaska',37647,2);
INSERT INTO "django_geo_db_city" VALUES(30140,'Chugiak','Chugiak, Alaska',37648,2);
INSERT INTO "django_geo_db_city" VALUES(30141,'Clam Gulch','Clam Gulch, Alaska',37649,2);
INSERT INTO "django_geo_db_city" VALUES(30142,'Clarks Point','Clarks Point, Alaska',37650,2);
INSERT INTO "django_geo_db_city" VALUES(30143,'Cold Bay','Cold Bay, Alaska',37651,2);
INSERT INTO "django_geo_db_city" VALUES(30144,'Cooper Landing','Cooper Landing, Alaska',37652,2);
INSERT INTO "django_geo_db_city" VALUES(30145,'Copper Center','Copper Center, Alaska',37653,2);
INSERT INTO "django_geo_db_city" VALUES(30146,'Cordova','Cordova, Alaska',37654,2);
INSERT INTO "django_geo_db_city" VALUES(30147,'Crooked Creek','Crooked Creek, Alaska',37655,2);
INSERT INTO "django_geo_db_city" VALUES(30148,'Dillingham','Dillingham, Alaska',37656,2);
INSERT INTO "django_geo_db_city" VALUES(30149,'Eagle River','Eagle River, Alaska',37657,2);
INSERT INTO "django_geo_db_city" VALUES(30150,'Eek','Eek, Alaska',37658,2);
INSERT INTO "django_geo_db_city" VALUES(30151,'Egegik','Egegik, Alaska',37659,2);
INSERT INTO "django_geo_db_city" VALUES(30152,'Ekwok','Ekwok, Alaska',37660,2);
INSERT INTO "django_geo_db_city" VALUES(30153,'Emmonak','Emmonak, Alaska',37661,2);
INSERT INTO "django_geo_db_city" VALUES(30154,'False Pass','False Pass, Alaska',37662,2);
INSERT INTO "django_geo_db_city" VALUES(30155,'Flat','Flat, Alaska',37663,2);
INSERT INTO "django_geo_db_city" VALUES(30156,'Marshall','Marshall, Alaska',37664,2);
INSERT INTO "django_geo_db_city" VALUES(30157,'Gakona','Gakona, Alaska',37665,2);
INSERT INTO "django_geo_db_city" VALUES(30158,'Girdwood','Girdwood, Alaska',37666,2);
INSERT INTO "django_geo_db_city" VALUES(30159,'Glennallen','Glennallen, Alaska',37667,2);
INSERT INTO "django_geo_db_city" VALUES(30160,'Goodnews Bay','Goodnews Bay, Alaska',37668,2);
INSERT INTO "django_geo_db_city" VALUES(30161,'Grayling','Grayling, Alaska',37669,2);
INSERT INTO "django_geo_db_city" VALUES(30162,'Saint George Island','Saint George Island, Alaska',37670,2);
INSERT INTO "django_geo_db_city" VALUES(30163,'Holy Cross','Holy Cross, Alaska',37672,2);
INSERT INTO "django_geo_db_city" VALUES(30164,'Homer','Homer, Alaska',37673,2);
INSERT INTO "django_geo_db_city" VALUES(30165,'Hooper Bay','Hooper Bay, Alaska',37674,2);
INSERT INTO "django_geo_db_city" VALUES(30166,'Hope','Hope, Alaska',37675,2);
INSERT INTO "django_geo_db_city" VALUES(30167,'Iliamna','Iliamna, Alaska',37676,2);
INSERT INTO "django_geo_db_city" VALUES(30168,'Kalskag','Kalskag, Alaska',37677,2);
INSERT INTO "django_geo_db_city" VALUES(30169,'Karluk','Karluk, Alaska',37678,2);
INSERT INTO "django_geo_db_city" VALUES(30170,'Kasigluk','Kasigluk, Alaska',37679,2);
INSERT INTO "django_geo_db_city" VALUES(30171,'Kasilof','Kasilof, Alaska',37680,2);
INSERT INTO "django_geo_db_city" VALUES(30172,'Kenai','Kenai, Alaska',37681,2);
INSERT INTO "django_geo_db_city" VALUES(30173,'King Cove','King Cove, Alaska',37682,2);
INSERT INTO "django_geo_db_city" VALUES(30174,'King Salmon','King Salmon, Alaska',37683,2);
INSERT INTO "django_geo_db_city" VALUES(30175,'Kipnuk','Kipnuk, Alaska',37684,2);
INSERT INTO "django_geo_db_city" VALUES(30176,'Kodiak','Kodiak, Alaska',37685,2);
INSERT INTO "django_geo_db_city" VALUES(30177,'Kotlik','Kotlik, Alaska',37687,2);
INSERT INTO "django_geo_db_city" VALUES(30178,'Kwethluk','Kwethluk, Alaska',37688,2);
INSERT INTO "django_geo_db_city" VALUES(30179,'Kwigillingok','Kwigillingok, Alaska',37689,2);
INSERT INTO "django_geo_db_city" VALUES(30180,'Larsen Bay','Larsen Bay, Alaska',37690,2);
INSERT INTO "django_geo_db_city" VALUES(30181,'Levelock','Levelock, Alaska',37691,2);
INSERT INTO "django_geo_db_city" VALUES(30182,'Lower Kalskag','Lower Kalskag, Alaska',37692,2);
INSERT INTO "django_geo_db_city" VALUES(30183,'McGrath','McGrath, Alaska',37693,2);
INSERT INTO "django_geo_db_city" VALUES(30184,'Manokotak','Manokotak, Alaska',37694,2);
INSERT INTO "django_geo_db_city" VALUES(30185,'Mekoryuk','Mekoryuk, Alaska',37695,2);
INSERT INTO "django_geo_db_city" VALUES(30186,'Moose Pass','Moose Pass, Alaska',37696,2);
INSERT INTO "django_geo_db_city" VALUES(30187,'Mountain Village','Mountain Village, Alaska',37697,2);
INSERT INTO "django_geo_db_city" VALUES(30188,'Naknek','Naknek, Alaska',37698,2);
INSERT INTO "django_geo_db_city" VALUES(30189,'Napakiak','Napakiak, Alaska',37699,2);
INSERT INTO "django_geo_db_city" VALUES(30190,'Nikiski','Nikiski, Alaska',37700,2);
INSERT INTO "django_geo_db_city" VALUES(30191,'New Stuyahok','New Stuyahok, Alaska',37701,2);
INSERT INTO "django_geo_db_city" VALUES(30192,'Toksook Bay','Toksook Bay, Alaska',37702,2);
INSERT INTO "django_geo_db_city" VALUES(30193,'Nikolski','Nikolski, Alaska',37703,2);
INSERT INTO "django_geo_db_city" VALUES(30194,'Ninilchik','Ninilchik, Alaska',37704,2);
INSERT INTO "django_geo_db_city" VALUES(30195,'Nondalton','Nondalton, Alaska',37705,2);
INSERT INTO "django_geo_db_city" VALUES(30196,'Nunapitchuk','Nunapitchuk, Alaska',37706,2);
INSERT INTO "django_geo_db_city" VALUES(30197,'Old Harbor','Old Harbor, Alaska',37707,2);
INSERT INTO "django_geo_db_city" VALUES(30198,'Ouzinkie','Ouzinkie, Alaska',37708,2);
INSERT INTO "django_geo_db_city" VALUES(30199,'Palmer','Palmer, Alaska',37709,2);
INSERT INTO "django_geo_db_city" VALUES(30200,'Pedro Bay','Pedro Bay, Alaska',37711,2);
INSERT INTO "django_geo_db_city" VALUES(30201,'Perryville','Perryville, Alaska',37712,2);
INSERT INTO "django_geo_db_city" VALUES(30202,'Pilot Point','Pilot Point, Alaska',37713,2);
INSERT INTO "django_geo_db_city" VALUES(30203,'Pilot Station','Pilot Station, Alaska',37714,2);
INSERT INTO "django_geo_db_city" VALUES(30204,'Platinum','Platinum, Alaska',37715,2);
INSERT INTO "django_geo_db_city" VALUES(30205,'Big Lake','Big Lake, Alaska',37716,2);
INSERT INTO "django_geo_db_city" VALUES(30206,'Port Alsworth','Port Alsworth, Alaska',37717,2);
INSERT INTO "django_geo_db_city" VALUES(30207,'Wasilla','Wasilla, Alaska',37718,2);
INSERT INTO "django_geo_db_city" VALUES(30208,'Quinhagak','Quinhagak, Alaska',37719,2);
INSERT INTO "django_geo_db_city" VALUES(30209,'Red Devil','Red Devil, Alaska',37720,2);
INSERT INTO "django_geo_db_city" VALUES(30210,'Russian Mission','Russian Mission, Alaska',37721,2);
INSERT INTO "django_geo_db_city" VALUES(30211,'Saint Marys','Saint Marys, Alaska',37722,2);
INSERT INTO "django_geo_db_city" VALUES(30212,'Saint Michael','Saint Michael, Alaska',37723,2);
INSERT INTO "django_geo_db_city" VALUES(30213,'Saint Paul Island','Saint Paul Island, Alaska',37724,2);
INSERT INTO "django_geo_db_city" VALUES(30214,'Sand Point','Sand Point, Alaska',37725,2);
INSERT INTO "django_geo_db_city" VALUES(30215,'Scammon Bay','Scammon Bay, Alaska',37726,2);
INSERT INTO "django_geo_db_city" VALUES(30216,'Seldovia','Seldovia, Alaska',37727,2);
INSERT INTO "django_geo_db_city" VALUES(30217,'Seward','Seward, Alaska',37728,2);
INSERT INTO "django_geo_db_city" VALUES(30218,'Shageluk','Shageluk, Alaska',37729,2);
INSERT INTO "django_geo_db_city" VALUES(30219,'Sheldon Point','Sheldon Point, Alaska',37730,2);
INSERT INTO "django_geo_db_city" VALUES(30220,'Skwentna','Skwentna, Alaska',37731,2);
INSERT INTO "django_geo_db_city" VALUES(30221,'Sleetmute','Sleetmute, Alaska',37732,2);
INSERT INTO "django_geo_db_city" VALUES(30222,'Soldotna','Soldotna, Alaska',37733,2);
INSERT INTO "django_geo_db_city" VALUES(30223,'South Naknek','South Naknek, Alaska',37734,2);
INSERT INTO "django_geo_db_city" VALUES(30224,'Stebbins','Stebbins, Alaska',37735,2);
INSERT INTO "django_geo_db_city" VALUES(30225,'Sterling','Sterling, Alaska',37736,2);
INSERT INTO "django_geo_db_city" VALUES(30226,'Sutton','Sutton, Alaska',37737,2);
INSERT INTO "django_geo_db_city" VALUES(30227,'Takotna','Takotna, Alaska',37738,2);
INSERT INTO "django_geo_db_city" VALUES(30228,'Talkeetna','Talkeetna, Alaska',37739,2);
INSERT INTO "django_geo_db_city" VALUES(30229,'Tatitlek','Tatitlek, Alaska',37740,2);
INSERT INTO "django_geo_db_city" VALUES(30230,'Togiak','Togiak, Alaska',37741,2);
INSERT INTO "django_geo_db_city" VALUES(30231,'Tuluksak','Tuluksak, Alaska',37742,2);
INSERT INTO "django_geo_db_city" VALUES(30232,'Tuntutuliak','Tuntutuliak, Alaska',37743,2);
INSERT INTO "django_geo_db_city" VALUES(30233,'Tununak','Tununak, Alaska',37744,2);
INSERT INTO "django_geo_db_city" VALUES(30234,'Tyonek','Tyonek, Alaska',37745,2);
INSERT INTO "django_geo_db_city" VALUES(30235,'Trapper Creek','Trapper Creek, Alaska',37746,2);
INSERT INTO "django_geo_db_city" VALUES(30236,'Unalakleet','Unalakleet, Alaska',37747,2);
INSERT INTO "django_geo_db_city" VALUES(30237,'Unalaska','Unalaska, Alaska',37748,2);
INSERT INTO "django_geo_db_city" VALUES(30238,'Valdez','Valdez, Alaska',37749,2);
INSERT INTO "django_geo_db_city" VALUES(30239,'Willow','Willow, Alaska',37751,2);
INSERT INTO "django_geo_db_city" VALUES(30240,'Yakutat','Yakutat, Alaska',37752,2);
INSERT INTO "django_geo_db_city" VALUES(30241,'Nightmute','Nightmute, Alaska',37753,2);
INSERT INTO "django_geo_db_city" VALUES(30242,'Nikolai','Nikolai, Alaska',37754,2);
INSERT INTO "django_geo_db_city" VALUES(30243,'Dutch Harbor','Dutch Harbor, Alaska',37755,2);
INSERT INTO "django_geo_db_city" VALUES(30244,'Whittier','Whittier, Alaska',37756,2);
INSERT INTO "django_geo_db_city" VALUES(30245,'Houston','Houston, Alaska',37757,2);
INSERT INTO "django_geo_db_city" VALUES(30246,'Funny River','Funny River, Alaska',37760,2);
INSERT INTO "django_geo_db_city" VALUES(30247,'Fairbanks','Fairbanks, Alaska',37761,2);
INSERT INTO "django_geo_db_city" VALUES(30248,'Eielson AFB','Eielson AFB, Alaska',37762,2);
INSERT INTO "django_geo_db_city" VALUES(30249,'Fort Wainwright','Fort Wainwright, Alaska',37763,2);
INSERT INTO "django_geo_db_city" VALUES(30250,'Clear','Clear, Alaska',37764,2);
INSERT INTO "django_geo_db_city" VALUES(30251,'North Pole','North Pole, Alaska',37765,2);
INSERT INTO "django_geo_db_city" VALUES(30252,'Salcha','Salcha, Alaska',37773,2);
INSERT INTO "django_geo_db_city" VALUES(30253,'Two Rivers','Two Rivers, Alaska',37774,2);
INSERT INTO "django_geo_db_city" VALUES(30254,'Allakaket','Allakaket, Alaska',37775,2);
INSERT INTO "django_geo_db_city" VALUES(30255,'Anaktuvuk Pass','Anaktuvuk Pass, Alaska',37776,2);
INSERT INTO "django_geo_db_city" VALUES(30256,'Arctic Village','Arctic Village, Alaska',37777,2);
INSERT INTO "django_geo_db_city" VALUES(30257,'Barrow','Barrow, Alaska',37778,2);
INSERT INTO "django_geo_db_city" VALUES(30258,'Beaver','Beaver, Alaska',37779,2);
INSERT INTO "django_geo_db_city" VALUES(30259,'Ester','Ester, Alaska',37780,2);
INSERT INTO "django_geo_db_city" VALUES(30260,'Bettles Field','Bettles Field, Alaska',37781,2);
INSERT INTO "django_geo_db_city" VALUES(30261,'Buckland','Buckland, Alaska',37782,2);
INSERT INTO "django_geo_db_city" VALUES(30262,'Cantwell','Cantwell, Alaska',37783,2);
INSERT INTO "django_geo_db_city" VALUES(30263,'Central','Central, Alaska',37784,2);
INSERT INTO "django_geo_db_city" VALUES(30264,'Chicken','Chicken, Alaska',37785,2);
INSERT INTO "django_geo_db_city" VALUES(30265,'Circle','Circle, Alaska',37786,2);
INSERT INTO "django_geo_db_city" VALUES(30266,'Prudhoe Bay','Prudhoe Bay, Alaska',37787,2);
INSERT INTO "django_geo_db_city" VALUES(30267,'Deering','Deering, Alaska',37788,2);
INSERT INTO "django_geo_db_city" VALUES(30268,'Delta Junction','Delta Junction, Alaska',37789,2);
INSERT INTO "django_geo_db_city" VALUES(30269,'Eagle','Eagle, Alaska',37790,2);
INSERT INTO "django_geo_db_city" VALUES(30270,'Elim','Elim, Alaska',37791,2);
INSERT INTO "django_geo_db_city" VALUES(30271,'Fort Yukon','Fort Yukon, Alaska',37792,2);
INSERT INTO "django_geo_db_city" VALUES(30272,'Galena','Galena, Alaska',37793,2);
INSERT INTO "django_geo_db_city" VALUES(30273,'Gambell','Gambell, Alaska',37794,2);
INSERT INTO "django_geo_db_city" VALUES(30274,'Healy','Healy, Alaska',37795,2);
INSERT INTO "django_geo_db_city" VALUES(30275,'Anderson','Anderson, Alaska',37796,2);
INSERT INTO "django_geo_db_city" VALUES(30276,'Hughes','Hughes, Alaska',37797,2);
INSERT INTO "django_geo_db_city" VALUES(30277,'Huslia','Huslia, Alaska',37798,2);
INSERT INTO "django_geo_db_city" VALUES(30278,'Kaktovik','Kaktovik, Alaska',37799,2);
INSERT INTO "django_geo_db_city" VALUES(30279,'Kaltag','Kaltag, Alaska',37800,2);
INSERT INTO "django_geo_db_city" VALUES(30280,'Kiana','Kiana, Alaska',37801,2);
INSERT INTO "django_geo_db_city" VALUES(30281,'Kivalina','Kivalina, Alaska',37802,2);
INSERT INTO "django_geo_db_city" VALUES(30282,'Kobuk','Kobuk, Alaska',37803,2);
INSERT INTO "django_geo_db_city" VALUES(30283,'Kotzebue','Kotzebue, Alaska',37804,2);
INSERT INTO "django_geo_db_city" VALUES(30284,'Koyuk','Koyuk, Alaska',37805,2);
INSERT INTO "django_geo_db_city" VALUES(30285,'Koyukuk','Koyukuk, Alaska',37806,2);
INSERT INTO "django_geo_db_city" VALUES(30286,'Denali National Park','Denali National Park, Alaska',37807,2);
INSERT INTO "django_geo_db_city" VALUES(30287,'Manley Hot Springs','Manley Hot Springs, Alaska',37808,2);
INSERT INTO "django_geo_db_city" VALUES(30288,'Lake Minchumina','Lake Minchumina, Alaska',37809,2);
INSERT INTO "django_geo_db_city" VALUES(30289,'Minto','Minto, Alaska',37810,2);
INSERT INTO "django_geo_db_city" VALUES(30290,'Point Lay','Point Lay, Alaska',37811,2);
INSERT INTO "django_geo_db_city" VALUES(30291,'Nenana','Nenana, Alaska',37812,2);
INSERT INTO "django_geo_db_city" VALUES(30292,'Noatak','Noatak, Alaska',37813,2);
INSERT INTO "django_geo_db_city" VALUES(30293,'Nome','Nome, Alaska',37814,2);
INSERT INTO "django_geo_db_city" VALUES(30294,'Noorvik','Noorvik, Alaska',37815,2);
INSERT INTO "django_geo_db_city" VALUES(30295,'Northway','Northway, Alaska',37816,2);
INSERT INTO "django_geo_db_city" VALUES(30296,'Nulato','Nulato, Alaska',37817,2);
INSERT INTO "django_geo_db_city" VALUES(30297,'Point Hope','Point Hope, Alaska',37818,2);
INSERT INTO "django_geo_db_city" VALUES(30298,'Rampart','Rampart, Alaska',37819,2);
INSERT INTO "django_geo_db_city" VALUES(30299,'Ruby','Ruby, Alaska',37820,2);
INSERT INTO "django_geo_db_city" VALUES(30300,'Savoonga','Savoonga, Alaska',37821,2);
INSERT INTO "django_geo_db_city" VALUES(30301,'Selawik','Selawik, Alaska',37822,2);
INSERT INTO "django_geo_db_city" VALUES(30302,'Shaktoolik','Shaktoolik, Alaska',37823,2);
INSERT INTO "django_geo_db_city" VALUES(30303,'Shishmaref','Shishmaref, Alaska',37824,2);
INSERT INTO "django_geo_db_city" VALUES(30304,'Shungnak','Shungnak, Alaska',37825,2);
INSERT INTO "django_geo_db_city" VALUES(30305,'Stevens Village','Stevens Village, Alaska',37826,2);
INSERT INTO "django_geo_db_city" VALUES(30306,'Tanacross','Tanacross, Alaska',37828,2);
INSERT INTO "django_geo_db_city" VALUES(30307,'Tanana','Tanana, Alaska',37829,2);
INSERT INTO "django_geo_db_city" VALUES(30308,'Teller','Teller, Alaska',37830,2);
INSERT INTO "django_geo_db_city" VALUES(30309,'Tetlin','Tetlin, Alaska',37831,2);
INSERT INTO "django_geo_db_city" VALUES(30310,'Tok','Tok, Alaska',37832,2);
INSERT INTO "django_geo_db_city" VALUES(30311,'Venetie','Venetie, Alaska',37833,2);
INSERT INTO "django_geo_db_city" VALUES(30312,'Wainwright','Wainwright, Alaska',37834,2);
INSERT INTO "django_geo_db_city" VALUES(30313,'Wales','Wales, Alaska',37835,2);
INSERT INTO "django_geo_db_city" VALUES(30314,'White Mountain','White Mountain, Alaska',37836,2);
INSERT INTO "django_geo_db_city" VALUES(30315,'Brevig Mission','Brevig Mission, Alaska',37837,2);
INSERT INTO "django_geo_db_city" VALUES(30316,'Ambler','Ambler, Alaska',37838,2);
INSERT INTO "django_geo_db_city" VALUES(30317,'Chalkyitsik','Chalkyitsik, Alaska',37839,2);
INSERT INTO "django_geo_db_city" VALUES(30318,'Nuiqsut','Nuiqsut, Alaska',37840,2);
INSERT INTO "django_geo_db_city" VALUES(30319,'Atqasuk','Atqasuk, Alaska',37842,2);
INSERT INTO "django_geo_db_city" VALUES(30320,'Juneau','Juneau, Alaska',37843,2);
INSERT INTO "django_geo_db_city" VALUES(30321,'Angoon','Angoon, Alaska',37847,2);
INSERT INTO "django_geo_db_city" VALUES(30322,'Auke Bay','Auke Bay, Alaska',37848,2);
INSERT INTO "django_geo_db_city" VALUES(30323,'Douglas','Douglas, Alaska',37849,2);
INSERT INTO "django_geo_db_city" VALUES(30324,'Elfin Cove','Elfin Cove, Alaska',37850,2);
INSERT INTO "django_geo_db_city" VALUES(30325,'Gustavus','Gustavus, Alaska',37851,2);
INSERT INTO "django_geo_db_city" VALUES(30326,'Haines','Haines, Alaska',37852,2);
INSERT INTO "django_geo_db_city" VALUES(30327,'Hoonah','Hoonah, Alaska',37853,2);
INSERT INTO "django_geo_db_city" VALUES(30328,'Kake','Kake, Alaska',37854,2);
INSERT INTO "django_geo_db_city" VALUES(30329,'Pelican','Pelican, Alaska',37855,2);
INSERT INTO "django_geo_db_city" VALUES(30330,'Petersburg','Petersburg, Alaska',37856,2);
INSERT INTO "django_geo_db_city" VALUES(30331,'Sitka','Sitka, Alaska',37857,2);
INSERT INTO "django_geo_db_city" VALUES(30332,'Port Alexander','Port Alexander, Alaska',37858,2);
INSERT INTO "django_geo_db_city" VALUES(30333,'Skagway','Skagway, Alaska',37859,2);
INSERT INTO "django_geo_db_city" VALUES(30334,'Tenakee Springs','Tenakee Springs, Alaska',37860,2);
INSERT INTO "django_geo_db_city" VALUES(30335,'Ketchikan','Ketchikan, Alaska',37862,2);
INSERT INTO "django_geo_db_city" VALUES(30336,'Meyers Chuck','Meyers Chuck, Alaska',37863,2);
INSERT INTO "django_geo_db_city" VALUES(30337,'Coffman Cove','Coffman Cove, Alaska',37864,2);
INSERT INTO "django_geo_db_city" VALUES(30338,'Thorne Bay','Thorne Bay, Alaska',37865,2);
INSERT INTO "django_geo_db_city" VALUES(30339,'Craig','Craig, Alaska',37866,2);
INSERT INTO "django_geo_db_city" VALUES(30340,'Hydaburg','Hydaburg, Alaska',37867,2);
INSERT INTO "django_geo_db_city" VALUES(30341,'Hyder','Hyder, Alaska',37868,2);
INSERT INTO "django_geo_db_city" VALUES(30342,'Klawock','Klawock, Alaska',37869,2);
INSERT INTO "django_geo_db_city" VALUES(30343,'Metlakatla','Metlakatla, Alaska',37870,2);
INSERT INTO "django_geo_db_city" VALUES(30344,'Point Baker','Point Baker, Alaska',37871,2);
INSERT INTO "django_geo_db_city" VALUES(30345,'Ward Cove','Ward Cove, Alaska',37872,2);
INSERT INTO "django_geo_db_city" VALUES(30346,'Wrangell','Wrangell, Alaska',37873,2);
CREATE INDEX "django_geo_db_city_c2ff64a1" ON "django_geo_db_city" ("geocoordinate_id");
CREATE INDEX "django_geo_db_city_d5582625" ON "django_geo_db_city" ("state_id");
COMMIT;
